/**
 * Copyright 2000 Systemcorp - All rights reserved. Made in Canada.
 *
 * Description:
 *
 * Author: Tudor Toma
 * Revision: 42
 * Date: 7/31/00 6:18p
 *
 **/
/*
#Stored Procedure  :SP_SEARCH_2
#Short Description :Search and Assign a resource or profile to a element.
#Description       :Search or Search and Assign a resource or profile with effort to a WBS or CRI element.
				   :If search/assign a participant (without effort) all effort related parameters are not required.
				   :Search criteria is a sum of input parameters, witch tells how to filter out the result set.
				   :This function gets called from RPM client, Import and Level/Calculate.
RULE1: cannot assign more then once a resource to a element.
RULE2: cannot assign a resource to a project if the resource is already assigned to a task whitin the project.
RULE3: cannot assign to a task from project reserve more effort then remaining effort at the project.
RULE4: if bitflag = 9 then assignment without effort, otherwise assignment with effort.
RULE5: if bitflag between 1 and 8 the assignment is contoured: contour > 0 and work > 0
RULE6: if search by name then partially ignore the search criteria: org_id, geo_id, pool_id, work_loc, and_roles, and_skills, shw_roles, shw_skills
RULE7: if effort = 0 and bitflag < 9 then both start  finish dates are required
RULE8: if assign units <> 100%, then bitflag < 9 and effort > 0 and both start  finish dates are required
RULE9: cannot assign a resource if is not active, effective date is in the future or discontinue date is in the past
#Table Name        :
#Parameters        :
 $$bitflag  = 0 - ASP ---------------------------------------------------------------------------------------------
            = 1 - Daily         -- contour3
            = 2 - Weekly        -- contour3{, contur1}, {amount falg}
            = 3 - Monthly(C)    -- contour3{, contur2}
            = 4 - Monthly(B)    -- contour3{, contur2}
            = 5 - Monthly(A)    -- contour3{, contur2 | contour2  countour1}
            = 6 - Yearly(C)     -- contour2, contur4
            = 7 - Yearly(B)     -- contour2, contur4, contur1(only one day)
            = 8 - Yearly(A)     -- contour2, contur4, contur1(many days)
            = 9 - Participant
 $$contour (contour structure) ------------------------------------------------------------------------------------
  contur1:  DAY:    bits 0-6    0 = Su, 1 = Mo, 2 = Tu, 3 = We, 4 = Th, 5 = Fr, 6 = Sa,
  contur2:  WEEK:   bits 7-11   A) 7 = week1, 8 = week2, 8 = week3, 9 = week4
                                B) 1-First/2-Second/3-Third/4-Fourth/5-Last
                                C) The Day 1 to 31
  contour3:     EVRY:   bits 12-16  EVRY 1 to 31 day / week / month
  contour4:     MONTH:  bits 17-28  17 = Jan, 18 = Feb, ... 28 = Dec
  2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
  8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
                                                S F T W T M S
                                      w1 to w4  A(7 days from the 1st)
                                      5 4 3 2 1 B(Last, Fourth, Third, Second, First)
                                      31 .... 1 C(The Day 6)
                            31 ........ 1 (Day)
                            31 ........ 1 (week)
                            12 ........ 1 (month)
  D N O S A J J M A M F J (Month)
  Exemple:
  2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1 
  9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 
                                      5-4-3-2-1               B) 1-First/2-Second/3-Third/4-Fourth/5-Last
  X D N O S A J J M A M F J --EVERY-- -THE-DAY- S F T W T M S C) The Day 1 to 31
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 = 4096      1 (every day) 	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 = 8192      1 (every 2nd day) 
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 = 12288     1 (every 3rd day) 
  1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 = 536875014 2 (Monday, Tuesday, every week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 = 4102      2 (Monday, Tuesday, every week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 1 1 0 = 8198      2 (Monday, Monday, every 2nd week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 = 4864      3 (6th day of every month)
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 1 0 = 8322      4 (1st Monday of every 2nd month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 = 4224      5 (week1 of every month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 = 4480      5 (week1, week2 of every month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 1 0 0 0 0 0 0 0 = 8576      5 (week1, week2 of every 2nd month)
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0 0 0 1 1 0 = 8454      5 (Monday, Tuesday, week2 every 2nd month)	
  1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0 0 0 1 1 0 = 536879366 5 (Monday, Tuesday, week2 every 2nd month)	
  0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 = 301990656 6 (6th day of month 9, 12)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 1 0 = 301990146 7 (1st Monday of month 1, 2)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 1 0 0 0 0 0 1 0 0 = 4356      7 (2nd Tuesday, every month)	
  0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 1 1 0 = 301990534 8 (Monday, Tuesday; week1, week3 of month 9, 12)	
  1 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 1 1 0 = 838861446 8 (Monday, Tuesday; week1, week3 of month 9, 12)	
 $$consider_planned_sched ------------------------------------------------------------------------------------------
  CONSIDER                                              inner current project   outer current project   all projects
  scheduled                                                         1                   2                   3
  scheduled  planned                                               4                   5                   6
  NONE(consider all available time)                                 7
  scheduled outer current project				                                        13                  14
  scheduled  planned outer current project				                                15                  16
  scheduled outer current project  planned all projects            20
  scheduled outer current project  planned inner current project   21
  scheduled all projects    planned outer current project          22
  planned inner current project                                     24
  search from project assignments		= 10  pool_id   = resource_id
  search create new profile				= 12  and_roles = the first role_id is used to create a new profile
  duplicate profile						= 12  pool_id   = profile_id
  Note: bits 30 - 31 (in addition to above values): Consider All Scop Element Exceptions = 1 consider, 0 don't consider
  $$eunit, applies to effort
		= 0 MINUTE (default), 
		= 1 h, 
		= 2 d, 
		= 3 w
  $$unit, applies to work
		= 0 h/d,
		= 3 h/w, 
		= 4 h/m, 
		= 1 d/w, 
		= 2 d/m, 
		= 5 w/m
		= 100 then work = percent units
#Returns           :Result Set of resource(s), Best Start date, Best Finish date and daly contour (5*480,2*0,3*400,...) 
				   :For search the number of rows depends on search criteria and is limited by max_rows parameter.
				   :For search/assign is always only one row, the resource whith has been assigned
#Errors            :The errors are returned only in search/assign
				   : TASK_ASSIGNMENT_ERROR (200062) - many reasons the assignment failed.
				   : CHILD_TASK_ASSIGNMENT_ALREADY_EXISTS (20083) - violation of RULE2
				   : CANNOT_ASSIGN_FROM_PROJECT_AFFECTED (20085) - violation of RULE3
				   : RESOURCE_NOT_ACTIVE (200019) - violation of RULE9
				   : F_DATE_EARLIER_THAN_S_DATE - finish date is earlier then start date
				   : 200220 - violation of RULE7
*/
Prompt == FUNCTION SP_SEARCH_2 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
2f8
2 :e:
1FUNCTION:
1SP_SEARCH_2:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1FNAME:
1COST001:
1ORG_ID001:
1GEO_ID001:
1POOL_ID001:
1WORK_LOCATION001:
1AND_ROLES:
1AND_SKILLS:
1SHW_ROLES:
1SHW_SKILLS:
1MAX_ROWS:
1P_UPDATE:
1WORK_TYPE:
1P_TYPE:
1LAST_ID:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_WBS_ID:
132:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RS_ID:
1H_UNIQUEID:
1H_REC_USER:
1H_FNAME:
1255:
1H_COST:
110:
1H_AND_ROLES:
18000:
1H_AND_SKILLS:
1H_SHW_ROLES:
1H_SHW_SKILLS:
1H_AND_ROLE:
1H_AND_SKILL:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_SOURCE_IDS:
1H_TARGET_IDS:
1H_RES_ID:
1H_LAST_ID:
1H_RANK:
1200:
1H_DAYOFYEAR:
1DATE:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_RES_TYPE:
11:
1H_ASSIGN_ID:
1H_ROLE_ID:
1H_SKILL_ID:
1H_FULL_NAME:
1H_REC_STATUS:
1H_BITFLAG:
10:
1H_EXISTS:
1H_TYPE:
1H_COUNT:
1H_UPDATE:
1H_WORK_TYPE:
1H_WORK_LOCATION:
1H_CRI:
1H_MAX_ROWS:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_DURATION:
1H_BIT_MINUTES:
1H_NUMBER:
1H_PRIORITY:
1H_DAYS:
1H_RES_COST:
1NUMBER:
10.00:
1H_RATE_ECHANGE:
1H_TOTAL:
1H_POOL_TYPE:
1H_CURRENCY_ID:
1H_JULIAN_DAY:
1H_J_EFECTIVE_DATE:
1H_J_DISCONTI_DATE:
1H_WEEK:
1H_ACTIVE:
1H_TASK_TYPE:
1H_SCHED_WORK:
1H_PARTICIPANT:
1STMT:
17999:
1STWHERE:
12999:
1H_TEMP_STMT:
1H_TABLE_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_PROFILE_ID:
1H_RESOURCE_ID:
1H_CRI_SECURITY_ID:
1H_CHAR:
1H_TEMP_VAR:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1I:
1II:
1I_ROW:
1I_RETURN:
1ISF:
1TOKEN:
1I_NOSKILL:
1NUMITEMS:
1BCREATEPROFILE:
1LEN:
1K:
1NLEN:
1NLEN001:
1NLEN002:
1C12:
1CURSOR:
1C42:
1PROJECT_ASSIGNMENT_ID:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1TASK_ID:
1RESOURCE_ID:
1SELECT PROJECT_ASSIGNMENT_ID:n         FROM TASK_ASSIGNMENTS:n         WHERE +
1PROJECT_ID = h_project_id:n         AND TASK_ID = h_project_id:n         AND +
1RESOURCE_ID = h_res_id:
1CU42:
1RS_ID:
1RES_ID:
1RTRIM:
1ROLE_ID:
1COALESCE:
1ROLE_NAME:
1SKILL_ID:
1SKILL_NAME:
1SHOW_ROLE:
1SHOW_SKILL:
1PMO_TMP_SEARCH:
1SELECT:n         RS_ID:n         , RES_ID:n         , RTRIM(ROLE_ID):n       +
1  , COALESCE(ROLE_NAME , ''):n         , RTRIM(SKILL_ID):n         , COALESCE+
1(SKILL_NAME , ''):n         , COALESCE(SHOW_ROLE , ''):n         , COALESCE(S+
1HOW_SKILL , ''):n         FROM PMO_TMP_SEARCH:n         ORDER BY RES_ID:
1C775C0:
1C775E1:
1C775E0:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_2(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1196:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_2(197) :: cplan.sql(343) :: :
1PMO_CNST:
1!=:
1SC_SRCH_PARTICIPANT:
1IS NULL:
18:
1239:
1      RETURN_INVALID:: SP_SEARCH_2(240) :: cplan.sql(386) :: :
1 :
1STATE:: :
1ELEMENT_ID_REQUIRED:
1242:
1                EXIT:: SP_SEARCH_2(243) :: cplan.sql(389) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_SRCH_FROM_PROJECT:
1=:
1SC_SRCH_PROFILE:
1251:
1      RETURN_INVALID:: SP_SEARCH_2(252) :: cplan.sql(398) :: :
1INVALID_PARAMS:
1254:
1                EXIT:: SP_SEARCH_2(255) :: cplan.sql(401) :: :
1ELSIF:
1259:
1      RETURN_INVALID:: SP_SEARCH_2(260) :: cplan.sql(406) :: :
1262:
1                EXIT:: SP_SEARCH_2(263) :: cplan.sql(409) :: :
1IS NOT NULL:
1LENGTH:
1<:
114:
1270:
1      RETURN_INVALID:: SP_SEARCH_2(271) :: cplan.sql(417) :: :
1273:
1                EXIT:: SP_SEARCH_2(274) :: cplan.sql(420) :: :
1280:
1      RETURN_INVALID:: SP_SEARCH_2(281) :: cplan.sql(427) :: :
1283:
1                EXIT:: SP_SEARCH_2(284) :: cplan.sql(430) :: :
15:
1290:
1      RETURN_INVALID:: SP_SEARCH_2(291) :: cplan.sql(437) :: :
1293:
1                EXIT:: SP_SEARCH_2(294) :: cplan.sql(440) :: :
1265:
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1317:
1           EXCEPTION:: SP_SEARCH_2(318) :: cplan.sql(464) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1324:
1      RETURN_INVALID:: SP_SEARCH_2(325) :: cplan.sql(471) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1327:
1                EXIT:: SP_SEARCH_2(328) :: cplan.sql(474) :: :
1SELECT SYSTIMESTAMP INTO h_start_date FROM DUAL:
1343:
1           EXCEPTION:: SP_SEARCH_2(344) :: cplan.sql(490) :: :
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1>:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1375:
1           EXCEPTION:: SP_SEARCH_2(376) :: cplan.sql(522) :: :
1REC_STATUS:
1TMT_WBS:
1ELEMENT_ID:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1391:
1           EXCEPTION:: SP_SEARCH_2(392) :: cplan.sql(538) :: :
1STRCMP:
1L:
1398:
1        RETURN_ERROR:: SP_SEARCH_2(399) :: cplan.sql(545) :: :
1LEV_LOCKED_BY_COPY:
1 ID:: :
1401:
1                EXIT:: SP_SEARCH_2(402) :: cplan.sql(548) :: :
1PMO_RETURN_ERROR_SP:
1GETTABLE:
1GETASSNTYPE:
1412:
1      RETURN_INVALID:: SP_SEARCH_2(413) :: cplan.sql(559) :: :
1415:
1                EXIT:: SP_SEARCH_2(416) :: cplan.sql(562) :: :
1SC_TABLE_WBS:
1428:
1      RETURN_INVALID:: SP_SEARCH_2(429) :: cplan.sql(575) :: :
1431:
1                EXIT:: SP_SEARCH_2(432) :: cplan.sql(578) :: :
1ASSIGNRESOURCE:
1446:
1        RETURN_ERROR:: SP_SEARCH_2(447) :: cplan.sql(593) :: :
1449:
1                EXIT:: SP_SEARCH_2(450) :: cplan.sql(596) :: :
1455:
1        RETURN_ERROR:: SP_SEARCH_2(456) :: cplan.sql(602) :: :
1458:
1                EXIT:: SP_SEARCH_2(459) :: cplan.sql(605) :: :
1ISPROJECTTYPE:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1SELECT:n               PROJECT_ID:n               , COALESCE(MINUTE_PER_DAY, +
1480):n               , COALESCE(MINUTE_PER_WEEK, 2400):n               , PRIO+
1RITY:n               INTO:n               h_project_id:n               , h_pe+
1r_day:n               , h_per_week:n               , h_priority:n            +
1   FROM TMT_WBS:n               WHERE ELEMENT_ID = h_task_id:
1484:
1           EXCEPTION:: SP_SEARCH_2(485) :: cplan.sql(631) :: :
1B:
1TASK_TYPE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1A:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1SELECT:n               B.TASK_TYPE:n               , B.UNRESOLVED_START:n    +
1           , B.UNRESOLVED_FINISH:n               , B.PROJECT_ID:n            +
1   , COALESCE(A.MINUTE_PER_DAY, 480):n               , COALESCE(A.MINUTE_PER_+
1WEEK, 2400):n               , A.PRIORITY:n               , B.PLANNED_EFFORT ++
1 B.SCHED_EFFORT:n               INTO:n               h_task_type:n           +
1    , h_task_start_DT:n               , h_task_finish_DT:n               , h_+
1project_id:n               , h_per_day:n               , h_per_week:n        +
1       , h_priority:n               , h_sched_work:n               FROM TMT_W+
1BS A, TMT_WBS B:n               WHERE B.ELEMENT_ID = h_task_id:n             +
1  AND A.ELEMENT_ID = B.PROJECT_ID:
1517:
1           EXCEPTION:: SP_SEARCH_2(518) :: cplan.sql(664) :: :
1525:
1        RETURN_ERROR:: SP_SEARCH_2(526) :: cplan.sql(672) :: :
1RECORD_NOT_FOUND:
1528:
1                EXIT:: SP_SEARCH_2(529) :: cplan.sql(675) :: :
1SC_TABLE_CRI:
1TYPE_ID:
1WBS_ID:
1TMT_CRI:
1SELECT:n            PROJECT_ID:n            , TYPE_ID:n            , WBS_ID:n+
1            INTO:n            h_project_id:n            , h_type:n           +
1 , h_wbs_id:n            FROM TMT_CRI:n            WHERE ELEMENT_ID = h_task_+
1id:
1550:
1           EXCEPTION:: SP_SEARCH_2(551) :: cplan.sql(697) :: :
1557:
1        RETURN_ERROR:: SP_SEARCH_2(558) :: cplan.sql(704) :: :
1560:
1                EXIT:: SP_SEARCH_2(561) :: cplan.sql(707) :: :
1START_DT:
1TO_TIMESTAMP:
1SELECT:n            CASE:n            WHEN START_DT > h_start_DT:n           +
1 THEN START_DT:n            ELSE TO_TIMESTAMP(h_start_DT):n            END:n +
1           , COALESCE(MINUTE_PER_DAY, 480):n            , COALESCE(MINUTE_PER+
1_WEEK, 2400):n            , PRIORITY:n            INTO:n            h_start_D+
1T:n            , h_per_day:n            , h_per_week:n            , h_priorit+
1y:n            FROM TMT_WBS:n            WHERE PROJECT_ID = h_project_id:n   +
1         AND ELEMENT_ID = h_project_id:
1591:
1           EXCEPTION:: SP_SEARCH_2(592) :: cplan.sql(738) :: :
1598:
1        RETURN_ERROR:: SP_SEARCH_2(599) :: cplan.sql(745) :: :
1601:
1                EXIT:: SP_SEARCH_2(602) :: cplan.sql(748) :: :
1FC_MIRROR_TYPE:
1616:
1        RETURN_ERROR:: SP_SEARCH_2(617) :: cplan.sql(763) :: :
1619:
1                EXIT:: SP_SEARCH_2(620) :: cplan.sql(766) :: :
1NICK_NAME:
1JULIAN_DAY:
1ACTIVE:
1EFFECTIVE_DATE:
1DISCONTINUE_DATE:
1RESOURCES:
1SELECT:n            NICK_NAME:n            , PMO_ORASTD.JULIAN_DAY(h_start_DT+
1):n            , ACTIVE:n            , COALESCE(PMO_ORASTD.JULIAN_DAY(EFFECTI+
1VE_DATE) ,0):n            , COALESCE(PMO_ORASTD.JULIAN_DAY(DISCONTINUE_DATE) +
1,0):n            INTO:n            h_full_name:n            , h_julian_day:n +
1           , h_active:n            , h_j_efective_date:n            , h_j_dis+
1conti_date:n            FROM RESOURCES:n            WHERE RESOURCE_ID = h_res+
1_id:
1648:
1           EXCEPTION:: SP_SEARCH_2(649) :: cplan.sql(795) :: :
1SC_SQL_NO_DATA:
1655:
1        RETURN_ERROR:: SP_SEARCH_2(656) :: cplan.sql(802) :: :
1658:
1                EXIT:: SP_SEARCH_2(659) :: cplan.sql(805) :: :
1666:
1        RETURN_ERROR:: SP_SEARCH_2(667) :: cplan.sql(813) :: :
1RESOURCE_NOT_ACTIVE:
1669:
1                EXIT:: SP_SEARCH_2(670) :: cplan.sql(816) :: :
1688:
1        RETURN_ERROR:: SP_SEARCH_2(689) :: cplan.sql(835) :: :
1CANNOT_ASSIGN_COMPETENCY:
1691:
1                EXIT:: SP_SEARCH_2(692) :: cplan.sql(838) :: :
1SELECT:n            PRIORITY:n            , COALESCE(MINUTE_PER_DAY, 480):n  +
1          , COALESCE(MINUTE_PER_WEEK, 2400):n            INTO:n            h_+
1priority:n            , h_per_day:n            , h_per_week:n            FROM+
1 TMT_WBS:n            WHERE ELEMENT_ID = h_project_id:
1716:
1           EXCEPTION:: SP_SEARCH_2(717) :: cplan.sql(863) :: :
1TMT_POOLS:
1SELECT:n               480:n               , 2400:n               INTO:n     +
1          h_per_day:n               , h_per_week:n               FROM TMT_POO+
1LS WHERE ELEMENT_ID = h_project_id:
1738:
1           EXCEPTION:: SP_SEARCH_2(739) :: cplan.sql(885) :: :
1745:
1        RETURN_ERROR:: SP_SEARCH_2(746) :: cplan.sql(892) :: :
1748:
1                EXIT:: SP_SEARCH_2(749) :: cplan.sql(895) :: :
1100:
11899-12-31 00::00::00:
1:
1FC_CALC_DURATION:
1785:
1      RETURN_INVALID:: SP_SEARCH_2(786) :: cplan.sql(932) :: :
1788:
1                EXIT:: SP_SEARCH_2(789) :: cplan.sql(935) :: :
1793:
1        RETURN_ERROR:: SP_SEARCH_2(794) :: cplan.sql(940) :: :
1796:
1                EXIT:: SP_SEARCH_2(797) :: cplan.sql(943) :: :
12:
13:
14:
1SYS_GUID:
1PROFILES:
1PROFILE_ID:
1SELECT REC_STATUS INTO h_rec_status:n            FROM PROFILES:n            W+
1HERE PROFILE_ID = h_res_id:
1851:
1           EXCEPTION:: SP_SEARCH_2(852) :: cplan.sql(998) :: :
1RES_ASSIGNMENT_ID:
1RESOURCE_ASSIGNMENTS:
1RESOURCE_TYPE:
1PARTICIPANT:
1SC_TEAMMEMBER:
1SELECT:n                  RES_ASSIGNMENT_ID:n                  INTO:n        +
1          h_uniqueID:n                  FROM RESOURCE_ASSIGNMENTS:n          +
1        WHERE ELEMENT_ID = h_task_id:n                  AND RESOURCE_ID = h_r+
1es_id:n                  AND RESOURCE_TYPE = '1':n                  AND PARTI+
1CIPANT = PMO_CNST.SC_TEAMMEMBER:
1874:
1           EXCEPTION:: SP_SEARCH_2(875) :: cplan.sql(1021) :: :
1MAX:
1PROF_NUMBER:
1SELECT:n            COALESCE(MAX(PROF_NUMBER),0)+1:n            INTO:n       +
1     h_number:n            FROM PROFILES:n            WHERE PROJECT_ID=h_proj+
1ect_id:n            AND ROLE_ID=h_role_id:
1903:
1           EXCEPTION:: SP_SEARCH_2(904) :: cplan.sql(1050) :: :
1STRINGCONCAT:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1PARENT_ID:
1SELECT:n            PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORAST+
1D.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEM+
1ENT_NAME):n            , ', '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(+
1h_number))), ')'):n            INTO h_full_name:n            FROM TMT_COMPETE+
1NCIES TC, TMT_COMPETENCIES TCP:n            WHERE TC.ELEMENT_ID = h_role_id:n+
1            AND TCP.ELEMENT_ID = TC.PARENT_ID:
1922:
1           EXCEPTION:: SP_SEARCH_2(923) :: cplan.sql(1069) :: :
1929:
1        RETURN_ERROR:: SP_SEARCH_2(930) :: cplan.sql(1076) :: :
1932:
1                EXIT:: SP_SEARCH_2(933) :: cplan.sql(1079) :: :
1U:
1D:
1PROFILE_NAME:
1POOL_ID:
1GEO_ID:
1ORG_ID:
1INSERT INTO PROFILES:n            (:n            PROFILE_ID:n            , PR+
1OJECT_ID:n            , ROLE_ID:n            , PROF_NUMBER:n            , PRO+
1FILE_NAME:n            , REC_STATUS:n            , POOL_ID:n            , GEO+
1_ID:n            , ORG_ID:n            ):n            VALUES:n            (:n+
1            h_res_id:n            , h_project_id:n            , h_role_id:n  +
1          , h_number:n            , h_full_name:n            , h_char:n      +
1      , pool_id001:n            , geo_id001:n            , org_id001:n       +
1     ):
1FOUND:
1974:
1           EXCEPTION:: SP_SEARCH_2(975) :: cplan.sql(1121) :: :
1UPDATE PROFILES SET REC_STATUS = 'U',:n            POOL_ID = pool_id001,:n   +
1         GEO_ID  = geo_id001,:n            ORG_ID  = org_id001:n            W+
1HERE PROFILE_ID = h_res_id:
1997:
1           EXCEPTION:: SP_SEARCH_2(998) :: cplan.sql(1144) :: :
1RESOURCE_ASSIGN_SKILLS:
1DELETE FROM RESOURCE_ASSIGN_SKILLS:n         WHERE RES_ASSIGNMENT_ID IN (:n  +
1       SELECT PROFILE_ID:n         FROM PROFILES:n         WHERE PROJECT_ID =+
1 h_project_id:n         AND REC_STATUS='D':n         AND PROFILE_ID <> h_res_+
1id):
11023:
1           EXCEPTION:: SP_SEARCH_2(1024) :: cplan.sql(1170) :: :
1RESOURCE_ASSIGN_ROLES:
1DELETE FROM RESOURCE_ASSIGN_ROLES:n         WHERE RES_ASSIGNMENT_ID IN (:n   +
1      SELECT PROFILE_ID:n         FROM PROFILES:n         WHERE PROJECT_ID = +
1h_project_id:n         AND REC_STATUS='D':n         AND PROFILE_ID <> h_res_i+
1d):
11046:
1           EXCEPTION:: SP_SEARCH_2(1047) :: cplan.sql(1193) :: :
1DELETE FROM PROFILES:n         WHERE PROJECT_ID = h_project_id:n         AND +
1REC_STATUS='D':n         AND PROFILE_ID <> h_res_id:
11066:
1           EXCEPTION:: SP_SEARCH_2(1067) :: cplan.sql(1213) :: :
1FC_DECLARE_PMO_TMP_SEARCH:
1SC_MAX_ROWS:
1SELECT ':
1' AS RESOURCE_ID :
1FROM TMT_COMPETENCIES r :
1WHERE r.TYPE_ID=73 :
1      AND r.ELEMENT_ID = ':
1SELECT ra.RESOURCE_ID :
1FROM RESOURCE_ASSIGNMENTS ra :
1JOIN TASK_ASSIGNMENTS ta ON ra.ELEMENT_ID=':
1' :
1AND ra.RESOURCE_ID=':
1AND ra.RES_ASSIGNMENT_ID=ta.RES_ASSIGNMENT_ID :
1SELECT r.RESOURCE_ID :
1FROM RESOURCES r :
1WHERE r.CALENDAR_ID IS NOT NuLL :
1        AND r.RESOURCE_ID = ':
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN_0007:
1DELETE FROM PMO_TMP_CPLN_007a:
1PMO_TMP_CPLN_007A:
1RANK:
1PUBLIC_FLAG:
1P:
1JOIN:
1RA:
1ELEMENT_TYPE:
1INSERT INTO PMO_TMP_CPLN_007a:n               SELECT ELEMENT_ID, RANK:n      +
1         FROM TMT_POOLS:n               WHERE PUBLIC_FLAG = '1':n            +
1   UNION ALL:n               ---- All pools to which the resource is assigned+
1:n               SELECT P.ELEMENT_ID, P.RANK:n               FROM TMT_POOLS P+
1:n               JOIN RESOURCE_ASSIGNMENTS RA ON:n               P.ELEMENT_ID+
1 = RA.ELEMENT_ID:n               AND RA.ELEMENT_TYPE = 11:n               AND+
1 RA.RESOURCE_ID = h_rec_user:
11191:
1           EXCEPTION:: SP_SEARCH_2(1192) :: cplan.sql(1338) :: :
1PMO_TMP_CPLN_0007:
1M:
1INSERT INTO PMO_TMP_CPLN_0007:n               SELECT M.RANK:n               F+
1ROM PMO_TMP_CPLN_007a M:n               WHERE NOT EXISTS (:n               SE+
1LECT A.ELEMENT_ID:n               FROM PMO_TMP_CPLN_007a A:n               WH+
1ERE A.RANK < M.RANK:n               AND SUBSTR(M.RANK, 1, LENGTH(A.RANK)) = A+
1.RANK):
11229:
1           EXCEPTION:: SP_SEARCH_2(1230) :: cplan.sql(1376) :: :
1INSERT INTO PMO_TMP_CPLN_0007:n               SELECT RANK FROM TMT_POOLS:n   +
1            WHERE ELEMENT_ID = h_res_id:
11252:
1           EXCEPTION:: SP_SEARCH_2(1253) :: cplan.sql(1399) :: :
132767:
165535:
1-:
165536:
1WHILE:
1LOOP:
1ASCII:
137:
195:
1EXIT:
11276:
1      RETURN_INVALID:: SP_SEARCH_2(1277) :: cplan.sql(1423) :: :
11279:
1                EXIT:: SP_SEARCH_2(1280) :: cplan.sql(1426) :: :
1REPLACE:
1SELECT REPLACE(h_fname,'''',''''''):n            INTO h_fname:n            FR+
1OM DUAL:
11294:
1           EXCEPTION:: SP_SEARCH_2(1295) :: cplan.sql(1441) :: :
1SELECT p.PROFILE_ID AS RESOURCE_ID FROM PROFILES p JOIN TMT_COMPETENCIES r ON+
1 p.ROLE_ID = r.ELEMENT_ID:
1 WHERE p.PROFILE_ID=':
1SELECT r.RESOURCE_ID FROM RESOURCES r JOIN RESOURCE_ASSIGNMENTS ra ON BITAND(+
1ra.PARTICIPANT,4096)>0 AND ra.ELEMENT_ID=':
1' AND ra.RESOURCE_ID=r.RESOURCE_ID:
1 WHERE 0=0 :
1SELECT DISTINCT r.RESOURCE_ID FROM RESOURCES r:
1 AND r.RESOURCE_ID > ':
1 AND r.CALENDAR_ID IS NOT NuLL :
1AND UPPER(r.FULL_NAME) like UPPER(':
1%'):
1SELECT DISTINCT r.RESOURCE_ID :
1FROM TMT_POOLS TP, PMO_TMP_CPLN_0007 MP, RESOURCES r:
1AND TP.ELEMENT_ID=R.RESOURCE_ID :
1  AND (MP.RANK >= SUBSTR(TP.RANK, 1, 8) :
1        AND MP.RANK <= TP.RANK :
1        AND length(MP.RANK) <= length(TP.RANK) :
1        AND substr(TP.RANK, 1, length(MP.RANK)) = MP.RANK) :
1  AND r.CALENDAR_ID IS NOT NuLL :
1  AND UPPER(r.FULL_NAME) LIKE UPPER(':
1SELECT RANK INTO h_rank:n               FROM TMT_POOLS:n               WHERE +
1ELEMENT_ID = pool_id001:
11372:
1           EXCEPTION:: SP_SEARCH_2(1373) :: cplan.sql(1519) :: :
1,TMT_POOLS p:
1 AND r.RESOURCE_ID = p.ELEMENT_ID :
1AND p.RANK LIKE ':
1%' :
11386:
1        RETURN_ERROR:: SP_SEARCH_2(1387) :: cplan.sql(1533) :: :
11389:
1                EXIT:: SP_SEARCH_2(1390) :: cplan.sql(1536) :: :
1TMT_ORGANIZATIONS:
1SELECT RANK INTO h_rank:n               FROM TMT_ORGANIZATIONS:n             +
1  WHERE ELEMENT_ID = org_id001:
11406:
1           EXCEPTION:: SP_SEARCH_2(1407) :: cplan.sql(1553) :: :
1,TMT_ORGANIZATIONS o:
1 AND r.RESOURCE_ID=o.ELEMENT_ID :
1AND o.RANK LIKE ':
11417:
1        RETURN_ERROR:: SP_SEARCH_2(1418) :: cplan.sql(1564) :: :
11420:
1                EXIT:: SP_SEARCH_2(1421) :: cplan.sql(1567) :: :
1TMT_GEOGRAPHIES:
1SELECT RANK INTO h_rank:n               FROM TMT_GEOGRAPHIES:n               +
1WHERE ELEMENT_ID = geo_id001:
11437:
1           EXCEPTION:: SP_SEARCH_2(1438) :: cplan.sql(1584) :: :
1,TMT_GEOGRAPHIES g:
1 AND r.RESOURCE_ID=g.ELEMENT_ID :
1AND g.RANK LIKE ':
11448:
1        RETURN_ERROR:: SP_SEARCH_2(1449) :: cplan.sql(1595) :: :
11451:
1                EXIT:: SP_SEARCH_2(1452) :: cplan.sql(1598) :: :
1 AND r.WORK_LOCATION=:
1PMO_STPU:
1STRNPCPY:
1SELECT RANK INTO h_rank:n               FROM TMT_COMPETENCIES:n              +
1 WHERE ELEMENT_ID = h_role_id:
11481:
1           EXCEPTION:: SP_SEARCH_2(1482) :: cplan.sql(1628) :: :
11488:
1        RETURN_ERROR:: SP_SEARCH_2(1489) :: cplan.sql(1635) :: :
11491:
1                EXIT:: SP_SEARCH_2(1492) :: cplan.sql(1638) :: :
1 AND EXISTS :
1(SELECT t1.ELEMENT_ID :
1  FROM TMT_COMPETENCIES t1:
1  WHERE t1.RANK LIKE ':
1%':
1AND r.ELEMENT_ID=t1.ELEMENT_ID) :
1AND r.RESOURCE_ID=t1.RESOURCE_ID) :
11534:
1           EXCEPTION:: SP_SEARCH_2(1535) :: cplan.sql(1681) :: :
11541:
1        RETURN_ERROR:: SP_SEARCH_2(1542) :: cplan.sql(1688) :: :
11544:
1                EXIT:: SP_SEARCH_2(1545) :: cplan.sql(1691) :: :
1     AND r.RESOURCE_ID=t1.RESOURCE_ID) :
1 ORDER BY RESOURCE_ID  :
1OPEN:
1CLOSE:
11606:
1           EXCEPTION:: SP_SEARCH_2(1607) :: cplan.sql(1753) :: :
1CONTINUE0000:
11624:
1           EXCEPTION:: SP_SEARCH_2(1625) :: cplan.sql(1771) :: :
1COUNT:
1TSK_ASSIGNMENT_ID:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_temp_var :n                  FROM TASK+
1_ASSIGNMENTS:n                  WHERE PROJECT_ID = h_project_id:n            +
1      AND RESOURCE_ID = h_res_id:n                  AND RESOURCE_TYPE = '0':
11653:
1           EXCEPTION:: SP_SEARCH_2(1654) :: cplan.sql(1800) :: :
11667:
1           EXCEPTION:: SP_SEARCH_2(1668) :: cplan.sql(1814) :: :
11673:
1        RETURN_ERROR:: SP_SEARCH_2(1674) :: cplan.sql(1820) :: :
1CHILD_TASK_ASSIGNMENT_ALREADY_:
11676:
1                EXIT:: SP_SEARCH_2(1677) :: cplan.sql(1823) :: :
1FC_SEARCH_2:
11700:
1           EXCEPTION:: SP_SEARCH_2(1701) :: cplan.sql(1847) :: :
1DB_OFFSET:
1TASK_ASSIGNMENT_ERROR:
11710:
1        RETURN_ERROR:: SP_SEARCH_2(1711) :: cplan.sql(1857) :: :
11713:
1                EXIT:: SP_SEARCH_2(1714) :: cplan.sql(1860) :: :
1UPDATE PROFILES SET REC_STATUS='U' WHERE PROFILE_ID = h_res_id AND REC_STATUS+
1='D':
11729:
1           EXCEPTION:: SP_SEARCH_2(1730) :: cplan.sql(1876) :: :
11769:
1           EXCEPTION:: SP_SEARCH_2(1770) :: cplan.sql(1916) :: :
1ASSIGN_STRING_TOLONG:
11778:
1        RETURN_ERROR:: SP_SEARCH_2(1779) :: cplan.sql(1925) :: :
11781:
1                EXIT:: SP_SEARCH_2(1782) :: cplan.sql(1928) :: :
1NOTNULL:
1UPDATE PMO_TMP_SEARCH SET:n                  ROLE_ID = h_source_ids:n        +
1          , ROLE_NAME = h_and_roles:n                  , SKILL_ID = h_target_+
1ids:n                  , SKILL_NAME = h_and_skills:n                  , SHOW_+
1ROLE = h_shw_roles:n                  , SHOW_SKILL = h_shw_skills:n          +
1        WHERE RS_ID = h_last_id:
11847:
1           EXCEPTION:: SP_SEARCH_2(1848) :: cplan.sql(1994) :: :
1UPDATE PMO_TMP_SEARCH SET:n               ROLE_ID = NuLL:n               , RO+
1LE_NAME = NuLL:n               , SKILL_ID = NuLL:n               , SKILL_NAME+
1 = NuLL:n               , SHOW_ROLE = NuLL:n               , SHOW_SKILL = NuL+
1L:n               WHERE RS_ID = h_last_id:
11888:
1           EXCEPTION:: SP_SEARCH_2(1889) :: cplan.sql(2035) :: :
1,:
11947:
1           EXCEPTION:: SP_SEARCH_2(1948) :: cplan.sql(2094) :: :
1UPDATE PMO_TMP_SEARCH SET:n            ROLE_ID = h_source_ids:n            , +
1ROLE_NAME = h_and_roles:n            , SKILL_ID = h_target_ids:n            ,+
1 SKILL_NAME = h_and_skills:n            , SHOW_ROLE = h_shw_roles:n          +
1  , SHOW_SKILL = h_shw_skills:n            WHERE RS_ID = h_last_id:
11973:
1           EXCEPTION:: SP_SEARCH_2(1974) :: cplan.sql(2120) :: :
1SUM:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1DAY_YEAR:
1TO_DATE:
1SELECT COALESCE(SUM(AVAILABLE_MIN),0) INTO h_effort:n            FROM CALENDA+
1R_DAY_OF_YEAR:n            WHERE ELEMENT_ID=h_project_id:n            AND DAY+
1_YEAR BETWEEN TO_DATE(SubStr(h_start_DT, 1, 10)) AND TO_DATE(SubStr(h_finish_+
1DT, 1, 10)):
11993:
1           EXCEPTION:: SP_SEARCH_2(1994) :: cplan.sql(2140) :: :
1CURRENCY_ID:
1TODECIMAL:
1TD:
1TW:
1TMT_DATAFIELDS:
1SELECT CURRENCY_ID, PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4) INTO h_currenc+
1y_id, h_rate_echange:n      FROM TMT_WBS tw JOIN TMT_DATAFIELDS td on tw.CURR+
1ENCY_ID = td.ELEMENT_ID:n      WHERE tw.ELEMENT_ID = h_project_id:
12013:
1           EXCEPTION:: SP_SEARCH_2(2014) :: cplan.sql(2160) :: :
1DELETE FROM PMO_TMP_CPLN_0005:
1PMO_TMP_CPLN_0005:
1REGULAR_COST:
1REGULAR_SALE:
1SPECIAL_COST:
1SPECIAL_SALE:
1INSERT INTO PMO_TMP_CPLN_0005:n         SELECT RES_ID:n         , REGULAR_COS+
1T:n         , REGULAR_SALE:n         , SPECIAL_COST:n         , SPECIAL_SALE+
1:n         FROM PMO_TMP_SEARCH:n         WHERE RS_ID = h_rs_id:n         AND +
1(REGULAR_COST + REGULAR_SALE) > 0:
12049:
1           EXCEPTION:: SP_SEARCH_2(2050) :: cplan.sql(2196) :: :
1INSERT INTO PMO_TMP_CPLN_0005:n            SELECT RES_ID:n            , MAX(R+
1EGULAR_COST) AS REGULAR_COST:n            , MAX(REGULAR_SALE) AS REGULAR_SALE+
1:n            , MAX(SPECIAL_COST) AS SPECIAL_COST:n            , MAX(SPECIAL_+
1SALE) AS SPECIAL_SALE:n            FROM PMO_TMP_SEARCH:n            WHERE RS_+
1ID <> h_rs_id:n            GROUP BY RES_ID:
12076:
1           EXCEPTION:: SP_SEARCH_2(2077) :: cplan.sql(2223) :: :
1INSERT INTO PMO_TMP_CPLN_0005:n               SELECT RES_ID, 0.00, 0.00, 0.00+
1, 0.00:n               FROM PMO_TMP_SEARCH:n               WHERE RS_ID = h_rs+
1_id:n               GROUP BY RES_ID:
12098:
1           EXCEPTION:: SP_SEARCH_2(2099) :: cplan.sql(2245) :: :
1RS:
1WORK_LOCATION:
1O1:
1ORGANIZATION:
1G1:
1GEOGRAPHY:
1ROUND:
1PA:
1RES_SALE_RATE:
1TEMP:
1REGULAR_RATE:
1SPECIAL_RATE:
1START_DATE:
1FINISH_DATE:
1ASSIGNABLE:
1PLANNED:
1SCHED:
1PROPOSED:
1WORK_EFFORT:
1UNIT_EFFORT:
1AVAILABLE:
1VERIFIED:
1STATUS2_ID:
1FULL_NAME:
1PP:
1POOL_NAME:
1E_MAIL_ADDRESS:
1UNIQUE_ID:
1CONTOUR:
1ASSIGN_STRING:
1ASSIGNED_FLAG:
1FS_LABOR_CODE:
1RES_MODIFIED_DATE:
1LEFT:
1OUTER:
1PROJECT_ASSIGNMENTS:
1R:
1RATES:
1RATE_ID:
1SELECT h_res_id AS ELEMENT_ID, 41 AS TYPE_ID, p.PROFILE_NAME AS ELEMENT_NAME,+
1 rs.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL, h_work_location AS+
1 WORK_LOCATION,:n      o1.ELEMENT_NAME AS ORGANIZATION,g1.ELEMENT_NAME AS GEO+
1GRAPHY,:n      ROUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.REGULAR_COST WHEN rs+
1.RES_SALE_RATE=0 THEN temp.REGULAR_COST * h_rate_echange ELSE a.REGULAR_COST +
1* h_rate_echange END,2) AS REGULAR_COST,:n      ROUND(CASE WHEN pa.REGULAR_RA+
1TE>0 THEN pa.REGULAR_RATE WHEN rs.RES_SALE_RATE=0 THEN temp.REGULAR_SALE * h_+
1rate_echange ELSE a.REGULAR_SALE * h_rate_echange END,2) AS REGULAR_SALE,:n  +
1    ROUND(CASE WHEN pa.SPECIAL_COST>0 THEN pa.SPECIAL_COST WHEN rs.RES_SALE_R+
1ATE=0 THEN temp.SPECIAL_COST * h_rate_echange ELSE a.SPECIAL_COST * h_rate_ec+
1hange END,2) AS SPECIAL_COST,:n      ROUND(CASE WHEN pa.SPECIAL_RATE>0 THEN p+
1a.SPECIAL_RATE WHEN rs.RES_SALE_RATE=0 THEN temp.SPECIAL_SALE * h_rate_echang+
1e ELSE a.SPECIAL_SALE * h_rate_echange END,2) AS SPECIAL_SALE,:n      rs.STAR+
1T_DATE,rs.FINISH_DATE,rs.ASSIGNABLE,rs.PLANNED,rs.SCHED, CASE WHEN rs.PROPOSE+
1D > 0 THEN rs.PROPOSED ELSE h_effort END AS WORK_EFFORT, h_eunit AS UNIT_EFFO+
1RT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS AVAILABLE,:n      '' AS VERIFIE+
1D, 0 AS STATUS2_ID, '' AS FULL_NAME, pp.ELEMENT_NAME AS POOL_NAME, '' AS E_MA+
1IL_ADDRESS, '' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIG+
1N_STRING, h_and_roles AS ROLE_ID, h_and_skills AS SKILL_ID, 0 AS ASSIGNED_FLA+
1G,:n      'PMOFFICE' AS FS_LABOR_CODE, TO_TIMESTAMP('1899-12-31 00::00::00') +
1AS RES_MODIFIED_DATE:n      FROM PMO_TMP_CPLN_0005 temp JOIN PMO_TMP_SEARCH r+
1s ON rs.RES_ID = temp.RES_ID:n      LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON+
1 pa.PROJECT_ID=h_project_id AND pa.RESOURCE_ID=rs.RES_ID:n      JOIN PROFILES+
1 p ON p.PROFILE_ID = h_res_id:n      JOIN TMT_COMPETENCIES r ON p.ROLE_ID=r.E+
1LEMENT_ID:n      LEFT OUTER JOIN RATES a ON r.RATE_ID=a.RATE_ID:n      LEFT O+
1UTER JOIN TMT_ORGANIZATIONS o1 ON p.ORG_ID = o1.ELEMENT_ID:n      LEFT OUTER +
1JOIN TMT_GEOGRAPHIES g1 ON p.GEO_ID = g1.ELEMENT_ID:n      LEFT OUTER JOIN TM+
1T_POOLS pp ON pp.ELEMENT_ID = p.POOL_ID:n      WHERE NOT (rs.ROLE_NAME IS NuL+
1L AND rs.SKILL_NAME IS NuLL AND rs.SHOW_ROLE IS NuLL AND rs.SHOW_SKILL IS NuL+
1L):
12124:
1                EXIT:: SP_SEARCH_2(2125) :: cplan.sql(2271) :: :
1O2:
1G2:
1DEFAULT_FLAG:
1RV:
1RM:
1PLANNED_WORK:
1SCHED_WORK:
1REC_DATETIME:
1MANAGER_ID:
1VERIFIED_1:
1SELECT rs.RES_ID AS ELEMENT_ID, 13 AS TYPE_ID, r.FULL_NAME AS ELEMENT_NAME, r+
1s.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL, r.WORK_LOCATION,:n  +
1       o2.ELEMENT_NAME AS ORGANIZATION,g2.ELEMENT_NAME AS GEOGRAPHY,:n       +
1  ROUND(CASE WHEN rs.DEFAULT_FLAG='0' THEN rs.REGULAR_COST * CASE WHEN (r.CUR+
1RENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE +
1(SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELE+
1MENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FR+
1OM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END WHEN rs.DEFAULT_FLAG=+
1'1' THEN rs.REGULAR_COST ELSE rs.REGULAR_COST * h_rate_echange END,2) AS REGU+
1LAR_COST,:n         ROUND(CASE WHEN rs.DEFAULT_FLAG='0' THEN rs.REGULAR_SALE +
1* CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id+
1 = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DA+
1TAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELE+
1MENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END WHE+
1N rs.DEFAULT_FLAG='1' THEN rs.REGULAR_SALE ELSE rs.REGULAR_SALE * h_rate_echa+
1nge END,2) AS REGULAR_SALE,:n         ROUND(CASE WHEN rs.DEFAULT_FLAG='0' THE+
1N rs.SPECIAL_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_+
1ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME+
1,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_OR+
1ASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CU+
1RRENCY_ID) END WHEN rs.DEFAULT_FLAG='1' THEN rs.SPECIAL_COST ELSE rs.SPECIAL_+
1COST * h_rate_echange END,2) AS SPECIAL_COST,:n         ROUND(CASE WHEN rs.DE+
1FAULT_FLAG='0' THEN rs.SPECIAL_SALE * CASE WHEN (r.CURRENCY_ID = h_currency_i+
1d) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODE+
1CIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id+
1) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE+
1 ELEMENT_ID = r.CURRENCY_ID) END WHEN rs.DEFAULT_FLAG='1' THEN rs.SPECIAL_SAL+
1E ELSE rs.SPECIAL_SALE * h_rate_echange END,2) AS SPECIAL_SALE,:n         rs.+
1START_DATE, rs.FINISH_DATE,rs.ASSIGNABLE,rs.PLANNED,rs.SCHED, CASE WHEN rs.PR+
1OPOSED > 0 THEN rs.PROPOSED ELSE h_effort END AS WORK_EFFORT, h_eunit AS UNIT+
1_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS AVAILABLE,:n         rv.FU+
1LL_NAME AS VERIFIED, r.STATUS2_ID, pp.ELEMENT_NAME AS POOL_NAME, RM.FULL_NAME+
1, RM.E_MAIL_ADDRESS, '' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR+
1 AS ASSIGN_STRING, rs.ROLE_ID, rs.SKILL_ID, COALESCE(pa.PLANNED_WORK + pa.SCH+
1ED_WORK,0) AS ASSIGNED_FLAG,:n         r.FS_LABOR_CODE, r.REC_DATETIME AS RES+
1_MODIFIED_DATE:n         FROM PMO_TMP_SEARCH rs JOIN TMT_POOLS p ON rs.RES_ID+
1=p.ELEMENT_ID:n         JOIN TMT_POOLS pp ON pp.ELEMENT_ID=p.PARENT_ID:n     +
1    LEFT OUTER JOIN RESOURCES RM ON pp.MANAGER_ID=RM.RESOURCE_ID:n         JO+
1IN RESOURCES r ON rs.RES_ID=r.RESOURCE_ID LEFT OUTER JOIN RESOURCES rv ON rv.+
1RESOURCE_ID=r.VERIFIED_1:n         LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON +
1pa.PROJECT_ID=h_project_id AND pa.RESOURCE_ID=rs.RES_ID:n         LEFT OUTER +
1JOIN TMT_ORGANIZATIONS o1 ON r.RESOURCE_ID=o1.ELEMENT_ID:n         LEFT OUTER+
1 JOIN TMT_ORGANIZATIONS o2 ON o1.PARENT_ID=o2.ELEMENT_ID:n         LEFT OUTER+
1 JOIN TMT_GEOGRAPHIES g1 ON r.RESOURCE_ID=g1.ELEMENT_ID:n         LEFT OUTER +
1JOIN TMT_GEOGRAPHIES g2 ON g1.PARENT_ID=g2.ELEMENT_ID:n         ORDER BY ELEM+
1ENT_ID:
12149:
1                EXIT:: SP_SEARCH_2(2150) :: cplan.sql(2296) :: :
1DELETE FROM PMO_TMP_CPLN_0006:
1PMO_TMP_CPLN_0006:
1INSERT INTO PMO_TMP_CPLN_0006:n            SELECT RES_ID, REGULAR_COST, REGUL+
1AR_SALE, SPECIAL_COST, SPECIAL_SALE, 1:n            FROM PMO_TMP_SEARCH WHERE+
1 DEFAULT_FLAG = '1':
12171:
1           EXCEPTION:: SP_SEARCH_2(2172) :: cplan.sql(2318) :: :
1INSERT INTO PMO_TMP_CPLN_0006:n            SELECT  RES_ID,                   +
1          MAX(REGULAR_COST) AS REGULAR_COST,:n            MAX(REGULAR_SALE) A+
1S REGULAR_SALE,  MAX(SPECIAL_COST) AS SPECIAL_COST,:n            MAX(SPECIAL_+
1SALE) AS SPECIAL_SALE , 0:n            FROM PMO_TMP_SEARCH:n            WHERE+
1 RES_ID NOT IN (SELECT RES_ID:n            FROM PMO_TMP_SEARCH WHERE DEFAULT_+
1FLAG = '1'):n            GROUP BY RES_ID:
12195:
1           EXCEPTION:: SP_SEARCH_2(2196) :: cplan.sql(2342) :: :
1DEF:
1PRF:
1RR:
1SELECT rs.RES_ID AS ELEMENT_ID, 13 AS TYPE_ID, r.FULL_NAME AS ELEMENT_NAME, r+
1s.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL, r.WORK_LOCATION,:n  +
1       o2.ELEMENT_NAME AS ORGANIZATION,g2.ELEMENT_NAME AS GEOGRAPHY,:n       +
1  :n         ROUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.REGULAR_COST:n        +
1 WHEN a.REGULAR_COST>0 THEN a.REGULAR_COST * CASE WHEN (r.CURRENCY_ID = h_cur+
1rency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORAS+
1TD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_curr+
1ency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELD+
1S WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         WHEN def.REGULAR_COST>0 THE+
1N def.REGULAR_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY+
1_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAM+
1E,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_O+
1RASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.C+
1URRENCY_ID) END:n         else prf.REGULAR_COST * h_rate_echange:n         EN+
1D,2) AS REGULAR_COST,:n         :n         ROUND(CASE WHEN pa.REGULAR_COST> 0+
1 THEN pa.REGULAR_RATE:n         WHEN a.REGULAR_COST > 0 THEN a.REGULAR_SALE *+
1 CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id +
1= 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DAT+
1AFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEM+
1ENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n   +
1      WHEN def.REGULAR_COST>0 THEN def.REGULAR_SALE * CASE WHEN (r.CURRENCY_I+
1D = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT+
1 PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID+
1 = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_+
1DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         else prf.REGULAR_S+
1ALE * h_rate_echange:n         END,2) AS REGULAR_SALE,:n         :n         R+
1OUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.SPECIAL_COST:n         WHEN a.REGULA+
1R_COST>0 THEN a.SPECIAL_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (+
1r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(E+
1LEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SE+
1LECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMEN+
1T_ID = r.CURRENCY_ID) END:n         WHEN def.REGULAR_COST>0 THEN def.SPECIAL_+
1COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_curren+
1cy_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM T+
1MT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMA+
1L(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) EN+
1D:n         else prf.SPECIAL_COST * h_rate_echange:n         END,2) AS SPECIA+
1L_COST,:n         :n         ROUND(CASE WHEN pa.REGULAR_RATE>0 THEN pa.SPECIA+
1L_RATE:n         WHEN a.REGULAR_SALE>0 THEN a.SPECIAL_SALE * CASE WHEN (r.CUR+
1RENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE +
1(SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELE+
1MENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FR+
1OM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         WHEN def.RE+
1GULAR_COST>0 THEN def.SPECIAL_SALE * CASE WHEN (r.CURRENCY_ID = h_currency_id+
1) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODEC+
1IMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id)+
1 / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE +
1ELEMENT_ID = r.CURRENCY_ID) END:n         else prf.SPECIAL_SALE * h_rate_echa+
1nge:n         END,2) AS SPECIAL_SALE,:n         :n         rs.START_DATE,rs.F+
1INISH_DATE,rs.ASSIGNABLE,rs.PLANNED,rs.SCHED, CASE WHEN rs.PROPOSED > 0 THEN +
1rs.PROPOSED ELSE h_effort END AS WORK_EFFORT, h_eunit AS UNIT_EFFORT,(rs.ASSI+
1GNABLE - rs.PLANNED - rs.SCHED) AS AVAILABLE,:n         rv.FULL_NAME AS VERIF+
1IED, r.STATUS2_ID, pp.ELEMENT_NAME AS POOL_NAME, RM.FULL_NAME, RM.E_MAIL_ADDR+
1ESS, '' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRIN+
1G,:n         rs.ROLE_ID, rs.SKILL_ID, COALESCE(pa.PLANNED_WORK + pa.SCHED_WOR+
1K,0) AS ASSIGNED_FLAG,:n         r.FS_LABOR_CODE, r.REC_DATETIME AS RES_MODIF+
1IED_DATE:n         FROM PMO_TMP_SEARCH rs:n         LEFT JOIN PMO_TMP_CPLN_00+
106 def ON rs.RES_ID=def.RES_ID AND def.DEFAULT_FLAG = 1:n         LEFT JOIN P+
1MO_TMP_CPLN_0006 prf ON rs.RES_ID=prf.RES_ID AND prf.DEFAULT_FLAG = 0:n      +
1   JOIN TMT_POOLS p ON rs.RES_ID=p.ELEMENT_ID:n         JOIN TMT_POOLS pp ON +
1pp.ELEMENT_ID=p.PARENT_ID:n         LEFT OUTER JOIN RESOURCES RM ON pp.MANAGE+
1R_ID=RM.RESOURCE_ID:n         JOIN RESOURCES r ON rs.RES_ID=r.RESOURCE_ID LEF+
1T OUTER JOIN RESOURCES rv ON rv.RESOURCE_ID=r.VERIFIED_1:n         LEFT OUTER+
1 JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID=h_project_id AND pa.RESOURCE_ID+
1=rs.RES_ID:n         LEFT OUTER JOIN RESOURCES rr ON r.VERIFIED_1=rr.RESOURCE+
1_ID:n         LEFT OUTER JOIN TMT_ORGANIZATIONS o1 ON r.RESOURCE_ID=o1.ELEMEN+
1T_ID LEFT OUTER JOIN TMT_ORGANIZATIONS o2 ON o1.PARENT_ID=o2.ELEMENT_ID:n    +
1     LEFT OUTER JOIN TMT_GEOGRAPHIES g1 ON r.RESOURCE_ID=g1.ELEMENT_ID LEFT O+
1UTER JOIN TMT_GEOGRAPHIES g2 ON g1.PARENT_ID=g2.ELEMENT_ID:n         LEFT OUT+
1ER JOIN RATES a ON r.RATE_ID=a.RATE_ID:n         WHERE NOT (rs.ROLE_NAME IS N+
1uLL AND rs.SKILL_NAME IS NuLL AND rs.SHOW_ROLE IS NuLL AND rs.SHOW_SKILL IS N+
1uLL):n         ORDER BY ELEMENT_ID:
12246:
1                EXIT:: SP_SEARCH_2(2247) :: cplan.sql(2393) :: :
1RETURN_ERROR_EXCEPTION:
12256:
1           EXCEPTION:: SP_SEARCH_2(2257) :: cplan.sql(2403) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
12268:
1           EXCEPTION:: SP_SEARCH_2(2269) :: cplan.sql(2415) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
3605
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 :2 a0 6b 1c 81
b0 a0 f4 b4 bf c8 :8 a0 12a
bd b7 11 a4 b1 a0 f4 b4
bf c8 :10 a0 12a bd b7 11 a4
b1 a3 :2 a0 6b 1c 81 b0 a3
:2 a0 6b 1c 81 b0 a3 :2 a0 6b
1c 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d a0 51 d
a0 51 d :2 a0 51 a5 b a0
7e a0 6b b4 2e 5a a0 7e
b4 2e :2 5a a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 19 3c a0
7e b4 2e :2 5a a0 7e b4 2e
:2 5a a 10 a0 7e b4 2e :2 5a
a 10 a0 7e b4 2e :2 5a a
10 :2 a0 51 a5 b a0 7e a0
6b b4 2e 5a a 10 a0 7e
b4 2e :2 5a :2 a0 51 a5 b a0
7e a0 6b b4 2e 5a a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 a0
b7 a0 7e b4 2e :2 5a a0 7e
b4 2e :2 5a a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 :2 19 3c b7
19 3c a0 7e b4 2e 5a :3 a0
a5 b 51 a5 b 7e 51 b4
2e 5a a 10 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 19 3c a0
7e b4 2e 5a :3 a0 a5 b 51
a5 b 7e 51 b4 2e 5a a
10 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 51
a5 b 7e 51 b4 2e a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c a0 7e b4 2e :2 5a a0
51 d b7 :2 a0 d b7 :2 19 3c
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a0 7e b4 2e :2 5a
a 10 a0 7e b4 2e :2 5a a
10 :8 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c a0 51 d b7 19 3c
a0 7e b4 2e :2 5a a0 7e b4
2e :2 5a a 10 :3 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 3c :2 a0 d :3 a0 6b :3 a0 51
a5 b :2 a0 6b a5 b 5a 51
a5 b d :4 a0 51 a5 b :2 a0
6b a5 b d :3 a0 6b :3 a0 51
a5 b :2 a0 6b a5 b 5a 51
a5 b d :4 a0 51 a5 b :2 a0
6b a5 b d :3 a0 51 a5 b
a0 7e a0 6b b4 2e 51 a6
122 51 122 124 d :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 6e a5 b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c b7 19 3c :4 a0 51 a5
b a5 b d :2 a0 51 a5 b
7e 51 b4 2e :4 a0 51 a5 b
a5 b d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c :3 a0 6b d
b7 19 3c :2 a0 d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d b7
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
:2 19 3c :8 a0 a5 b d :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
51 a5 b :2 a0 a5 57 b7 19
3c :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 51 a5
b a0 7e a0 6b b4 2e :3 a0
51 a5 b a5 b 7e 51 b4
2e :d a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :27 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c a0 b7
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :9 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:13 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c a0 7e
b4 2e 5a :3 a0 6b d :3 a0 a5
b d b7 19 3c b7 19 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 19
3c :2 a0 51 a5 b a0 7e a0
6b b4 2e :15 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 a0 b7
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 :2 51 a5 b 7e 6e b4
2e :2 a0 51 a5 b 7e 51 b4
2e :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e a 10 5a
52 10 :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e 52 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c b7 :2 19 3c b7 19 3c
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b a0
7e a0 6b b4 2e a0 7e b4
2e 5a a 10 :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :b a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :5 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c b7 19 3c b7
19 3c b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e a 10 a0
51 d b7 19 3c :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
7e b4 2e 5a a0 6e d a0
6e d b7 :2 a0 d :2 a0 d b7
:2 19 3c a0 51 d b7 a0 7e
51 b4 2e a0 6e d :6 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :3 a0 a5
b d :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 b7 :2 19 3c
b7 :2 a0 d b7 :2 19 3c :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 a0 51
d a0 b7 :2 a0 51 a5 b 7e
51 b4 2e a0 51 d a0 b7
19 :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 a0 51 d
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e a0 51 d b7 :2 19
3c b7 19 3c b7 :2 19 3c :2 a0
51 a5 b a0 7e a0 6b b4
2e a0 51 d :2 a0 d :2 a0 d
:3 a0 :2 51 a5 b d a0 4d d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 b4 2e d a0 51 d b7
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e :b a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 51 d b7 19 3c b7 19
3c b7 a0 51 d b7 :2 19 3c
b7 :2 19 3c a0 7e 51 b4 2e
:9 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :1f a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :3 a0 51 a5 b 7e 51 b4
2e 6e a6 122 6e 122 124 d
:13 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 :2 a0 :2 51 a5 b 7e
6e b4 2e :a a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :6 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c :2 a0 b4 2e
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 51 a5 b a0 7e a0
6b b4 2e a 10 :2 a0 51 a5
b a0 7e a0 6b b4 2e a
10 a0 7e b4 2e 5a :2 a0 d
b7 19 3c b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
d b7 19 3c a0 7e b4 2e
5a a0 7e b4 2e 5a a 10
a0 7e b4 2e 5a a 10 a0
7e b4 2e :2 5a a 10 a0 51
d b7 19 3c a0 6e d a0
6e d :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b a0 7e
a0 6b b4 2e a0 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d a0 b7 :2 a0 51 a5
b 7e 51 b4 2e a0 6e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e d
b7 19 a0 6e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
d b7 :2 19 3c b7 :2 a0 51 a5
b a0 7e a0 6b b4 2e :2 a0
51 a5 b a0 7e a0 6b b4
2e a 10 :2 a0 51 a5 b a0
7e a0 6b b4 2e a 10 :2 a0
6e 11e 11d :2 a0 6b 51 d a0
7e b4 2e 5a :2 a0 6e 11e 11d
:2 a0 6b 51 d :17 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :15 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 a0
d :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 19 3c
a0 7e b4 2e 5a :4 a0 a5 b
51 a5 b 7e 51 b4 2e :4 a0
a5 b 51 a5 b 51 a5 b
7e 51 b4 2e a6 122 :4 a0 a5
b 51 a5 b 51 a5 b 122
124 d a0 51 d :3 a0 7e a0
b4 2e 82 :5 a0 7e 51 b4 2e
51 a5 b a5 b 51 a5 b
7e 51 b4 2e :5 a0 7e 51 b4
2e 51 a5 b a5 b 51 a5
b 7e 51 b4 2e a 10 a0
2b b7 19 3c :2 a0 7e 51 b4
2e d b7 a0 47 :2 a0 7e b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c :4 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c :2 a0 51 a5 b a0 7e a0
6b b4 2e a0 6e d a0 6e
d :2 a0 7e a0 b4 2e d :2 a0
7e 6e b4 2e d a0 b7 :2 a0
51 a5 b a0 7e a0 6b b4
2e a0 6e d :2 a0 7e a0 b4
2e d :2 a0 7e 6e b4 2e d
a0 6e d b7 19 :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
6e d a0 6e d a0 7e b4
2e 5a :2 a0 7e 6e b4 2e d
:2 a0 7e a0 b4 2e d :2 a0 7e
6e b4 2e d b7 19 3c :2 a0
7e 6e b4 2e d a0 7e b4
2e 5a :2 a0 7e 6e b4 2e d
:2 a0 7e a0 b4 2e d :2 a0 7e
6e b4 2e d b7 19 3c b7
:2 a0 7e 6e b4 2e 7e 6e b4
2e d a0 6e d a0 7e b4
2e 5a :2 a0 7e 6e b4 2e d
:2 a0 7e a0 b4 2e d :2 a0 7e
6e b4 2e d b7 19 3c :2 a0
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
d a0 7e b4 2e 5a :2 a0 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e d b7 19 3c b7
:2 19 3c b7 :2 19 3c :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
7e b4 2e 5a :5 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:4 a0 a5 b 51 a5 b d :2 a0
7e 6e b4 2e d :2 a0 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d b7
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 19 3c b7 19 3c a0 7e b4
2e 5a :5 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 7e
6e b4 2e d :2 a0 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e d b7 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 19
3c b7 19 3c a0 7e b4 2e
5a :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 7e 6e
b4 2e d :2 a0 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e d b7 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 19 3c
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e a 10 :2 a0 7e 6e
b4 2e 7e :3 a0 51 a5 b a5
b b4 2e 7e 6e b4 2e d
b7 19 3c b7 19 3c a0 7e
b4 2e 5a :4 a0 a5 b 51 a5
b d a0 51 d :3 a0 7e a0
b4 2e 82 :3 a0 6b :2 51 a0 7e
51 b4 2e a0 a5 b d :5 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 7e 6e b4 2e d b7
:2 a0 7e 6e b4 2e d b7 :2 19
3c :2 a0 51 a5 b a0 7e a0
6b b4 2e a0 2b b7 19 3c
:2 a0 7e 51 b4 2e d b7 a0
47 b7 19 3c :2 a0 51 a5 b
a0 7e a0 6b b4 2e :4 a0 a5
b 51 a5 b d a0 51 d
:3 a0 7e a0 b4 2e 82 :3 a0 6b
:2 51 a0 7e 51 b4 2e a0 a5
b d :5 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:2 a0 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e d :2 a0 7e
51 b4 2e d b7 a0 47 b7
19 3c :2 a0 7e a0 b4 2e d
b7 :2 19 3c :2 a0 7e 6e b4 2e
d :3 a0 11c 11d :3 a0 e9 d3 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a a0 2b
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b a0
7e a0 6b b4 2e a 10 :2 a0
51 a5 b a0 7e a0 6b b4
2e a 10 :2 a0 51 a5 b a0
7e a0 6b b4 2e a0 7e b4
2e 5a 52 10 5a a 10 :2 a0
e9 dd b3 :2 a0 e9 d3 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 e9 c1
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 3b b7 :2 a0 e9 c1 :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 19 3c :2 a0 d
:2 a0 d :2 a0 51 a5 b 7e 51
b4 2e :2 a0 :2 51 a5 b 7e 6e
b4 2e :2 a0 b4 2e d a0 51
d b7 :3 a0 51 a5 b a5 b
7e 51 b4 2e :9 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
e9 c1 :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 19 3c
b7 :2 19 3c :20 a0 51 a5 b :3 51
a5 b d a0 7e 51 b4 2e
:2 a0 e9 c1 :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 7e a0 6b
b4 2e :3 a0 6b d b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :3 a0 a5 57 a0 b7 :2 a0 :2 51
a5 b 7e 6e b4 2e 5a :2 a0
:2 51 a5 b 7e 6e b4 2e 5a
a 10 :5 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c a0 2b
b7 :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 d :2 a0 d b7
19 3c :1e a0 :4 51 a5 b d a0
7e 51 b4 2e :2 a0 7e 51 b4
2e d b7 19 3c :2 a0 7e a0
51 a5 b b4 2e a0 2b b7
19 3c b7 :2 19 3c 93 4f b0
46 b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 7e a0 6b b4 2e 5a a0
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
5a 52 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :3 a0 a5 57 b7
19 3c a0 7e 51 b4 2e a0
6e d a0 6e d a0 6e d
:2 a0 e9 dd b3 a0 51 d :a a0
e9 d3 5 :2 a0 f :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a a0 2b b7 19 3c a0
7e b4 2e 5a :2 a0 6b :2 a0 a5
b 7e 51 b4 2e a 10 :3 a0
a5 b 51 a5 b 7e 51 b4
2e a 10 :2 a0 d b7 19 3c
:2 a0 6b :2 a0 a5 b 7e 51 b4
2e a0 7e 51 b4 2e :f a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 3c a0 6e d a0 6e d
a0 6e d a0 6e d a0 6e
d a0 6e d :2 a0 d a0 51
d b7 19 3c a0 7e 51 b4
2e a0 7e b4 2e 5a a 10
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c a0 7e b4 2e
5a a0 7e b4 2e 5a :3 a0 7e
6e b4 2e :2 51 a5 b d b7
19 3c :3 a0 7e a0 b4 2e :2 51
a5 b d b7 19 3c a0 7e
b4 2e 5a :3 a0 7e a0 b4 2e
:2 51 a5 b d b7 19 3c a0
7e b4 2e 5a a0 7e b4 2e
5a :3 a0 7e 6e b4 2e :2 51 a5
b d b7 19 3c :3 a0 7e a0
b4 2e :2 51 a5 b d b7 19
3c a0 7e b4 2e 5a :3 a0 7e
a0 b4 2e :2 51 a5 b d b7
19 3c a0 7e b4 2e 5a a0
7e b4 2e 5a :3 a0 7e 6e b4
2e :2 51 a5 b d b7 19 3c
:3 a0 7e a0 b4 2e :2 51 a5 b
d b7 19 3c a0 7e b4 2e
5a a0 7e b4 2e 5a :3 a0 7e
6e b4 2e :2 51 a5 b d b7
19 3c :3 a0 7e a0 b4 2e :2 51
a5 b d b7 19 3c :2 a0 7e
51 b4 2e d :2 a0 d b7 a0
47 :2 a0 e9 c1 :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 7e 51
b4 2e :f a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c b7 19
3c a0 7e b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e :e a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 a0 51 d 4f b7 :2 19
3c b7 19 3c :13 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 6e 11e 11d :2 a0 6b 51
d :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :12 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :6 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c b7 19 3c :cc a0 12a e9 dd
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 65 b7 a0 7e
51 b4 2e :12d a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 b7 :2 a0 6e 11e
11d :2 a0 6b 51 d :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :14 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :1b7 a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
b7 :2 19 3c b7 :2 19 3c b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
3605
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 168
164 13a 170 179 175 163 181 18e
18a 160 196 19f 19b 189 1a7 1b4
1b0 186 1bc 1c5 1c1 1af 1cd 1da
1d6 1ac 1e2 1eb 1e7 1d5 1f3 200
1fc 1d2 208 211 20d 1fb 219 1f8
21e 222 226 22a 22d 231 24e 239
23d 240 241 249 238 26b 259 235
25d 25e 266 258 288 276 255 27a
27b 283 275 2a5 293 272 297 298
2a0 292 2c2 2b0 28f 2b4 2b5 2bd
2af 2df 2cd 2ac 2d1 2d2 2da 2cc
2fc 2ea 2c9 2ee 2ef 2f7 2e9 319
307 2e6 30b 30c 314 306 336 324
303 328 329 331 323 353 341 320
345 346 34e 340 370 35e 33d 362
363 36b 35d 38d 37b 35a 37f 380
388 37a 3aa 398 377 39c 39d 3a5
397 3c7 3b5 394 3b9 3ba 3c2 3b4
3e4 3d2 3b1 3d6 3d7 3df 3d1 401
3ef 3ce 3f3 3f4 3fc 3ee 41e 40c
3eb 410 411 419 40b 43b 429 408
42d 42e 436 428 458 446 425 44a
44b 453 445 475 463 442 467 468
470 462 492 480 45f 484 485 48d
47f 4ae 49d 4a1 4a9 47c 4ca 4b5
4b9 4bc 4bd 4c5 49c 4e7 4d5 499
4d9 4da 4e2 4d4 504 4f2 4d1 4f6
4f7 4ff 4f1 521 50f 4ee 513 514
51c 50e 53e 52c 50b 530 531 539
52b 55b 549 528 54d 54e 556 548
578 566 545 56a 56b 573 565 595
583 562 587 588 590 582 5b2 5a0
57f 5a4 5a5 5ad 59f 5cf 5bd 59c
5c1 5c2 5ca 5bc 5ec 5da 5b9 5de
5df 5e7 5d9 608 5f7 5fb 5d6 603
5f6 624 613 617 5f3 61f 612 640
62f 633 60f 63b 62e 65c 64b 64f
62b 657 64a 678 667 66b 647 673
666 694 683 687 663 68f 682 6b0
69f 6a3 67f 6ab 69e 6cc 6bb 6bf
69b 6c7 6ba 6e8 6d7 6db 6b7 6e3
6d6 704 6f3 6f7 6d3 6ff 6f2 720
70f 713 6ef 71b 70e 73c 72b 72f
70b 737 72a 758 747 74b 727 753
746 774 763 767 743 76f 762 790
77f 783 75f 78b 77e 7ac 79b 79f
77b 7a7 79a 7c8 7b7 7bb 797 7c3
7b6 7e4 7d3 7d7 7b3 7df 7d2 800
7ef 7f3 7cf 7fb 7ee 81c 80b 80f
7eb 817 80a 838 827 82b 807 833
826 854 843 847 823 84f 842 870
85f 863 83f 86b 85e 88c 87b 87f
85b 887 87a 8a8 897 89b 877 8a3
896 8c4 8b3 8b7 893 8bf 8b2 8e0
8cf 8d3 8af 8db 8ce 8fc 8eb 8ef
8cb 8f7 8ea 918 907 90b 8e7 913
906 934 923 927 903 92f 922 950
93f 943 91f 94b 93e 96c 95b 95f
93b 967 95a 988 977 97b 957 983
976 9a5 993 973 997 998 9a0 992
9c1 9b0 9b4 98f 9bc 9af 9dd 9cc
9d0 9ac 9d8 9cb 9f9 9e8 9ec 9c8
9f4 9e7 a16 a04 9e4 a08 a09 a11
a03 a33 a21 a00 a25 a26 a2e a20
a50 a3e a1d a42 a43 a4b a3d a6c
a5b a5f a3a a67 a5a a88 a77 a7b
a57 a83 a76 aa5 a93 a73 a97 a98
aa0 a92 ac2 ab0 a8f ab4 ab5 abd
aaf adf acd aac ad1 ad2 ada acc
afc aea ac9 aee aef af7 ae9 b19
b07 ae6 b0b b0c b14 b06 b36 b24
b03 b28 b29 b31 b23 b52 b41 b45
b20 b4d b40 b6e b5d b61 b3d b69
b5c b8a b79 b7d b59 b85 b78 ba6
b95 b99 b75 ba1 b94 bc2 bb1 bb5
b91 bbd bb0 bde bcd bd1 bad bd9
bcc bfa be9 bed bc9 bf5 be8 c16
c05 c09 be5 c11 c04 c33 c21 c01
c25 c26 c2e c20 c4f c3e c42 c1d
c4a c3d c6b c5a c5e c66 c3a c83
c72 c76 c7e c59 c9f c8e c92 c9a
c56 cb7 ca6 caa cb2 c8d cd3 cc2
cc6 cce c8a ceb cda cde ce6 cc1
d07 cf6 cfa d02 cbe d26 d0e d12
d16 d19 d21 cf5 d2d d31 cf2 d42
d45 d49 d4d d51 d55 d59 d5d d61
d65 d69 d75 d7a d7c d88 d8c d8e
d92 da3 da4 da7 dab daf db3 db7
dbb dbf dc3 dc7 dcb dcf dd3 dd7
ddb ddf de3 de7 deb df7 dfc dfe
e0a e0e e2c e14 e18 e1c e1f e27
e13 e4c e37 e3b e10 e3f e47 e36
e6c e57 e5b e33 e5f e67 e56 e8c
e77 e7b e53 e7f e87 e76 e93 e97
e73 e9b e9f ea3 ea6 eab eac 1
eae eb3 eb7 ebb ebe ec3 ec7 ecb
ece ed3 ed4 ed6 edb ede ee2 ee3
ee8 eed ef0 ef5 ef6 efb efe f02
f03 f08 f0b f10 f11 f16 f19 f1e
f1f f24 f27 f2c f2d f32 f35 f39
f3a f3f f42 f47 f48 f4d f50 f55
f56 f5b f5e f63 f64 f69 f6c f70
f71 f76 f79 f7e f7f f84 f87 f8c
f8d f92 f95 f99 f9d fa1 fa2 fa4
fa9 faa fac fad fb2 fb5 fba fbb
fc0 fc3 fc7 fcb fcf fd0 fd2 fd7
fd8 fda fdb fe0 fe3 fe8 fe9 fee
ff1 ff5 ff9 ffd ffe 1000 1005 1006
1008 1009 100e 1011 1016 1017 101c 101f
1023 1027 102b 102c 102e 1033 1034 1036
1037 103c 103f 1044 1045 104a 104d 1051
1055 1059 105a 105c 1061 1062 1064 1065
106a 106d 1072 1073 1078 107b 107f 1083
1087 1088 108a 108f 1090 1092 1093 1098
109b 10a0 10a1 10a6 10a9 10ad 10b1 10b5
10b6 10b8 10bd 10be 10c0 10c1 10c6 10c9
10ce 10cf 10d4 10d7 10db 10df 10e3 10e4
10e6 10eb 10ec 10ee 10ef 10f4 10f7 10fc
10fd 1102 1105 110a 110b 1110 1113 1117
1118 111d 1120 1125 1126 112b 112e 1133
1134 1139 113c 1141 1142 1147 114a 114e
114f 1154 1157 115c 115d 1162 1165 116a
116b 1170 1173 1178 1179 117e 1181 1185
1186 118b 118e 1193 1194 1199 119c 11a1
11a2 11a7 11aa 11af 11b0 11b5 11b8 11bc
11bd 11c2 11c5 11ca 11cb 11d0 11d3 11d8
11d9 11de 11e1 11e6 11e7 11ec 11ef 11f3
11f4 11f9 11fc 1201 1202 1207 120a 120f
1210 1215 1218 121c 1220 1224 1225 1227
122c 122d 122f 1230 1235 1238 123d 123e
1243 1246 124b 124c 1251 1254 1258 1259
125e 1261 1266 1267 126c 126f 1274 1275
127a 127d 1282 1283 1288 128b 128f 1290
1295 1298 129d 129e 12a3 12a6 12ab 12ac
12b1 12b4 12b9 12ba 12bf 12c2 12c6 12c7
12cc 12cf 12d4 12d5 12da 12dd 12e2 12e3
12e8 12eb 12f0 12f1 12f6 12f9 12fd 12fe
1303 1306 130b 130c 1311 1314 1319 131a
131f 1322 1326 132a 132e 132f 1331 1336
1337 1339 133a 133f 1342 1347 1348 134d
1350 1354 1358 135c 135d 135f 1364 1365
1367 1368 136d 1370 1375 1376 137b 137e
1382 1386 138a 138b 138d 1392 1393 1395
1396 139b 139e 13a3 13a4 13a9 13ac 13b0
13b4 13b8 13b9 13bb 13c0 13c1 13c3 13c4
13c9 13cc 13d1 13d2 13d7 13da 13df 13e0
13e5 13e8 13ec 13ed 13f2 13f5 13fa 13fb
1400 1403 1408 1409 140e 1411 1416 1417
141c 141f 1423 1424 1429 142c 1431 1432
1437 143a 143f 1440 1445 1446 144b 144d
1451 1454 1458 145c 145f 1463 1467 146a
146d 1472 1475 1478 147b 147c 1481 1482
1 1484 1489 148d 1491 1494 1499 149e
14a1 14a5 14a6 14ab 14ac 14b1 14b3 14b7
14ba 14be 14c2 14c6 14ca 14ce 14d2 14d6
14da 14de 14e2 14e6 14ea 14ee 14f2 14f6
14fa 14fe 1502 1506 150a 150e 1512 1516
151a 151e 1522 1526 152a 152e 1532 1536
153a 153e 1542 1546 154a 154e 1552 1556
155a 155e 1562 1566 156a 156e 1572 1576
157a 157e 1582 1586 158a 158e 1592 1596
159a 159e 15a2 15a6 15aa 15ae 15b2 15b6
15ba 15be 15c2 15c6 15c9 15cd 15d1 15d4
15d8 15dc 15e0 15e3 15e4 15e6 15ea 15ed
15f1 15f4 15f5 15fa 15fd 1601 1604 1605
160a 160d 1 1610 1615 1619 161d 1620
1624 1628 162b 162e 1633 1636 1639 163c
163d 1642 1643 1 1645 164a 164e 1652
1655 165a 165f 1662 1666 1667 166c 166f
1674 1675 167a 167d 1682 1683 1688 168b
168f 1693 1697 169b 169e 169f 16a1 16a6
16a7 16a9 16aa 16af 16b0 16b5 16b7 16bb
16be 16c2 16c6 16c9 16cd 16d1 16d4 16d7
16dc 16df 16e2 16e5 16e6 16eb 16ec 1
16ee 16f3 16f7 16fb 16fe 1703 1708 170b
170f 1710 1715 1716 171b 171d 1721 1724
1728 172c 172f 1733 1737 173a 173e 173f
1744 1746 174a 174d 1751 1754 1755 175a
175d 1760 1764 1767 1768 176d 1770 1
1773 1778 177c 177f 1780 1785 1788 1
178b 1790 1794 1797 1798 179d 17a0 1
17a3 17a8 17ac 17b0 17b3 17b4 17b6 17ba
17bd 17c1 17c4 17c5 17ca 1 17cd 17d2
17d6 17d9 17da 17df 17e2 17e5 17e9 17ed
17f0 17f1 17f3 17f7 17fa 17fe 1801 1802
1807 1 180a 180f 1813 1817 181a 181e
1822 1825 1828 182d 1830 1833 1836 1837
183c 183d 1 183f 1844 1848 184c 184f
1854 1859 185c 1860 1861 1866 1869 186e
186f 1874 1877 187c 187d 1882 1885 1889
188d 1891 1895 1898 1899 189b 18a0 18a1
18a3 18a4 18a9 18aa 18af 18b1 18b5 18b8
18bc 18c0 18c3 18c7 18cb 18ce 18d1 18d6
18d9 18dc 18df 18e0 18e5 18e6 1 18e8
18ed 18f1 18f5 18f8 18fd 1902 1905 1909
190a 190f 1910 1915 1917 191b 191e 1922
1926 1929 192d 1931 1934 1938 1939 193e
1942 1944 1948 194b 194c 1951 1954 1957
195b 195e 195f 1964 1967 1 196a 196f
1973 1977 197a 197e 1982 1985 1988 198d
1990 1993 1996 1997 199c 199d 1 199f
19a4 19a8 19ac 19af 19b4 19b9 19bc 19c0
19c1 19c6 19c9 19ce 19cf 19d4 19d7 19dc
19dd 19e2 19e5 19e9 19ed 19f1 19f5 19f8
19f9 19fb 1a00 1a01 1a03 1a04 1a09 1a0a
1a0f 1a11 1a15 1a18 1a1c 1a20 1a23 1a27
1a2b 1a2e 1a31 1a36 1a39 1a3c 1a3f 1a40
1a45 1a46 1 1a48 1a4d 1a51 1a55 1a58
1a5d 1a62 1a65 1a69 1a6a 1a6f 1a70 1a75
1a77 1a7b 1a7e 1a82 1a86 1a89 1a8d 1a91
1a94 1a98 1a99 1a9e 1aa0 1aa4 1aa8 1aab
1aad 1ab1 1ab4 1ab8 1abb 1abc 1ac1 1ac4
1ac8 1acc 1ad0 1ad1 1ad3 1ad6 1ad7 1ad9
1adc 1adf 1ae0 1ae5 1 1ae8 1aed 1af0
1af4 1af8 1afb 1aff 1b03 1b06 1b09 1b0e
1b11 1b14 1b17 1b18 1b1d 1b1e 1 1b20
1b25 1b29 1b2d 1b30 1b35 1b3a 1b3d 1b41
1b42 1b47 1b4a 1b4f 1b50 1b55 1b58 1b5d
1b5e 1b63 1b66 1b6a 1b6e 1b72 1b76 1b79
1b7a 1b7c 1b81 1b82 1b84 1b85 1b8a 1b8b
1b90 1b92 1b96 1b99 1b9d 1ba1 1ba4 1ba8
1bac 1baf 1bb2 1bb7 1bba 1bbd 1bc0 1bc1
1bc6 1bc7 1 1bc9 1bce 1bd2 1bd6 1bd9
1bde 1be3 1be6 1bea 1beb 1bf0 1bf1 1bf6
1bf8 1bfc 1bff 1c03 1c07 1c0a 1c0e 1c12
1c15 1c19 1c1a 1c1f 1c21 1c25 1c28 1c2c
1c2f 1c30 1c35 1c38 1c3c 1c40 1c44 1c45
1c47 1c4a 1c4b 1c4d 1c50 1c53 1c54 1c59
1 1c5c 1c61 1c64 1c68 1c6c 1c6f 1c73
1c77 1c7a 1c7d 1c82 1c85 1c88 1c8b 1c8c
1c91 1c92 1 1c94 1c99 1c9d 1ca1 1ca4
1ca9 1cae 1cb1 1cb5 1cb6 1cbb 1cbe 1cc3
1cc4 1cc9 1ccc 1cd1 1cd2 1cd7 1cda 1cde
1ce2 1ce6 1cea 1ced 1cee 1cf0 1cf5 1cf6
1cf8 1cf9 1cfe 1cff 1d04 1d06 1d0a 1d0d
1d11 1d15 1d18 1d1c 1d20 1d23 1d26 1d2b
1d2e 1d31 1d34 1d35 1d3a 1d3b 1 1d3d
1d42 1d46 1d4a 1d4d 1d52 1d57 1d5a 1d5e
1d5f 1d64 1d65 1d6a 1d6c 1d70 1d73 1d77
1d7b 1d7e 1d82 1d86 1d89 1d8d 1d8e 1d93
1d95 1d99 1d9c 1da0 1da4 1da7 1da8 1daa
1dad 1db0 1db1 1db6 1dba 1dbe 1dc1 1dc2
1dc4 1dc7 1dca 1dcb 1 1dd0 1dd5 1dd9
1ddd 1de0 1de1 1de3 1de6 1de9 1dea 1
1def 1df4 1df8 1dfc 1dff 1e03 1e07 1e0a
1e0d 1e12 1e15 1e18 1e1b 1e1c 1e21 1e22
1 1e24 1e29 1e2d 1e31 1e34 1e39 1e3e
1e41 1e45 1e46 1e4b 1e4e 1e53 1e54 1e59
1e5c 1e61 1e62 1e67 1e6a 1e6e 1e72 1e76
1e7a 1e7d 1e7e 1e80 1e85 1e86 1e88 1e89
1e8e 1e8f 1e94 1e96 1e9a 1e9d 1ea1 1ea5
1ea8 1eac 1eb0 1eb3 1eb6 1ebb 1ebe 1ec1
1ec4 1ec5 1eca 1ecb 1 1ecd 1ed2 1ed6
1eda 1edd 1ee2 1ee7 1eea 1eee 1eef 1ef4
1ef5 1efa 1efc 1f00 1f03 1f07 1f0b 1f0e
1f12 1f16 1f19 1f1d 1f1e 1f23 1f25 1f29
1f2c 1f30 1f33 1f34 1f39 1f3c 1f3f 1f43
1f46 1f4a 1f4c 1f50 1f54 1f58 1f5a 1f5e
1f62 1f65 1f69 1f6d 1f70 1f71 1f73 1f77
1f7a 1f7e 1f81 1f82 1f87 1f8a 1f8e 1f91
1f92 1f97 1f9a 1 1f9d 1fa2 1fa6 1fa9
1faa 1faf 1fb2 1 1fb5 1fba 1fbe 1fc2
1fc6 1fca 1fce 1fd2 1fd6 1fda 1fe6 1fea
1fee 1ff1 1ff5 1ff9 1ffb 1 1fff 2003
2007 200a 200e 2012 2016 201a 201d 2021
2025 2028 202b 2030 2033 2036 2039 203a
203f 2040 1 2042 2047 204b 204f 2052
2057 205c 205f 2063 2064 2069 206c 2071
2072 2077 207a 207f 2080 2085 2088 208c
208d 2092 2095 209a 209b 20a0 20a3 20a7
20ab 20ae 20b1 20b2 20b4 20b5 20ba 20bb
20c0 20c2 20c6 20c9 20cb 20cf 20d1 20dd
20df 20e1 20e2 20e7 20eb 20ed 20f9 20fb
20ff 2103 2106 210a 210d 2111 2114 2115
211a 211d 2121 2125 2128 2129 212b 212e
2131 2132 2137 1 213a 213f 2143 2147
214a 214e 2152 2155 2158 215d 2160 2163
2166 2167 216c 216d 1 216f 2174 2178
217c 217f 2184 2189 218c 2190 2191 2196
2199 219e 219f 21a4 21a7 21ac 21ad 21b2
21b5 21b9 21bd 21c1 21c5 21c8 21c9 21cb
21d0 21d1 21d3 21d4 21d9 21da 21df 21e1
21e5 21e8 21ec 21f0 21f3 21f7 21fb 21fe
2201 2206 2209 220c 220f 2210 2215 2216
1 2218 221d 2221 2225 2228 222d 2232
2235 2239 223a 223f 2240 2245 2247 224b
224e 2252 2256 2259 225d 2261 2264 2268
2269 226e 2270 2274 2277 227b 227e 2282
2284 2288 228b 228f 2292 2293 2298 229b
229e 22a2 22a5 22a6 22ab 22ae 1 22b1
22b6 22ba 22be 22c2 22ce 22d2 22d6 22d9
22dd 22e1 22e3 1 22e7 22eb 22ef 22f2
22f6 22fa 22fe 2302 2305 2309 230d 2310
2313 2318 231b 231e 2321 2322 2327 2328
1 232a 232f 2333 2337 233a 233f 2344
2347 234b 234c 2351 2354 2359 235a 235f
2362 2367 2368 236d 2370 2374 2375 237a
237d 2382 2383 2388 238b 238f 2393 2396
2399 239a 239c 239d 23a2 23a3 23a8 23aa
23ae 23b1 23b3 23b7 23b9 23c5 23c7 23c9
23ca 23cf 23d3 23d5 23e1 23e3 23e5 23e9
23ec 23f0 23f4 23f8 23fc 2400 2404 2407
240b 240f 2413 2416 2417 2419 241d 2421
2424 2425 2427 242a 242d 242e 2430 2434
2438 243c 2440 2444 2447 2448 244a 244e
2452 2455 2456 2458 245c 2460 2464 2468
246b 246f 2473 2477 247a 247b 247d 2481
2485 2488 2489 248b 248e 2491 2492 2494
2498 249c 24a0 24a4 24a8 24ab 24ac 24ae
24b2 24b6 24b9 24ba 24bc 24c0 24c4 24c8
24cc 24cf 24d0 24d2 24d6 24d9 24dd 24e0
24e1 24e6 24e9 24ea 24ec 24ef 24f1 24f5
24f9 24fd 2501 2504 2505 2507 250a 250d
250e 2513 2517 251a 251e 2522 2526 252a
252e 2532 253e 2542 2546 2549 254d 2551
2553 1 2557 255b 255f 2562 2566 256a
256e 2572 2575 2579 257d 2580 2583 2588
258b 258e 2591 2592 2597 2598 1 259a
259f 25a3 25a7 25aa 25af 25b4 25b7 25bb
25bc 25c1 25c4 25c9 25ca 25cf 25d2 25d7
25d8 25dd 25e0 25e4 25e5 25ea 25ed 25f2
25f3 25f8 25fb 25ff 2603 2606 2609 260a
260c 260d 2612 2613 2618 261a 261e 2621
2623 2627 2629 2635 2637 2639 263a 263f
2643 2645 2651 2653 2657 265b 265e 265f
2661 2664 2667 2668 266d 2671 2675 2679
267d 2681 268d 2691 2695 2698 269c 26a0
26a2 1 26a6 26aa 26ae 26b1 26b5 26b9
26bd 26c1 26c4 26c8 26cc 26cf 26d2 26d7
26da 26dd 26e0 26e1 26e6 26e7 1 26e9
26ee 26f2 26f6 26f9 26fe 2703 2706 270a
270b 2710 2713 2718 2719 271e 2721 2726
2727 272c 272f 2733 2734 2739 273c 2741
2742 2747 274a 274e 2752 2755 2758 2759
275b 275c 2761 2762 2767 2769 276d 2770
2772 2776 2778 2784 2786 2788 2789 278e
2792 2794 27a0 27a2 27a6 27aa 27ad 27b1
27b6 27b7 27b9 27bc 27bf 27c0 27c5 27c9
27cd 27d0 27d4 27d8 27db 27de 27e3 27e6
27e9 27ec 27ed 27f2 27f3 1 27f5 27fa
27fe 2802 2805 280a 280f 2812 2816 2817
281c 281f 2824 2825 282a 282d 2832 2833
2838 283b 283f 2843 2847 284b 284e 284f
2851 2856 2857 2859 285a 285f 2862 2867
2868 286d 2870 2875 2876 287b 287e 2882
2883 2888 288b 2890 2891 2896 2897 289c
289e 28a2 28a5 28a9 28ad 28b0 28b4 28b8
28bb 28be 28c3 28c6 28c9 28cc 28cd 28d2
28d3 1 28d5 28da 28de 28e2 28e5 28ea
28ef 28f2 28f6 28f7 28fc 28fd 2902 2904
2908 290b 290f 2913 2916 291a 291e 2921
2925 2929 292a 292f 2931 2935 2938 293a
293e 2941 2945 2949 294d 2951 2954 2955
2957 2958 295a 295e 2962 2966 2969 296a
296c 296f 2972 2973 2978 297c 2980 2984
2988 298b 298c 298e 298f 2991 2995 2999
299d 29a0 29a1 29a3 29a6 29a9 29aa 29af
29b3 29b7 29ba 29be 29c2 29c5 29c8 29cd
29d0 29d3 29d6 29d7 29dc 29dd 1 29df
29e4 29e8 29ec 29ef 29f4 29f9 29fc 2a00
2a01 2a06 2a09 2a0e 2a0f 2a14 2a17 2a1c
2a1d 2a22 2a25 2a29 2a2d 2a31 2a35 2a38
2a39 2a3b 2a40 2a41 2a43 2a44 2a49 2a4a
2a4f 2a51 2a55 2a58 2a5c 2a60 2a63 2a67
2a6b 2a6e 2a71 2a76 2a79 2a7c 2a7f 2a80
2a85 2a86 1 2a88 2a8d 2a91 2a95 2a98
2a9d 2aa2 2aa5 2aa9 2aaa 2aaf 2ab0 2ab5
2ab7 2abb 2abe 2ac2 2ac6 2ac9 2acd 2ad1
2ad4 2ad8 2ad9 2ade 2ae0 2ae4 2ae7 2aeb
2aef 2af3 2af6 2afa 2afc 2b00 2b03 2b07
2b0b 2b0f 2b13 2b17 2b1a 2b1b 2b1d 2b20
2b23 2b24 2b29 2b2d 2b31 2b35 2b37 2b3b
2b3f 2b42 2b46 2b4a 2b4d 2b50 2b55 2b58
2b5b 2b5e 2b5f 2b64 2b65 1 2b67 2b6c
2b70 2b74 2b77 2b7c 2b81 2b84 2b88 2b89
2b8e 2b91 2b96 2b97 2b9c 2b9f 2ba4 2ba5
2baa 2bad 2bb1 2bb5 2bb9 2bbd 2bc0 2bc1
2bc3 2bc8 2bc9 2bcb 2bcc 2bd1 2bd2 2bd7
2bd9 2bdd 2be0 2be4 2be8 2beb 2bef 2bf3
2bf6 2bf9 2bfe 2c01 2c04 2c07 2c08 2c0d
2c0e 1 2c10 2c15 2c19 2c1d 2c20 2c25
2c2a 2c2d 2c31 2c32 2c37 2c38 2c3d 2c3f
2c43 2c46 2c4a 2c4e 2c51 2c55 2c59 2c5c
2c60 2c61 2c66 2c68 2c6c 2c70 2c73 2c77
2c7b 2c7f 2c83 2c87 2c8b 2c8f 2c93 2c94
2c96 2c9a 2c9e 2ca2 2ca5 2ca6 2ca8 2cab
2cae 2caf 2cb4 2cb8 2cbc 2cbf 2cc3 2cc7
2cca 2ccd 2cd2 2cd5 2cd8 2cdb 2cdc 2ce1
2ce2 1 2ce4 2ce9 2ced 2cf1 2cf4 2cf9
2cfe 2d01 2d05 2d06 2d0b 2d0e 2d13 2d14
2d19 2d1c 2d21 2d22 2d27 2d2a 2d2e 2d32
2d36 2d37 2d39 2d3e 2d3f 2d41 2d42 2d47
2d4a 2d4f 2d50 2d55 2d58 2d5d 2d5e 2d63
2d66 2d6a 2d6b 2d70 2d73 2d78 2d79 2d7e
2d7f 2d84 2d86 2d8a 2d8d 2d91 2d95 2d98
2d9c 2da0 2da3 2da6 2dab 2dae 2db1 2db4
2db5 2dba 2dbb 1 2dbd 2dc2 2dc6 2dca
2dcd 2dd2 2dd7 2dda 2dde 2ddf 2de4 2de5
2dea 2dec 2df0 2df3 2df7 2dfb 2dfe 2e02
2e06 2e09 2e0a 2e0c 2e10 2e14 2e15 2e1a
2e1c 2e20 2e23 2e27 2e2b 2e2e 2e2f 2e31
2e35 2e38 2e3c 2e3f 2e40 2e45 2e49 2e4d
2e50 2e54 2e58 2e5b 2e5e 2e63 2e66 2e69
2e6c 2e6d 2e72 2e73 1 2e75 2e7a 2e7e
2e82 2e85 2e8a 2e8f 2e92 2e96 2e97 2e9c
2e9f 2ea4 2ea5 2eaa 2ead 2eb2 2eb3 2eb8
2ebb 2ebf 2ec3 2ec7 2ecb 2ece 2ecf 2ed1
2ed6 2ed7 2ed9 2eda 2edf 2ee2 2ee7 2ee8
2eed 2ef0 2ef5 2ef6 2efb 2efe 2f02 2f03
2f08 2f0b 2f10 2f11 2f16 2f17 2f1c 2f1e
2f22 2f25 2f29 2f2d 2f30 2f34 2f38 2f3b
2f3e 2f43 2f46 2f49 2f4c 2f4d 2f52 2f53
1 2f55 2f5a 2f5e 2f62 2f65 2f6a 2f6f
2f72 2f76 2f77 2f7c 2f7d 2f82 2f84 2f88
2f8b 2f8f 2f93 2f96 2f9a 2f9e 2fa1 2fa5
2fa9 2faa 2faf 2fb1 2fb5 2fb8 2fbc 2fc0
2fc3 2fc4 2fc6 2fca 2fcd 2fd1 2fd4 2fd5
2fda 2fde 2fe2 2fe6 2fe9 2fea 2fec 2fed
2fef 2ff2 2ff5 2ff6 2ffb 2fff 3003 3007
300b 300f 3013 3017 301b 301f 3023 3027
302b 302f 303b 303f 3043 3046 304a 304e
3050 1 3054 3058 305c 305f 3063 3067
306b 306f 3072 3076 307a 307d 3080 3085
3088 308b 308e 308f 3094 3095 1 3097
309c 30a0 30a4 30a7 30ac 30b1 30b4 30b8
30b9 30be 30c1 30c6 30c7 30cc 30cf 30d4
30d5 30da 30dd 30e1 30e2 30e7 30ea 30ef
30f0 30f5 30f8 30fc 3100 3103 3106 3107
3109 310a 310f 3110 3115 3117 311b 311e
3120 3124 3126 3132 3134 3136 3137 313c
3140 3142 314e 3150 3152 3156 315a 315e
3162 3166 316a 316e 3172 3176 317a 317e
3182 3186 318a 318e 3192 3196 319a 319e
31a2 31a6 31aa 31ae 31b2 31b6 31ba 31be
31c2 31c6 31ca 31ce 31d2 31d6 31da 31de
31e2 31e6 31ea 31ee 31fa 31fe 3202 3205
3209 320d 320f 1 3213 3217 321b 321e
3222 3226 322a 322e 3231 3235 3239 323c
323f 3244 3247 324a 324d 324e 3253 3254
1 3256 325b 325f 3263 3266 326b 3270
3273 3277 3278 327d 3280 3285 3286 328b
328e 3293 3294 3299 329c 32a0 32a1 32a6
32a9 32ae 32af 32b4 32b7 32bb 32bf 32c2
32c5 32c6 32c8 32c9 32ce 32cf 32d4 32d6
32da 32dd 32df 32e3 32e5 32f1 32f3 32f5
32f6 32fb 32ff 3301 330d 330f 3311 3315
3319 331c 3320 3324 3327 332b 332e 3332
3335 3336 333b 333e 3342 3346 3349 334d
3351 3354 3357 335c 335f 3362 3365 3366
336b 336c 1 336e 3373 3377 337b 337e
3383 3388 338b 338f 3390 3395 3398 339d
339e 33a3 33a6 33ab 33ac 33b1 33b4 33b8
33bc 33c0 33c4 33c7 33c8 33ca 33cf 33d0
33d2 33d3 33d8 33db 33e0 33e1 33e6 33e9
33ee 33ef 33f4 33f7 33fb 33fc 3401 3404
3409 340a 340f 3410 3415 3417 341b 341e
3422 3426 3429 342d 3431 3434 3437 343c
343f 3442 3445 3446 344b 344c 1 344e
3453 3457 345b 345e 3463 3468 346b 346f
3470 3475 3476 347b 347d 3481 3484 3488
348c 348f 3493 3497 349a 349e 34a2 34a3
34a8 34aa 34ae 34b1 34b5 34b7 34bb 34bf
34c2 34c3 34c5 34c9 34cc 34d0 34d3 34d4
34d9 34dd 34e1 34e5 34e9 34ed 34f1 34f5
34f9 34fd 3509 350d 3511 3514 3518 351c
351e 1 3522 3526 352a 352d 3531 3535
3539 353d 3540 3544 3548 354b 354e 3553
3556 3559 355c 355d 3562 3563 1 3565
356a 356e 3572 3575 357a 357f 3582 3586
3587 358c 358f 3594 3595 359a 359d 35a2
35a3 35a8 35ab 35af 35b0 35b5 35b8 35bd
35be 35c3 35c6 35ca 35ce 35d1 35d4 35d5
35d7 35d8 35dd 35de 35e3 35e5 35e9 35ec
35ee 35f2 35f4 3600 3602 3604 3605 360a
360e 3610 361c 361e 3622 3626 3629 362d
3630 3634 3637 3638 363d 3640 3644 3648
364b 364f 3653 3656 3659 365e 3661 3664
3667 3668 366d 366e 1 3670 3675 3679
367d 3680 3685 368a 368d 3691 3692 3697
369a 369f 36a0 36a5 36a8 36ad 36ae 36b3
36b6 36ba 36be 36c2 36c6 36c9 36ca 36cc
36d1 36d2 36d4 36d5 36da 36dd 36e2 36e3
36e8 36eb 36f0 36f1 36f6 36f9 36fd 36fe
3703 3706 370b 370c 3711 3712 3717 3719
371d 3720 3724 3728 372b 372f 3733 3736
3739 373e 3741 3744 3747 3748 374d 374e
1 3750 3755 3759 375d 3760 3765 376a
376d 3771 3772 3777 3778 377d 377f 3783
3786 378a 378e 3791 3795 3799 379c 37a0
37a4 37a5 37aa 37ac 37b0 37b3 37b7 37bb
37bf 37c3 37c7 37cb 37cf 37d3 37d7 37db
37df 37e3 37e7 37eb 37ef 37f3 37f7 37fb
37ff 380b 380f 3813 3816 381a 381e 3820
1 3824 3828 382c 382f 3833 3837 383b
383f 3842 3846 384a 384d 3850 3855 3858
385b 385e 385f 3864 3865 1 3867 386c
3870 3874 3877 387c 3881 3884 3888 3889
388e 3891 3896 3897 389c 389f 38a4 38a5
38aa 38ad 38b1 38b2 38b7 38ba 38bf 38c0
38c5 38c8 38cc 38d0 38d3 38d6 38d7 38d9
38da 38df 38e0 38e5 38e7 38eb 38ee 38f0
38f4 38f6 3902 3904 3906 3907 390c 3910
3912 391e 3920 3924 3928 392b 392f 3932
3936 3939 393a 393f 3942 3946 394a 394d
3951 3955 3958 395b 3960 3963 3966 3969
396a 396f 3970 1 3972 3977 397b 397f
3982 3987 398c 398f 3993 3994 3999 399c
39a1 39a2 39a7 39aa 39af 39b0 39b5 39b8
39bc 39c0 39c4 39c8 39cb 39cc 39ce 39d3
39d4 39d6 39d7 39dc 39df 39e4 39e5 39ea
39ed 39f2 39f3 39f8 39fb 39ff 3a00 3a05
3a08 3a0d 3a0e 3a13 3a14 3a19 3a1b 3a1f
3a22 3a26 3a2a 3a2d 3a31 3a35 3a38 3a3b
3a40 3a43 3a46 3a49 3a4a 3a4f 3a50 1
3a52 3a57 3a5b 3a5f 3a62 3a67 3a6c 3a6f
3a73 3a74 3a79 3a7a 3a7f 3a81 3a85 3a88
3a8c 3a90 3a93 3a97 3a9b 3a9e 3aa2 3aa6
3aa7 3aac 3aae 3ab2 3ab5 3ab9 3abc 3abd
3ac2 3ac5 3ac9 3acd 3ad1 3ad4 3ad8 3adc
3ae0 3ae4 3ae5 3ae7 3aeb 3aed 3af1 3af4
3af6 3afa 3afe 3b02 3b05 3b09 3b0d 3b10
3b13 3b18 3b1b 3b1e 3b21 3b22 3b27 3b28
1 3b2a 3b2f 3b33 3b37 3b3a 3b3f 3b44
3b47 3b4b 3b4c 3b51 3b54 3b59 3b5a 3b5f
3b62 3b67 3b68 3b6d 3b70 3b74 3b78 3b7c
3b80 3b83 3b84 3b86 3b8b 3b8c 3b8e 3b8f
3b94 3b97 3b9c 3b9d 3ba2 3ba5 3baa 3bab
3bb0 3bb3 3bb7 3bb8 3bbd 3bc0 3bc5 3bc6
3bcb 3bcc 3bd1 3bd3 3bd7 3bda 3bde 3be2
3be5 3be9 3bed 3bf0 3bf3 3bf8 3bfb 3bfe
3c01 3c02 3c07 3c08 1 3c0a 3c0f 3c13
3c17 3c1a 3c1f 3c24 3c27 3c2b 3c2c 3c31
3c32 3c37 3c39 3c3d 3c40 3c44 3c48 3c4b
3c4f 3c53 3c56 3c5a 3c5e 3c5f 3c64 3c66
3c6a 3c6e 3c71 3c75 3c79 3c7c 3c7d 3c7f
3c83 3c86 3c8a 3c8d 3c8e 3c93 3c97 3c9b
3c9f 3ca3 3ca7 3cab 3caf 3cb3 3cb7 3cbb
3cbf 3cc3 3cc7 3ccb 3ccf 3cd3 3cd7 3cdb
3cdf 3ce3 3ce7 3cf3 3cf7 3cfb 3cfe 3d02
3d06 3d08 1 3d0c 3d10 3d14 3d17 3d1b
3d1f 3d23 3d27 3d2a 3d2e 3d32 3d35 3d38
3d3d 3d40 3d43 3d46 3d47 3d4c 3d4d 1
3d4f 3d54 3d58 3d5c 3d5f 3d64 3d69 3d6c
3d70 3d71 3d76 3d79 3d7e 3d7f 3d84 3d87
3d8c 3d8d 3d92 3d95 3d99 3d9a 3d9f 3da2
3da7 3da8 3dad 3db0 3db4 3db8 3dbb 3dbe
3dbf 3dc1 3dc2 3dc7 3dc8 3dcd 3dcf 3dd3
3dd6 3dd8 3ddc 3dde 3dea 3dec 3dee 3def
3df4 3df8 3dfa 3e06 3e08 3e0c 3e10 3e13
3e17 3e1a 3e1e 3e21 3e22 3e27 3e2a 3e2e
3e32 3e35 3e39 3e3d 3e40 3e43 3e48 3e4b
3e4e 3e51 3e52 3e57 3e58 1 3e5a 3e5f
3e63 3e67 3e6a 3e6f 3e74 3e77 3e7b 3e7c
3e81 3e84 3e89 3e8a 3e8f 3e92 3e97 3e98
3e9d 3ea0 3ea4 3ea8 3eac 3eb0 3eb3 3eb4
3eb6 3ebb 3ebc 3ebe 3ebf 3ec4 3ec7 3ecc
3ecd 3ed2 3ed5 3eda 3edb 3ee0 3ee3 3ee7
3ee8 3eed 3ef0 3ef5 3ef6 3efb 3efc 3f01
3f03 3f07 3f0a 3f0e 3f12 3f15 3f19 3f1d
3f20 3f23 3f28 3f2b 3f2e 3f31 3f32 3f37
3f38 1 3f3a 3f3f 3f43 3f47 3f4a 3f4f
3f54 3f57 3f5b 3f5c 3f61 3f62 3f67 3f69
3f6d 3f70 3f74 3f78 3f7b 3f7f 3f83 3f86
3f8a 3f8e 3f8f 3f94 3f98 3f9a 3f9e 3fa2
3fa5 3fa9 3fac 3fb0 3fb3 3fb4 3fb9 3fbc
3fc0 3fc4 3fc7 3fca 3fcb 3fcd 3fd0 3fd5
3fd6 3fdb 3fdf 3fe3 3fe6 3fe7 3fe9 3fec
3fef 3ff0 3ff5 3ff9 3ffd 4000 4001 4003
4007 400a 400e 4011 4012 4014 4015 1
401a 401f 1 4022 4027 402b 402f 4032
4033 4035 4039 403c 4040 4043 4044 4046
4047 1 404c 4051 4055 4059 405c 4060
4064 4067 406a 406f 4072 4075 4078 4079
407e 407f 1 4081 4086 408a 408e 4091
4096 409b 409e 40a2 40a3 40a8 40ab 40b0
40b1 40b6 40b9 40be 40bf 40c4 40c7 40cb
40cf 40d3 40d7 40da 40db 40dd 40e2 40e3
40e5 40e6 40eb 40ee 40f3 40f4 40f9 40fc
4101 4102 4107 410a 410e 410f 4114 4117
411c 411d 4122 4123 4128 412a 412e 4131
4135 4139 413c 4140 4144 4147 414a 414f
4152 4155 4158 4159 415e 415f 1 4161
4166 416a 416e 4171 4176 417b 417e 4182
4183 4188 4189 418e 4190 4194 4197 419b
419f 41a2 41a6 41aa 41ad 41b1 41b5 41b6
41bb 41bd 41c1 41c4 41c6 41ca 41ce 41d1
41d3 41d7 41da 41dc 41e0 41e3 41e7 41eb
41ee 41ef 41f1 41f4 41f7 41f8 41fd 4201
4205 4208 4209 420b 420f 4212 4216 4219
421a 421f 4223 4226 4227 422c 1 422f
4234 4238 423c 423f 4240 4242 4245 4248
4249 1 424e 4253 4257 425b 425e 4262
4266 4269 426c 4271 4274 4277 427a 427b
4280 4281 1 4283 4288 428c 4290 4293
4298 429d 42a0 42a4 42a5 42aa 42ad 42b2
42b3 42b8 42bb 42c0 42c1 42c6 42c9 42cd
42d1 42d5 42d9 42dc 42dd 42df 42e4 42e5
42e7 42e8 42ed 42f0 42f5 42f6 42fb 42fe
4303 4304 4309 430c 4310 4311 4316 4319
431e 431f 4324 4325 432a 432c 4330 4333
4337 433b 433e 4342 4346 4349 434c 4351
4354 4357 435a 435b 4360 4361 1 4363
4368 436c 4370 4373 4378 437d 4380 4384
4385 438a 438b 4390 4392 4396 4399 439d
43a1 43a4 43a8 43ac 43af 43b3 43b7 43b8
43bd 43bf 43c3 43c6 43ca 43ce 43d1 43d2
43d4 43d8 43db 43df 43e2 43e3 43e8 43ec
43f0 43f4 43f8 43fc 4400 4404 4408 440c
4410 4414 4420 4424 4428 442b 442f 4433
4435 1 4439 443d 4441 4444 4448 444c
4450 4454 4457 445b 445f 4462 4465 446a
446d 4470 4473 4474 4479 447a 1 447c
4481 4485 4489 448c 4491 4496 4499 449d
449e 44a3 44a6 44ab 44ac 44b1 44b4 44b9
44ba 44bf 44c2 44c6 44c7 44cc 44cf 44d4
44d5 44da 44dd 44e1 44e5 44e8 44eb 44ec
44ee 44ef 44f4 44f5 44fa 44fc 4500 4503
4505 4509 450b 4517 4519 451b 451c 4521
4525 4527 4533 4535 4539 453d 4540 4544
4547 454b 454e 454f 4554 4557 455b 455f
4563 4567 456b 4577 457b 457f 4582 4586
458a 458c 1 4590 4594 4598 459b 459f
45a3 45a7 45ab 45ae 45b2 45b6 45b9 45bc
45c1 45c4 45c7 45ca 45cb 45d0 45d1 1
45d3 45d8 45dc 45e0 45e3 45e8 45ed 45f0
45f4 45f5 45fa 45fd 4602 4603 4608 460b
4610 4611 4616 4619 461d 461e 4623 4626
462b 462c 4631 4634 4638 463c 463f 4642
4643 4645 4646 464b 464c 4651 4653 4657
465a 465c 4660 4662 466e 4670 4672 4673
4678 467c 467e 468a 468c 4690 4694 4697
469b 469e 46a2 46a5 46a6 46ab 46ae 46b2
46b6 46b9 46bd 46c1 46c4 46c7 46cc 46cf
46d2 46d5 46d6 46db 46dc 1 46de 46e3
46e7 46eb 46ee 46f3 46f8 46fb 46ff 4700
4705 4708 470d 470e 4713 4716 471b 471c
4721 4724 4728 472c 4730 4734 4737 4738
473a 473f 4740 4742 4743 4748 474b 4750
4751 4756 4759 475e 475f 4764 4767 476b
476c 4771 4774 4779 477a 477f 4780 4785
4787 478b 478e 4792 4796 4799 479d 47a1
47a4 47a7 47ac 47af 47b2 47b5 47b6 47bb
47bc 1 47be 47c3 47c7 47cb 47ce 47d3
47d8 47db 47df 47e0 47e5 47e6 47eb 47ed
47f1 47f4 47f8 47fc 47ff 4803 4807 480a
480e 4812 4813 4818 481a 481e 4821 4823
4827 482a 482c 4830 4833 4835 4839 483c
4840 4844 4847 4848 484a 484d 4850 4851
4856 485a 485e 4861 4862 4864 4867 486a
486b 1 4870 4875 4879 487c 4880 4882
4886 4889 488d 4891 4894 4895 4897 489b
489e 48a2 48a5 48a6 48ab 48af 48b2 48b3
48b8 48bb 48bf 48c4 48c8 48cc 48d1 48d5
48d7 48db 48df 48e3 48e7 48eb 48ef 48f1
48f5 48f9 48fc 4900 4903 4907 4909 490d
4910 4913 4914 4919 491d 4922 4926 492a
492e 4932 4936 493a 493e 4941 4942 4944
4948 494c 494f 4950 4952 4956 495a 495d
495e 4960 4964 4968 496b 496c 496e 4972
4976 4979 497a 497c 4980 4984 4987 4988
498a 498e 4992 4995 4996 4998 499c 49a0
49a3 49a4 49a6 49aa 49ae 49b2 49b3 49b5
49b9 49bd 49c1 49c4 49c5 49c7 49cb 49ce
49d2 49d5 49d6 49db 49df 49e3 49e6 49ea
49ee 49f1 49f4 49f9 49fc 49ff 4a02 4a03
4a08 4a09 1 4a0b 4a10 4a14 4a18 4a1b
4a20 4a25 4a28 4a2c 4a2d 4a32 4a35 4a3a
4a3b 4a40 4a43 4a48 4a49 4a4e 4a51 4a55
4a59 4a5d 4a61 4a64 4a65 4a67 4a6c 4a6d
4a6f 4a70 4a75 4a76 4a7b 4a7d 4a81 4a84
4a88 4a8c 4a8f 4a93 4a97 4a9a 4a9d 4aa2
4aa5 4aa8 4aab 4aac 4ab1 4ab2 1 4ab4
4ab9 4abd 4ac1 4ac4 4ac9 4ace 4ad1 4ad5
4ad6 4adb 4adc 4ae1 4ae3 4ae7 4aea 4aee
4af2 4af5 4af9 4afd 4b00 4b04 4b05 4b0a
4b0e 4b10 4b14 4b18 4b1b 4b1c 4b1e 4b21
4b24 4b25 4b2a 4b2e 4b32 4b35 4b39 4b3d
4b40 4b43 4b48 4b4b 4b4e 4b51 4b52 4b57
4b58 1 4b5a 4b5f 4b63 4b67 4b6a 4b6f
4b74 4b77 4b7b 4b7c 4b81 4b84 4b89 4b8a
4b8f 4b92 4b97 4b98 4b9d 4ba0 4ba4 4ba8
4bac 4bad 4baf 4bb4 4bb5 4bb7 4bb8 4bbd
4bc0 4bc5 4bc6 4bcb 4bce 4bd3 4bd4 4bd9
4bdc 4be0 4be1 4be6 4be9 4bee 4bef 4bf4
4bf5 4bfa 4bfc 4c00 4c03 4c07 4c0b 4c0e
4c12 4c16 4c19 4c1c 4c21 4c24 4c27 4c2a
4c2b 4c30 4c31 1 4c33 4c38 4c3c 4c40
4c43 4c48 4c4d 4c50 4c54 4c55 4c5a 4c5b
4c60 4c62 4c66 4c69 4c6d 4c71 4c74 4c78
4c7c 4c7f 4c80 4c82 4c86 4c8a 4c8b 4c90
4c92 4c96 4c9a 4c9d 4c9f 4ca3 4ca7 4cab
4cad 4cb1 4cb5 4cb8 4cbc 4cc0 4cc3 4cc4
4cc6 4cc9 4ccc 4ccd 4cd2 4cd5 4cd9 4cdd
4ce0 4ce1 4ce3 4ce6 4ce9 4cea 4cef 1
4cf2 4cf7 4cfb 4cff 4d02 4d03 4d05 4d08
4d0b 4d0c 4d11 4d14 4d18 4d1c 4d1f 4d20
4d22 4d25 4d28 4d29 4d2e 1 4d31 4d36
4d3a 4d3d 4d41 4d45 4d47 4d4b 4d4f 4d52
4d53 4d55 4d58 4d5b 4d5c 4d61 4d65 4d68
4d6c 4d70 4d72 4d76 4d7a 4d7e 4d81 4d82
4d84 4d87 4d8a 4d8b 4d90 4d93 4d97 4d9b
4d9e 4d9f 4da1 4da4 4da7 4da8 4dad 1
4db0 4db5 4db9 4dbc 4dc0 4dc4 4dc6 4dca
4dce 4dd2 4dd5 4dd6 4dd8 4ddb 4dde 4ddf
4de4 4de8 4deb 4def 4df1 4df5 4df9 4dfc
4dfe 4e02 4e05 4e07 4e0b 4e0f 4e12 4e16
4e1a 4e1d 4e1e 4e20 4e24 4e27 4e2b 4e2e
4e2f 4e34 4e38 4e3b 4e3f 4e43 4e47 4e4b
4e4f 4e53 4e57 4e5b 4e5f 4e63 4e66 4e69
4e6a 4e6c 4e70 4e74 4e75 4e79 4e7d 4e81
4e84 4e85 4e87 4e8a 4e8d 4e8e 4e93 4e97
4e9b 4e9c 4ea1 4ea5 4ea9 4eac 4eb0 4eb2
4eb6 4eba 4ebe 4ec2 4ec6 4ed2 4ed6 4eda
4edd 4ee1 4ee5 4ee7 1 4eeb 4eef 4ef3
4ef6 4efa 4efe 4f02 4f06 4f09 4f0d 4f11
4f14 4f17 4f1c 4f1f 4f22 4f25 4f26 4f2b
4f2c 1 4f2e 4f33 4f37 4f3b 4f3e 4f43
4f48 4f4b 4f4f 4f50 4f55 4f58 4f5d 4f5e
4f63 4f66 4f6b 4f6c 4f71 4f74 4f78 4f79
4f7e 4f81 4f86 4f87 4f8c 4f8f 4f93 4f97
4f9a 4f9d 4f9e 4fa0 4fa1 4fa6 4fa7 4fac
4fae 4fb2 4fb5 4fb7 4fbb 4fbd 4fc9 4fcb
4fcd 4fce 4fd3 4fd7 4fd9 4fe5 4fe7 4feb
4fef 4ff2 4ff6 4ff9 4ffd 5000 5001 5006
5009 500d 5011 5014 5015 5017 501a 501d
501e 5023 5027 502b 502f 5033 5037 503b
503f 5043 5047 504b 504f 505b 505f 5063
5066 506a 506e 5070 1 5074 5078 507c
507f 5083 5087 508b 508f 5092 5096 509a
509d 50a0 50a5 50a8 50ab 50ae 50af 50b4
50b5 1 50b7 50bc 50c0 50c4 50c7 50cc
50d1 50d4 50d8 50d9 50de 50e1 50e6 50e7
50ec 50ef 50f4 50f5 50fa 50fd 5101 5102
5107 510a 510f 5110 5115 5118 511c 5120
5123 5126 5127 5129 512a 512f 5130 5135
5137 513b 513e 5140 5144 5146 5152 5154
5156 5157 515c 5160 5162 516e 5170 5174
5178 517b 517f 5182 5186 5189 518a 518f
5192 5196 5199 519d 519f 51a3 51a6 51a8
51ac 51af 51b1 51b5 51b8 51bc 51be 51c2
51c6 51c9 51cb 51cf 51d3 51d6 51da 51dd
51e0 51e1 51e6 51ea 51ee 51f2 51f6 51fa
51fe 5202 5206 520a 5216 521a 521e 5221
5225 5229 522b 1 522f 5233 5237 523a
523e 5242 5246 524a 524d 5251 5255 5258
525b 5260 5263 5266 5269 526a 526f 5270
1 5272 5277 527b 527f 5282 5287 528c
528f 5293 5294 5299 529c 52a1 52a2 52a7
52aa 52af 52b0 52b5 52b8 52bc 52bd 52c2
52c5 52ca 52cb 52d0 52d3 52d7 52db 52de
52e1 52e2 52e4 52e5 52ea 52eb 52f0 52f2
52f6 52f9 52fb 52ff 5301 530d 530f 5311
5312 5317 531b 531d 5329 532b 532f 5333
5337 533b 533f 5343 5347 534b 534f 5353
5357 535b 535f 5363 5367 536b 536f 5373
5377 537b 537f 5383 5387 538b 538f 5393
5397 539b 539f 53a3 53a7 53b3 53b7 53bb
53be 53c2 53c6 53c8 1 53cc 53d0 53d4
53d7 53db 53df 53e3 53e7 53ea 53ee 53f2
53f5 53f8 53fd 5400 5403 5406 5407 540c
540d 1 540f 5414 5418 541c 541f 5424
5429 542c 5430 5431 5436 5439 543e 543f
5444 5447 544c 544d 5452 5455 5459 545a
545f 5462 5467 5468 546d 5470 5474 5478
547b 547e 547f 5481 5482 5487 5488 548d
548f 5493 5496 5498 549c 549e 54aa 54ac
54ae 54af 54b4 54b8 54ba 54c6 54c8 54cc
54d0 54d3 54d7 54da 54de 54e1 54e2 54e7
54ea 54ee 54f2 54f5 54f9 54fd 5500 5503
5508 550b 550e 5511 5512 5517 5518 1
551a 551f 5523 5527 552a 552f 5534 5537
553b 553c 5541 5544 5549 554a 554f 5552
5557 5558 555d 5560 5564 5568 556c 5570
5573 5574 5576 557b 557c 557e 557f 5584
5587 558c 558d 5592 5595 559a 559b 55a0
55a3 55a7 55a8 55ad 55b0 55b5 55b6 55bb
55bc 55c1 55c3 55c7 55ca 55ce 55d2 55d5
55d9 55dd 55e0 55e3 55e8 55eb 55ee 55f1
55f2 55f7 55f8 1 55fa 55ff 5603 5607
560a 560f 5614 5617 561b 561c 5621 5622
5627 5629 562d 5630 5634 5638 563b 563f
5643 5646 564a 564e 564f 5654 5656 565a
565d 5661 5665 5669 566c 566d 566f 5672
5675 5676 567b 5680 5681 5683 5688 568a
568e 5692 5696 569a 569e 56a2 56a6 56aa
56ae 56b2 56b6 56ba 56be 56c2 56c6 56ca
56ce 56d2 56d6 56da 56de 56ea 56ee 56f3
56f7 56fa 56fb 5700 5704 5708 570b 570e
5712 5714 5718 571c 571f 5722 5726 5728
572c 5730 5733 5735 1 5739 573d 5741
5744 5748 574c 5750 5754 5757 575b 575f
5762 5765 576a 576d 5770 5773 5774 5779
577a 1 577c 5781 5785 5789 578c 5791
5796 5799 579d 579e 57a3 57a6 57ab 57ac
57b1 57b4 57b9 57ba 57bf 57c2 57c6 57c7
57cc 57cf 57d4 57d5 57da 57dd 57e1 57e5
57e8 57eb 57ec 57ee 57ef 57f4 57f5 57fa
57fc 5800 5803 5805 5809 580b 5817 5819
581b 581c 5821 5825 5827 5833 5835 5839
583b 583f 5843 5846 5849 584a 584c 584f
5854 5855 585a 585e 5862 5866 586a 586e
5872 5876 587a 587e 5882 588e 5892 5897
589b 589e 589f 58a4 58a8 58ac 58af 58b2
58b6 58b8 58bc 58c0 58c3 58c6 58ca 58cc
58d0 58d4 58d7 58d9 1 58dd 58e1 58e5
58e8 58ec 58f0 58f4 58f8 58fb 58ff 5903
5906 5909 590e 5911 5914 5917 5918 591d
591e 1 5920 5925 5929 592d 5930 5935
593a 593d 5941 5942 5947 594a 594f 5950
5955 5958 595d 595e 5963 5966 596a 596b
5970 5973 5978 5979 597e 5981 5985 5989
598c 598f 5990 5992 5993 5998 5999 599e
59a0 59a4 59a7 59a9 59ad 59af 59bb 59bd
59bf 59c0 59c5 59c9 59cb 59d7 59d9 59db
59df 59e3 59e6 59ea 59ee 59f2 59f6 59fa
59fe 5a02 5a06 5a0a 5a16 5a1a 5a1f 5a23
5a26 5a27 5a2c 5a30 5a34 5a37 5a3a 5a3e
5a40 5a44 5a48 5a4b 5a4e 5a52 5a54 5a58
5a5c 5a5f 5a61 1 5a65 5a69 5a6d 5a70
5a74 5a78 5a7c 5a80 5a83 5a87 5a8b 5a8e
5a91 5a96 5a99 5a9c 5a9f 5aa0 5aa5 5aa6
1 5aa8 5aad 5ab1 5ab5 5ab8 5abd 5ac2
5ac5 5ac9 5aca 5acf 5ad2 5ad7 5ad8 5add
5ae0 5ae5 5ae6 5aeb 5aee 5af2 5af3 5af8
5afb 5b00 5b01 5b06 5b09 5b0d 5b11 5b14
5b17 5b18 5b1a 5b1b 5b20 5b21 5b26 5b28
5b2c 5b2f 5b31 5b35 5b37 5b43 5b45 5b47
5b48 5b4d 5b51 5b53 5b5f 5b61 5b65 5b69
5b6d 5b71 5b75 5b79 5b7d 5b81 5b85 5b91
5b95 5b9a 5b9e 5ba1 5ba2 5ba7 5bab 5baf
5bb2 5bb5 5bb9 5bbb 5bbf 5bc3 5bc6 5bc9
5bcd 5bcf 5bd3 5bd7 5bda 5bdc 1 5be0
5be4 5be8 5beb 5bef 5bf3 5bf7 5bfb 5bfe
5c02 5c06 5c09 5c0c 5c11 5c14 5c17 5c1a
5c1b 5c20 5c21 1 5c23 5c28 5c2c 5c30
5c33 5c38 5c3d 5c40 5c44 5c45 5c4a 5c4d
5c52 5c53 5c58 5c5b 5c60 5c61 5c66 5c69
5c6d 5c6e 5c73 5c76 5c7b 5c7c 5c81 5c84
5c88 5c8c 5c8f 5c92 5c93 5c95 5c96 5c9b
5c9c 5ca1 5ca3 5ca7 5caa 5cac 5cb0 5cb2
5cbe 5cc0 5cc2 5cc3 5cc8 5ccc 5cce 5cda
5cdc 5ce0 5ce4 5ce8 5cec 5cf0 5cf4 5d00
5d04 5d09 5d0d 5d10 5d11 5d16 5d1a 5d1e
5d21 5d24 5d28 5d2a 5d2e 5d32 5d35 5d38
5d3c 5d3e 5d42 5d46 5d49 5d4b 1 5d4f
5d53 5d57 5d5a 5d5e 5d62 5d66 5d6a 5d6d
5d71 5d75 5d78 5d7b 5d80 5d83 5d86 5d89
5d8a 5d8f 5d90 1 5d92 5d97 5d9b 5d9f
5da2 5da7 5dac 5daf 5db3 5db4 5db9 5dbc
5dc1 5dc2 5dc7 5dca 5dcf 5dd0 5dd5 5dd8
5ddc 5ddd 5de2 5de5 5dea 5deb 5df0 5df3
5df7 5dfb 5dfe 5e01 5e02 5e04 5e05 5e0a
5e0b 5e10 5e12 5e16 5e19 5e1b 5e1f 5e21
5e2d 5e2f 5e31 5e32 5e37 5e3b 5e3d 5e49
5e4b 5e4d 5e51 5e54 5e58 5e5c 5e5d 5e62
5e66 5e6a 5e6e 5e71 5e72 5e74 5e77 5e7a
5e7b 5e80 5e84 5e88 5e8b 5e8c 5e8e 5e92
5e95 5e99 5e9c 5e9d 1 5ea2 5ea7 5eab
5eaf 5eb2 5eb3 5eb5 5eb9 5ebc 5ec0 5ec3
5ec4 1 5ec9 5ece 5ed2 5ed5 5ed6 5edb
5ede 5ee2 5ee6 5eea 5eec 5ef0 5ef3 5ef5
5ef9 5efc 5f00 5f04 5f07 5f08 5f0a 5f0d
5f10 5f11 5f16 5f1a 5f1e 5f22 5f25 5f29
5f2b 5f2f 5f32 5f36 5f39 5f3a 5f3f 5f42
5f46 5f49 5f4a 5f4f 1 5f52 5f57 5f5b
5f5e 5f5f 5f64 1 5f67 5f6c 5f70 5f73
5f74 5f79 5f7c 1 5f7f 5f84 5f88 5f8b
5f8f 5f91 5f95 5f98 5f9c 5fa1 5fa5 5fa9
5fae 5fb2 5fb6 5fba 5fbd 5fbe 5fc0 5fc3
5fc6 5fc7 5fcc 5fd0 5fd4 5fd7 5fd8 5fda
5fde 5fe1 5fe5 5fe8 5fe9 5fee 5ff2 5ff7
5ffa 5ffe 5fff 6004 6007 600c 600d 6012
6015 601a 601b 6020 6023 6028 6029 602e
6031 6036 6037 603c 603f 6043 6044 6049
604c 6051 6052 6057 605b 605f 6061 6065
6069 606c 606d 606f 6072 6075 6076 607b
607f 6084 6087 608c 608d 6092 6095 609a
609b 60a0 60a3 60a7 60a8 60ad 60b0 60b5
60b6 60bb 60be 60c3 60c4 60c9 60cc 60d0
60d1 60d6 60d9 60de 60df 60e4 60e7 60ec
60ed 60f2 60f6 60f8 60fc 6100 6105 6108
610d 610e 6113 6116 611b 611c 6121 6124
6129 612a 612f 6132 6136 6137 613c 613f
6144 6145 614a 614e 6150 6154 6158 615b
615d 6161 6165 6168 6169 616b 616f 6172
6176 6179 617a 617f 6183 6187 618a 618b
618d 6191 6194 6198 619b 619c 1 61a1
61a6 61aa 61ae 61b1 61b2 61b4 61b8 61bb
61bf 61c2 61c3 1 61c8 61cd 61d1 61d5
61da 61df 61e3 61e7 61eb 61ee 61f1 61f5
61f9 61fc 61fd 6202 6205 6209 620d 6212
6217 621b 621f 6223 6226 6229 622d 6231
6235 6239 623d 6241 6245 6249 624d 6251
6255 6259 625d 6261 6265 6269 626d 6271
6275 6279 627d 6281 6285 6289 6295 6299
629e 62a2 62a5 62a6 62ab 62af 62b3 62b6
62b9 62bd 62bf 62c3 62c7 62ca 62cd 62d1
62d3 62d7 62db 62de 62e0 1 62e4 62e8
62ec 62ef 62f3 62f7 62fb 62ff 6302 6306
630a 630d 6310 6315 6318 631b 631e 631f
6324 6325 1 6327 632c 6330 6334 6337
633c 6341 6344 6348 6349 634e 6351 6356
6357 635c 635f 6364 6365 636a 636d 6371
6372 6377 637a 637f 6380 6385 6388 638c
6390 6393 6396 6397 6399 639a 639f 63a0
63a5 63a7 63ab 63ae 63b0 63b4 63b6 63c2
63c4 63c6 63c7 63cc 63d0 63d2 63de 63e0
63e4 63e8 63ec 63f0 63f4 63f8 63fc 6400
6404 6408 640c 6410 6414 6418 641c 6420
6424 6428 642c 6430 6434 6440 6444 6449
644d 6450 6451 6456 645a 645e 6461 6464
6468 646a 646e 6472 6475 6478 647c 647e
6482 6486 6489 648b 1 648f 6493 6497
649a 649e 64a2 64a6 64aa 64ad 64b1 64b5
64b8 64bb 64c0 64c3 64c6 64c9 64ca 64cf
64d0 1 64d2 64d7 64db 64df 64e2 64e7
64ec 64ef 64f3 64f4 64f9 64fc 6501 6502
6507 650a 650f 6510 6515 6518 651c 651d
6522 6525 652a 652b 6530 6533 6537 653b
653e 6541 6542 6544 6545 654a 654b 6550
6552 6556 6559 655b 655f 6561 656d 656f
6571 6572 6577 657b 657d 6589 658b 658d
6591 6595 6599 659d 65a1 65a5 65a9 65ad
65b9 65bd 65c2 65c6 65c9 65ca 65cf 65d3
65d7 65da 65dd 65e1 65e3 65e7 65eb 65ee
65f1 65f5 65f7 65fb 65ff 6602 6604 1
6608 660c 6610 6613 6617 661b 661f 6623
6626 662a 662e 6631 6634 6639 663c 663f
6642 6643 6648 6649 1 664b 6650 6654
6658 665b 6660 6665 6668 666c 666d 6672
6675 667a 667b 6680 6683 6688 6689 668e
6691 6695 6696 669b 669e 66a3 66a4 66a9
66ac 66b0 66b4 66b7 66ba 66bb 66bd 66be
66c3 66c4 66c9 66cb 66cf 66d2 66d4 66d8
66da 66e6 66e8 66ea 66eb 66f0 66f4 66f6
6702 6704 6706 670a 670e 6711 6713 6717
671a 671e 6721 6722 6727 672a 672e 6732
6736 673a 673b 673d 6740 6741 6743 6746
6749 674a 674f 6753 6757 675b 675f 6760
6762 6765 6766 6768 676b 676c 676e 6771
6774 6775 677a 677b 677d 6781 6785 6789
678d 678e 6790 6793 6794 6796 6799 679a
679c 679e 67a2 67a6 67aa 67ad 67b1 67b5
67b9 67bd 67c0 67c4 67c5 67ca 67cc 67d0
67d4 67d8 67dc 67e0 67e3 67e6 67e7 67ec
67ef 67f0 67f2 67f3 67f5 67f8 67f9 67fb
67fe 6801 6802 6807 680b 680f 6813 6817
681b 681e 6821 6822 6827 682a 682b 682d
682e 6830 6833 6834 6836 6839 683c 683d
1 6842 6847 684b 6851 6853 6857 685a
685e 6862 6865 6868 6869 686e 6872 6874
6878 687f 6883 6887 688a 688b 6890 6894
6898 689b 689f 68a3 68a6 68a9 68ae 68b1
68b4 68b7 68b8 68bd 68be 1 68c0 68c5
68c9 68cd 68d0 68d5 68da 68dd 68e1 68e2
68e7 68ea 68ef 68f0 68f5 68f8 68fd 68fe
6903 6906 690a 690e 6912 6916 6919 691a
691c 6921 6922 6924 6925 692a 692b 6930
6932 6936 6939 693d 6941 6944 6948 694c
694f 6952 6957 695a 695d 6960 6961 6966
6967 1 6969 696e 6972 6976 6979 697e
6983 6986 698a 698b 6990 6991 6996 6998
699c 699f 69a3 69a7 69aa 69ae 69b2 69b5
69b9 69ba 69bf 69c1 69c5 69c8 69cc 69d0
69d4 69d8 69e4 69e8 69ec 69ef 69f3 69f7
69f9 1 69fd 6a01 6a05 6a08 6a0c 6a10
6a14 6a18 6a1b 6a1f 6a23 6a26 6a29 6a2e
6a31 6a34 6a37 6a38 6a3d 6a3e 1 6a40
6a45 6a49 6a4d 6a50 6a55 6a5a 6a5d 6a61
6a62 6a67 6a6a 6a6f 6a70 6a75 6a78 6a7d
6a7e 6a83 6a86 6a8a 6a8b 6a90 6a93 6a98
6a99 6a9e 6aa1 6aa5 6aa9 6aac 6aaf 6ab0
6ab2 6ab3 6ab8 6ab9 6abe 6ac0 6ac4 6ac7
6ac9 6acd 6acf 6adb 6add 6adf 6ae0 6ae5
6ae9 6aeb 6af7 6af9 6afb 6aff 6b02 6b06
6b0a 6b0d 6b0e 6b10 6b14 6b17 6b1b 6b1e
6b1f 6b24 6b28 6b2d 6b31 6b35 6b3a 6b3e
6b42 6b46 6b49 6b4d 6b4e 6b53 6b57 6b5b
6b5f 6b62 6b67 6b68 6b6d 6b71 6b75 6b77
6b7b 6b7f 6b82 6b83 6b85 6b89 6b8c 6b90
6b93 6b94 6b99 6b9d 6ba2 6ba6 6baa 6bae
6bb1 6bb5 6bb6 6bbb 6bbf 6bc3 6bc7 6bca
6bcf 6bd0 6bd5 6bd9 6bdd 6be2 6be6 6be8
6bec 6bf0 6bf4 6bf7 6bf8 6bfa 6bfe 6c01
6c05 6c08 6c09 6c0e 6c12 6c17 6c1b 6c1f
6c24 6c28 6c2c 6c2f 6c30 6c35 6c38 6c3c
6c40 6c43 6c48 6c49 6c4e 6c52 6c56 6c5a
6c5d 6c61 6c62 6c67 6c6b 6c6f 6c73 6c76
6c7b 6c7c 6c81 6c85 6c87 6c8b 6c8e 6c92
6c96 6c99 6c9e 6c9f 6ca4 6ca8 6cac 6caf
6cb0 6cb5 6cb8 6cbc 6cc0 6cc3 6cc8 6cc9
6cce 6cd2 6cd6 6cda 6cdd 6ce1 6ce2 6ce7
6ceb 6cef 6cf3 6cf6 6cfb 6cfc 6d01 6d05
6d07 6d0b 6d0e 6d10 6d14 6d18 6d1b 6d20
6d21 6d26 6d29 6d2e 6d2f 6d34 6d38 6d3c
6d41 6d45 6d49 6d4c 6d4d 6d52 6d55 6d59
6d5d 6d60 6d65 6d66 6d6b 6d6f 6d73 6d77
6d7a 6d7e 6d7f 6d84 6d88 6d8c 6d90 6d93
6d98 6d99 6d9e 6da2 6da4 6da8 6dab 6daf
6db3 6db6 6dbb 6dbc 6dc1 6dc4 6dc9 6dca
6dcf 6dd2 6dd7 6dd8 6ddd 6de0 6de5 6de6
6deb 6dee 6df3 6df4 6df9 6dfc 6e01 6e02
6e07 6e0b 6e0f 6e12 6e13 6e18 6e1b 6e1f
6e23 6e26 6e2b 6e2c 6e31 6e34 6e38 6e39
6e3e 6e41 6e46 6e47 6e4c 6e50 6e52 6e56
6e59 6e5b 6e5f 6e63 6e66 6e68 6e6c 6e70
6e73 6e77 6e7b 6e7e 6e7f 6e81 6e85 6e88
6e8c 6e8f 6e90 6e95 6e99 6e9c 6e9d 6ea2
6ea5 6ea9 6ead 6eb1 6eb5 6eb9 6ec5 6ec9
6ecd 6ed0 6ed4 6ed8 6eda 1 6ede 6ee2
6ee6 6ee9 6eed 6ef1 6ef5 6ef9 6efc 6f00
6f04 6f07 6f0a 6f0f 6f12 6f15 6f18 6f19
6f1e 6f1f 1 6f21 6f26 6f2a 6f2e 6f31
6f36 6f3b 6f3e 6f42 6f43 6f48 6f4b 6f50
6f51 6f56 6f59 6f5e 6f5f 6f64 6f67 6f6b
6f6c 6f71 6f74 6f79 6f7a 6f7f 6f82 6f86
6f8a 6f8d 6f90 6f91 6f93 6f94 6f99 6f9a
6f9f 6fa1 6fa5 6fa8 6faa 6fae 6fb0 6fbc
6fbe 6fc0 6fc1 6fc6 6fca 6fcc 6fd8 6fda
6fde 6fe2 6fe5 6fe9 6fec 6ff0 6ff3 6ff4
6ff9 6ffc 7000 7004 7008 700c 700d 700f
7012 7013 7015 7019 701d 7021 7024 7029
702a 702f 7033 7037 703b 703e 7043 7044
7049 704c 7051 7052 7057 705a 705e 705f
7064 7067 706c 706d 7072 7076 7078 707c
7080 7083 7087 708b 708e 7091 7096 7099
709c 709f 70a0 70a5 70a6 1 70a8 70ad
70b1 70b5 70b8 70bd 70c2 70c5 70c9 70ca
70cf 70d2 70d7 70d8 70dd 70e0 70e5 70e6
70eb 70ee 70f2 70f6 70fa 70fe 7101 7102
7104 7109 710a 710c 710d 7112 7115 711a
711b 7120 7123 7128 7129 712e 7131 7135
7136 713b 713e 7143 7144 7149 714a 714f
7151 7155 7158 715c 7160 7163 7167 716b
716e 7171 7176 7179 717c 717f 7180 7185
7186 1 7188 718d 7191 7195 7198 719d
71a2 71a5 71a9 71aa 71af 71b0 71b5 71b7
71bb 71be 71c2 71c6 71c9 71cd 71d1 71d4
71d8 71dc 71dd 71e2 71e4 71e8 71ec 71ef
71f1 71f5 71f8 71fc 71ff 7200 7205 7208
720c 7210 7214 7218 721c 7228 722c 7230
7233 7237 723b 723d 1 7241 7245 7249
724c 7250 7254 7258 725c 725f 7263 7267
726a 726d 7272 7275 7278 727b 727c 7281
7282 1 7284 7289 728d 7291 7294 7299
729e 72a1 72a5 72a6 72ab 72ae 72b3 72b4
72b9 72bc 72c1 72c2 72c7 72ca 72ce 72cf
72d4 72d7 72dc 72dd 72e2 72e5 72e9 72ed
72f0 72f3 72f4 72f6 72f7 72fc 72fd 7302
7304 7308 730b 730d 7311 7313 731f 7321
7323 7324 7329 732d 732f 733b 733d 7341
7345 7348 734c 734f 7353 7356 7357 735c
735f 7363 7367 736a 736f 7370 7375 7379
737d 7381 7384 7389 738a 738f 7392 7397
7398 739d 73a0 73a4 73a5 73aa 73ad 73b2
73b3 73b8 73bc 73be 73c2 73c6 73c9 73cd
73d1 73d4 73d7 73dc 73df 73e2 73e5 73e6
73eb 73ec 1 73ee 73f3 73f7 73fb 73fe
7403 7408 740b 740f 7410 7415 7418 741d
741e 7423 7426 742b 742c 7431 7434 7438
743c 7440 7444 7447 7448 744a 744f 7450
7452 7453 7458 745b 7460 7461 7466 7469
746e 746f 7474 7477 747b 747c 7481 7484
7489 748a 748f 7490 7495 7497 749b 749e
74a2 74a6 74a9 74ad 74b1 74b4 74b7 74bc
74bf 74c2 74c5 74c6 74cb 74cc 1 74ce
74d3 74d7 74db 74de 74e3 74e8 74eb 74ef
74f0 74f5 74f6 74fb 74fd 7501 7504 7508
750c 750f 7513 7517 751a 751e 7522 7523
7528 752a 752e 7532 7535 7537 753b 753e
7542 7545 7546 754b 754e 7552 7556 755a
755e 7562 756e 7572 7576 7579 757d 7581
7583 1 7587 758b 758f 7592 7596 759a
759e 75a2 75a5 75a9 75ad 75b0 75b3 75b8
75bb 75be 75c1 75c2 75c7 75c8 1 75ca
75cf 75d3 75d7 75da 75df 75e4 75e7 75eb
75ec 75f1 75f4 75f9 75fa 75ff 7602 7607
7608 760d 7610 7614 7615 761a 761d 7622
7623 7628 762b 762f 7633 7636 7639 763a
763c 763d 7642 7643 7648 764a 764e 7651
7653 7657 7659 7665 7667 7669 766a 766f
7673 7675 7681 7683 7687 768b 768e 7692
7695 7699 769c 769d 76a2 76a5 76a9 76ad
76b0 76b5 76b6 76bb 76bf 76c3 76c7 76ca
76cf 76d0 76d5 76d8 76dd 76de 76e3 76e6
76ea 76eb 76f0 76f3 76f8 76f9 76fe 7702
7704 7708 770c 770f 7713 7717 771a 771d
7722 7725 7728 772b 772c 7731 7732 1
7734 7739 773d 7741 7744 7749 774e 7751
7755 7756 775b 775e 7763 7764 7769 776c
7771 7772 7777 777a 777e 7782 7786 778a
778d 778e 7790 7795 7796 7798 7799 779e
77a1 77a6 77a7 77ac 77af 77b4 77b5 77ba
77bd 77c1 77c2 77c7 77ca 77cf 77d0 77d5
77d6 77db 77dd 77e1 77e4 77e8 77ec 77ef
77f3 77f7 77fa 77fd 7802 7805 7808 780b
780c 7811 7812 1 7814 7819 781d 7821
7824 7829 782e 7831 7835 7836 783b 783c
7841 7843 7847 784a 784e 7852 7855 7859
785d 7860 7864 7868 7869 786e 7870 7874
7878 787b 787d 7881 7884 7888 788c 788f
7890 7892 7895 7898 7899 789e 78a2 78a6
78a9 78aa 78ac 78af 78b2 78b3 1 78b8
78bd 78c1 78c5 78c8 78cd 78ce 78d3 78d6
78da 78de 78e2 78e5 78e6 78e8 78e9 78eb
78ec 78f1 78f4 78f9 78fa 78ff 7903 7905
7909 790c 790e 7912 7915 7919 791c 791d
7922 7925 7929 792d 7931 7935 7936 7938
793b 793c 793e 7942 7946 7949 794d 7951
7955 7959 795c 7960 7961 7966 7968 796c
7970 7974 7977 797a 797d 7981 7984 7987
7988 798d 7991 7992 7994 7998 799c 79a0
79a4 79a8 79ac 79b8 79bc 79c0 79c3 79c7
79cb 79cd 1 79d1 79d5 79d9 79dc 79e0
79e4 79e8 79ec 79ef 79f3 79f7 79fa 79fd
7a02 7a05 7a08 7a0b 7a0c 7a11 7a12 1
7a14 7a19 7a1d 7a21 7a24 7a29 7a2e 7a31
7a35 7a36 7a3b 7a3e 7a43 7a44 7a49 7a4c
7a51 7a52 7a57 7a5a 7a5e 7a5f 7a64 7a67
7a6c 7a6d 7a72 7a75 7a79 7a7d 7a80 7a83
7a84 7a86 7a87 7a8c 7a8d 7a92 7a94 7a98
7a9b 7a9d 7aa1 7aa3 7aaf 7ab1 7ab3 7ab4
7ab9 7abd 7abf 7acb 7acd 7ad1 7ad5 7ad8
7adc 7adf 7ae3 7ae6 7ae7 7aec 7aef 7af3
7af7 7afa 7afe 7b02 7b05 7b08 7b0d 7b10
7b13 7b16 7b17 7b1c 7b1d 1 7b1f 7b24
7b28 7b2c 7b2f 7b34 7b39 7b3c 7b40 7b41
7b46 7b49 7b4e 7b4f 7b54 7b57 7b5c 7b5d
7b62 7b65 7b69 7b6d 7b71 7b75 7b78 7b79
7b7b 7b80 7b81 7b83 7b84 7b89 7b8c 7b91
7b92 7b97 7b9a 7b9f 7ba0 7ba5 7ba8 7bac
7bad 7bb2 7bb5 7bba 7bbb 7bc0 7bc1 7bc6
7bc8 7bcc 7bcf 7bd3 7bd7 7bda 7bde 7be2
7be5 7be8 7bed 7bf0 7bf3 7bf6 7bf7 7bfc
7bfd 1 7bff 7c04 7c08 7c0c 7c0f 7c14
7c19 7c1c 7c20 7c21 7c26 7c27 7c2c 7c2e
7c32 7c35 7c39 7c3d 7c40 7c44 7c48 7c4b
7c4f 7c53 7c54 7c59 7c5b 7c5f 7c62 7c66
7c6a 7c6d 7c72 7c73 7c78 7c7b 7c80 7c81
7c86 7c89 7c8e 7c8f 7c94 7c97 7c9c 7c9d
7ca2 7ca5 7ca9 7caa 7caf 7cb2 7cb7 7cb8
7cbd 7cc1 7cc5 7cc9 7ccc 7ccd 7ccf 7cd3
7cd6 7cda 7cdd 7cde 7ce3 7ce7 7ceb 7cee
7cf3 7cf4 7cf9 7cfd 7cff 7d03 7d07 7d0a
7d0f 7d10 7d15 7d19 7d1b 7d1f 7d23 7d26
7d2a 7d2e 7d31 7d32 7d34 7d38 7d3b 7d3f
7d42 7d43 7d48 7d4c 7d52 7d54 7d58 7d5b
7d5f 7d63 7d66 7d69 7d6a 7d6f 7d73 7d75
7d79 7d80 7d82 7d86 7d89 7d8d 7d91 7d94
7d95 7d97 7d9b 7d9e 7da2 7da5 7da6 7dab
7daf 7db3 7db7 7dbb 7dbc 7dbe 7dc1 7dc2
7dc4 7dc8 7dcc 7dcf 7dd3 7dd7 7ddb 7ddf
7de2 7de6 7de7 7dec 7dee 7df2 7df6 7dfa
7dfd 7e00 7e03 7e07 7e0a 7e0d 7e0e 7e13
7e17 7e18 7e1a 7e1e 7e22 7e26 7e2a 7e2e
7e32 7e3e 7e42 7e46 7e49 7e4d 7e51 7e53
1 7e57 7e5b 7e5f 7e62 7e66 7e6a 7e6e
7e72 7e75 7e79 7e7d 7e80 7e83 7e88 7e8b
7e8e 7e91 7e92 7e97 7e98 1 7e9a 7e9f
7ea3 7ea7 7eaa 7eaf 7eb4 7eb7 7ebb 7ebc
7ec1 7ec4 7ec9 7eca 7ecf 7ed2 7ed7 7ed8
7edd 7ee0 7ee4 7ee5 7eea 7eed 7ef2 7ef3
7ef8 7efb 7eff 7f03 7f06 7f09 7f0a 7f0c
7f0d 7f12 7f13 7f18 7f1a 7f1e 7f21 7f23
7f27 7f29 7f35 7f37 7f39 7f3a 7f3f 7f43
7f45 7f51 7f53 7f57 7f5b 7f5e 7f62 7f65
7f69 7f6c 7f6d 7f72 7f75 7f79 7f7d 7f80
7f84 7f88 7f8b 7f8e 7f93 7f96 7f99 7f9c
7f9d 7fa2 7fa3 1 7fa5 7faa 7fae 7fb2
7fb5 7fba 7fbf 7fc2 7fc6 7fc7 7fcc 7fcf
7fd4 7fd5 7fda 7fdd 7fe2 7fe3 7fe8 7feb
7fef 7ff3 7ff7 7ffb 7ffe 7fff 8001 8006
8007 8009 800a 800f 8012 8017 8018 801d
8020 8025 8026 802b 802e 8032 8033 8038
803b 8040 8041 8046 8047 804c 804e 8052
8055 8059 805d 8060 8064 8068 806b 806e
8073 8076 8079 807c 807d 8082 8083 1
8085 808a 808e 8092 8095 809a 809f 80a2
80a6 80a7 80ac 80ad 80b2 80b4 80b8 80bb
80bf 80c3 80c6 80ca 80ce 80d1 80d5 80d9
80da 80df 80e1 80e5 80e8 80ec 80f0 80f3
80f8 80f9 80fe 8101 8106 8107 810c 810f
8114 8115 811a 811d 8122 8123 8128 812b
812f 8130 8135 8138 813d 813e 8143 8146
814b 814c 8151 8155 8159 815d 8160 8163
8164 8169 816d 816f 8173 817a 817c 8180
8183 8187 818b 818e 8192 8193 8198 819c
819e 81a2 81a6 81a9 81ad 81b1 81b4 81b9
81ba 81bf 81c3 81c7 81cb 81cf 81d2 81d6
81da 81de 81e2 81e7 81ec 81f0 81f4 81f9
81fd 8201 8204 8207 820b 820d 8211 8215
8218 821b 821f 8221 8225 8229 822c 8230
8234 8237 823b 823e 8242 8245 8246 824b
824e 8252 8258 825a 825e 8261 8265 8269
826c 826d 826f 8272 8275 8276 827b 827f
8283 8286 8287 8289 828d 8290 8294 8297
8298 1 829d 82a2 82a6 82aa 82ad 82ae
82b0 82b4 82b7 82bb 82be 82bf 1 82c4
82c9 82cd 82d1 82d4 82d5 82d7 82db 82de
82e2 82e5 82e6 82eb 82ef 82f2 82f3 82f8
1 82fb 8300 1 8303 8308 830c 8310
8315 8319 831a 831e 8322 8327 832c 8330
8334 8339 833d 8341 8344 8347 834b 834d
8351 8355 8358 835b 835f 8361 8365 8369
836c 8370 8374 8377 837b 837e 8382 8385
8386 838b 838e 8392 8396 839b 839d 83a1
83a5 83a8 83ac 83b0 83b2 1 83b6 83ba
83be 83c1 83c5 83c9 83cd 83d1 83d4 83d8
83dc 83df 83e2 83e7 83ea 83ed 83f0 83f1
83f6 83f7 1 83f9 83fe 8402 8406 8409
840e 8413 8416 841a 841b 8420 8423 8428
8429 842e 8431 8436 8437 843c 843f 8443
8444 8449 844c 8451 8452 8457 845a 845e
8462 8465 8468 8469 846b 846c 8471 8472
8477 8479 847d 8480 8482 8486 8488 8494
8496 8498 8499 849e 84a2 84a4 84b0 84b2
84b6 84bc 84be 84c2 84c6 84cb 84cd 84d1
84d5 84d8 84dc 84e0 84e2 1 84e6 84ea
84ee 84f1 84f5 84f9 84fd 8501 8504 8508
850c 850f 8512 8517 851a 851d 8520 8521
8526 8527 1 8529 852e 8532 8536 8539
853e 8543 8546 854a 854b 8550 8553 8558
8559 855e 8561 8566 8567 856c 856f 8573
8574 8579 857c 8581 8582 8587 858a 858e
8592 8595 8598 8599 859b 859c 85a1 85a2
85a7 85a9 85ad 85b0 85b2 85b6 85b8 85c4
85c6 85c8 85c9 85ce 85d2 85d4 85e0 85e2
85e4 85e8 85ec 85ef 85f1 85f5 85f8 85fc
8600 8604 8608 860c 8610 8614 8618 861b
861c 861e 8621 8624 8625 862a 862e 8632
8635 8638 8639 863b 863e 8643 8644 8649
864d 8651 8652 8657 865b 865f 8662 8666
8668 866c 8670 8674 8677 8678 867a 867b
867d 8680 8683 8684 8689 868d 8691 8695
8699 869d 86a1 86a5 86a9 86ad 86b9 86bd
86c1 86c4 86c8 86cc 86ce 1 86d2 86d6
86da 86dd 86e1 86e5 86e9 86ed 86f0 86f4
86f8 86fb 86fe 8703 8706 8709 870c 870d
8712 8713 1 8715 871a 871e 8722 8725
872a 872f 8732 8736 8737 873c 873f 8744
8745 874a 874d 8752 8753 8758 875b 875f
8760 8765 8768 876d 876e 8773 8776 877a
877e 8781 8784 8785 8787 8788 878d 878e
8793 8795 8799 879c 879e 87a2 87a4 87b0
87b2 87b4 87b5 87ba 87be 87c0 87cc 87ce
87d2 87d6 87d9 87da 87dc 87df 87e2 87e3
87e8 87ec 87f0 87f5 87f7 87fb 87ff 8802
8806 880a 880c 1 8810 8814 8818 881b
881f 8823 8827 882b 882e 8832 8836 8839
883c 8841 8844 8847 884a 884b 8850 8851
1 8853 8858 885c 8860 8863 8868 886d
8870 8874 8875 887a 887d 8882 8883 8888
888b 8890 8891 8896 8899 889d 889e 88a3
88a6 88ab 88ac 88b1 88b4 88b8 88bc 88bf
88c2 88c3 88c5 88c6 88cb 88cc 88d1 88d3
88d7 88da 88dc 88e0 88e2 88ee 88f0 88f2
88f3 88f8 88fc 88fe 890a 890c 8910 8914
8917 891b 891f 8922 8925 892a 892d 8930
8933 8934 8939 893a 1 893c 8941 8945
8949 894c 8951 8956 8959 895d 895e 8963
8966 896b 896c 8971 8974 8979 897a 897f
8982 8986 898a 898e 8992 8995 8996 8998
899d 899e 89a0 89a1 89a6 89a9 89ae 89af
89b4 89b7 89bc 89bd 89c2 89c5 89c9 89ca
89cf 89d2 89d7 89d8 89dd 89de 89e3 89e5
89e9 89ec 89f0 89f4 89f7 89fb 89ff 8a02
8a05 8a0a 8a0d 8a10 8a13 8a14 8a19 8a1a
1 8a1c 8a21 8a25 8a29 8a2c 8a31 8a36
8a39 8a3d 8a3e 8a43 8a44 8a49 8a4b 8a4f
8a52 8a56 8a5a 8a5d 8a61 8a65 8a68 8a6c
8a70 8a71 8a76 8a78 8a7c 8a7f 8a81 8a85
8a88 8a8a 8a8e 8a92 8a95 8a99 8a9d 8aa1
8aa5 8aa9 8aad 8ab1 8ab5 8ab9 8abd 8ac1
8ac5 8ac9 8acd 8ad1 8ad5 8ad9 8add 8ae1
8ae5 8ae9 8aed 8af1 8af5 8af9 8afd 8b01
8b05 8b09 8b0d 8b11 8b15 8b18 8b19 8b1b
8b1e 8b21 8b24 8b25 8b27 8b2b 8b2f 8b32
8b35 8b36 8b3b 8b3f 8b43 8b48 8b4a 8b4e
8b52 8b55 8b59 8b5d 8b5f 1 8b63 8b67
8b6b 8b6e 8b72 8b76 8b7a 8b7e 8b81 8b85
8b89 8b8c 8b8f 8b94 8b97 8b9a 8b9d 8b9e
8ba3 8ba4 1 8ba6 8bab 8baf 8bb3 8bb6
8bbb 8bc0 8bc3 8bc7 8bc8 8bcd 8bd0 8bd5
8bd6 8bdb 8bde 8be3 8be4 8be9 8bec 8bf0
8bf1 8bf6 8bf9 8bfe 8bff 8c04 8c07 8c0b
8c0f 8c12 8c15 8c16 8c18 8c19 8c1e 8c1f
8c24 8c26 8c2a 8c2d 8c2f 8c33 8c35 8c41
8c43 8c45 8c46 8c4b 8c4f 8c51 8c5d 8c5f
8c63 8c67 8c6a 8c6e 8c71 8c72 8c77 8c7b
8c7f 8c83 8c86 8c8a 8c8c 8c90 8c93 8c97
8c9b 8c9e 8ca2 8ca6 8ca9 8cac 8cb1 8cb4
8cb7 8cba 8cbb 8cc0 8cc1 1 8cc3 8cc8
8ccc 8cd0 8cd3 8cd8 8cdd 8ce0 8ce4 8ce5
8cea 8ced 8cf2 8cf3 8cf8 8cfb 8d00 8d01
8d06 8d09 8d0d 8d11 8d15 8d16 8d18 8d1d
8d1e 8d20 8d21 8d26 8d29 8d2e 8d2f 8d34
8d37 8d3c 8d3d 8d42 8d45 8d49 8d4a 8d4f
8d52 8d57 8d58 8d5d 8d5e 8d63 8d65 8d69
8d6c 8d70 8d74 8d77 8d7b 8d7f 8d82 8d85
8d8a 8d8d 8d90 8d93 8d94 8d99 8d9a 1
8d9c 8da1 8da5 8da9 8dac 8db1 8db6 8db9
8dbd 8dbe 8dc3 8dc4 8dc9 8dcb 8dcf 8dd2
8dd6 8dda 8ddd 8de1 8de5 8de9 8dea 8def
8df3 8df5 8df9 8dfd 8e00 8e03 8e04 8e06
8e09 8e0e 8e0f 8e14 8e17 8e1b 8e1f 8e22
8e25 8e26 8e28 8e2b 8e30 8e31 8e36 1
8e39 8e3e 8e42 8e46 8e4a 8e4e 8e52 8e5e
8e62 8e67 8e6b 8e6e 8e6f 8e74 8e78 8e7c
8e7f 8e82 8e86 8e88 8e8c 8e90 8e93 8e96
8e9a 8e9c 8ea0 8ea4 8ea7 8ea9 1 8ead
8eb1 8eb5 8eb8 8ebc 8ec0 8ec4 8ec8 8ecb
8ecf 8ed3 8ed6 8ed9 8ede 8ee1 8ee4 8ee7
8ee8 8eed 8eee 1 8ef0 8ef5 8ef9 8efd
8f00 8f05 8f0a 8f0d 8f11 8f12 8f17 8f1a
8f1f 8f20 8f25 8f28 8f2d 8f2e 8f33 8f36
8f3a 8f3b 8f40 8f43 8f48 8f49 8f4e 8f51
8f55 8f59 8f5c 8f5f 8f60 8f62 8f63 8f68
8f69 8f6e 8f70 8f74 8f77 8f79 8f7d 8f7f
8f8b 8f8d 8f8f 8f90 8f95 8f99 8f9b 8fa7
8fa9 8fab 8faf 8fb3 8fb6 8fba 8fc0 8fc2
8fc6 8fca 8fcd 8fce 8fd0 8fd4 8fd7 8fdb
8fde 8fdf 8fe4 8fe8 8fec 8ff0 8ff4 8ff8
8ffc 8ffe 9002 9005 9009 900d 9011 9015
9019 901d 9021 9025 9029 902d 9031 9035
9039 903d 9041 9045 9049 904d 9051 9055
9059 905d 9061 9065 9069 906d 9071 9075
9079 907d 9080 9083 9086 9089 908a 908c
9090 9094 9097 909a 909b 90a0 90a4 90a8
90ab 90ae 90af 90b4 90b8 90ba 90be 90c1
90c5 90c9 90cc 90d0 90d3 90d4 90d6 90d7
90dc 90e0 90e6 90e8 90ec 90ef 90f1 90f5
90f9 90fc 9104 9106 9107 910a 910c 9110
9117 911b 911f 9124 9126 912a 912e 9131
9135 9139 913b 1 913f 9143 9147 914a
914e 9152 9156 915a 915d 9161 9165 9168
916b 9170 9173 9176 9179 917a 917f 9180
1 9182 9187 918b 918f 9192 9197 919c
919f 91a3 91a4 91a9 91ac 91b1 91b2 91b7
91ba 91bf 91c0 91c5 91c8 91cc 91cd 91d2
91d5 91da 91db 91e0 91e3 91e7 91eb 91ee
91f1 91f2 91f4 91f5 91fa 91fb 9200 9202
9206 9209 920b 920f 9211 921d 921f 9221
9222 9227 922b 922d 9239 923b 923f 9243
9246 924a 924d 924e 9253 9256 925a 925d
9260 9261 9266 9269 926d 9271 9274 9275
9277 927a 927d 927e 9283 1 9286 928b
1 928e 9293 9297 929b 929e 92a2 92a6
92a9 92ac 92b1 92b4 92b7 92ba 92bb 92c0
92c1 1 92c3 92c8 92cc 92d0 92d3 92d8
92dd 92e0 92e4 92e5 92ea 92ed 92f2 92f3
92f8 92fb 9300 9301 9306 9309 930d 9311
9315 9316 9318 931d 931e 9320 9321 9326
9329 932e 932f 9334 9337 933c 933d 9342
9345 9349 934a 934f 9352 9357 9358 935d
935e 9363 9365 9369 936c 9370 9374 9377
937b 937f 9382 9385 938a 938d 9390 9393
9394 9399 939a 1 939c 93a1 93a5 93a9
93ac 93b1 93b6 93b9 93bd 93be 93c3 93c4
93c9 93cb 93cf 93d2 93d6 93da 93dd 93e1
93e5 93e9 93ea 93ef 93f1 93f5 93f8 93fc
93ff 9402 9403 9408 940c 9411 9415 9419
941e 9422 9426 942b 942f 9433 9437 943c
9440 9441 9445 9448 944c 9450 9454 9458
945c 9460 9464 9468 946c 9470 9474 9479
947e 9482 9486 948a 948f 9493 9497 949a
949d 94a1 94a3 94a7 94ab 94ae 94b1 94b5
94b7 94bb 94bf 94c2 94c6 94ca 94cd 94d1
94d4 94d8 94db 94dc 94e1 94e4 94e8 94ee
94f0 94f4 94f7 94fb 94fe 94ff 9504 9507
950b 950f 9512 9516 951a 951b 951d 9520
9523 9524 1 9529 952e 9532 9536 953a
953b 953d 9540 9541 9543 9546 9549 954a
1 954f 9554 9558 955c 9560 9562 9566
9569 956d 9571 9574 9578 957c 957d 957f
9582 9585 9586 958b 958f 9592 9595 9596
959b 959f 95a3 95a7 95ab 95af 95b3 95b7
95bb 95bf 95c3 95c7 95cb 95cf 95d3 95d7
95e3 95e7 95ec 95f0 95f3 95f4 95f9 95fd
9601 9604 9607 960b 960d 9611 9615 9618
961b 961f 9621 9625 9629 962c 962e 1
9632 9636 963a 963d 9641 9645 9649 964d
9650 9654 9658 965b 965e 9663 9666 9669
966c 966d 9672 9673 1 9675 967a 967e
9682 9685 968a 968f 9692 9696 9697 969c
969f 96a4 96a5 96aa 96ad 96b2 96b3 96b8
96bb 96bf 96c0 96c5 96c8 96cd 96ce 96d3
96d6 96da 96de 96e1 96e4 96e5 96e7 96e8
96ed 96ee 96f3 96f5 96f9 96fc 96fe 9702
9704 9710 9712 9714 9715 971a 971e 9720
972c 972e 9730 9734 9737 973b 9740 9744
9748 974d 9751 9755 975a 975e 9762 9767
976b 976f 9774 9778 977c 9781 9785 9789
978d 9791 9795 9798 979c 979e 97a2 97a5
97a9 97ac 97af 97b0 97b5 97b9 97bc 97bd
97c2 1 97c5 97ca 97ce 97d2 97d6 97da
97de 97e2 97e6 97ea 97ee 97fa 97fe 9803
9807 980a 980b 9810 9814 9818 981b 981e
9822 9824 9828 982c 982f 9832 9836 9838
983c 9840 9843 9845 1 9849 984d 9851
9854 9858 985c 9860 9864 9867 986b 986f
9872 9875 987a 987d 9880 9883 9884 9889
988a 1 988c 9891 9895 9899 989c 98a1
98a6 98a9 98ad 98ae 98b3 98b6 98bb 98bc
98c1 98c4 98c9 98ca 98cf 98d2 98d6 98d7
98dc 98df 98e4 98e5 98ea 98ed 98f1 98f5
98f8 98fb 98fc 98fe 98ff 9904 9905 990a
990c 9910 9913 9915 9919 991b 9927 9929
992b 992c 9931 9935 9937 9943 9945 9947
994b 994e 9952 9955 9956 995b 995e 9962
9965 9966 996b 996e 9972 9976 997a 997d
9982 9983 9988 998b 998e 998f 9991 9995
9997 999b 999e 99a2 99a6 99aa 99ad 99b1
99b2 99b7 99ba 99bd 99be 99c0 99c4 99c6
99ca 99cd 99d1 99d4 99d5 99da 99dd 99e1
99e5 99e9 99ec 99f0 99f1 99f6 99f9 99fc
99fd 99ff 9a03 9a05 9a09 9a0c 9a10 9a13
9a14 9a19 9a1c 9a20 9a23 9a24 9a29 9a2c
9a30 9a34 9a38 9a3b 9a40 9a41 9a46 9a49
9a4c 9a4d 9a4f 9a53 9a55 9a59 9a5c 9a60
9a64 9a68 9a6b 9a6f 9a70 9a75 9a78 9a7b
9a7c 9a7e 9a82 9a84 9a88 9a8b 9a8f 9a92
9a93 9a98 9a9b 9a9f 9aa3 9aa7 9aaa 9aae
9aaf 9ab4 9ab7 9aba 9abb 9abd 9ac1 9ac3
9ac7 9aca 9ace 9ad1 9ad2 9ad7 9ada 9ade
9ae1 9ae2 9ae7 9aea 9aee 9af2 9af6 9af9
9afe 9aff 9b04 9b07 9b0a 9b0b 9b0d 9b11
9b13 9b17 9b1a 9b1e 9b22 9b26 9b29 9b2d
9b2e 9b33 9b36 9b39 9b3a 9b3c 9b40 9b42
9b46 9b49 9b4d 9b50 9b51 9b56 9b59 9b5d
9b60 9b61 9b66 9b69 9b6d 9b71 9b75 9b78
9b7d 9b7e 9b83 9b86 9b89 9b8a 9b8c 9b90
9b92 9b96 9b99 9b9d 9ba1 9ba5 9ba8 9bac
9bad 9bb2 9bb5 9bb8 9bb9 9bbb 9bbf 9bc1
9bc5 9bc8 9bcc 9bd0 9bd3 9bd6 9bd7 9bdc
9be0 9be4 9be8 9bec 9bee 9bf2 9bf9 9bfd
9c01 9c06 9c08 9c0c 9c10 9c13 9c17 9c1b
9c1d 1 9c21 9c25 9c29 9c2c 9c30 9c34
9c38 9c3c 9c3f 9c43 9c47 9c4a 9c4d 9c52
9c55 9c58 9c5b 9c5c 9c61 9c62 1 9c64
9c69 9c6d 9c71 9c74 9c79 9c7e 9c81 9c85
9c86 9c8b 9c8e 9c93 9c94 9c99 9c9c 9ca1
9ca2 9ca7 9caa 9cae 9caf 9cb4 9cb7 9cbc
9cbd 9cc2 9cc5 9cc9 9ccd 9cd0 9cd3 9cd4
9cd6 9cd7 9cdc 9cdd 9ce2 9ce4 9ce8 9ceb
9ced 9cf1 9cf3 9cff 9d01 9d03 9d04 9d09
9d0d 9d0f 9d1b 9d1d 9d21 9d24 9d27 9d28
9d2d 9d31 9d35 9d39 9d3d 9d41 9d45 9d49
9d4d 9d51 9d55 9d59 9d5d 9d61 9d65 9d69
9d75 9d79 9d7e 9d82 9d85 9d86 9d8b 9d8f
9d93 9d96 9d99 9d9d 9d9f 9da3 9da7 9daa
9dad 9db1 9db3 9db7 9dbb 9dbe 9dc0 1
9dc4 9dc8 9dcc 9dcf 9dd3 9dd7 9ddb 9ddf
9de2 9de6 9dea 9ded 9df0 9df5 9df8 9dfb
9dfe 9dff 9e04 9e05 1 9e07 9e0c 9e10
9e14 9e17 9e1c 9e21 9e24 9e28 9e29 9e2e
9e31 9e36 9e37 9e3c 9e3f 9e44 9e45 9e4a
9e4d 9e51 9e52 9e57 9e5a 9e5f 9e60 9e65
9e68 9e6c 9e70 9e73 9e76 9e77 9e79 9e7a
9e7f 9e80 9e85 9e87 9e8b 9e8e 9e90 9e94
9e96 9ea2 9ea4 9ea6 9ea7 9eac 9eb0 9eb2
9ebe 9ec0 9ec2 9ec6 9ec9 9ecb 9ecf 9ed2
9ed6 9ed9 9eda 9edf 9ee2 9ee6 9eea 9eed
9eee 9ef0 9ef3 9ef6 9ef7 9efc 9f00 9f04
9f08 9f0c 9f10 9f14 9f18 9f1c 9f20 9f24
9f28 9f2c 9f30 9f34 9f40 9f44 9f48 9f4b
9f4f 9f53 9f55 1 9f59 9f5d 9f61 9f64
9f68 9f6c 9f70 9f74 9f77 9f7b 9f7f 9f82
9f85 9f8a 9f8d 9f90 9f93 9f94 9f99 9f9a
1 9f9c 9fa1 9fa5 9fa9 9fac 9fb1 9fb6
9fb9 9fbd 9fbe 9fc3 9fc6 9fcb 9fcc 9fd1
9fd4 9fd9 9fda 9fdf 9fe2 9fe6 9fe7 9fec
9fef 9ff4 9ff5 9ffa 9ffd a001 a005 a008
a00b a00c a00e a00f a014 a015 a01a a01c
a020 a023 a025 a029 a02b a037 a039 a03b
a03c a041 a045 a047 a053 a055 a057 a05b
a05e a062 a064 a066 a06a a06e a071 a073
a077 a07a a07e a082 a086 a08a a08e a092
a096 a09a a09e a0a2 a0a6 a0aa a0ae a0b2
a0b6 a0ba a0be a0c2 a0c6 a0d2 a0d6 a0da
a0dd a0e1 a0e5 a0e7 1 a0eb a0ef a0f3
a0f6 a0fa a0fe a102 a106 a109 a10d a111
a114 a117 a11c a11f a122 a125 a126 a12b
a12c 1 a12e a133 a137 a13b a13e a143
a148 a14b a14f a150 a155 a158 a15d a15e
a163 a166 a16b a16c a171 a174 a178 a179
a17e a181 a186 a187 a18c a18f a193 a197
a19a a19d a19e a1a0 a1a1 a1a6 a1a7 a1ac
a1ae a1b2 a1b5 a1b7 a1bb a1bd a1c9 a1cb
a1cd a1ce a1d3 a1d7 a1d9 a1e5 a1e7 a1eb
a1ef a1f2 a1f3 a1f5 a1f9 a1fc a200 a203
a204 a209 a20d a211 a216 a21b a21f a223
a227 a22a a22d a231 a235 a239 a23d a241
a245 a249 a24d a251 a255 a259 a25d a269
a26d a272 a276 a279 a27a a27f a283 a287
a28a a28d a291 a293 a297 a29b a29e a2a1
a2a5 a2a7 a2ab a2af a2b2 a2b4 1 a2b8
a2bc a2c0 a2c3 a2c7 a2cb a2cf a2d3 a2d6
a2da a2de a2e1 a2e4 a2e9 a2ec a2ef a2f2
a2f3 a2f8 a2f9 1 a2fb a300 a304 a308
a30b a310 a315 a318 a31c a31d a322 a325
a32a a32b a330 a333 a338 a339 a33e a341
a345 a346 a34b a34e a353 a354 a359 a35c
a360 a364 a367 a36a a36b a36d a36e a373
a374 a379 a37b a37f a382 a384 a388 a38a
a396 a398 a39a a39b a3a0 a3a4 a3a6 a3b2
a3b4 a3b8 a3bc a3bf a3c3 a3c6 a3ca a3cd
a3ce a3d3 a3d6 a3da a3de a3e2 a3e6 a3ea
a3ee a3f2 a3f6 a3fa a3fe a402 a406 a40a
a40e a412 a416 a41a a41e a42a a42e a433
a437 a43a a43b a440 a444 a448 a44b a44e
a452 a454 a458 a45c a45f a462 a466 a468
a46c a470 a473 a475 1 a479 a47d a481
a484 a488 a48c a490 a494 a497 a49b a49f
a4a2 a4a5 a4aa a4ad a4b0 a4b3 a4b4 a4b9
a4ba 1 a4bc a4c1 a4c5 a4c9 a4cc a4d1
a4d6 a4d9 a4dd a4de a4e3 a4e6 a4eb a4ec
a4f1 a4f4 a4f9 a4fa a4ff a502 a506 a507
a50c a50f a514 a515 a51a a51d a521 a525
a528 a52b a52c a52e a52f a534 a535 a53a
a53c a540 a543 a545 a549 a54b a557 a559
a55b a55c a561 a565 a567 a573 a575 a579
a57d a580 a584 a587 a58b a58e a58f a594
a597 a59b a59f a5a3 a5a7 a5ab a5af a5bb
a5bf a5c4 a5c8 a5cb a5cc a5d1 a5d5 a5d9
a5dc a5df a5e3 a5e5 a5e9 a5ed a5f0 a5f3
a5f7 a5f9 a5fd a601 a604 a606 1 a60a
a60e a612 a615 a619 a61d a621 a625 a628
a62c a630 a633 a636 a63b a63e a641 a644
a645 a64a a64b 1 a64d a652 a656 a65a
a65d a662 a667 a66a a66e a66f a674 a677
a67c a67d a682 a685 a68a a68b a690 a693
a697 a698 a69d a6a0 a6a5 a6a6 a6ab a6ae
a6b2 a6b6 a6b9 a6bc a6bd a6bf a6c0 a6c5
a6c6 a6cb a6cd a6d1 a6d4 a6d6 a6da a6dc
a6e8 a6ea a6ec a6ed a6f2 a6f6 a6f8 a704
a706 a708 a70c a70f a711 a715 a718 a71c
a720 a724 a728 a72c a730 a734 a738 a73c
a740 a744 a748 a74c a750 a754 a758 a75c
a760 a764 a768 a76c a770 a774 a778 a77c
a780 a784 a788 a78c a790 a794 a798 a79c
a7a0 a7a4 a7a8 a7ac a7b0 a7b4 a7b8 a7bc
a7c0 a7c4 a7c8 a7cc a7d0 a7d4 a7d8 a7dc
a7e0 a7e4 a7e8 a7ec a7f0 a7f4 a7f8 a7fc
a800 a804 a808 a80c a810 a814 a818 a81c
a820 a824 a828 a82c a830 a834 a838 a83c
a840 a844 a848 a84c a850 a854 a858 a85c
a860 a864 a868 a86c a870 a874 a878 a87c
a880 a884 a888 a88c a890 a894 a898 a89c
a8a0 a8a4 a8a8 a8ac a8b0 a8b4 a8b8 a8bc
a8c0 a8c4 a8c8 a8cc a8d0 a8d4 a8d8 a8dc
a8e0 a8e4 a8e8 a8ec a8f0 a8f4 a8f8 a8fc
a900 a904 a908 a90c a910 a914 a918 a91c
a920 a924 a928 a92c a930 a934 a938 a93c
a940 a944 a948 a94c a950 a954 a958 a95c
a960 a964 a968 a96c a970 a974 a978 a97c
a980 a984 a988 a98c a990 a994 a998 a99c
a9a0 a9a4 a9a8 a9ac a9b0 a9b4 a9b8 a9bc
a9c0 a9c4 a9c8 a9cc a9d0 a9d4 a9d8 a9dc
a9e0 a9e4 a9e8 a9ec a9f0 a9f4 a9f8 a9fc
aa00 aa04 aa08 aa0c aa10 aa14 aa18 aa1c
aa20 aa24 aa28 aa2c aa30 aa34 aa38 aa3c
aa40 aa44 aa48 aa54 aa59 aa5d aa61 aa65
aa68 aa6c aa70 aa73 aa76 aa7b aa7e aa81
aa84 aa85 aa8a aa8b 1 aa8d aa92 aa96
aa9a aa9d aaa2 aaa7 aaaa aaae aaaf aab4
aab5 aaba aabc aac0 aac3 aac7 aacb aacf
aad1 aad5 aad8 aadb aadc aae1 aae5 aae9
aaed aaf1 aaf5 aaf9 aafd ab01 ab05 ab09
ab0d ab11 ab15 ab19 ab1d ab21 ab25 ab29
ab2d ab31 ab35 ab39 ab3d ab41 ab45 ab49
ab4d ab51 ab55 ab59 ab5d ab61 ab65 ab69
ab6d ab71 ab75 ab79 ab7d ab81 ab85 ab89
ab8d ab91 ab95 ab99 ab9d aba1 aba5 aba9
abad abb1 abb5 abb9 abbd abc1 abc5 abc9
abcd abd1 abd5 abd9 abdd abe1 abe5 abe9
abed abf1 abf5 abf9 abfd ac01 ac05 ac09
ac0d ac11 ac15 ac19 ac1d ac21 ac25 ac29
ac2d ac31 ac35 ac39 ac3d ac41 ac45 ac49
ac4d ac51 ac55 ac59 ac5d ac61 ac65 ac69
ac6d ac71 ac75 ac79 ac7d ac81 ac85 ac89
ac8d ac91 ac95 ac99 ac9d aca1 aca5 aca9
acad acb1 acb5 acb9 acbd acc1 acc5 acc9
accd acd1 acd5 acd9 acdd ace1 ace5 ace9
aced acf1 acf5 acf9 acfd ad01 ad05 ad09
ad0d ad11 ad15 ad19 ad1d ad21 ad25 ad29
ad2d ad31 ad35 ad39 ad3d ad41 ad45 ad49
ad4d ad51 ad55 ad59 ad5d ad61 ad65 ad69
ad6d ad71 ad75 ad79 ad7d ad81 ad85 ad89
ad8d ad91 ad95 ad99 ad9d ada1 ada5 ada9
adad adb1 adb5 adb9 adbd adc1 adc5 adc9
adcd add1 add5 add9 addd ade1 ade5 ade9
aded adf1 adf5 adf9 adfd ae01 ae05 ae09
ae0d ae11 ae15 ae19 ae1d ae21 ae25 ae29
ae2d ae31 ae35 ae39 ae3d ae41 ae45 ae49
ae4d ae51 ae55 ae59 ae5d ae61 ae65 ae69
ae6d ae71 ae75 ae79 ae7d ae81 ae85 ae89
ae8d ae91 ae95 ae99 ae9d aea1 aea5 aea9
aead aeb1 aeb5 aeb9 aebd aec1 aec5 aec9
aecd aed1 aed5 aed9 aedd aee1 aee5 aee9
aeed aef1 aef5 aef9 aefd af01 af05 af09
af0d af11 af15 af19 af1d af21 af25 af29
af2d af31 af35 af39 af3d af41 af45 af49
af4d af51 af55 af59 af5d af61 af65 af69
af6d af71 af75 af79 af7d af81 af85 af89
af8d af91 af95 afa1 afa6 afaa afae afb2
afb5 afb9 afbd afc0 afc3 afc8 afcb afce
afd1 afd2 afd7 afd8 1 afda afdf afe3
afe7 afea afef aff4 aff7 affb affc b001
b002 b007 b009 b00d b010 b014 b018 b01c
b01e b022 b026 b02b b030 b034 b038 b03c
b03f b042 b046 b04a b04e b052 b056 b05a
b05e b062 b066 b072 b076 b07b b07f b082
b083 b088 b08c b090 b093 b096 b09a b09c
b0a0 b0a4 b0a7 b0aa b0ae b0b0 b0b4 b0b8
b0bb b0bd 1 b0c1 b0c5 b0c9 b0cc b0d0
b0d4 b0d8 b0dc b0df b0e3 b0e7 b0ea b0ed
b0f2 b0f5 b0f8 b0fb b0fc b101 b102 1
b104 b109 b10d b111 b114 b119 b11e b121
b125 b126 b12b b12e b133 b134 b139 b13c
b141 b142 b147 b14a b14e b14f b154 b157
b15c b15d b162 b165 b169 b16d b170 b173
b174 b176 b177 b17c b17d b182 b184 b188
b18b b18d b191 b193 b19f b1a1 b1a3 b1a4
b1a9 b1ad b1af b1bb b1bd b1c1 b1c5 b1c9
b1cd b1d1 b1d5 b1d9 b1dd b1e1 b1e5 b1e9
b1ed b1f1 b1f5 b1f9 b1fd b201 b205 b209
b20d b219 b21d b222 b226 b229 b22a b22f
b233 b237 b23a b23d b241 b243 b247 b24b
b24e b251 b255 b257 b25b b25f b262 b264
1 b268 b26c b270 b273 b277 b27b b27f
b283 b286 b28a b28e b291 b294 b299 b29c
b29f b2a2 b2a3 b2a8 b2a9 1 b2ab b2b0
b2b4 b2b8 b2bb b2c0 b2c5 b2c8 b2cc b2cd
b2d2 b2d5 b2da b2db b2e0 b2e3 b2e8 b2e9
b2ee b2f1 b2f5 b2f6 b2fb b2fe b303 b304
b309 b30c b310 b314 b317 b31a b31b b31d
b31e b323 b324 b329 b32b b32f b332 b334
b338 b33a b346 b348 b34a b34b b350 b354
b356 b362 b364 b368 b36c b370 b374 b378
b37c b380 b384 b388 b38c b390 b394 b398
b39c b3a0 b3a4 b3a8 b3ac b3b0 b3b4 b3b8
b3bc b3c0 b3c4 b3c8 b3cc b3d0 b3d4 b3d8
b3dc b3e0 b3e4 b3e8 b3ec b3f0 b3f4 b3f8
b3fc b400 b404 b408 b40c b410 b414 b418
b41c b420 b424 b428 b42c b430 b434 b438
b43c b440 b444 b448 b44c b450 b454 b458
b45c b460 b464 b468 b46c b470 b474 b478
b47c b480 b484 b488 b48c b490 b494 b498
b49c b4a0 b4a4 b4a8 b4ac b4b0 b4b4 b4b8
b4bc b4c0 b4c4 b4c8 b4cc b4d0 b4d4 b4d8
b4dc b4e0 b4e4 b4e8 b4ec b4f0 b4f4 b4f8
b4fc b500 b504 b508 b50c b510 b514 b518
b51c b520 b524 b528 b52c b530 b534 b538
b53c b540 b544 b548 b54c b550 b554 b558
b55c b560 b564 b568 b56c b570 b574 b578
b57c b580 b584 b588 b58c b590 b594 b598
b59c b5a0 b5a4 b5a8 b5ac b5b0 b5b4 b5b8
b5bc b5c0 b5c4 b5c8 b5cc b5d0 b5d4 b5d8
b5dc b5e0 b5e4 b5e8 b5ec b5f0 b5f4 b5f8
b5fc b600 b604 b608 b60c b610 b614 b618
b61c b620 b624 b628 b62c b630 b634 b638
b63c b640 b644 b648 b64c b650 b654 b658
b65c b660 b664 b668 b66c b670 b674 b678
b67c b680 b684 b688 b68c b690 b694 b698
b69c b6a0 b6a4 b6a8 b6ac b6b0 b6b4 b6b8
b6bc b6c0 b6c4 b6c8 b6cc b6d0 b6d4 b6d8
b6dc b6e0 b6e4 b6e8 b6ec b6f0 b6f4 b6f8
b6fc b700 b704 b708 b70c b710 b714 b718
b71c b720 b724 b728 b72c b730 b734 b738
b73c b740 b744 b748 b74c b750 b754 b758
b75c b760 b764 b768 b76c b770 b774 b778
b77c b780 b784 b788 b78c b790 b794 b798
b79c b7a0 b7a4 b7a8 b7ac b7b0 b7b4 b7b8
b7bc b7c0 b7c4 b7c8 b7cc b7d0 b7d4 b7d8
b7dc b7e0 b7e4 b7e8 b7ec b7f0 b7f4 b7f8
b7fc b800 b804 b808 b80c b810 b814 b818
b81c b820 b824 b828 b82c b830 b834 b838
b83c b840 b844 b848 b84c b850 b854 b858
b85c b860 b864 b868 b86c b870 b874 b878
b87c b880 b884 b888 b88c b890 b894 b898
b89c b8a0 b8a4 b8a8 b8ac b8b0 b8b4 b8b8
b8bc b8c0 b8c4 b8c8 b8cc b8d0 b8d4 b8d8
b8dc b8e0 b8e4 b8e8 b8ec b8f0 b8f4 b8f8
b8fc b900 b904 b908 b90c b910 b914 b918
b91c b920 b924 b928 b92c b930 b934 b938
b93c b940 b944 b948 b94c b950 b954 b958
b95c b960 b964 b968 b96c b970 b974 b978
b97c b980 b984 b988 b98c b990 b994 b998
b99c b9a0 b9a4 b9a8 b9ac b9b0 b9b4 b9b8
b9bc b9c0 b9c4 b9c8 b9cc b9d0 b9d4 b9d8
b9dc b9e0 b9e4 b9e8 b9ec b9f0 b9f4 b9f8
b9fc ba00 ba04 ba08 ba0c ba10 ba14 ba18
ba1c ba20 ba24 ba28 ba2c ba30 ba34 ba38
ba3c ba40 ba4c ba51 ba55 ba59 ba5d ba60
ba64 ba68 ba6b ba6e ba73 ba76 ba79 ba7c
ba7d ba82 ba83 1 ba85 ba8a ba8e ba92
ba95 ba9a ba9f baa2 baa6 baa7 baac baad
bab2 bab4 bab8 babb babf bac3 bac7 bac9
bacd bad1 bad4 bad6 bada bade bae1 bae3
bae7 baeb baee baf2 baf6 baf9 bafd bb01
bb04 bb07 bb0c bb0f bb12 bb15 bb16 bb1b
bb1c 1 bb1e bb23 bb27 bb2b bb2e bb33
bb38 bb3b bb3f bb40 bb45 bb46 bb4b bb4f
bb53 bb56 bb5b bb60 bb63 bb67 bb6b bb6e
bb6f bb74 bb77 bb7c bb7d bb82 bb85 bb89
bb8d bb90 bb91 bb96 bb97 bb9c bb9e bba2
bba5 bba9 bbad bbb1 bbb5 bbb9 bbbd bbc1
bbc5 bbc9 bbd5 bbda bbde bbe2 bbe6 bbea
bbec bbed bbf2 1 bbf6 bbfa bbfe bc01
bc05 bc09 bc0d bc11 bc14 bc18 bc1c bc1f
bc22 bc27 bc2a bc2d bc30 bc31 bc36 bc37
1 bc39 bc3e bc42 bc46 bc49 bc4e bc53
bc56 bc5a bc5b bc60 bc61 bc66 bc6a bc6e
bc71 bc76 bc7b bc7e bc82 bc83 bc88 bc8b
bc90 bc91 bc96 bc99 bc9d bca1 bca4 bca7
bca8 bcaa bcab bcb0 bcb1 bcb6 bcb8 bcbc
bcbf bcc3 bcc7 bccb bccf bcd3 bcd7 bcdb
bce7 bcec bcf0 bcf4 bcf8 bcfc bcfe bd02
bd04 bd10 bd12 bd14 bd15 bd1a bd1e bd20
bd2c bd30 bd32 bd33 bd3c 
3605
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 c :3 6 e :3 6 10 :3 6
10 :3 6 11 :3 6 17 :3 6 10 :3 6
11 :3 6 10 :3 6 11 :3 6 f :3 6
f :3 6 10 :3 6 d :3 6 e :3 6
12 :2 6 1 3 a 13 a :2 1
4 d 16 15 :2 d :2 4 11 1a
19 :2 11 :2 4 e 17 16 :2 e :2 4
c 15 14 :2 c :2 4 f 18 17
:2 f :2 4 f 18 17 :2 f :2 4 c
15 14 :2 c :2 4 b 14 13 :2 b
:2 4 10 19 18 :2 10 :2 4 11 1a
19 :2 11 :2 4 10 19 18 :2 10 :2 4
11 1a 19 :2 11 :2 4 f 18 17
:2 f :2 4 10 19 18 :2 10 :2 4 f
18 17 :2 f :2 4 10 19 18 :2 10
:2 4 11 1a 19 :2 11 :2 4 11 1a
19 :2 11 :2 4 d 16 15 :2 d :2 4
e 17 16 :2 e :2 4 b 14 13
:2 b :2 4 :3 10 :2 4 11 1a 19 :2 11
:2 4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 14 1d 1c :2 14 :2 4
15 1e 1d :2 15 :2 4 f 18 17
:2 f :2 4 10 19 18 :2 10 :2 4 e
17 16 :2 e :2 4 f 18 17 :2 f
:2 4 10 19 18 :2 10 :2 4 11 1a
19 :2 11 :2 4 :2 e 1d e :2 4 :2 d
1c d :2 4 :2 b 1a b :2 4 :2 c
1b c :2 4 :2 d 1c d :2 4 :2 10
1f 10 :2 4 :2 14 23 14 :2 4 :2 a
19 a :2 4 :2 f 1e f :2 4 :2 b
1a b :2 4 :2 11 20 11 :2 4 :2 d
1c d :2 4 :2 c 1b c :2 4 :2 b
1a b :2 4 :2 f 1e f :2 4 :2 e
1d e :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 f 1e f :2 4 :2 f
1e f :2 4 :2 12 21 12 :2 4 :2 d
1c d :2 4 :2 f 1e f :2 4 :2 b
1a b :2 4 :2 f 19 f :2 4 :2 13
1d 13 :2 4 :2 c 1b c :2 4 :2 10
1f 10 :2 4 :2 12 21 12 :2 4 :2 11
20 11 :2 4 :2 16 25 16 :2 4 :2 16
25 16 :2 4 :2 b 1a b :2 4 d
16 15 :2 d :2 4 :2 10 1f 10 :2 4
:2 11 20 11 :2 4 :2 12 21 12 :2 4
9 12 11 :2 9 :2 4 c 15 14
:2 c :2 4 10 19 18 :2 10 :2 4 :2 11
20 11 :2 4 :2 17 26 17 :2 4 17
1c 1b :2 17 :2 4 18 1d 1c :2 18
:2 4 11 1a 19 :2 11 :2 4 12 1b
1a :2 12 :2 4 16 1f 1e :2 16 :2 4
b 14 13 :2 b :2 4 :2 f 1e f
:2 4 :2 13 22 13 :2 4 :2 14 23 14
:2 4 :2 6 1e 6 :2 4 :2 7 1f 7
:2 4 :2 a 22 a :2 4 :2 d 25 d
:2 4 :2 8 20 8 :2 4 a 13 12
:2 a :2 4 :2 e 26 e :2 4 :3 d :2 4
:3 13 :2 4 :3 8 :2 4 :3 6 :2 4 :3 9 :2 4
:3 c :2 4 :3 c 4 7 b 14 :3 b
:2 7 e 0 :2 7 11 f 10 1d
e 18 e 1c a :6 7 e 0
:2 7 a :2 c 12 c 15 c 12
c 15 c 15 c 15 f 13
fffa :6 7 e 17 :3 e :2 7 e 17
:3 e :2 7 e 17 :3 e 7 4 e
17 :3 e 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
53 59 5c :2 53 6a 7f 8 :2 6a
d 10 :2 6a 17 1a :2 6a b e
:2 6a 13 16 :2 6a 1b 1e :2 6a 2c
2f :2 6a b e :2 6a 13 16 :2 6a
1b 1e :2 6a 2d 30 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 33 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 31 :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 34 :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 2f
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 2e :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 34 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
34 :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 40 :2 16 :2 6a b e
:2 6a 13 16 :2 6a 1b 1e :2 6a 24
27 :2 6a b e :2 6a 13 16 :2 6a
1b 1e :2 6a 26 29 :2 6a b e
:2 6a 13 16 :2 6a 1b 1e :2 6a 28
2b :2 6a b e :2 6a 13 16 :2 6a
1b 1e :2 6a 28 2b :2 6a b e
:2 6a 13 16 :2 6a 1b 1e :2 6a 29
2c :2 6a b e :2 6a 13 16 1f
27 :2 1f 3a :2 16 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 29 2c :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 29 2c :2 6a b e :2 6a
13 16 1f 27 :2 1f 32 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
32 :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 33 :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 30 :2 16
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 26 29 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 2a 2d
:2 6a 32 35 :2 6a :2 7 49 :2 4 7
:2 11 23 :2 2d 39 3c 4b 4e 4f
:2 4b :2 23 :3 7 :2 d 12 1e 5b 5e
:2 1e :2 7 52 :3 4 14 :2 4 14 :2 4
13 :2 4 f :2 4 e :2 4 13 :2 4
14 :2 4 13 :2 4 14 :2 4 12 :2 4
10 :2 4 e :2 4 14 :2 4 12 :2 4
f :2 4 12 :2 4 e :2 4 e :2 4
11 :2 4 11 :2 4 10 :2 4 13 :2 4
13 :2 4 14 4 8 11 1c :2 8
22 1f :2 2b :2 1f 7 :4 46 45 44
:2 7 a :2 14 26 :2 30 3c 3f 4e
51 52 :2 4e :2 26 :3 a :2 10 15 21
5e 61 :2 21 6e 71 :2 21 75 78
:2 21 82 85 8e 96 :2 9f :2 8e b5
:2 85 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4e 51 52 :2 4e :2 26
:3 a :2 10 15 21 5e 61 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 46 :2 7 57
:2 4 :4 9 8 7 :4 1f 1e 1d :2 7
:4 39 38 37 :2 7 :4 53 52 51 :2 7
f 18 24 :2 f 2a 27 :2 33 :2 27
e :2 7 :4 c b a 25 2e 3a
:2 25 3f 3d :2 48 :2 3d 24 :2 a d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 61 64
:2 24 71 74 :2 24 78 7b :2 24 85
88 91 99 :2 a2 :2 91 b3 :2 88 :2 24
:2 d 58 :2 a d :2 17 29 :2 33 3f
42 51 54 55 :2 51 :2 29 :3 d :2 13
18 24 61 64 :2 24 :2 d 58 :3 a
:2 15 2b :2 34 44 :2 a 7 59 :4 f
e d :4 29 28 27 :3 d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 61 64 :2 24 71
74 :2 24 78 7b :2 24 85 88 91
99 :2 a2 :2 91 b3 :2 88 :2 24 :2 d 58
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
61 64 :2 24 :2 d 58 :3 a :2 15 2b
:2 34 44 :2 a 3e 59 :2 7 49 :2 4
:4 9 8 2a 33 3a :2 33 48 :2 2a
4b 4d :2 4b 29 :2 8 7 a :2 14
26 :2 30 3c 3f 4e 51 52 :2 4e
:2 26 :3 a :2 10 15 21 5e 61 :2 21
6e 71 :2 21 75 78 :2 21 82 85
8e 96 :2 9f :2 8e b0 :2 85 :2 21 :2 a
55 :2 7 a :2 14 26 :2 30 3c 3f
4e 51 52 :2 4e :2 26 :3 a :2 10 15
21 5e 61 :2 21 :2 a 55 :3 7 :2 12
28 :2 31 41 :2 7 52 :2 4 :4 9 8
29 32 39 :2 32 48 :2 29 4b 4d
:2 4b 28 :2 8 7 a :2 14 26 :2 30
3c 3f 4e 51 52 :2 4e :2 26 :3 a
:2 10 15 21 5e 61 :2 21 6e 71
:2 21 75 78 :2 21 82 85 8e 96
:2 9f :2 8e b0 :2 85 :2 21 :2 a 55 :2 7
a :2 14 26 :2 30 3c 3f 4e 51
52 :2 4e :2 26 :3 a :2 10 15 21 5e
61 :2 21 :2 a 55 :3 7 :2 12 28 :2 31
41 :2 7 52 :2 4 7 10 1b :2 7
1e 20 :2 1e 26 2f 37 :2 26 3a
3c :2 3a :2 7 42 4b 53 :2 42 56
58 :2 56 :2 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 6e 71 :2 21
75 78 :2 21 82 85 8e 96 :2 9f
:2 8e b0 :2 85 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 41
:2 7 5a :2 4 :4 9 8 :2 7 1a 7
24 7 1a 7 :4 4 8 11 1c
:2 8 22 1f :2 2b :2 1f 7 :4 46 45
44 :2 7 :4 14 13 12 :2 7 11 1c
21 33 3e 43 :2 f :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 64 67
:2 27 74 77 :2 27 7b 7e :2 27 8a
8d :2 27 95 98 :2 27 a4 a7 ae
b7 ba :2 a7 :2 27 :2 10 5c :2 d :2 a
:4 16 :2 a 7 :3 31 b :2 14 1f 1d
:2 28 :2 1d a 3d 46 4f :2 3d 52
54 :2 52 3c :2 a d :2 17 29 :2 33
3f 42 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 61 64 :2 24 71 74
:2 24 78 7b :2 24 85 88 91 99
:2 a2 :2 91 bf :2 88 :2 24 :2 d 58 :2 a
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 61
64 :2 24 :2 d 58 :3 a :2 15 2b :2 34
50 :2 a 57 :3 7 e 7 31 :2 4
:4 9 8 7 :4 27 26 25 :2 7 11
23 35 :2 a :2 13 1f a 7 :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 8a 8d :2 27 95
98 :2 27 a4 a7 ae b7 ba :2 a7
:2 27 :2 10 5c :2 d :2 a :4 16 :2 a 7
:4 40 :3 4 12 :2 4 13 :2 1c 28 2f
38 40 :2 2f 44 :2 4d :2 28 27 5c
:2 13 :2 4 e 15 1e 26 :2 15 2a
:2 33 :2 e :2 4 d :2 16 22 29 32
3e :2 29 42 :2 4b :2 22 21 5a :2 d
:2 4 12 19 22 2e :2 19 32 :2 3b
:2 12 :2 4 1c 25 31 :2 1c 36 34
:2 3f :2 34 54 :2 17 5b :2 12 4 7
10 18 :2 7 1b 1d :2 1b 7 15
7 11 21 f 10 1d :2 a :2 13
1f a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 74 77 :2 27 7b 7e :2 27
8a 8d :2 27 95 98 :2 27 a4 a7
ae b7 ba :2 a7 :2 27 :2 10 5c :2 d
:2 a :4 16 :2 a 7 :3 1f a 13 1f
:2 a 22 24 :2 22 14 24 12 13
20 :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 67 6a :2 2a 77 7a :2 2a
7e 81 :2 2a 8d 90 :2 2a 98 9b
:2 2a a7 aa b1 ba bd :2 aa :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 26
d :2 18 1f 2d :2 d 32 34 :2 32
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 74 77 :2 27 7b 7e :2 27
88 8b 94 9c :2 a5 :2 94 ba :2 8b
:2 27 c2 c5 :2 27 cd d0 :2 27 d5
d8 :2 27 e5 e8 :2 27 :2 10 5c :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 :2 10 5b :3 d :2 18 2c :2 35
49 57 :2 d 36 :2 a 26 :3 7 17
20 29 31 :2 20 :2 17 7 a 13
21 :2 a 24 26 :2 24 a 14 20
29 31 :2 20 :2 14 a d 16 1e
:2 d 21 23 :2 21 10 :2 1a 2c :2 36
42 45 54 57 58 :2 54 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 88 8b 94 9c
:2 a5 :2 94 b6 :2 8b :2 27 :2 10 5b :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 :2 10 5b :3 d :2 18 2e :2 37
47 :2 d 25 :3 a 1a :2 23 a 28
:3 7 14 7 a 13 20 :2 a 23
26 :2 23 a 16 a 28 d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 61 64 :2 24
71 74 :2 24 78 7b :2 24 85 88
91 99 :2 a2 :2 91 b3 :2 88 :2 24 :2 d
58 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 61 64 :2 24 :2 d 58 :3 a :2 15
2b :2 34 44 :2 a :5 7 1a 29 37
3f 4a 54 25 :2 1a 7 a 13
24 :2 a 27 2a :2 27 d :2 17 29
:2 33 3f 43 52 55 56 :2 52 :2 29
:3 d :2 13 18 24 61 64 :2 24 71
74 :2 24 78 7b :2 24 85 88 91
99 :2 91 ab :2 88 :2 24 b3 b6 :2 24
be c1 :2 24 c6 c9 :2 24 d5 d8
:2 24 :2 d 59 :2 a d :2 17 29 :2 33
3f 42 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 61 64 :2 24 :2 d 58
:3 a :2 15 29 32 43 :2 29 47 54
:2 a 2c :2 7 a 13 1e :2 a 23
21 :2 2c :2 21 d :2 17 29 :2 33 3f
43 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 61 64 :2 24 71 74 :2 24
78 7b :2 24 85 88 91 99 :2 a2
:2 91 ad :2 88 :2 24 b5 b8 :2 24 c0
c3 :2 24 c8 cb :2 24 d7 da :2 24
:2 d 59 :2 a d :2 17 29 :2 33 3f
42 51 54 55 :2 51 :2 29 :3 d :2 13
18 24 61 64 :2 24 :2 d 58 :3 a
:2 15 29 :2 32 3c 49 :2 a 40 :2 7
a 13 21 :2 a 26 24 :2 2f :2 24
d 1b 24 2c :2 1b :2 d 30 33
:2 30 10 12 1b 12 1b 12 10
:3 12 15 16 23 fffa 10 :2 19 25
10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5e 5f
:2 5b :2 32 :3 16 :2 1c 21 2d 6a 6d
:2 2d 7a 7d :2 2d 81 84 :2 2d 90
93 :2 2d 9b 9e :2 2d aa ad b4
bd c0 :2 ad :2 2d :2 16 62 :2 13 :2 10
:4 1c :2 10 d :4 35 10 :2 12 14 12
14 12 14 12 1b 1d 12 1b
1d 12 14 12 14 25 27 10
:7 12 15 1d 20 28 16 18 25
14 16 23 25 fffa 10 :2 19 25
10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5e 5f
:2 5b :2 32 :3 16 :2 1c 21 2d 6a 6d
:2 2d 7a 7d :2 2d 81 84 :2 2d 90
93 :2 2d 9b 9e :2 2d aa ad b4
bd c0 :2 ad :2 2d :2 16 62 :2 13 :2 10
:4 1c :2 10 d :7 a e :2 17 23 20
:2 2c :2 20 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 74 77 :2 27
7b 7e :2 27 88 8b 94 9c :2 a5
:2 94 b8 :2 8b :2 27 c0 c3 :2 27 cb
ce :2 27 d3 d6 :2 27 e0 e3 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 47 52 :2 d 3c :2 a
7 3c d 16 24 :2 d 29 27
:2 32 :2 27 d :2 f d :2 f 12 13
20 fffa d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 67 6a :2 2a 77 7a
:2 2a 7e 81 :2 2a 8d 90 :2 2a 98
9b :2 2a a7 aa b1 ba bd :2 aa
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 3f e :2 17 23 20 :2 2c :2 20 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 74 77 :2 27 7b 7e :2 27
88 8b 94 9c :2 a5 :2 94 b8 :2 8b
:2 27 c0 c3 :2 27 cb ce :2 27 d3
d6 :2 27 e0 e3 :2 27 :2 10 5c :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 :2 10 5b :3 d :2 18 2c :2 35
47 52 :2 d 3c :2 a 12 1d :2 12
1f f 18 f 18 f d :3 f
12 13 20 11 1e fffa d :2 16
22 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 67
6a :2 2a 77 7a :2 2a 7e 81 :2 2a
8d 90 :2 2a 98 9b :2 2a a7 aa
b1 ba bd :2 aa :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 3f e :2 17 23
20 :2 2c :2 20 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 88 8b 94 9c
:2 a5 :2 94 b8 :2 8b :2 27 c0 c3 :2 27
cb ce :2 27 d3 d6 :2 27 e3 e6
:2 27 :2 10 5c :2 d 10 :2 1a 2c :2 36
42 45 54 57 58 :2 54 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 :2 10 5b
:3 d :2 18 2c :2 35 47 55 :2 d 3c
:2 a :4 e :2 d 1d :2 26 :2 d 17 26
:2 17 d 24 :2 a 3f 3c d :2 17
29 :2 33 3f 43 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 61 64 :2 24
71 74 :2 24 78 7b :2 24 85 88
91 99 :2 a2 :2 91 b3 :2 88 :2 24 bb
be :2 24 c6 c9 :2 24 ce d1 :2 24
de e1 :2 24 :2 d 59 :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 61 64 :2 24
:2 d 58 :3 a :2 15 29 :2 32 42 50
:2 a :4 7 a 13 1f :2 a 25 22
:2 2e :2 22 d f 1a 25 :2 f 18
23 2e f 18 23 2e d :4 f
12 13 21 fffa d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 67 6a :2 2a
77 7a :2 2a 7e 81 :2 2a 8d 90
:2 2a 98 9b :2 2a a7 aa b1 ba
bd :2 aa :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 3e e :2 17 22 20 :2 2b
:2 20 d 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 64 67 :2 27 74 77 :2 27 7b
7e :2 27 88 8b 94 9c :2 a5 :2 94
b8 :2 8b :2 27 c0 c3 :2 27 cb ce
:2 27 d3 d6 :2 27 df e2 :2 27 :2 10
5c :2 d 10 :2 1a 2c :2 36 42 45
54 57 58 :2 54 :2 2c :3 10 :2 16 1b
27 64 67 :2 27 :2 10 5b :3 d :2 18
2c :2 35 47 51 :2 d a 3b 11
:2 1a 25 23 :2 2e :2 23 :2 10 17 21
24 :2 10 27 29 :2 27 31 3a 4d
:2 31 50 52 :2 50 58 13 21 :2 58
26 24 2f 42 :2 26 :2 24 :2 31 30
:2 10 49 13 21 :2 49 26 24 2f
42 :2 26 :2 24 :2 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 67 6a :2 2a 77 7a
:2 2a 7e 81 :2 2a 8b 8e 97 9f
:2 a8 :2 97 be :2 8e :2 2a c6 c9 :2 2a
d1 d4 :2 2a d9 dc :2 2a e5 e8
:2 2a :2 13 5f :2 10 13 :2 1d 2f :2 39
45 48 57 5a 5b :2 57 :2 2f :3 13
:2 19 1e 2a 67 6a :2 2a :2 13 5e
:3 10 :2 1b 2f :2 38 4d 57 :2 10 45
:2 d 3e 3b :2 a 3e :2 7 1f :2 4
7 10 18 :2 7 1b 1d :2 1b a
13 1f :2 a 24 22 :2 2d :2 22 :4 42
41 :2 a 59 d 1a :2 59 1d 1f
:2 1d :2 a d :2 17 29 :2 33 3f 43
52 55 56 :2 52 :2 29 :3 d :2 13 18
24 61 64 :2 24 71 74 :2 24 78
7b :2 24 85 88 91 99 :2 a2 :2 91
bd :2 88 :2 24 c5 c8 :2 24 d0 d3
:2 24 d8 db :2 24 e8 eb :2 24 :2 d
59 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 61 64 :2 24 :2 d 58 :3 a :2 15
29 :2 32 4c 12 :2 a 21 :2 7 a
13 1e :2 a 24 21 :2 2d :2 21 d
f 18 f 18 d :2 f 12 13
20 fffa d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 67 6a :2 2a 77 7a
:2 2a 7e 81 :2 2a 8d 90 :2 2a 98
9b :2 2a a7 aa b1 ba bd :2 aa
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 41 e :2 17 22 20 :2 2b :2 20 d
10 12 15 25 32 fffa 10 :2 19
25 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5e
5f :2 5b :2 32 :3 16 :2 1c 21 2d 6a
6d :2 2d 7a 7d :2 2d 81 84 :2 2d
90 93 :2 2d 9b 9e :2 2d aa ad
b4 bd c0 :2 ad :2 2d :2 16 62 :2 13
:2 10 :4 1c :2 10 d :3 3b 11 :2 1a 25
23 :2 2e :2 23 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 67 6a :2 2a 77 7a
:2 2a 7e 81 :2 2a 8b 8e 97 9f
:2 a8 :2 97 b9 :2 8e :2 2a c1 c4 :2 2a
cc cf :2 2a d4 d7 :2 2a e4 e7
:2 2a :2 13 5f :2 10 13 :2 1d 2f :2 39
45 48 57 5a 5b :2 57 :2 2f :3 13
:2 19 1e 2a 67 6a :2 2a :2 13 5e
:3 10 :2 1b 2f :2 38 48 56 :2 10 3e
:2 d 3b :2 a 41 :2 7 1f :2 4 7
10 1c :2 7 1f 21 :2 1f 27 30
38 :2 27 3b 3e :2 3b :3 7 11 7
42 :2 4 7 10 1b :2 7 20 1e
:2 29 :2 1e :4 b :2 a 18 :2 a 19 a
22 a 18 :2 a 19 a :5 7 13
7 3d a e 10 :2 e a 19
:2 a 18 29 35 42 4b 54 :2 42
58 61 69 :2 58 22 2b 37 :2 22
3b 44 4f :2 3b 53 20 2b :2 53
2f 38 46 :2 2f 4a 53 5e :2 4a
22 2b 37 :2 22 3b 43 4d :2 18
a d 16 22 :2 d 27 25 :2 30
:2 25 10 :2 1a 2c :2 36 42 45 54
57 58 :2 54 :2 2c :3 10 :2 16 1b 27
64 67 :2 27 74 77 :2 27 7b 7e
:2 27 88 8b 94 9c :2 a5 :2 94 b6
:2 8b :2 27 :2 10 5b :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 64 67 :2 27 :2 10
5b :3 d :2 18 2e :2 37 47 :2 d a
3f 10 19 25 :2 10 28 2b :2 28
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 74 77 :2 27 7b 7e :2 27
88 8b 94 9c :2 94 a9 :2 8b :2 27
b1 b4 :2 27 bc bf :2 27 c4 c7
:2 27 d4 d7 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 64 67
:2 27 :2 10 5b :3 d :2 18 2c 35 41
:2 2c 45 53 :2 d 2d 3f :2 a 12
a 19 a :4 7 b 14 1c :2 b
1f 21 :2 1f a 29 32 3a :2 29
3d 40 :2 3d 28 :2 a e 17 1f
:2 e 22 24 :2 22 d 2b 34 3c
:2 2b 3f 41 :2 3f 2a :3 d 18 d
a 44 10 19 21 :2 10 24 26
:2 24 d 18 d a 28 44 11
1a 22 :2 11 25 27 :2 25 10 2e
37 3f :2 2e 42 44 :2 42 2d :2 10
d 18 d a 47 44 10 19
21 :2 10 24 26 :2 24 d 18 d
28 44 :2 a 45 :2 7 :4 4 7 10
1c :2 7 21 1f :2 2a :2 1f 7 19
:2 7 16 :2 7 17 :2 7 14 1b 28
2b :2 14 :2 7 17 7 a 13 20
:2 a 23 25 :2 23 a :3 16 :2 a 1c
a 27 14 24 12 13 20 :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
67 6a :2 2a 77 7a :2 2a 7e 81
:2 2a 8d 90 :2 2a 98 9b :2 2a a7
aa b1 ba bd :2 aa :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :3 7 e :2 17
22 20 :2 2b :2 20 d 10 19 21
:2 10 24 26 :2 24 :2 13 18 19 26
17 25 :2 17 25 2e fffa 13 :2 1c
28 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 5e 61
62 :2 5e :2 35 :3 19 :2 1f 24 30 6e
71 :2 30 7e 81 :2 30 85 88 :2 30
94 97 :2 30 9f a2 :2 30 ae b1
b8 c1 c4 :2 b1 :2 30 :2 19 65 :2 16
:2 13 :4 1f :2 13 10 :3 28 14 :2 1d 28
26 :2 31 :2 26 :2 13 25 13 41 :2 10
28 :2 d 3b d 1f d :4 a :4 7
a 19 1c :2 19 d 16 1a d
12 13 1e 11 19 fffa d :2 16
22 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 1e d 18 25
30 3d 48 55 60 6d 78 85
8b 8f 16 1c 1f 35 3b 43
:2 12 23 27 38 13 16 23 11
15 22 25 fffa d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 1e e :2 17 22 20 :2 2b
:2 20 d 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 89 8c 95 9d :2 a6 :2 95
b9 :2 8c :2 27 c1 c4 :2 27 cc cf
:2 27 d4 d7 :2 27 e1 e4 :2 27 :2 10
5c :2 d 10 :2 1a 2c :2 36 42 45
54 57 58 :2 54 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 :2 10 5b :3 d :2 18
2c :2 35 47 52 :2 d 3b :3 a 1e
27 2f :2 1e 32 34 :2 32 3b :2 19
44 :2 14 a 19 d :8 f d :8 f
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 1e 7 1e d 14 22 25
:2 d 28 2a :2 28 14 21 d 17
d 17 d 17 13 20 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :4 2e
1e :2 7 16 10 11 f 10 1d
:2 e 1c a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 55 59 5a
:2 55 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8c
8f :2 27 97 9a :2 27 a6 a9 b0
b9 bc :2 a9 :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 3a 16 10 11 f
10 1d :2 e 1c a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
59 5a :2 55 :2 2c :3 10 :2 16 1b 27
66 69 :2 27 76 79 :2 27 7d 80
:2 27 8c 8f :2 27 97 9a :2 27 a6
a9 b0 b9 bc :2 a9 :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 3a 16 10
1d :2 e 1c a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 59
5a :2 55 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :4 3a :3 4 :3 17 4
7 10 18 :2 7 1b 1d :2 1b 23
2c 38 :2 23 3e 3b :2 47 :2 3b :2 7
5b d 19 :2 5b 1f 1c :2 28 :2 1c
:2 7 :4 b :2 a 17 a 20 :2 7 3d
:2 4 7 10 1c :2 7 1f 21 :2 1f
7 15 :2 1e 7 23 :2 4 :4 8 7
:4 20 1f :2 7 :4 39 38 :2 7 :4 10 f
e :3 7 14 7 25 :3 4 c :2 4
f 4 7 10 18 :2 7 1b 1d
:2 1b a 13 1f :2 a 24 22 :2 2d
:2 22 a 12 1e 21 :2 12 2a 2d
:2 12 11 14 :2 12 11 14 :2 12 11
14 :2 12 32 35 :2 12 3f 42 :2 12
a 7 3d d 16 22 :2 d 25
27 :2 25 a 12 11 14 :2 12 11
14 :2 12 43 46 :2 12 53 56 :2 12
11 14 :2 12 2c 2f :2 12 38 3b
:2 12 11 14 :2 12 a 2a 3d a
12 11 14 :2 12 11 14 :2 12 11
14 :2 12 35 38 :2 12 41 44 :2 12
a :4 7 1f a 13 1f :2 a 25
22 :2 2e :2 22 42 d 19 :2 42 1f
1c :2 28 :2 1c :2 a 41 d 19 :2 41
1f 1c :2 28 :2 1c :3 a 12 1c :3 a
:2 13 1f a :4 e :2 d 15 1f :3 d
:2 16 22 d 1c 17 23 15 16
17 19 25 27 15 1f 10 15
2a 10 12 1f 22 14 17 14
17 25 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5f 60
:2 5b :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :3 22 1c 17 19 15
27 17 19 15 27 16 18 1f
21 14 1b 1d 26 2d 2f 38
3a 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5f 60 :2 5b
:2 32 :3 16 :2 1c 21 2d 6c 6f :2 2d
7c 7f :2 2d 83 86 :2 2d 92 95
:2 2d 9d a0 :2 2d ac af b6 bf
c2 :2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c
:2 10 d :4 22 d 19 d 1c 17
21 16 23 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5f
60 :2 5b :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d 7c 7f :2 2d 83 86 :2 2d
92 95 :2 2d 9d a0 :2 2d ac af
b6 bf c2 :2 af :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :7 a 3c :2 7 :4 b
:2 a 12 1b 22 :2 1b 2a :2 12 2d
2f :2 2d 3a 41 4a 51 :2 4a 59
:2 41 5d :2 3a 64 66 :2 3a :2 16 71
78 81 88 :2 81 90 :2 78 94 :2 71
:2 11 :2 a f :2 a 10 14 12 18
:2 12 a 10 19 1f 26 2f 31
33 :2 2f 36 :2 1f :2 19 3b :2 10 3e
41 :2 3e 17 20 26 2d 36 38
3a :2 36 3d :2 26 :2 20 42 :2 17 45
48 :2 45 :4 10 4b :3 d 12 14 16
:2 12 d 18 e a d 11 :3 f
10 :2 1a 2c :2 36 42 45 54 58
59 :2 54 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8a 8d 96 9e :2 a7 :2 96 b8 :2 8d
:2 27 :2 10 5c :2 d 10 :2 1a 2c :2 36
42 45 54 58 59 :2 54 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 :2 10 5c
:3 d :2 18 2e :2 37 47 :2 d 15 :2 a
14 1c :2 12 :2 d :2 16 22 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5c 5d :2 58 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :4 1e :2 7 a 13 1f :2 a 24
22 :2 2d :2 22 a 10 :2 a 15 :2 a
15 1d 20 :2 15 :2 a 15 1d 20
:2 15 a 7 3d d 16 22 :2 d
27 25 :2 30 :2 25 a 10 :2 a 12
17 1a :2 12 :2 a 12 17 1a :2 12
:2 a 15 a 45 3d d 16 22
:2 d 27 25 :2 30 :2 25 d 15 :2 d
18 d :4 11 :2 10 1b 23 26 :2 1b
:2 10 1b 23 26 :2 1b :2 10 1b 23
26 :2 1b 10 26 :3 d 18 20 23
:2 18 d :4 11 :2 10 1b 23 26 :2 1b
:2 10 1b 23 26 :2 1b :2 10 1b 23
26 :2 1b 10 24 :2 d 44 d 15
1a 1d :2 15 14 17 :2 15 :2 d 18
d :4 11 :2 10 1b 23 26 :2 1b :2 10
1b 23 26 :2 1b :2 10 1b 23 26
:2 1b 10 26 :3 d 18 20 23 :2 18
14 17 :2 18 14 17 :2 18 14 17
:2 18 14 17 :2 18 14 17 :2 18 d
:4 11 :2 10 1b 23 26 :2 1b 4f 52
:2 1b 5a 5d :2 1b 10 24 :2 d :4 a
:4 7 a 13 1f :2 a 25 22 :2 2e
:2 22 :4 e d 17 21 15 16 23
:2 10 :2 19 25 10 d :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5b 5f 60 :2 5b :2 32 :3 16 :2 1c 21
2d 6c 6f :2 2d 7c 7f :2 2d 83
86 :2 2d 92 95 :2 2d 9d a0 :2 2d
ac af b6 bf c2 :2 af :2 2d :2 16
63 :2 13 :2 10 :4 1c :2 10 d :3 26 11
:2 1a 25 23 :2 2e :2 23 :2 10 18 21
28 :2 21 31 :2 18 :2 10 18 1d 20
:2 18 :2 10 1b 23 26 :2 1b 17 1a
:2 1b 2f 32 :2 1b 39 3c :2 1b 10
3e 13 :2 1d 2f :2 39 45 49 58
5c 5d :2 58 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a 79 7c :2 2a 80 83
:2 2a 8d 90 99 a1 :2 aa :2 99 bb
:2 90 :2 2a c3 c6 :2 2a ce d1 :2 2a
d6 d9 :2 2a e4 e7 :2 2a :2 13 60
:2 10 13 :2 1d 2f :2 39 45 48 57
5b 5c :2 57 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a :2 13 5f :3 10 :2 1b 2f
:2 38 48 54 :2 10 :4 d 26 :2 a :4 e
d 17 21 15 16 23 :2 10 :2 19
25 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5f
60 :2 5b :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d 7c 7f :2 2d 83 86 :2 2d
92 95 :2 2d 9d a0 :2 2d ac af
b6 bf c2 :2 af :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :3 25 11 :2 1a 25
23 :2 2e :2 23 :2 10 18 1d 20 :2 18
:2 10 1b 23 26 :2 1b 17 1a :2 1b
2f 32 :2 1b 39 3c :2 1b 10 3e
13 :2 1d 2f :2 39 45 49 58 5c
5d :2 58 :2 2f :3 13 :2 19 1e 2a 69
6c :2 2a 79 7c :2 2a 80 83 :2 2a
8d 90 99 a1 :2 aa :2 99 bb :2 90
:2 2a c3 c6 :2 2a ce d1 :2 2a d6
d9 :2 2a e3 e6 :2 2a :2 13 60 :2 10
13 :2 1d 2f :2 39 45 48 57 5b
5c :2 57 :2 2f :3 13 :2 19 1e 2a 69
6c :2 2a :2 13 5f :3 10 :2 1b 2f :2 38
48 53 :2 10 :4 d 25 :2 a :4 e d
17 21 15 16 23 :2 10 :2 19 25
10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5f 60
:2 5b :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :3 25 11 :2 1a 25 23
:2 2e :2 23 :2 10 18 1d 20 :2 18 :2 10
1b 23 26 :2 1b 17 1a :2 1b 2f
32 :2 1b 39 3c :2 1b 10 3e 13
:2 1d 2f :2 39 45 49 58 5c 5d
:2 58 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a 79 7c :2 2a 80 83 :2 2a 8d
90 99 a1 :2 aa :2 99 bb :2 90 :2 2a
c3 c6 :2 2a ce d1 :2 2a d6 d9
:2 2a e3 e6 :2 2a :2 13 60 :2 10 13
:2 1d 2f :2 39 45 48 57 5b 5c
:2 57 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a :2 13 5f :3 10 :2 1b 2f :2 38 48
53 :2 10 :4 d 25 :2 a d 16 27
:2 d 2a 2c :2 2a 32 3b 4c :2 32
4f 52 :2 4f :3 d 18 20 23 :2 18
3b 3e 46 4f 61 :2 46 :2 3e :2 18
65 68 :2 18 d 56 :2 a 3e :2 7
:4 b :2 a 15 1e 25 :2 1e 33 :2 15
:2 a f :2 a 10 14 12 1c :2 12
a d 1a :2 23 2c 30 34 35
36 :2 34 39 :2 1a d 17 21 15
16 23 :2 10 :2 19 25 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5f 60 :2 5b :2 32 :3 16
:2 1c 21 2d 6c 6f :2 2d 7c 7f
:2 2d 83 86 :2 2d 92 95 :2 2d 9d
a0 :2 2d ac af b6 bf c2 :2 af
:2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10 d
:3 1c 11 :2 1a 26 23 :2 2f :2 23 10
13 :2 1d 2f :2 39 45 49 58 5c
5d :2 58 :2 2f :3 13 :2 19 1e 2a 69
6c :2 2a 79 7c :2 2a 80 83 :2 2a
8d 90 99 a1 :2 aa :2 99 bb :2 90
:2 2a c3 c6 :2 2a ce d1 :2 2a d6
d9 :2 2a e3 e6 :2 2a :2 13 60 :2 10
13 :2 1d 2f :2 39 45 48 57 5b
5c :2 57 :2 2f :3 13 :2 19 1e 2a 69
6c :2 2a :2 13 5f :3 10 :2 1b 2f :2 38
48 53 :2 10 3f :3 d 18 20 23
:2 18 14 17 :2 18 14 17 :2 18 14
17 :2 18 31 34 :2 18 3b 3e :2 18
d 10 19 25 :2 10 2a 28 :2 33
:2 28 10 1b 23 26 :2 1b 10 43
10 1b 23 26 :2 1b 10 :4 d 10
19 25 :2 10 2a 28 :2 33 :2 28 :2 10
43 :2 d a f 11 13 :2 f a
1c e a 22 :2 7 a 13 1f
:2 a 25 22 :2 2e :2 22 a 15 1e
25 :2 1e 34 :2 15 :2 a f :2 a 10
14 12 1c :2 12 a d 1a :2 23
2c 30 34 35 36 :2 34 39 :2 1a
d 17 21 15 16 23 :2 10 :2 19
25 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5f
60 :2 5b :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d 7c 7f :2 2d 83 86 :2 2d
92 95 :2 2d 9d a0 :2 2d ac af
b6 bf c2 :2 af :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :3 1c 11 :2 1a 26
23 :2 2f :2 23 10 13 :2 1d 2f :2 39
45 49 58 5c 5d :2 58 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8d 90 99 a1
:2 aa :2 99 bb :2 90 :2 2a c3 c6 :2 2a
ce d1 :2 2a d6 d9 :2 2a e3 e6
:2 2a :2 13 60 :2 10 13 :2 1d 2f :2 39
45 48 57 5b 5c :2 57 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a :2 13 5f
:3 10 :2 1b 2f :2 38 48 53 :2 10 3f
:3 d 18 20 23 :2 18 14 17 :2 18
14 17 :2 18 14 17 :2 18 31 34
:2 18 3b 3e :2 18 14 17 :2 18 d
a f 11 13 :2 f a 1c e
a 3e :3 7 f 14 17 :2 f 7
:5 4 c 11 14 :2 c :2 4 9 :2 11
:2 4 d 16 :2 7 a e :2 a :2 13
1f a 14 a :2 13 1f a :4 7
b :2 14 20 1d :2 29 :2 1d :3 a 39
:2 7 a 13 1b :2 a 1e 20 :2 1e
26 2f 3b :2 26 41 3e :2 4a :2 3e
:2 a 62 d 19 :2 62 1f 1c :2 28
:2 1c :2 a 42 d 19 :2 42 1f 1c
:2 28 :2 1c :4 3c 3b :2 42 41 :3 a f
:3 a 10 19 :2 a d 11 :2 d :2 16
22 d 17 d :2 16 22 d :4 a
e :2 17 22 20 :2 2b :2 20 d 10
16 :3 10 :2 19 25 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5f 60 :2 5b :2 32 :3 16 :2 1c
21 2d 6c 6f :2 2d 7c 7f :2 2d
83 86 :2 2d 92 95 :2 2d 9d a0
:2 2d ac af b6 bf c2 :2 af :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :3 3b
12 d 3b 10 16 :3 10 :2 19 25
10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5f 60
:2 5b :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :7 a 51 :3 7 16 :2 7
17 7 a 13 1b :2 a 1e 20
:2 1e d 14 20 23 :2 d 26 28
:2 26 d :3 1c :2 d 19 d 2c 10
1e 27 2f :2 1e :2 10 33 36 :2 33
1a 20 38 18 19 26 17 25
17 :2 13 :2 1c 28 13 10 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5e 62 63 :2 5e :2 35 :3 19 :2 1f
24 30 6f 72 :2 30 7f 82 :2 30
86 89 :2 30 95 98 :2 30 a0 a3
:2 30 af b2 b9 c2 c5 :2 b2 :2 30
:2 19 66 :2 16 :2 13 :4 1f :2 13 10 :3 38
13 1c 28 :2 13 2b 2d :2 2b 16
1c :3 16 :2 1f 2b 16 13 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 61 65 66 :2 61 :2 38 :3 1c :2 22
27 33 72 75 :2 33 82 85 :2 33
89 8c :2 33 98 9b :2 33 a3 a6
:2 33 b2 b5 bc c5 c8 :2 b5 :2 33
:2 1c 69 :2 19 :2 16 :4 22 :2 16 13 :3 2f
16 :2 20 32 :2 3c 48 4c 5b 5f
60 :2 5b :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d 7c 7f :2 2d 83 86 :2 2d
90 93 9c a4 :2 ad :2 9c ce :2 93
:2 2d d6 d9 :2 2d e1 e4 :2 2d e9
ec :2 2d f5 f8 :2 2d :2 16 63 :2 13
16 :2 20 32 :2 3c 48 4b 5a 5e
5f :2 5a :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d :2 16 62 :3 13 :2 1e 32 :2 3b
5b 1b :2 13 2f :2 10 38 :2 d :5 a
16 22 2f 3d 48 52 5e 1b
28 36 43 51 1b 28 34 3e
46 4f 57 1b 27 33 40 4b
56 1b 25 30 3c 48 51 5c
:2 48 60 1b 21 :2 16 a d 16
19 :2 16 10 16 :3 10 :2 19 25 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5f 60 :2 5b
:2 32 :3 16 :2 1c 21 2d 6c 6f :2 2d
7c 7f :2 2d 83 86 :2 2d 92 95
:2 2d 9d a0 :2 2d ac af b6 bf
c2 :2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c
:2 10 d :3 1b 10 1b 19 :2 24 :2 19
10 1c :2 25 10 2e :2 d 10 :2 1a
2c :2 36 42 46 55 59 5a :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8a 8d
96 9e :2 96 a9 :2 8d :2 27 b1 b4
:2 27 bc bf :2 27 c4 c7 :2 27 d3
d6 :2 27 :2 10 5d :2 d 10 :2 1a 2c
:2 36 42 45 54 58 59 :2 54 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 :2 10
5c :3 d :2 18 2c 36 43 :2 d a
1b 11 18 24 27 :2 11 2a 2c
:2 2a 10 36 3d 4b 4e :2 36 51
53 :2 51 35 :2 10 17 24 39 46
53 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5f 60 :2 5b
:2 32 :3 16 :2 1c 21 2d 6c 6f :2 2d
7c 7f :2 2d 83 86 :2 2d 92 95
:2 2d 9d a0 :2 2d ac af b6 bf
c2 :2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c
:2 10 d :4 58 1b :4 a 22 d 16
21 :2 d 27 24 :2 30 :2 24 d 1b
:2 d 1c d 44 :3 a 16 22 2f
3d 48 52 5e 1b 28 36 43
51 1b 28 34 3e 46 4f 57
1b 27 33 40 4b 56 1b 25
30 3c 48 4b 4e 54 :2 16 a
d 16 18 :2 16 d 16 1c 1e
:2 16 d 1a :2 a d 15 13 1e
2a :2 15 :2 13 :2 d 2d :2 a :4 7 9
7 :3 4 8 1 7 d :3 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 52 56
57 :2 52 :2 29 :3 d :2 13 18 24 63
66 :2 24 73 76 :2 24 7a 7d :2 24
89 8c :2 24 94 97 :2 24 a3 a6
ad b6 b9 :2 a6 :2 24 :2 d 5a :2 a
:2 7 :4 13 :2 7 4 :3 1 8 13 11
:2 1c :2 11 7 37 40 43 :2 40 36
4b a 12 :2 4b 15 17 :2 15 4a
:2 36 35 :2 7 a :2 14 26 :2 30 3c
40 4f 53 54 :2 4f :2 26 :3 a :2 10
15 21 60 63 :2 21 70 73 :2 21
77 7a :2 21 84 87 90 98 :2 90
a3 :2 87 :2 21 ab ae :2 21 b6 b9
:2 21 be c1 :2 21 cd d0 :2 21 :2 a
57 :2 7 a :2 14 26 :2 30 3c 3f
4e 52 53 :2 4e :2 26 :3 a :2 10 15
21 60 63 :2 21 :2 a 56 :3 7 :2 12
26 30 3d :2 7 1b :2 4 7 11
14 :2 11 7 12 :2 7 15 :2 7 14
:2 7 c :4 7 c :2 7 10 a :7 c
:3 a d 12 :2 d :2 16 22 d 18
d :2 16 22 d :4 a e :2 17 23
20 :2 2c :2 20 :3 d 3c :2 a :4 e d
29 :2 34 3b 46 :2 29 50 52 :2 50
:2 d 14 1d 24 :2 1d 2e :2 14 31
33 :2 31 :3 d 18 d 35 :2 a d
:2 18 1f 2b :2 d 35 38 :2 35 10
12 15 :2 12 1a 13 1d 15 21
15 20 15 22 15 21 15 22
19 21 13 1a 16 22 :3 20 16
:2 1f 2b 16 27 16 :2 1f 2b 16
:4 13 10 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 5e 62 63
:2 5e :2 35 :3 19 :2 1f 24 30 6f 72
:2 30 7f 82 :2 30 86 89 :2 30 95
98 :2 30 a0 a3 :2 30 af b2 b9
c2 c5 :2 b2 :2 30 :2 19 66 :2 16 :2 13
:4 1f :2 13 10 :4 17 :3 d 1c :2 d 1d
:2 d 1c :2 d 1d :2 d 1d :2 d 1d
:2 d 1b :2 d 12 d 3a :2 a d
f 12 :2 f :4 19 18 :2 d 17 10
:5 12 16 1e 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5f
60 :2 5b :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d 7c 7f :2 2d 83 86 :2 2d
92 95 :2 2d 9d a0 :2 2d ac af
b6 bf c2 :2 af :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :4 30 :2 a :4 e d
:4 11 :2 10 1f 26 32 35 :2 26 3a
3d :2 1f 10 2a :3 d 1c 23 2f
32 :2 23 3e 41 :2 1c d 26 :2 a
:4 e :2 d 1d 24 31 34 :2 24 3f
42 :2 1d d 25 :2 a :4 e d :4 11
:2 10 20 27 34 37 :2 27 3c 3f
:2 20 10 2b :3 d 1d 24 31 34
:2 24 41 44 :2 1d d 27 :2 a :4 e
:2 d 1d 24 31 34 :2 24 40 43
:2 1d d 26 :2 a :4 e d :4 11 :2 10
1f 26 32 35 :2 26 3a 3d :2 1f
10 2a :3 d 1c 23 2f 32 :2 23
3e 41 :2 1c d 26 :2 a :4 e d
:4 11 :2 10 20 27 34 37 :2 27 3c
3f :2 20 10 2b :3 d 1d 24 31
34 :2 24 41 44 :2 1d d 27 :3 a
f 11 13 :2 f :2 a 17 a 7
b 16 a 10 :3 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 59 5a :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8c 8f
:2 27 97 9a :2 27 a6 a9 b0 b9
bc :2 a9 :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 16 a c f :2 c 14
d 17 f 1b f 1a f 1c
f 1b f 1c 13 1b d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5c 5d :2 58 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a 79 7c :2 2a
80 83 :2 2a 8f 92 :2 2a 9a 9d
:2 2a a9 ac b3 bc bf :2 ac :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :4 11
:2 7 16 :2 4 :4 8 7 a 13 1b
:2 a 1e 20 :2 1e 14 1d 21 38
12 13 1e 11 22 2a 31 49
51 58 :2 d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5c 5d :2 58 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8f 92 :2 2a 9a
9d :2 2a a9 ac b3 bc bf :2 ac
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:4 22 a 18 :2 a :4 7 24 :2 4 e
1b 26 30 33 4b 5a c 14
17 1c 2b 31 34 42 45 d
10 1d :2 7 :2 10 1c 7 4 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 52 56 57 :2 52 :2 29 :3 d
:2 13 18 24 63 66 :2 24 73 76
:2 24 7a 7d :2 24 89 8c :2 24 94
97 :2 24 a3 a6 ad b6 b9 :2 a6
:2 24 :2 d 5a :2 a :2 7 :4 13 :2 7 4
:3 1 7 10 1c :2 7 21 1f :2 2a
:2 1f 7 f 19 :3 7 :2 10 1c 7
16 11 :4 c f 10 18 f 1e
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 55 59 5a :2 55 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 3a b :2 14 1f 1d :2 28 :2 1d
a 19 14 f 13 24 f 13
24 f 13 24 f 13 24 12
13 1c 16 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5c
5d :2 58 :2 2f :3 13 :2 19 1e 2a 69
6c :2 2a 79 7c :2 2a 80 83 :2 2a
8f 92 :2 2a 9a 9d :2 2a a9 ac
b3 bc bf :2 ac :2 2a :2 13 60 :2 10
:2 d :4 19 :2 d a :3 38 e :2 17 22
20 :2 2b :2 20 d 1c 17 15 16
1e 19 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5f 60
:2 5b :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :4 3b :2 a 38 :3 7 c
1e 2a 3c 45 47 57 65 68
73 76 82 85 90 93 9f b2
7 a 1a 27 2a 3a 7 17
1a 2e 31 43 46 5b 60 6f
83 85 94 ad 7 17 1a 2e
31 43 46 5b 60 6f 83 85
94 ad 7 17 1a 2e 31 43
46 5b 60 6f 83 85 94 ad
7 17 1a 2e 31 43 46 5b
60 6f 83 85 94 ad 7 a
15 18 24 27 32 35 3d 40
51 54 66 69 77 87 94 9f
ac af bc bf c9 cc d6 d
1c 2e 39 3c 4c 5d 73 7e
8b 9b 9e a9 b8 c7 d0 e0
ef 15 24 4b c 1e 23 28
37 3d 40 49 4e 7 c 12
17 2b 31 34 3f 50 53 5f
62 7 c 15 1a 1c 29 7
c 1d 22 24 2c 2e 7 c
12 17 1d 22 24 2c 2e 7
c 12 17 29 2f 31 3a 3d
7 c 12 17 27 2d 2f 38
3b 7 c 12 17 21 27 2a
37 39 12 15 2b 2e 45 48
5e 61 17 7 17 a :2 14 26
:2 30 3c 3f 4e 52 53 :2 4e :2 26
:3 a :2 10 15 21 60 63 :2 21 :2 a
56 :3 7 e 7 3a a 14 16
:2 14 a f 21 24 2e 40 49
4b 58 66 69 74 77 83 86
91 94 a0 a2 a d 1d 2a
2d 3d a 1a 1d 33 36 50
52 60 73 75 83 aa b5 bf
d7 ec f9 112 11d 127 13f 154
161 163 179 17c 192 195 1a7 1aa
1b9 1d2 a 1a 1d 33 36 50
52 60 73 75 83 aa b5 bf
d7 ec f9 112 11d 127 13f 154
161 163 179 17c 192 195 1a7 1aa
1b9 1d2 a 1a 1d 33 36 50
52 60 73 75 83 aa b5 bf
d7 ec f9 112 11d 127 13f 154
161 163 179 17c 192 195 1a7 1aa
1b9 1d2 a 1a 1d 33 36 50
52 60 73 75 83 aa b5 bf
d7 ec f9 112 11d 127 13f 154
161 163 179 17c 192 195 1a7 1aa
1b9 1d2 a d 19 1c 28 2b
36 39 41 44 55 58 6a 6d
7b 8b 98 a3 b0 b3 c0 c3
cd d0 da a d 1a 24 26
32 35 45 50 53 5e 61 77
82 8f 9f a2 ad bc bf c8
cb d5 de e1 f0 f3 104 a
c 1b 1d 2d f 1e 21 26
30 35 38 3f 41 a f 19
1f 22 2d 2f a f 15 1a
24 2a 2d 38 3b a f 19
1e 21 28 2a 36 3b 41 46
50 56 59 65 67 a f 15
1a 2e 34 37 42 53 56 62
65 a f 15 1a 2c 32 34
40 43 a f 15 1a 2c 32
35 3f 42 a f 15 1a 2a
30 32 3e 41 a f 15 1a
2a 30 33 3d 40 13 1a a
1a d :2 17 29 :2 33 3f 42 51
55 56 :2 51 :2 29 :3 d :2 13 18 24
63 66 :2 24 :2 d 59 :3 a 11 a
18 a 12 1c :3 a :2 13 1f a
19 14 1c 2a 38 46 12 27
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5c 5d :2 58 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :3 7 19 15 39 3d 4e d
11 22 31 35 46 d 11 22
12 13 29 12 27 16 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5c 5d :2 58 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a 79 7c :2 2a
80 83 :2 2a 8f 92 :2 2a 9a 9d
:2 2a a9 ac b3 bc bf :2 ac :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :3 7
a f 21 24 2e 40 49 4b
58 66 69 74 77 83 86 91
94 a0 a2 a d 1d 2a 2d
3d a 1a 1d 31 34 f 11
25 27 41 43 51 64 66 74
9b a6 b0 c8 dd ea 103 10e
118 130 145 152 154 f 13 27
2b 45 47 55 68 6a 78 9f
aa b4 cc e1 ee 107 112 11c
134 149 156 158 f 13 22 14
a 1a 1d 32 35 f 11 27
29 43 45 53 66 68 76 9d
a8 b2 ca df ec 105 110 11a
132 147 154 156 f 13 27 2b
45 47 55 68 6a 78 9f aa
b4 cc e1 ee 107 112 11c 134
149 156 158 f 13 22 14 a
1a 1d 31 34 f 11 25 27
41 43 51 64 66 74 9b a6
b0 c8 dd ea 103 10e 118 130
145 152 154 f 13 27 2b 45
47 55 68 6a 78 9f aa b4
cc e1 ee 107 112 11c 134 149
156 158 f 13 22 14 a 1a
1d 31 34 f 11 25 27 41
43 51 64 66 74 9b a6 b0
c8 dd ea 103 10e 118 130 145
152 154 f 13 27 2b 45 47
55 68 6a 78 9f aa b4 cc
e1 ee 107 112 11c 134 149 156
158 f 13 22 14 a d 18
1b 27 2a 35 38 40 43 54
57 69 6c 7a 8a 97 a2 af
b2 bf c2 cc cf d9 a d
1a 24 26 32 35 45 50 53
5e 61 77 82 8f 9f a2 ad
a d 16 19 23 2c 2f 3e
41 52 a c 1b 1d 2d f
1e a f 14 26 2d 30 37
3b 46 4a a f 14 26 2d
30 37 3b 46 4a a f 19
1e 21 28 2a a f 19 1f
22 2d 2f a f 15 1a 24
2a 2d 38 3b a f 19 1e
21 28 2a 36 3b 41 46 50
56 59 65 67 a f 15 1a
2e 34 37 42 53 56 62 65
a f 15 1a 24 2a 2c 37
3a a f 15 1a 2c 32 34
40 43 4e 53 59 5e 70 76
79 83 86 a f 15 1a 2a
30 32 3e 41 4c 51 57 5c
6c 72 75 7f 82 a f 15
1a 20 25 27 2f 31 15 18
2e 31 48 4b 61 64 13 1a
a 1a d :2 17 29 :2 33 3f 42
51 55 56 :2 51 :2 29 :3 d :2 13 18
24 63 66 :2 24 :2 d 59 :3 a 11
a :4 7 :4 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 4f 53 54
:2 4f :2 26 :3 a :2 10 15 21 60 63
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 57 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4c 50 51
:2 4c :2 23 :3 7 :2 d 12 1e 5d 60
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 54 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
3605
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 :4 14
:4 15 :4 16 :4 17 :4 18
:4 19 :4 1a :4 1b :4 1c
:4 1d 2 :4 1e :2 1
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :7 26 :7 27
:7 28 :7 29 :7 2a :7 2b
:7 2c :7 2d :7 2e :7 2f
:7 30 :7 31 :7 32 :7 33
:7 34 :5 35 :7 36 :7 37
:7 38 :7 39 :7 3a :7 3b
:7 3c :7 3d :7 3e :7 3f
:7 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :6 5a :6 5b
:6 5c :6 5d :6 5e :6 5f
:6 60 :6 61 :7 62 :6 63
:6 64 :6 65 :7 66 :7 67
:7 68 :6 69 :6 6a :7 6b
:7 6c :7 6d :7 6e :7 6f
:7 70 :6 71 :6 72 :6 73
:6 74 :6 75 :6 76 :6 77
:6 78 :7 79 :6 7a :5 7b
:5 7c :5 7d :5 7e :5 7f
:5 80 :5 81 :7 84 :2 86
0 :2 86 87 88
:2 89 :2 8a :2 8b 87
:5 86 :2 8d 0 :2 8d
8f 90 :2 91 :2 92
:2 93 :2 94 :2 95 :2 96
97 98 8f :5 8d
:7 9b :7 9e :7 a1 :7 a3
:b a5 :11 a6 a7 :2 a6
:2 a7 :2 a6 :2 a7 :2 a6
:2 a8 :2 a6 :2 a8 :2 a6
:2 a8 :2 a6 :2 a8 :2 a6
:2 a9 :2 a6 :2 a9 :2 a6
:2 a9 :2 a6 :2 a9 :2 a6
:2 aa :2 a6 :9 aa :2 a6
:2 ab :2 a6 :9 ab :2 a6
:2 ac :2 a6 :9 ac :2 a6
:2 ad :2 a6 :9 ad :2 a6
:2 ae :2 a6 :9 ae :2 a6
:2 af :2 a6 :9 af :2 a6
:2 b0 :2 a6 :9 b0 :2 a6
:2 b1 :2 a6 :9 b1 :2 a6
:2 b2 :2 a6 :2 b2 :2 a6
:2 b2 :2 a6 :2 b2 :2 a6
:2 b3 :2 a6 :2 b3 :2 a6
:2 b3 :2 a6 :2 b3 :2 a6
:2 b4 :2 a6 :2 b4 :2 a6
:2 b4 :2 a6 :2 b4 :2 a6
:2 b5 :2 a6 :2 b5 :2 a6
:2 b5 :2 a6 :2 b5 :2 a6
:2 b6 :2 a6 :2 b6 :2 a6
:2 b6 :2 a6 :2 b6 :2 a6
:2 b7 :2 a6 :9 b7 :2 a6
:2 b8 :2 a6 :2 b8 :2 a6
:2 b8 :2 a6 :2 b8 :2 a6
:2 b9 :2 a6 :2 b9 :2 a6
:2 b9 :2 a6 :2 b9 :2 a6
:2 ba :2 a6 :2 ba :2 a6
:2 ba :2 a6 :2 ba :2 a6
:2 bb :2 a6 :2 bb :2 a6
:2 bb :2 a6 :2 bb :2 a6
:2 bc :2 a6 :9 bc :2 a6
:2 bd :2 a6 :9 bd :2 a6
:2 be :2 a6 :9 be :2 a6
:2 bf :2 a6 :9 bf :2 a6
:2 c0 :2 a6 :2 c0 :2 a6
:2 c0 :2 a6 :2 c0 :2 a6
:2 c1 :2 a6 :2 c1 :2 a6
:2 c1 :2 a6 :2 c1 :2 a6
:2 c1 :4 a6 :3 a5 :11 c4
:b c5 :3 c4 :3 cd :3 ce
:3 cf :3 d0 :3 d1 :3 d2
:3 d3 :3 d4 :3 d5 :3 d6
:3 d8 :3 da :3 dc :3 de
:3 df :3 e0 :3 e1 :3 e2
:3 e3 :3 e4 :3 e5 :3 e6
:3 e8 :3 e9 :14 ee :11 ef
:20 f0 :3 ef :11 f2 :b f3
:3 f2 :9 f5 :3 ee :1e f8
:c f9 :2 f8 :14 fa :11 fb
:20 fc :3 fb :11 fe :b ff
:3 fe :9 101 102 fa
:e 102 :11 103 :20 104 :3 103
:11 106 :b 107 :3 106 :9 109
102 :3 fa f9 :2 f8
:15 10d :11 10e :20 10f :3 10e
:11 111 :b 112 :3 111 :9 114
:3 10d :15 117 :11 118 :20 119
:3 118 :11 11b :b 11c :3 11b
:9 11e :3 117 :1f 121 :11 122
:20 123 :3 122 :11 125 :b 126
:3 125 :9 128 :3 121 :6 12c
:3 12d 12c :3 12f 12e
:3 12c :14 132 :6 133 :2 132
:6 135 136 137 135
:5 138 134 :2 13a :5 13c
:11 13d :24 13e :3 13d :2 13b
:6 13a 139 :3 133 :16 143
:11 144 :20 145 :3 144 :11 147
:b 148 :3 147 :9 14a :3 143
:3 14c 133 :2 132 :e 14f
:4 151 :5 152 150 :2 154
:5 156 :11 157 :24 158 :3 157
:2 155 :6 154 153 :6 14f
:3 15e :14 162 :d 164 :14 166
:d 168 :13 16a :9 16c :3 16d
:2 16f 170 :2 171 16f
:5 172 16e :2 174 :5 176
:11 177 :24 178 :3 177 :2 175
:6 174 173 :3 16c :9 17d
:2 17f 180 :2 181 17f
:5 182 17e :2 184 :5 186
:11 187 :24 188 :3 187 :2 185
:6 184 183 :3 17d :b 18d
:11 18e :30 18f :3 18e :11 191
:b 192 :3 191 :a 194 :3 18d
:3 17d :a 198 :9 199 :a 19a
:9 19b :11 19c :20 19d :3 19c
:11 19f :b 1a0 :3 19f :9 1a2
:3 19b :5 1a4 :3 199 :3 1a6
:9 1a8 :3 1a9 1a8 :11 1ac
:20 1ad :3 1ac :11 1af :b 1b0
:3 1af :9 1b2 1aa :3 1a8
:7 1ba 1bb :3 1ba :9 1bd
:11 1be :2e 1bf :3 1be :11 1c1
:b 1c2 :3 1c1 :c 1c4 :3 1bd
:b 1c6 :11 1c7 :30 1c8 :3 1c7
:11 1ca :b 1cb :3 1ca :a 1cd
:3 1c6 :b 1d0 :c 1d1 1d4
:2 1d5 :2 1d6 1d7 1d9
1da 1db 1dc 1dd
:2 1de 1d4 :5 1df 1d2
:2 1e1 :5 1e3 :11 1e4 :24 1e5
:3 1e4 :2 1e2 :6 1e1 1e0
:4 1d1 :2 1ec :2 1ed :2 1ee
:2 1ef :3 1f0 :3 1f1 :2 1f2
:4 1f3 1f5 1f6 1f7
1f8 1f9 1fa 1fb
1fc :4 1fd :3 1fe :4 1ff
1ec :5 200 1ea :2 202
:5 204 :11 205 :24 206 :3 205
:2 203 :6 202 201 :4 1e9
:3 1d1 :a 20c :11 20d :30 20e
:3 20d :11 210 :b 211 :3 210
:a 213 :3 20c 215 1d0
:b 215 218 219 21a
21c 21d 21e 21f
:2 220 218 :5 221 216
:2 223 :5 225 :11 226 :24 227
:3 226 :2 224 :6 223 222
:3 215 :a 22c :11 22d :30 22e
:3 22d :11 230 :b 231 :3 230
:a 233 :3 22c :2 23b 23c
:2 23d :2 23f :2 240 241
243 244 245 246
247 :2 248 :2 249 23a
:5 24a 238 :2 24c :5 24e
:11 24f :24 250 :3 24f :2 24d
:6 24c 24b :3 215 :a 255
:11 256 :30 257 :3 256 :11 259
:b 25a :3 259 :a 25c :3 255
:5 25f :5 263 :6 264 :3 25f
215 1d0 :11 268 :30 269
:3 268 :11 26b :b 26c :3 26b
:a 26e 266 :3 1d0 :b 272
276 :3 277 278 :4 279
:4 27a 27c 27d 27e
27f 280 281 :2 282
276 :5 283 274 :2 285
:5 287 :11 288 :24 289 :3 288
:2 286 :6 285 284 :3 272
:a 28e :11 28f :30 290 :3 28f
:11 292 :b 293 :3 292 :a 295
296 28e :a 296 :14 297
:2 298 :2 297 :8 298 :5 297
298 :2 299 :2 298 :8 299
:2 297 :11 29a :30 29b :3 29a
:11 29d :b 29e :3 29d :a 2a0
299 :2 297 296 :3 28e
:3 272 :3 16c :9 2a8 :13 2ae
:2 2af :2 2ae :4 2af :2 2ae
:11 2b0 :30 2b1 :3 2b0 :11 2b3
:b 2b4 :3 2b3 :7 2b6 2b7
:2 2b6 2af :2 2ae :b 2bb
2be :2 2bf :2 2c0 2c2
2c3 2c4 2c5 :2 2c6
2be :5 2c7 2bc :2 2c9
:5 2cb :11 2cc :24 2cd :3 2cc
:2 2ca :6 2c9 2c8 :3 2bb
:a 2d4 2da 2db :3 2dc
2d7 :5 2dd 2d5 :2 2df
:5 2e1 :11 2e2 :24 2e3 :3 2e2
:2 2e0 :6 2df 2de :3 2d4
:a 2e8 :11 2e9 :30 2ea :3 2e9
:11 2ec :b 2ed :3 2ec :a 2ef
:3 2e8 :3 2d4 :3 2bb :3 2a8
:14 2f6 :3 2f7 :3 2f6 :b 2fa
:5 2fc :3 2fd :3 2fe 2fc
:3 300 :3 301 2ff :3 2fc
:3 304 2fa :5 307 :3 309
:e 30b :b 30c :2 30d :2 30c
:a 30d :8 30e :3 30b :b 310
:11 311 :20 312 :3 311 :11 314
:b 315 :3 314 :9 317 318
310 :9 318 :11 319 :2e 31a
:3 319 :11 31c :b 31d :3 31c
:c 31f 318 :3 310 307
:3 322 321 :3 307 :16 324
:16 325 :3 326 327 325
:9 327 :3 328 329 327
325 :16 329 :3 32a 32b
329 325 :9 32b :3 32c
32b :3 325 :3 324 305
:3 2fa :b 336 :3 337 :3 339
:3 33a :8 33d :3 33e :9 345
:5 346 :3 347 345 :2 34b
34c :2 34d 34b :5 34e
34a :2 350 :5 352 :11 353
:24 354 :3 353 :2 351 :6 350
34f :3 348 :a 359 :9 35a
35d 35f 360 :2 361
:2 362 363 :3 364 35d
:5 365 35b :2 367 :5 369
:11 36a :24 36b :3 36a :2 368
:6 367 366 :3 35a :a 370
:3 371 :3 370 :3 35a 359
:3 375 374 :3 359 348
:3 345 :5 379 :3 37c 37e
37f :2 380 :2 381 37c
:5 382 37a :2 384 :5 386
:11 387 :24 388 :3 387 :2 385
:6 384 383 :3 379 :d 38f
:6 390 391 :4 392 :3 393
:4 394 38f :5 395 38d
:2 397 :5 399 :11 39a :24 39b
:3 39a :2 398 :6 397 396
:3 379 :a 3a0 :11 3a1 :30 3a2
:3 3a1 :11 3a4 :b 3a5 :3 3a4
:a 3a7 :3 3a0 :11 3aa 3ad
3af 3b0 3b1 3b2
3b3 3b4 3b5 3b6
3b7 3bb 3bc 3bd
3be 3bf 3c0 3c1
3c2 3c3 3ad :6 3c5
:5 3c6 3c5 :5 3c8 3c7
:3 3c5 3ac :2 3cb :5 3cd
:11 3ce :24 3cf :3 3ce :2 3cc
:6 3cb 3ca :3 379 3d3
379 :a 3d3 :2 3d7 :2 3d8
:2 3d9 :2 3da :2 3db 3d7
:6 3dc :5 3dd 3dc :5 3df
3de :3 3dc 3d6 :2 3e2
:5 3e4 :11 3e5 :24 3e6 :3 3e5
:2 3e3 :6 3e2 3e1 :4 3d3
:3 379 3ef 3f0 3f1
3f2 :2 3f3 3f4 :2 3f5
3ef :6 3f6 :5 3f7 3f6
:5 3f9 3f8 :3 3f6 3ee
:2 3fc :5 3fe :11 3ff :24 400
:3 3ff :2 3fd :6 3fc 3fb
:3 336 406 407 408
409 :2 40a 40b :2 40c
406 :6 40d :5 40e 40d
:5 410 40f :3 40d 405
:2 413 :5 415 :11 416 :24 417
:3 416 :2 414 :6 413 412
:3 336 41d :2 41e 41f
:2 420 41d :6 421 :5 422
421 :5 424 423 :3 421
41c :2 427 :5 429 :11 42a
:24 42b :3 42a :2 428 :6 427
426 :6 336 :5 44d :17 44f
:2 450 :2 44f :6 450 :2 44f
:5 451 :3 452 :3 451 450
:2 44f :9 456 :5 457 :3 456
:13 45a :6 45b :2 45a :3 45c
45b :2 45a :3 460 :3 461
:9 462 :b 469 :a 46a :2 46b
:2 46a :2 46c :2 46a :2 46d
:2 46a :2 46d :2 46a :2 46d
:3 46a 46e 469 :9 46e
:2 46f :2 470 :2 46f :2 471
:2 46f :2 471 :2 46f :2 471
:2 46f :2 472 :2 46f :2 472
:2 46f :2 472 :2 46f :2 473
:3 46f 46e 469 :2 475
:2 476 :2 475 :2 477 :2 475
:2 478 :2 475 :2 478 :2 475
:2 478 :3 475 474 :3 469
462 :c 482 :2 483 :2 482
:6 483 :2 482 483 :2 484
:2 483 :6 484 :2 482 :5 488
:5 489 :5 48b :5 48e :5 48f
492 :2 493 494 495
:4 498 :2 499 :3 49a :4 49b
:2 49c :3 49d 492 :6 49e
:5 49f 49e :5 4a1 4a0
:3 49e 491 :2 4a4 :5 4a6
:11 4a7 :24 4a8 :3 4a7 :2 4a5
:6 4a4 4a3 :3 48b 4bc
:2 4bd :2 4be :2 4c0 :2 4c1
:4 4c2 :8 4c3 4bc :6 4c4
:5 4c5 4c4 :5 4c7 4c6
:3 4c4 4bb :2 4ca :5 4cc
:11 4cd :24 4ce :3 4cd :2 4cb
:6 4ca 4c9 :4 48b :3 4d4
4d8 :2 4d9 :2 4da 4d8
:6 4db :5 4dc 4db :5 4de
4dd :3 4db 4d7 :2 4e1
:5 4e3 :11 4e4 :24 4e5 :3 4e4
:2 4e2 :6 4e1 4e0 :4 4d2
:3 48b 484 :2 482 :5 4ec
4ee :1c 4ef :2 4ee :c 4ef
:3 4ee :3 4f0 :8 4f3 :15 4f4
:15 4f5 :2 4f4 :2 4f6 4f5
:2 4f4 :7 4f8 4f3 4f9
4f3 :5 4fb :11 4fc :20 4fd
:3 4fc :11 4ff :b 500 :3 4ff
:9 502 :3 4fb :2 506 507
508 506 :5 509 505
:2 50b :5 50d :11 50e :24 50f
:3 50e :2 50c :6 50b 50a
:6 4ec :b 515 517 518
517 :3 519 :7 51a :7 51b
51c 515 :b 51c 51e
51f 51e :7 520 :7 521
:3 522 51c 515 :b 524
:3 527 :3 528 :5 52a :7 52b
:7 52c :7 52d :3 52a :7 530
:5 532 :7 533 :7 534 :7 535
:3 532 524 :6 539 :2 53a
:3 539 :3 53c :5 53e :7 53f
:7 540 :7 541 :3 53e :6 544
:2 545 :2 544 :2 546 :2 544
:2 547 :2 544 :2 548 :2 544
:2 549 :3 544 :5 54b :f 54c
:3 54b 537 :3 524 523
:3 515 :b 551 :5 552 :2 554
555 :2 556 554 :5 557
553 :2 559 :5 55b :11 55c
:24 55d :3 55c :2 55a :6 559
558 :3 552 :a 562 :a 563
:7 566 :6 567 :2 568 :2 567
:2 568 :2 567 :2 568 :3 567
562 :11 56a :30 56b :3 56a
:11 56d :b 56e :3 56d :a 570
569 :3 562 :3 552 :5 574
:2 576 577 :2 578 576
:5 579 575 :2 57b :5 57d
:11 57e :24 57f :3 57e :2 57c
:6 57b 57a :3 574 :a 584
:7 585 :6 586 :2 587 :2 586
:2 587 :2 586 :2 587 :3 586
584 :11 589 :30 58a :3 589
:11 58c :b 58d :3 58c :a 58f
588 :3 584 :3 574 :5 593
:2 595 596 :2 597 595
:5 598 594 :2 59a :5 59c
:11 59d :24 59e :3 59d :2 59b
:6 59a 599 :3 593 :a 5a3
:7 5a4 :6 5a5 :2 5a6 :2 5a5
:2 5a6 :2 5a5 :2 5a6 :3 5a5
5a3 :11 5a8 :30 5a9 :3 5a8
:11 5ab :b 5ac :3 5ab :a 5ae
5a7 :3 5a3 :3 593 :14 5b2
:16 5b3 :3 5b2 :3 551 :5 5b8
:a 5b9 :3 5bb :8 5bc :f 5be
:2 5c1 5c2 :2 5c3 5c1
:5 5c4 5c0 :2 5c6 :5 5c8
:11 5c9 :24 5ca :3 5c9 :2 5c7
:6 5c6 5c5 :3 5bc :a 5cf
:11 5d0 :30 5d1 :3 5d0 :11 5d3
:b 5d4 :3 5d3 :a 5d6 :3 5cf
:6 5d9 :2 5da :2 5d9 :2 5db
:2 5d9 :2 5dc :2 5d9 :2 5dc
:2 5d9 :2 5dc :3 5d9 :b 5de
:7 5df 5de :7 5e1 5e0
:3 5de :b 5e5 :2 5e6 :3 5e5
:7 5e8 5bc 5e9 5bc
:3 5b8 :b 5ed :a 5ee :3 5f0
:8 5f1 :f 5f3 :2 5f6 5f7
:2 5f8 5f6 :5 5f9 5f5
:2 5fb :5 5fd :11 5fe :24 5ff
:3 5fe :2 5fc :6 5fb 5fa
:3 5f1 :a 604 :11 605 :30 606
:3 605 :11 608 :b 609 :3 608
:a 60b :3 604 :6 60e :2 60f
:2 60e :2 610 :2 60e :2 611
:2 60e :2 611 :2 60e :2 611
:2 60e :2 612 :3 60e :7 613
5f1 614 5f1 :3 5ed
:7 617 47a :3 462 :7 61a
:5 61e 621 :4 622 :3 623
:5 624 623 :5 626 625
:3 623 :a 62a :2 62b :3 62a
:17 630 :2 631 :2 630 :6 631
:2 630 631 :2 632 :2 631
:b 632 :3 631 :2 630 :5 635
:4 637 :3 638 :5 639 638
:5 63b 63a :3 638 :a 63e
:4 640 :5 641 63f :2 643
:5 645 :11 646 :24 647 :3 646
:2 644 :6 643 642 :3 63e
:2 64f 63e :4 652 :5 653
651 :2 655 :5 657 :11 658
:24 659 :3 658 :2 656 :6 655
654 :4 650 :3 63e 632
:2 630 :3 660 :3 661 :9 662
:a 663 :5 665 :3 666 663
:c 668 :3 66b 66c :2 66d
:2 66e 66f 66b :5 670
66a :2 672 :5 674 :11 675
:24 676 :3 675 :2 673 :6 672
671 :3 668 :9 67b :4 67d
:5 67e 67c :2 680 :5 682
:11 683 :24 684 :3 683 :2 681
:6 680 67f :3 67b :11 689
:30 68a :3 689 :11 68c :b 68d
:3 68c :7 68f 690 :2 68f
:3 67b :3 668 667 :3 663
:8 695 :5 696 :7 697 :6 698
:a 699 :2 69a :3 695 :5 69c
:4 69e :5 69f 69d :2 6a1
:5 6a3 :11 6a4 :24 6a5 :3 6a4
:2 6a2 :6 6a1 6a0 :3 69c
:7 6aa :5 6ab :3 6aa :11 6ae
:2e 6af :3 6ae :11 6b1 :b 6b2
:3 6b1 :8 6b4 6b5 69c
:18 6b5 :6 6b7 :6 6b8 :5 6b9
6b8 :5 6bb 6ba :3 6b8
6b6 :2 6be :5 6c0 :11 6c1
:24 6c2 :3 6c1 :2 6bf :6 6be
6bd :4 6b5 :3 69c :2 6c8
662 :b 6ca :3 6cb :3 6cc
:3 6ca :8 6cf :5 6d0 :7 6d1
:6 6d2 :8 6d3 :3 6cf :5 6d5
:7 6d6 :3 6d5 :9 6d9 :2 6da
:3 6d9 6c9 :3 662 6dd
6de :3 621 6df a4
:4 6e3 :5 6e4 6e2 :2 6e6
:5 6e8 :11 6e9 :24 6ea :3 6e9
:2 6e7 :6 6e6 6e5 :3 a4
:f 6f0 :2 6f1 :2 6f0 :4 6f1
:6 6f0 :11 6f2 :2e 6f3 :3 6f2
:11 6f5 :b 6f6 :3 6f5 :8 6f8
6f1 :2 6f0 :5 6fb :3 6fc
:3 6fd :3 6fe :5 700 :3 702
704 705 706 707
708 709 70a 70b
70c 70d :3 705 :3 70e
:5 70f 70e :5 711 710
:3 70e :a 714 :2 715 :3 714
:12 71a :c 71b :2 71a :3 71d
71b :2 71a :b 721 :5 723
726 :2 727 :2 728 :2 729
:2 72a :2 72b :2 72c :2 72d
726 :6 72e :5 72f 72e
:5 731 730 :3 72e 725
:2 734 :5 736 :11 737 :24 738
:3 737 :2 735 :6 734 733
:6 723 :3 73e :3 73f :3 740
:3 741 :3 742 :3 744 :3 748
:3 749 :3 721 :c 74c 74f
750 751 752 753
754 755 :2 756 74f
:6 757 :5 758 757 :5 75a
759 :3 757 74e :2 75d
:5 75f :11 760 :24 761 :3 760
:2 75e :6 75d 75c :6 74c
:5 767 :5 768 :c 769 :3 768
:c 76c :3 767 :5 76f :c 770
:3 76f :5 773 :5 774 :c 775
:3 774 :c 778 :3 773 :5 77b
:c 77c :3 77b :5 77f :5 780
:c 781 :3 780 :c 784 :3 77f
:5 787 :5 788 :c 789 :3 788
:c 78c :3 787 :7 790 :3 792
704 793 6fb :4 795
:5 796 794 :2 798 :5 79a
:11 79b :24 79c :3 79b :2 799
:6 798 797 :3 6fb :5 7a1
7a4 :2 7a5 :2 7a6 :2 7a7
:2 7a8 :2 7a9 :2 7aa :2 7ab
7a4 :6 7ac :5 7ad 7ac
:5 7af 7ae :3 7ac 7a3
:2 7b2 :5 7b4 :11 7b5 :24 7b6
:3 7b5 :2 7b3 :6 7b2 7b1
:6 7a1 :3 6fb :5 7bd :9 7be
:4 7c0 7c1 :2 7c2 :7 7c3
7c0 :5 7c4 7bf :2 7c6
:5 7c8 :11 7c9 :24 7ca :3 7c9
:2 7c7 :6 7c6 7c5 :4 7be
:3 7cf 7d0 7ce :3 7be
:3 7bd :7 7d5 :9 7d6 :3 7d7
7d5 :5 7d8 7d4 :2 7da
:5 7dc :11 7dd :24 7de :3 7dd
:2 7db :6 7da 7d9 :3 a4
:b 7e6 :5 7e9 :5 7ea 7ef
7f0 7f1 7f2 7f3
7f4 7f5 :2 7f6 :2 7f7
7ef :6 7f8 :5 7f9 7f8
:5 7fb 7fa :3 7f8 7ee
:2 7fe :5 800 :11 801 :24 802
:3 801 :2 7ff :6 7fe 7fd
:3 7e6 :a 808 80a 80b
:3 80c :3 80d :3 80e :3 80f
810 :2 811 812 80a
:6 813 :5 814 813 :5 816
815 :3 813 809 :2 819
:5 81b :11 81c :24 81d :3 81c
:2 81a :6 819 818 :3 808
:a 822 824 825 826
:2 827 828 824 :6 829
:5 82a 829 :5 82c 82b
:3 829 823 :2 82f :5 831
:11 832 :24 833 :3 832 :2 830
:6 82f 82e :6 822 :3 808
:12 83a :6 83b :e 83c :e 83d
:e 83e :e 83f :19 840 :12 841
:3 842 :9 843 :c 844 :6 845
:7 846 :9 847 :9 848 :9 849
:9 84a :8 84b :3 83a :11 84c
:b 84d :3 84c :3 84f 7e6
:5 851 :13 852 :6 853 :20 854
:20 855 :20 856 :20 857 :19 858
:1c 859 :5 85a :9 85b :7 85c
:9 85d :10 85e :c 85f :9 860
:9 861 :9 862 :9 863 864
:3 852 :11 865 :b 866 :3 865
:3 868 851 :5 86b :5 86c
86f :5 870 :2 871 86f
:6 872 :5 873 872 :5 875
874 :3 872 86e :2 878
:5 87a :11 87b :24 87c :3 87b
:2 879 :6 878 877 :3 869
882 :4 883 :6 884 :3 885
886 :2 887 :2 888 889
882 :6 88a :5 88b 88a
:5 88d 88c :3 88a 881
:2 890 :5 892 :11 893 :24 894
:3 893 :2 891 :6 890 88f
:3 869 :13 899 :6 89a :5 89c
:17 89d :17 89e :3 89f 8a0
:5 8a2 :17 8a3 :17 8a4 :3 8a5
8a6 :5 8a8 :17 8a9 :17 8aa
:3 8ab 8ac :5 8ae :17 8af
:17 8b0 :3 8b1 8b2 :19 8b4
:12 8b5 :a 8b6 :5 8b7 :2 8b8
:a 8b9 :a 8ba :7 8bb :7 8bc
:9 8bd :10 8be :c 8bf :9 8c0
:12 8c1 :12 8c2 :9 8c3 :8 8c4
8c5 :3 899 :11 8c6 :b 8c7
:3 8c6 :3 8c9 869 :3 851
850 :3 7e6 a4 :3 8cf
:11 8d0 :b 8d1 :17 8d2 :3 8d0
:2 8d4 :3 8d5 :3 8d6 8d7
8d5 8d4 8d5 :3 8d8
:3 8cf :2 8d9 :5 8db :11 8dc
:b 8dd :18 8de :3 8dc :2 8e0
8e1 :3 8e2 8e3 8e1
8e0 8e1 :3 8e4 :2 8da
:6 8d9 8ce :7 1 
bd3e
4
:3 0 1 :3 0 2
:a 0 3600 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 4 :3 0 10
:7 0 31 30 :3 0
4 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 4
:3 0 12 :7 0 39
38 :3 0 4 :3 0
13 :7 0 3d 3c
:3 0 25 160 0
23 4 :3 0 14
:7 0 41 40 :3 0
8 :3 0 15 :7 0
45 44 :3 0 29
186 0 27 4
:3 0 16 :7 0 49
48 :3 0 4 :3 0
17 :7 0 4d 4c
:3 0 2d 1ac 0
2b 4 :3 0 18
:7 0 51 50 :3 0
4 :3 0 19 :7 0
55 54 :3 0 31
1d2 0 2f 8
:3 0 1a :7 0 59
58 :3 0 8 :3 0
1b :7 0 5d 5c
:3 0 35 1f8 0
33 8 :3 0 1c
:7 0 61 60 :3 0
8 :3 0 1d :7 0
65 64 :3 0 39
:2 0 37 4 :3 0
1e :7 0 69 68
:3 0 4 :3 0 1f
:7 0 6d 6c :3 0
20 :3 0 21 :3 0
22 :2 0 4 71
72 0 6f 73
0 3600 2 74
:2 0 24 :2 0 57
4 :3 0 24 :2 0
55 77 79 :6 0
7c 7a 0 35fe
0 23 :6 0 24
:2 0 5b 4 :3 0
59 7e 80 :6 0
83 81 0 35fe
0 25 :6 0 24
:2 0 5f 4 :3 0
5d 85 87 :6 0
8a 88 0 35fe
0 26 :6 0 24
:2 0 63 4 :3 0
61 8c 8e :6 0
91 8f 0 35fe
0 27 :6 0 24
:2 0 67 4 :3 0
65 93 95 :6 0
98 96 0 35fe
0 28 :6 0 2b
:2 0 6b 4 :3 0
69 9a 9c :6 0
9f 9d 0 35fe
0 29 :6 0 2d
:2 0 6f 4 :3 0
6d a1 a3 :6 0
a6 a4 0 35fe
0 2a :6 0 2f
:2 0 73 4 :3 0
71 a8 aa :6 0
ad ab 0 35fe
0 2c :6 0 2f
:2 0 77 4 :3 0
75 af b1 :6 0
b4 b2 0 35fe
0 2e :6 0 2f
:2 0 7b 4 :3 0
79 b6 b8 :6 0
bb b9 0 35fe
0 30 :6 0 2f
:2 0 7f 4 :3 0
7d bd bf :6 0
c2 c0 0 35fe
0 31 :6 0 2f
:2 0 83 4 :3 0
81 c4 c6 :6 0
c9 c7 0 35fe
0 32 :6 0 2f
:2 0 87 4 :3 0
85 cb cd :6 0
d0 ce 0 35fe
0 33 :6 0 2f
:2 0 8b 4 :3 0
89 d2 d4 :6 0
d7 d5 0 35fe
0 34 :6 0 2f
:2 0 8f 4 :3 0
8d d9 db :6 0
de dc 0 35fe
0 35 :6 0 2f
:2 0 93 4 :3 0
91 e0 e2 :6 0
e5 e3 0 35fe
0 36 :6 0 2f
:2 0 97 4 :3 0
95 e7 e9 :6 0
ec ea 0 35fe
0 37 :6 0 24
:2 0 9b 4 :3 0
99 ee f0 :6 0
f3 f1 0 35fe
0 38 :6 0 24
:2 0 9f 4 :3 0
9d f5 f7 :6 0
fa f8 0 35fe
0 39 :6 0 3c
:2 0 a3 4 :3 0
a1 fc fe :6 0
101 ff 0 35fe
0 3a :6 0 a9
499 0 a7 4
:3 0 a5 103 105
:6 0 108 106 0
35fe 0 3b :6 0
40 :2 0 ad 3e
:3 0 10a :7 0 10d
10b 0 35fe 0
3d :6 0 4 :3 0
40 :2 0 ab 10f
111 :6 0 114 112
0 35fe 0 3f
:6 0 40 :2 0 b1
4 :3 0 af 116
118 :6 0 11b 119
0 35fe 0 41
:6 0 40 :2 0 b5
4 :3 0 b3 11d
11f :6 0 122 120
0 35fe 0 42
:6 0 40 :2 0 b9
4 :3 0 b7 124
126 :6 0 129 127
0 35fe 0 43
:6 0 46 :2 0 bd
4 :3 0 bb 12b
12d :6 0 130 12e
0 35fe 0 44
:6 0 24 :2 0 c1
4 :3 0 bf 132
134 :6 0 137 135
0 35fe 0 45
:6 0 24 :2 0 c5
4 :3 0 c3 139
13b :6 0 13e 13c
0 35fe 0 47
:6 0 24 :2 0 c9
4 :3 0 c7 140
142 :6 0 145 143
0 35fe 0 48
:6 0 2b :2 0 cd
4 :3 0 cb 147
149 :6 0 14c 14a
0 35fe 0 49
:6 0 46 :2 0 d1
4 :3 0 cf 14e
150 :6 0 153 151
0 35fe 0 4a
:6 0 4d :2 0 d5
4 :3 0 d3 155
157 :6 0 15a 158
0 35fe 0 4b
:6 0 4d :2 0 d7
8 :3 0 15c :7 0
160 15d 15e 35fe
0 4c :6 0 4d
:2 0 d9 8 :3 0
162 :7 0 166 163
164 35fe 0 4e
:6 0 4d :2 0 db
8 :3 0 168 :7 0
16c 169 16a 35fe
0 4f :6 0 4d
:2 0 dd 8 :3 0
16e :7 0 172 16f
170 35fe 0 50
:6 0 4d :2 0 df
8 :3 0 174 :7 0
178 175 176 35fe
0 51 :6 0 4d
:2 0 e1 8 :3 0
17a :7 0 17e 17b
17c 35fe 0 52
:6 0 4d :2 0 e3
8 :3 0 180 :7 0
184 181 182 35fe
0 53 :6 0 4d
:2 0 e5 8 :3 0
186 :7 0 18a 187
188 35fe 0 54
:6 0 4d :2 0 e7
8 :3 0 18c :7 0
190 18d 18e 35fe
0 55 :6 0 4d
:2 0 e9 8 :3 0
192 :7 0 196 193
194 35fe 0 56
:6 0 4d :2 0 eb
8 :3 0 198 :7 0
19c 199 19a 35fe
0 57 :6 0 4d
:2 0 ed 8 :3 0
19e :7 0 1a2 19f
1a0 35fe 0 58
:6 0 4d :2 0 ef
8 :3 0 1a4 :7 0
1a8 1a5 1a6 35fe
0 59 :6 0 4d
:2 0 f1 8 :3 0
1aa :7 0 1ae 1ab
1ac 35fe 0 5a
:6 0 4d :2 0 f3
8 :3 0 1b0 :7 0
1b4 1b1 1b2 35fe
0 5b :6 0 4d
:2 0 f5 8 :3 0
1b6 :7 0 1ba 1b7
1b8 35fe 0 5c
:6 0 4d :2 0 f7
8 :3 0 1bc :7 0
1c0 1bd 1be 35fe
0 5d :6 0 4d
:2 0 f9 8 :3 0
1c2 :7 0 1c6 1c3
1c4 35fe 0 5e
:6 0 4d :2 0 fb
8 :3 0 1c8 :7 0
1cc 1c9 1ca 35fe
0 5f :6 0 4d
:2 0 fd 8 :3 0
1ce :7 0 1d2 1cf
1d0 35fe 0 60
:6 0 4d :2 0 ff
8 :3 0 1d4 :7 0
1d8 1d5 1d6 35fe
0 61 :6 0 4d
:2 0 101 8 :3 0
1da :7 0 1de 1db
1dc 35fe 0 62
:6 0 4d :2 0 103
8 :3 0 1e0 :7 0
1e4 1e1 1e2 35fe
0 63 :6 0 67
:2 0 105 8 :3 0
1e6 :7 0 1ea 1e7
1e8 35fe 0 64
:6 0 67 :2 0 107
66 :3 0 1ec :7 0
1f0 1ed 1ee 35fe
0 65 :6 0 4d
:2 0 109 66 :3 0
1f2 :7 0 1f6 1f3
1f4 35fe 0 68
:6 0 4d :2 0 10b
8 :3 0 1f8 :7 0
1fc 1f9 1fa 35fe
0 69 :6 0 4d
:2 0 10d 8 :3 0
1fe :7 0 202 1ff
200 35fe 0 6a
:6 0 4d :2 0 10f
8 :3 0 204 :7 0
208 205 206 35fe
0 6b :6 0 4d
:2 0 111 8 :3 0
20a :7 0 20e 20b
20c 35fe 0 6c
:6 0 4d :2 0 113
8 :3 0 210 :7 0
214 211 212 35fe
0 6d :6 0 4d
:2 0 115 8 :3 0
216 :7 0 21a 217
218 35fe 0 6e
:6 0 46 :2 0 117
8 :3 0 21c :7 0
220 21d 21e 35fe
0 6f :6 0 4d
:2 0 11b 4 :3 0
119 222 224 :6 0
227 225 0 35fe
0 70 :6 0 4d
:2 0 11d 8 :3 0
229 :7 0 22d 22a
22b 35fe 0 71
:6 0 4d :2 0 11f
8 :3 0 22f :7 0
233 230 231 35fe
0 72 :6 0 75
:2 0 121 8 :3 0
235 :7 0 239 236
237 35fe 0 73
:6 0 77 :2 0 125
4 :3 0 123 23b
23d :6 0 240 23e
0 35fe 0 74
:6 0 75 :2 0 129
4 :3 0 127 242
244 :6 0 247 245
0 35fe 0 76
:6 0 4d :2 0 12d
4 :3 0 12b 249
24b :6 0 24e 24c
0 35fe 0 78
:6 0 4d :2 0 12f
8 :3 0 250 :7 0
254 251 252 35fe
0 79 :6 0 24
:2 0 131 8 :3 0
256 :7 0 25a 257
258 35fe 0 7a
:6 0 24 :2 0 135
7c :3 0 133 25c
25e :6 0 261 25f
0 35fe 0 7b
:6 0 24 :2 0 139
7c :3 0 137 263
265 :6 0 268 266
0 35fe 0 7d
:6 0 24 :2 0 13d
4 :3 0 13b 26a
26c :6 0 26f 26d
0 35fe 0 7e
:6 0 24 :2 0 141
4 :3 0 13f 271
273 :6 0 276 274
0 35fe 0 7f
:6 0 46 :2 0 145
4 :3 0 143 278
27a :6 0 27d 27b
0 35fe 0 80
:6 0 4d :2 0 149
4 :3 0 147 27f
281 :6 0 284 282
0 35fe 0 81
:6 0 4d :2 0 14b
8 :3 0 286 :7 0
28a 287 288 35fe
0 82 :6 0 4d
:2 0 14d 8 :3 0
28c :7 0 290 28d
28e 35fe 0 83
:6 0 46 :2 0 14f
8 :3 0 292 :7 0
296 293 294 35fe
0 84 :6 0 46
:2 0 151 8 :3 0
298 0 2 :5 0
29c 299 29a 35fe
0 85 :6 0 4d
:2 0 153 8 :3 0
29e 0 2 :5 0
2a2 29f 2a0 35fe
0 86 :6 0 4d
:2 0 155 8 :3 0
2a4 0 2 :5 0
2a8 2a5 2a6 35fe
0 87 :6 0 4d
:2 0 157 8 :3 0
2aa 0 2 :5 0
2ae 2ab 2ac 35fe
0 88 :6 0 24
:2 0 159 8 :3 0
2b0 0 2 :5 0
2b4 2b1 2b2 35fe
0 89 :6 0 4d
:2 0 15d 4 :3 0
15b 2b6 2b8 :6 0
2bb 2b9 0 35fe
0 8a :6 0 161
c56 0 15f 8
:3 0 2bd 0 2
:5 0 2c1 2be 2bf
35fe 0 8b :6 0
165 c8a 0 163
8 :3 0 2c3 :7 0
2c6 2c4 0 35fe
0 8c :6 0 8
:3 0 2c8 :7 0 2cb
2c9 0 35fe 0
8d :6 0 169 cbe
0 167 8 :3 0
2cd :7 0 2d0 2ce
0 35fe 0 8e
:6 0 8 :3 0 2d2
:7 0 2d5 2d3 0
35fe 0 8f :6 0
16d cf2 0 16b
8 :3 0 2d7 :7 0
2da 2d8 0 35fe
0 90 :6 0 8
:3 0 2dc :7 0 2df
2dd 0 35fe 0
91 :9 0 16f 8
:3 0 2e1 :7 0 2e4
2e2 0 35fe 0
92 :6 0 21 :3 0
22 :2 0 4 2e6
2e7 0 2e8 :7 0
2eb 2e9 0 35fe
0 93 :6 0 94
:3 0 95 :a 0 2
2fa :4 0 2ed 2f0
0 2ee :3 0 96
:3 0 97 :3 0 98
:3 0 25 :3 0 99
:3 0 25 :3 0 9a
:3 0 39 :4 0 9b
1 :8 0 2fb 2ed
2f0 2fc 0 35fe
171 2fc 2fe 2fb
2fd :6 0 2fa :7 0
2fc 94 :3 0 9c
:a 0 3 315 :5 0
300 303 0 301
:3 0 9d :3 0 9e
:3 0 9f :3 0 a0
:3 0 a1 :3 0 a2
:3 0 9f :3 0 a3
:3 0 a1 :3 0 a4
:3 0 a1 :3 0 a5
:3 0 a1 :3 0 a6
:3 0 a7 :3 0 9e
:4 0 a8 1 :8 0
316 300 303 317
0 35fe 173 317
319 316 318 :6 0
315 :7 0 317 322
323 0 175 21
:3 0 22 :2 0 4
31b 31c 0 31d
:7 0 320 31e 0
35fe 0 a9 :6 0
329 32a 0 177
21 :3 0 22 :2 0
4 324 :7 0 327
325 0 35fe 0
aa :6 0 330 331
0 179 21 :3 0
22 :2 0 4 32b
:7 0 32e 32c 0
35fe 0 ab :6 0
336 337 0 17b
21 :3 0 22 :2 0
4 332 :7 0 335
333 0 35fe 0
ac :6 0 ad :3 0
ae :3 0 ad :3 0
af :3 0 339 33a
0 2 :4 0 17d
33b 33d 338 33f
33e :2 0 b0 :3 0
b1 :3 0 341 342
0 b2 :4 0 ad
:3 0 b3 :3 0 345
346 0 2 :4 0
17f 347 349 b4
:4 0 b5 :2 0 b6
:3 0 181 34c 34e
:3 0 b7 :4 0 b5
:2 0 b8 :4 0 184
351 353 :3 0 b5
:2 0 3 :3 0 187
355 357 :3 0 b5
:2 0 b8 :4 0 18a
359 35b :3 0 b5
:2 0 b9 :4 0 18d
35d 35f :3 0 b5
:2 0 b8 :4 0 190
361 363 :3 0 b5
:2 0 5 :3 0 193
365 367 :3 0 b5
:2 0 b8 :4 0 196
369 36b :3 0 b5
:2 0 b9 :4 0 199
36d 36f :3 0 b5
:2 0 b8 :4 0 19c
371 373 :3 0 b5
:2 0 6 :3 0 19f
375 377 :3 0 b5
:2 0 b8 :4 0 1a2
379 37b :3 0 b5
:2 0 b9 :4 0 1a5
37d 37f :3 0 b5
:2 0 a1 :3 0 ba
:3 0 7 :3 0 1a8
383 385 bb :4 0
1aa 382 388 1ad
381 38a :3 0 b5
:2 0 b9 :4 0 1b0
38c 38e :3 0 b5
:2 0 a1 :3 0 ba
:3 0 9 :3 0 1b3
392 394 bb :4 0
1b5 391 397 1b8
390 399 :3 0 b5
:2 0 b9 :4 0 1bb
39b 39d :3 0 b5
:2 0 a1 :3 0 ba
:3 0 a :3 0 1be
3a1 3a3 bb :4 0
1c0 3a0 3a6 1c3
39f 3a8 :3 0 b5
:2 0 b9 :4 0 1c6
3aa 3ac :3 0 b5
:2 0 a1 :3 0 ba
:3 0 b :3 0 1c9
3b0 3b2 bb :4 0
1cb 3af 3b5 1ce
3ae 3b7 :3 0 b5
:2 0 b9 :4 0 1d1
3b9 3bb :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c :3 0 1d4
3bf 3c1 bb :4 0
1d6 3be 3c4 1d9
3bd 3c6 :3 0 b5
:2 0 b9 :4 0 1dc
3c8 3ca :3 0 b5
:2 0 a1 :3 0 ba
:3 0 d :3 0 1df
3ce 3d0 bb :4 0
1e1 3cd 3d3 1e4
3cc 3d5 :3 0 b5
:2 0 b9 :4 0 1e7
3d7 3d9 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 e :3 0 1ea
3dd 3df bb :4 0
1ec 3dc 3e2 1ef
3db 3e4 :3 0 b5
:2 0 b9 :4 0 1f2
3e6 3e8 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 f :3 0 1f5
3ec 3ee bb :4 0
1f7 3eb 3f1 1fa
3ea 3f3 :3 0 b5
:2 0 b9 :4 0 1fd
3f5 3f7 :3 0 b5
:2 0 b8 :4 0 200
3f9 3fb :3 0 b5
:2 0 10 :3 0 203
3fd 3ff :3 0 b5
:2 0 b8 :4 0 206
401 403 :3 0 b5
:2 0 b9 :4 0 209
405 407 :3 0 b5
:2 0 b8 :4 0 20c
409 40b :3 0 b5
:2 0 11 :3 0 20f
40d 40f :3 0 b5
:2 0 b8 :4 0 212
411 413 :3 0 b5
:2 0 b9 :4 0 215
415 417 :3 0 b5
:2 0 b8 :4 0 218
419 41b :3 0 b5
:2 0 12 :3 0 21b
41d 41f :3 0 b5
:2 0 b8 :4 0 21e
421 423 :3 0 b5
:2 0 b9 :4 0 221
425 427 :3 0 b5
:2 0 b8 :4 0 224
429 42b :3 0 b5
:2 0 13 :3 0 227
42d 42f :3 0 b5
:2 0 b8 :4 0 22a
431 433 :3 0 b5
:2 0 b9 :4 0 22d
435 437 :3 0 b5
:2 0 b8 :4 0 230
439 43b :3 0 b5
:2 0 14 :3 0 233
43d 43f :3 0 b5
:2 0 b8 :4 0 236
441 443 :3 0 b5
:2 0 b9 :4 0 239
445 447 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 15 :3 0 23c
44b 44d bb :4 0
23e 44a 450 241
449 452 :3 0 b5
:2 0 b9 :4 0 244
454 456 :3 0 b5
:2 0 b8 :4 0 247
458 45a :3 0 b5
:2 0 16 :3 0 24a
45c 45e :3 0 b5
:2 0 b8 :4 0 24d
460 462 :3 0 b5
:2 0 b9 :4 0 250
464 466 :3 0 b5
:2 0 b8 :4 0 253
468 46a :3 0 b5
:2 0 17 :3 0 256
46c 46e :3 0 b5
:2 0 b8 :4 0 259
470 472 :3 0 b5
:2 0 b9 :4 0 25c
474 476 :3 0 b5
:2 0 b8 :4 0 25f
478 47a :3 0 b5
:2 0 18 :3 0 262
47c 47e :3 0 b5
:2 0 b8 :4 0 265
480 482 :3 0 b5
:2 0 b9 :4 0 268
484 486 :3 0 b5
:2 0 b8 :4 0 26b
488 48a :3 0 b5
:2 0 19 :3 0 26e
48c 48e :3 0 b5
:2 0 b8 :4 0 271
490 492 :3 0 b5
:2 0 b9 :4 0 274
494 496 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 1a :3 0 277
49a 49c bb :4 0
279 499 49f 27c
498 4a1 :3 0 b5
:2 0 b9 :4 0 27f
4a3 4a5 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 1b :3 0 282
4a9 4ab bb :4 0
284 4a8 4ae 287
4a7 4b0 :3 0 b5
:2 0 b9 :4 0 28a
4b2 4b4 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 1c :3 0 28d
4b8 4ba bb :4 0
28f 4b7 4bd 292
4b6 4bf :3 0 b5
:2 0 b9 :4 0 295
4c1 4c3 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 1d :3 0 298
4c7 4c9 bb :4 0
29a 4c6 4cc 29d
4c5 4ce :3 0 b5
:2 0 b9 :4 0 2a0
4d0 4d2 :3 0 b5
:2 0 b8 :4 0 2a3
4d4 4d6 :3 0 b5
:2 0 1e :3 0 2a6
4d8 4da :3 0 b5
:2 0 b8 :4 0 2a9
4dc 4de :3 0 b5
:2 0 b9 :4 0 2ac
4e0 4e2 :3 0 b5
:2 0 b8 :4 0 2af
4e4 4e6 :3 0 b5
:2 0 1f :3 0 2b2
4e8 4ea :3 0 b5
:2 0 b8 :4 0 2b5
4ec 4ee :3 0 b5
:2 0 bc :4 0 2b8
4f0 4f2 :3 0 2bb
343 4f4 :2 0 4f6
2c0 4f7 340 4f6
0 4f8 2c2 0
355e ad :3 0 ae
:3 0 4f9 4fa 0
ad :3 0 bd :3 0
4fc 4fd 0 46
:2 0 2 :4 0 be
:2 0 bf :2 0 46
:2 0 2c4 502 504
:3 0 2c7 4fe 506
4fb 508 507 :2 0
b0 :3 0 c0 :3 0
50a 50b 0 b2
:4 0 c1 :4 0 b5
:2 0 b6 :3 0 2cb
50f 511 :3 0 2ce
50c 513 :2 0 515
2d1 516 509 515
0 517 2d3 0
355e 25 :3 0 3
:3 0 518 519 0
355e 3f :3 0 5
:3 0 51b 51c 0
355e 42 :3 0 6
:3 0 51e 51f 0
355e 2a :3 0 10
:3 0 521 522 0
355e 2c :3 0 11
:3 0 524 525 0
355e 2e :3 0 16
:3 0 527 528 0
355e 30 :3 0 17
:3 0 52a 52b 0
355e 31 :3 0 18
:3 0 52d 52e 0
355e 32 :3 0 19
:3 0 530 531 0
355e 29 :3 0 1f
:3 0 533 534 0
355e 58 :3 0 7
:3 0 536 537 0
355e 56 :3 0 9
:3 0 539 53a 0
355e 57 :3 0 e
:3 0 53c 53d 0
355e 55 :3 0 1a
:3 0 53f 540 0
355e 59 :3 0 b
:3 0 542 543 0
355e 5b :3 0 f
:3 0 545 546 0
355e 5a :3 0 c
:3 0 548 549 0
355e 4f :3 0 1d
:3 0 54b 54c 0
355e 4c :3 0 a
:3 0 54e 54f 0
355e 5c :3 0 d
:3 0 551 552 0
355e 51 :3 0 1b
:3 0 554 555 0
355e 52 :3 0 1c
:3 0 557 558 0
355e 71 :3 0 4d
:2 0 55a 55b 0
355e 72 :3 0 4d
:2 0 55d 55e 0
355e a1 :3 0 4c
:3 0 4d :2 0 2d5
560 563 c2 :3 0
c3 :2 0 c4 :3 0
565 567 0 2da
566 569 :3 0 56a
:2 0 3 :3 0 c5
:2 0 2dd 56d 56e
:3 0 56f :2 0 570
:2 0 56b 572 571
:2 0 ad :3 0 ae
:3 0 574 575 0
ad :3 0 bd :3 0
577 578 0 c6
:2 0 2 :4 0 c7
:2 0 bf :2 0 46
:2 0 2df 57d 57f
:3 0 2e2 579 581
576 583 582 :2 0
b0 :3 0 c0 :3 0
585 586 0 b2
:4 0 c8 :4 0 b5
:2 0 b6 :3 0 2e6
58a 58c :3 0 b5
:2 0 c9 :4 0 2e9
58e 590 :3 0 b5
:2 0 ca :4 0 2ec
592 594 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 cb
:3 0 599 59a 0
2ef 598 59c bb
:4 0 2f1 597 59f
2f4 596 5a1 :3 0
2f7 587 5a3 :2 0
5a5 2fa 5a6 584
5a5 0 5a7 2fc
0 5d0 ad :3 0
ae :3 0 5a8 5a9
0 ad :3 0 bd
:3 0 5ab 5ac 0
46 :2 0 2 :4 0
cc :2 0 bf :2 0
46 :2 0 2fe 5b1
5b3 :3 0 301 5ad
5b5 5aa 5b7 5b6
:2 0 b0 :3 0 c0
:3 0 5b9 5ba 0
b2 :4 0 cd :4 0
b5 :2 0 b6 :3 0
305 5be 5c0 :3 0
308 5bb 5c2 :2 0
5c4 30b 5c5 5b8
5c4 0 5c6 30d
0 5d0 ce :3 0
cf :3 0 5c7 5c8
0 c2 :3 0 cb
:3 0 5ca 5cb 0
d0 :3 0 30f 5c9
5ce :2 0 5d0 312
5d1 573 5d0 0
5d2 316 0 355e
10 :3 0 c5 :2 0
318 5d4 5d5 :3 0
5d6 :2 0 5d7 :2 0
12 :3 0 c5 :2 0
31a 5da 5db :3 0
5dc :2 0 5dd :2 0
5d8 5df 5de :2 0
13 :3 0 c5 :2 0
31c 5e2 5e3 :3 0
5e4 :2 0 5e5 :2 0
5e0 5e7 5e6 :2 0
14 :3 0 c5 :2 0
31e 5ea 5eb :3 0
5ec :2 0 5ed :2 0
5e8 5ef 5ee :2 0
a1 :3 0 5b :3 0
4d :2 0 320 5f1
5f4 c2 :3 0 c3
:2 0 d1 :3 0 5f6
5f8 0 325 5f7
5fa :3 0 5fb :2 0
5f0 5fd 5fc :2 0
16 :3 0 c5 :2 0
328 600 601 :3 0
602 :2 0 603 :2 0
a1 :3 0 5b :3 0
4d :2 0 32a 605
608 c2 :3 0 d2
:2 0 d3 :3 0 60a
60c 0 32f 60b
60e :3 0 60f :2 0
604 611 610 :2 0
ad :3 0 ae :3 0
613 614 0 ad
:3 0 bd :3 0 616
617 0 c6 :2 0
2 :4 0 d4 :2 0
bf :2 0 46 :2 0
332 61c 61e :3 0
335 618 620 615
622 621 :2 0 b0
:3 0 c0 :3 0 624
625 0 b2 :4 0
d5 :4 0 b5 :2 0
b6 :3 0 339 629
62b :3 0 b5 :2 0
c9 :4 0 33c 62d
62f :3 0 b5 :2 0
ca :4 0 33f 631
633 :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 d6 :3 0
638 639 0 342
637 63b bb :4 0
344 636 63e 347
635 640 :3 0 34a
626 642 :2 0 644
34d 645 623 644
0 646 34f 0
670 ad :3 0 ae
:3 0 647 648 0
ad :3 0 bd :3 0
64a 64b 0 46
:2 0 2 :4 0 d7
:2 0 bf :2 0 46
:2 0 351 650 652
:3 0 354 64c 654
649 656 655 :2 0
b0 :3 0 c0 :3 0
658 659 0 b2
:4 0 d8 :4 0 b5
:2 0 b6 :3 0 358
65d 65f :3 0 35b
65a 661 :2 0 663
35e 664 657 663
0 665 360 0
670 ce :3 0 cf
:3 0 666 667 0
c2 :3 0 d6 :3 0
669 66a 0 d0
:3 0 362 668 66d
:2 0 670 d9 :3 0
365 6dd 16 :3 0
c5 :2 0 369 672
673 :3 0 674 :2 0
675 :2 0 17 :3 0
c5 :2 0 36b 678
679 :3 0 67a :2 0
67b :2 0 676 67d
67c :2 0 ad :3 0
ae :3 0 67f 680
0 ad :3 0 bd
:3 0 682 683 0
c6 :2 0 2 :4 0
da :2 0 bf :2 0
46 :2 0 36d 688
68a :3 0 370 684
68c 681 68e 68d
:2 0 b0 :3 0 c0
:3 0 690 691 0
b2 :4 0 db :4 0
b5 :2 0 b6 :3 0
374 695 697 :3 0
b5 :2 0 c9 :4 0
377 699 69b :3 0
b5 :2 0 ca :4 0
37a 69d 69f :3 0
b5 :2 0 a1 :3 0
ba :3 0 c2 :3 0
d6 :3 0 6a4 6a5
0 37d 6a3 6a7
bb :4 0 37f 6a2
6aa 382 6a1 6ac
:3 0 385 692 6ae
:2 0 6b0 388 6b1
68f 6b0 0 6b2
38a 0 6db ad
:3 0 ae :3 0 6b3
6b4 0 ad :3 0
bd :3 0 6b6 6b7
0 46 :2 0 2
:4 0 dc :2 0 bf
:2 0 46 :2 0 38c
6bc 6be :3 0 38f
6b8 6c0 6b5 6c2
6c1 :2 0 b0 :3 0
c0 :3 0 6c4 6c5
0 b2 :4 0 dd
:4 0 b5 :2 0 b6
:3 0 393 6c9 6cb
:3 0 396 6c6 6cd
:2 0 6cf 399 6d0
6c3 6cf 0 6d1
39b 0 6db ce
:3 0 cf :3 0 6d2
6d3 0 c2 :3 0
d6 :3 0 6d5 6d6
0 d0 :3 0 39d
6d4 6d9 :2 0 6db
3a0 6dc 67e 6db
0 6de 612 670
0 6de 3a4 0
6df 3a7 6e0 5fe
6df 0 6e1 3a9
0 355e 6 :3 0
de :2 0 3ab 6e3
6e4 :3 0 6e5 :2 0
a1 :3 0 df :3 0
42 :3 0 3ad 6e8
6ea 4d :2 0 3af
6e7 6ed e0 :2 0
e1 :2 0 3b4 6ef
6f1 :3 0 6f2 :2 0
6e6 6f4 6f3 :2 0
6f5 :2 0 ad :3 0
ae :3 0 6f7 6f8
0 ad :3 0 bd
:3 0 6fa 6fb 0
c6 :2 0 2 :4 0
e2 :2 0 bf :2 0
46 :2 0 3b7 700
702 :3 0 3ba 6fc
704 6f9 706 705
:2 0 b0 :3 0 c0
:3 0 708 709 0
b2 :4 0 e3 :4 0
b5 :2 0 b6 :3 0
3be 70d 70f :3 0
b5 :2 0 c9 :4 0
3c1 711 713 :3 0
b5 :2 0 ca :4 0
3c4 715 717 :3 0
b5 :2 0 a1 :3 0
ba :3 0 c2 :3 0
d6 :3 0 71c 71d
0 3c7 71b 71f
bb :4 0 3c9 71a
722 3cc 719 724
:3 0 3cf 70a 726
:2 0 728 3d2 729
707 728 0 72a
3d4 0 753 ad
:3 0 ae :3 0 72b
72c 0 ad :3 0
bd :3 0 72e 72f
0 46 :2 0 2
:4 0 e4 :2 0 bf
:2 0 46 :2 0 3d6
734 736 :3 0 3d9
730 738 72d 73a
739 :2 0 b0 :3 0
c0 :3 0 73c 73d
0 b2 :4 0 e5
:4 0 b5 :2 0 b6
:3 0 3dd 741 743
:3 0 3e0 73e 745
:2 0 747 3e3 748
73b 747 0 749
3e5 0 753 ce
:3 0 cf :3 0 74a
74b 0 c2 :3 0
d6 :3 0 74d 74e
0 d0 :3 0 3e7
74c 751 :2 0 753
3ea 754 6f6 753
0 755 3ee 0
355e 5 :3 0 de
:2 0 3f0 757 758
:3 0 759 :2 0 a1
:3 0 df :3 0 3f
:3 0 3f2 75c 75e
4d :2 0 3f4 75b
761 e0 :2 0 e1
:2 0 3f9 763 765
:3 0 766 :2 0 75a
768 767 :2 0 769
:2 0 ad :3 0 ae
:3 0 76b 76c 0
ad :3 0 bd :3 0
76e 76f 0 c6
:2 0 2 :4 0 e6
:2 0 bf :2 0 46
:2 0 3fc 774 776
:3 0 3ff 770 778
76d 77a 779 :2 0
b0 :3 0 c0 :3 0
77c 77d 0 b2
:4 0 e7 :4 0 b5
:2 0 b6 :3 0 403
781 783 :3 0 b5
:2 0 c9 :4 0 406
785 787 :3 0 b5
:2 0 ca :4 0 409
789 78b :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 d6
:3 0 790 791 0
40c 78f 793 bb
:4 0 40e 78e 796
411 78d 798 :3 0
414 77e 79a :2 0
79c 417 79d 77b
79c 0 79e 419
0 7c7 ad :3 0
ae :3 0 79f 7a0
0 ad :3 0 bd
:3 0 7a2 7a3 0
46 :2 0 2 :4 0
e8 :2 0 bf :2 0
46 :2 0 41b 7a8
7aa :3 0 41e 7a4
7ac 7a1 7ae 7ad
:2 0 b0 :3 0 c0
:3 0 7b0 7b1 0
b2 :4 0 e9 :4 0
b5 :2 0 b6 :3 0
422 7b5 7b7 :3 0
425 7b2 7b9 :2 0
7bb 428 7bc 7af
7bb 0 7bd 42a
0 7c7 ce :3 0
cf :3 0 7be 7bf
0 c2 :3 0 d6
:3 0 7c1 7c2 0
d0 :3 0 42c 7c0
7c5 :2 0 7c7 42f
7c8 76a 7c7 0
7c9 433 0 355e
a1 :3 0 4c :3 0
4d :2 0 435 7ca
7cd d2 :2 0 ea
:2 0 43a 7cf 7d1
:3 0 a1 :3 0 5a
:3 0 4d :2 0 43d
7d3 7d6 d2 :2 0
ea :2 0 442 7d8
7da :3 0 7d2 7dc
7db :2 0 a1 :3 0
56 :3 0 4d :2 0
445 7de 7e1 d2
:2 0 ea :2 0 44a
7e3 7e5 :3 0 7dd
7e7 7e6 :2 0 ad
:3 0 ae :3 0 7e9
7ea 0 ad :3 0
bd :3 0 7ec 7ed
0 c6 :2 0 2
:4 0 eb :2 0 bf
:2 0 46 :2 0 44d
7f2 7f4 :3 0 450
7ee 7f6 7eb 7f8
7f7 :2 0 b0 :3 0
c0 :3 0 7fa 7fb
0 b2 :4 0 ec
:4 0 b5 :2 0 b6
:3 0 454 7ff 801
:3 0 b5 :2 0 c9
:4 0 457 803 805
:3 0 b5 :2 0 ca
:4 0 45a 807 809
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 d6 :3 0 80e
80f 0 45d 80d
811 bb :4 0 45f
80c 814 462 80b
816 :3 0 465 7fc
818 :2 0 81a 468
81b 7f9 81a 0
81c 46a 0 845
ad :3 0 ae :3 0
81d 81e 0 ad
:3 0 bd :3 0 820
821 0 46 :2 0
2 :4 0 ed :2 0
bf :2 0 46 :2 0
46c 826 828 :3 0
46f 822 82a 81f
82c 82b :2 0 b0
:3 0 c0 :3 0 82e
82f 0 b2 :4 0
ee :4 0 b5 :2 0
b6 :3 0 473 833
835 :3 0 476 830
837 :2 0 839 479
83a 82d 839 0
83b 47b 0 845
ce :3 0 cf :3 0
83c 83d 0 c2
:3 0 d6 :3 0 83f
840 0 d0 :3 0
47d 83e 843 :2 0
845 480 846 7e8
845 0 847 484
0 355e 15 :3 0
c5 :2 0 486 849
84a :3 0 84b :2 0
84c :2 0 53 :3 0
ef :2 0 84e 84f
0 851 488 856
53 :3 0 15 :3 0
852 853 0 855
48a 857 84d 851
0 858 0 855
0 858 48c 0
355e a1 :3 0 4c
:3 0 4d :2 0 48f
859 85c c2 :3 0
c3 :2 0 c4 :3 0
85e 860 0 494
85f 862 :3 0 863
:2 0 5 :3 0 de
:2 0 497 866 867
:3 0 868 :2 0 869
:2 0 864 86b 86a
:2 0 6 :3 0 de
:2 0 499 86e 86f
:3 0 870 :2 0 871
:2 0 86c 873 872
:2 0 f0 :3 0 f1
:3 0 6 :3 0 f0
:3 0 f1 :3 0 5
:3 0 69 :3 0 f2
:4 0 f3 1 :8 0
883 21 :3 0 f4
:3 0 87e 87f 0
f5 :3 0 880 881
0 883 49b 8cd
f6 :3 0 21 :3 0
f4 :3 0 886 887
0 f5 :3 0 888
889 0 8c3 ad
:3 0 ae :3 0 88b
88c 0 ad :3 0
bd :3 0 88e 88f
0 f7 :2 0 2
:4 0 f8 :2 0 bf
:2 0 46 :2 0 49e
894 896 :3 0 4a1
890 898 88d 89a
899 :2 0 b0 :3 0
c0 :3 0 89c 89d
0 b2 :4 0 f9
:4 0 b5 :2 0 b6
:3 0 4a5 8a1 8a3
:3 0 b5 :2 0 c9
:4 0 4a8 8a5 8a7
:3 0 b5 :2 0 fa
:4 0 4ab 8a9 8ab
:3 0 b5 :2 0 f5
:3 0 4ae 8ad 8af
:3 0 b5 :2 0 fb
:4 0 4b1 8b1 8b3
:3 0 b5 :2 0 fc
:3 0 fd :3 0 46
:2 0 fe :2 0 4b4
8b6 8ba 4b8 8b5
8bc :3 0 4bb 89e
8be :2 0 8c0 4be
8c1 89b 8c0 0
8c2 4c0 0 8c3
4c2 8c6 :3 0 8c6
0 8c6 8c5 8c3
8c4 :6 0 8c8 4
:3 0 4c5 8ca 4c7
8c9 8c8 :2 0 8cb
4c9 :2 0 8cd 0
8cd 8cc 883 8cb
:6 0 947 1 :3 0
21 :3 0 f4 :3 0
8cf 8d0 0 21
:3 0 d2 :2 0 ff
:3 0 8d2 8d4 0
4cd 8d3 8d6 :3 0
8d7 :2 0 a1 :3 0
69 :3 0 4d :2 0
4d0 8d9 8dc e0
:2 0 4d :2 0 4d5
8de 8e0 :3 0 8e1
:2 0 8d8 8e3 8e2
:2 0 ad :3 0 ae
:3 0 8e5 8e6 0
ad :3 0 bd :3 0
8e8 8e9 0 c6
:2 0 2 :4 0 100
:2 0 bf :2 0 46
:2 0 4d8 8ee 8f0
:3 0 4db 8ea 8f2
8e7 8f4 8f3 :2 0
b0 :3 0 c0 :3 0
8f6 8f7 0 b2
:4 0 101 :4 0 b5
:2 0 b6 :3 0 4df
8fb 8fd :3 0 b5
:2 0 c9 :4 0 4e2
8ff 901 :3 0 b5
:2 0 ca :4 0 4e5
903 905 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 102
:3 0 90a 90b 0
4e8 909 90d bb
:4 0 4ea 908 910
4ed 907 912 :3 0
4f0 8f8 914 :2 0
916 4f3 917 8f5
916 0 918 4f5
0 941 ad :3 0
ae :3 0 919 91a
0 ad :3 0 bd
:3 0 91c 91d 0
46 :2 0 2 :4 0
103 :2 0 bf :2 0
46 :2 0 4f7 922
924 :3 0 4fa 91e
926 91b 928 927
:2 0 b0 :3 0 c0
:3 0 92a 92b 0
b2 :4 0 104 :4 0
b5 :2 0 b6 :3 0
4fe 92f 931 :3 0
501 92c 933 :2 0
935 504 936 929
935 0 937 506
0 941 ce :3 0
cf :3 0 938 939
0 c2 :3 0 102
:3 0 93b 93c 0
d0 :3 0 508 93a
93f :2 0 941 50b
942 8e4 941 0
943 50f 0 947
89 :3 0 46 :2 0
944 945 0 947
511 948 874 947
0 949 515 0
355e 5 :3 0 c5
:2 0 517 94b 94c
:3 0 94d :2 0 94e
:2 0 6 :3 0 c5
:2 0 519 951 952
:3 0 953 :2 0 954
:2 0 94f 956 955
:2 0 b6 :3 0 3f
:3 0 f2 :4 0 105
1 :8 0 961 21
:3 0 f4 :3 0 95c
95d 0 f5 :3 0
95e 95f 0 961
51b 9ab f6 :3 0
21 :3 0 f4 :3 0
964 965 0 f5
:3 0 966 967 0
9a1 ad :3 0 ae
:3 0 969 96a 0
ad :3 0 bd :3 0
96c 96d 0 f7
:2 0 2 :4 0 106
:2 0 bf :2 0 46
:2 0 51e 972 974
:3 0 521 96e 976
96b 978 977 :2 0
b0 :3 0 c0 :3 0
97a 97b 0 b2
:4 0 107 :4 0 b5
:2 0 b6 :3 0 525
97f 981 :3 0 b5
:2 0 c9 :4 0 528
983 985 :3 0 b5
:2 0 fa :4 0 52b
987 989 :3 0 b5
:2 0 f5 :3 0 52e
98b 98d :3 0 b5
:2 0 fb :4 0 531
98f 991 :3 0 b5
:2 0 fc :3 0 fd
:3 0 46 :2 0 fe
:2 0 534 994 998
538 993 99a :3 0
53b 97c 99c :2 0
99e 53e 99f 979
99e 0 9a0 540
0 9a1 542 9a4
:3 0 9a4 0 9a4
9a3 9a1 9a2 :6 0
9a6 6 :3 0 545
9a8 547 9a7 9a6
:2 0 9a9 549 :2 0
9ab 0 9ab 9aa
961 9a9 :6 0 9ad
1 :3 0 54b 9ae
957 9ad 0 9af
54d 0 355e 41
:3 0 3f :3 0 9b0
9b1 0 355e 6a
:3 0 108 :3 0 109
:3 0 9b4 9b5 0
10a :3 0 a1 :3 0
4f :3 0 4d :2 0
54f 9b8 9bb c2
:3 0 10b :3 0 9bd
9be 0 552 9b7
9c0 9c1 :2 0 10c
:2 0 555 9b6 9c4
9b3 9c5 0 355e
4f :3 0 10a :3 0
a1 :3 0 4f :3 0
4d :2 0 558 9c9
9cc c2 :3 0 10d
:3 0 9ce 9cf 0
55b 9c8 9d1 9c7
9d2 0 355e 54
:3 0 108 :3 0 109
:3 0 9d5 9d6 0
10a :3 0 a1 :3 0
5b :3 0 4d :2 0
55e 9d9 9dc c2
:3 0 10b :3 0 9de
9df 0 561 9d8
9e1 9e2 :2 0 10c
:2 0 564 9d7 9e5
9d4 9e6 0 355e
5b :3 0 10a :3 0
a1 :3 0 5b :3 0
4d :2 0 567 9ea
9ed c2 :3 0 10d
:3 0 9ef 9f0 0
56a 9e9 9f2 9e8
9f3 0 355e 45
:3 0 a1 :3 0 5b
:3 0 4d :2 0 56d
9f6 9f9 c2 :3 0
d2 :2 0 d3 :3 0
9fb 9fd 0 572
9fc 9ff :3 0 46
:2 0 575 a02 a01
4d :3 0 a04 0
577 :2 0 9f5 a06
0 355e a1 :3 0
4f :3 0 4d :2 0
57a a08 a0b 10e
:2 0 4d :2 0 57f
a0d a0f :3 0 82
:3 0 4d :2 0 a11
a12 0 129a 10f
:3 0 82 :3 0 110
:3 0 98 :3 0 25
:4 0 111 1 :8 0
a1f 21 :3 0 f4
:3 0 a1a a1b 0
f5 :3 0 a1c a1d
0 a1f 582 a69
f6 :3 0 21 :3 0
f4 :3 0 a22 a23
0 f5 :3 0 a24
a25 0 a5f ad
:3 0 ae :3 0 a27
a28 0 ad :3 0
bd :3 0 a2a a2b
0 f7 :2 0 2
:4 0 112 :2 0 bf
:2 0 46 :2 0 585
a30 a32 :3 0 588
a2c a34 a29 a36
a35 :2 0 b0 :3 0
c0 :3 0 a38 a39
0 b2 :4 0 113
:4 0 b5 :2 0 b6
:3 0 58c a3d a3f
:3 0 b5 :2 0 c9
:4 0 58f a41 a43
:3 0 b5 :2 0 fa
:4 0 592 a45 a47
:3 0 b5 :2 0 f5
:3 0 595 a49 a4b
:3 0 b5 :2 0 fb
:4 0 598 a4d a4f
:3 0 b5 :2 0 fc
:3 0 fd :3 0 46
:2 0 fe :2 0 59b
a52 a56 59f a51
a58 :3 0 5a2 a3a
a5a :2 0 a5c 5a5
a5d a37 a5c 0
a5e 5a7 0 a5f
5a9 a62 :3 0 a62
0 a62 a61 a5f
a60 :6 0 a64 8
:3 0 5ac a66 5ae
a65 a64 :2 0 a67
5b0 :2 0 a69 0
a69 a68 a1f a67
:6 0 129a 1 :3 0
a1 :3 0 82 :3 0
4d :2 0 5b2 a6b
a6e 10e :2 0 4d
:2 0 5b7 a70 a72
:3 0 114 :3 0 4b
:3 0 115 :3 0 116
:3 0 25 :4 0 117
1 :8 0 a7f 21
:3 0 f4 :3 0 a7a
a7b 0 f5 :3 0
a7c a7d 0 a7f
5ba ac9 f6 :3 0
21 :3 0 f4 :3 0
a82 a83 0 f5
:3 0 a84 a85 0
abf ad :3 0 ae
:3 0 a87 a88 0
ad :3 0 bd :3 0
a8a a8b 0 f7
:2 0 2 :4 0 118
:2 0 bf :2 0 46
:2 0 5bd a90 a92
:3 0 5c0 a8c a94
a89 a96 a95 :2 0
b0 :3 0 c0 :3 0
a98 a99 0 b2
:4 0 119 :4 0 b5
:2 0 b6 :3 0 5c4
a9d a9f :3 0 b5
:2 0 c9 :4 0 5c7
aa1 aa3 :3 0 b5
:2 0 fa :4 0 5ca
aa5 aa7 :3 0 b5
:2 0 f5 :3 0 5cd
aa9 aab :3 0 b5
:2 0 fb :4 0 5d0
aad aaf :3 0 b5
:2 0 fc :3 0 fd
:3 0 46 :2 0 fe
:2 0 5d3 ab2 ab6
5d7 ab1 ab8 :3 0
5da a9a aba :2 0
abc 5dd abd a97
abc 0 abe 5df
0 abf 5e1 ac2
:3 0 ac2 0 ac2
ac1 abf ac0 :6 0
ac4 a :3 0 5e4
ac6 5e6 ac5 ac4
:2 0 ac7 5e8 :2 0
ac9 0 ac9 ac8
a7f ac7 :6 0 b46
1 :3 0 f0 :3 0
11a :3 0 acb acc
0 4b :3 0 11b
:4 0 5ea acd ad0
d2 :2 0 4d :2 0
5ef ad2 ad4 :3 0
ad :3 0 ae :3 0
ad6 ad7 0 ad
:3 0 bd :3 0 ad9
ada 0 24 :2 0
2 :4 0 11c :2 0
bf :2 0 46 :2 0
5f2 adf ae1 :3 0
5f5 adb ae3 ad8
ae5 ae4 :2 0 b0
:3 0 c0 :3 0 ae7
ae8 0 b2 :4 0
11d :4 0 b5 :2 0
b6 :3 0 5f9 aec
aee :3 0 b5 :2 0
c9 :4 0 5fc af0
af2 :3 0 b5 :2 0
ca :4 0 5ff af4
af6 :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 11e :3 0
afb afc 0 602
afa afe bb :4 0
604 af9 b01 607
af8 b03 :3 0 b5
:2 0 11f :4 0 60a
b05 b07 :3 0 b5
:2 0 b8 :4 0 60d
b09 b0b :3 0 b5
:2 0 25 :3 0 610
b0d b0f :3 0 b5
:2 0 b8 :4 0 613
b11 b13 :3 0 616
ae9 b15 :2 0 b17
619 b18 ae6 b17
0 b19 61b 0
b43 ad :3 0 ae
:3 0 b1a b1b 0
ad :3 0 bd :3 0
b1d b1e 0 46
:2 0 2 :4 0 120
:2 0 bf :2 0 46
:2 0 61d b23 b25
:3 0 620 b1f b27
b1c b29 b28 :2 0
b0 :3 0 c0 :3 0
b2b b2c 0 b2
:4 0 121 :4 0 b5
:2 0 b6 :3 0 624
b30 b32 :3 0 627
b2d b34 :2 0 b36
62a b37 b2a b36
0 b38 62c 0
b43 ce :3 0 122
:3 0 b39 b3a 0
c2 :3 0 11e :3 0
b3c b3d 0 25
:3 0 d0 :3 0 62e
b3b b41 :2 0 b43
632 b44 ad5 b43
0 b45 636 0
b46 638 b47 a73
b46 0 b48 63b
0 129a 79 :3 0
123 :3 0 a1 :3 0
4f :3 0 4d :2 0
63d b4b b4e 640
b4a b50 b49 b51
0 129a a1 :3 0
79 :3 0 4d :2 0
642 b53 b56 d2
:2 0 4d :2 0 647
b58 b5a :3 0 4f
:3 0 124 :3 0 a1
:3 0 4f :3 0 4d
:2 0 64a b5e b61
64d b5d b63 b5c
b64 0 bd3 a1
:3 0 4f :3 0 4d
:2 0 64f b66 b69
d2 :2 0 4d :2 0
654 b6b b6d :3 0
ad :3 0 ae :3 0
b6f b70 0 ad
:3 0 bd :3 0 b72
b73 0 c6 :2 0
2 :4 0 125 :2 0
bf :2 0 46 :2 0
657 b78 b7a :3 0
65a b74 b7c b71
b7e b7d :2 0 b0
:3 0 c0 :3 0 b80
b81 0 b2 :4 0
126 :4 0 b5 :2 0
b6 :3 0 65e b85
b87 :3 0 b5 :2 0
c9 :4 0 661 b89
b8b :3 0 b5 :2 0
ca :4 0 664 b8d
b8f :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 d6 :3 0
b94 b95 0 667
b93 b97 bb :4 0
669 b92 b9a 66c
b91 b9c :3 0 66f
b82 b9e :2 0 ba0
672 ba1 b7f ba0
0 ba2 674 0
bcb ad :3 0 ae
:3 0 ba3 ba4 0
ad :3 0 bd :3 0
ba6 ba7 0 46
:2 0 2 :4 0 127
:2 0 bf :2 0 46
:2 0 676 bac bae
:3 0 679 ba8 bb0
ba5 bb2 bb1 :2 0
b0 :3 0 c0 :3 0
bb4 bb5 0 b2
:4 0 128 :4 0 b5
:2 0 b6 :3 0 67d
bb9 bbb :3 0 680
bb6 bbd :2 0 bbf
683 bc0 bb3 bbf
0 bc1 685 0
bcb ce :3 0 cf
:3 0 bc2 bc3 0
c2 :3 0 d6 :3 0
bc5 bc6 0 d0
:3 0 687 bc4 bc9
:2 0 bcb 68a bcc
b6e bcb 0 bcd
68e 0 bd3 79
:3 0 c2 :3 0 129
:3 0 bcf bd0 0
bce bd1 0 bd3
690 bd4 b5b bd3
0 bd5 694 0
129a 26 :3 0 25
:3 0 bd6 bd7 0
129a a1 :3 0 6a
:3 0 4d :2 0 696
bd9 bdc c3 :2 0
4d :2 0 69b bde
be0 :3 0 39 :3 0
14 :3 0 be2 be3
0 be5 69e c43
ad :3 0 ae :3 0
be6 be7 0 ad
:3 0 bd :3 0 be9
bea 0 c6 :2 0
2 :4 0 12a :2 0
bf :2 0 46 :2 0
6a0 bef bf1 :3 0
6a3 beb bf3 be8
bf5 bf4 :2 0 b0
:3 0 c0 :3 0 bf7
bf8 0 b2 :4 0
12b :4 0 b5 :2 0
b6 :3 0 6a7 bfc
bfe :3 0 b5 :2 0
c9 :4 0 6aa c00
c02 :3 0 b5 :2 0
ca :4 0 6ad c04
c06 :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 d6 :3 0
c0b c0c 0 6b0
c0a c0e bb :4 0
6b2 c09 c11 6b5
c08 c13 :3 0 6b8
bf9 c15 :2 0 c17
6bb c18 bf6 c17
0 c19 6bd 0
c42 ad :3 0 ae
:3 0 c1a c1b 0
ad :3 0 bd :3 0
c1d c1e 0 46
:2 0 2 :4 0 12c
:2 0 bf :2 0 46
:2 0 6bf c23 c25
:3 0 6c2 c1f c27
c1c c29 c28 :2 0
b0 :3 0 c0 :3 0
c2b c2c 0 b2
:4 0 12d :4 0 b5
:2 0 b6 :3 0 6c6
c30 c32 :3 0 6c9
c2d c34 :2 0 c36
6cc c37 c2a c36
0 c38 6ce 0
c42 ce :3 0 cf
:3 0 c39 c3a 0
c2 :3 0 d6 :3 0
c3c c3d 0 d0
:3 0 6d0 c3b c40
:2 0 c42 6d3 c44
be1 be5 0 c45
0 c42 0 c45
6d7 0 129a 84
:3 0 12e :3 0 79
:3 0 4f :3 0 26
:3 0 39 :3 0 29
:3 0 47 :3 0 6da
c47 c4e c46 c4f
0 129a a1 :3 0
84 :3 0 4d :2 0
6e1 c51 c54 c3
:2 0 4d :2 0 6e6
c56 c58 :3 0 ad
:3 0 ae :3 0 c5a
c5b 0 ad :3 0
bd :3 0 c5d c5e
0 24 :2 0 2
:4 0 12f :2 0 bf
:2 0 46 :2 0 6e9
c63 c65 :3 0 6ec
c5f c67 c5c c69
c68 :2 0 b0 :3 0
c0 :3 0 c6b c6c
0 b2 :4 0 130
:4 0 b5 :2 0 b6
:3 0 6f0 c70 c72
:3 0 b5 :2 0 c9
:4 0 6f3 c74 c76
:3 0 b5 :2 0 ca
:4 0 6f6 c78 c7a
:3 0 b5 :2 0 a1
:3 0 ba :3 0 84
:3 0 6f9 c7e c80
bb :4 0 6fb c7d
c83 6fe c7c c85
:3 0 b5 :2 0 11f
:4 0 701 c87 c89
:3 0 b5 :2 0 b8
:4 0 704 c8b c8d
:3 0 b5 :2 0 47
:3 0 707 c8f c91
:3 0 b5 :2 0 b8
:4 0 70a c93 c95
:3 0 70d c6d c97
:2 0 c99 710 c9a
c6a c99 0 c9b
712 0 cc7 ad
:3 0 ae :3 0 c9c
c9d 0 ad :3 0
bd :3 0 c9f ca0
0 46 :2 0 2
:4 0 131 :2 0 bf
:2 0 46 :2 0 714
ca5 ca7 :3 0 717
ca1 ca9 c9e cab
caa :2 0 b0 :3 0
c0 :3 0 cad cae
0 b2 :4 0 132
:4 0 b5 :2 0 b6
:3 0 71b cb2 cb4
:3 0 71e caf cb6
:2 0 cb8 721 cb9
cac cb8 0 cba
723 0 cc7 ce
:3 0 122 :3 0 cbb
cbc 0 a1 :3 0
84 :3 0 4d :2 0
725 cbe cc1 47
:3 0 d0 :3 0 728
cbd cc5 :2 0 cc7
72c cc8 c59 cc7
0 cc9 730 0
129a a1 :3 0 4c
:3 0 4d :2 0 732
cca ccd c2 :3 0
d2 :2 0 c4 :3 0
ccf cd1 0 737
cd0 cd3 :3 0 ad
:3 0 ae :3 0 cd5
cd6 0 ad :3 0
bd :3 0 cd8 cd9
0 24 :2 0 2
:4 0 133 :2 0 bf
:2 0 46 :2 0 73a
cde ce0 :3 0 73d
cda ce2 cd7 ce4
ce3 :2 0 b0 :3 0
c0 :3 0 ce6 ce7
0 b2 :4 0 134
:4 0 b5 :2 0 b6
:3 0 741 ceb ced
:3 0 b5 :2 0 c9
:4 0 744 cef cf1
:3 0 b5 :2 0 ca
:4 0 747 cf3 cf5
:3 0 b5 :2 0 a1
:3 0 ba :3 0 21
:3 0 f4 :3 0 cfa
cfb 0 74a cf9
cfd bb :4 0 74c
cf8 d00 74f cf7
d02 :3 0 b5 :2 0
11f :4 0 752 d04
d06 :3 0 b5 :2 0
b8 :4 0 755 d08
d0a :3 0 b5 :2 0
47 :3 0 758 d0c
d0e :3 0 b5 :2 0
b8 :4 0 75b d10
d12 :3 0 75e ce8
d14 :2 0 d16 761
d17 ce5 d16 0
d18 763 0 d42
ad :3 0 ae :3 0
d19 d1a 0 ad
:3 0 bd :3 0 d1c
d1d 0 46 :2 0
2 :4 0 135 :2 0
bf :2 0 46 :2 0
765 d22 d24 :3 0
768 d1e d26 d1b
d28 d27 :2 0 b0
:3 0 c0 :3 0 d2a
d2b 0 b2 :4 0
136 :4 0 b5 :2 0
b6 :3 0 76c d2f
d31 :3 0 76f d2c
d33 :2 0 d35 772
d36 d29 d35 0
d37 774 0 d42
ce :3 0 122 :3 0
d38 d39 0 21
:3 0 f4 :3 0 d3b
d3c 0 47 :3 0
d0 :3 0 776 d3a
d40 :2 0 d42 77a
d43 cd4 d42 0
d44 77e 0 129a
a1 :3 0 79 :3 0
4d :2 0 780 d45
d48 c2 :3 0 d2
:2 0 129 :3 0 d4a
d4c 0 785 d4b
d4e :3 0 137 :3 0
a1 :3 0 4f :3 0
4d :2 0 788 d51
d54 78b d50 d56
c3 :2 0 4d :2 0
78f d58 d5a :3 0
98 :3 0 a1 :3 0
138 :3 0 a1 :3 0
139 :3 0 13a :3 0
25 :3 0 5e :3 0
5f :3 0 63 :3 0
115 :3 0 116 :3 0
26 :4 0 13b 1
:8 0 d6f 21 :3 0
f4 :3 0 d6a d6b
0 f5 :3 0 d6c
d6d 0 d6f 792
db9 f6 :3 0 21
:3 0 f4 :3 0 d72
d73 0 f5 :3 0
d74 d75 0 daf
ad :3 0 ae :3 0
d77 d78 0 ad
:3 0 bd :3 0 d7a
d7b 0 f7 :2 0
2 :4 0 13c :2 0
bf :2 0 46 :2 0
795 d80 d82 :3 0
798 d7c d84 d79
d86 d85 :2 0 b0
:3 0 c0 :3 0 d88
d89 0 b2 :4 0
13d :4 0 b5 :2 0
b6 :3 0 79c d8d
d8f :3 0 b5 :2 0
c9 :4 0 79f d91
d93 :3 0 b5 :2 0
fa :4 0 7a2 d95
d97 :3 0 b5 :2 0
f5 :3 0 7a5 d99
d9b :3 0 b5 :2 0
fb :4 0 7a8 d9d
d9f :3 0 b5 :2 0
fc :3 0 fd :3 0
46 :2 0 fe :2 0
7ab da2 da6 7af
da1 da8 :3 0 7b2
d8a daa :2 0 dac
7b5 dad d87 dac
0 dae 7b7 0
daf 7b9 db2 :3 0
db2 0 db2 db1
daf db0 :6 0 db4
c :3 0 7bc db6
7be db5 db4 :2 0
db7 7c0 :2 0 db9
0 db9 db8 d6f
db7 :6 0 dbb 1
:3 0 7c2 e36 13e
:3 0 13f :3 0 13e
:3 0 140 :3 0 13e
:3 0 141 :3 0 13e
:3 0 98 :3 0 a1
:3 0 142 :3 0 138
:3 0 a1 :3 0 142
:3 0 139 :3 0 142
:3 0 13a :3 0 13e
:3 0 143 :3 0 13e
:3 0 144 :3 0 71
:3 0 43 :3 0 44
:3 0 25 :3 0 5e
:3 0 5f :3 0 63
:3 0 72 :3 0 115
:3 0 142 :3 0 115
:3 0 13e :3 0 13e
:3 0 116 :3 0 26
:3 0 142 :3 0 116
:3 0 13e :3 0 98
:4 0 145 1 :8 0
de9 21 :3 0 f4
:3 0 de4 de5 0
f5 :3 0 de6 de7
0 de9 7c4 e33
f6 :3 0 21 :3 0
f4 :3 0 dec ded
0 f5 :3 0 dee
def 0 e29 ad
:3 0 ae :3 0 df1
df2 0 ad :3 0
bd :3 0 df4 df5
0 f7 :2 0 2
:4 0 146 :2 0 bf
:2 0 46 :2 0 7c7
dfa dfc :3 0 7ca
df6 dfe df3 e00
dff :2 0 b0 :3 0
c0 :3 0 e02 e03
0 b2 :4 0 147
:4 0 b5 :2 0 b6
:3 0 7ce e07 e09
:3 0 b5 :2 0 c9
:4 0 7d1 e0b e0d
:3 0 b5 :2 0 fa
:4 0 7d4 e0f e11
:3 0 b5 :2 0 f5
:3 0 7d7 e13 e15
:3 0 b5 :2 0 fb
:4 0 7da e17 e19
:3 0 b5 :2 0 fc
:3 0 fd :3 0 46
:2 0 fe :2 0 7dd
e1c e20 7e1 e1b
e22 :3 0 7e4 e04
e24 :2 0 e26 7e7
e27 e01 e26 0
e28 7e9 0 e29
7eb e2c :3 0 e2c
0 e2c e2b e29
e2a :6 0 e2e e
:3 0 7ee e30 7f0
e2f e2e :2 0 e31
7f2 :2 0 e33 0
e33 e32 de9 e31
:6 0 e35 1 :3 0
7f4 e37 d5b dbb
0 e38 0 e35
0 e38 7f6 0
eb4 21 :3 0 f4
:3 0 e39 e3a 0
21 :3 0 c3 :2 0
ff :3 0 e3c e3e
0 7fb e3d e40
:3 0 e41 :2 0 ad
:3 0 ae :3 0 e43
e44 0 ad :3 0
bd :3 0 e46 e47
0 24 :2 0 2
:4 0 148 :2 0 bf
:2 0 46 :2 0 7fe
e4c e4e :3 0 801
e48 e50 e45 e52
e51 :2 0 b0 :3 0
c0 :3 0 e54 e55
0 b2 :4 0 149
:4 0 b5 :2 0 b6
:3 0 805 e59 e5b
:3 0 b5 :2 0 c9
:4 0 808 e5d e5f
:3 0 b5 :2 0 ca
:4 0 80b e61 e63
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 14a :3 0 e68
e69 0 80e e67
e6b bb :4 0 810
e66 e6e 813 e65
e70 :3 0 b5 :2 0
11f :4 0 816 e72
e74 :3 0 b5 :2 0
b8 :4 0 819 e76
e78 :3 0 b5 :2 0
26 :3 0 81c e7a
e7c :3 0 b5 :2 0
b8 :4 0 81f e7e
e80 :3 0 822 e56
e82 :2 0 e84 825
e85 e53 e84 0
e86 827 0 eb0
ad :3 0 ae :3 0
e87 e88 0 ad
:3 0 bd :3 0 e8a
e8b 0 46 :2 0
2 :4 0 14b :2 0
bf :2 0 46 :2 0
829 e90 e92 :3 0
82c e8c e94 e89
e96 e95 :2 0 b0
:3 0 c0 :3 0 e98
e99 0 b2 :4 0
14c :4 0 b5 :2 0
b6 :3 0 830 e9d
e9f :3 0 833 e9a
ea1 :2 0 ea3 836
ea4 e97 ea3 0
ea5 838 0 eb0
ce :3 0 122 :3 0
ea6 ea7 0 c2
:3 0 14a :3 0 ea9
eaa 0 26 :3 0
d0 :3 0 83a ea8
eae :2 0 eb0 83e
eb1 e42 eb0 0
eb2 842 0 eb4
d9 :3 0 844 10f7
a1 :3 0 79 :3 0
4d :2 0 847 eb5
eb8 c2 :3 0 d2
:2 0 14d :3 0 eba
ebc 0 84c ebb
ebe :3 0 98 :3 0
14e :3 0 14f :3 0
25 :3 0 4f :3 0
23 :3 0 150 :3 0
116 :3 0 26 :4 0
151 1 :8 0 ecf
21 :3 0 f4 :3 0
eca ecb 0 f5
:3 0 ecc ecd 0
ecf 84f f19 f6
:3 0 21 :3 0 f4
:3 0 ed2 ed3 0
f5 :3 0 ed4 ed5
0 f0f ad :3 0
ae :3 0 ed7 ed8
0 ad :3 0 bd
:3 0 eda edb 0
f7 :2 0 2 :4 0
152 :2 0 bf :2 0
46 :2 0 852 ee0
ee2 :3 0 855 edc
ee4 ed9 ee6 ee5
:2 0 b0 :3 0 c0
:3 0 ee8 ee9 0
b2 :4 0 153 :4 0
b5 :2 0 b6 :3 0
859 eed eef :3 0
b5 :2 0 c9 :4 0
85c ef1 ef3 :3 0
b5 :2 0 fa :4 0
85f ef5 ef7 :3 0
b5 :2 0 f5 :3 0
862 ef9 efb :3 0
b5 :2 0 fb :4 0
865 efd eff :3 0
b5 :2 0 fc :3 0
fd :3 0 46 :2 0
fe :2 0 868 f02
f06 86c f01 f08
:3 0 86f eea f0a
:2 0 f0c 872 f0d
ee7 f0c 0 f0e
874 0 f0f 876
f12 :3 0 f12 0
f12 f11 f0f f10
:6 0 f14 10 :3 0
879 f16 87b f15
f14 :2 0 f17 87d
:2 0 f19 0 f19
f18 ecf f17 :6 0
1087 1 :3 0 21
:3 0 f4 :3 0 f1b
f1c 0 21 :3 0
c3 :2 0 ff :3 0
f1e f20 0 881
f1f f22 :3 0 f23
:2 0 ad :3 0 ae
:3 0 f25 f26 0
ad :3 0 bd :3 0
f28 f29 0 24
:2 0 2 :4 0 154
:2 0 bf :2 0 46
:2 0 884 f2e f30
:3 0 887 f2a f32
f27 f34 f33 :2 0
b0 :3 0 c0 :3 0
f36 f37 0 b2
:4 0 155 :4 0 b5
:2 0 b6 :3 0 88b
f3b f3d :3 0 b5
:2 0 c9 :4 0 88e
f3f f41 :3 0 b5
:2 0 ca :4 0 891
f43 f45 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 14a
:3 0 f4a f4b 0
894 f49 f4d bb
:4 0 896 f48 f50
899 f47 f52 :3 0
b5 :2 0 11f :4 0
89c f54 f56 :3 0
b5 :2 0 b8 :4 0
89f f58 f5a :3 0
b5 :2 0 26 :3 0
8a2 f5c f5e :3 0
b5 :2 0 b8 :4 0
8a5 f60 f62 :3 0
8a8 f38 f64 :2 0
f66 8ab f67 f35
f66 0 f68 8ad
0 f92 ad :3 0
ae :3 0 f69 f6a
0 ad :3 0 bd
:3 0 f6c f6d 0
46 :2 0 2 :4 0
156 :2 0 bf :2 0
46 :2 0 8af f72
f74 :3 0 8b2 f6e
f76 f6b f78 f77
:2 0 b0 :3 0 c0
:3 0 f7a f7b 0
b2 :4 0 157 :4 0
b5 :2 0 b6 :3 0
8b6 f7f f81 :3 0
8b9 f7c f83 :2 0
f85 8bc f86 f79
f85 0 f87 8be
0 f92 ce :3 0
122 :3 0 f88 f89
0 c2 :3 0 14a
:3 0 f8b f8c 0
26 :3 0 d0 :3 0
8c0 f8a f90 :2 0
f92 8c4 f93 f24
f92 0 f94 8c8
0 1087 158 :3 0
41 :3 0 158 :3 0
159 :3 0 41 :3 0
a1 :3 0 138 :3 0
a1 :3 0 139 :3 0
13a :3 0 41 :3 0
5e :3 0 5f :3 0
63 :3 0 115 :3 0
98 :3 0 25 :3 0
116 :3 0 25 :4 0
15a 1 :8 0 fae
21 :3 0 f4 :3 0
fa9 faa 0 f5
:3 0 fab fac 0
fae 8ca ff8 f6
:3 0 21 :3 0 f4
:3 0 fb1 fb2 0
f5 :3 0 fb3 fb4
0 fee ad :3 0
ae :3 0 fb6 fb7
0 ad :3 0 bd
:3 0 fb9 fba 0
f7 :2 0 2 :4 0
15b :2 0 bf :2 0
46 :2 0 8cd fbf
fc1 :3 0 8d0 fbb
fc3 fb8 fc5 fc4
:2 0 b0 :3 0 c0
:3 0 fc7 fc8 0
b2 :4 0 15c :4 0
b5 :2 0 b6 :3 0
8d4 fcc fce :3 0
b5 :2 0 c9 :4 0
8d7 fd0 fd2 :3 0
b5 :2 0 fa :4 0
8da fd4 fd6 :3 0
b5 :2 0 f5 :3 0
8dd fd8 fda :3 0
b5 :2 0 fb :4 0
8e0 fdc fde :3 0
b5 :2 0 fc :3 0
fd :3 0 46 :2 0
fe :2 0 8e3 fe1
fe5 8e7 fe0 fe7
:3 0 8ea fc9 fe9
:2 0 feb 8ed fec
fc6 feb 0 fed
8ef 0 fee 8f1
ff1 :3 0 ff1 0
ff1 ff0 fee fef
:6 0 ff3 12 :3 0
8f4 ff5 8f6 ff4
ff3 :2 0 ff6 8f8
:2 0 ff8 0 ff8
ff7 fae ff6 :6 0
1087 1 :3 0 21
:3 0 f4 :3 0 ffa
ffb 0 21 :3 0
c3 :2 0 ff :3 0
ffd fff 0 8fc
ffe 1001 :3 0 1002
:2 0 ad :3 0 ae
:3 0 1004 1005 0
ad :3 0 bd :3 0
1007 1008 0 24
:2 0 2 :4 0 15d
:2 0 bf :2 0 46
:2 0 8ff 100d 100f
:3 0 902 1009 1011
1006 1013 1012 :2 0
b0 :3 0 c0 :3 0
1015 1016 0 b2
:4 0 15e :4 0 b5
:2 0 b6 :3 0 906
101a 101c :3 0 b5
:2 0 c9 :4 0 909
101e 1020 :3 0 b5
:2 0 ca :4 0 90c
1022 1024 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 14a
:3 0 1029 102a 0
90f 1028 102c bb
:4 0 911 1027 102f
914 1026 1031 :3 0
b5 :2 0 11f :4 0
917 1033 1035 :3 0
b5 :2 0 b8 :4 0
91a 1037 1039 :3 0
b5 :2 0 25 :3 0
91d 103b 103d :3 0
b5 :2 0 b8 :4 0
920 103f 1041 :3 0
923 1017 1043 :2 0
1045 926 1046 1014
1045 0 1047 928
0 1071 ad :3 0
ae :3 0 1048 1049
0 ad :3 0 bd
:3 0 104b 104c 0
46 :2 0 2 :4 0
15f :2 0 bf :2 0
46 :2 0 92a 1051
1053 :3 0 92d 104d
1055 104a 1057 1056
:2 0 b0 :3 0 c0
:3 0 1059 105a 0
b2 :4 0 160 :4 0
b5 :2 0 b6 :3 0
931 105e 1060 :3 0
934 105b 1062 :2 0
1064 937 1065 1058
1064 0 1066 939
0 1071 ce :3 0
122 :3 0 1067 1068
0 c2 :3 0 14a
:3 0 106a 106b 0
25 :3 0 d0 :3 0
93b 1069 106f :2 0
1071 93f 1072 1003
1071 0 1073 943
0 1087 23 :3 0
de :2 0 945 1075
1076 :3 0 1077 :2 0
79 :3 0 c2 :3 0
129 :3 0 107a 107b
0 1079 107c 0
1084 4f :3 0 161
:3 0 4f :3 0 947
107f 1081 107e 1082
0 1084 949 1085
1078 1084 0 1086
94c 0 1087 94e
1088 ebf 1087 0
10f9 ad :3 0 ae
:3 0 1089 108a 0
ad :3 0 bd :3 0
108c 108d 0 24
:2 0 2 :4 0 162
:2 0 bf :2 0 46
:2 0 954 1092 1094
:3 0 957 108e 1096
108b 1098 1097 :2 0
b0 :3 0 c0 :3 0
109a 109b 0 b2
:4 0 163 :4 0 b5
:2 0 b6 :3 0 95b
109f 10a1 :3 0 b5
:2 0 c9 :4 0 95e
10a3 10a5 :3 0 b5
:2 0 ca :4 0 961
10a7 10a9 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 d6
:3 0 10ae 10af 0
964 10ad 10b1 bb
:4 0 966 10ac 10b4
969 10ab 10b6 :3 0
b5 :2 0 11f :4 0
96c 10b8 10ba :3 0
b5 :2 0 b8 :4 0
96f 10bc 10be :3 0
b5 :2 0 25 :3 0
972 10c0 10c2 :3 0
b5 :2 0 b8 :4 0
975 10c4 10c6 :3 0
978 109c 10c8 :2 0
10ca 97b 10cb 1099
10ca 0 10cc 97d
0 10f6 ad :3 0
ae :3 0 10cd 10ce
0 ad :3 0 bd
:3 0 10d0 10d1 0
46 :2 0 2 :4 0
164 :2 0 bf :2 0
46 :2 0 97f 10d6
10d8 :3 0 982 10d2
10da 10cf 10dc 10db
:2 0 b0 :3 0 c0
:3 0 10de 10df 0
b2 :4 0 165 :4 0
b5 :2 0 b6 :3 0
986 10e3 10e5 :3 0
989 10e0 10e7 :2 0
10e9 98c 10ea 10dd
10e9 0 10eb 98e
0 10f6 ce :3 0
122 :3 0 10ec 10ed
0 c2 :3 0 d6
:3 0 10ef 10f0 0
25 :3 0 d0 :3 0
990 10ee 10f4 :2 0
10f6 994 10f8 d4f
eb4 0 10f9 0
10f6 0 10f9 998
0 129a a1 :3 0
5b :3 0 4d :2 0
99c 10fa 10fd c2
:3 0 c3 :2 0 d3
:3 0 10ff 1101 0
9a1 1100 1103 :3 0
166 :3 0 f0 :3 0
167 :3 0 41 :3 0
168 :3 0 a1 :3 0
f0 :3 0 167 :3 0
169 :3 0 a1 :3 0
f0 :3 0 167 :3 0
16a :3 0 4a :3 0
6c :3 0 70 :3 0
6d :3 0 6e :3 0
16b :3 0 9a :3 0
39 :4 0 16c 1
:8 0 1120 21 :3 0
f4 :3 0 111b 111c
0 f5 :3 0 111d
111e 0 1120 9a4
116a f6 :3 0 21
:3 0 f4 :3 0 1123
1124 0 f5 :3 0
1125 1126 0 1160
ad :3 0 ae :3 0
1128 1129 0 ad
:3 0 bd :3 0 112b
112c 0 f7 :2 0
2 :4 0 16d :2 0
bf :2 0 46 :2 0
9a7 1131 1133 :3 0
9aa 112d 1135 112a
1137 1136 :2 0 b0
:3 0 c0 :3 0 1139
113a 0 b2 :4 0
16e :4 0 b5 :2 0
b6 :3 0 9ae 113e
1140 :3 0 b5 :2 0
c9 :4 0 9b1 1142
1144 :3 0 b5 :2 0
fa :4 0 9b4 1146
1148 :3 0 b5 :2 0
f5 :3 0 9b7 114a
114c :3 0 b5 :2 0
fb :4 0 9ba 114e
1150 :3 0 b5 :2 0
fc :3 0 fd :3 0
46 :2 0 fe :2 0
9bd 1153 1157 9c1
1152 1159 :3 0 9c4
113b 115b :2 0 115d
9c7 115e 1138 115d
0 115f 9c9 0
1160 9cb 1163 :3 0
1163 0 1163 1162
1160 1161 :6 0 1165
14 :3 0 9ce 1167
9d0 1166 1165 :2 0
1168 9d2 :2 0 116a
0 116a 1169 1120
1168 :6 0 1297 1
:3 0 21 :3 0 f4
:3 0 116c 116d 0
21 :3 0 d2 :2 0
16f :3 0 116f 1171
0 9d6 1170 1173
:3 0 1174 :2 0 ad
:3 0 ae :3 0 1176
1177 0 ad :3 0
bd :3 0 1179 117a
0 24 :2 0 2
:4 0 170 :2 0 bf
:2 0 46 :2 0 9d9
117f 1181 :3 0 9dc
117b 1183 1178 1185
1184 :2 0 b0 :3 0
c0 :3 0 1187 1188
0 b2 :4 0 171
:4 0 b5 :2 0 b6
:3 0 9e0 118c 118e
:3 0 b5 :2 0 c9
:4 0 9e3 1190 1192
:3 0 b5 :2 0 ca
:4 0 9e6 1194 1196
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 14a :3 0 119b
119c 0 9e9 119a
119e bb :4 0 9eb
1199 11a1 9ee 1198
11a3 :3 0 b5 :2 0
11f :4 0 9f1 11a5
11a7 :3 0 b5 :2 0
b8 :4 0 9f4 11a9
11ab :3 0 b5 :2 0
39 :3 0 9f7 11ad
11af :3 0 b5 :2 0
b8 :4 0 9fa 11b1
11b3 :3 0 9fd 1189
11b5 :2 0 11b7 a00
11b8 1186 11b7 0
11b9 a02 0 11e4
ad :3 0 ae :3 0
11ba 11bb 0 ad
:3 0 bd :3 0 11bd
11be 0 46 :2 0
2 :4 0 172 :2 0
bf :2 0 46 :2 0
a04 11c3 11c5 :3 0
a07 11bf 11c7 11bc
11c9 11c8 :2 0 b0
:3 0 c0 :3 0 11cb
11cc 0 b2 :4 0
173 :4 0 b5 :2 0
b6 :3 0 a0b 11d0
11d2 :3 0 a0e 11cd
11d4 :2 0 11d6 a11
11d7 11ca 11d6 0
11d8 a13 0 11e4
ce :3 0 122 :3 0
11d9 11da 0 c2
:3 0 14a :3 0 11dc
11dd 0 39 :3 0
d0 :3 0 a15 11db
11e1 :2 0 11e4 d9
:3 0 a19 1295 21
:3 0 f4 :3 0 11e5
11e6 0 21 :3 0
d2 :2 0 ff :3 0
11e8 11ea 0 a1f
11e9 11ec :3 0 11ed
:2 0 fc :3 0 70
:3 0 46 :2 0 46
:2 0 a22 11ef 11f3
d2 :2 0 4d :4 0
a28 11f5 11f7 :3 0
a1 :3 0 6e :3 0
4d :2 0 a2b 11f9
11fc 10e :2 0 4d
:2 0 a30 11fe 1200
:3 0 a1 :3 0 6c
:3 0 4d :2 0 a33
1202 1205 a1 :3 0
10e :2 0 6e :3 0
4d :2 0 a36 1207
120b a3b 1208 120d
:3 0 1201 120f 120e
:2 0 1210 :2 0 11f8
1212 1211 :2 0 a1
:3 0 6c :3 0 4d
:2 0 a3e 1214 1217
a1 :3 0 e0 :2 0
6d :3 0 4d :2 0
a41 1219 121d a46
121a 121f :3 0 1213
1221 1220 :2 0 ad
:3 0 ae :3 0 1223
1224 0 ad :3 0
bd :3 0 1226 1227
0 24 :2 0 2
:4 0 174 :2 0 bf
:2 0 46 :2 0 a49
122c 122e :3 0 a4c
1228 1230 1225 1232
1231 :2 0 b0 :3 0
c0 :3 0 1234 1235
0 b2 :4 0 175
:4 0 b5 :2 0 b6
:3 0 a50 1239 123b
:3 0 b5 :2 0 c9
:4 0 a53 123d 123f
:3 0 b5 :2 0 ca
:4 0 a56 1241 1243
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 176 :3 0 1248
1249 0 a59 1247
124b bb :4 0 a5b
1246 124e a5e 1245
1250 :3 0 b5 :2 0
11f :4 0 a61 1252
1254 :3 0 b5 :2 0
b8 :4 0 a64 1256
1258 :3 0 b5 :2 0
39 :3 0 a67 125a
125c :3 0 b5 :2 0
b8 :4 0 a6a 125e
1260 :3 0 a6d 1236
1262 :2 0 1264 a70
1265 1233 1264 0
1266 a72 0 1290
ad :3 0 ae :3 0
1267 1268 0 ad
:3 0 bd :3 0 126a
126b 0 46 :2 0
2 :4 0 177 :2 0
bf :2 0 46 :2 0
a74 1270 1272 :3 0
a77 126c 1274 1269
1276 1275 :2 0 b0
:3 0 c0 :3 0 1278
1279 0 b2 :4 0
178 :4 0 b5 :2 0
b6 :3 0 a7b 127d
127f :3 0 a7e 127a
1281 :2 0 1283 a81
1284 1277 1283 0
1285 a83 0 1290
ce :3 0 122 :3 0
1286 1287 0 c2
:3 0 176 :3 0 1289
128a 0 39 :3 0
d0 :3 0 a85 1288
128e :2 0 1290 a89
1291 1222 1290 0
1292 a8d 0 1293
a8f 1294 11ee 1293
0 1296 1175 11e4
0 1296 a91 0
1297 a94 1298 1104
1297 0 1299 a97
0 129a a99 129b
a10 129a 0 129c
aa6 0 355e a1
:3 0 4f :3 0 4d
:2 0 aa8 129d 12a0
d2 :2 0 4d :2 0
aad 12a2 12a4 :3 0
a1 :3 0 5b :3 0
4d :2 0 ab0 12a6
12a9 c2 :3 0 d2
:2 0 d3 :3 0 12ab
12ad 0 ab5 12ac
12af :3 0 16 :3 0
c5 :2 0 ab8 12b2
12b3 :3 0 12b4 :2 0
12b0 12b6 12b5 :2 0
a1 :3 0 6a :3 0
4d :2 0 aba 12b8
12bb d2 :2 0 4d
:2 0 abf 12bd 12bf
:3 0 12b7 12c1 12c0
:2 0 ad :3 0 ae
:3 0 12c3 12c4 0
ad :3 0 bd :3 0
12c6 12c7 0 24
:2 0 2 :4 0 179
:2 0 bf :2 0 46
:2 0 ac2 12cc 12ce
:3 0 ac5 12c8 12d0
12c5 12d2 12d1 :2 0
b0 :3 0 c0 :3 0
12d4 12d5 0 b2
:4 0 17a :4 0 b5
:2 0 b6 :3 0 ac9
12d9 12db :3 0 b5
:2 0 c9 :4 0 acc
12dd 12df :3 0 b5
:2 0 ca :4 0 acf
12e1 12e3 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 17b
:3 0 12e8 12e9 0
ad2 12e7 12eb bb
:4 0 ad4 12e6 12ee
ad7 12e5 12f0 :3 0
b5 :2 0 11f :4 0
ada 12f2 12f4 :3 0
b5 :2 0 b8 :4 0
add 12f6 12f8 :3 0
b5 :2 0 25 :3 0
ae0 12fa 12fc :3 0
b5 :2 0 b8 :4 0
ae3 12fe 1300 :3 0
ae6 12d6 1302 :2 0
1304 ae9 1305 12d3
1304 0 1306 aeb
0 1330 ad :3 0
ae :3 0 1307 1308
0 ad :3 0 bd
:3 0 130a 130b 0
46 :2 0 2 :4 0
17c :2 0 bf :2 0
46 :2 0 aed 1310
1312 :3 0 af0 130c
1314 1309 1316 1315
:2 0 b0 :3 0 c0
:3 0 1318 1319 0
b2 :4 0 17d :4 0
b5 :2 0 b6 :3 0
af4 131d 131f :3 0
af7 131a 1321 :2 0
1323 afa 1324 1317
1323 0 1325 afc
0 1330 ce :3 0
122 :3 0 1326 1327
0 c2 :3 0 17b
:3 0 1329 132a 0
25 :3 0 d0 :3 0
afe 1328 132e :2 0
1330 b02 1331 12c2
1330 0 1332 b06
0 147c a1 :3 0
4c :3 0 4d :2 0
b08 1333 1336 c2
:3 0 c3 :2 0 c4
:3 0 1338 133a 0
b0d 1339 133c :3 0
13a :3 0 a1 :3 0
138 :3 0 a1 :3 0
139 :3 0 63 :3 0
5e :3 0 5f :3 0
115 :3 0 116 :3 0
25 :4 0 17e 1
:8 0 134f 21 :3 0
f4 :3 0 134a 134b
0 f5 :3 0 134c
134d 0 134f b10
1399 f6 :3 0 21
:3 0 f4 :3 0 1352
1353 0 f5 :3 0
1354 1355 0 138f
ad :3 0 ae :3 0
1357 1358 0 ad
:3 0 bd :3 0 135a
135b 0 f7 :2 0
2 :4 0 17f :2 0
bf :2 0 46 :2 0
b13 1360 1362 :3 0
b16 135c 1364 1359
1366 1365 :2 0 b0
:3 0 c0 :3 0 1368
1369 0 b2 :4 0
180 :4 0 b5 :2 0
b6 :3 0 b1a 136d
136f :3 0 b5 :2 0
c9 :4 0 b1d 1371
1373 :3 0 b5 :2 0
fa :4 0 b20 1375
1377 :3 0 b5 :2 0
f5 :3 0 b23 1379
137b :3 0 b5 :2 0
fb :4 0 b26 137d
137f :3 0 b5 :2 0
fc :3 0 fd :3 0
46 :2 0 fe :2 0
b29 1382 1386 b2d
1381 1388 :3 0 b30
136a 138a :2 0 138c
b33 138d 1367 138c
0 138e b35 0
138f b37 1392 :3 0
1392 0 1392 1391
138f 1390 :6 0 1394
16 :3 0 b3a 1396
b3c 1395 1394 :2 0
1397 b3e :2 0 1399
0 1399 1398 134f
1397 :6 0 1479 1
:3 0 21 :3 0 f4
:3 0 139b 139c 0
21 :3 0 d2 :2 0
16f :3 0 139e 13a0
0 b42 139f 13a2
:3 0 13a3 :2 0 5e
:3 0 5f :3 0 181
:3 0 116 :3 0 25
:4 0 182 1 :8 0
13b0 21 :3 0 f4
:3 0 13ab 13ac 0
f5 :3 0 13ad 13ae
0 13b0 b45 13fa
f6 :3 0 21 :3 0
f4 :3 0 13b3 13b4
0 f5 :3 0 13b5
13b6 0 13f0 ad
:3 0 ae :3 0 13b8
13b9 0 ad :3 0
bd :3 0 13bb 13bc
0 f7 :2 0 2
:4 0 183 :2 0 bf
:2 0 46 :2 0 b48
13c1 13c3 :3 0 b4b
13bd 13c5 13ba 13c7
13c6 :2 0 b0 :3 0
c0 :3 0 13c9 13ca
0 b2 :4 0 184
:4 0 b5 :2 0 b6
:3 0 b4f 13ce 13d0
:3 0 b5 :2 0 c9
:4 0 b52 13d2 13d4
:3 0 b5 :2 0 fa
:4 0 b55 13d6 13d8
:3 0 b5 :2 0 f5
:3 0 b58 13da 13dc
:3 0 b5 :2 0 fb
:4 0 b5b 13de 13e0
:3 0 b5 :2 0 fc
:3 0 fd :3 0 46
:2 0 fe :2 0 b5e
13e3 13e7 b62 13e2
13e9 :3 0 b65 13cb
13eb :2 0 13ed b68
13ee 13c8 13ed 0
13ef b6a 0 13f0
b6c 13f3 :3 0 13f3
0 13f3 13f2 13f0
13f1 :6 0 13f5 18
:3 0 b6f 13f7 b71
13f6 13f5 :2 0 13f8
b73 :2 0 13fa 0
13fa 13f9 13b0 13f8
:6 0 1476 1 :3 0
21 :3 0 f4 :3 0
13fc 13fd 0 21
:3 0 d2 :2 0 16f
:3 0 13ff 1401 0
b77 1400 1403 :3 0
1404 :2 0 ad :3 0
ae :3 0 1406 1407
0 ad :3 0 bd
:3 0 1409 140a 0
24 :2 0 2 :4 0
185 :2 0 bf :2 0
46 :2 0 b7a 140f
1411 :3 0 b7d 140b
1413 1408 1415 1414
:2 0 b0 :3 0 c0
:3 0 1417 1418 0
b2 :4 0 186 :4 0
b5 :2 0 b6 :3 0
b81 141c 141e :3 0
b5 :2 0 c9 :4 0
b84 1420 1422 :3 0
b5 :2 0 ca :4 0
b87 1424 1426 :3 0
b5 :2 0 a1 :3 0
ba :3 0 c2 :3 0
d6 :3 0 142b 142c
0 b8a 142a 142e
bb :4 0 b8c 1429
1431 b8f 1428 1433
:3 0 b5 :2 0 11f
:4 0 b92 1435 1437
:3 0 b5 :2 0 b8
:4 0 b95 1439 143b
:3 0 b5 :2 0 25
:3 0 b98 143d 143f
:3 0 b5 :2 0 b8
:4 0 b9b 1441 1443
:3 0 b9e 1419 1445
:2 0 1447 ba1 1448
1416 1447 0 1449
ba3 0 1473 ad
:3 0 ae :3 0 144a
144b 0 ad :3 0
bd :3 0 144d 144e
0 46 :2 0 2
:4 0 187 :2 0 bf
:2 0 46 :2 0 ba5
1453 1455 :3 0 ba8
144f 1457 144c 1459
1458 :2 0 b0 :3 0
c0 :3 0 145b 145c
0 b2 :4 0 188
:4 0 b5 :2 0 b6
:3 0 bac 1460 1462
:3 0 baf 145d 1464
:2 0 1466 bb2 1467
145a 1466 0 1468
bb4 0 1473 ce
:3 0 122 :3 0 1469
146a 0 c2 :3 0
d6 :3 0 146c 146d
0 25 :3 0 d0
:3 0 bb6 146b 1471
:2 0 1473 bba 1474
1405 1473 0 1475
bbe 0 1476 bc0
1477 13a4 1476 0
1478 bc3 0 1479
bc5 147a 133d 1479
0 147b bc8 0
147c bca 147d 12a5
147c 0 147e bcd
0 355e a1 :3 0
d :3 0 4d :2 0
bcf 147f 1482 d2
:2 0 4d :2 0 bd4
1484 1486 :3 0 a1
:3 0 5a :3 0 4d
:2 0 bd7 1488 148b
c3 :2 0 189 :2 0
bdc 148d 148f :3 0
1487 1491 1490 :2 0
56 :3 0 4d :2 0
1493 1494 0 1496
bdf 1497 1492 1496
0 1498 be1 0
355e a1 :3 0 4c
:3 0 4d :2 0 be3
1499 149c c2 :3 0
d2 :2 0 c4 :3 0
149e 14a0 0 be8
149f 14a2 :3 0 5
:3 0 c5 :2 0 beb
14a5 14a6 :3 0 14a7
:2 0 41 :3 0 18a
:4 0 14a9 14aa 0
14af 42 :3 0 18a
:4 0 14ac 14ad 0
14af bed 14b7 41
:3 0 5 :3 0 14b0
14b1 0 14b6 42
:3 0 5 :3 0 14b3
14b4 0 14b6 bf0
14b8 14a8 14af 0
14b9 0 14b6 0
14b9 bf3 0 14bd
58 :3 0 4d :2 0
14ba 14bb 0 14bd
bf6 1653 89 :3 0
d2 :2 0 4d :2 0
bfb 14bf 14c1 :3 0
42 :3 0 18b :4 0
14c3 14c4 0 15db
82 :3 0 18c :3 0
41 :3 0 42 :3 0
a1 :3 0 59 :3 0
4d :2 0 bfe 14ca
14cd a1 :3 0 5a
:3 0 4d :2 0 c01
14cf 14d2 a1 :3 0
5b :3 0 4d :2 0
c04 14d4 14d7 a1
:3 0 4c :3 0 4d
:2 0 c07 14d9 14dc
a1 :3 0 5c :3 0
4d :2 0 c0a 14de
14e1 a1 :3 0 57
:3 0 4d :2 0 c0d
14e3 14e6 a1 :3 0
5e :3 0 4d :2 0
c10 14e8 14eb a1
:3 0 5f :3 0 4d
:2 0 c13 14ed 14f0
56 :3 0 58 :3 0
60 :3 0 c16 14c7
14f5 14c6 14f6 0
15db a1 :3 0 82
:3 0 4d :2 0 c24
14f8 14fb c2 :3 0
d2 :2 0 d6 :3 0
14fd 14ff 0 c29
14fe 1501 :3 0 ad
:3 0 ae :3 0 1503
1504 0 ad :3 0
bd :3 0 1506 1507
0 c6 :2 0 2
:4 0 18d :2 0 bf
:2 0 46 :2 0 c2c
150c 150e :3 0 c2f
1508 1510 1505 1512
1511 :2 0 b0 :3 0
c0 :3 0 1514 1515
0 b2 :4 0 18e
:4 0 b5 :2 0 b6
:3 0 c33 1519 151b
:3 0 b5 :2 0 c9
:4 0 c36 151d 151f
:3 0 b5 :2 0 ca
:4 0 c39 1521 1523
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 d6 :3 0 1528
1529 0 c3c 1527
152b bb :4 0 c3e
1526 152e c41 1525
1530 :3 0 c44 1516
1532 :2 0 1534 c47
1535 1513 1534 0
1536 c49 0 1560
ad :3 0 ae :3 0
1537 1538 0 ad
:3 0 bd :3 0 153a
153b 0 46 :2 0
2 :4 0 18f :2 0
bf :2 0 46 :2 0
c4b 1540 1542 :3 0
c4e 153c 1544 1539
1546 1545 :2 0 b0
:3 0 c0 :3 0 1548
1549 0 b2 :4 0
190 :4 0 b5 :2 0
b6 :3 0 c52 154d
154f :3 0 c55 154a
1551 :2 0 1553 c58
1554 1547 1553 0
1555 c5a 0 1560
ce :3 0 cf :3 0
1556 1557 0 c2
:3 0 d6 :3 0 1559
155a 0 d0 :3 0
c5c 1558 155d :2 0
1560 d9 :3 0 c5f
15d9 a1 :3 0 82
:3 0 4d :2 0 c63
1561 1564 c3 :2 0
4d :2 0 c68 1566
1568 :3 0 ad :3 0
ae :3 0 156a 156b
0 ad :3 0 bd
:3 0 156d 156e 0
24 :2 0 2 :4 0
191 :2 0 bf :2 0
46 :2 0 c6b 1573
1575 :3 0 c6e 156f
1577 156c 1579 1578
:2 0 b0 :3 0 c0
:3 0 157b 157c 0
b2 :4 0 192 :4 0
b5 :2 0 b6 :3 0
c72 1580 1582 :3 0
b5 :2 0 c9 :4 0
c75 1584 1586 :3 0
b5 :2 0 ca :4 0
c78 1588 158a :3 0
b5 :2 0 a1 :3 0
ba :3 0 82 :3 0
c7b 158e 1590 bb
:4 0 c7d 158d 1593
c80 158c 1595 :3 0
b5 :2 0 11f :4 0
c83 1597 1599 :3 0
b5 :2 0 b8 :4 0
c86 159b 159d :3 0
b5 :2 0 25 :3 0
c89 159f 15a1 :3 0
b5 :2 0 b8 :4 0
c8c 15a3 15a5 :3 0
c8f 157d 15a7 :2 0
15a9 c92 15aa 157a
15a9 0 15ab c94
0 15d7 ad :3 0
ae :3 0 15ac 15ad
0 ad :3 0 bd
:3 0 15af 15b0 0
46 :2 0 2 :4 0
193 :2 0 bf :2 0
46 :2 0 c96 15b5
15b7 :3 0 c99 15b1
15b9 15ae 15bb 15ba
:2 0 b0 :3 0 c0
:3 0 15bd 15be 0
b2 :4 0 194 :4 0
b5 :2 0 b6 :3 0
c9d 15c2 15c4 :3 0
ca0 15bf 15c6 :2 0
15c8 ca3 15c9 15bc
15c8 0 15ca ca5
0 15d7 ce :3 0
122 :3 0 15cb 15cc
0 a1 :3 0 82
:3 0 4d :2 0 ca7
15ce 15d1 25 :3 0
d0 :3 0 caa 15cd
15d5 :2 0 15d7 cae
15d8 1569 15d7 0
15da 1502 1560 0
15da cb2 0 15db
cb5 15e0 42 :3 0
6 :3 0 15dc 15dd
0 15df cb9 15e1
14c2 15db 0 15e2
0 15df 0 15e2
cbb 0 1652 a1
:3 0 56 :3 0 4d
:2 0 cbe 15e3 15e6
10e :2 0 4d :2 0
cc3 15e8 15ea :3 0
15eb :2 0 a1 :3 0
5a :3 0 4d :2 0
cc6 15ed 15f0 c3
:2 0 189 :2 0 ccb
15f2 15f4 :3 0 15f5
:2 0 15ec 15f7 15f6
:2 0 a1 :3 0 5a
:3 0 4d :2 0 cce
15f9 15fc d2 :2 0
46 :2 0 cd3 15fe
1600 :3 0 1601 :2 0
a1 :3 0 5a :3 0
4d :2 0 cd6 1603
1606 d2 :2 0 195
:2 0 cdb 1608 160a
:3 0 160b :2 0 1602
160d 160c :2 0 59
:3 0 195 :2 0 160f
1610 0 1613 d9
:3 0 cde 164d a1
:3 0 5a :3 0 4d
:2 0 ce0 1614 1617
d2 :2 0 4d :2 0
ce5 1619 161b :3 0
59 :3 0 46 :2 0
161d 161e 0 1621
d9 :3 0 ce8 1622
161c 1621 0 164e
a1 :3 0 5a :3 0
4d :2 0 cea 1623
1626 d2 :2 0 196
:2 0 cef 1628 162a
:3 0 162b :2 0 a1
:3 0 5a :3 0 4d
:2 0 cf2 162d 1630
d2 :2 0 197 :2 0
cf7 1632 1634 :3 0
1635 :2 0 162c 1637
1636 :2 0 59 :3 0
46 :2 0 1639 163a
0 163d d9 :3 0
cfa 163e 1638 163d
0 164e a1 :3 0
5a :3 0 4d :2 0
cfc 163f 1642 d2
:2 0 ea :2 0 d01
1644 1646 :3 0 59
:3 0 196 :2 0 1648
1649 0 164b d04
164c 1647 164b 0
164e 160e 1613 0
164e d06 0 164f
d0b 1650 15f8 164f
0 1651 d0d 0
1652 d0f 1654 14a3
14bd 0 1655 0
1652 0 1655 d12
0 355e a1 :3 0
5b :3 0 4d :2 0
d15 1656 1659 c2
:3 0 d2 :2 0 d3
:3 0 165b 165d 0
d1a 165c 165f :3 0
8d :3 0 4d :2 0
1661 1662 0 1af8
2e :3 0 16 :3 0
1664 1665 0 1af8
30 :3 0 17 :3 0
1667 1668 0 1af8
48 :3 0 fc :3 0
2e :3 0 46 :2 0
24 :2 0 d1d 166b
166f 166a 1670 0
1af8 4b :4 0 1672
1673 0 1af8 a1
:3 0 6a :3 0 4d
:2 0 d21 1675 1678
d2 :2 0 4d :2 0
d26 167a 167c :3 0
39 :3 0 198 :4 0
167f 1680 :3 0 167e
1681 0 1686 8d
:3 0 46 :2 0 1683
1684 0 1686 d29
176a 114 :3 0 4b
:3 0 199 :3 0 19a
:3 0 39 :4 0 19b
1 :8 0 1692 21
:3 0 f4 :3 0 168d
168e 0 f5 :3 0
168f 1690 0 1692
d2c 16dc f6 :3 0
21 :3 0 f4 :3 0
1695 1696 0 f5
:3 0 1697 1698 0
16d2 ad :3 0 ae
:3 0 169a 169b 0
ad :3 0 bd :3 0
169d 169e 0 f7
:2 0 2 :4 0 19c
:2 0 bf :2 0 46
:2 0 d2f 16a3 16a5
:3 0 d32 169f 16a7
169c 16a9 16a8 :2 0
b0 :3 0 c0 :3 0
16ab 16ac 0 b2
:4 0 19d :4 0 b5
:2 0 b6 :3 0 d36
16b0 16b2 :3 0 b5
:2 0 c9 :4 0 d39
16b4 16b6 :3 0 b5
:2 0 fa :4 0 d3c
16b8 16ba :3 0 b5
:2 0 f5 :3 0 d3f
16bc 16be :3 0 b5
:2 0 fb :4 0 d42
16c0 16c2 :3 0 b5
:2 0 fc :3 0 fd
:3 0 46 :2 0 fe
:2 0 d45 16c5 16c9
d49 16c4 16cb :3 0
d4c 16ad 16cd :2 0
16cf d4f 16d0 16aa
16cf 0 16d1 d51
0 16d2 d53 16d5
:3 0 16d5 0 16d5
16d4 16d2 16d3 :6 0
16d7 1a :3 0 d56
16d9 d58 16d8 16d7
:2 0 16da d5a :2 0
16dc 0 16dc 16db
1692 16da :6 0 1769
1 :3 0 21 :3 0
f4 :3 0 16de 16df
0 21 :3 0 d2
:2 0 ff :3 0 16e1
16e3 0 d5e 16e2
16e5 :3 0 16e6 :2 0
a1 :3 0 4f :3 0
4d :2 0 d61 16e8
16eb 10e :2 0 4d
:2 0 d66 16ed 16ef
:3 0 19e :3 0 28
:3 0 19f :3 0 116
:3 0 26 :3 0 9a
:3 0 39 :3 0 1a0
:3 0 1a1 :3 0 c2
:3 0 1a2 :4 0 1a3
1 :8 0 1702 21
:3 0 f4 :3 0 16fd
16fe 0 f5 :3 0
16ff 1700 0 1702
d69 174c f6 :3 0
21 :3 0 f4 :3 0
1705 1706 0 f5
:3 0 1707 1708 0
1742 ad :3 0 ae
:3 0 170a 170b 0
ad :3 0 bd :3 0
170d 170e 0 f7
:2 0 2 :4 0 1a4
:2 0 bf :2 0 46
:2 0 d6c 1713 1715
:3 0 d6f 170f 1717
170c 1719 1718 :2 0
b0 :3 0 c0 :3 0
171b 171c 0 b2
:4 0 1a5 :4 0 b5
:2 0 b6 :3 0 d73
1720 1722 :3 0 b5
:2 0 c9 :4 0 d76
1724 1726 :3 0 b5
:2 0 fa :4 0 d79
1728 172a :3 0 b5
:2 0 f5 :3 0 d7c
172c 172e :3 0 b5
:2 0 fb :4 0 d7f
1730 1732 :3 0 b5
:2 0 fc :3 0 fd
:3 0 46 :2 0 fe
:2 0 d82 1735 1739
d86 1734 173b :3 0
d89 171d 173d :2 0
173f d8c 1740 171a
173f 0 1741 d8e
0 1742 d90 1745
:3 0 1745 0 1745
1744 1742 1743 :6 0
1747 1c :3 0 d93
1749 d95 1748 1747
:2 0 174a d97 :2 0
174c 0 174c 174b
1702 174a :6 0 175e
1 :3 0 21 :3 0
f4 :3 0 174e 174f
0 21 :3 0 d2
:2 0 ff :3 0 1751
1753 0 d9b 1752
1755 :3 0 1756 :2 0
8d :3 0 46 :2 0
1758 1759 0 175b
d9e 175c 1757 175b
0 175d da0 0
175e da2 175f 16f0
175e 0 1760 da5
0 1761 da7 1766
8d :3 0 46 :2 0
1762 1763 0 1765
da9 1767 16e7 1761
0 1768 0 1765
0 1768 dab 0
1769 dae 176b 167d
1686 0 176c 0
1769 0 176c db1
0 1af8 8d :3 0
c3 :2 0 4d :2 0
db6 176e 1770 :3 0
a1 :3 0 1a6 :3 0
1a7 :3 0 62 :3 0
199 :3 0 98 :3 0
25 :3 0 a0 :3 0
48 :4 0 1a8 1
:8 0 1781 21 :3 0
f4 :3 0 177c 177d
0 f5 :3 0 177e
177f 0 1781 db9
17cb f6 :3 0 21
:3 0 f4 :3 0 1784
1785 0 f5 :3 0
1786 1787 0 17c1
ad :3 0 ae :3 0
1789 178a 0 ad
:3 0 bd :3 0 178c
178d 0 f7 :2 0
2 :4 0 1a9 :2 0
bf :2 0 46 :2 0
dbc 1792 1794 :3 0
dbf 178e 1796 178b
1798 1797 :2 0 b0
:3 0 c0 :3 0 179a
179b 0 b2 :4 0
1aa :4 0 b5 :2 0
b6 :3 0 dc3 179f
17a1 :3 0 b5 :2 0
c9 :4 0 dc6 17a3
17a5 :3 0 b5 :2 0
fa :4 0 dc9 17a7
17a9 :3 0 b5 :2 0
f5 :3 0 dcc 17ab
17ad :3 0 b5 :2 0
fb :4 0 dcf 17af
17b1 :3 0 b5 :2 0
fc :3 0 fd :3 0
46 :2 0 fe :2 0
dd2 17b4 17b8 dd6
17b3 17ba :3 0 dd9
179c 17bc :2 0 17be
ddc 17bf 1799 17be
0 17c0 dde 0
17c1 de0 17c4 :3 0
17c4 0 17c4 17c3
17c1 17c2 :6 0 17c6
1e :3 0 de3 17c8
de5 17c7 17c6 :2 0
17c9 de7 :2 0 17cb
0 17cb 17ca 1781
17c9 :6 0 193f 1
:3 0 f0 :3 0 1ab
:3 0 f0 :3 0 1ab
:3 0 f0 :3 0 1ab
:3 0 f0 :3 0 1ab
:3 0 f0 :3 0 1ab
:3 0 9f :3 0 1ac
:3 0 1ad :3 0 9f
:3 0 1ae :3 0 1ad
:3 0 9f :3 0 ba
:3 0 62 :3 0 4a
:3 0 1af :3 0 1ae
:3 0 1af :3 0 1ac
:3 0 1ae :3 0 116
:3 0 48 :3 0 1ac
:3 0 116 :3 0 1ae
:3 0 1b0 :4 0 1b1
1 :8 0 17f2 21
:3 0 f4 :3 0 17ed
17ee 0 f5 :3 0
17ef 17f0 0 17f2
de9 183c f6 :3 0
21 :3 0 f4 :3 0
17f5 17f6 0 f5
:3 0 17f7 17f8 0
1832 ad :3 0 ae
:3 0 17fa 17fb 0
ad :3 0 bd :3 0
17fd 17fe 0 f7
:2 0 2 :4 0 1b2
:2 0 bf :2 0 46
:2 0 dec 1803 1805
:3 0 def 17ff 1807
17fc 1809 1808 :2 0
b0 :3 0 c0 :3 0
180b 180c 0 b2
:4 0 1b3 :4 0 b5
:2 0 b6 :3 0 df3
1810 1812 :3 0 b5
:2 0 c9 :4 0 df6
1814 1816 :3 0 b5
:2 0 fa :4 0 df9
1818 181a :3 0 b5
:2 0 f5 :3 0 dfc
181c 181e :3 0 b5
:2 0 fb :4 0 dff
1820 1822 :3 0 b5
:2 0 fc :3 0 fd
:3 0 46 :2 0 fe
:2 0 e02 1825 1829
e06 1824 182b :3 0
e09 180d 182d :2 0
182f e0c 1830 180a
182f 0 1831 e0e
0 1832 e10 1835
:3 0 1835 0 1835
1834 1832 1833 :6 0
1837 20 :3 0 e13
1839 e15 1838 1837
:2 0 183a e17 :2 0
183c 0 183c 183b
17f2 183a :6 0 193f
1 :3 0 21 :3 0
f4 :3 0 183e 183f
0 21 :3 0 d2
:2 0 16f :3 0 1841
1843 0 e1b 1842
1845 :3 0 1846 :2 0
ad :3 0 ae :3 0
1848 1849 0 ad
:3 0 bd :3 0 184b
184c 0 24 :2 0
2 :4 0 1b4 :2 0
bf :2 0 46 :2 0
e1e 1851 1853 :3 0
e21 184d 1855 184a
1857 1856 :2 0 b0
:3 0 c0 :3 0 1859
185a 0 b2 :4 0
1b5 :4 0 b5 :2 0
b6 :3 0 e25 185e
1860 :3 0 b5 :2 0
c9 :4 0 e28 1862
1864 :3 0 b5 :2 0
ca :4 0 e2b 1866
1868 :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 14a :3 0
186d 186e 0 e2e
186c 1870 bb :4 0
e30 186b 1873 e33
186a 1875 :3 0 b5
:2 0 11f :4 0 e36
1877 1879 :3 0 b5
:2 0 b8 :4 0 e39
187b 187d :3 0 b5
:2 0 48 :3 0 e3c
187f 1881 :3 0 b5
:2 0 b8 :4 0 e3f
1883 1885 :3 0 e42
185b 1887 :2 0 1889
e45 188a 1858 1889
0 188b e47 0
18b5 ad :3 0 ae
:3 0 188c 188d 0
ad :3 0 bd :3 0
188f 1890 0 46
:2 0 2 :4 0 1b6
:2 0 bf :2 0 46
:2 0 e49 1895 1897
:3 0 e4c 1891 1899
188e 189b 189a :2 0
b0 :3 0 c0 :3 0
189d 189e 0 b2
:4 0 1b7 :4 0 b5
:2 0 b6 :3 0 e50
18a2 18a4 :3 0 e53
189f 18a6 :2 0 18a8
e56 18a9 189c 18a8
0 18aa e58 0
18b5 ce :3 0 122
:3 0 18ab 18ac 0
c2 :3 0 14a :3 0
18ae 18af 0 48
:3 0 d0 :3 0 e5a
18ad 18b3 :2 0 18b5
e5e 18b6 1847 18b5
0 18b7 e62 0
193f 81 :3 0 a1
:3 0 4f :3 0 4d
:2 0 e64 18b9 18bc
10e :2 0 4d :2 0
e69 18be 18c0 :3 0
1b8 :4 0 e6c 18c3
18c2 1b9 :5 0 18c5
0 e6e :2 0 18b8
18c7 0 193f 199
:3 0 19a :3 0 98
:3 0 a0 :3 0 1a7
:3 0 1ba :3 0 114
:3 0 1bb :3 0 1bc
:3 0 1bd :3 0 39
:3 0 25 :3 0 48
:3 0 62 :3 0 4a
:3 0 81 :3 0 14
:3 0 13 :3 0 12
:4 0 1be 1 :8 0
18f2 1bf :4 0 18dd
:3 0 d0 :3 0 d2
:2 0 e73 18e0 18e1
:3 0 21 :3 0 f4
:3 0 18e3 18e4 0
4d :2 0 18e5 18e6
0 18e8 e76 18ef
21 :3 0 f4 :3 0
18e9 18ea 0 189
:2 0 18eb 18ec 0
18ee e78 18f0 18e2
18e8 0 18f1 0
18ee 0 18f1 e7a
0 18f2 e7d 193c
f6 :3 0 21 :3 0
f4 :3 0 18f5 18f6
0 f5 :3 0 18f7
18f8 0 1932 ad
:3 0 ae :3 0 18fa
18fb 0 ad :3 0
bd :3 0 18fd 18fe
0 f7 :2 0 2
:4 0 1c0 :2 0 bf
:2 0 46 :2 0 e80
1903 1905 :3 0 e83
18ff 1907 18fc 1909
1908 :2 0 b0 :3 0
c0 :3 0 190b 190c
0 b2 :4 0 1c1
:4 0 b5 :2 0 b6
:3 0 e87 1910 1912
:3 0 b5 :2 0 c9
:4 0 e8a 1914 1916
:3 0 b5 :2 0 fa
:4 0 e8d 1918 191a
:3 0 b5 :2 0 f5
:3 0 e90 191c 191e
:3 0 b5 :2 0 fb
:4 0 e93 1920 1922
:3 0 b5 :2 0 fc
:3 0 fd :3 0 46
:2 0 fe :2 0 e96
1925 1929 e9a 1924
192b :3 0 e9d 190d
192d :2 0 192f ea0
1930 190a 192f 0
1931 ea2 0 1932
ea4 1935 :3 0 1935
0 1935 1934 1932
1933 :6 0 1937 22
:3 0 ea7 1939 ea9
1938 1937 :2 0 193a
eab :2 0 193c 0
193c 193b 18f2 193a
:6 0 193f 1 :3 0
d9 :3 0 ead 19b8
fc :3 0 4b :3 0
46 :2 0 46 :2 0
eb3 1940 1944 d2
:2 0 1b9 :4 0 eb9
1946 1948 :3 0 199
:3 0 114 :3 0 1bb
:3 0 14 :3 0 1bc
:3 0 13 :3 0 1bd
:3 0 12 :3 0 19a
:3 0 39 :4 0 1c2
1 :8 0 196a 1bf
:4 0 1955 :3 0 d0
:3 0 d2 :2 0 ebe
1958 1959 :3 0 21
:3 0 f4 :3 0 195b
195c 0 4d :2 0
195d 195e 0 1960
ec1 1967 21 :3 0
f4 :3 0 1961 1962
0 189 :2 0 1963
1964 0 1966 ec3
1968 195a 1960 0
1969 0 1966 0
1969 ec5 0 196a
ec8 19b4 f6 :3 0
21 :3 0 f4 :3 0
196d 196e 0 f5
:3 0 196f 1970 0
19aa ad :3 0 ae
:3 0 1972 1973 0
ad :3 0 bd :3 0
1975 1976 0 f7
:2 0 2 :4 0 1c3
:2 0 bf :2 0 46
:2 0 ecb 197b 197d
:3 0 ece 1977 197f
1974 1981 1980 :2 0
b0 :3 0 c0 :3 0
1983 1984 0 b2
:4 0 1c4 :4 0 b5
:2 0 b6 :3 0 ed2
1988 198a :3 0 b5
:2 0 c9 :4 0 ed5
198c 198e :3 0 b5
:2 0 fa :4 0 ed8
1990 1992 :3 0 b5
:2 0 f5 :3 0 edb
1994 1996 :3 0 b5
:2 0 fb :4 0 ede
1998 199a :3 0 b5
:2 0 fc :3 0 fd
:3 0 46 :2 0 fe
:2 0 ee1 199d 19a1
ee5 199c 19a3 :3 0
ee8 1985 19a5 :2 0
19a7 eeb 19a8 1982
19a7 0 19a9 eed
0 19aa eef 19ad
:3 0 19ad 0 19ad
19ac 19aa 19ab :6 0
19af 24 :3 0 ef2
19b1 ef4 19b0 19af
:2 0 19b2 ef6 :2 0
19b4 0 19b4 19b3
196a 19b2 :6 0 19b6
1 :3 0 ef8 19b7
1949 19b6 0 19b9
1771 193f 0 19b9
efa 0 1af8 1c5
:3 0 19e :3 0 19a
:3 0 199 :3 0 98
:3 0 25 :3 0 114
:3 0 19a :3 0 39
:4 0 1c6 1 :8 0
19d9 1bf :4 0 19c4
:3 0 d0 :3 0 d2
:2 0 eff 19c7 19c8
:3 0 21 :3 0 f4
:3 0 19ca 19cb 0
4d :2 0 19cc 19cd
0 19cf f02 19d6
21 :3 0 f4 :3 0
19d0 19d1 0 189
:2 0 19d2 19d3 0
19d5 f04 19d7 19c9
19cf 0 19d8 0
19d5 0 19d8 f06
0 19d9 f09 1a23
f6 :3 0 21 :3 0
f4 :3 0 19dc 19dd
0 f5 :3 0 19de
19df 0 1a19 ad
:3 0 ae :3 0 19e1
19e2 0 ad :3 0
bd :3 0 19e4 19e5
0 f7 :2 0 2
:4 0 1c7 :2 0 bf
:2 0 46 :2 0 f0c
19ea 19ec :3 0 f0f
19e6 19ee 19e3 19f0
19ef :2 0 b0 :3 0
c0 :3 0 19f2 19f3
0 b2 :4 0 1c8
:4 0 b5 :2 0 b6
:3 0 f13 19f7 19f9
:3 0 b5 :2 0 c9
:4 0 f16 19fb 19fd
:3 0 b5 :2 0 fa
:4 0 f19 19ff 1a01
:3 0 b5 :2 0 f5
:3 0 f1c 1a03 1a05
:3 0 b5 :2 0 fb
:4 0 f1f 1a07 1a09
:3 0 b5 :2 0 fc
:3 0 fd :3 0 46
:2 0 fe :2 0 f22
1a0c 1a10 f26 1a0b
1a12 :3 0 f29 19f4
1a14 :2 0 1a16 f2c
1a17 19f1 1a16 0
1a18 f2e 0 1a19
f30 1a1c :3 0 1a1c
0 1a1c 1a1b 1a19
1a1a :6 0 1a1e 26
:3 0 f33 1a20 f35
1a1f 1a1e :2 0 1a21
f37 :2 0 1a23 0
1a23 1a22 19d9 1a21
:6 0 1af8 1 :3 0
1c9 :3 0 19e :3 0
19a :3 0 199 :3 0
98 :3 0 25 :3 0
114 :3 0 19a :3 0
39 :4 0 1ca 1
:8 0 1a44 1bf :4 0
1a2f :3 0 d0 :3 0
d2 :2 0 f3b 1a32
1a33 :3 0 21 :3 0
f4 :3 0 1a35 1a36
0 4d :2 0 1a37
1a38 0 1a3a f3e
1a41 21 :3 0 f4
:3 0 1a3b 1a3c 0
189 :2 0 1a3d 1a3e
0 1a40 f40 1a42
1a34 1a3a 0 1a43
0 1a40 0 1a43
f42 0 1a44 f45
1a8e f6 :3 0 21
:3 0 f4 :3 0 1a47
1a48 0 f5 :3 0
1a49 1a4a 0 1a84
ad :3 0 ae :3 0
1a4c 1a4d 0 ad
:3 0 bd :3 0 1a4f
1a50 0 f7 :2 0
2 :4 0 1cb :2 0
bf :2 0 46 :2 0
f48 1a55 1a57 :3 0
f4b 1a51 1a59 1a4e
1a5b 1a5a :2 0 b0
:3 0 c0 :3 0 1a5d
1a5e 0 b2 :4 0
1cc :4 0 b5 :2 0
b6 :3 0 f4f 1a62
1a64 :3 0 b5 :2 0
c9 :4 0 f52 1a66
1a68 :3 0 b5 :2 0
fa :4 0 f55 1a6a
1a6c :3 0 b5 :2 0
f5 :3 0 f58 1a6e
1a70 :3 0 b5 :2 0
fb :4 0 f5b 1a72
1a74 :3 0 b5 :2 0
fc :3 0 fd :3 0
46 :2 0 fe :2 0
f5e 1a77 1a7b f62
1a76 1a7d :3 0 f65
1a5f 1a7f :2 0 1a81
f68 1a82 1a5c 1a81
0 1a83 f6a 0
1a84 f6c 1a87 :3 0
1a87 0 1a87 1a86
1a84 1a85 :6 0 1a89
28 :3 0 f6f 1a8b
f71 1a8a 1a89 :2 0
1a8c f73 :2 0 1a8e
0 1a8e 1a8d 1a44
1a8c :6 0 1af8 1
:3 0 199 :3 0 98
:3 0 25 :3 0 114
:3 0 19a :3 0 39
:4 0 1cd 1 :8 0
1aac 1bf :4 0 1a97
:3 0 d0 :3 0 d2
:2 0 f77 1a9a 1a9b
:3 0 21 :3 0 f4
:3 0 1a9d 1a9e 0
4d :2 0 1a9f 1aa0
0 1aa2 f7a 1aa9
21 :3 0 f4 :3 0
1aa3 1aa4 0 189
:2 0 1aa5 1aa6 0
1aa8 f7c 1aaa 1a9c
1aa2 0 1aab 0
1aa8 0 1aab f7e
0 1aac f81 1af6
f6 :3 0 21 :3 0
f4 :3 0 1aaf 1ab0
0 f5 :3 0 1ab1
1ab2 0 1aec ad
:3 0 ae :3 0 1ab4
1ab5 0 ad :3 0
bd :3 0 1ab7 1ab8
0 f7 :2 0 2
:4 0 1ce :2 0 bf
:2 0 46 :2 0 f84
1abd 1abf :3 0 f87
1ab9 1ac1 1ab6 1ac3
1ac2 :2 0 b0 :3 0
c0 :3 0 1ac5 1ac6
0 b2 :4 0 1cf
:4 0 b5 :2 0 b6
:3 0 f8b 1aca 1acc
:3 0 b5 :2 0 c9
:4 0 f8e 1ace 1ad0
:3 0 b5 :2 0 fa
:4 0 f91 1ad2 1ad4
:3 0 b5 :2 0 f5
:3 0 f94 1ad6 1ad8
:3 0 b5 :2 0 fb
:4 0 f97 1ada 1adc
:3 0 b5 :2 0 fc
:3 0 fd :3 0 46
:2 0 fe :2 0 f9a
1adf 1ae3 f9e 1ade
1ae5 :3 0 fa1 1ac7
1ae7 :2 0 1ae9 fa4
1aea 1ac4 1ae9 0
1aeb fa6 0 1aec
fa8 1aef :3 0 1aef
0 1aef 1aee 1aec
1aed :6 0 1af1 2a
:3 0 fab 1af3 fad
1af2 1af1 :2 0 1af4
faf :2 0 1af6 0
1af6 1af5 1aac 1af4
:6 0 1af8 1 :3 0
fb1 1af9 1660 1af8
0 1afa fbc 0
355e 84 :3 0 1d0
:4 0 1afc 1afd :3 0
1afb 1afe 0 355e
a1 :3 0 4f :3 0
4d :2 0 fbe 1b00
1b03 d2 :2 0 4d
:2 0 fc3 1b05 1b07
:3 0 a1 :3 0 5b
:3 0 4d :2 0 fc6
1b09 1b0c c2 :3 0
c3 :2 0 d3 :3 0
1b0e 1b10 0 fcb
1b0f 1b12 :3 0 1b08
1b14 1b13 :2 0 a1
:3 0 5b :3 0 4d
:2 0 fce 1b16 1b19
c2 :3 0 c3 :2 0
d1 :3 0 1b1b 1b1d
0 fd3 1b1c 1b1f
:3 0 1b15 1b21 1b20
:2 0 1e :3 0 de
:2 0 fd6 1b24 1b25
:3 0 1b26 :2 0 3a
:3 0 1e :3 0 1b28
1b29 0 1b2b fd8
1b2c 1b27 1b2b 0
1b2d fda 0 1b2e
fdc 1b2f 1b22 1b2e
0 1b30 fde 0
355e a1 :3 0 55
:3 0 4d :2 0 fe0
1b31 1b34 d2 :2 0
4d :2 0 fe5 1b36
1b38 :3 0 55 :3 0
c2 :3 0 1d1 :3 0
1b3b 1b3c 0 1b3a
1b3d 0 1b3f fe8
1b40 1b39 1b3f 0
1b41 fea 0 355e
16 :3 0 c5 :2 0
fec 1b43 1b44 :3 0
1b45 :2 0 17 :3 0
c5 :2 0 fee 1b48
1b49 :3 0 1b4a :2 0
1b46 1b4c 1b4b :2 0
18 :3 0 c5 :2 0
ff0 1b4f 1b50 :3 0
1b51 :2 0 1b4d 1b53
1b52 :2 0 19 :3 0
c5 :2 0 ff2 1b56
1b57 :3 0 1b58 :2 0
1b59 :2 0 1b54 1b5b
1b5a :2 0 8b :3 0
46 :2 0 1b5d 1b5e
0 1b60 ff4 1b61
1b5c 1b60 0 1b62
ff6 0 355e 74
:3 0 18b :4 0 1b63
1b64 0 355e 76
:3 0 18b :4 0 1b66
1b67 0 355e a1
:3 0 4f :3 0 4d
:2 0 ff8 1b69 1b6c
10e :2 0 4d :2 0
ffd 1b6e 1b70 :3 0
a1 :3 0 5b :3 0
4d :2 0 1000 1b72
1b75 c2 :3 0 d2
:2 0 d3 :3 0 1b77
1b79 0 1005 1b78
1b7b :3 0 74 :3 0
1d2 :4 0 b5 :2 0
39 :3 0 1008 1b7f
1b81 :3 0 b5 :2 0
1d3 :4 0 100b 1b83
1b85 :3 0 b5 :2 0
1d4 :4 0 100e 1b87
1b89 :3 0 b5 :2 0
1d5 :4 0 1011 1b8b
1b8d :3 0 b5 :2 0
1d6 :4 0 1014 1b8f
1b91 :3 0 b5 :2 0
48 :3 0 1017 1b93
1b95 :3 0 b5 :2 0
b8 :4 0 101a 1b97
1b99 :3 0 1b7d 1b9a
0 1b9d d9 :3 0
101d 1be4 a1 :3 0
5b :3 0 4d :2 0
101f 1b9e 1ba1 d2
:2 0 2d :2 0 1024
1ba3 1ba5 :3 0 74
:3 0 1d7 :4 0 b5
:2 0 1d8 :4 0 1027
1ba9 1bab :3 0 b5
:2 0 1d9 :4 0 102a
1bad 1baf :3 0 b5
:2 0 25 :3 0 102d
1bb1 1bb3 :3 0 b5
:2 0 1da :4 0 1030
1bb5 1bb7 :3 0 b5
:2 0 1db :4 0 1033
1bb9 1bbb :3 0 b5
:2 0 39 :3 0 1036
1bbd 1bbf :3 0 b5
:2 0 1da :4 0 1039
1bc1 1bc3 :3 0 b5
:2 0 1dc :4 0 103c
1bc5 1bc7 :3 0 1ba7
1bc8 0 1bca 103f
1bcb 1ba6 1bca 0
1be6 74 :3 0 1dd
:4 0 b5 :2 0 1de
:4 0 1041 1bce 1bd0
:3 0 b5 :2 0 1df
:4 0 1044 1bd2 1bd4
:3 0 b5 :2 0 1e0
:4 0 1047 1bd6 1bd8
:3 0 b5 :2 0 39
:3 0 104a 1bda 1bdc
:3 0 b5 :2 0 1da
:4 0 104d 1bde 1be0
:3 0 1bcc 1be1 0
1be3 1050 1be5 1b7c
1b9d 0 1be6 0
1be3 0 1be6 1052
0 1be7 1056 2560
a1 :3 0 5b :3 0
4d :2 0 1058 1be8
1beb c2 :3 0 c3
:2 0 d3 :3 0 1bed
1bef 0 105d 1bee
1bf1 :3 0 a1 :3 0
5b :3 0 4d :2 0
1060 1bf3 1bf6 c2
:3 0 c3 :2 0 d1
:3 0 1bf8 1bfa 0
1065 1bf9 1bfc :3 0
1bf2 1bfe 1bfd :2 0
a1 :3 0 a :3 0
4d :2 0 1068 1c00
1c03 c2 :3 0 c3
:2 0 c4 :3 0 1c05
1c07 0 106d 1c06
1c09 :3 0 1bff 1c0b
1c0a :2 0 1e1 :3 0
1e2 :3 0 1e3 :4 0
1c0f :4 0 1c10 :2 0
1d85 21 :3 0 f4
:3 0 1c12 1c13 0
4d :2 0 1c14 1c15
0 1d85 14 :3 0
c5 :2 0 1070 1c18
1c19 :3 0 1c1a :2 0
1e1 :3 0 1e2 :3 0
1e4 :4 0 1c1e :4 0
1c1f :2 0 1d16 21
:3 0 f4 :3 0 1c21
1c22 0 4d :2 0
1c23 1c24 0 1d16
1e5 :3 0 116 :3 0
1e6 :3 0 181 :3 0
1e7 :3 0 1e8 :3 0
116 :3 0 1e8 :3 0
1e6 :3 0 181 :3 0
1e8 :3 0 1e9 :3 0
19f :3 0 1ea :3 0
1e8 :3 0 116 :3 0
1ea :3 0 116 :3 0
1ea :3 0 1eb :3 0
1ea :3 0 9a :3 0
29 :4 0 1ec 1
:8 0 1c53 1bf :4 0
1c3e :3 0 d0 :3 0
d2 :2 0 1074 1c41
1c42 :3 0 21 :3 0
f4 :3 0 1c44 1c45
0 4d :2 0 1c46
1c47 0 1c49 1077
1c50 21 :3 0 f4
:3 0 1c4a 1c4b 0
189 :2 0 1c4c 1c4d
0 1c4f 1079 1c51
1c43 1c49 0 1c52
0 1c4f 0 1c52
107b 0 1c53 107e
1c9d f6 :3 0 21
:3 0 f4 :3 0 1c56
1c57 0 f5 :3 0
1c58 1c59 0 1c93
ad :3 0 ae :3 0
1c5b 1c5c 0 ad
:3 0 bd :3 0 1c5e
1c5f 0 f7 :2 0
2 :4 0 1ed :2 0
bf :2 0 46 :2 0
1081 1c64 1c66 :3 0
1084 1c60 1c68 1c5d
1c6a 1c69 :2 0 b0
:3 0 c0 :3 0 1c6c
1c6d 0 b2 :4 0
1ee :4 0 b5 :2 0
b6 :3 0 1088 1c71
1c73 :3 0 b5 :2 0
c9 :4 0 108b 1c75
1c77 :3 0 b5 :2 0
fa :4 0 108e 1c79
1c7b :3 0 b5 :2 0
f5 :3 0 1091 1c7d
1c7f :3 0 b5 :2 0
fb :4 0 1094 1c81
1c83 :3 0 b5 :2 0
fc :3 0 fd :3 0
46 :2 0 fe :2 0
1097 1c86 1c8a 109b
1c85 1c8c :3 0 109e
1c6e 1c8e :2 0 1c90
10a1 1c91 1c6b 1c90
0 1c92 10a3 0
1c93 10a5 1c96 :3 0
1c96 0 1c96 1c95
1c93 1c94 :6 0 1c98
2c :3 0 10a8 1c9a
10aa 1c99 1c98 :2 0
1c9b 10ac :2 0 1c9d
0 1c9d 1c9c 1c53
1c9b :6 0 1d16 1
:3 0 1ef :3 0 1f0
:3 0 1e6 :3 0 1e5
:3 0 1f0 :3 0 142
:3 0 116 :3 0 1e5
:3 0 142 :3 0 142
:3 0 1e6 :3 0 1f0
:3 0 1e6 :3 0 fc
:3 0 1f0 :3 0 1e6
:3 0 df :3 0 142
:3 0 1e6 :3 0 142
:3 0 1e6 :4 0 1f1
1 :8 0 1cca 1bf
:4 0 1cb5 :3 0 d0
:3 0 d2 :2 0 10b0
1cb8 1cb9 :3 0 21
:3 0 f4 :3 0 1cbb
1cbc 0 4d :2 0
1cbd 1cbe 0 1cc0
10b3 1cc7 21 :3 0
f4 :3 0 1cc1 1cc2
0 189 :2 0 1cc3
1cc4 0 1cc6 10b5
1cc8 1cba 1cc0 0
1cc9 0 1cc6 0
1cc9 10b7 0 1cca
10ba 1d14 f6 :3 0
21 :3 0 f4 :3 0
1ccd 1cce 0 f5
:3 0 1ccf 1cd0 0
1d0a ad :3 0 ae
:3 0 1cd2 1cd3 0
ad :3 0 bd :3 0
1cd5 1cd6 0 f7
:2 0 2 :4 0 1f2
:2 0 bf :2 0 46
:2 0 10bd 1cdb 1cdd
:3 0 10c0 1cd7 1cdf
1cd4 1ce1 1ce0 :2 0
b0 :3 0 c0 :3 0
1ce3 1ce4 0 b2
:4 0 1f3 :4 0 b5
:2 0 b6 :3 0 10c4
1ce8 1cea :3 0 b5
:2 0 c9 :4 0 10c7
1cec 1cee :3 0 b5
:2 0 fa :4 0 10ca
1cf0 1cf2 :3 0 b5
:2 0 f5 :3 0 10cd
1cf4 1cf6 :3 0 b5
:2 0 fb :4 0 10d0
1cf8 1cfa :3 0 b5
:2 0 fc :3 0 fd
:3 0 46 :2 0 fe
:2 0 10d3 1cfd 1d01
10d7 1cfc 1d03 :3 0
10da 1ce5 1d05 :2 0
1d07 10dd 1d08 1ce2
1d07 0 1d09 10df
0 1d0a 10e1 1d0d
:3 0 1d0d 0 1d0d
1d0c 1d0a 1d0b :6 0
1d0f 2e :3 0 10e4
1d11 10e6 1d10 1d0f
:2 0 1d12 10e8 :2 0
1d14 0 1d14 1d13
1cca 1d12 :6 0 1d16
1 :3 0 10ea 1d82
39 :3 0 14 :3 0
1d17 1d18 0 1d81
1ef :3 0 1e6 :3 0
181 :3 0 116 :3 0
39 :4 0 1f4 1
:8 0 1d35 1bf :4 0
1d20 :3 0 d0 :3 0
d2 :2 0 10f1 1d23
1d24 :3 0 21 :3 0
f4 :3 0 1d26 1d27
0 4d :2 0 1d28
1d29 0 1d2b 10f4
1d32 21 :3 0 f4
:3 0 1d2c 1d2d 0
189 :2 0 1d2e 1d2f
0 1d31 10f6 1d33
1d25 1d2b 0 1d34
0 1d31 0 1d34
10f8 0 1d35 10fb
1d7f f6 :3 0 21
:3 0 f4 :3 0 1d38
1d39 0 f5 :3 0
1d3a 1d3b 0 1d75
ad :3 0 ae :3 0
1d3d 1d3e 0 ad
:3 0 bd :3 0 1d40
1d41 0 f7 :2 0
2 :4 0 1f5 :2 0
bf :2 0 46 :2 0
10fe 1d46 1d48 :3 0
1101 1d42 1d4a 1d3f
1d4c 1d4b :2 0 b0
:3 0 c0 :3 0 1d4e
1d4f 0 b2 :4 0
1f6 :4 0 b5 :2 0
b6 :3 0 1105 1d53
1d55 :3 0 b5 :2 0
c9 :4 0 1108 1d57
1d59 :3 0 b5 :2 0
fa :4 0 110b 1d5b
1d5d :3 0 b5 :2 0
f5 :3 0 110e 1d5f
1d61 :3 0 b5 :2 0
fb :4 0 1111 1d63
1d65 :3 0 b5 :2 0
fc :3 0 fd :3 0
46 :2 0 fe :2 0
1114 1d68 1d6c 1118
1d67 1d6e :3 0 111b
1d50 1d70 :2 0 1d72
111e 1d73 1d4d 1d72
0 1d74 1120 0
1d75 1122 1d78 :3 0
1d78 0 1d78 1d77
1d75 1d76 :6 0 1d7a
30 :3 0 1125 1d7c
1127 1d7b 1d7a :2 0
1d7d 1129 :2 0 1d7f
0 1d7f 1d7e 1d35
1d7d :6 0 1d81 1
:3 0 112b 1d83 1c1b
1d16 0 1d84 0
1d81 0 1d84 112e
0 1d85 1131 1d86
1c0c 1d85 0 1d87
1135 0 255f 10
:3 0 de :2 0 1137
1d89 1d8a :3 0 1d8b
:2 0 8e :3 0 a1
:3 0 df :3 0 10
:3 0 1139 1d8f 1d91
4d :2 0 113b 1d8e
1d94 10e :2 0 1f7
:2 0 1140 1d96 1d98
:3 0 10a :3 0 a1
:3 0 df :3 0 10
:3 0 1143 1d9c 1d9e
4d :2 0 1145 1d9b
1da1 1f8 :2 0 1148
1d9a 1da4 1f9 :2 0
1fa :2 0 114b 1da6
1da8 :3 0 114e 1daa
1da9 10a :3 0 a1
:3 0 df :3 0 10
:3 0 1150 1dae 1db0
4d :2 0 1152 1dad
1db3 1f8 :2 0 1155
1dac 1db6 0 1db7
0 1158 :2 0 1d8d
1db9 0 1ebb 8f
:3 0 4d :2 0 1dbb
1dbc 0 1ebb 1fb
:3 0 8f :3 0 8e
:3 0 e0 :2 0 1fc
:3 0 115d 1dc1 1dc3
:3 0 1dc4 1e00 a1
:3 0 1fd :3 0 fc
:3 0 2a :3 0 8f
:3 0 bf :2 0 46
:2 0 1160 1dcb 1dcd
:3 0 46 :2 0 1163
1dc8 1dd0 1167 1dc7
1dd2 4d :2 0 1169
1dc6 1dd5 c3 :2 0
1fe :2 0 116e 1dd7
1dd9 :3 0 a1 :3 0
1fd :3 0 fc :3 0
2a :3 0 8f :3 0
bf :2 0 46 :2 0
1171 1de0 1de2 :3 0
46 :2 0 1174 1ddd
1de5 1178 1ddc 1de7
4d :2 0 117a 1ddb
1dea c3 :2 0 1ff
:2 0 117f 1dec 1dee
:3 0 1dda 1df0 1def
:2 0 200 :8 0 1df4
1182 1df5 1df1 1df4
0 1df6 1184 0
1dfe 8f :3 0 8f
:3 0 bf :2 0 46
:2 0 1186 1df9 1dfb
:3 0 1df7 1dfc 0
1dfe 1189 1e00 1fc
:3 0 1dc5 1dfe :4 0
1ebb 8f :3 0 8e
:3 0 d2 :2 0 118e
1e03 1e04 :3 0 ad
:3 0 ae :3 0 1e06
1e07 0 ad :3 0
bd :3 0 1e09 1e0a
0 c6 :2 0 2
:4 0 201 :2 0 bf
:2 0 46 :2 0 1191
1e0f 1e11 :3 0 1194
1e0b 1e13 1e08 1e15
1e14 :2 0 b0 :3 0
c0 :3 0 1e17 1e18
0 b2 :4 0 202
:4 0 b5 :2 0 b6
:3 0 1198 1e1c 1e1e
:3 0 b5 :2 0 c9
:4 0 119b 1e20 1e22
:3 0 b5 :2 0 ca
:4 0 119e 1e24 1e26
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 d6 :3 0 1e2b
1e2c 0 11a1 1e2a
1e2e bb :4 0 11a3
1e29 1e31 11a6 1e28
1e33 :3 0 11a9 1e19
1e35 :2 0 1e37 11ac
1e38 1e16 1e37 0
1e39 11ae 0 1e62
ad :3 0 ae :3 0
1e3a 1e3b 0 ad
:3 0 bd :3 0 1e3d
1e3e 0 46 :2 0
2 :4 0 203 :2 0
bf :2 0 46 :2 0
11b0 1e43 1e45 :3 0
11b3 1e3f 1e47 1e3c
1e49 1e48 :2 0 b0
:3 0 c0 :3 0 1e4b
1e4c 0 b2 :4 0
204 :4 0 b5 :2 0
b6 :3 0 11b7 1e50
1e52 :3 0 11ba 1e4d
1e54 :2 0 1e56 11bd
1e57 1e4a 1e56 0
1e58 11bf 0 1e62
ce :3 0 cf :3 0
1e59 1e5a 0 c2
:3 0 d6 :3 0 1e5c
1e5d 0 d0 :3 0
11c1 1e5b 1e60 :2 0
1e62 11c4 1e63 1e05
1e62 0 1e64 11c8
0 1ebb 205 :3 0
2a :3 0 2a :3 0
f2 :4 0 206 1
:8 0 1e6f 21 :3 0
f4 :3 0 1e6a 1e6b
0 f5 :3 0 1e6c
1e6d 0 1e6f 11ca
1eb9 f6 :3 0 21
:3 0 f4 :3 0 1e72
1e73 0 f5 :3 0
1e74 1e75 0 1eaf
ad :3 0 ae :3 0
1e77 1e78 0 ad
:3 0 bd :3 0 1e7a
1e7b 0 f7 :2 0
2 :4 0 207 :2 0
bf :2 0 46 :2 0
11cd 1e80 1e82 :3 0
11d0 1e7c 1e84 1e79
1e86 1e85 :2 0 b0
:3 0 c0 :3 0 1e88
1e89 0 b2 :4 0
208 :4 0 b5 :2 0
b6 :3 0 11d4 1e8d
1e8f :3 0 b5 :2 0
c9 :4 0 11d7 1e91
1e93 :3 0 b5 :2 0
fa :4 0 11da 1e95
1e97 :3 0 b5 :2 0
f5 :3 0 11dd 1e99
1e9b :3 0 b5 :2 0
fb :4 0 11e0 1e9d
1e9f :3 0 b5 :2 0
fc :3 0 fd :3 0
46 :2 0 fe :2 0
11e3 1ea2 1ea6 11e7
1ea1 1ea8 :3 0 11ea
1e8a 1eaa :2 0 1eac
11ed 1ead 1e87 1eac
0 1eae 11ef 0
1eaf 11f1 1eb2 :3 0
1eb2 0 1eb2 1eb1
1eaf 1eb0 :6 0 1eb4
33 :3 0 11f4 1eb6
11f6 1eb5 1eb4 :2 0
1eb7 11f8 :2 0 1eb9
0 1eb9 1eb8 1e6f
1eb7 :6 0 1ebb 1
:3 0 11fa 1ebc 1d8c
1ebb 0 1ebd 1200
0 255f a1 :3 0
5b :3 0 4d :2 0
1202 1ebe 1ec1 c2
:3 0 d2 :2 0 d3
:3 0 1ec3 1ec5 0
1207 1ec4 1ec7 :3 0
74 :3 0 209 :4 0
1ec9 1eca 0 1ede
76 :3 0 20a :4 0
1ecc 1ecd 0 1ede
76 :3 0 76 :3 0
b5 :2 0 39 :3 0
120a 1ed1 1ed3 :3 0
1ecf 1ed4 0 1ede
76 :3 0 76 :3 0
b5 :2 0 b8 :4 0
120d 1ed8 1eda :3 0
1ed6 1edb 0 1ede
d9 :3 0 1210 1fb5
a1 :3 0 5b :3 0
4d :2 0 1215 1edf
1ee2 c2 :3 0 d2
:2 0 d1 :3 0 1ee4
1ee6 0 121a 1ee5
1ee8 :3 0 74 :3 0
20b :4 0 1eea 1eeb
0 1efe 74 :3 0
74 :3 0 b5 :2 0
25 :3 0 121d 1eef
1ef1 :3 0 1eed 1ef2
0 1efe 74 :3 0
74 :3 0 b5 :2 0
20c :4 0 1220 1ef6
1ef8 :3 0 1ef4 1ef9
0 1efe 76 :3 0
20d :4 0 1efb 1efc
0 1efe 1223 1eff
1ee9 1efe 0 1fb7
a1 :3 0 a :3 0
4d :2 0 1228 1f00
1f03 c2 :3 0 d2
:2 0 c4 :3 0 1f05
1f07 0 122d 1f06
1f09 :3 0 74 :3 0
20e :4 0 1f0b 1f0c
0 1f52 76 :3 0
20d :4 0 1f0e 1f0f
0 1f52 1e :3 0
de :2 0 1230 1f12
1f13 :3 0 1f14 :2 0
76 :3 0 76 :3 0
b5 :2 0 20f :4 0
1232 1f18 1f1a :3 0
1f16 1f1b 0 1f2b
76 :3 0 76 :3 0
b5 :2 0 3a :3 0
1235 1f1f 1f21 :3 0
1f1d 1f22 0 1f2b
76 :3 0 76 :3 0
b5 :2 0 1da :4 0
1238 1f26 1f28 :3 0
1f24 1f29 0 1f2b
123b 1f2c 1f15 1f2b
0 1f2d 123f 0
1f52 76 :3 0 76
:3 0 b5 :2 0 210
:4 0 1241 1f30 1f32
:3 0 1f2e 1f33 0
1f52 10 :3 0 de
:2 0 1244 1f36 1f37
:3 0 1f38 :2 0 76
:3 0 76 :3 0 b5
:2 0 211 :4 0 1246
1f3c 1f3e :3 0 1f3a
1f3f 0 1f4f 76
:3 0 76 :3 0 b5
:2 0 2a :3 0 1249
1f43 1f45 :3 0 1f41
1f46 0 1f4f 76
:3 0 76 :3 0 b5
:2 0 212 :4 0 124c
1f4a 1f4c :3 0 1f48
1f4d 0 1f4f 124f
1f50 1f39 1f4f 0
1f51 1253 0 1f52
1255 1fb1 74 :3 0
74 :3 0 b5 :2 0
213 :4 0 125b 1f55
1f57 :3 0 b5 :2 0
214 :4 0 125e 1f59
1f5b :3 0 1f53 1f5c
0 1fb0 76 :3 0
20d :4 0 1f5e 1f5f
0 1fb0 1e :3 0
de :2 0 1261 1f62
1f63 :3 0 1f64 :2 0
76 :3 0 76 :3 0
b5 :2 0 20f :4 0
1263 1f68 1f6a :3 0
1f66 1f6b 0 1f7b
76 :3 0 76 :3 0
b5 :2 0 3a :3 0
1266 1f6f 1f71 :3 0
1f6d 1f72 0 1f7b
76 :3 0 76 :3 0
b5 :2 0 1da :4 0
1269 1f76 1f78 :3 0
1f74 1f79 0 1f7b
126c 1f7c 1f65 1f7b
0 1f7d 1270 0
1fb0 76 :3 0 76
:3 0 b5 :2 0 215
:4 0 1272 1f80 1f82
:3 0 b5 :2 0 216
:4 0 1275 1f84 1f86
:3 0 b5 :2 0 217
:4 0 1278 1f88 1f8a
:3 0 b5 :2 0 218
:4 0 127b 1f8c 1f8e
:3 0 b5 :2 0 219
:4 0 127e 1f90 1f92
:3 0 b5 :2 0 21a
:4 0 1281 1f94 1f96
:3 0 1f7e 1f97 0
1fb0 10 :3 0 de
:2 0 1284 1f9a 1f9b
:3 0 1f9c :2 0 76
:3 0 76 :3 0 b5
:2 0 21b :4 0 1286
1fa0 1fa2 :3 0 b5
:2 0 2a :3 0 1289
1fa4 1fa6 :3 0 b5
:2 0 212 :4 0 128c
1fa8 1faa :3 0 1f9e
1fab 0 1fad 128f
1fae 1f9d 1fad 0
1faf 1291 0 1fb0
1293 1fb2 1f0a 1f52
0 1fb3 0 1fb0
0 1fb3 1299 0
1fb4 129c 1fb6 1ec8
1ede 0 1fb7 0
1fb4 0 1fb7 129e
0 255f a1 :3 0
5b :3 0 4d :2 0
12a2 1fb8 1fbb c2
:3 0 c3 :2 0 d3
:3 0 1fbd 1fbf 0
12a7 1fbe 1fc1 :3 0
14 :3 0 de :2 0
12aa 1fc4 1fc5 :3 0
1fc6 :2 0 1e6 :3 0
3b :3 0 181 :3 0
116 :3 0 14 :4 0
21c 1 :8 0 1fd3
21 :3 0 f4 :3 0
1fce 1fcf 0 f5
:3 0 1fd0 1fd1 0
1fd3 12ac 201d f6
:3 0 21 :3 0 f4
:3 0 1fd6 1fd7 0
f5 :3 0 1fd8 1fd9
0 2013 ad :3 0
ae :3 0 1fdb 1fdc
0 ad :3 0 bd
:3 0 1fde 1fdf 0
f7 :2 0 2 :4 0
21d :2 0 bf :2 0
46 :2 0 12af 1fe4
1fe6 :3 0 12b2 1fe0
1fe8 1fdd 1fea 1fe9
:2 0 b0 :3 0 c0
:3 0 1fec 1fed 0
b2 :4 0 21e :4 0
b5 :2 0 b6 :3 0
12b6 1ff1 1ff3 :3 0
b5 :2 0 c9 :4 0
12b9 1ff5 1ff7 :3 0
b5 :2 0 fa :4 0
12bc 1ff9 1ffb :3 0
b5 :2 0 f5 :3 0
12bf 1ffd 1fff :3 0
b5 :2 0 fb :4 0
12c2 2001 2003 :3 0
b5 :2 0 fc :3 0
fd :3 0 46 :2 0
fe :2 0 12c5 2006
200a 12c9 2005 200c
:3 0 12cc 1fee 200e
:2 0 2010 12cf 2011
1feb 2010 0 2012
12d1 0 2013 12d3
2016 :3 0 2016 0
2016 2015 2013 2014
:6 0 2018 35 :3 0
12d6 201a 12d8 2019
2018 :2 0 201b 12da
:2 0 201d 0 201d
201c 1fd3 201b :6 0
20bf 1 :3 0 21
:3 0 f4 :3 0 201f
2020 0 21 :3 0
d2 :2 0 ff :3 0
2022 2024 0 12de
2023 2026 :3 0 2027
:2 0 90 :3 0 a1
:3 0 df :3 0 3b
:3 0 12e1 202b 202d
4d :2 0 12e3 202a
2030 2029 2031 0
204d 74 :3 0 74
:3 0 b5 :2 0 21f
:4 0 12e6 2035 2037
:3 0 2033 2038 0
204d 76 :3 0 76
:3 0 b5 :2 0 220
:4 0 12e9 203c 203e
:3 0 b5 :2 0 221
:4 0 12ec 2040 2042
:3 0 b5 :2 0 3b
:3 0 12ef 2044 2046
:3 0 b5 :2 0 222
:4 0 12f2 2048 204a
:3 0 203a 204b 0
204d 12f5 20bc ad
:3 0 ae :3 0 204e
204f 0 ad :3 0
bd :3 0 2051 2052
0 24 :2 0 2
:4 0 223 :2 0 bf
:2 0 46 :2 0 12f9
2057 2059 :3 0 12fc
2053 205b 2050 205d
205c :2 0 b0 :3 0
c0 :3 0 205f 2060
0 b2 :4 0 224
:4 0 b5 :2 0 b6
:3 0 1300 2064 2066
:3 0 b5 :2 0 c9
:4 0 1303 2068 206a
:3 0 b5 :2 0 ca
:4 0 1306 206c 206e
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 d6 :3 0 2073
2074 0 1309 2072
2076 bb :4 0 130b
2071 2079 130e 2070
207b :3 0 b5 :2 0
11f :4 0 1311 207d
207f :3 0 b5 :2 0
b8 :4 0 1314 2081
2083 :3 0 b5 :2 0
14 :3 0 1317 2085
2087 :3 0 b5 :2 0
b8 :4 0 131a 2089
208b :3 0 131d 2061
208d :2 0 208f 1320
2090 205e 208f 0
2091 1322 0 20bb
ad :3 0 ae :3 0
2092 2093 0 ad
:3 0 bd :3 0 2095
2096 0 46 :2 0
2 :4 0 225 :2 0
bf :2 0 46 :2 0
1324 209b 209d :3 0
1327 2097 209f 2094
20a1 20a0 :2 0 b0
:3 0 c0 :3 0 20a3
20a4 0 b2 :4 0
226 :4 0 b5 :2 0
b6 :3 0 132b 20a8
20aa :3 0 132e 20a5
20ac :2 0 20ae 1331
20af 20a2 20ae 0
20b0 1333 0 20bb
ce :3 0 122 :3 0
20b1 20b2 0 c2
:3 0 d6 :3 0 20b4
20b5 0 14 :3 0
d0 :3 0 1335 20b3
20b9 :2 0 20bb 1339
20bd 2028 204d 0
20be 0 20bb 0
20be 133d 0 20bf
1340 20c0 1fc7 20bf
0 20c1 1343 0
22d9 12 :3 0 de
:2 0 1345 20c3 20c4
:3 0 20c5 :2 0 1e6
:3 0 3b :3 0 227
:3 0 116 :3 0 12
:4 0 228 1 :8 0
20d2 21 :3 0 f4
:3 0 20cd 20ce 0
f5 :3 0 20cf 20d0
0 20d2 1347 211c
f6 :3 0 21 :3 0
f4 :3 0 20d5 20d6
0 f5 :3 0 20d7
20d8 0 2112 ad
:3 0 ae :3 0 20da
20db 0 ad :3 0
bd :3 0 20dd 20de
0 f7 :2 0 2
:4 0 229 :2 0 bf
:2 0 46 :2 0 134a
20e3 20e5 :3 0 134d
20df 20e7 20dc 20e9
20e8 :2 0 b0 :3 0
c0 :3 0 20eb 20ec
0 b2 :4 0 22a
:4 0 b5 :2 0 b6
:3 0 1351 20f0 20f2
:3 0 b5 :2 0 c9
:4 0 1354 20f4 20f6
:3 0 b5 :2 0 fa
:4 0 1357 20f8 20fa
:3 0 b5 :2 0 f5
:3 0 135a 20fc 20fe
:3 0 b5 :2 0 fb
:4 0 135d 2100 2102
:3 0 b5 :2 0 fc
:3 0 fd :3 0 46
:2 0 fe :2 0 1360
2105 2109 1364 2104
210b :3 0 1367 20ed
210d :2 0 210f 136a
2110 20ea 210f 0
2111 136c 0 2112
136e 2115 :3 0 2115
0 2115 2114 2112
2113 :6 0 2117 37
:3 0 1371 2119 1373
2118 2117 :2 0 211a
1375 :2 0 211c 0
211c 211b 20d2 211a
:6 0 21b4 1 :3 0
21 :3 0 f4 :3 0
211e 211f 0 21
:3 0 d2 :2 0 ff
:3 0 2121 2123 0
1379 2122 2125 :3 0
2126 :2 0 74 :3 0
74 :3 0 b5 :2 0
22b :4 0 137c 212a
212c :3 0 2128 212d
0 2142 76 :3 0
76 :3 0 b5 :2 0
22c :4 0 137f 2131
2133 :3 0 b5 :2 0
22d :4 0 1382 2135
2137 :3 0 b5 :2 0
3b :3 0 1385 2139
213b :3 0 b5 :2 0
222 :4 0 1388 213d
213f :3 0 212f 2140
0 2142 138b 21b1
ad :3 0 ae :3 0
2143 2144 0 ad
:3 0 bd :3 0 2146
2147 0 24 :2 0
2 :4 0 22e :2 0
bf :2 0 46 :2 0
138e 214c 214e :3 0
1391 2148 2150 2145
2152 2151 :2 0 b0
:3 0 c0 :3 0 2154
2155 0 b2 :4 0
22f :4 0 b5 :2 0
b6 :3 0 1395 2159
215b :3 0 b5 :2 0
c9 :4 0 1398 215d
215f :3 0 b5 :2 0
ca :4 0 139b 2161
2163 :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 d6 :3 0
2168 2169 0 139e
2167 216b bb :4 0
13a0 2166 216e 13a3
2165 2170 :3 0 b5
:2 0 11f :4 0 13a6
2172 2174 :3 0 b5
:2 0 b8 :4 0 13a9
2176 2178 :3 0 b5
:2 0 12 :3 0 13ac
217a 217c :3 0 b5
:2 0 b8 :4 0 13af
217e 2180 :3 0 13b2
2156 2182 :2 0 2184
13b5 2185 2153 2184
0 2186 13b7 0
21b0 ad :3 0 ae
:3 0 2187 2188 0
ad :3 0 bd :3 0
218a 218b 0 46
:2 0 2 :4 0 230
:2 0 bf :2 0 46
:2 0 13b9 2190 2192
:3 0 13bc 218c 2194
2189 2196 2195 :2 0
b0 :3 0 c0 :3 0
2198 2199 0 b2
:4 0 231 :4 0 b5
:2 0 b6 :3 0 13c0
219d 219f :3 0 13c3
219a 21a1 :2 0 21a3
13c6 21a4 2197 21a3
0 21a5 13c8 0
21b0 ce :3 0 122
:3 0 21a6 21a7 0
c2 :3 0 d6 :3 0
21a9 21aa 0 12
:3 0 d0 :3 0 13ca
21a8 21ae :2 0 21b0
13ce 21b2 2127 2142
0 21b3 0 21b0
0 21b3 13d2 0
21b4 13d5 21b5 20c6
21b4 0 21b6 13d8
0 22d9 13 :3 0
de :2 0 13da 21b8
21b9 :3 0 21ba :2 0
1e6 :3 0 3b :3 0
232 :3 0 116 :3 0
13 :4 0 233 1
:8 0 21c7 21 :3 0
f4 :3 0 21c2 21c3
0 f5 :3 0 21c4
21c5 0 21c7 13dc
2211 f6 :3 0 21
:3 0 f4 :3 0 21ca
21cb 0 f5 :3 0
21cc 21cd 0 2207
ad :3 0 ae :3 0
21cf 21d0 0 ad
:3 0 bd :3 0 21d2
21d3 0 f7 :2 0
2 :4 0 234 :2 0
bf :2 0 46 :2 0
13df 21d8 21da :3 0
13e2 21d4 21dc 21d1
21de 21dd :2 0 b0
:3 0 c0 :3 0 21e0
21e1 0 b2 :4 0
235 :4 0 b5 :2 0
b6 :3 0 13e6 21e5
21e7 :3 0 b5 :2 0
c9 :4 0 13e9 21e9
21eb :3 0 b5 :2 0
fa :4 0 13ec 21ed
21ef :3 0 b5 :2 0
f5 :3 0 13ef 21f1
21f3 :3 0 b5 :2 0
fb :4 0 13f2 21f5
21f7 :3 0 b5 :2 0
fc :3 0 fd :3 0
46 :2 0 fe :2 0
13f5 21fa 21fe 13f9
21f9 2200 :3 0 13fc
21e2 2202 :2 0 2204
13ff 2205 21df 2204
0 2206 1401 0
2207 1403 220a :3 0
220a 0 220a 2209
2207 2208 :6 0 220c
39 :3 0 1406 220e
1408 220d 220c :2 0
220f 140a :2 0 2211
0 2211 2210 21c7
220f :6 0 22a9 1
:3 0 21 :3 0 f4
:3 0 2213 2214 0
21 :3 0 d2 :2 0
ff :3 0 2216 2218
0 140e 2217 221a
:3 0 221b :2 0 74
:3 0 74 :3 0 b5
:2 0 236 :4 0 1411
221f 2221 :3 0 221d
2222 0 2237 76
:3 0 76 :3 0 b5
:2 0 237 :4 0 1414
2226 2228 :3 0 b5
:2 0 238 :4 0 1417
222a 222c :3 0 b5
:2 0 3b :3 0 141a
222e 2230 :3 0 b5
:2 0 222 :4 0 141d
2232 2234 :3 0 2224
2235 0 2237 1420
22a6 ad :3 0 ae
:3 0 2238 2239 0
ad :3 0 bd :3 0
223b 223c 0 24
:2 0 2 :4 0 239
:2 0 bf :2 0 46
:2 0 1423 2241 2243
:3 0 1426 223d 2245
223a 2247 2246 :2 0
b0 :3 0 c0 :3 0
2249 224a 0 b2
:4 0 23a :4 0 b5
:2 0 b6 :3 0 142a
224e 2250 :3 0 b5
:2 0 c9 :4 0 142d
2252 2254 :3 0 b5
:2 0 ca :4 0 1430
2256 2258 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 d6
:3 0 225d 225e 0
1433 225c 2260 bb
:4 0 1435 225b 2263
1438 225a 2265 :3 0
b5 :2 0 11f :4 0
143b 2267 2269 :3 0
b5 :2 0 b8 :4 0
143e 226b 226d :3 0
b5 :2 0 13 :3 0
1441 226f 2271 :3 0
b5 :2 0 b8 :4 0
1444 2273 2275 :3 0
1447 224b 2277 :2 0
2279 144a 227a 2248
2279 0 227b 144c
0 22a5 ad :3 0
ae :3 0 227c 227d
0 ad :3 0 bd
:3 0 227f 2280 0
46 :2 0 2 :4 0
23b :2 0 bf :2 0
46 :2 0 144e 2285
2287 :3 0 1451 2281
2289 227e 228b 228a
:2 0 b0 :3 0 c0
:3 0 228d 228e 0
b2 :4 0 23c :4 0
b5 :2 0 b6 :3 0
1455 2292 2294 :3 0
1458 228f 2296 :2 0
2298 145b 2299 228c
2298 0 229a 145d
0 22a5 ce :3 0
122 :3 0 229b 229c
0 c2 :3 0 d6
:3 0 229e 229f 0
13 :3 0 d0 :3 0
145f 229d 22a3 :2 0
22a5 1463 22a7 221c
2237 0 22a8 0
22a5 0 22a8 1467
0 22a9 146a 22aa
21bb 22a9 0 22ab
146d 0 22d9 a1
:3 0 53 :3 0 4d
:2 0 146f 22ac 22af
10e :2 0 4d :2 0
1474 22b1 22b3 :3 0
a1 :3 0 53 :3 0
4d :2 0 1477 22b5
22b8 c3 :2 0 ef
:2 0 147c 22ba 22bc
:3 0 22b4 22be 22bd
:2 0 76 :3 0 76
:3 0 b5 :2 0 23d
:4 0 147f 22c2 22c4
:3 0 b5 :2 0 ba
:3 0 a1 :3 0 15
:3 0 4d :2 0 1482
22c8 22cb 1485 22c7
22cd 1487 22c6 22cf
:3 0 b5 :2 0 c9
:4 0 148a 22d1 22d3
:3 0 22c0 22d4 0
22d6 148d 22d7 22bf
22d6 0 22d8 148f
0 22d9 1491 22da
1fc2 22d9 0 22db
1496 0 255f 16
:3 0 de :2 0 1498
22dd 22de :3 0 22df
:2 0 91 :3 0 a1
:3 0 df :3 0 2e
:3 0 149a 22e3 22e5
4d :2 0 149c 22e2
22e8 22e1 22e9 0
2429 85 :3 0 4d
:2 0 22eb 22ec 0
2429 1fb :3 0 85
:3 0 91 :3 0 e0
:2 0 1fc :3 0 14a1
22f1 22f3 :3 0 22f4
2428 48 :3 0 23e
:3 0 23f :3 0 22f7
22f8 0 24 :2 0
24 :2 0 85 :3 0
bf :2 0 46 :2 0
14a4 22fd 22ff :3 0
2e :3 0 14a7 22f9
2302 22f6 2303 0
2426 1e6 :3 0 3b
:3 0 1af :3 0 116
:3 0 48 :4 0 240
1 :8 0 2310 21
:3 0 f4 :3 0 230b
230c 0 f5 :3 0
230d 230e 0 2310
14ac 235a f6 :3 0
21 :3 0 f4 :3 0
2313 2314 0 f5
:3 0 2315 2316 0
2350 ad :3 0 ae
:3 0 2318 2319 0
ad :3 0 bd :3 0
231b 231c 0 f7
:2 0 2 :4 0 241
:2 0 bf :2 0 46
:2 0 14af 2321 2323
:3 0 14b2 231d 2325
231a 2327 2326 :2 0
b0 :3 0 c0 :3 0
2329 232a 0 b2
:4 0 242 :4 0 b5
:2 0 b6 :3 0 14b6
232e 2330 :3 0 b5
:2 0 c9 :4 0 14b9
2332 2334 :3 0 b5
:2 0 fa :4 0 14bc
2336 2338 :3 0 b5
:2 0 f5 :3 0 14bf
233a 233c :3 0 b5
:2 0 fb :4 0 14c2
233e 2340 :3 0 b5
:2 0 fc :3 0 fd
:3 0 46 :2 0 fe
:2 0 14c5 2343 2347
14c9 2342 2349 :3 0
14cc 232b 234b :2 0
234d 14cf 234e 2328
234d 0 234f 14d1
0 2350 14d3 2353
:3 0 2353 0 2353
2352 2350 2351 :6 0
2355 3c :3 0 14d6
2357 14d8 2356 2355
:2 0 2358 14da :2 0
235a 0 235a 2359
2310 2358 :6 0 2426
3b :3 0 21 :3 0
f4 :3 0 235c 235d
0 21 :3 0 c3
:2 0 ff :3 0 235f
2361 0 14de 2360
2363 :3 0 2364 :2 0
ad :3 0 ae :3 0
2366 2367 0 ad
:3 0 bd :3 0 2369
236a 0 24 :2 0
2 :4 0 243 :2 0
bf :2 0 46 :2 0
14e1 236f 2371 :3 0
14e4 236b 2373 2368
2375 2374 :2 0 b0
:3 0 c0 :3 0 2377
2378 0 b2 :4 0
244 :4 0 b5 :2 0
b6 :3 0 14e8 237c
237e :3 0 b5 :2 0
c9 :4 0 14eb 2380
2382 :3 0 b5 :2 0
ca :4 0 14ee 2384
2386 :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 d6 :3 0
238b 238c 0 14f1
238a 238e bb :4 0
14f3 2389 2391 14f6
2388 2393 :3 0 b5
:2 0 11f :4 0 14f9
2395 2397 :3 0 b5
:2 0 b8 :4 0 14fc
2399 239b :3 0 b5
:2 0 48 :3 0 14ff
239d 239f :3 0 b5
:2 0 b8 :4 0 1502
23a1 23a3 :3 0 1505
2379 23a5 :2 0 23a7
1508 23a8 2376 23a7
0 23a9 150a 0
23d3 ad :3 0 ae
:3 0 23aa 23ab 0
ad :3 0 bd :3 0
23ad 23ae 0 46
:2 0 2 :4 0 245
:2 0 bf :2 0 46
:2 0 150c 23b3 23b5
:3 0 150f 23af 23b7
23ac 23b9 23b8 :2 0
b0 :3 0 c0 :3 0
23bb 23bc 0 b2
:4 0 246 :4 0 b5
:2 0 b6 :3 0 1513
23c0 23c2 :3 0 1516
23bd 23c4 :2 0 23c6
1519 23c7 23ba 23c6
0 23c8 151b 0
23d3 ce :3 0 122
:3 0 23c9 23ca 0
c2 :3 0 d6 :3 0
23cc 23cd 0 48
:3 0 d0 :3 0 151d
23cb 23d1 :2 0 23d3
1521 23d4 2365 23d3
0 23d5 1525 0
2426 76 :3 0 76
:3 0 b5 :2 0 247
:4 0 1527 23d8 23da
:3 0 b5 :2 0 248
:4 0 152a 23dc 23de
:3 0 b5 :2 0 249
:4 0 152d 23e0 23e2
:3 0 b5 :2 0 24a
:4 0 1530 23e4 23e6
:3 0 b5 :2 0 3b
:3 0 1533 23e8 23ea
:3 0 b5 :2 0 24b
:4 0 1536 23ec 23ee
:3 0 23d6 23ef 0
2426 a1 :3 0 5b
:3 0 4d :2 0 1539
23f1 23f4 c2 :3 0
d2 :2 0 d3 :3 0
23f6 23f8 0 153e
23f7 23fa :3 0 76
:3 0 76 :3 0 b5
:2 0 24c :4 0 1541
23fe 2400 :3 0 23fc
2401 0 2403 1544
240c 76 :3 0 76
:3 0 b5 :2 0 24d
:4 0 1546 2406 2408
:3 0 2404 2409 0
240b 1549 240d 23fb
2403 0 240e 0
240b 0 240e 154b
0 2426 a1 :3 0
5b :3 0 4d :2 0
154e 240f 2412 c2
:3 0 d2 :2 0 d3
:3 0 2414 2416 0
1553 2415 2418 :3 0
200 :8 0 241c 1556
241d 2419 241c 0
241e 1558 0 2426
85 :3 0 85 :3 0
bf :2 0 24 :2 0
155a 2421 2423 :3 0
241f 2424 0 2426
155d 2428 1fc :3 0
22f5 2426 :4 0 2429
1565 242a 22e0 2429
0 242b 1569 0
255f a1 :3 0 5b
:3 0 4d :2 0 156b
242c 242f c2 :3 0
c3 :2 0 d3 :3 0
2431 2433 0 1570
2432 2435 :3 0 92
:3 0 a1 :3 0 df
:3 0 30 :3 0 1573
2439 243b 4d :2 0
1575 2438 243e 2437
243f 0 2555 85
:3 0 4d :2 0 2441
2442 0 2555 1fb
:3 0 85 :3 0 92
:3 0 e0 :2 0 1fc
:3 0 157a 2447 2449
:3 0 244a 2554 48
:3 0 23e :3 0 23f
:3 0 244d 244e 0
24 :2 0 24 :2 0
85 :3 0 bf :2 0
46 :2 0 157d 2453
2455 :3 0 30 :3 0
1580 244f 2458 244c
2459 0 2552 1e6
:3 0 3b :3 0 1af
:3 0 116 :3 0 48
:4 0 240 1 :8 0
2466 21 :3 0 f4
:3 0 2461 2462 0
f5 :3 0 2463 2464
0 2466 1585 24b0
f6 :3 0 21 :3 0
f4 :3 0 2469 246a
0 f5 :3 0 246b
246c 0 24a6 ad
:3 0 ae :3 0 246e
246f 0 ad :3 0
bd :3 0 2471 2472
0 f7 :2 0 2
:4 0 24e :2 0 bf
:2 0 46 :2 0 1588
2477 2479 :3 0 158b
2473 247b 2470 247d
247c :2 0 b0 :3 0
c0 :3 0 247f 2480
0 b2 :4 0 24f
:4 0 b5 :2 0 b6
:3 0 158f 2484 2486
:3 0 b5 :2 0 c9
:4 0 1592 2488 248a
:3 0 b5 :2 0 fa
:4 0 1595 248c 248e
:3 0 b5 :2 0 f5
:3 0 1598 2490 2492
:3 0 b5 :2 0 fb
:4 0 159b 2494 2496
:3 0 b5 :2 0 fc
:3 0 fd :3 0 46
:2 0 fe :2 0 159e
2499 249d 15a2 2498
249f :3 0 15a5 2481
24a1 :2 0 24a3 15a8
24a4 247e 24a3 0
24a5 15aa 0 24a6
15ac 24a9 :3 0 24a9
0 24a9 24a8 24a6
24a7 :6 0 24ab 3f
:3 0 15af 24ad 15b1
24ac 24ab :2 0 24ae
15b3 :2 0 24b0 0
24b0 24af 2466 24ae
:6 0 2552 3e :3 0
21 :3 0 f4 :3 0
24b2 24b3 0 21
:3 0 c3 :2 0 ff
:3 0 24b5 24b7 0
15b7 24b6 24b9 :3 0
24ba :2 0 ad :3 0
ae :3 0 24bc 24bd
0 ad :3 0 bd
:3 0 24bf 24c0 0
24 :2 0 2 :4 0
250 :2 0 bf :2 0
46 :2 0 15ba 24c5
24c7 :3 0 15bd 24c1
24c9 24be 24cb 24ca
:2 0 b0 :3 0 c0
:3 0 24cd 24ce 0
b2 :4 0 251 :4 0
b5 :2 0 b6 :3 0
15c1 24d2 24d4 :3 0
b5 :2 0 c9 :4 0
15c4 24d6 24d8 :3 0
b5 :2 0 ca :4 0
15c7 24da 24dc :3 0
b5 :2 0 a1 :3 0
ba :3 0 c2 :3 0
d6 :3 0 24e1 24e2
0 15ca 24e0 24e4
bb :4 0 15cc 24df
24e7 15cf 24de 24e9
:3 0 b5 :2 0 11f
:4 0 15d2 24eb 24ed
:3 0 b5 :2 0 b8
:4 0 15d5 24ef 24f1
:3 0 b5 :2 0 48
:3 0 15d8 24f3 24f5
:3 0 b5 :2 0 b8
:4 0 15db 24f7 24f9
:3 0 15de 24cf 24fb
:2 0 24fd 15e1 24fe
24cc 24fd 0 24ff
15e3 0 2529 ad
:3 0 ae :3 0 2500
2501 0 ad :3 0
bd :3 0 2503 2504
0 46 :2 0 2
:4 0 252 :2 0 bf
:2 0 46 :2 0 15e5
2509 250b :3 0 15e8
2505 250d 2502 250f
250e :2 0 b0 :3 0
c0 :3 0 2511 2512
0 b2 :4 0 253
:4 0 b5 :2 0 b6
:3 0 15ec 2516 2518
:3 0 15ef 2513 251a
:2 0 251c 15f2 251d
2510 251c 0 251e
15f4 0 2529 ce
:3 0 122 :3 0 251f
2520 0 c2 :3 0
d6 :3 0 2522 2523
0 48 :3 0 d0
:3 0 15f6 2521 2527
:2 0 2529 15fa 252a
24bb 2529 0 252b
15fe 0 2552 76
:3 0 76 :3 0 b5
:2 0 247 :4 0 1600
252e 2530 :3 0 b5
:2 0 248 :4 0 1603
2532 2534 :3 0 b5
:2 0 249 :4 0 1606
2536 2538 :3 0 b5
:2 0 24a :4 0 1609
253a 253c :3 0 b5
:2 0 3b :3 0 160c
253e 2540 :3 0 b5
:2 0 24b :4 0 160f
2542 2544 :3 0 b5
:2 0 254 :4 0 1612
2546 2548 :3 0 252c
2549 0 2552 85
:3 0 85 :3 0 bf
:2 0 24 :2 0 1615
254d 254f :3 0 254b
2550 0 2552 1618
2554 1fc :3 0 244b
2552 :4 0 2555 161e
2556 2436 2555 0
2557 1622 0 255f
74 :3 0 74 :3 0
b5 :2 0 76 :3 0
1624 255a 255c :3 0
2558 255d 0 255f
1627 2561 1b71 1be7
0 2562 0 255f
0 2562 162f 0
355e 74 :3 0 74
:3 0 b5 :2 0 255
:4 0 1632 2565 2567
:3 0 2563 2568 0
355e 256 :3 0 93
:3 0 74 :3 0 256b
256c 0 256d :2 0
355e 1fc :3 0 93
:3 0 39 :4 0 2573
:2 0 29e5 2570 2571
:3 0 93 :3 0 1bf
:3 0 2574 2575 :3 0
21 :3 0 f4 :3 0
2577 2578 0 4d
:2 0 2579 257a 0
257c 1635 2583 21
:3 0 f4 :3 0 257d
257e 0 189 :2 0
257f 2580 0 2582
1637 2584 2576 257c
0 2585 0 2582
0 2585 1639 0
29e5 21 :3 0 f4
:3 0 2586 2587 0
21 :3 0 c3 :2 0
ff :3 0 2589 258b
0 163e 258a 258d
:3 0 258e :2 0 200
:8 0 2592 1641 2593
258f 2592 0 2594
1643 0 29e5 a1
:3 0 4f :3 0 4d
:2 0 1645 2595 2598
d2 :2 0 4d :2 0
164a 259a 259c :3 0
a1 :3 0 5b :3 0
4d :2 0 164d 259e
25a1 c2 :3 0 c3
:2 0 c4 :3 0 25a3
25a5 0 1652 25a4
25a7 :3 0 259d 25a9
25a8 :2 0 a1 :3 0
5b :3 0 4d :2 0
1655 25ab 25ae c2
:3 0 c3 :2 0 d1
:3 0 25b0 25b2 0
165a 25b1 25b4 :3 0
25aa 25b6 25b5 :2 0
a1 :3 0 5b :3 0
4d :2 0 165d 25b8
25bb c2 :3 0 c3
:2 0 d3 :3 0 25bd
25bf 0 1662 25be
25c1 :3 0 14 :3 0
c5 :2 0 1665 25c4
25c5 :3 0 25c6 :2 0
25c2 25c8 25c7 :2 0
25c9 :2 0 25b7 25cb
25ca :2 0 256 :3 0
95 :4 0 25d0 :2 0
26a3 25ce 25d1 :3 0
95 :3 0 28 :4 0
25d5 :2 0 26a3 25d2
25d3 :3 0 95 :3 0
1bf :3 0 25d6 25d7
:3 0 21 :3 0 f4
:3 0 25d9 25da 0
4d :2 0 25db 25dc
0 25de 1667 25e5
21 :3 0 f4 :3 0
25df 25e0 0 189
:2 0 25e1 25e2 0
25e4 1669 25e6 25d8
25de 0 25e7 0
25e4 0 25e7 166b
0 26a3 21 :3 0
f4 :3 0 25e8 25e9
0 21 :3 0 d2
:2 0 ff :3 0 25eb
25ed 0 1670 25ec
25ef :3 0 25f0 :2 0
257 :3 0 95 :4 0
25f5 :2 0 25fb 25f3
0 21 :3 0 f4
:3 0 25f6 25f7 0
f5 :3 0 25f8 25f9
0 25fb 1673 2645
f6 :3 0 21 :3 0
f4 :3 0 25fe 25ff
0 f5 :3 0 2600
2601 0 263b ad
:3 0 ae :3 0 2603
2604 0 ad :3 0
bd :3 0 2606 2607
0 f7 :2 0 2
:4 0 258 :2 0 bf
:2 0 46 :2 0 1676
260c 260e :3 0 1679
2608 2610 2605 2612
2611 :2 0 b0 :3 0
c0 :3 0 2614 2615
0 b2 :4 0 259
:4 0 b5 :2 0 b6
:3 0 167d 2619 261b
:3 0 b5 :2 0 c9
:4 0 1680 261d 261f
:3 0 b5 :2 0 fa
:4 0 1683 2621 2623
:3 0 b5 :2 0 f5
:3 0 1686 2625 2627
:3 0 b5 :2 0 fb
:4 0 1689 2629 262b
:3 0 b5 :2 0 fc
:3 0 fd :3 0 46
:2 0 fe :2 0 168c
262e 2632 1690 262d
2634 :3 0 1693 2616
2636 :2 0 2638 1696
2639 2613 2638 0
263a 1698 0 263b
169a 263e :3 0 263e
0 263e 263d 263b
263c :6 0 2640 42
:3 0 169d 2642 169f
2641 2640 :2 0 2643
16a1 :2 0 2645 0
2645 2644 25fb 2643
:6 0 2649 41 :3 0
25a :3 0 2647 :4 0
2649 16a3 26a0 257
:3 0 95 :4 0 264d
:2 0 2653 264b 0
21 :3 0 f4 :3 0
264e 264f 0 f5
:3 0 2650 2651 0
2653 16a6 269d f6
:3 0 21 :3 0 f4
:3 0 2656 2657 0
f5 :3 0 2658 2659
0 2693 ad :3 0
ae :3 0 265b 265c
0 ad :3 0 bd
:3 0 265e 265f 0
f7 :2 0 2 :4 0
25b :2 0 bf :2 0
46 :2 0 16a9 2664
2666 :3 0 16ac 2660
2668 265d 266a 2669
:2 0 b0 :3 0 c0
:3 0 266c 266d 0
b2 :4 0 25c :4 0
b5 :2 0 b6 :3 0
16b0 2671 2673 :3 0
b5 :2 0 c9 :4 0
16b3 2675 2677 :3 0
b5 :2 0 fa :4 0
16b6 2679 267b :3 0
b5 :2 0 f5 :3 0
16b9 267d 267f :3 0
b5 :2 0 fb :4 0
16bc 2681 2683 :3 0
b5 :2 0 fc :3 0
fd :3 0 46 :2 0
fe :2 0 16bf 2686
268a 16c3 2685 268c
:3 0 16c6 266e 268e
:2 0 2690 16c9 2691
266b 2690 0 2692
16cb 0 2693 16cd
2696 :3 0 2696 0
2696 2695 2693 2694
:6 0 2698 44 :3 0
16d0 269a 16d2 2699
2698 :2 0 269b 16d4
:2 0 269d 0 269d
269c 2653 269b :6 0
269f 41 :3 0 16d6
26a1 25f1 2649 0
26a2 0 269f 0
26a2 16d8 0 26a3
16db 26a4 25cc 26a3
0 26a5 16e0 0
29e5 2e :3 0 16
:3 0 26a6 26a7 0
29e5 30 :3 0 17
:3 0 26a9 26aa 0
29e5 a1 :3 0 4f
:3 0 4d :2 0 16e2
26ac 26af 10e :2 0
4d :2 0 16e7 26b1
26b3 :3 0 fc :3 0
45 :3 0 46 :2 0
46 :2 0 16ea 26b5
26b9 d2 :2 0 46
:4 0 16f0 26bb 26bd
:3 0 47 :3 0 198
:4 0 26c0 26c1 :3 0
26bf 26c2 0 26c7
4e :3 0 4d :2 0
26c4 26c5 0 26c7
16f3 2801 137 :3 0
a1 :3 0 4f :3 0
4d :2 0 16f6 26c9
26cc 16f9 26c8 26ce
c3 :2 0 4d :2 0
16fd 26d0 26d2 :3 0
25d :3 0 25e :3 0
82 :3 0 97 :3 0
98 :3 0 25 :3 0
9a :3 0 39 :3 0
1a0 :4 0 25f 1
:8 0 26e3 21 :3 0
f4 :3 0 26de 26df
0 f5 :3 0 26e0
26e1 0 26e3 1700
272d f6 :3 0 21
:3 0 f4 :3 0 26e6
26e7 0 f5 :3 0
26e8 26e9 0 2723
ad :3 0 ae :3 0
26eb 26ec 0 ad
:3 0 bd :3 0 26ee
26ef 0 f7 :2 0
2 :4 0 260 :2 0
bf :2 0 46 :2 0
1703 26f4 26f6 :3 0
1706 26f0 26f8 26ed
26fa 26f9 :2 0 b0
:3 0 c0 :3 0 26fc
26fd 0 b2 :4 0
261 :4 0 b5 :2 0
b6 :3 0 170a 2701
2703 :3 0 b5 :2 0
c9 :4 0 170d 2705
2707 :3 0 b5 :2 0
fa :4 0 1710 2709
270b :3 0 b5 :2 0
f5 :3 0 1713 270d
270f :3 0 b5 :2 0
fb :4 0 1716 2711
2713 :3 0 b5 :2 0
fc :3 0 fd :3 0
46 :2 0 fe :2 0
1719 2716 271a 171d
2715 271c :3 0 1720
26fe 271e :2 0 2720
1723 2721 26fb 2720
0 2722 1725 0
2723 1727 2726 :3 0
2726 0 2726 2725
2723 2724 :6 0 2728
46 :3 0 172a 272a
172c 2729 2728 :2 0
272b 172e :2 0 272d
0 272d 272c 26e3
272b :6 0 27fd 41
:3 0 a1 :3 0 82
:3 0 4d :2 0 1730
272f 2732 10e :2 0
4d :2 0 1735 2734
2736 :3 0 257 :3 0
93 :4 0 273b :2 0
2741 2739 0 21
:3 0 f4 :3 0 273c
273d 0 f5 :3 0
273e 273f 0 2741
1738 278b f6 :3 0
21 :3 0 f4 :3 0
2744 2745 0 f5
:3 0 2746 2747 0
2781 ad :3 0 ae
:3 0 2749 274a 0
ad :3 0 bd :3 0
274c 274d 0 f7
:2 0 2 :4 0 262
:2 0 bf :2 0 46
:2 0 173b 2752 2754
:3 0 173e 274e 2756
274b 2758 2757 :2 0
b0 :3 0 c0 :3 0
275a 275b 0 b2
:4 0 263 :4 0 b5
:2 0 b6 :3 0 1742
275f 2761 :3 0 b5
:2 0 c9 :4 0 1745
2763 2765 :3 0 b5
:2 0 fa :4 0 1748
2767 2769 :3 0 b5
:2 0 f5 :3 0 174b
276b 276d :3 0 b5
:2 0 fb :4 0 174e
276f 2771 :3 0 b5
:2 0 fc :3 0 fd
:3 0 46 :2 0 fe
:2 0 1751 2774 2778
1755 2773 277a :3 0
1758 275c 277c :2 0
277e 175b 277f 2759
277e 0 2780 175d
0 2781 175f 2784
:3 0 2784 0 2784
2783 2781 2782 :6 0
2786 48 :3 0 1762
2788 1764 2787 2786
:2 0 2789 1766 :2 0
278b 0 278b 278a
2741 2789 :6 0 27fa
41 :3 0 ad :3 0
ae :3 0 278d 278e
0 ad :3 0 bd
:3 0 2790 2791 0
24 :2 0 2 :4 0
264 :2 0 bf :2 0
46 :2 0 1768 2796
2798 :3 0 176b 2792
279a 278f 279c 279b
:2 0 b0 :3 0 c0
:3 0 279e 279f 0
b2 :4 0 265 :4 0
b5 :2 0 b6 :3 0
176f 27a3 27a5 :3 0
b5 :2 0 c9 :4 0
1772 27a7 27a9 :3 0
b5 :2 0 ca :4 0
1775 27ab 27ad :3 0
b5 :2 0 a1 :3 0
ba :3 0 c2 :3 0
266 :3 0 27b2 27b3
0 1778 27b1 27b5
bb :4 0 177a 27b0
27b8 177d 27af 27ba
:3 0 b5 :2 0 11f
:4 0 1780 27bc 27be
:3 0 b5 :2 0 b8
:4 0 1783 27c0 27c2
:3 0 b5 :2 0 39
:3 0 1786 27c4 27c6
:3 0 b5 :2 0 b8
:4 0 1789 27c8 27ca
:3 0 178c 27a0 27cc
:2 0 27ce 178f 27cf
279d 27ce 0 27d0
1791 0 27fa ad
:3 0 ae :3 0 27d1
27d2 0 ad :3 0
bd :3 0 27d4 27d5
0 46 :2 0 2
:4 0 267 :2 0 bf
:2 0 46 :2 0 1793
27da 27dc :3 0 1796
27d6 27de 27d3 27e0
27df :2 0 b0 :3 0
c0 :3 0 27e2 27e3
0 b2 :4 0 268
:4 0 b5 :2 0 b6
:3 0 179a 27e7 27e9
:3 0 179d 27e4 27eb
:2 0 27ed 17a0 27ee
27e1 27ed 0 27ef
17a2 0 27fa ce
:3 0 122 :3 0 27f0
27f1 0 c2 :3 0
266 :3 0 27f3 27f4
0 39 :3 0 d0
:3 0 17a4 27f2 27f8
:2 0 27fa 17a8 27fb
2737 27fa 0 27fc
17ad 0 27fd 17af
27fe 26d3 27fd 0
27ff 17b2 0 2800
17b4 2802 26be 26c7
0 2803 0 2800
0 2803 17b6 0
2986 88 :3 0 269
:3 0 47 :3 0 25
:3 0 26 :3 0 39
:3 0 65 :3 0 4f
:3 0 2e :3 0 30
:3 0 31 :3 0 32
:3 0 41 :3 0 42
:3 0 60 :3 0 58
:3 0 56 :3 0 59
:3 0 5a :3 0 54
:3 0 5b :3 0 45
:3 0 52 :3 0 4c
:3 0 5c :3 0 57
:3 0 51 :3 0 5e
:3 0 63 :3 0 29
:3 0 a1 :3 0 5e
:3 0 4d :2 0 17b9
2822 2825 4d :2 0
67 :2 0 67 :2 0
17bc 2805 282a 2804
282b 0 2986 88
:3 0 c3 :2 0 4d
:2 0 17df 282e 2830
:3 0 257 :3 0 93
:4 0 2835 :2 0 283b
2833 0 21 :3 0
f4 :3 0 2836 2837
0 f5 :3 0 2838
2839 0 283b 17e2
2885 f6 :3 0 21
:3 0 f4 :3 0 283e
283f 0 f5 :3 0
2840 2841 0 287b
ad :3 0 ae :3 0
2843 2844 0 ad
:3 0 bd :3 0 2846
2847 0 f7 :2 0
2 :4 0 26a :2 0
bf :2 0 46 :2 0
17e5 284c 284e :3 0
17e8 2848 2850 2845
2852 2851 :2 0 b0
:3 0 c0 :3 0 2854
2855 0 b2 :4 0
26b :4 0 b5 :2 0
b6 :3 0 17ec 2859
285b :3 0 b5 :2 0
c9 :4 0 17ef 285d
285f :3 0 b5 :2 0
fa :4 0 17f2 2861
2863 :3 0 b5 :2 0
f5 :3 0 17f5 2865
2867 :3 0 b5 :2 0
fb :4 0 17f8 2869
286b :3 0 b5 :2 0
fc :3 0 fd :3 0
46 :2 0 fe :2 0
17fb 286e 2872 17ff
286d 2874 :3 0 1802
2856 2876 :2 0 2878
1805 2879 2853 2878
0 287a 1807 0
287b 1809 287e :3 0
287e 0 287e 287d
287b 287c :6 0 2880
4a :3 0 180c 2882
180e 2881 2880 :2 0
2883 1810 :2 0 2885
0 2885 2884 283b
2883 :6 0 2900 41
:3 0 88 :3 0 c2
:3 0 e0 :2 0 26c
:3 0 2888 288a 0
1814 2889 288c :3 0
88 :3 0 c2 :3 0
26d :3 0 288f 2890
0 288e 2891 0
2893 1817 2894 288d
2893 0 2895 1819
0 2900 ad :3 0
ae :3 0 2896 2897
0 ad :3 0 bd
:3 0 2899 289a 0
24 :2 0 2 :4 0
26e :2 0 bf :2 0
46 :2 0 181b 289f
28a1 :3 0 181e 289b
28a3 2898 28a5 28a4
:2 0 b0 :3 0 c0
:3 0 28a7 28a8 0
b2 :4 0 26f :4 0
b5 :2 0 b6 :3 0
1822 28ac 28ae :3 0
b5 :2 0 c9 :4 0
1825 28b0 28b2 :3 0
b5 :2 0 ca :4 0
1828 28b4 28b6 :3 0
b5 :2 0 a1 :3 0
ba :3 0 88 :3 0
182b 28ba 28bc bb
:4 0 182d 28b9 28bf
1830 28b8 28c1 :3 0
b5 :2 0 11f :4 0
1833 28c3 28c5 :3 0
b5 :2 0 b8 :4 0
1836 28c7 28c9 :3 0
b5 :2 0 47 :3 0
1839 28cb 28cd :3 0
b5 :2 0 b8 :4 0
183c 28cf 28d1 :3 0
183f 28a9 28d3 :2 0
28d5 1842 28d6 28a6
28d5 0 28d7 1844
0 2900 ad :3 0
ae :3 0 28d8 28d9
0 ad :3 0 bd
:3 0 28db 28dc 0
46 :2 0 2 :4 0
270 :2 0 bf :2 0
46 :2 0 1846 28e1
28e3 :3 0 1849 28dd
28e5 28da 28e7 28e6
:2 0 b0 :3 0 c0
:3 0 28e9 28ea 0
b2 :4 0 271 :4 0
b5 :2 0 b6 :3 0
184d 28ee 28f0 :3 0
1850 28eb 28f2 :2 0
28f4 1853 28f5 28e8
28f4 0 28f6 1855
0 2900 ce :3 0
122 :3 0 28f7 28f8
0 88 :3 0 47
:3 0 d0 :3 0 1857
28f9 28fd :2 0 2900
d9 :3 0 185b 2982
fc :3 0 45 :3 0
46 :2 0 46 :2 0
1861 2901 2905 d2
:2 0 46 :4 0 1867
2907 2909 :3 0 290a
:2 0 fc :3 0 4b
:3 0 46 :2 0 46
:2 0 186a 290c 2910
d2 :2 0 1b9 :4 0
1870 2912 2914 :3 0
2915 :2 0 290b 2917
2916 :2 0 199 :3 0
114 :3 0 19a :3 0
39 :3 0 114 :4 0
272 1 :8 0 2934
1bf :4 0 291f :3 0
d0 :3 0 d2 :2 0
1875 2922 2923 :3 0
21 :3 0 f4 :3 0
2925 2926 0 4d
:2 0 2927 2928 0
292a 1878 2931 21
:3 0 f4 :3 0 292b
292c 0 189 :2 0
292d 292e 0 2930
187a 2932 2924 292a
0 2933 0 2930
0 2933 187c 0
2934 187f 297e f6
:3 0 21 :3 0 f4
:3 0 2937 2938 0
f5 :3 0 2939 293a
0 2974 ad :3 0
ae :3 0 293c 293d
0 ad :3 0 bd
:3 0 293f 2940 0
f7 :2 0 2 :4 0
273 :2 0 bf :2 0
46 :2 0 1882 2945
2947 :3 0 1885 2941
2949 293e 294b 294a
:2 0 b0 :3 0 c0
:3 0 294d 294e 0
b2 :4 0 274 :4 0
b5 :2 0 b6 :3 0
1889 2952 2954 :3 0
b5 :2 0 c9 :4 0
188c 2956 2958 :3 0
b5 :2 0 fa :4 0
188f 295a 295c :3 0
b5 :2 0 f5 :3 0
1892 295e 2960 :3 0
b5 :2 0 fb :4 0
1895 2962 2964 :3 0
b5 :2 0 fc :3 0
fd :3 0 46 :2 0
fe :2 0 1898 2967
296b 189c 2966 296d
:3 0 189f 294f 296f
:2 0 2971 18a2 2972
294c 2971 0 2973
18a4 0 2974 18a6
2977 :3 0 2977 0
2977 2976 2974 2975
:6 0 2979 4c :3 0
18a9 297b 18ab 297a
2979 :2 0 297c 18ad
:2 0 297e 0 297e
297d 2934 297c :6 0
2980 41 :3 0 18af
2981 2918 2980 0
2983 2831 2900 0
2983 18b1 0 2986
200 :8 0 2986 18b4
29de a1 :3 0 4c
:3 0 4d :2 0 18b9
2987 298a c2 :3 0
c3 :2 0 c4 :3 0
298c 298e 0 18be
298d 2990 :3 0 41
:3 0 5 :3 0 2992
2993 0 2998 42
:3 0 6 :3 0 2995
2996 0 2998 18c1
2999 2991 2998 0
299a 18c4 0 29dd
88 :3 0 269 :3 0
47 :3 0 25 :3 0
26 :3 0 39 :3 0
65 :3 0 4f :3 0
2e :3 0 30 :3 0
31 :3 0 32 :3 0
41 :3 0 42 :3 0
60 :3 0 58 :3 0
56 :3 0 59 :3 0
5a :3 0 54 :3 0
5b :3 0 45 :3 0
52 :3 0 4c :3 0
5c :3 0 57 :3 0
51 :3 0 5e :3 0
63 :3 0 29 :3 0
4d :2 0 4d :2 0
67 :2 0 67 :2 0
18c6 299c 29bd 299b
29be 0 29dd 88
:3 0 d2 :2 0 4d
:2 0 18e9 29c1 29c3
:3 0 87 :3 0 87
:3 0 bf :2 0 46
:2 0 18ec 29c7 29c9
:3 0 29c5 29ca 0
29cc 18ef 29cd 29c4
29cc 0 29ce 18f1
0 29dd 87 :3 0
a1 :3 0 d2 :2 0
55 :3 0 4d :2 0
18f3 29d0 29d4 18f8
29d1 29d6 :3 0 200
:8 0 29da 18fb 29db
29d7 29da 0 29dc
18fd 0 29dd 18ff
29df 26b4 2986 0
29e0 0 29dd 0
29e0 1904 0 29e5
25a :5 0 29e3 4e
0 29e4 1907 29e3
29e2 29e5 1909 29e7
1fc :4 0 29e5 :4 0
355e 257 :3 0 93
:4 0 29eb :2 0 29f1
29e9 0 21 :3 0
f4 :3 0 29ec 29ed
0 f5 :3 0 29ee
29ef 0 29f1 1912
2a3b f6 :3 0 21
:3 0 f4 :3 0 29f4
29f5 0 f5 :3 0
29f6 29f7 0 2a31
ad :3 0 ae :3 0
29f9 29fa 0 ad
:3 0 bd :3 0 29fc
29fd 0 f7 :2 0
2 :4 0 275 :2 0
bf :2 0 46 :2 0
1915 2a02 2a04 :3 0
1918 29fe 2a06 29fb
2a08 2a07 :2 0 b0
:3 0 c0 :3 0 2a0a
2a0b 0 b2 :4 0
276 :4 0 b5 :2 0
b6 :3 0 191c 2a0f
2a11 :3 0 b5 :2 0
c9 :4 0 191f 2a13
2a15 :3 0 b5 :2 0
fa :4 0 1922 2a17
2a19 :3 0 b5 :2 0
f5 :3 0 1925 2a1b
2a1d :3 0 b5 :2 0
fb :4 0 1928 2a1f
2a21 :3 0 b5 :2 0
fc :3 0 fd :3 0
46 :2 0 fe :2 0
192b 2a24 2a28 192f
2a23 2a2a :3 0 1932
2a0c 2a2c :2 0 2a2e
1935 2a2f 2a09 2a2e
0 2a30 1937 0
2a31 1939 2a34 :3 0
2a34 0 2a34 2a33
2a31 2a32 :6 0 2a36
4e :3 0 193c 2a38
193e 2a37 2a36 :2 0
2a39 1940 :2 0 2a3b
0 2a3b 2a3a 29f1
2a39 :6 0 355e 1
:3 0 88 :3 0 c2
:3 0 d2 :2 0 277
:3 0 2a3e 2a40 0
1944 2a3f 2a42 :3 0
2a43 :2 0 88 :3 0
c3 :2 0 4d :2 0
1949 2a46 2a48 :3 0
2a49 :2 0 a1 :3 0
4f :3 0 4d :2 0
194c 2a4b 2a4e 10e
:2 0 4d :2 0 1951
2a50 2a52 :3 0 2a53
:2 0 2a4a 2a55 2a54
:2 0 2a56 :2 0 2a44
2a58 2a57 :2 0 ad
:3 0 ae :3 0 2a5a
2a5b 0 ad :3 0
bd :3 0 2a5d 2a5e
0 24 :2 0 2
:4 0 278 :2 0 bf
:2 0 46 :2 0 1954
2a63 2a65 :3 0 1957
2a5f 2a67 2a5c 2a69
2a68 :2 0 b0 :3 0
c0 :3 0 2a6b 2a6c
0 b2 :4 0 279
:4 0 b5 :2 0 b6
:3 0 195b 2a70 2a72
:3 0 b5 :2 0 c9
:4 0 195e 2a74 2a76
:3 0 b5 :2 0 ca
:4 0 1961 2a78 2a7a
:3 0 b5 :2 0 a1
:3 0 ba :3 0 88
:3 0 1964 2a7e 2a80
bb :4 0 1966 2a7d
2a83 1969 2a7c 2a85
:3 0 b5 :2 0 11f
:4 0 196c 2a87 2a89
:3 0 b5 :2 0 b8
:4 0 196f 2a8b 2a8d
:3 0 b5 :2 0 47
:3 0 1972 2a8f 2a91
:3 0 b5 :2 0 b8
:4 0 1975 2a93 2a95
:3 0 1978 2a6d 2a97
:2 0 2a99 197b 2a9a
2a6a 2a99 0 2a9b
197d 0 2ac3 ad
:3 0 ae :3 0 2a9c
2a9d 0 ad :3 0
bd :3 0 2a9f 2aa0
0 46 :2 0 2
:4 0 27a :2 0 bf
:2 0 46 :2 0 197f
2aa5 2aa7 :3 0 1982
2aa1 2aa9 2a9e 2aab
2aaa :2 0 b0 :3 0
c0 :3 0 2aad 2aae
0 b2 :4 0 27b
:4 0 b5 :2 0 b6
:3 0 1986 2ab2 2ab4
:3 0 1989 2aaf 2ab6
:2 0 2ab8 198c 2ab9
2aac 2ab8 0 2aba
198e 0 2ac3 ce
:3 0 122 :3 0 2abb
2abc 0 88 :3 0
47 :3 0 d0 :3 0
1990 2abd 2ac1 :2 0
2ac3 1994 2ac4 2a59
2ac3 0 2ac5 1998
0 355e 8b :3 0
c3 :2 0 46 :2 0
199c 2ac7 2ac9 :3 0
27 :3 0 27c :4 0
2acb 2acc 0 2dec
28 :3 0 18b :4 0
2ace 2acf 0 2dec
3a :3 0 18b :4 0
2ad1 2ad2 0 2dec
256 :3 0 9c :4 0
2ad7 :2 0 2dec 2ad5
2ad8 :3 0 85 :3 0
4d :2 0 2ad9 2ada
0 2dec 1fc :3 0
9c :3 0 26 :3 0
39 :3 0 48 :3 0
33 :3 0 49 :3 0
34 :3 0 35 :3 0
36 :4 0 2ae7 :2 0
2d1b 2add 2ae8 :3 0
199f :3 0 9c :3 0
1bf :3 0 2ae9 2aea
:3 0 21 :3 0 f4
:3 0 2aec 2aed 0
4d :2 0 2aee 2aef
0 2af1 19a8 2af8
21 :3 0 f4 :3 0
2af2 2af3 0 189
:2 0 2af4 2af5 0
2af7 19aa 2af9 2aeb
2af1 0 2afa 0
2af7 0 2afa 19ac
0 2d1b 21 :3 0
f4 :3 0 2afb 2afc
0 21 :3 0 c3
:2 0 ff :3 0 2afe
2b00 0 19b1 2aff
2b02 :3 0 2b03 :2 0
200 :8 0 2b07 19b4
2b08 2b04 2b07 0
2b09 19b6 0 2d1b
48 :3 0 de :2 0
19b8 2b0b 2b0c :3 0
2b0d :2 0 f0 :3 0
11a :3 0 2b0f 2b10
0 48 :3 0 39
:3 0 19ba 2b11 2b14
d2 :2 0 4d :2 0
19bf 2b16 2b18 :3 0
2b0e 2b1a 2b19 :2 0
a1 :3 0 df :3 0
27 :3 0 19c2 2b1d
2b1f 4d :2 0 19c4
2b1c 2b22 d2 :2 0
4d :2 0 19c9 2b24
2b26 :3 0 2b1b 2b28
2b27 :2 0 27 :3 0
26 :3 0 2b2a 2b2b
0 2b2d 19cc 2b2e
2b29 2b2d 0 2b2f
19ce 0 2d1b f0
:3 0 11a :3 0 2b30
2b31 0 28 :3 0
39 :3 0 19d0 2b32
2b35 c3 :2 0 4d
:2 0 19d5 2b37 2b39
:3 0 85 :3 0 c3
:2 0 4d :2 0 19da
2b3c 2b3e :3 0 a7
:3 0 a0 :3 0 37
:3 0 a2 :3 0 2e
:3 0 a3 :3 0 38
:3 0 a4 :3 0 30
:3 0 a5 :3 0 31
:3 0 a6 :3 0 32
:3 0 9d :3 0 3a
:4 0 27d 1 :8 0
2b65 1bf :4 0 2b50
:3 0 d0 :3 0 d2
:2 0 19df 2b53 2b54
:3 0 21 :3 0 f4
:3 0 2b56 2b57 0
4d :2 0 2b58 2b59
0 2b5b 19e2 2b62
21 :3 0 f4 :3 0
2b5c 2b5d 0 189
:2 0 2b5e 2b5f 0
2b61 19e4 2b63 2b55
2b5b 0 2b64 0
2b61 0 2b64 19e6
0 2b65 19e9 2baf
f6 :3 0 21 :3 0
f4 :3 0 2b68 2b69
0 f5 :3 0 2b6a
2b6b 0 2ba5 ad
:3 0 ae :3 0 2b6d
2b6e 0 ad :3 0
bd :3 0 2b70 2b71
0 f7 :2 0 2
:4 0 27e :2 0 bf
:2 0 46 :2 0 19ec
2b76 2b78 :3 0 19ef
2b72 2b7a 2b6f 2b7c
2b7b :2 0 b0 :3 0
c0 :3 0 2b7e 2b7f
0 b2 :4 0 27f
:4 0 b5 :2 0 b6
:3 0 19f3 2b83 2b85
:3 0 b5 :2 0 c9
:4 0 19f6 2b87 2b89
:3 0 b5 :2 0 fa
:4 0 19f9 2b8b 2b8d
:3 0 b5 :2 0 f5
:3 0 19fc 2b8f 2b91
:3 0 b5 :2 0 fb
:4 0 19ff 2b93 2b95
:3 0 b5 :2 0 fc
:3 0 fd :3 0 46
:2 0 fe :2 0 1a02
2b98 2b9c 1a06 2b97
2b9e :3 0 1a09 2b80
2ba0 :2 0 2ba2 1a0c
2ba3 2b7d 2ba2 0
2ba4 1a0e 0 2ba5
1a10 2ba8 :3 0 2ba8
0 2ba8 2ba7 2ba5
2ba6 :6 0 2baa 51
:3 0 1a13 2bac 1a15
2bab 2baa :2 0 2bad
1a17 :2 0 2baf 0
2baf 2bae 2b65 2bad
:6 0 2bb1 50 :3 0
1a19 2bb2 2b3f 2bb1
0 2bb3 1a1b 0
2bcc 2e :3 0 18b
:4 0 2bb4 2bb5 0
2bcc 30 :3 0 18b
:4 0 2bb7 2bb8 0
2bcc 31 :3 0 18b
:4 0 2bba 2bbb 0
2bcc 32 :3 0 18b
:4 0 2bbd 2bbe 0
2bcc 37 :3 0 18b
:4 0 2bc0 2bc1 0
2bcc 38 :3 0 18b
:4 0 2bc3 2bc4 0
2bcc 28 :3 0 39
:3 0 2bc6 2bc7 0
2bcc 85 :3 0 4d
:2 0 2bc9 2bca 0
2bcc 1a1d 2bcd 2b3a
2bcc 0 2bce 1a27
0 2d1b 85 :3 0
c3 :2 0 4d :2 0
1a2b 2bd0 2bd2 :3 0
3a :3 0 de :2 0
1a2e 2bd5 2bd6 :3 0
2bd7 :2 0 2bd3 2bd9
2bd8 :2 0 a7 :3 0
a0 :3 0 a2 :3 0
a3 :3 0 a4 :3 0
a5 :3 0 a6 :3 0
9d :3 0 3a :4 0
280 1 :8 0 2bfa
1bf :4 0 2be5 :3 0
d0 :3 0 d2 :2 0
1a32 2be8 2be9 :3 0
21 :3 0 f4 :3 0
2beb 2bec 0 4d
:2 0 2bed 2bee 0
2bf0 1a35 2bf7 21
:3 0 f4 :3 0 2bf1
2bf2 0 189 :2 0
2bf3 2bf4 0 2bf6
1a37 2bf8 2bea 2bf0
0 2bf9 0 2bf6
0 2bf9 1a39 0
2bfa 1a3c 2c44 f6
:3 0 21 :3 0 f4
:3 0 2bfd 2bfe 0
f5 :3 0 2bff 2c00
0 2c3a ad :3 0
ae :3 0 2c02 2c03
0 ad :3 0 bd
:3 0 2c05 2c06 0
f7 :2 0 2 :4 0
281 :2 0 bf :2 0
46 :2 0 1a3f 2c0b
2c0d :3 0 1a42 2c07
2c0f 2c04 2c11 2c10
:2 0 b0 :3 0 c0
:3 0 2c13 2c14 0
b2 :4 0 282 :4 0
b5 :2 0 b6 :3 0
1a46 2c18 2c1a :3 0
b5 :2 0 c9 :4 0
1a49 2c1c 2c1e :3 0
b5 :2 0 fa :4 0
1a4c 2c20 2c22 :3 0
b5 :2 0 f5 :3 0
1a4f 2c24 2c26 :3 0
b5 :2 0 fb :4 0
1a52 2c28 2c2a :3 0
b5 :2 0 fc :3 0
fd :3 0 46 :2 0
fe :2 0 1a55 2c2d
2c31 1a59 2c2c 2c33
:3 0 1a5c 2c15 2c35
:2 0 2c37 1a5f 2c38
2c12 2c37 0 2c39
1a61 0 2c3a 1a63
2c3d :3 0 2c3d 0
2c3d 2c3c 2c3a 2c3b
:6 0 2c3f 53 :3 0
1a66 2c41 1a68 2c40
2c3f :2 0 2c42 1a6a
:2 0 2c44 0 2c44
2c43 2bfa 2c42 :6 0
2c46 50 :3 0 1a6c
2c47 2bda 2c46 0
2c48 1a6e 0 2d1b
33 :3 0 de :2 0
1a70 2c4a 2c4b :3 0
2c4c :2 0 2e :3 0
de :2 0 1a72 2c4f
2c50 :3 0 2c51 :2 0
2e :3 0 fc :3 0
2e :3 0 b5 :2 0
283 :4 0 1a74 2c56
2c58 :3 0 46 :2 0
2f :2 0 1a77 2c54
2c5c 2c53 2c5d 0
2c5f 1a7b 2c60 2c52
2c5f 0 2c61 1a7d
0 2c6e 2e :3 0
fc :3 0 2e :3 0
b5 :2 0 33 :3 0
1a7f 2c65 2c67 :3 0
46 :2 0 2f :2 0
1a82 2c63 2c6b 2c62
2c6c 0 2c6e 1a86
2c6f 2c4d 2c6e 0
2c70 1a89 0 2d1b
48 :3 0 de :2 0
1a8b 2c72 2c73 :3 0
2c74 :2 0 37 :3 0
fc :3 0 37 :3 0
b5 :2 0 48 :3 0
1a8d 2c79 2c7b :3 0
46 :2 0 2f :2 0
1a90 2c77 2c7f 2c76
2c80 0 2c82 1a94
2c83 2c75 2c82 0
2c84 1a96 0 2d1b
34 :3 0 de :2 0
1a98 2c86 2c87 :3 0
2c88 :2 0 30 :3 0
de :2 0 1a9a 2c8b
2c8c :3 0 2c8d :2 0
30 :3 0 fc :3 0
30 :3 0 b5 :2 0
283 :4 0 1a9c 2c92
2c94 :3 0 46 :2 0
2f :2 0 1a9f 2c90
2c98 2c8f 2c99 0
2c9b 1aa3 2c9c 2c8e
2c9b 0 2c9d 1aa5
0 2caa 30 :3 0
fc :3 0 30 :3 0
b5 :2 0 34 :3 0
1aa7 2ca1 2ca3 :3 0
46 :2 0 2f :2 0
1aaa 2c9f 2ca7 2c9e
2ca8 0 2caa 1aae
2cab 2c89 2caa 0
2cac 1ab1 0 2d1b
49 :3 0 de :2 0
1ab3 2cae 2caf :3 0
2cb0 :2 0 38 :3 0
fc :3 0 38 :3 0
b5 :2 0 49 :3 0
1ab5 2cb5 2cb7 :3 0
46 :2 0 2f :2 0
1ab8 2cb3 2cbb 2cb2
2cbc 0 2cbe 1abc
2cbf 2cb1 2cbe 0
2cc0 1abe 0 2d1b
35 :3 0 de :2 0
1ac0 2cc2 2cc3 :3 0
2cc4 :2 0 31 :3 0
de :2 0 1ac2 2cc7
2cc8 :3 0 2cc9 :2 0
31 :3 0 fc :3 0
31 :3 0 b5 :2 0
283 :4 0 1ac4 2cce
2cd0 :3 0 46 :2 0
2f :2 0 1ac7 2ccc
2cd4 2ccb 2cd5 0
2cd7 1acb 2cd8 2cca
2cd7 0 2cd9 1acd
0 2ce6 31 :3 0
fc :3 0 31 :3 0
b5 :2 0 35 :3 0
1acf 2cdd 2cdf :3 0
46 :2 0 2f :2 0
1ad2 2cdb 2ce3 2cda
2ce4 0 2ce6 1ad6
2ce7 2cc5 2ce6 0
2ce8 1ad9 0 2d1b
36 :3 0 de :2 0
1adb 2cea 2ceb :3 0
2cec :2 0 32 :3 0
de :2 0 1add 2cef
2cf0 :3 0 2cf1 :2 0
32 :3 0 fc :3 0
32 :3 0 b5 :2 0
283 :4 0 1adf 2cf6
2cf8 :3 0 46 :2 0
2f :2 0 1ae2 2cf4
2cfc 2cf3 2cfd 0
2cff 1ae6 2d00 2cf2
2cff 0 2d01 1ae8
0 2d0e 32 :3 0
fc :3 0 32 :3 0
b5 :2 0 36 :3 0
1aea 2d05 2d07 :3 0
46 :2 0 2f :2 0
1aed 2d03 2d0b 2d02
2d0c 0 2d0e 1af1
2d0f 2ced 2d0e 0
2d10 1af4 0 2d1b
85 :3 0 85 :3 0
bf :2 0 46 :2 0
1af6 2d13 2d15 :3 0
2d11 2d16 0 2d1b
3a :3 0 26 :3 0
2d18 2d19 0 2d1b
1af9 2d1d 1fc :4 0
2d1b :4 0 2dec 257
:3 0 9c :4 0 2d21
:2 0 2d27 2d1f 0
21 :3 0 f4 :3 0
2d22 2d23 0 f5
:3 0 2d24 2d25 0
2d27 1b08 2d71 f6
:3 0 21 :3 0 f4
:3 0 2d2a 2d2b 0
f5 :3 0 2d2c 2d2d
0 2d67 ad :3 0
ae :3 0 2d2f 2d30
0 ad :3 0 bd
:3 0 2d32 2d33 0
f7 :2 0 2 :4 0
284 :2 0 bf :2 0
46 :2 0 1b0b 2d38
2d3a :3 0 1b0e 2d34
2d3c 2d31 2d3e 2d3d
:2 0 b0 :3 0 c0
:3 0 2d40 2d41 0
b2 :4 0 285 :4 0
b5 :2 0 b6 :3 0
1b12 2d45 2d47 :3 0
b5 :2 0 c9 :4 0
1b15 2d49 2d4b :3 0
b5 :2 0 fa :4 0
1b18 2d4d 2d4f :3 0
b5 :2 0 f5 :3 0
1b1b 2d51 2d53 :3 0
b5 :2 0 fb :4 0
1b1e 2d55 2d57 :3 0
b5 :2 0 fc :3 0
fd :3 0 46 :2 0
fe :2 0 1b21 2d5a
2d5e 1b25 2d59 2d60
:3 0 1b28 2d42 2d62
:2 0 2d64 1b2b 2d65
2d3f 2d64 0 2d66
1b2d 0 2d67 1b2f
2d6a :3 0 2d6a 0
2d6a 2d69 2d67 2d68
:6 0 2d6c 55 :3 0
1b32 2d6e 1b34 2d6d
2d6c :2 0 2d6f 1b36
:2 0 2d71 0 2d71
2d70 2d27 2d6f :6 0
2dec 1 :3 0 85
:3 0 c3 :2 0 4d
:2 0 1b3a 2d74 2d76
:3 0 a7 :3 0 a0
:3 0 37 :3 0 a2
:3 0 2e :3 0 a3
:3 0 38 :3 0 a4
:3 0 30 :3 0 a5
:3 0 31 :3 0 a6
:3 0 32 :3 0 9d
:3 0 3a :4 0 286
1 :8 0 2d9d 1bf
:4 0 2d88 :3 0 d0
:3 0 d2 :2 0 1b3f
2d8b 2d8c :3 0 21
:3 0 f4 :3 0 2d8e
2d8f 0 4d :2 0
2d90 2d91 0 2d93
1b42 2d9a 21 :3 0
f4 :3 0 2d94 2d95
0 189 :2 0 2d96
2d97 0 2d99 1b44
2d9b 2d8d 2d93 0
2d9c 0 2d99 0
2d9c 1b46 0 2d9d
1b49 2de7 f6 :3 0
21 :3 0 f4 :3 0
2da0 2da1 0 f5
:3 0 2da2 2da3 0
2ddd ad :3 0 ae
:3 0 2da5 2da6 0
ad :3 0 bd :3 0
2da8 2da9 0 f7
:2 0 2 :4 0 287
:2 0 bf :2 0 46
:2 0 1b4c 2dae 2db0
:3 0 1b4f 2daa 2db2
2da7 2db4 2db3 :2 0
b0 :3 0 c0 :3 0
2db6 2db7 0 b2
:4 0 288 :4 0 b5
:2 0 b6 :3 0 1b53
2dbb 2dbd :3 0 b5
:2 0 c9 :4 0 1b56
2dbf 2dc1 :3 0 b5
:2 0 fa :4 0 1b59
2dc3 2dc5 :3 0 b5
:2 0 f5 :3 0 1b5c
2dc7 2dc9 :3 0 b5
:2 0 fb :4 0 1b5f
2dcb 2dcd :3 0 b5
:2 0 fc :3 0 fd
:3 0 46 :2 0 fe
:2 0 1b62 2dd0 2dd4
1b66 2dcf 2dd6 :3 0
1b69 2db8 2dd8 :2 0
2dda 1b6c 2ddb 2db5
2dda 0 2ddc 1b6e
0 2ddd 1b70 2de0
:3 0 2de0 0 2de0
2ddf 2ddd 2dde :6 0
2de2 57 :3 0 1b73
2de4 1b75 2de3 2de2
:2 0 2de5 1b77 :2 0
2de7 0 2de7 2de6
2d9d 2de5 :6 0 2de9
1 :3 0 1b79 2dea
2d77 2de9 0 2deb
1b7b 0 2dec 1b7d
2ded 2aca 2dec 0
2dee 1b86 0 355e
6 :3 0 de :2 0
1b88 2df0 2df1 :3 0
2df2 :2 0 a1 :3 0
56 :3 0 4d :2 0
1b8a 2df4 2df7 d2
:2 0 4d :2 0 1b8f
2df9 2dfb :3 0 a1
:3 0 289 :3 0 28a
:3 0 58 :3 0 28b
:3 0 116 :3 0 25
:3 0 28c :3 0 28d
:3 0 fc :3 0 41
:3 0 28d :3 0 fc
:3 0 42 :4 0 28e
1 :8 0 2e11 21
:3 0 f4 :3 0 2e0c
2e0d 0 f5 :3 0
2e0e 2e0f 0 2e11
1b92 2e5b f6 :3 0
21 :3 0 f4 :3 0
2e14 2e15 0 f5
:3 0 2e16 2e17 0
2e51 ad :3 0 ae
:3 0 2e19 2e1a 0
ad :3 0 bd :3 0
2e1c 2e1d 0 f7
:2 0 2 :4 0 28f
:2 0 bf :2 0 46
:2 0 1b95 2e22 2e24
:3 0 1b98 2e1e 2e26
2e1b 2e28 2e27 :2 0
b0 :3 0 c0 :3 0
2e2a 2e2b 0 b2
:4 0 290 :4 0 b5
:2 0 b6 :3 0 1b9c
2e2f 2e31 :3 0 b5
:2 0 c9 :4 0 1b9f
2e33 2e35 :3 0 b5
:2 0 fa :4 0 1ba2
2e37 2e39 :3 0 b5
:2 0 f5 :3 0 1ba5
2e3b 2e3d :3 0 b5
:2 0 fb :4 0 1ba8
2e3f 2e41 :3 0 b5
:2 0 fc :3 0 fd
:3 0 46 :2 0 fe
:2 0 1bab 2e44 2e48
1baf 2e43 2e4a :3 0
1bb2 2e2c 2e4c :2 0
2e4e 1bb5 2e4f 2e29
2e4e 0 2e50 1bb7
0 2e51 1bb9 2e54
:3 0 2e54 0 2e54
2e53 2e51 2e52 :6 0
2e56 59 :3 0 1bbc
2e58 1bbe 2e57 2e56
:2 0 2e59 1bc0 :2 0
2e5b 0 2e5b 2e5a
2e11 2e59 :6 0 2e5d
1 :3 0 1bc2 2e63
60 :3 0 4d :2 0
2e5e 2e5f 0 2e62
0 2e62 1bc4 2e64
2dfc 2e5d 0 2e65
0 2e62 0 2e65
1bc7 0 2e66 1bca
2e67 2df3 2e66 0
2e68 1bcc 0 355e
291 :3 0 f0 :3 0
292 :3 0 293 :3 0
1ad :3 0 6b :3 0
68 :3 0 115 :3 0
294 :3 0 1e9 :3 0
295 :3 0 293 :3 0
294 :3 0 291 :3 0
293 :3 0 116 :3 0
294 :3 0 116 :3 0
25 :4 0 296 1
:8 0 2e82 21 :3 0
f4 :3 0 2e7d 2e7e
0 f5 :3 0 2e7f
2e80 0 2e82 1bce
2ecc f6 :3 0 21
:3 0 f4 :3 0 2e85
2e86 0 f5 :3 0
2e87 2e88 0 2ec2
ad :3 0 ae :3 0
2e8a 2e8b 0 ad
:3 0 bd :3 0 2e8d
2e8e 0 f7 :2 0
2 :4 0 297 :2 0
bf :2 0 46 :2 0
1bd1 2e93 2e95 :3 0
1bd4 2e8f 2e97 2e8c
2e99 2e98 :2 0 b0
:3 0 c0 :3 0 2e9b
2e9c 0 b2 :4 0
298 :4 0 b5 :2 0
b6 :3 0 1bd8 2ea0
2ea2 :3 0 b5 :2 0
c9 :4 0 1bdb 2ea4
2ea6 :3 0 b5 :2 0
fa :4 0 1bde 2ea8
2eaa :3 0 b5 :2 0
f5 :3 0 1be1 2eac
2eae :3 0 b5 :2 0
fb :4 0 1be4 2eb0
2eb2 :3 0 b5 :2 0
fc :3 0 fd :3 0
46 :2 0 fe :2 0
1be7 2eb5 2eb9 1beb
2eb4 2ebb :3 0 1bee
2e9d 2ebd :2 0 2ebf
1bf1 2ec0 2e9a 2ebf
0 2ec1 1bf3 0
2ec2 1bf5 2ec5 :3 0
2ec5 0 2ec5 2ec4
2ec2 2ec3 :6 0 2ec7
5b :3 0 1bf8 2ec9
1bfa 2ec8 2ec7 :2 0
2eca 1bfc :2 0 2ecc
0 2ecc 2ecb 2e82
2eca :6 0 355e 1
:3 0 a1 :3 0 5b
:3 0 4d :2 0 1bfe
2ece 2ed1 c2 :3 0
d2 :2 0 d3 :3 0
2ed3 2ed5 0 1c03
2ed4 2ed7 :3 0 1e1
:3 0 1e2 :3 0 299
:4 0 2edb :4 0 2edc
:2 0 3137 21 :3 0
f4 :3 0 2ede 2edf
0 4d :2 0 2ee0
2ee1 0 3137 29a
:3 0 9e :3 0 29b
:3 0 29c :3 0 29d
:3 0 29e :3 0 a7
:3 0 9d :3 0 27
:3 0 29b :3 0 29c
:4 0 29f 1 :8 0
2f04 1bf :4 0 2eef
:3 0 d0 :3 0 d2
:2 0 1c08 2ef2 2ef3
:3 0 21 :3 0 f4
:3 0 2ef5 2ef6 0
4d :2 0 2ef7 2ef8
0 2efa 1c0b 2f01
21 :3 0 f4 :3 0
2efb 2efc 0 189
:2 0 2efd 2efe 0
2f00 1c0d 2f02 2ef4
2efa 0 2f03 0
2f00 0 2f03 1c0f
0 2f04 1c12 2f4e
f6 :3 0 21 :3 0
f4 :3 0 2f07 2f08
0 f5 :3 0 2f09
2f0a 0 2f44 ad
:3 0 ae :3 0 2f0c
2f0d 0 ad :3 0
bd :3 0 2f0f 2f10
0 f7 :2 0 2
:4 0 2a0 :2 0 bf
:2 0 46 :2 0 1c15
2f15 2f17 :3 0 1c18
2f11 2f19 2f0e 2f1b
2f1a :2 0 b0 :3 0
c0 :3 0 2f1d 2f1e
0 b2 :4 0 2a1
:4 0 b5 :2 0 b6
:3 0 1c1c 2f22 2f24
:3 0 b5 :2 0 c9
:4 0 1c1f 2f26 2f28
:3 0 b5 :2 0 fa
:4 0 1c22 2f2a 2f2c
:3 0 b5 :2 0 f5
:3 0 1c25 2f2e 2f30
:3 0 b5 :2 0 fb
:4 0 1c28 2f32 2f34
:3 0 b5 :2 0 fc
:3 0 fd :3 0 46
:2 0 fe :2 0 1c2b
2f37 2f3b 1c2f 2f36
2f3d :3 0 1c32 2f1f
2f3f :2 0 2f41 1c35
2f42 2f1c 2f41 0
2f43 1c37 0 2f44
1c39 2f47 :3 0 2f47
0 2f47 2f46 2f44
2f45 :6 0 2f49 5d
:3 0 1c3c 2f4b 1c3e
2f4a 2f49 :2 0 2f4c
1c40 :2 0 2f4e 0
2f4e 2f4d 2f04 2f4c
:6 0 3137 1 :3 0
21 :3 0 f4 :3 0
2f50 2f51 0 21
:3 0 d2 :2 0 16f
:3 0 2f53 2f55 0
1c44 2f54 2f57 :3 0
2f58 :2 0 29a :3 0
9e :3 0 1a6 :3 0
29b :3 0 29b :3 0
1a6 :3 0 29c :3 0
29c :3 0 1a6 :3 0
29d :3 0 29d :3 0
1a6 :3 0 29e :3 0
29e :3 0 a7 :3 0
9d :3 0 27 :3 0
9e :4 0 2a2 1
:8 0 2f82 1bf :4 0
2f6d :3 0 d0 :3 0
d2 :2 0 1c49 2f70
2f71 :3 0 21 :3 0
f4 :3 0 2f73 2f74
0 4d :2 0 2f75
2f76 0 2f78 1c4c
2f7f 21 :3 0 f4
:3 0 2f79 2f7a 0
189 :2 0 2f7b 2f7c
0 2f7e 1c4e 2f80
2f72 2f78 0 2f81
0 2f7e 0 2f81
1c50 0 2f82 1c53
2fcc f6 :3 0 21
:3 0 f4 :3 0 2f85
2f86 0 f5 :3 0
2f87 2f88 0 2fc2
ad :3 0 ae :3 0
2f8a 2f8b 0 ad
:3 0 bd :3 0 2f8d
2f8e 0 f7 :2 0
2 :4 0 2a3 :2 0
bf :2 0 46 :2 0
1c56 2f93 2f95 :3 0
1c59 2f8f 2f97 2f8c
2f99 2f98 :2 0 b0
:3 0 c0 :3 0 2f9b
2f9c 0 b2 :4 0
2a4 :4 0 b5 :2 0
b6 :3 0 1c5d 2fa0
2fa2 :3 0 b5 :2 0
c9 :4 0 1c60 2fa4
2fa6 :3 0 b5 :2 0
fa :4 0 1c63 2fa8
2faa :3 0 b5 :2 0
f5 :3 0 1c66 2fac
2fae :3 0 b5 :2 0
fb :4 0 1c69 2fb0
2fb2 :3 0 b5 :2 0
fc :3 0 fd :3 0
46 :2 0 fe :2 0
1c6c 2fb5 2fb9 1c70
2fb4 2fbb :3 0 1c73
2f9d 2fbd :2 0 2fbf
1c76 2fc0 2f9a 2fbf
0 2fc1 1c78 0
2fc2 1c7a 2fc5 :3 0
2fc5 0 2fc5 2fc4
2fc2 2fc3 :6 0 2fc7
5f :3 0 1c7d 2fc9
1c7f 2fc8 2fc7 :2 0
2fca 1c81 :2 0 2fcc
0 2fcc 2fcb 2f82
2fca :6 0 3043 1
:3 0 21 :3 0 f4
:3 0 2fce 2fcf 0
21 :3 0 d2 :2 0
16f :3 0 2fd1 2fd3
0 1c85 2fd2 2fd5
:3 0 2fd6 :2 0 29a
:3 0 9e :3 0 a7
:3 0 9d :3 0 27
:3 0 9e :4 0 2a5
1 :8 0 2ff4 1bf
:4 0 2fdf :3 0 d0
:3 0 d2 :2 0 1c8a
2fe2 2fe3 :3 0 21
:3 0 f4 :3 0 2fe5
2fe6 0 4d :2 0
2fe7 2fe8 0 2fea
1c8d 2ff1 21 :3 0
f4 :3 0 2feb 2fec
0 189 :2 0 2fed
2fee 0 2ff0 1c8f
2ff2 2fe4 2fea 0
2ff3 0 2ff0 0
2ff3 1c91 0 2ff4
1c94 303e f6 :3 0
21 :3 0 f4 :3 0
2ff7 2ff8 0 f5
:3 0 2ff9 2ffa 0
3034 ad :3 0 ae
:3 0 2ffc 2ffd 0
ad :3 0 bd :3 0
2fff 3000 0 f7
:2 0 2 :4 0 2a6
:2 0 bf :2 0 46
:2 0 1c97 3005 3007
:3 0 1c9a 3001 3009
2ffe 300b 300a :2 0
b0 :3 0 c0 :3 0
300d 300e 0 b2
:4 0 2a7 :4 0 b5
:2 0 b6 :3 0 1c9e
3012 3014 :3 0 b5
:2 0 c9 :4 0 1ca1
3016 3018 :3 0 b5
:2 0 fa :4 0 1ca4
301a 301c :3 0 b5
:2 0 f5 :3 0 1ca7
301e 3020 :3 0 b5
:2 0 fb :4 0 1caa
3022 3024 :3 0 b5
:2 0 fc :3 0 fd
:3 0 46 :2 0 fe
:2 0 1cad 3027 302b
1cb1 3026 302d :3 0
1cb4 300f 302f :2 0
3031 1cb7 3032 300c
3031 0 3033 1cb9
0 3034 1cbb 3037
:3 0 3037 0 3037
3036 3034 3035 :6 0
3039 61 :3 0 1cbe
303b 1cc0 303a 3039
:2 0 303c 1cc2 :2 0
303e 0 303e 303d
2ff4 303c :6 0 3040
1 :3 0 1cc4 3041
2fd7 3040 0 3042
1cc6 0 3043 1cc8
3044 2f59 3043 0
3045 1ccb 0 3137
256 :3 0 a9 :3 0
39 :3 0 116 :3 0
14e :3 0 1e8 :3 0
1ba :3 0 1ad :3 0
2a8 :3 0 a2 :3 0
2a8 :3 0 a4 :3 0
2a8 :3 0 a5 :3 0
2a8 :3 0 a6 :3 0
53 :3 0 2a9 :3 0
2aa :3 0 1ad :3 0
2ab :3 0 2ac :3 0
1ad :3 0 2ad :3 0
2ae :3 0 2af :3 0
29b :3 0 2af :3 0
29b :3 0 2a8 :3 0
2b0 :3 0 2b1 :3 0
29b :3 0 68 :3 0
142 :3 0 29b :3 0
68 :3 0 29b :3 0
2ae :3 0 2af :3 0
2b2 :3 0 2af :3 0
2b2 :3 0 2a8 :3 0
2b0 :3 0 2b1 :3 0
29c :3 0 68 :3 0
142 :3 0 29c :3 0
68 :3 0 29c :3 0
2ae :3 0 2af :3 0
29d :3 0 2af :3 0
29d :3 0 2a8 :3 0
2b0 :3 0 2b1 :3 0
29d :3 0 68 :3 0
142 :3 0 29d :3 0
68 :3 0 29d :3 0
2ae :3 0 2af :3 0
2b3 :3 0 2af :3 0
2b3 :3 0 2a8 :3 0
2b0 :3 0 2b1 :3 0
29e :3 0 68 :3 0
142 :3 0 29e :3 0
68 :3 0 29e :3 0
2a8 :3 0 2b4 :3 0
2a8 :3 0 2b5 :3 0
2a8 :3 0 2b6 :3 0
2a8 :3 0 2b7 :3 0
2a8 :3 0 2b8 :3 0
2a8 :3 0 2b9 :3 0
2a8 :3 0 2b9 :3 0
58 :3 0 2ba :3 0
59 :3 0 2bb :3 0
2a8 :3 0 2b6 :3 0
2a8 :3 0 2b7 :3 0
2a8 :3 0 2b8 :3 0
2bc :3 0 2bd :3 0
2be :3 0 2bf :3 0
2c0 :3 0 1ad :3 0
2c1 :3 0 2c2 :3 0
2c3 :3 0 5e :3 0
138 :3 0 2a8 :3 0
2c4 :3 0 2c5 :3 0
2e :3 0 a0 :3 0
30 :3 0 a3 :3 0
2c6 :3 0 2c7 :3 0
159 :3 0 2c8 :3 0
29a :3 0 2b1 :3 0
1e9 :3 0 a7 :3 0
2a8 :3 0 2a8 :3 0
9e :3 0 2b1 :3 0
9e :3 0 2c9 :3 0
2ca :3 0 1e9 :3 0
2cb :3 0 2af :3 0
2af :3 0 98 :3 0
25 :3 0 2af :3 0
9a :3 0 2a8 :3 0
9e :3 0 1e9 :3 0
199 :3 0 1e8 :3 0
1e8 :3 0 19a :3 0
39 :3 0 1e9 :3 0
1af :3 0 2cc :3 0
1e8 :3 0 a0 :3 0
2cc :3 0 116 :3 0
2c9 :3 0 2ca :3 0
1e9 :3 0 2cd :3 0
142 :3 0 2cc :3 0
2ce :3 0 142 :3 0
2ce :3 0 2c9 :3 0
2ca :3 0 1e9 :3 0
227 :3 0 2aa :3 0
1e8 :3 0 1bd :3 0
2aa :3 0 116 :3 0
2c9 :3 0 2ca :3 0
1e9 :3 0 232 :3 0
2ac :3 0 1e8 :3 0
1bc :3 0 2ac :3 0
116 :3 0 2c9 :3 0
2ca :3 0 1e9 :3 0
181 :3 0 2c0 :3 0
2c0 :3 0 116 :3 0
1e8 :3 0 1bb :3 0
2a8 :3 0 a2 :3 0
2a8 :3 0 a4 :3 0
2a8 :3 0 a5 :3 0
2a8 :3 0 a6 :4 0
2cf 1 :a 0 3114
:2 0 3137 3047 3112
:2 0 ad :3 0 ae
:3 0 3115 3116 0
ad :3 0 bd :3 0
3118 3119 0 46
:2 0 2 :4 0 2d0
:2 0 bf :2 0 46
:2 0 1ccd 311e 3120
:3 0 1cd0 311a 3122
3117 3124 3123 :2 0
b0 :3 0 c0 :3 0
3126 3127 0 b2
:4 0 2d1 :4 0 b5
:2 0 b6 :3 0 1cd4
312b 312d :3 0 1cd7
3128 312f :2 0 3131
1cda 3132 3125 3131
0 3133 1cdc 0
3137 20 :3 0 a9
:3 0 3135 :2 0 3137
1cde 355b 8b :3 0
d2 :2 0 46 :2 0
1ce8 3139 313b :3 0
256 :3 0 aa :3 0
2a8 :3 0 9e :3 0
116 :3 0 14e :3 0
2cc :3 0 2bf :3 0
1ad :3 0 2a8 :3 0
a2 :3 0 2a8 :3 0
a4 :3 0 2a8 :3 0
a5 :3 0 2a8 :3 0
a6 :3 0 2cc :3 0
2a9 :3 0 2d2 :3 0
1ad :3 0 2ab :3 0
2d3 :3 0 1ad :3 0
2ad :3 0 2ae :3 0
2a8 :3 0 2d4 :3 0
2a8 :3 0 29b :3 0
2cc :3 0 291 :3 0
6b :3 0 2cc :3 0
291 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 2cc :3 0
291 :3 0 2a8 :3 0
2d4 :3 0 2a8 :3 0
29b :3 0 2a8 :3 0
29b :3 0 68 :3 0
29b :3 0 2ae :3 0
2a8 :3 0 2d4 :3 0
2a8 :3 0 29c :3 0
2cc :3 0 291 :3 0
6b :3 0 2cc :3 0
291 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 2cc :3 0
291 :3 0 2a8 :3 0
2d4 :3 0 2a8 :3 0
29c :3 0 2a8 :3 0
29c :3 0 68 :3 0
29c :3 0 2ae :3 0
2a8 :3 0 2d4 :3 0
2a8 :3 0 29d :3 0
2cc :3 0 291 :3 0
6b :3 0 2cc :3 0
291 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 2cc :3 0
291 :3 0 2a8 :3 0
2d4 :3 0 2a8 :3 0
29d :3 0 2a8 :3 0
29d :3 0 68 :3 0
29d :3 0 2ae :3 0
2a8 :3 0 2d4 :3 0
2a8 :3 0 29e :3 0
2cc :3 0 291 :3 0
6b :3 0 2cc :3 0
291 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 2cc :3 0
291 :3 0 2a8 :3 0
2d4 :3 0 2a8 :3 0
29e :3 0 2a8 :3 0
29e :3 0 68 :3 0
29e :3 0 2a8 :3 0
2b4 :3 0 2a8 :3 0
2b5 :3 0 2a8 :3 0
2b6 :3 0 2a8 :3 0
2b7 :3 0 2a8 :3 0
2b8 :3 0 2a8 :3 0
2b9 :3 0 2a8 :3 0
2b9 :3 0 58 :3 0
2ba :3 0 59 :3 0
2bb :3 0 2a8 :3 0
2b6 :3 0 2a8 :3 0
2b7 :3 0 2a8 :3 0
2b8 :3 0 2bc :3 0
2d5 :3 0 2bf :3 0
2bd :3 0 2cc :3 0
2be :3 0 2c0 :3 0
1ad :3 0 2c1 :3 0
2d6 :3 0 2bf :3 0
2d6 :3 0 2c2 :3 0
2c3 :3 0 5e :3 0
138 :3 0 2a8 :3 0
2c4 :3 0 2c5 :3 0
2a8 :3 0 a0 :3 0
2a8 :3 0 a3 :3 0
a1 :3 0 2af :3 0
2d7 :3 0 2af :3 0
2d8 :3 0 2c6 :3 0
2cc :3 0 2c7 :3 0
2cc :3 0 2d9 :3 0
2c8 :3 0 a7 :3 0
2a8 :3 0 1e9 :3 0
181 :3 0 1e8 :3 0
2a8 :3 0 9e :3 0
1e8 :3 0 116 :3 0
1e9 :3 0 181 :3 0
2c0 :3 0 2c0 :3 0
116 :3 0 1e8 :3 0
1b0 :3 0 2c9 :3 0
2ca :3 0 1e9 :3 0
16b :3 0 2d6 :3 0
2c0 :3 0 2da :3 0
2d6 :3 0 9a :3 0
1e9 :3 0 16b :3 0
2cc :3 0 2a8 :3 0
9e :3 0 2cc :3 0
9a :3 0 2c9 :3 0
2ca :3 0 1e9 :3 0
16b :3 0 2d5 :3 0
2d5 :3 0 9a :3 0
2cc :3 0 2db :3 0
2c9 :3 0 2ca :3 0
1e9 :3 0 2cb :3 0
2af :3 0 2af :3 0
98 :3 0 25 :3 0
2af :3 0 9a :3 0
2a8 :3 0 9e :3 0
2c9 :3 0 2ca :3 0
1e9 :3 0 227 :3 0
2aa :3 0 2cc :3 0
9a :3 0 2aa :3 0
116 :3 0 2c9 :3 0
2ca :3 0 1e9 :3 0
227 :3 0 2d2 :3 0
2aa :3 0 1b0 :3 0
2d2 :3 0 116 :3 0
2c9 :3 0 2ca :3 0
1e9 :3 0 232 :3 0
2ac :3 0 2cc :3 0
9a :3 0 2ac :3 0
116 :3 0 2c9 :3 0
2ca :3 0 1e9 :3 0
232 :3 0 2d3 :3 0
2ac :3 0 1b0 :3 0
2d3 :3 0 116 :3 0
116 :4 0 2dc 1
:a 0 326c :2 0 328f
313e 326a :2 0 ad
:3 0 ae :3 0 326d
326e 0 ad :3 0
bd :3 0 3270 3271
0 46 :2 0 2
:4 0 2dd :2 0 bf
:2 0 46 :2 0 1ceb
3276 3278 :3 0 1cee
3272 327a 326f 327c
327b :2 0 b0 :3 0
c0 :3 0 327e 327f
0 b2 :4 0 2de
:4 0 b5 :2 0 b6
:3 0 1cf2 3283 3285
:3 0 1cf5 3280 3287
:2 0 3289 1cf8 328a
327d 3289 0 328b
1cfa 0 328f 20
:3 0 aa :3 0 328d
:2 0 328f 1cfc 3557
1e1 :3 0 1e2 :3 0
2df :4 0 3292 :4 0
3293 :2 0 3556 21
:3 0 f4 :3 0 3295
3296 0 4d :2 0
3297 3298 0 3556
2e0 :3 0 9e :3 0
29b :3 0 29c :3 0
29d :3 0 29e :3 0
a7 :3 0 2d4 :4 0
2e1 1 :8 0 32b8
1bf :4 0 32a3 :3 0
d0 :3 0 d2 :2 0
1d02 32a6 32a7 :3 0
21 :3 0 f4 :3 0
32a9 32aa 0 4d
:2 0 32ab 32ac 0
32ae 1d05 32b5 21
:3 0 f4 :3 0 32af
32b0 0 189 :2 0
32b1 32b2 0 32b4
1d07 32b6 32a8 32ae
0 32b7 0 32b4
0 32b7 1d09 0
32b8 1d0c 3302 f6
:3 0 21 :3 0 f4
:3 0 32bb 32bc 0
f5 :3 0 32bd 32be
0 32f8 ad :3 0
ae :3 0 32c0 32c1
0 ad :3 0 bd
:3 0 32c3 32c4 0
f7 :2 0 2 :4 0
2e2 :2 0 bf :2 0
46 :2 0 1d0f 32c9
32cb :3 0 1d12 32c5
32cd 32c2 32cf 32ce
:2 0 b0 :3 0 c0
:3 0 32d1 32d2 0
b2 :4 0 2e3 :4 0
b5 :2 0 b6 :3 0
1d16 32d6 32d8 :3 0
b5 :2 0 c9 :4 0
1d19 32da 32dc :3 0
b5 :2 0 fa :4 0
1d1c 32de 32e0 :3 0
b5 :2 0 f5 :3 0
1d1f 32e2 32e4 :3 0
b5 :2 0 fb :4 0
1d22 32e6 32e8 :3 0
b5 :2 0 fc :3 0
fd :3 0 46 :2 0
fe :2 0 1d25 32eb
32ef 1d29 32ea 32f1
:3 0 1d2c 32d3 32f3
:2 0 32f5 1d2f 32f6
32d0 32f5 0 32f7
1d31 0 32f8 1d33
32fb :3 0 32fb 0
32fb 32fa 32f8 32f9
:6 0 32fd 63 :3 0
1d36 32ff 1d38 32fe
32fd :2 0 3300 1d3a
:2 0 3302 0 3302
3301 32b8 3300 :6 0
3556 1 :3 0 2e0
:3 0 9e :3 0 1a6
:3 0 29b :3 0 29b
:3 0 1a6 :3 0 29c
:3 0 29c :3 0 1a6
:3 0 29d :3 0 29d
:3 0 1a6 :3 0 29e
:3 0 29e :3 0 a7
:3 0 9e :3 0 9e
:3 0 a7 :3 0 2d4
:3 0 9e :4 0 2e4
1 :8 0 332e 1bf
:4 0 3319 :3 0 d0
:3 0 d2 :2 0 1d3e
331c 331d :3 0 21
:3 0 f4 :3 0 331f
3320 0 4d :2 0
3321 3322 0 3324
1d41 332b 21 :3 0
f4 :3 0 3325 3326
0 189 :2 0 3327
3328 0 332a 1d43
332c 331e 3324 0
332d 0 332a 0
332d 1d45 0 332e
1d48 3378 f6 :3 0
21 :3 0 f4 :3 0
3331 3332 0 f5
:3 0 3333 3334 0
336e ad :3 0 ae
:3 0 3336 3337 0
ad :3 0 bd :3 0
3339 333a 0 f7
:2 0 2 :4 0 2e5
:2 0 bf :2 0 46
:2 0 1d4b 333f 3341
:3 0 1d4e 333b 3343
3338 3345 3344 :2 0
b0 :3 0 c0 :3 0
3347 3348 0 b2
:4 0 2e6 :4 0 b5
:2 0 b6 :3 0 1d52
334c 334e :3 0 b5
:2 0 c9 :4 0 1d55
3350 3352 :3 0 b5
:2 0 fa :4 0 1d58
3354 3356 :3 0 b5
:2 0 f5 :3 0 1d5b
3358 335a :3 0 b5
:2 0 fb :4 0 1d5e
335c 335e :3 0 b5
:2 0 fc :3 0 fd
:3 0 46 :2 0 fe
:2 0 1d61 3361 3365
1d65 3360 3367 :3 0
1d68 3349 3369 :2 0
336b 1d6b 336c 3346
336b 0 336d 1d6d
0 336e 1d6f 3371
:3 0 3371 0 3371
3370 336e 336f :6 0
3373 65 :3 0 1d72
3375 1d74 3374 3373
:2 0 3376 1d76 :2 0
3378 0 3378 3377
332e 3376 :6 0 3556
1 :3 0 256 :3 0
ab :3 0 2a8 :3 0
9e :3 0 116 :3 0
14e :3 0 2cc :3 0
2bf :3 0 1ad :3 0
2a8 :3 0 a2 :3 0
2a8 :3 0 a4 :3 0
2a8 :3 0 a5 :3 0
2a8 :3 0 a6 :3 0
2cc :3 0 2a9 :3 0
2d2 :3 0 1ad :3 0
2ab :3 0 2d3 :3 0
1ad :3 0 2ad :3 0
2ae :3 0 2af :3 0
29b :3 0 2af :3 0
29b :3 0 142 :3 0
29b :3 0 142 :3 0
29b :3 0 2cc :3 0
291 :3 0 6b :3 0
2cc :3 0 291 :3 0
6b :3 0 f0 :3 0
292 :3 0 1ad :3 0
295 :3 0 116 :3 0
6b :3 0 f0 :3 0
292 :3 0 1ad :3 0
295 :3 0 116 :3 0
2cc :3 0 291 :3 0
2e7 :3 0 29b :3 0
2e7 :3 0 29b :3 0
2cc :3 0 291 :3 0
6b :3 0 2cc :3 0
291 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 2cc :3 0
291 :3 0 2e8 :3 0
29b :3 0 68 :3 0
29b :3 0 2ae :3 0
2af :3 0 29b :3 0
2af :3 0 2b2 :3 0
142 :3 0 29b :3 0
142 :3 0 29c :3 0
2cc :3 0 291 :3 0
6b :3 0 2cc :3 0
291 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 2cc :3 0
291 :3 0 2e7 :3 0
29b :3 0 2e7 :3 0
29c :3 0 2cc :3 0
291 :3 0 6b :3 0
2cc :3 0 291 :3 0
6b :3 0 f0 :3 0
292 :3 0 1ad :3 0
295 :3 0 116 :3 0
6b :3 0 f0 :3 0
292 :3 0 1ad :3 0
295 :3 0 116 :3 0
2cc :3 0 291 :3 0
2e8 :3 0 29c :3 0
68 :3 0 29c :3 0
2ae :3 0 2af :3 0
29b :3 0 2af :3 0
29d :3 0 142 :3 0
29b :3 0 142 :3 0
29d :3 0 2cc :3 0
291 :3 0 6b :3 0
2cc :3 0 291 :3 0
6b :3 0 f0 :3 0
292 :3 0 1ad :3 0
295 :3 0 116 :3 0
6b :3 0 f0 :3 0
292 :3 0 1ad :3 0
295 :3 0 116 :3 0
2cc :3 0 291 :3 0
2e7 :3 0 29b :3 0
2e7 :3 0 29d :3 0
2cc :3 0 291 :3 0
6b :3 0 2cc :3 0
291 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 2cc :3 0
291 :3 0 2e8 :3 0
29d :3 0 68 :3 0
29d :3 0 2ae :3 0
2af :3 0 2b2 :3 0
2af :3 0 2b3 :3 0
142 :3 0 29c :3 0
142 :3 0 29e :3 0
2cc :3 0 291 :3 0
6b :3 0 2cc :3 0
291 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 6b :3 0
f0 :3 0 292 :3 0
1ad :3 0 295 :3 0
116 :3 0 2cc :3 0
291 :3 0 2e7 :3 0
29b :3 0 2e7 :3 0
29e :3 0 2cc :3 0
291 :3 0 6b :3 0
2cc :3 0 291 :3 0
6b :3 0 f0 :3 0
292 :3 0 1ad :3 0
295 :3 0 116 :3 0
6b :3 0 f0 :3 0
292 :3 0 1ad :3 0
295 :3 0 116 :3 0
2cc :3 0 291 :3 0
2e8 :3 0 29e :3 0
68 :3 0 29e :3 0
2a8 :3 0 2b4 :3 0
2a8 :3 0 2b5 :3 0
2a8 :3 0 2b6 :3 0
2a8 :3 0 2b7 :3 0
2a8 :3 0 2b8 :3 0
2a8 :3 0 2b9 :3 0
2a8 :3 0 2b9 :3 0
58 :3 0 2ba :3 0
59 :3 0 2bb :3 0
2a8 :3 0 2b6 :3 0
2a8 :3 0 2b7 :3 0
2a8 :3 0 2b8 :3 0
2bc :3 0 2d5 :3 0
2bf :3 0 2bd :3 0
2cc :3 0 2be :3 0
2c0 :3 0 1ad :3 0
2c1 :3 0 2d6 :3 0
2bf :3 0 2d6 :3 0
2c2 :3 0 2c3 :3 0
5e :3 0 138 :3 0
2a8 :3 0 2c4 :3 0
2c5 :3 0 2a8 :3 0
a0 :3 0 2a8 :3 0
a3 :3 0 a1 :3 0
2af :3 0 2d7 :3 0
2af :3 0 2d8 :3 0
2c6 :3 0 2cc :3 0
2c7 :3 0 2cc :3 0
2d9 :3 0 2c8 :3 0
a7 :3 0 2a8 :3 0
2c9 :3 0 1e9 :3 0
2e0 :3 0 2e7 :3 0
2a8 :3 0 9e :3 0
2e7 :3 0 9e :3 0
2e7 :3 0 2d4 :3 0
2c9 :3 0 1e9 :3 0
2e0 :3 0 2e8 :3 0
2a8 :3 0 9e :3 0
2e8 :3 0 9e :3 0
2e8 :3 0 2d4 :3 0
1e9 :3 0 181 :3 0
1e8 :3 0 2a8 :3 0
9e :3 0 1e8 :3 0
116 :3 0 1e9 :3 0
181 :3 0 2c0 :3 0
2c0 :3 0 116 :3 0
1e8 :3 0 1b0 :3 0
2c9 :3 0 2ca :3 0
1e9 :3 0 16b :3 0
2d6 :3 0 2c0 :3 0
2da :3 0 2d6 :3 0
9a :3 0 1e9 :3 0
16b :3 0 2cc :3 0
2a8 :3 0 9e :3 0
2cc :3 0 9a :3 0
2c9 :3 0 2ca :3 0
1e9 :3 0 16b :3 0
2d5 :3 0 2d5 :3 0
9a :3 0 2cc :3 0
2db :3 0 2c9 :3 0
2ca :3 0 1e9 :3 0
2cb :3 0 2af :3 0
2af :3 0 98 :3 0
25 :3 0 2af :3 0
9a :3 0 2a8 :3 0
9e :3 0 2c9 :3 0
2ca :3 0 1e9 :3 0
16b :3 0 2e9 :3 0
2cc :3 0 2db :3 0
2e9 :3 0 9a :3 0
2c9 :3 0 2ca :3 0
1e9 :3 0 227 :3 0
2aa :3 0 2cc :3 0
9a :3 0 2aa :3 0
116 :3 0 2c9 :3 0
2ca :3 0 1e9 :3 0
227 :3 0 2d2 :3 0
2aa :3 0 1b0 :3 0
2d2 :3 0 116 :3 0
2c9 :3 0 2ca :3 0
1e9 :3 0 232 :3 0
2ac :3 0 2cc :3 0
9a :3 0 2ac :3 0
116 :3 0 2c9 :3 0
2ca :3 0 1e9 :3 0
232 :3 0 2d3 :3 0
2ac :3 0 1b0 :3 0
2d3 :3 0 116 :3 0
2c9 :3 0 2ca :3 0
1e9 :3 0 2cd :3 0
142 :3 0 2cc :3 0
2ce :3 0 142 :3 0
2ce :3 0 2a8 :3 0
a2 :3 0 2a8 :3 0
a4 :3 0 2a8 :3 0
a5 :3 0 2a8 :3 0
a6 :3 0 116 :4 0
2ea 1 :a 0 3533
:2 0 3556 337b 3531
:2 0 ad :3 0 ae
:3 0 3534 3535 0
ad :3 0 bd :3 0
3537 3538 0 46
:2 0 2 :4 0 2eb
:2 0 bf :2 0 46
:2 0 1d78 353d 353f
:3 0 1d7b 3539 3541
3536 3543 3542 :2 0
b0 :3 0 c0 :3 0
3545 3546 0 b2
:4 0 2ec :4 0 b5
:2 0 b6 :3 0 1d7f
354a 354c :3 0 1d82
3547 354e :2 0 3550
1d85 3551 3544 3550
0 3552 1d87 0
3556 20 :3 0 ab
:3 0 3554 :2 0 3556
1d89 3558 313c 328f
0 3559 0 3556
0 3559 1d91 0
355a 1d94 355c 2ed8
3137 0 355d 0
355a 0 355d 1d96
0 355e 1d99 35ff
21 :3 0 2ed :2 0
4 355f 3560 0
ad :3 0 ae :3 0
3562 3563 0 ad
:3 0 bd :3 0 3565
3566 0 f7 :2 0
2 :4 0 2ee :2 0
bf :2 0 46 :2 0
1dd7 356b 356d :3 0
1dda 3567 356f 3564
3571 3570 :2 0 b0
:3 0 c0 :3 0 3573
3574 0 b2 :4 0
2ef :4 0 b5 :2 0
b6 :3 0 1dde 3578
357a :3 0 1de1 3575
357c :2 0 3595 b0
:3 0 c0 :3 0 357e
357f 0 b2 :4 0
2f0 :4 0 b5 :2 0
21 :3 0 2f1 :3 0
3584 3585 0 1de4
3583 3587 :3 0 b5
:2 0 11f :4 0 1de7
3589 358b :3 0 b5
:2 0 21 :3 0 2f2
:3 0 358e 358f 0
1dea 358d 3591 :3 0
1ded 3580 3593 :2 0
3595 1df0 3596 3572
3595 0 3597 1df3
0 35a7 256 :3 0
ac :3 0 21 :3 0
2f1 :3 0 2f3 :3 0
21 :3 0 2f2 :3 0
2f4 :3 0 f2 :4 0
2f5 1 :a 0 35a3
:2 0 35a7 3599 35a1
:2 0 20 :3 0 ac
:3 0 35a5 :2 0 35a7
1df5 35a9 1df9 35a8
35a7 :2 0 35fd f6
:3 0 21 :3 0 f4
:3 0 35ac 35ad 0
f5 :3 0 35ae 35af
0 35f5 ad :3 0
ae :3 0 35b1 35b2
0 ad :3 0 bd
:3 0 35b4 35b5 0
f7 :2 0 2 :4 0
2f6 :2 0 bf :2 0
46 :2 0 1dfb 35ba
35bc :3 0 1dfe 35b6
35be 35b3 35c0 35bf
:2 0 b0 :3 0 c0
:3 0 35c2 35c3 0
b2 :4 0 2f7 :4 0
b5 :2 0 b6 :3 0
1e02 35c7 35c9 :3 0
1e05 35c4 35cb :2 0
35e5 b0 :3 0 c0
:3 0 35cd 35ce 0
b2 :4 0 fa :4 0
b5 :2 0 f5 :3 0
1e08 35d2 35d4 :3 0
b5 :2 0 fb :4 0
1e0b 35d6 35d8 :3 0
b5 :2 0 fc :3 0
fd :3 0 46 :2 0
fe :2 0 1e0e 35db
35df 1e12 35da 35e1
:3 0 1e15 35cf 35e3
:2 0 35e5 1e18 35e6
35c1 35e5 0 35e7
1e1b 0 35f5 256
:3 0 ac :3 0 2f3
:3 0 21 :3 0 2f2
:3 0 2f4 :3 0 f2
:4 0 2f8 1 :a 0
35f1 :2 0 35f5 35e9
35ef :2 0 20 :3 0
ac :3 0 35f3 :2 0
35f5 1e1d 35f8 :3 0
35f8 0 35f8 35f7
35f5 35f6 :6 0 35fa
1 :3 0 1e22 35fc
1e24 35fb 35fa :2 0
35fd 1e26 :2 0 35ff
1e29 35ff 35fe 355e
35fd :6 0 3600 :2 0
2 74 35ff 3603
:3 0 3602 3600 3604
:8 0 
1e93
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 1
47 1 4b 1
4f 1 53 1
57 1 5b 1
5f 1 63 1
67 1 6b 1b
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 4a 4e 52
56 5a 5e 62
66 6a 6e 1
78 1 76 1
7f 1 7d 1
86 1 84 1
8d 1 8b 1
94 1 92 1
9b 1 99 1
a2 1 a0 1
a9 1 a7 1
b0 1 ae 1
b7 1 b5 1
be 1 bc 1
c5 1 c3 1
cc 1 ca 1
d3 1 d1 1
da 1 d8 1
e1 1 df 1
e8 1 e6 1
ef 1 ed 1
f6 1 f4 1
fd 1 fb 1
104 1 102 1
109 1 110 1
10e 1 117 1
115 1 11e 1
11c 1 125 1
123 1 12c 1
12a 1 133 1
131 1 13a 1
138 1 141 1
13f 1 148 1
146 1 14f 1
14d 1 156 1
154 1 15b 1
161 1 167 1
16d 1 173 1
179 1 17f 1
185 1 18b 1
191 1 197 1
19d 1 1a3 1
1a9 1 1af 1
1b5 1 1bb 1
1c1 1 1c7 1
1cd 1 1d3 1
1d9 1 1df 1
1e5 1 1eb 1
1f1 1 1f7 1
1fd 1 203 1
209 1 20f 1
215 1 21b 1
223 1 221 1
228 1 22e 1
234 1 23c 1
23a 1 243 1
241 1 24a 1
248 1 24f 1
255 1 25d 1
25b 1 264 1
262 1 26b 1
269 1 272 1
270 1 279 1
277 1 280 1
27e 1 285 1
28b 1 291 1
297 1 29d 1
2a3 1 2a9 1
2af 1 2b7 1
2b5 1 2bc 1
2c2 1 2c7 1
2cc 1 2d1 1
2d6 1 2db 1
2e0 1 2e5 1
2f9 1 314 1
31a 1 321 1
328 1 32f 1
33c 1 348 2
34b 34d 2 350
352 2 354 356
2 358 35a 2
35c 35e 2 360
362 2 364 366
2 368 36a 2
36c 36e 2 370
372 2 374 376
2 378 37a 2
37c 37e 1 384
2 386 387 2
380 389 2 38b
38d 1 393 2
395 396 2 38f
398 2 39a 39c
1 3a2 2 3a4
3a5 2 39e 3a7
2 3a9 3ab 1
3b1 2 3b3 3b4
2 3ad 3b6 2
3b8 3ba 1 3c0
2 3c2 3c3 2
3bc 3c5 2 3c7
3c9 1 3cf 2
3d1 3d2 2 3cb
3d4 2 3d6 3d8
1 3de 2 3e0
3e1 2 3da 3e3
2 3e5 3e7 1
3ed 2 3ef 3f0
2 3e9 3f2 2
3f4 3f6 2 3f8
3fa 2 3fc 3fe
2 400 402 2
404 406 2 408
40a 2 40c 40e
2 410 412 2
414 416 2 418
41a 2 41c 41e
2 420 422 2
424 426 2 428
42a 2 42c 42e
2 430 432 2
434 436 2 438
43a 2 43c 43e
2 440 442 2
444 446 1 44c
2 44e 44f 2
448 451 2 453
455 2 457 459
2 45b 45d 2
45f 461 2 463
465 2 467 469
2 46b 46d 2
46f 471 2 473
475 2 477 479
2 47b 47d 2
47f 481 2 483
485 2 487 489
2 48b 48d 2
48f 491 2 493
495 1 49b 2
49d 49e 2 497
4a0 2 4a2 4a4
1 4aa 2 4ac
4ad 2 4a6 4af
2 4b1 4b3 1
4b9 2 4bb 4bc
2 4b5 4be 2
4c0 4c2 1 4c8
2 4ca 4cb 2
4c4 4cd 2 4cf
4d1 2 4d3 4d5
2 4d7 4d9 2
4db 4dd 2 4df
4e1 2 4e3 4e5
2 4e7 4e9 2
4eb 4ed 2 4ef
4f1 4 344 34a
34f 4f3 1 4f5
1 4f7 2 501
503 3 4ff 500
505 2 50e 510
2 50d 512 1
514 1 516 2
561 562 1 568
2 564 568 1
56c 2 57c 57e
3 57a 57b 580
2 589 58b 2
58d 58f 2 591
593 1 59b 2
59d 59e 2 595
5a0 2 588 5a2
1 5a4 1 5a6
2 5b0 5b2 3
5ae 5af 5b4 2
5bd 5bf 2 5bc
5c1 1 5c3 1
5c5 2 5cc 5cd
3 5a7 5c6 5cf
1 5d1 1 5d3
1 5d9 1 5e1
1 5e9 2 5f2
5f3 1 5f9 2
5f5 5f9 1 5ff
2 606 607 1
60d 2 609 60d
2 61b 61d 3
619 61a 61f 2
628 62a 2 62c
62e 2 630 632
1 63a 2 63c
63d 2 634 63f
2 627 641 1
643 1 645 2
64f 651 3 64d
64e 653 2 65c
65e 2 65b 660
1 662 1 664
2 66b 66c 3
646 665 66e 1
671 1 677 2
687 689 3 685
686 68b 2 694
696 2 698 69a
2 69c 69e 1
6a6 2 6a8 6a9
2 6a0 6ab 2
693 6ad 1 6af
1 6b1 2 6bb
6bd 3 6b9 6ba
6bf 2 6c8 6ca
2 6c7 6cc 1
6ce 1 6d0 2
6d7 6d8 3 6b2
6d1 6da 2 6dd
6dc 1 6de 1
6e0 1 6e2 1
6e9 2 6eb 6ec
1 6f0 2 6ee
6f0 2 6ff 701
3 6fd 6fe 703
2 70c 70e 2
710 712 2 714
716 1 71e 2
720 721 2 718
723 2 70b 725
1 727 1 729
2 733 735 3
731 732 737 2
740 742 2 73f
744 1 746 1
748 2 74f 750
3 72a 749 752
1 754 1 756
1 75d 2 75f
760 1 764 2
762 764 2 773
775 3 771 772
777 2 780 782
2 784 786 2
788 78a 1 792
2 794 795 2
78c 797 2 77f
799 1 79b 1
79d 2 7a7 7a9
3 7a5 7a6 7ab
2 7b4 7b6 2
7b3 7b8 1 7ba
1 7bc 2 7c3
7c4 3 79e 7bd
7c6 1 7c8 2
7cb 7cc 1 7d0
2 7ce 7d0 2
7d4 7d5 1 7d9
2 7d7 7d9 2
7df 7e0 1 7e4
2 7e2 7e4 2
7f1 7f3 3 7ef
7f0 7f5 2 7fe
800 2 802 804
2 806 808 1
810 2 812 813
2 80a 815 2
7fd 817 1 819
1 81b 2 825
827 3 823 824
829 2 832 834
2 831 836 1
838 1 83a 2
841 842 3 81c
83b 844 1 846
1 848 1 850
1 854 2 856
857 2 85a 85b
1 861 2 85d
861 1 865 1
86d 2 87d 882
2 893 895 3
891 892 897 2
8a0 8a2 2 8a4
8a6 2 8a8 8aa
2 8ac 8ae 2
8b0 8b2 3 8b7
8b8 8b9 2 8b4
8bb 2 89f 8bd
1 8bf 1 8c1
2 88a 8c2 1
8c6 1 885 1
8ca 1 8d5 2
8d1 8d5 2 8da
8db 1 8df 2
8dd 8df 2 8ed
8ef 3 8eb 8ec
8f1 2 8fa 8fc
2 8fe 900 2
902 904 1 90c
2 90e 90f 2
906 911 2 8f9
913 1 915 1
917 2 921 923
3 91f 920 925
2 92e 930 2
92d 932 1 934
1 936 2 93d
93e 3 918 937
940 1 942 3
8cd 943 946 1
948 1 94a 1
950 2 95b 960
2 971 973 3
96f 970 975 2
97e 980 2 982
984 2 986 988
2 98a 98c 2
98e 990 3 995
996 997 2 992
999 2 97d 99b
1 99d 1 99f
2 968 9a0 1
9a4 1 963 1
9a8 1 9ab 1
9ae 2 9b9 9ba
2 9bc 9bf 2
9c2 9c3 2 9ca
9cb 2 9cd 9d0
2 9da 9db 2
9dd 9e0 2 9e3
9e4 2 9eb 9ec
2 9ee 9f1 2
9f7 9f8 1 9fe
2 9fa 9fe 1
a00 2 a03 a05
2 a09 a0a 1
a0e 2 a0c a0e
2 a19 a1e 2
a2f a31 3 a2d
a2e a33 2 a3c
a3e 2 a40 a42
2 a44 a46 2
a48 a4a 2 a4c
a4e 3 a53 a54
a55 2 a50 a57
2 a3b a59 1
a5b 1 a5d 2
a26 a5e 1 a62
1 a21 1 a66
2 a6c a6d 1
a71 2 a6f a71
2 a79 a7e 2
a8f a91 3 a8d
a8e a93 2 a9c
a9e 2 aa0 aa2
2 aa4 aa6 2
aa8 aaa 2 aac
aae 3 ab3 ab4
ab5 2 ab0 ab7
2 a9b ab9 1
abb 1 abd 2
a86 abe 1 ac2
1 a81 1 ac6
2 ace acf 1
ad3 2 ad1 ad3
2 ade ae0 3
adc add ae2 2
aeb aed 2 aef
af1 2 af3 af5
1 afd 2 aff
b00 2 af7 b02
2 b04 b06 2
b08 b0a 2 b0c
b0e 2 b10 b12
2 aea b14 1
b16 1 b18 2
b22 b24 3 b20
b21 b26 2 b2f
b31 2 b2e b33
1 b35 1 b37
3 b3e b3f b40
3 b19 b38 b42
1 b44 2 ac9
b45 1 b47 2
b4c b4d 1 b4f
2 b54 b55 1
b59 2 b57 b59
2 b5f b60 1
b62 2 b67 b68
1 b6c 2 b6a
b6c 2 b77 b79
3 b75 b76 b7b
2 b84 b86 2
b88 b8a 2 b8c
b8e 1 b96 2
b98 b99 2 b90
b9b 2 b83 b9d
1 b9f 1 ba1
2 bab bad 3
ba9 baa baf 2
bb8 bba 2 bb7
bbc 1 bbe 1
bc0 2 bc7 bc8
3 ba2 bc1 bca
1 bcc 3 b65
bcd bd2 1 bd4
2 bda bdb 1
bdf 2 bdd bdf
1 be4 2 bee
bf0 3 bec bed
bf2 2 bfb bfd
2 bff c01 2
c03 c05 1 c0d
2 c0f c10 2
c07 c12 2 bfa
c14 1 c16 1
c18 2 c22 c24
3 c20 c21 c26
2 c2f c31 2
c2e c33 1 c35
1 c37 2 c3e
c3f 3 c19 c38
c41 2 c43 c44
6 c48 c49 c4a
c4b c4c c4d 2
c52 c53 1 c57
2 c55 c57 2
c62 c64 3 c60
c61 c66 2 c6f
c71 2 c73 c75
2 c77 c79 1
c7f 2 c81 c82
2 c7b c84 2
c86 c88 2 c8a
c8c 2 c8e c90
2 c92 c94 2
c6e c96 1 c98
1 c9a 2 ca4
ca6 3 ca2 ca3
ca8 2 cb1 cb3
2 cb0 cb5 1
cb7 1 cb9 2
cbf cc0 3 cc2
cc3 cc4 3 c9b
cba cc6 1 cc8
2 ccb ccc 1
cd2 2 cce cd2
2 cdd cdf 3
cdb cdc ce1 2
cea cec 2 cee
cf0 2 cf2 cf4
1 cfc 2 cfe
cff 2 cf6 d01
2 d03 d05 2
d07 d09 2 d0b
d0d 2 d0f d11
2 ce9 d13 1
d15 1 d17 2
d21 d23 3 d1f
d20 d25 2 d2e
d30 2 d2d d32
1 d34 1 d36
3 d3d d3e d3f
3 d18 d37 d41
1 d43 2 d46
d47 1 d4d 2
d49 d4d 2 d52
d53 1 d55 1
d59 2 d57 d59
2 d69 d6e 2
d7f d81 3 d7d
d7e d83 2 d8c
d8e 2 d90 d92
2 d94 d96 2
d98 d9a 2 d9c
d9e 3 da3 da4
da5 2 da0 da7
2 d8b da9 1
dab 1 dad 2
d76 dae 1 db2
1 d71 1 db6
1 db9 2 de3
de8 2 df9 dfb
3 df7 df8 dfd
2 e06 e08 2
e0a e0c 2 e0e
e10 2 e12 e14
2 e16 e18 3
e1d e1e e1f 2
e1a e21 2 e05
e23 1 e25 1
e27 2 df0 e28
1 e2c 1 deb
1 e30 1 e33
2 e36 e37 1
e3f 2 e3b e3f
2 e4b e4d 3
e49 e4a e4f 2
e58 e5a 2 e5c
e5e 2 e60 e62
1 e6a 2 e6c
e6d 2 e64 e6f
2 e71 e73 2
e75 e77 2 e79
e7b 2 e7d e7f
2 e57 e81 1
e83 1 e85 2
e8f e91 3 e8d
e8e e93 2 e9c
e9e 2 e9b ea0
1 ea2 1 ea4
3 eab eac ead
3 e86 ea5 eaf
1 eb1 2 e38
eb2 2 eb6 eb7
1 ebd 2 eb9
ebd 2 ec9 ece
2 edf ee1 3
edd ede ee3 2
eec eee 2 ef0
ef2 2 ef4 ef6
2 ef8 efa 2
efc efe 3 f03
f04 f05 2 f00
f07 2 eeb f09
1 f0b 1 f0d
2 ed6 f0e 1
f12 1 ed1 1
f16 1 f21 2
f1d f21 2 f2d
f2f 3 f2b f2c
f31 2 f3a f3c
2 f3e f40 2
f42 f44 1 f4c
2 f4e f4f 2
f46 f51 2 f53
f55 2 f57 f59
2 f5b f5d 2
f5f f61 2 f39
f63 1 f65 1
f67 2 f71 f73
3 f6f f70 f75
2 f7e f80 2
f7d f82 1 f84
1 f86 3 f8d
f8e f8f 3 f68
f87 f91 1 f93
2 fa8 fad 2
fbe fc0 3 fbc
fbd fc2 2 fcb
fcd 2 fcf fd1
2 fd3 fd5 2
fd7 fd9 2 fdb
fdd 3 fe2 fe3
fe4 2 fdf fe6
2 fca fe8 1
fea 1 fec 2
fb5 fed 1 ff1
1 fb0 1 ff5
1 1000 2 ffc
1000 2 100c 100e
3 100a 100b 1010
2 1019 101b 2
101d 101f 2 1021
1023 1 102b 2
102d 102e 2 1025
1030 2 1032 1034
2 1036 1038 2
103a 103c 2 103e
1040 2 1018 1042
1 1044 1 1046
2 1050 1052 3
104e 104f 1054 2
105d 105f 2 105c
1061 1 1063 1
1065 3 106c 106d
106e 3 1047 1066
1070 1 1072 1
1074 1 1080 2
107d 1083 1 1085
5 f19 f94 ff8
1073 1086 2 1091
1093 3 108f 1090
1095 2 109e 10a0
2 10a2 10a4 2
10a6 10a8 1 10b0
2 10b2 10b3 2
10aa 10b5 2 10b7
10b9 2 10bb 10bd
2 10bf 10c1 2
10c3 10c5 2 109d
10c7 1 10c9 1
10cb 2 10d5 10d7
3 10d3 10d4 10d9
2 10e2 10e4 2
10e1 10e6 1 10e8
1 10ea 3 10f1
10f2 10f3 3 10cc
10eb 10f5 3 10f7
1088 10f8 2 10fb
10fc 1 1102 2
10fe 1102 2 111a
111f 2 1130 1132
3 112e 112f 1134
2 113d 113f 2
1141 1143 2 1145
1147 2 1149 114b
2 114d 114f 3
1154 1155 1156 2
1151 1158 2 113c
115a 1 115c 1
115e 2 1127 115f
1 1163 1 1122
1 1167 1 1172
2 116e 1172 2
117e 1180 3 117c
117d 1182 2 118b
118d 2 118f 1191
2 1193 1195 1
119d 2 119f 11a0
2 1197 11a2 2
11a4 11a6 2 11a8
11aa 2 11ac 11ae
2 11b0 11b2 2
118a 11b4 1 11b6
1 11b8 2 11c2
11c4 3 11c0 11c1
11c6 2 11cf 11d1
2 11ce 11d3 1
11d5 1 11d7 3
11de 11df 11e0 3
11b9 11d8 11e2 1
11eb 2 11e7 11eb
3 11f0 11f1 11f2
1 11f6 2 11f4
11f6 2 11fa 11fb
1 11ff 2 11fd
11ff 2 1203 1204
2 1209 120a 1
120c 2 1206 120c
2 1215 1216 2
121b 121c 1 121e
2 1218 121e 2
122b 122d 3 1229
122a 122f 2 1238
123a 2 123c 123e
2 1240 1242 1
124a 2 124c 124d
2 1244 124f 2
1251 1253 2 1255
1257 2 1259 125b
2 125d 125f 2
1237 1261 1 1263
1 1265 2 126f
1271 3 126d 126e
1273 2 127c 127e
2 127b 1280 1
1282 1 1284 3
128b 128c 128d 3
1266 1285 128f 1
1291 1 1292 2
1295 1294 2 116a
1296 1 1298 c
a13 a69 b48 b52
bd5 bd8 c45 c50
cc9 d44 10f9 1299
1 129b 2 129e
129f 1 12a3 2
12a1 12a3 2 12a7
12a8 1 12ae 2
12aa 12ae 1 12b1
2 12b9 12ba 1
12be 2 12bc 12be
2 12cb 12cd 3
12c9 12ca 12cf 2
12d8 12da 2 12dc
12de 2 12e0 12e2
1 12ea 2 12ec
12ed 2 12e4 12ef
2 12f1 12f3 2
12f5 12f7 2 12f9
12fb 2 12fd 12ff
2 12d7 1301 1
1303 1 1305 2
130f 1311 3 130d
130e 1313 2 131c
131e 2 131b 1320
1 1322 1 1324
3 132b 132c 132d
3 1306 1325 132f
1 1331 2 1334
1335 1 133b 2
1337 133b 2 1349
134e 2 135f 1361
3 135d 135e 1363
2 136c 136e 2
1370 1372 2 1374
1376 2 1378 137a
2 137c 137e 3
1383 1384 1385 2
1380 1387 2 136b
1389 1 138b 1
138d 2 1356 138e
1 1392 1 1351
1 1396 1 13a1
2 139d 13a1 2
13aa 13af 2 13c0
13c2 3 13be 13bf
13c4 2 13cd 13cf
2 13d1 13d3 2
13d5 13d7 2 13d9
13db 2 13dd 13df
3 13e4 13e5 13e6
2 13e1 13e8 2
13cc 13ea 1 13ec
1 13ee 2 13b7
13ef 1 13f3 1
13b2 1 13f7 1
1402 2 13fe 1402
2 140e 1410 3
140c 140d 1412 2
141b 141d 2 141f
1421 2 1423 1425
1 142d 2 142f
1430 2 1427 1432
2 1434 1436 2
1438 143a 2 143c
143e 2 1440 1442
2 141a 1444 1
1446 1 1448 2
1452 1454 3 1450
1451 1456 2 145f
1461 2 145e 1463
1 1465 1 1467
3 146e 146f 1470
3 1449 1468 1472
1 1474 2 13fa
1475 1 1477 2
1399 1478 1 147a
2 1332 147b 1
147d 2 1480 1481
1 1485 2 1483
1485 2 1489 148a
1 148e 2 148c
148e 1 1495 1
1497 2 149a 149b
1 14a1 2 149d
14a1 1 14a4 2
14ab 14ae 2 14b2
14b5 2 14b7 14b8
2 14b9 14bc 1
14c0 2 14be 14c0
2 14cb 14cc 2
14d0 14d1 2 14d5
14d6 2 14da 14db
2 14df 14e0 2
14e4 14e5 2 14e9
14ea 2 14ee 14ef
d 14c8 14c9 14ce
14d3 14d8 14dd 14e2
14e7 14ec 14f1 14f2
14f3 14f4 2 14f9
14fa 1 1500 2
14fc 1500 2 150b
150d 3 1509 150a
150f 2 1518 151a
2 151c 151e 2
1520 1522 1 152a
2 152c 152d 2
1524 152f 2 1517
1531 1 1533 1
1535 2 153f 1541
3 153d 153e 1543
2 154c 154e 2
154b 1550 1 1552
1 1554 2 155b
155c 3 1536 1555
155e 2 1562 1563
1 1567 2 1565
1567 2 1572 1574
3 1570 1571 1576
2 157f 1581 2
1583 1585 2 1587
1589 1 158f 2
1591 1592 2 158b
1594 2 1596 1598
2 159a 159c 2
159e 15a0 2 15a2
15a4 2 157e 15a6
1 15a8 1 15aa
2 15b4 15b6 3
15b2 15b3 15b8 2
15c1 15c3 2 15c0
15c5 1 15c7 1
15c9 2 15cf 15d0
3 15d2 15d3 15d4
3 15ab 15ca 15d6
2 15d9 15d8 3
14c5 14f7 15da 1
15de 2 15e0 15e1
2 15e4 15e5 1
15e9 2 15e7 15e9
2 15ee 15ef 1
15f3 2 15f1 15f3
2 15fa 15fb 1
15ff 2 15fd 15ff
2 1604 1605 1
1609 2 1607 1609
1 1611 2 1615
1616 1 161a 2
1618 161a 1 161f
2 1624 1625 1
1629 2 1627 1629
2 162e 162f 1
1633 2 1631 1633
1 163b 2 1640
1641 1 1645 2
1643 1645 1 164a
4 164d 1622 163e
164c 1 164e 1
1650 2 15e2 1651
2 1653 1654 2
1657 1658 1 165e
2 165a 165e 3
166c 166d 166e 2
1676 1677 1 167b
2 1679 167b 2
1682 1685 2 168c
1691 2 16a2 16a4
3 16a0 16a1 16a6
2 16af 16b1 2
16b3 16b5 2 16b7
16b9 2 16bb 16bd
2 16bf 16c1 3
16c6 16c7 16c8 2
16c3 16ca 2 16ae
16cc 1 16ce 1
16d0 2 1699 16d1
1 16d5 1 1694
1 16d9 1 16e4
2 16e0 16e4 2
16e9 16ea 1 16ee
2 16ec 16ee 2
16fc 1701 2 1712
1714 3 1710 1711
1716 2 171f 1721
2 1723 1725 2
1727 1729 2 172b
172d 2 172f 1731
3 1736 1737 1738
2 1733 173a 2
171e 173c 1 173e
1 1740 2 1709
1741 1 1745 1
1704 1 1749 1
1754 2 1750 1754
1 175a 1 175c
2 174c 175d 1
175f 1 1760 1
1764 2 1766 1767
2 16dc 1768 2
176a 176b 1 176f
2 176d 176f 2
177b 1780 2 1791
1793 3 178f 1790
1795 2 179e 17a0
2 17a2 17a4 2
17a6 17a8 2 17aa
17ac 2 17ae 17b0
3 17b5 17b6 17b7
2 17b2 17b9 2
179d 17bb 1 17bd
1 17bf 2 1788
17c0 1 17c4 1
1783 1 17c8 2
17ec 17f1 2 1802
1804 3 1800 1801
1806 2 180f 1811
2 1813 1815 2
1817 1819 2 181b
181d 2 181f 1821
3 1826 1827 1828
2 1823 182a 2
180e 182c 1 182e
1 1830 2 17f9
1831 1 1835 1
17f4 1 1839 1
1844 2 1840 1844
2 1850 1852 3
184e 184f 1854 2
185d 185f 2 1861
1863 2 1865 1867
1 186f 2 1871
1872 2 1869 1874
2 1876 1878 2
187a 187c 2 187e
1880 2 1882 1884
2 185c 1886 1
1888 1 188a 2
1894 1896 3 1892
1893 1898 2 18a1
18a3 2 18a0 18a5
1 18a7 1 18a9
3 18b0 18b1 18b2
3 188b 18aa 18b4
1 18b6 2 18ba
18bb 1 18bf 2
18bd 18bf 1 18c1
2 18c4 18c6 1
18df 2 18de 18df
1 18e7 1 18ed
2 18ef 18f0 2
18dc 18f1 2 1902
1904 3 1900 1901
1906 2 190f 1911
2 1913 1915 2
1917 1919 2 191b
191d 2 191f 1921
3 1926 1927 1928
2 1923 192a 2
190e 192c 1 192e
1 1930 2 18f9
1931 1 1935 1
18f4 1 1939 5
17cb 183c 18b7 18c8
193c 3 1941 1942
1943 1 1947 2
1945 1947 1 1957
2 1956 1957 1
195f 1 1965 2
1967 1968 2 1954
1969 2 197a 197c
3 1978 1979 197e
2 1987 1989 2
198b 198d 2 198f
1991 2 1993 1995
2 1997 1999 3
199e 199f 19a0 2
199b 19a2 2 1986
19a4 1 19a6 1
19a8 2 1971 19a9
1 19ad 1 196c
1 19b1 1 19b4
2 19b8 19b7 1
19c6 2 19c5 19c6
1 19ce 1 19d4
2 19d6 19d7 2
19c3 19d8 2 19e9
19eb 3 19e7 19e8
19ed 2 19f6 19f8
2 19fa 19fc 2
19fe 1a00 2 1a02
1a04 2 1a06 1a08
3 1a0d 1a0e 1a0f
2 1a0a 1a11 2
19f5 1a13 1 1a15
1 1a17 2 19e0
1a18 1 1a1c 1
19db 1 1a20 1
1a31 2 1a30 1a31
1 1a39 1 1a3f
2 1a41 1a42 2
1a2e 1a43 2 1a54
1a56 3 1a52 1a53
1a58 2 1a61 1a63
2 1a65 1a67 2
1a69 1a6b 2 1a6d
1a6f 2 1a71 1a73
3 1a78 1a79 1a7a
2 1a75 1a7c 2
1a60 1a7e 1 1a80
1 1a82 2 1a4b
1a83 1 1a87 1
1a46 1 1a8b 1
1a99 2 1a98 1a99
1 1aa1 1 1aa7
2 1aa9 1aaa 2
1a96 1aab 2 1abc
1abe 3 1aba 1abb
1ac0 2 1ac9 1acb
2 1acd 1acf 2
1ad1 1ad3 2 1ad5
1ad7 2 1ad9 1adb
3 1ae0 1ae1 1ae2
2 1add 1ae4 2
1ac8 1ae6 1 1ae8
1 1aea 2 1ab3
1aeb 1 1aef 1
1aae 1 1af3 a
1663 1666 1669 1671
1674 176c 19b9 1a23
1a8e 1af6 1 1af9
2 1b01 1b02 1
1b06 2 1b04 1b06
2 1b0a 1b0b 1
1b11 2 1b0d 1b11
2 1b17 1b18 1
1b1e 2 1b1a 1b1e
1 1b23 1 1b2a
1 1b2c 1 1b2d
1 1b2f 2 1b32
1b33 1 1b37 2
1b35 1b37 1 1b3e
1 1b40 1 1b42
1 1b47 1 1b4e
1 1b55 1 1b5f
1 1b61 2 1b6a
1b6b 1 1b6f 2
1b6d 1b6f 2 1b73
1b74 1 1b7a 2
1b76 1b7a 2 1b7e
1b80 2 1b82 1b84
2 1b86 1b88 2
1b8a 1b8c 2 1b8e
1b90 2 1b92 1b94
2 1b96 1b98 1
1b9b 2 1b9f 1ba0
1 1ba4 2 1ba2
1ba4 2 1ba8 1baa
2 1bac 1bae 2
1bb0 1bb2 2 1bb4
1bb6 2 1bb8 1bba
2 1bbc 1bbe 2
1bc0 1bc2 2 1bc4
1bc6 1 1bc9 2
1bcd 1bcf 2 1bd1
1bd3 2 1bd5 1bd7
2 1bd9 1bdb 2
1bdd 1bdf 1 1be2
3 1be4 1bcb 1be5
1 1be6 2 1be9
1bea 1 1bf0 2
1bec 1bf0 2 1bf4
1bf5 1 1bfb 2
1bf7 1bfb 2 1c01
1c02 1 1c08 2
1c04 1c08 1 1c17
1 1c40 2 1c3f
1c40 1 1c48 1
1c4e 2 1c50 1c51
2 1c3d 1c52 2
1c63 1c65 3 1c61
1c62 1c67 2 1c70
1c72 2 1c74 1c76
2 1c78 1c7a 2
1c7c 1c7e 2 1c80
1c82 3 1c87 1c88
1c89 2 1c84 1c8b
2 1c6f 1c8d 1
1c8f 1 1c91 2
1c5a 1c92 1 1c96
1 1c55 1 1c9a
1 1cb7 2 1cb6
1cb7 1 1cbf 1
1cc5 2 1cc7 1cc8
2 1cb4 1cc9 2
1cda 1cdc 3 1cd8
1cd9 1cde 2 1ce7
1ce9 2 1ceb 1ced
2 1cef 1cf1 2
1cf3 1cf5 2 1cf7
1cf9 3 1cfe 1cff
1d00 2 1cfb 1d02
2 1ce6 1d04 1
1d06 1 1d08 2
1cd1 1d09 1 1d0d
1 1ccc 1 1d11
4 1c20 1c25 1c9d
1d14 1 1d22 2
1d21 1d22 1 1d2a
1 1d30 2 1d32
1d33 2 1d1f 1d34
2 1d45 1d47 3
1d43 1d44 1d49 2
1d52 1d54 2 1d56
1d58 2 1d5a 1d5c
2 1d5e 1d60 2
1d62 1d64 3 1d69
1d6a 1d6b 2 1d66
1d6d 2 1d51 1d6f
1 1d71 1 1d73
2 1d3c 1d74 1
1d78 1 1d37 1
1d7c 2 1d19 1d7f
2 1d82 1d83 3
1c11 1c16 1d84 1
1d86 1 1d88 1
1d90 2 1d92 1d93
1 1d97 2 1d95
1d97 1 1d9d 2
1d9f 1da0 2 1da2
1da3 2 1da5 1da7
1 1d99 1 1daf
2 1db1 1db2 2
1db4 1db5 2 1dab
1db8 1 1dc0 2
1dbf 1dc0 2 1dca
1dcc 3 1dc9 1dce
1dcf 1 1dd1 2
1dd3 1dd4 1 1dd8
2 1dd6 1dd8 2
1ddf 1de1 3 1dde
1de3 1de4 1 1de6
2 1de8 1de9 1
1ded 2 1deb 1ded
1 1df3 1 1df5
2 1df8 1dfa 2
1df6 1dfd 1 1e02
2 1e01 1e02 2
1e0e 1e10 3 1e0c
1e0d 1e12 2 1e1b
1e1d 2 1e1f 1e21
2 1e23 1e25 1
1e2d 2 1e2f 1e30
2 1e27 1e32 2
1e1a 1e34 1 1e36
1 1e38 2 1e42
1e44 3 1e40 1e41
1e46 2 1e4f 1e51
2 1e4e 1e53 1
1e55 1 1e57 2
1e5e 1e5f 3 1e39
1e58 1e61 1 1e63
2 1e69 1e6e 2
1e7f 1e81 3 1e7d
1e7e 1e83 2 1e8c
1e8e 2 1e90 1e92
2 1e94 1e96 2
1e98 1e9a 2 1e9c
1e9e 3 1ea3 1ea4
1ea5 2 1ea0 1ea7
2 1e8b 1ea9 1
1eab 1 1ead 2
1e76 1eae 1 1eb2
1 1e71 1 1eb6
5 1dba 1dbd 1e00
1e64 1eb9 1 1ebc
2 1ebf 1ec0 1
1ec6 2 1ec2 1ec6
2 1ed0 1ed2 2
1ed7 1ed9 4 1ecb
1ece 1ed5 1edc 2
1ee0 1ee1 1 1ee7
2 1ee3 1ee7 2
1eee 1ef0 2 1ef5
1ef7 4 1eec 1ef3
1efa 1efd 2 1f01
1f02 1 1f08 2
1f04 1f08 1 1f11
2 1f17 1f19 2
1f1e 1f20 2 1f25
1f27 3 1f1c 1f23
1f2a 1 1f2c 2
1f2f 1f31 1 1f35
2 1f3b 1f3d 2
1f42 1f44 2 1f49
1f4b 3 1f40 1f47
1f4e 1 1f50 5
1f0d 1f10 1f2d 1f34
1f51 2 1f54 1f56
2 1f58 1f5a 1
1f61 2 1f67 1f69
2 1f6e 1f70 2
1f75 1f77 3 1f6c
1f73 1f7a 1 1f7c
2 1f7f 1f81 2
1f83 1f85 2 1f87
1f89 2 1f8b 1f8d
2 1f8f 1f91 2
1f93 1f95 1 1f99
2 1f9f 1fa1 2
1fa3 1fa5 2 1fa7
1fa9 1 1fac 1
1fae 5 1f5d 1f60
1f7d 1f98 1faf 2
1fb1 1fb2 1 1fb3
3 1fb5 1eff 1fb6
2 1fb9 1fba 1
1fc0 2 1fbc 1fc0
1 1fc3 2 1fcd
1fd2 2 1fe3 1fe5
3 1fe1 1fe2 1fe7
2 1ff0 1ff2 2
1ff4 1ff6 2 1ff8
1ffa 2 1ffc 1ffe
2 2000 2002 3
2007 2008 2009 2
2004 200b 2 1fef
200d 1 200f 1
2011 2 1fda 2012
1 2016 1 1fd5
1 201a 1 2025
2 2021 2025 1
202c 2 202e 202f
2 2034 2036 2
203b 203d 2 203f
2041 2 2043 2045
2 2047 2049 3
2032 2039 204c 2
2056 2058 3 2054
2055 205a 2 2063
2065 2 2067 2069
2 206b 206d 1
2075 2 2077 2078
2 206f 207a 2
207c 207e 2 2080
2082 2 2084 2086
2 2088 208a 2
2062 208c 1 208e
1 2090 2 209a
209c 3 2098 2099
209e 2 20a7 20a9
2 20a6 20ab 1
20ad 1 20af 3
20b6 20b7 20b8 3
2091 20b0 20ba 2
20bc 20bd 2 201d
20be 1 20c0 1
20c2 2 20cc 20d1
2 20e2 20e4 3
20e0 20e1 20e6 2
20ef 20f1 2 20f3
20f5 2 20f7 20f9
2 20fb 20fd 2
20ff 2101 3 2106
2107 2108 2 2103
210a 2 20ee 210c
1 210e 1 2110
2 20d9 2111 1
2115 1 20d4 1
2119 1 2124 2
2120 2124 2 2129
212b 2 2130 2132
2 2134 2136 2
2138 213a 2 213c
213e 2 212e 2141
2 214b 214d 3
2149 214a 214f 2
2158 215a 2 215c
215e 2 2160 2162
1 216a 2 216c
216d 2 2164 216f
2 2171 2173 2
2175 2177 2 2179
217b 2 217d 217f
2 2157 2181 1
2183 1 2185 2
218f 2191 3 218d
218e 2193 2 219c
219e 2 219b 21a0
1 21a2 1 21a4
3 21ab 21ac 21ad
3 2186 21a5 21af
2 21b1 21b2 2
211c 21b3 1 21b5
1 21b7 2 21c1
21c6 2 21d7 21d9
3 21d5 21d6 21db
2 21e4 21e6 2
21e8 21ea 2 21ec
21ee 2 21f0 21f2
2 21f4 21f6 3
21fb 21fc 21fd 2
21f8 21ff 2 21e3
2201 1 2203 1
2205 2 21ce 2206
1 220a 1 21c9
1 220e 1 2219
2 2215 2219 2
221e 2220 2 2225
2227 2 2229 222b
2 222d 222f 2
2231 2233 2 2223
2236 2 2240 2242
3 223e 223f 2244
2 224d 224f 2
2251 2253 2 2255
2257 1 225f 2
2261 2262 2 2259
2264 2 2266 2268
2 226a 226c 2
226e 2270 2 2272
2274 2 224c 2276
1 2278 1 227a
2 2284 2286 3
2282 2283 2288 2
2291 2293 2 2290
2295 1 2297 1
2299 3 22a0 22a1
22a2 3 227b 229a
22a4 2 22a6 22a7
2 2211 22a8 1
22aa 2 22ad 22ae
1 22b2 2 22b0
22b2 2 22b6 22b7
1 22bb 2 22b9
22bb 2 22c1 22c3
2 22c9 22ca 1
22cc 2 22c5 22ce
2 22d0 22d2 1
22d5 1 22d7 4
20c1 21b6 22ab 22d8
1 22da 1 22dc
1 22e4 2 22e6
22e7 1 22f0 2
22ef 22f0 2 22fc
22fe 4 22fa 22fb
2300 2301 2 230a
230f 2 2320 2322
3 231e 231f 2324
2 232d 232f 2
2331 2333 2 2335
2337 2 2339 233b
2 233d 233f 3
2344 2345 2346 2
2341 2348 2 232c
234a 1 234c 1
234e 2 2317 234f
1 2353 1 2312
1 2357 1 2362
2 235e 2362 2
236e 2370 3 236c
236d 2372 2 237b
237d 2 237f 2381
2 2383 2385 1
238d 2 238f 2390
2 2387 2392 2
2394 2396 2 2398
239a 2 239c 239e
2 23a0 23a2 2
237a 23a4 1 23a6
1 23a8 2 23b2
23b4 3 23b0 23b1
23b6 2 23bf 23c1
2 23be 23c3 1
23c5 1 23c7 3
23ce 23cf 23d0 3
23a9 23c8 23d2 1
23d4 2 23d7 23d9
2 23db 23dd 2
23df 23e1 2 23e3
23e5 2 23e7 23e9
2 23eb 23ed 2
23f2 23f3 1 23f9
2 23f5 23f9 2
23fd 23ff 1 2402
2 2405 2407 1
240a 2 240c 240d
2 2410 2411 1
2417 2 2413 2417
1 241b 1 241d
2 2420 2422 7
2304 235a 23d5 23f0
240e 241e 2425 3
22ea 22ed 2428 1
242a 2 242d 242e
1 2434 2 2430
2434 1 243a 2
243c 243d 1 2446
2 2445 2446 2
2452 2454 4 2450
2451 2456 2457 2
2460 2465 2 2476
2478 3 2474 2475
247a 2 2483 2485
2 2487 2489 2
248b 248d 2 248f
2491 2 2493 2495
3 249a 249b 249c
2 2497 249e 2
2482 24a0 1 24a2
1 24a4 2 246d
24a5 1 24a9 1
2468 1 24ad 1
24b8 2 24b4 24b8
2 24c4 24c6 3
24c2 24c3 24c8 2
24d1 24d3 2 24d5
24d7 2 24d9 24db
1 24e3 2 24e5
24e6 2 24dd 24e8
2 24ea 24ec 2
24ee 24f0 2 24f2
24f4 2 24f6 24f8
2 24d0 24fa 1
24fc 1 24fe 2
2508 250a 3 2506
2507 250c 2 2515
2517 2 2514 2519
1 251b 1 251d
3 2524 2525 2526
3 24ff 251e 2528
1 252a 2 252d
252f 2 2531 2533
2 2535 2537 2
2539 253b 2 253d
253f 2 2541 2543
2 2545 2547 2
254c 254e 5 245a
24b0 252b 254a 2551
3 2440 2443 2554
1 2556 2 2559
255b 7 1d87 1ebd
1fb7 22db 242b 2557
255e 2 2560 2561
2 2564 2566 1
257b 1 2581 2
2583 2584 1 258c
2 2588 258c 1
2591 1 2593 2
2596 2597 1 259b
2 2599 259b 2
259f 25a0 1 25a6
2 25a2 25a6 2
25ac 25ad 1 25b3
2 25af 25b3 2
25b9 25ba 1 25c0
2 25bc 25c0 1
25c3 1 25dd 1
25e3 2 25e5 25e6
1 25ee 2 25ea
25ee 2 25f4 25fa
2 260b 260d 3
2609 260a 260f 2
2618 261a 2 261c
261e 2 2620 2622
2 2624 2626 2
2628 262a 3 262f
2630 2631 2 262c
2633 2 2617 2635
1 2637 1 2639
2 2602 263a 1
263e 1 25fd 1
2642 2 2645 2648
2 264c 2652 2
2663 2665 3 2661
2662 2667 2 2670
2672 2 2674 2676
2 2678 267a 2
267c 267e 2 2680
2682 3 2687 2688
2689 2 2684 268b
2 266f 268d 1
268f 1 2691 2
265a 2692 1 2696
1 2655 1 269a
1 269d 2 26a0
26a1 4 25cf 25d4
25e7 26a2 1 26a4
2 26ad 26ae 1
26b2 2 26b0 26b2
3 26b6 26b7 26b8
1 26bc 2 26ba
26bc 2 26c3 26c6
2 26ca 26cb 1
26cd 1 26d1 2
26cf 26d1 2 26dd
26e2 2 26f3 26f5
3 26f1 26f2 26f7
2 2700 2702 2
2704 2706 2 2708
270a 2 270c 270e
2 2710 2712 3
2717 2718 2719 2
2714 271b 2 26ff
271d 1 271f 1
2721 2 26ea 2722
1 2726 1 26e5
1 272a 2 2730
2731 1 2735 2
2733 2735 2 273a
2740 2 2751 2753
3 274f 2750 2755
2 275e 2760 2
2762 2764 2 2766
2768 2 276a 276c
2 276e 2770 3
2775 2776 2777 2
2772 2779 2 275d
277b 1 277d 1
277f 2 2748 2780
1 2784 1 2743
1 2788 2 2795
2797 3 2793 2794
2799 2 27a2 27a4
2 27a6 27a8 2
27aa 27ac 1 27b4
2 27b6 27b7 2
27ae 27b9 2 27bb
27bd 2 27bf 27c1
2 27c3 27c5 2
27c7 27c9 2 27a1
27cb 1 27cd 1
27cf 2 27d9 27db
3 27d7 27d8 27dd
2 27e6 27e8 2
27e5 27ea 1 27ec
1 27ee 3 27f5
27f6 27f7 4 278b
27d0 27ef 27f9 1
27fb 2 272d 27fc
1 27fe 1 27ff
2 2801 2802 2
2823 2824 20 2806
2807 2808 2809 280a
280b 280c 280d 280e
280f 2810 2811 2812
2813 2814 2815 2816
2817 2818 2819 281a
281b 281c 281d 281e
281f 2820 2821 2826
2827 2828 2829 1
282f 2 282d 282f
2 2834 283a 2
284b 284d 3 2849
284a 284f 2 2858
285a 2 285c 285e
2 2860 2862 2
2864 2866 2 2868
286a 3 286f 2870
2871 2 286c 2873
2 2857 2875 1
2877 1 2879 2
2842 287a 1 287e
1 283d 1 2882
1 288b 2 2887
288b 1 2892 1
2894 2 289e 28a0
3 289c 289d 28a2
2 28ab 28ad 2
28af 28b1 2 28b3
28b5 1 28bb 2
28bd 28be 2 28b7
28c0 2 28c2 28c4
2 28c6 28c8 2
28ca 28cc 2 28ce
28d0 2 28aa 28d2
1 28d4 1 28d6
2 28e0 28e2 3
28de 28df 28e4 2
28ed 28ef 2 28ec
28f1 1 28f3 1
28f5 3 28fa 28fb
28fc 5 2885 2895
28d7 28f6 28fe 3
2902 2903 2904 1
2908 2 2906 2908
3 290d 290e 290f
1 2913 2 2911
2913 1 2921 2
2920 2921 1 2929
1 292f 2 2931
2932 2 291e 2933
2 2944 2946 3
2942 2943 2948 2
2951 2953 2 2955
2957 2 2959 295b
2 295d 295f 2
2961 2963 3 2968
2969 296a 2 2965
296c 2 2950 296e
1 2970 1 2972
2 293b 2973 1
2977 1 2936 1
297b 1 297e 2
2982 2981 4 2803
282c 2983 2985 2
2988 2989 1 298f
2 298b 298f 2
2994 2997 1 2999
20 299d 299e 299f
29a0 29a1 29a2 29a3
29a4 29a5 29a6 29a7
29a8 29a9 29aa 29ab
29ac 29ad 29ae 29af
29b0 29b1 29b2 29b3
29b4 29b5 29b6 29b7
29b8 29b9 29ba 29bb
29bc 1 29c2 2
29c0 29c2 2 29c6
29c8 1 29cb 1
29cd 2 29d2 29d3
1 29d5 2 29cf
29d5 1 29d9 1
29db 4 299a 29bf
29ce 29dc 2 29de
29df 1 29e1 8
2572 2585 2594 26a5
26a8 26ab 29e0 29e4
2 29ea 29f0 2
2a01 2a03 3 29ff
2a00 2a05 2 2a0e
2a10 2 2a12 2a14
2 2a16 2a18 2
2a1a 2a1c 2 2a1e
2a20 3 2a25 2a26
2a27 2 2a22 2a29
2 2a0d 2a2b 1
2a2d 1 2a2f 2
29f8 2a30 1 2a34
1 29f3 1 2a38
1 2a41 2 2a3d
2a41 1 2a47 2
2a45 2a47 2 2a4c
2a4d 1 2a51 2
2a4f 2a51 2 2a62
2a64 3 2a60 2a61
2a66 2 2a6f 2a71
2 2a73 2a75 2
2a77 2a79 1 2a7f
2 2a81 2a82 2
2a7b 2a84 2 2a86
2a88 2 2a8a 2a8c
2 2a8e 2a90 2
2a92 2a94 2 2a6e
2a96 1 2a98 1
2a9a 2 2aa4 2aa6
3 2aa2 2aa3 2aa8
2 2ab1 2ab3 2
2ab0 2ab5 1 2ab7
1 2ab9 3 2abe
2abf 2ac0 3 2a9b
2aba 2ac2 1 2ac4
1 2ac8 2 2ac6
2ac8 8 2ade 2adf
2ae0 2ae1 2ae2 2ae3
2ae4 2ae5 1 2af0
1 2af6 2 2af8
2af9 1 2b01 2
2afd 2b01 1 2b06
1 2b08 1 2b0a
2 2b12 2b13 1
2b17 2 2b15 2b17
1 2b1e 2 2b20
2b21 1 2b25 2
2b23 2b25 1 2b2c
1 2b2e 2 2b33
2b34 1 2b38 2
2b36 2b38 1 2b3d
2 2b3b 2b3d 1
2b52 2 2b51 2b52
1 2b5a 1 2b60
2 2b62 2b63 2
2b4f 2b64 2 2b75
2b77 3 2b73 2b74
2b79 2 2b82 2b84
2 2b86 2b88 2
2b8a 2b8c 2 2b8e
2b90 2 2b92 2b94
3 2b99 2b9a 2b9b
2 2b96 2b9d 2
2b81 2b9f 1 2ba1
1 2ba3 2 2b6c
2ba4 1 2ba8 1
2b67 1 2bac 1
2baf 1 2bb2 9
2bb3 2bb6 2bb9 2bbc
2bbf 2bc2 2bc5 2bc8
2bcb 1 2bcd 1
2bd1 2 2bcf 2bd1
1 2bd4 1 2be7
2 2be6 2be7 1
2bef 1 2bf5 2
2bf7 2bf8 2 2be4
2bf9 2 2c0a 2c0c
3 2c08 2c09 2c0e
2 2c17 2c19 2
2c1b 2c1d 2 2c1f
2c21 2 2c23 2c25
2 2c27 2c29 3
2c2e 2c2f 2c30 2
2c2b 2c32 2 2c16
2c34 1 2c36 1
2c38 2 2c01 2c39
1 2c3d 1 2bfc
1 2c41 1 2c44
1 2c47 1 2c49
1 2c4e 2 2c55
2c57 3 2c59 2c5a
2c5b 1 2c5e 1
2c60 2 2c64 2c66
3 2c68 2c69 2c6a
2 2c61 2c6d 1
2c6f 1 2c71 2
2c78 2c7a 3 2c7c
2c7d 2c7e 1 2c81
1 2c83 1 2c85
1 2c8a 2 2c91
2c93 3 2c95 2c96
2c97 1 2c9a 1
2c9c 2 2ca0 2ca2
3 2ca4 2ca5 2ca6
2 2c9d 2ca9 1
2cab 1 2cad 2
2cb4 2cb6 3 2cb8
2cb9 2cba 1 2cbd
1 2cbf 1 2cc1
1 2cc6 2 2ccd
2ccf 3 2cd1 2cd2
2cd3 1 2cd6 1
2cd8 2 2cdc 2cde
3 2ce0 2ce1 2ce2
2 2cd9 2ce5 1
2ce7 1 2ce9 1
2cee 2 2cf5 2cf7
3 2cf9 2cfa 2cfb
1 2cfe 1 2d00
2 2d04 2d06 3
2d08 2d09 2d0a 2
2d01 2d0d 1 2d0f
2 2d12 2d14 e
2ae6 2afa 2b09 2b2f
2bce 2c48 2c70 2c84
2cac 2cc0 2ce8 2d10
2d17 2d1a 2 2d20
2d26 2 2d37 2d39
3 2d35 2d36 2d3b
2 2d44 2d46 2
2d48 2d4a 2 2d4c
2d4e 2 2d50 2d52
2 2d54 2d56 3
2d5b 2d5c 2d5d 2
2d58 2d5f 2 2d43
2d61 1 2d63 1
2d65 2 2d2e 2d66
1 2d6a 1 2d29
1 2d6e 1 2d75
2 2d73 2d75 1
2d8a 2 2d89 2d8a
1 2d92 1 2d98
2 2d9a 2d9b 2
2d87 2d9c 2 2dad
2daf 3 2dab 2dac
2db1 2 2dba 2dbc
2 2dbe 2dc0 2
2dc2 2dc4 2 2dc6
2dc8 2 2dca 2dcc
3 2dd1 2dd2 2dd3
2 2dce 2dd5 2
2db9 2dd7 1 2dd9
1 2ddb 2 2da4
2ddc 1 2de0 1
2d9f 1 2de4 1
2de7 1 2dea 8
2acd 2ad0 2ad3 2ad6
2adb 2d1d 2d71 2deb
1 2ded 1 2def
2 2df5 2df6 1
2dfa 2 2df8 2dfa
2 2e0b 2e10 2
2e21 2e23 3 2e1f
2e20 2e25 2 2e2e
2e30 2 2e32 2e34
2 2e36 2e38 2
2e3a 2e3c 2 2e3e
2e40 3 2e45 2e46
2e47 2 2e42 2e49
2 2e2d 2e4b 1
2e4d 1 2e4f 2
2e18 2e50 1 2e54
1 2e13 1 2e58
1 2e5b 2 2e60
2e61 2 2e63 2e64
1 2e65 1 2e67
2 2e7c 2e81 2
2e92 2e94 3 2e90
2e91 2e96 2 2e9f
2ea1 2 2ea3 2ea5
2 2ea7 2ea9 2
2eab 2ead 2 2eaf
2eb1 3 2eb6 2eb7
2eb8 2 2eb3 2eba
2 2e9e 2ebc 1
2ebe 1 2ec0 2
2e89 2ec1 1 2ec5
1 2e84 1 2ec9
2 2ecf 2ed0 1
2ed6 2 2ed2 2ed6
1 2ef1 2 2ef0
2ef1 1 2ef9 1
2eff 2 2f01 2f02
2 2eee 2f03 2
2f14 2f16 3 2f12
2f13 2f18 2 2f21
2f23 2 2f25 2f27
2 2f29 2f2b 2
2f2d 2f2f 2 2f31
2f33 3 2f38 2f39
2f3a 2 2f35 2f3c
2 2f20 2f3e 1
2f40 1 2f42 2
2f0b 2f43 1 2f47
1 2f06 1 2f4b
1 2f56 2 2f52
2f56 1 2f6f 2
2f6e 2f6f 1 2f77
1 2f7d 2 2f7f
2f80 2 2f6c 2f81
2 2f92 2f94 3
2f90 2f91 2f96 2
2f9f 2fa1 2 2fa3
2fa5 2 2fa7 2fa9
2 2fab 2fad 2
2faf 2fb1 3 2fb6
2fb7 2fb8 2 2fb3
2fba 2 2f9e 2fbc
1 2fbe 1 2fc0
2 2f89 2fc1 1
2fc5 1 2f84 1
2fc9 1 2fd4 2
2fd0 2fd4 1 2fe1
2 2fe0 2fe1 1
2fe9 1 2fef 2
2ff1 2ff2 2 2fde
2ff3 2 3004 3006
3 3002 3003 3008
2 3011 3013 2
3015 3017 2 3019
301b 2 301d 301f
2 3021 3023 3
3028 3029 302a 2
3025 302c 2 3010
302e 1 3030 1
3032 2 2ffb 3033
1 3037 1 2ff6
1 303b 1 303e
1 3041 2 2fcc
3042 1 3044 2
311d 311f 3 311b
311c 3121 2 312a
312c 2 3129 312e
1 3130 1 3132
7 2edd 2ee2 2f4e
3045 3113 3133 3136
1 313a 2 3138
313a 2 3275 3277
3 3273 3274 3279
2 3282 3284 2
3281 3286 1 3288
1 328a 3 326b
328b 328e 1 32a5
2 32a4 32a5 1
32ad 1 32b3 2
32b5 32b6 2 32a2
32b7 2 32c8 32ca
3 32c6 32c7 32cc
2 32d5 32d7 2
32d9 32db 2 32dd
32df 2 32e1 32e3
2 32e5 32e7 3
32ec 32ed 32ee 2
32e9 32f0 2 32d4
32f2 1 32f4 1
32f6 2 32bf 32f7
1 32fb 1 32ba
1 32ff 1 331b
2 331a 331b 1
3323 1 3329 2
332b 332c 2 3318
332d 2 333e 3340
3 333c 333d 3342
2 334b 334d 2
334f 3351 2 3353
3355 2 3357 3359
2 335b 335d 3
3362 3363 3364 2
335f 3366 2 334a
3368 1 336a 1
336c 2 3335 336d
1 3371 1 3330
1 3375 2 353c
353e 3 353a 353b
3540 2 3549 354b
2 3548 354d 1
354f 1 3551 7
3294 3299 3302 3378
3532 3552 3555 2
3557 3558 1 3559
2 355b 355c 3d
4f8 517 51a 51d
520 523 526 529
52c 52f 532 535
538 53b 53e 541
544 547 54a 54d
550 553 556 559
55c 55f 5d2 6e1
755 7c9 847 858
949 9af 9b2 9c6
9d3 9e7 9f4 a07
129c 147e 1498 1655
1afa 1aff 1b30 1b41
1b62 1b65 1b68 2562
2569 256e 29e7 2a3b
2ac5 2dee 2e68 2ecc
355d 2 356a 356c
3 3568 3569 356e
2 3577 3579 2
3576 357b 2 3582
3586 2 3588 358a
2 358c 3590 2
3581 3592 2 357d
3594 1 3596 3
3597 35a2 35a6 1
3561 2 35b9 35bb
3 35b7 35b8 35bd
2 35c6 35c8 2
35c5 35ca 2 35d1
35d3 2 35d5 35d7
3 35dc 35dd 35de
2 35d9 35e0 2
35d0 35e2 2 35cc
35e4 1 35e6 4
35b0 35e7 35f0 35f4
1 35f8 1 35ab
2 35a9 35fc 69
7b 82 89 90
97 9e a5 ac
b3 ba c1 c8
cf d6 dd e4
eb f2 f9 100
107 10c 113 11a
121 128 12f 136
13d 144 14b 152
159 15f 165 16b
171 177 17d 183
189 18f 195 19b
1a1 1a7 1ad 1b3
1b9 1bf 1c5 1cb
1d1 1d7 1dd 1e3
1e9 1ef 1f5 1fb
201 207 20d 213
219 21f 226 22c
232 238 23f 246
24d 253 259 260
267 26e 275 27c
283 289 28f 295
29b 2a1 2a7 2ad
2b3 2ba 2c0 2c5
2ca 2cf 2d4 2d9
2de 2e3 2ea 2fa
315 31f 326 32d
334 
1
4
0 
3603
0
1
a0
67
86
0 1 1 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 1 33 1 35 1 37
1 39 1 3b 3c 1 3e 3f
1 41 42 41 44 41 46 41
48 41 4a 41 4c 1 4e 1
50 51 50 53 1 55 1 57
1 59 1 5b 1 5d 1 5f
1 61 1 63 1 65 1 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

2a3 1 0
6b 1 0
2b 1 0
e6 1 0
255 1 0
2a9 1 0
21b 1 0
bc 1 0
5f 1 0
270 1 0
4b 1 0
285 1 0
d8 1 0
2e5 1 0
2bc 1 0
1af 1 0
215 1 0
185 1 0
8b 1 0
29d 1 0
27 1 0
2cc 1 0
2ed 1 2
25b 1 0
1f 1 0
53 1 0
1fd 1 0
a7 1 0
1b 1 0
1f1 1 0
2f 1 0
2af 1 0
131 1 0
300 1 3
13f 1 0
fb 1 0
29e1 41 4e
16d 1 0
d1 1 0
138 1 0
173 1 0
63 1 0
43 1 0
23a 1 0
67 1 0
234 1 0
109 1 0
2c2 1 0
291 1 0
4f 1 0
2d6 1 0
1d3 1 0
13 1 0
1a9 1 0
ed 1 0
b5 1 0
19d 1 0
123 1 0
115 1 0
154 1 0
3f 1 0
248 1 0
1d9 1 0
221 1 0
10e 1 0
ae 1 0
3b 1 0
37 1 0
33 1 0
f 1 0
197 1 0
31a 1 0
92 1 0
3 1 0
c3 1 0
27e 1 0
15b 1 0
5b 1 0
328 1 0
146 1 0
321 1 0
22e 1 0
209 1 0
12a 1 0
11c 1 0
28b 1 0
18b 1 0
1f7 1 0
2 0 1
1c7 1 0
1bb 1 0
23 1 0
84 1 0
102 1 0
297 1 0
20f 1 0
7 1 0
1eb 1 0
1a3 1 0
2d1 1 0
191 1 0
a0 1 0
241 1 0
1df 1 0
179 1 0
277 1 0
269 1 0
203 1 0
161 1 0
24f 1 0
228 1 0
167 1 0
57 1 0
f4 1 0
7d 1 0
1c1 1 0
ca 1 0
47 1 0
17f 1 0
df 1 0
2db 1 0
1e5 1 0
17 1 0
2e0 1 0
14d 1 0
2b5 1 0
1cd 1 0
99 1 0
2c7 1 0
76 1 0
1b5 1 0
b 1 0
32f 1 0
262 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_2;
ALTER FUNCTION SP_SEARCH_2 COMPILE DEBUG;
/*#################################################################################################*/
/*#################################################################################################*/
/*
#Stored Procedure  :SP_SEARCH_1
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_SEARCH_1 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_1 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
2a4
2 :e:
1FUNCTION:
1SP_SEARCH_1:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1TYPE001:
1AND_ROLES:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PROJECT_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_TASK_ID:
1H_UNIQUEID:
1H_REC_USER:
1H_RES_ID:
1H_SECURITY_ID:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_FINISH_D:
1H_RES_TYPE:
11:
1H_ASSIGN_ID:
1H_AND_ROLES:
18000:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_FULL_NAME:
1255:
1H_COUNT:
10:
1H_BITFLAG:
1H_TYPE:
1H_WORK_TYPE:
1H_CRI:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_UPDATE:
1H_DAYS:
1H_DURATION:
1H_PARTICIPANT:
1H_PRIORITY:
1H_TOTAL:
1H_TOTPR:
1H_FROM_PRJ:
1H_SCHED_WORK:
1H_JULIAN_DAY:
1H_J_EFECTIVE_DATE:
1H_J_DISCONTI_DATE:
1H_WEEK:
1H_ACTIVE:
1H_REC_STATUS:
1H_RES_COST:
1NUMBER:
10.00:
1STMT:
17999:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_CRI_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TABLE_TYPE:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_TASK_TYPE:
1H_TEMP_VAR:
1ID:
1I:
1II:
1I_RETURN:
1ISF:
1NUMITEMS:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_1(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1109:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_1(110) :: cplan.sql(2555) :: :
1:
1GETTABLE:
1IS NULL:
18:
1150:
1      RETURN_INVALID:: SP_SEARCH_1(151) :: cplan.sql(2596) :: :
1 :
1STATE:: :
1PMO_CNST:
1ELEMENT_ID_REQUIRED:
1153:
1                EXIT:: SP_SEARCH_1(154) :: cplan.sql(2599) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1160:
1      RETURN_INVALID:: SP_SEARCH_1(161) :: cplan.sql(2606) :: :
1163:
1                EXIT:: SP_SEARCH_1(164) :: cplan.sql(2609) :: :
1IS NOT NULL:
1LENGTH:
1<:
114:
1170:
1      RETURN_INVALID:: SP_SEARCH_1(171) :: cplan.sql(2616) :: :
1INVALID_PARAMS:
1173:
1                EXIT:: SP_SEARCH_1(174) :: cplan.sql(2619) :: :
1180:
1      RETURN_INVALID:: SP_SEARCH_1(181) :: cplan.sql(2626) :: :
1183:
1                EXIT:: SP_SEARCH_1(184) :: cplan.sql(2629) :: :
1=:
15:
1190:
1      RETURN_INVALID:: SP_SEARCH_1(191) :: cplan.sql(2636) :: :
1193:
1                EXIT:: SP_SEARCH_1(194) :: cplan.sql(2639) :: :
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1209:
1           EXCEPTION:: SP_SEARCH_1(210) :: cplan.sql(2655) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1216:
1      RETURN_INVALID:: SP_SEARCH_1(217) :: cplan.sql(2662) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1219:
1                EXIT:: SP_SEARCH_1(220) :: cplan.sql(2665) :: :
1ELSIF:
1SELECT SYSTIMESTAMP INTO h_start_date:n         FROM DUAL:
1235:
1           EXCEPTION:: SP_SEARCH_1(236) :: cplan.sql(2681) :: :
1>:
1PMO_STPU:
1STRNPCPY:
133:
1ISPROJECTTYPE:
1!=:
1PROJECT_ID:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2+
1400), PRIORITY:n            INTO h_project_id, h_per_day, h_per_week, h_prior+
1ity:n            FROM TMT_WBS WHERE ELEMENT_ID = h_task_id:
1266:
1           EXCEPTION:: SP_SEARCH_1(267) :: cplan.sql(2712) :: :
1B:
1TYPE_ID:
1TASK_TYPE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1A:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1SELECT B.TYPE_ID, B.TASK_TYPE, B.UNRESOLVED_START, B.UNRESOLVED_FINISH, B.PRO+
1JECT_ID,:n            COALESCE(A.MINUTE_PER_DAY, 480), COALESCE(A.MINUTE_PER_+
1WEEK, 2400), A.PRIORITY:n            INTO h_type, h_task_type, h_task_start_D+
1T, h_task_finish_DT, h_project_id,:n            h_per_day, h_per_week, h_prio+
1rity FROM TMT_WBS A, TMT_WBS B:n            WHERE B.ELEMENT_ID = h_task_id AN+
1D B.TYPE_ID IN (PMO_CNST.SC_TASK,PMO_CNST.SC_TASK_TYPE1,PMO_CNST.SC_TASK_TYPE+
12,PMO_CNST.SC_TASK_TYPE3,PMO_CNST.SC_MILESTONE,PMO_CNST.SC_PERSONAL_TASK,PMO_+
1CNST.SC_ACTIVE_ADM_TASK,PMO_CNST.SC_INACTIVE_ADM_TASK,PMO_CNST.SC_WBS_CHANGE_+
1REQUEST_TASK,PMO_CNST.SC_WBS_ACTION_ITEM_TASK,PMO_CNST.SC_WBS_RISK_TASK,PMO_C+
1NST.SC_WBS_ISSUE_TASK,PMO_CNST.SC_WBS_REQUIREMENT_TASK,PMO_CNST.SC_WBS_DEFECT+
1_TASK,PMO_CNST.SC_WBS_SERVICE_REQUEST_TASK) AND A.ELEMENT_ID = B.PROJECT_ID:
1283:
1           EXCEPTION:: SP_SEARCH_1(284) :: cplan.sql(2729) :: :
1SC_SQL_NO_DATA:
1WBS_ID:
1TMT_CRI:
1SELECT PROJECT_ID, WBS_ID INTO h_project_id, id:n            FROM TMT_CRI WHE+
1RE ELEMENT_ID = h_task_id:
1299:
1           EXCEPTION:: SP_SEARCH_1(300) :: cplan.sql(2745) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n               INTO h_per_day, h_per_week, h_priority:n               FRO+
1M TMT_WBS WHERE ELEMENT_ID = h_project_id:
1318:
1           EXCEPTION:: SP_SEARCH_1(319) :: cplan.sql(2764) :: :
1324:
1        RETURN_ERROR:: SP_SEARCH_1(325) :: cplan.sql(2770) :: :
1RECORD_NOT_FOUND:
1 ID:: :
1327:
1                EXIT:: SP_SEARCH_1(328) :: cplan.sql(2773) :: :
1PMO_RETURN_ERROR_SP:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1346:
1           EXCEPTION:: SP_SEARCH_1(347) :: cplan.sql(2792) :: :
1REC_STATUS:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1362:
1           EXCEPTION:: SP_SEARCH_1(363) :: cplan.sql(2808) :: :
1STRCMP:
1L:
1369:
1        RETURN_ERROR:: SP_SEARCH_1(370) :: cplan.sql(2815) :: :
1LEV_LOCKED_BY_COPY:
1372:
1                EXIT:: SP_SEARCH_1(373) :: cplan.sql(2818) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n         INTO h_per_day, h_per_week, h_priority:n         FROM TMT_WBS WH+
1ERE ELEMENT_ID = h_project_id:
1388:
1           EXCEPTION:: SP_SEARCH_1(389) :: cplan.sql(2834) :: :
1TMT_POOLS:
1SELECT 480, 2400 INTO h_per_day, h_per_week FROM TMT_POOLS WHERE ELEMENT_ID =+
1 h_project_id:
1401:
1           EXCEPTION:: SP_SEARCH_1(402) :: cplan.sql(2847) :: :
1407:
1        RETURN_ERROR:: SP_SEARCH_1(408) :: cplan.sql(2853) :: :
1410:
1                EXIT:: SP_SEARCH_1(411) :: cplan.sql(2856) :: :
1FC_CALC_DURATION:
1441:
1      RETURN_INVALID:: SP_SEARCH_1(442) :: cplan.sql(2887) :: :
1444:
1                EXIT:: SP_SEARCH_1(445) :: cplan.sql(2890) :: :
1449:
1        RETURN_ERROR:: SP_SEARCH_1(450) :: cplan.sql(2895) :: :
1452:
1                EXIT:: SP_SEARCH_1(453) :: cplan.sql(2898) :: :
1100:
12:
13:
14:
1*:
1FC_DECLARE_PMO_TMP_SEARCH:
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1ASSIGNRESOURCE:
1490:
1        RETURN_ERROR:: SP_SEARCH_1(491) :: cplan.sql(2936) :: :
1493:
1                EXIT:: SP_SEARCH_1(494) :: cplan.sql(2939) :: :
1MIN:
1BAK_START_DT:
1TASK_ASSIGNMENTS:
1TASK_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1SELECT MIN(BAK_START_DT), PMO_ORASTD.DAYS(h_start_date) - PMO_ORASTD.DAYS(MIN+
1(BAK_START_DT)):n         INTO h_start_DT, h_total :n         FROM TASK_ASSIG+
1NMENTS:n         WHERE PROJECT_ID = h_project_id :n         AND TASK_ID = h_p+
1roject_id :n         AND RESOURCE_ID = h_res_id :n         AND RESOURCE_TYPE +
1= h_res_type:
1514:
1           EXCEPTION:: SP_SEARCH_1(515) :: cplan.sql(2960) :: :
1PROJECT_ASSIGNMENT_ID:
1SCHED_START:
1TO_DATE:
1SCHED_FINISH:
1SCHED_WORK:
1BIT_FLAG:
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START, CASE WHEN TO_DATE(SubStr(h_start_d+
1ate, 1, 10)) >= TO_DATE(SubStr(SCHED_START, 1, 10)) AND:n               TO_DA+
1TE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(SCHED_FINISH, 1, 10)) AND SC+
1HED_WORK >= h_effort THEN 0 ELSE 1 END,SCHED_WORK:n               INTO h_prj_+
1assign_id, h_start_DT, h_total, h_sched_work:n               FROM TASK_ASSIGN+
1MENTS:n               WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND+
1 RESOURCE_TYPE='0' AND BIT_FLAG = '2':
1542:
1           EXCEPTION:: SP_SEARCH_1(543) :: cplan.sql(2988) :: :
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_WORK:
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1     TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1,+
1 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                     IN+
1TO h_prj_assign_id, h_start_DT, h_total :n                     FROM TASK_ASSI+
1GNMENTS:n                     WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_re+
1s_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
1562:
1           EXCEPTION:: SP_SEARCH_1(563) :: cplan.sql(3008) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1  TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1, 10+
1)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                  INTO h_p+
1rj_assign_id, h_start_DT, h_total :n                  FROM TASK_ASSIGNMENTS:n+
1                  WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RES+
1OURCE_TYPE='0' AND BIT_FLAG = '0':
1582:
1           EXCEPTION:: SP_SEARCH_1(583) :: cplan.sql(3028) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n               T+
1O_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) +
1AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n               INTO h_prj_ass+
1ign_id, h_start_DT, h_total :n               FROM TASK_ASSIGNMENTS:n         +
1      WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='+
11' AND BIT_FLAG = '0':
1600:
1           EXCEPTION:: SP_SEARCH_1(601) :: cplan.sql(3046) :: :
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START,CASE WHEN TO_DATE(SubStr(h_start_da+
1te, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AND TO_DATE(SubStr(SC+
1HED_FINISH, 1, 10)) AND h_effort <= SCHED_WORK THEN 0 ELSE 1 END, SCHED_WORK+
1:n               INTO h_prj_assign_id, h_start_DT,h_total, h_sched_work :n   +
1            FROM TASK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_id +
1AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
1618:
1           EXCEPTION:: SP_SEARCH_1(619) :: cplan.sql(3064) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLAN+
1NED_WORK THEN 0 ELSE 1 END:n                     INTO h_prj_assign_id, h_star+
1t_DT,h_total :n                     FROM TASK_ASSIGNMENTS:n                  +
1   WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' +
1AND BIT_FLAG = '0':
1637:
1           EXCEPTION:: SP_SEARCH_1(638) :: cplan.sql(3083) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1               INTO h_prj_assign_id, h_start_DT,h_total :n                  F+
1ROM TASK_ASSIGNMENTS:n                  WHERE TASK_ID=h_project_id AND RESOUR+
1CE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
1657:
1           EXCEPTION:: SP_SEARCH_1(658) :: cplan.sql(3103) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1            INTO h_prj_assign_id, h_start_DT,h_total :n               FROM TA+
1SK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_r+
1es_id AND RESOURCE_TYPE='1' AND BIT_FLAG = '0':
1674:
1           EXCEPTION:: SP_SEARCH_1(675) :: cplan.sql(3120) :: :
1684:
1        RETURN_ERROR:: SP_SEARCH_1(685) :: cplan.sql(3130) :: :
1TASK_ASSIGNMENT_ERROR:
1687:
1                EXIT:: SP_SEARCH_1(688) :: cplan.sql(3133) :: :
1SUM:
1SCHED_MIN:
1TASK_DAY_OF_YEAR:
1TSK_ASSIGNMENT_ID:
1DAY_YEAR:
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                  FROM TASK_DAY_OF_+
1YEAR:n                  WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID+
1 = h_prj_assign_id :n                  AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_+
1start_date, 1, 10)) AND TO_DATE(SubStr(h_finish_DT, 1, 10)):
1704:
1           EXCEPTION:: SP_SEARCH_1(705) :: cplan.sql(3150) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                  FROM TASK_DAY_OF_+
1YEAR:n                  WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID+
1 = h_prj_assign_id :n                  AND DAY_YEAR >= TO_DATE(SubStr(h_start+
1_date, 1, 10)):
1721:
1           EXCEPTION:: SP_SEARCH_1(722) :: cplan.sql(3167) :: :
1729:
1        RETURN_ERROR:: SP_SEARCH_1(730) :: cplan.sql(3175) :: :
1732:
1                EXIT:: SP_SEARCH_1(733) :: cplan.sql(3178) :: :
1ISNOTPROJECTTYPE:
1740:
1        RETURN_ERROR:: SP_SEARCH_1(741) :: cplan.sql(3186) :: :
1743:
1                EXIT:: SP_SEARCH_1(744) :: cplan.sql(3189) :: :
1NICK_NAME:
1JULIAN_DAY:
1ACTIVE:
1EFFECTIVE_DATE:
1DISCONTINUE_DATE:
1RESOURCES:
1SELECT NICK_NAME, PMO_ORASTD.JULIAN_DAY(h_start_DT), ACTIVE, COALESCE(PMO_ORA+
1STD.JULIAN_DAY(EFFECTIVE_DATE),0),COALESCE(PMO_ORASTD.JULIAN_DAY(DISCONTINUE_+
1DATE),0):n            INTO h_full_name, h_julian_day, h_active, h_j_efective_+
1date, h_j_disconti_date:n            FROM RESOURCES :n            WHERE RESOU+
1RCE_ID = h_res_id:
1762:
1           EXCEPTION:: SP_SEARCH_1(763) :: cplan.sql(3208) :: :
1769:
1        RETURN_ERROR:: SP_SEARCH_1(770) :: cplan.sql(3215) :: :
1772:
1                EXIT:: SP_SEARCH_1(773) :: cplan.sql(3218) :: :
1780:
1        RETURN_ERROR:: SP_SEARCH_1(781) :: cplan.sql(3226) :: :
1RESOURCE_NOT_ACTIVE:
1783:
1                EXIT:: SP_SEARCH_1(784) :: cplan.sql(3229) :: :
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_assign_id, h_partic+
1ipant, h_security_id:n            FROM RESOURCE_ASSIGNMENTS:n            WHER+
1E ELEMENT_ID = h_task_id AND RESOURCE_TYPE = '0' AND RESOURCE_ID = h_res_id:
1798:
1           EXCEPTION:: SP_SEARCH_1(799) :: cplan.sql(3244) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME INTO h_full_name FROM PROFILES WHERE PROFILE_ID = h_res_i+
1d:
1813:
1           EXCEPTION:: SP_SEARCH_1(814) :: cplan.sql(3259) :: :
1820:
1        RETURN_ERROR:: SP_SEARCH_1(821) :: cplan.sql(3266) :: :
1823:
1                EXIT:: SP_SEARCH_1(824) :: cplan.sql(3269) :: :
1BAK_FINISH_DT:
1BAK_WORK:
1SELECT BAK_START_DT, CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) BETWEEN T+
1O_DATE(SubStr(BAK_START_DT, 1, 10)) AND TO_DATE(SubStr(BAK_FINISH_DT, 1, 10))+
1 AND BAK_WORK >= h_effort THEN 0 ELSE 1 END:n            INTO h_start_DT, h_t+
1otal :n            FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project+
1_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1':
1839:
1           EXCEPTION:: SP_SEARCH_1(840) :: cplan.sql(3285) :: :
1846:
1        RETURN_ERROR:: SP_SEARCH_1(847) :: cplan.sql(3292) :: :
1849:
1                EXIT:: SP_SEARCH_1(850) :: cplan.sql(3295) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_assign_id, h_partic+
1ipant, h_security_id:n            FROM RESOURCE_ASSIGNMENTS:n            WHER+
1E ELEMENT_ID = h_task_id AND RESOURCE_TYPE = '1' AND RESOURCE_ID = h_res_id:
1864:
1           EXCEPTION:: SP_SEARCH_1(865) :: cplan.sql(3310) :: :
1DB2TIMESTAMP:
1TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_DT, 1, 10)), PMO_ORASTD+
1.TIME(h_start_date)) INTO h_start_DT:n            FROM DUAL:
1882:
1           EXCEPTION:: SP_SEARCH_1(883) :: cplan.sql(3328) :: :
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) > TO_DATE(SubStr(h_star+
1t_DT, 1, 10)) THEN h_start_date:n            ELSE h_start_DT END:n           +
1 INTO h_start_DT:n            FROM DUAL:
1898:
1           EXCEPTION:: SP_SEARCH_1(899) :: cplan.sql(3344) :: :
110:
1FC_SEARCH_2:
1PMO_TMP_SEARCH:
1PLANNED_SCHED_FLAG:
1RES_ID:
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='0' WHERE RES_ID=h_res_id:
1FOUND:
1929:
1           EXCEPTION:: SP_SEARCH_1(930) :: cplan.sql(3375) :: :
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='1' WHERE RES_ID=h_res_id:
1946:
1           EXCEPTION:: SP_SEARCH_1(947) :: cplan.sql(3392) :: :
1SC_SRCH_PROFILE:
1982:
1           EXCEPTION:: SP_SEARCH_1(983) :: cplan.sql(3428) :: :
1TRUNC:
1/:
1WHILE:
1LOOP:
1COUNT:
1PROPOSED_START:
1SELECT COUNT(*), MIN(PROPOSED_START) INTO h_total, h_start_DT :n             +
1  FROM TASK_ASSIGNMENTS:n               WHERE PROJECT_ID = h_project_id AND T+
1ASK_ID = h_project_id:n               AND RESOURCE_ID = h_res_id AND RESOURCE+
1_TYPE = h_res_type:
11022:
1           EXCEPTION:: SP_SEARCH_1(1023) :: cplan.sql(3468) :: :
1',':
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START, CASE WHEN TO_DATE(SubStr(h_start_d+
1ate, 1, 10)) >= TO_DATE(SubStr(SCHED_START, 1, 10)) AND:n                    +
1    TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(SCHED_FINISH, 1, 10+
1)) AND SCHED_WORK >= h_effort THEN 0 ELSE 1 END,SCHED_WORK:n                 +
1       INTO h_prj_assign_id, h_start_DT, h_total, h_sched_work:n             +
1           FROM TASK_ASSIGNMENTS:n                        WHERE TASK_ID=h_pro+
1ject_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '2':
11069:
1           EXCEPTION:: SP_SEARCH_1(1070) :: cplan.sql(3515) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1              TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_F+
1INISH, 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n              +
1                INTO h_prj_assign_id, h_start_DT, h_total :n                 +
1             FROM TASK_ASSIGNMENTS:n                              WHERE TASK_+
1ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG =+
1 '0':
11089:
1           EXCEPTION:: SP_SEARCH_1(1090) :: cplan.sql(3535) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1           TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINI+
1SH, 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                 +
1          INTO h_prj_assign_id, h_start_DT, h_total :n                       +
1    FROM TASK_ASSIGNMENTS:n                           WHERE TASK_ID=h_project+
1_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
11109:
1           EXCEPTION:: SP_SEARCH_1(1110) :: cplan.sql(3555) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1        TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH,+
1 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                    +
1    INTO h_prj_assign_id, h_start_DT, h_total FROM TASK_ASSIGNMENTS:n        +
1                WHERE PROJECT_ID = h_project_id AND TASK_ID=h_project_id:n   +
1                     AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1' AND BIT_F+
1LAG = '0':
11127:
1           EXCEPTION:: SP_SEARCH_1(1128) :: cplan.sql(3573) :: :
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START,CASE WHEN TO_DATE(SubStr(h_start_da+
1te, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AND TO_DATE(SubStr(SC+
1HED_FINISH, 1, 10)) AND h_effort <= SCHED_WORK THEN 0 ELSE 1 END, SCHED_WORK+
1:n                        INTO h_prj_assign_id, h_start_DT,h_total, h_sched_w+
1ork FROM TASK_ASSIGNMENTS:n                        WHERE PROJECT_ID = h_proje+
1ct_id AND TASK_ID=h_project_id:n                        AND RESOURCE_ID=h_res+
1_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
11145:
1           EXCEPTION:: SP_SEARCH_1(1146) :: cplan.sql(3591) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLAN+
1NED_WORK THEN 0 ELSE 1 END:n                              INTO h_prj_assign_i+
1d, h_start_DT,h_total FROM TASK_ASSIGNMENTS:n                              WH+
1ERE PROJECT_ID = h_project_id AND TASK_ID=h_project_id:n                     +
1         AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
11163:
1           EXCEPTION:: SP_SEARCH_1(1164) :: cplan.sql(3609) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubS+
1tr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n  +
1                         INTO h_prj_assign_id, h_start_DT,h_total FROM TASK_A+
1SSIGNMENTS:n                           WHERE PROJECT_ID = h_project_id AND TA+
1SK_ID=h_project_id:n                           AND RESOURCE_ID=h_res_id AND R+
1ESOURCE_TYPE='0' AND BIT_FLAG = '0':
11183:
1           EXCEPTION:: SP_SEARCH_1(1184) :: cplan.sql(3629) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1                     INTO h_prj_assign_id, h_start_DT,h_total FROM TASK_ASSIG+
1NMENTS:n                        WHERE PROJECT_ID = h_project_id AND TASK_ID=h+
1_project_id:n                        AND RESOURCE_ID=h_res_id AND RESOURCE_TY+
1PE='1' AND BIT_FLAG = '0':
11200:
1           EXCEPTION:: SP_SEARCH_1(1201) :: cplan.sql(3646) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                              FROM +
1TASK_DAY_OF_YEAR:n                              WHERE PROJECT_ID = h_project_+
1id AND TSK_ASSIGNMENT_ID = h_prj_assign_id :n                              AN+
1D DAY_YEAR BETWEEN TO_DATE(SubStr(h_start_date, 1, 10)) AND TO_DATE(SubStr(h_+
1finish_DT, 1, 10)):
11225:
1           EXCEPTION:: SP_SEARCH_1(1226) :: cplan.sql(3671) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                              FROM +
1TASK_DAY_OF_YEAR:n                              WHERE PROJECT_ID = h_project_+
1id AND TSK_ASSIGNMENT_ID = h_prj_assign_id :n                              AN+
1D DAY_YEAR >= TO_DATE(SubStr(h_start_date, 1, 10)):
11242:
1           EXCEPTION:: SP_SEARCH_1(1243) :: cplan.sql(3688) :: :
1CONTINUE0000:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_DT, 1, 10)), PMO_ORASTD+
1.TIME(h_start_date)):n                  INTO h_start_DT:n                  FR+
1OM DUAL:
11272:
1           EXCEPTION:: SP_SEARCH_1(1273) :: cplan.sql(3718) :: :
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) > TO_DATE(SubStr(h_star+
1t_DT, 1, 10)) THEN h_start_date ELSE h_start_DT END:n                  INTO h+
1_start_DT:n                  FROM DUAL:
11287:
1           EXCEPTION:: SP_SEARCH_1(1288) :: cplan.sql(3733) :: :
11318:
1           EXCEPTION:: SP_SEARCH_1(1319) :: cplan.sql(3764) :: :
11335:
1           EXCEPTION:: SP_SEARCH_1(1336) :: cplan.sql(3781) :: :
11369:
1           EXCEPTION:: SP_SEARCH_1(1370) :: cplan.sql(3815) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
11397:
1           EXCEPTION:: SP_SEARCH_1(1398) :: cplan.sql(3843) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET SECURITY_ID = h_security_id, PARTICIPANT = h_+
1participant:n            WHERE RES_ASSIGNMENT_ID = h_assign_id:
11415:
1           EXCEPTION:: SP_SEARCH_1(1416) :: cplan.sql(3861) :: :
11423:
1        RETURN_ERROR:: SP_SEARCH_1(1424) :: cplan.sql(3869) :: :
11426:
1                EXIT:: SP_SEARCH_1(1427) :: cplan.sql(3872) :: :
1CANNOT_ASSIGN_TO_DEFAULT_CRI:
11431:
1        RETURN_ERROR:: SP_SEARCH_1(1432) :: cplan.sql(3877) :: :
11434:
1                EXIT:: SP_SEARCH_1(1435) :: cplan.sql(3880) :: :
1CANNOT_CHANGE_OBJECT_TYPE:
11440:
1        RETURN_ERROR:: SP_SEARCH_1(1441) :: cplan.sql(3886) :: :
11443:
1                EXIT:: SP_SEARCH_1(1444) :: cplan.sql(3889) :: :
11449:
1        RETURN_ERROR:: SP_SEARCH_1(1450) :: cplan.sql(3895) :: :
11452:
1                EXIT:: SP_SEARCH_1(1453) :: cplan.sql(3898) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN_0003:
1INSERT INTO PMO_TMP_CPLN_0003 SELECT RESOURCE_ID, RESOURCE_TYPE, :
1 MIN(PLANNED_START) AS PLANNED_START,  MAX(PLANNED_FINISH) AS PLANNED_FINISH,+
1 :
1 SUM(PLANNED_WORK) AS PLANNED_EFFORT,  MIN(SCHED_START) AS START_DATE,  :
1 MAX(SCHED_FINISH) AS FINISH_DATE,     SUM(SCHED_WORK) AS WORK,  :
1 SUM(ETC) AS REMAINING :
1 FROM TASK_ASSIGNMENTS WHERE PROJECT_ID=':
1' AND :
1      (RESOURCE_ID IN (':
1') OR RESOURCE_ID IN (':
1')) GROUP BY RESOURCE_ID, RESOURCE_TYPE :
11484:
1           EXCEPTION:: SP_SEARCH_1(1485) :: cplan.sql(3930) :: :
1SQL :: :
1DELETE FROM PMO_TMP_CPLN_0002:
1INSERT INTO PMO_TMP_CPLN_0002 SELECT RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,MIN+
1(PLANNED_START) AS PRJ_PLANNED_START, :
1 MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH,  SUM(PLANNED_WORK) AS PLANNED_REM+
1AINING, :
1 MIN(SCHED_START) AS PRJ_SCHED_START,        MAX(SCHED_FINISH) AS PRJ_SCHED_F+
1INISH, :
1 SUM(SCHED_WORK) AS SCHED_REMAINING  :
1 FROM TASK_ASSIGNMENTS :
1 WHERE TASK_ID=':
1 (RESOURCE_ID IN (':
1')) GROUP BY RESOURCE_ID :
11516:
1           EXCEPTION:: SP_SEARCH_1(1517) :: cplan.sql(3962) :: :
1FC_U_CREATETMPTABLE:
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME,RESOURCE_TYPE,TYPE_ID+
1,E_MAIL_ADDRESS,PLANNED_START,:
1PLANNED_FINISH,PLANNED_EFFORT,START_DATE,FINISH_DATE,WORK,REMAINING,BEST_STAR+
1T,BEST_FINISH,:
1ASSIGNABLE,PLANNED,SCHED,WORK_EFFORT,PERIOD_AVAILABILITY,PROJECT_ASSIGNMENT_I+
1D,PRJ_PLANNED_START,:
1PRJ_PLANNED_FINISH,PLANNED_REMAINING,PRJ_SCHED_START,PRJ_SCHED_FINISH,SCHED_R+
1EMAINING,REGULAR_COST,:
1REGULAR_RATE,SPECIAL_COST,SPECIAL_RATE) :
1SELECT DISTINCT r.RESOURCE_ID,r.FULL_NAME AS ELEMENT_NAME,'0',:
1CASE WHEN ta.TSK_ASSIGNMENT_ID IS NuLL THEN 185 ELSE 13 END AS TYPE_ID,:
1r.E_MAIL_ADDRESS, a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.STAR+
1T_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,:
1rs.START_DATE, rs.FINISH_DATE, rs.ASSIGNABLE, rs.PLANNED, rs.SCHED, rs.PROPOS+
1ED, (rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) ,:
1tb.PROJECT_ASSIGNMENT_ID,tb.PRJ_PLANNED_START, tb.PRJ_PLANNED_FINISH, tb.PLAN+
1NED_REMAINING,:
1tb.PRJ_SCHED_START, tb.PRJ_SCHED_FINISH, tb.SCHED_REMAINING, pa.REGULAR_COST,+
1 pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE :
1FROM RESOURCES r LEFT OUTER JOIN PMO_TMP_CPLN_0003 a ON a.RESOURCE_TYPE='0' A+
1ND a.RESOURCE_ID=r.RESOURCE_ID :
1LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID=':
1' AND r.RESOURCE_ID = pa.RESOURCE_ID :
1LEFT OUTER JOIN TASK_ASSIGNMENTS ta ON ta.PROJECT_ID=':
1' AND r.RESOURCE_ID = ta.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_CPLN_0002 tb ON r.RESOURCE_ID = tb.PROJECT_ASSIGNMENT+
1_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON r.RESOURCE_ID=rs.RES_ID WHERE r.RESOURCE+
1_ID IN (':
1') :
1UNION ALL :
1SELECT DISTINCT p.PROFILE_ID , p.PROFILE_NAME AS ELEMENT_NAME, '1', 41 AS TYP+
1E_ID,:
1'', a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.START_DATE, a.FINI+
1SH_DATE, a.WORK, a.REMAINING,:
1rs.START_DATE , rs.FINISH_DATE, rs.ASSIGNABLE ,rs.PLANNED,rs.SCHED, rs.PROPOS+
1ED,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) ,:
1FROM PROFILES p LEFT OUTER JOIN PMO_TMP_CPLN_0003 a ON a.RESOURCE_TYPE='1' AN+
1D p.PROFILE_ID=a.RESOURCE_ID :
1LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID= ':
1' AND p.PROFILE_ID = pa.RESOURCE_ID :
1JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=p.ROLE_ID :
1JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID LEFT OUTER JOIN PMO_TMP_S+
1EARCH rs ON a.RESOURCE_ID=rs.RES_ID :
1LEFT OUTER JOIN PMO_TMP_CPLN_0002 tb ON p.PROFILE_ID = tb.PROJECT_ASSIGNMENT_+
1ID :
1WHERE p.PROFILE_ID IN (':
1ORDER BY TYPE_ID,ELEMENT_NAME:
11571:
1           EXCEPTION:: SP_SEARCH_1(1572) :: cplan.sql(4017) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME AS ELEMENT_NAME,+
1 T.TYPE_ID AS TYPE_ID, :
1 T.E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T.STA+
1RT_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1 T.BEST_START, T.BEST_FINISH, T.ASSIGNABLE AS CALENDAR,T.PLANNED AS PLANNED_W+
1ORK,:
1 T.SCHED AS SCHED_WORK, T.WORK_EFFORT, :
1 AS UNIT_EFFORT,T.PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED_+
1REMAINING, :
1T.PRJ_SCHED_START, T.PRJ_SCHED_FINISH, T.SCHED_REMAINING, T.REGULAR_COST, T.R+
1EGULAR_RATE, T.SPECIAL_COST, T.SPECIAL_RATE :
1 FROM PMO_TMP_CPLN01_TEMP T:
1 LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=rs.RES_ID WHERE T.RESOURCE+
1_TYPE IN ('0') :
1 UNION ALL :
1 SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME, T.TYPE_ID, :
1 '' AS E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T+
1.START_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1 T.BEST_START, T.BEST_FINISH, T.ASSIGNABLE AS CALENDAR, :
1 T.PLANNED AS PLANNED_WORK,T.SCHED AS SCHED_WORK, T.WORK_EFFORT, :
1 AS UNIT_EFFORT, :
1 T.PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING,'' AS OBJECTIVES,'' AS RANK, :
1 T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED+
1_REMAINING, :
1  T.PRJ_SCHED_START, T.PRJ_SCHED_FINISH, T.SCHED_REMAINING, T.REGULAR_COST, T+
1.REGULAR_RATE, T.SPECIAL_COST, T.SPECIAL_RATE :
1 FROM PMO_TMP_CPLN01_TEMP T LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID+
1=rs.RES_ID :
1 WHERE T.RESOURCE_TYPE = '1' ORDER BY TYPE_ID,ELEMENT_NAME:
1DELETE FROM PMO_TMP_CPLN_0001:
1INSERT INTO PMO_TMP_CPLN_0001 :
1SELECT  RESOURCE_ID, MIN(PLANNED_START) AS PLANNED_START, :
1 MAX(PLANNED_FINISH) AS PLANNED_FINISH,   SUM(PLANNED_WORK) AS PLANNED_EFFORT+
1, :
1 MIN(SCHED_START) AS START_DATE,          MAX(SCHED_FINISH) AS FINISH_DATE, :
1 SUM(SCHED_WORK) AS WORK,                 SUM(ETC) AS REMAINING :
1 RESOURCE_ID IN (':
1') AND PROJECT_ID<>TASK_ID GROUP BY RESOURCE_ID:
11625:
1           EXCEPTION:: SP_SEARCH_1(1626) :: cplan.sql(4071) :: :
1INSERT INTO PMO_TMP_CPLN_0002 :
1SELECT RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,      MIN(PLANNED_START) AS PRJ_P+
1LANNED_START, :
1 MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH, SUM(PLANNED_WORK) AS PLANNED_REMA+
1INING, :
1 MIN(SCHED_START) AS PRJ_SCHED_START,       MAX(SCHED_FINISH) AS PRJ_SCHED_FI+
1NISH, :
1 SUM(SCHED_WORK) AS SCHED_REMAINING :
1 FROM TASK_ASSIGNMENTS WHERE TASK_ID=':
1' AND RESOURCE_ID IN (':
1') GROUP BY RESOURCE_ID:
11655:
1           EXCEPTION:: SP_SEARCH_1(1656) :: cplan.sql(4101) :: :
1PLANNED_FINISH,PLANNED_EFFORT,START_DATE,FINISH_DATE,WORK,REMAINING,PROJECT_A+
1SSIGNMENT_ID,PRJ_PLANNED_START,:
1REGULAR_RATE,SPECIAL_COST,SPECIAL_RATE):
1SELECT DISTINCT r.RESOURCE_ID, r.FULL_NAME,'0',CASE WHEN ta.TSK_ASSIGNMENT_ID+
1 IS NuLL THEN 185 ELSE 13 END ,:
1tb.PROJECT_ASSIGNMENT_ID, tb.PRJ_PLANNED_START, tb.PRJ_PLANNED_FINISH, tb.PLA+
1NNED_REMAINING,:
1FROM RESOURCES r LEFT OUTER JOIN PMO_TMP_CPLN_0001 a ON a.RESOURCE_ID=r.RESOU+
1RCE_ID :
1WHERE r.RESOURCE_ID IN (':
1'):
11691:
1           EXCEPTION:: SP_SEARCH_1(1692) :: cplan.sql(4137) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME AS ELEMENT_NAME,+
1 T.TYPE_ID, :
1T.E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T.STAR+
1T_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR,rs.PLANNED AS PLANNED_WORK, :
1rs.SCHED AS SCHED_WORK, rs.PROPOSED AS WORK_EFFORT, :
1 AS UNIT_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILIT+
1Y, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1T.PROJECT_ASSIGNMENT_ID, T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED+
1_REMAINING, :
1FROM PMO_TMP_CPLN01_TEMP T :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=rs.RES_ID :
1ORDER BY ELEMENT_NAME:
1SELECT RESOURCE_ID, MIN(PLANNED_START) AS PLANNED_START, :
1       MAX(PLANNED_FINISH) AS PLANNED_FINISH,    SUM(PLANNED_WORK) AS PLANNED+
1_EFFORT, :
1       MIN(SCHED_START) AS START_DATE,           MAX(SCHED_FINISH) AS FINISH_+
1DATE, :
1       SUM(SCHED_WORK) AS WORK,                  SUM(ETC) AS REMAINING :
1 WHERE PROJECT_ID=':
1'        AND :
1       RESOURCE_ID IN (':
1')   AND :
1       PROJECT_ID<>TASK_ID GROUP BY RESOURCE_ID :
11736:
1           EXCEPTION:: SP_SEARCH_1(1737) :: cplan.sql(4182) :: :
1SELECT    RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,          MIN(PLANNED_START) A+
1S PRJ_PLANNED_START, :
1          MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH,     SUM(PLANNED_WORK) AS+
1 PLANNED_REMAINING, :
1          MIN(SCHED_START) AS PRJ_SCHED_START,           MAX(SCHED_FINISH) AS+
1 PRJ_SCHED_FINISH, :
1          SUM(SCHED_WORK) AS SCHED_REMAINING  :
1') GROUP BY RESOURCE_ID :
11766:
1           EXCEPTION:: SP_SEARCH_1(1767) :: cplan.sql(4212) :: :
1SELECT DISTINCT p.PROFILE_ID , p.PROFILE_NAME ,'1', 41 ,:
1'' , a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.START_DATE, a.FIN+
1ISH_DATE, a.WORK, a.REMAINING,:
1FROM PROFILES p LEFT OUTER JOIN PMO_TMP_CPLN_0001 a ON p.PROFILE_ID=a.RESOURC+
1E_ID JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=p.ROLE_ID :
1JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID :
11802:
1           EXCEPTION:: SP_SEARCH_1(1803) :: cplan.sql(4248) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME, T.TYPE_ID, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR, :
1rs.PLANNED AS PLANNED_WORK,rs.SCHED AS SCHED_WORK, rs.PROPOSED AS WORK_EFFORT+
1, :
1(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1  :
1T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED_+
1REMAINING, :
1FROM PMO_TMP_CPLN01_TEMP T LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=+
1rs.RES_ID :
11824:
1                EXIT:: SP_SEARCH_1(1825) :: cplan.sql(4270) :: :
11827:
1                EXIT:: SP_SEARCH_1(1828) :: cplan.sql(4273) :: :
1PMO_SELECT_READ:
1RETURN_ERROR_EXCEPTION:
11835:
1           EXCEPTION:: SP_SEARCH_1(1836) :: cplan.sql(4281) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11847:
1           EXCEPTION:: SP_SEARCH_1(1848) :: cplan.sql(4293) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
30ce
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 81 b0 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d a0 6e d a0 4d d :4 a0
51 a5 b a5 b d a0 51
d a0 51 d a0 51 d a0
7e b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 b7 19 3c a0 7e
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c a0 7e b4
2e 5a :3 a0 a5 b 51 a5 b
7e 51 b4 2e 5a a 10 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c a0 7e b4 2e 5a :3 a0
a5 b 51 a5 b 7e 51 b4
2e 5a a 10 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e a
10 :2 a0 51 a5 b 7e 51 b4
2e a 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c a0 7e b4
2e :2 5a a0 7e b4 2e :2 5a a
10 :8 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c a0 51 d a0 b7 a0
7e b4 2e :2 5a a0 7e b4 2e
:2 5a a 10 :3 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 d a0 7e b4 2e 5a
a0 6e d b7 19 3c :3 a0 :2 51
a5 b d :3 a0 :2 51 a5 b d
:2 a0 d :2 a0 51 a5 b 7e 51
b4 2e :4 a0 :2 51 a5 b :2 51 a5
b d :3 a0 6b :3 51 a0 a5 b
d :3 a0 51 a5 b a5 b 7e
51 b4 2e :d a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :45 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a :7 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a a0 7e b4 2e 5a a0
51 d b7 19 3c :b a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c b7 a0 51 d b7
:2 19 3c a0 51 d :5 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 6e a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c b7
19 3c b7 :b a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :5 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 19 3c
b7 :2 19 3c a0 7e 51 b4 2e
:2 a0 d :2 a0 d :6 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :3 a0 a5 b d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 51 a5 b
:2 a0 a5 57 b7 :2 19 3c :2 a0 d
a0 7e b4 2e 5a a0 6e d
b7 19 3c a0 b7 :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 a0 51 d
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e a0 51 d a0 b7 19
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a 52 10 a0 51 d a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e :3 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e d a0 51
d b7 :2 19 3c b7 :2 19 3c :2 a0
b4 2e d a0 6e d a0 6e
d :3 a0 6b :3 a0 51 a5 b :2 a0
6b a5 b 5a 51 a5 b d
:4 a0 51 a5 b :2 a0 6b a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :8 a0 a5 b d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 b7 19 3c
a0 4d d :14 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
7e b4 2e :2 5a a 10 a0 51
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d b7 19 3c b7 19
3c a0 51 d a0 51 d a0
7e 51 b4 2e :2 a0 :2 51 a5 b
7e 6e b4 2e :1c a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 :1a a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a0 51 d b7 :2 19
3c a0 b7 :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 :1a a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 :1a a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :2 a0 :2 51 a5
b 7e 6e b4 2e :19 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 51 d :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a 52 10
:14 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 a0 51 d 4f
b7 :2 19 3c a0 b7 :2 a0 6b a0
7e a0 6b b4 2e 5a :17 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :17 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 a0 b7
a0 7e b4 2e 5a a0 7e 51
b4 2e a0 51 d :f a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 51 d :c a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 :2 19 3c a0 51 d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
5a :3 a0 51 a5 b a5 b 5a
7e 51 b4 2e a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 19 3c
:2 a0 :2 51 a5 b 7e 6e b4 2e
:3 a0 7e a0 b4 2e :2 51 a5 b
d :15 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :2 a0
:2 51 a5 b 7e 6e b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 5a a 10
5a 52 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :c a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :3 a0 7e a0 b4 2e :2 51 a5
b d :5 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:14 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :c a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
d :2 a0 51 a5 b 7e 51 b4
2e :a a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :a a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
51 d :2 a0 d :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
19 3c :1e a0 :4 51 a5 b d a0
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e :4 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :4 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 19 3c b7 :2 a0 d
:2 a0 d :2 a0 :2 51 a5 b 7e 6e
b4 2e :3 a0 6b d b7 :4 a0 51
a5 b :2 a0 6b a5 b d b7
:2 19 3c :1e a0 :4 51 a5 b d a0
7e 51 b4 2e :4 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 :2 19 3c b7 :3 a0 a5 b 51
a5 b 7e 51 b4 2e a0 51
d b7 :5 a0 a5 b 51 a5 b
7e 51 b4 2e 5a 7e 51 b4
2e a5 b d b7 :2 19 3c a0
7e 51 b4 2e a0 51 d :3 a0
51 a5 b a0 7e a0 b4 2e
82 a0 51 d :3 a0 6b :2 51 :2 a0
51 a5 b 7e 51 b4 2e 7e
51 b4 2e a0 a5 b d :3 a0
6b :2 51 :2 a0 51 a5 b 7e 51
b4 2e 7e 51 b4 2e 7e 51
b4 2e a0 a5 b d :2 a0 d
a0 51 d a0 51 d :2 a0 d
:e a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e 5a a0 7e b4 2e
:2 5a a 10 a0 51 d :2 a0 6b
:2 a0 a5 b 7e 51 b4 2e :2 a0
d b7 19 3c b7 19 3c :2 a0
:2 51 a5 b 7e 6e b4 2e :3 a0
6b d :3 a0 a5 b 51 a5 b
7e 51 b4 2e :2 a0 d b7 :3 a0
7e 6e b4 2e :2 51 a5 b d
:3 a0 7e a0 b4 2e :2 51 a5 b
d b7 :2 19 3c b7 :3 a0 a5 b
51 a5 b 7e 51 b4 2e :2 a0
d b7 :3 a0 7e 6e b4 2e :2 51
a5 b d :3 a0 7e a0 b4 2e
:2 51 a5 b d b7 :2 19 3c b7
:2 19 3c a0 51 d a0 51 d
:2 a0 51 a5 b 7e 51 b4 2e
a0 7e 51 b4 2e :2 a0 :2 51 a5
b 7e 6e b4 2e :1c a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 51 d :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a 52 10
:1a a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 a0 51 d b7
:2 19 3c a0 b7 :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a 52 10
:1a a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :1c a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 :2 a0 :2 51
a5 b 7e 6e b4 2e :1b a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 :16 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 a0 51 d 4f b7 :2 19
3c a0 b7 :2 a0 6b a0 7e a0
6b b4 2e 5a :19 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :19 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
b7 a0 7e b4 2e 5a a0 7e
51 b4 2e a0 51 d :f a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 a0 51 d :c a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :3 a0
51 a5 b 7e 51 b4 2e d
a0 3b b7 19 3c b7 19 3c
a0 51 d b7 :2 19 3c b7 :3 a0
51 a5 b 7e 51 b4 2e d
a0 3b b7 :2 19 3c :2 a0 d a0
51 d :a a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 51 d :2 a0 d :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
b7 19 3c :1e a0 :4 51 a5 b d
a0 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e :4 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :4 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 19 3c a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 d :2 a0 d :2 a0 :2 51 a5 b
7e 6e b4 2e :3 a0 6b d b7
:3 a0 51 a5 b d b7 :2 19 3c
:1e a0 :4 51 a5 b d a0 7e 51
b4 2e :4 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c b7 :2 19
3c :3 a0 51 a5 b 7e 51 b4
2e d 93 4f b0 46 b7 a0
47 b7 19 3c b7 :2 19 3c a0
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :7 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c a0 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 a0 b7 :2 a0 7e a0 6b
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 a0 b7 19 :2 a0 7e a0 6b
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :2 19 3c b7 19 3c
:3 a0 a5 b 51 a5 b 7e 51
b4 2e 5a :3 a0 a5 b 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 6e 11e 11d :2 a0 6b 51 d
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d :3 a0 11e 11d a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6e
11e 11d :2 a0 6b 51 d a0 6e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
d :3 a0 11e 11d a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 b4
2e d a0 6e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e d :3 a0 11e 11d
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
51 a5 b a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 51
a5 b a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e d a0 b7 :3 a0 a5 b
51 a5 b 7e 51 b4 2e :2 a0
6e 11e 11d :2 a0 6b 51 d a0
6e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e d :3 a0 11e 11d a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6e 11e
11d :2 a0 6b 51 d a0 6e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e d :3 a0 11e 11d a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 b4 2e d a0 6e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e d
:3 a0 11e 11d a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 6e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 51 a5 b a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
51 a5 b a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e d b7 19 :2 a0 6e
11e 11d :2 a0 6b 51 d a0 6e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
d :3 a0 11e 11d a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6e 11e 11d
:2 a0 6b 51 d a0 6e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d :3 a0 11e 11d a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 b4 2e d a0 6e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d :3 a0
11e 11d a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 6e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 51 a5 b a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 51 a5 b a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e d b7
:2 19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 6b a0 a5 b 65 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
30ce
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 16a 155
159 15c 15d 165 154 187 175 151
179 17a 182 174 1a4 192 171 196
197 19f 191 1c1 1af 18e 1b3 1b4
1bc 1ae 1de 1cc 1ab 1d0 1d1 1d9
1cb 1fb 1e9 1c8 1ed 1ee 1f6 1e8
218 206 1e5 20a 20b 213 205 235
223 202 227 228 230 222 252 240
21f 244 245 24d 23f 26f 25d 23c
261 262 26a 25c 28b 27a 27e 286
259 2a3 292 296 29e 279 2c0 2ae
276 2b2 2b3 2bb 2ad 2dd 2cb 2aa
2cf 2d0 2d8 2ca 2fa 2e8 2c7 2ec
2ed 2f5 2e7 317 305 2e4 309 30a
312 304 334 322 301 326 327 32f
321 351 33f 31e 343 344 34c 33e
36d 35c 360 33b 368 35b 389 378
37c 358 384 377 3a5 394 398 374
3a0 393 3c1 3b0 3b4 390 3bc 3af
3dd 3cc 3d0 3ac 3d8 3cb 3f9 3e8
3ec 3c8 3f4 3e7 415 404 408 3e4
410 403 431 420 424 400 42c 41f
44d 43c 440 41c 448 43b 469 458
45c 438 464 457 485 474 478 454
480 473 4a1 490 494 470 49c 48f
4bd 4ac 4b0 48c 4b8 4ab 4d9 4c8
4cc 4a8 4d4 4c7 4f5 4e4 4e8 4c4
4f0 4e3 511 500 504 4e0 50c 4ff
52d 51c 520 4fc 528 51b 549 538
53c 518 544 537 565 554 558 534
560 553 581 570 574 550 57c 56f
59d 58c 590 56c 598 58b 5b9 5a8
5ac 588 5b4 5a7 5d5 5c4 5c8 5a4
5d0 5c3 5f1 5e0 5e4 5c0 5ec 5df
60d 5fc 600 5dc 608 5fb 629 618
61c 5f8 624 617 645 634 638 614
640 633 661 650 654 630 65c 64f
67e 66c 64c 670 671 679 66b 69b
689 668 68d 68e 696 688 6b7 6a6
6aa 685 6b2 6a5 6d4 6c2 6a2 6c6
6c7 6cf 6c1 6f0 6df 6e3 6be 6eb
6de 70d 6fb 6db 6ff 700 708 6fa
72a 718 6f7 71c 71d 725 717 747
735 714 739 73a 742 734 763 752
756 731 75e 751 77f 76e 772 74e
77a 76d 79b 78a 78e 76a 796 789
7b8 7a6 786 7aa 7ab 7b3 7a5 7d5
7c3 7a2 7c7 7c8 7d0 7c2 7f1 7e0
7e4 7bf 7ec 7df 80d 7fc 800 7dc
808 7fb 82a 818 7f8 81c 81d 825
817 846 835 839 814 841 834 862
851 855 831 85d 850 87e 86d 871
84d 879 86c 89a 889 88d 869 895
888 8b6 8a5 8a9 8b1 885 8d5 8bd
8c1 8c5 8c8 8d0 8a4 8dc 8e0 8a1
8e4 8e8 8ec 8ef 8f4 8f5 1 8f7
8fc 900 904 907 90c 910 914 917
91c 91d 91f 924 927 92b 92c 931
936 939 93e 93f 944 947 94b 94c
951 954 959 95a 95f 962 967 968
96d 970 975 976 97b 97e 982 983
988 98b 990 991 996 999 99e 99f
9a4 9a7 9ac 9ad 9b2 9b5 9b9 9ba
9bf 9c2 9c7 9c8 9cd 9d0 9d5 9d6
9db 9de 9e2 9e6 9ea 9eb 9ed 9f2
9f3 9f5 9f6 9fb 9fe a03 a04 a09
a0c a10 a14 a18 a19 a1b a20 a21
a23 a24 a29 a2c a31 a32 a37 a3a
a3e a42 a46 a47 a49 a4e a4f a51
a52 a57 a5a a5f a60 a65 a68 a6c
a70 a74 a75 a77 a7c a7d a7f a80
a85 a88 a8d a8e a93 a96 a9a a9e
aa2 aa3 aa5 aaa aab aad aae ab3
ab6 abb abc ac1 ac4 ac8 acc ad0
ad1 ad3 ad8 ad9 adb adc ae1 ae4
ae9 aea aef af2 af6 afa afe aff
b01 b06 b07 b09 b0a b0f b12 b17
b18 b1d b20 b24 b28 b2c b2d b2f
b34 b35 b37 b38 b3d b40 b45 b46
b4b b4e b52 b56 b5a b5b b5d b62
b63 b65 b66 b6b b6e b73 b74 b79
b7c b80 b84 b88 b89 b8b b90 b91
b93 b94 b99 b9c ba1 ba2 ba7 baa
baf bb0 bb5 bb8 bbc bbd bc2 bc5
bca bcb bd0 bd3 bd8 bd9 bde be1
be6 be7 bec bef bf3 bf4 bf9 bfc
c01 c02 c07 c0a c0f c10 c15 c16
c1b c1d c21 c24 c28 c2c c2f c33
c37 c3a c3d c42 c45 c48 c4b c4c
c51 c52 1 c54 c59 c5d c61 c64
c69 c6e c71 c75 c76 c7b c7c c81
c83 c87 c8a c8e c92 c96 c9a c9e
ca2 ca6 caa cae cb2 cb6 cba cbe
cc2 cc6 cca cce cd2 cd6 cda cde
ce2 ce6 cea cee cf2 cf6 cfa cfe
d02 d06 d0a d0e d12 d16 d1a d1e
d22 d26 d2a d2e d32 d36 d3a d3e
d42 d47 d4b d4f d50 d54 d58 d5c
d60 d64 d67 d68 d6a d6b d6d d71
d75 d78 d7c d80 d83 d87 d8b d8e
d92 d96 d99 d9a d9f da2 da6 daa
dad db1 db5 db8 dbb dc0 dc3 dc6
dc9 dca dcf dd0 1 dd2 dd7 ddb
ddf de2 de7 dec def df3 df4 df9
dfc e01 e02 e07 e0a e0f e10 e15
e18 e1c e20 e24 e28 e2b e2c e2e
e33 e34 e36 e37 e3c e3d e42 e44
e48 e4b e4f e53 e56 e5a e5e e61
e64 e69 e6c e6f e72 e73 e78 e79
1 e7b e80 e84 e88 e8b e90 e95
e98 e9c e9d ea2 ea3 ea8 eaa eae
eb1 eb5 eb9 ebc ec0 ec4 ec7 ecb
ecc ed1 ed3 ed7 eda ede ee1 ee2
ee7 eea eee ef2 ef5 ef9 efd f00
f03 f08 f0b f0e f11 f12 f17 f18
1 f1a f1f f23 f27 f2a f2f f34
f37 f3b f3c f41 f44 f49 f4a f4f
f52 f57 f58 f5d f60 f64 f68 f6c
f70 f73 f74 f76 f7b f7c f7e f7f
f84 f85 f8a f8c f90 f93 f97 f9b
f9e fa2 fa6 fa9 fac fb1 fb4 fb7
fba fbb fc0 fc1 1 fc3 fc8 fcc
fd0 fd3 fd8 fdd fe0 fe4 fe5 fea
feb ff0 ff2 ff6 ff9 ffd 1001 1004
1008 100c 100f 1013 1014 1019 101b 101f
1022 1026 1029 102a 102f 1032 1036 103a
103e 103f 1041 1044 1045 1047 104a 104d
104e 1053 1 1056 105b 105e 1062 1066
1069 106d 1071 1074 1077 107c 107f 1082
1085 1086 108b 108c 1 108e 1093 1097
109b 109e 10a3 10a8 10ab 10af 10b0 10b5
10b8 10bd 10be 10c3 10c6 10cb 10cc 10d1
10d4 10d8 10dc 10e0 10e4 10e7 10e8 10ea
10ef 10f0 10f2 10f3 10f8 10f9 10fe 1100
1104 1107 110b 110f 1112 1116 111a 111d
1120 1125 1128 112b 112e 112f 1134 1135
1 1137 113c 1140 1144 1147 114c 1151
1154 1158 1159 115e 115f 1164 1166 116a
116d 1171 1175 1178 117c 1180 1183 1187
1188 118d 118f 1193 1196 119a 119d 119e
11a3 11a6 11aa 11ae 11b2 11b3 11b5 11b8
11b9 11bb 11be 11c1 11c2 11c7 1 11ca
11cf 11d2 11d6 11da 11dd 11e1 11e5 11e8
11eb 11f0 11f3 11f6 11f9 11fa 11ff 1200
1 1202 1207 120b 120f 1212 1217 121c
121f 1223 1224 1229 122c 1231 1232 1237
123a 123f 1240 1245 1248 124c 1250 1254
1258 125b 125c 125e 1263 1264 1266 1267
126c 126d 1272 1274 1278 127b 127f 1283
1286 128a 128e 1291 1294 1299 129c 129f
12a2 12a3 12a8 12a9 1 12ab 12b0 12b4
12b8 12bb 12c0 12c5 12c8 12cc 12cd 12d2
12d3 12d8 12da 12de 12e1 12e5 12e9 12ec
12f0 12f4 12f7 12fb 12fc 1301 1303 1307
130a 130e 1312 1315 1316 1318 131b 131e
131f 1324 1328 132c 132f 1330 1332 1335
1338 1339 1 133e 1343 1347 134b 134e
134f 1351 1354 1357 1358 1 135d 1362
1366 136a 136d 1371 1375 1378 137b 1380
1383 1386 1389 138a 138f 1390 1 1392
1397 139b 139f 13a2 13a7 13ac 13af 13b3
13b4 13b9 13bc 13c1 13c2 13c7 13ca 13cf
13d0 13d5 13d8 13dc 13e0 13e4 13e8 13eb
13ec 13ee 13f3 13f4 13f6 13f7 13fc 13fd
1402 1404 1408 140b 140f 1413 1416 141a
141e 1421 1424 1429 142c 142f 1432 1433
1438 1439 1 143b 1440 1444 1448 144b
1450 1455 1458 145c 145d 1462 1463 1468
146a 146e 1471 1475 1479 147c 1480 1484
1487 148b 148c 1491 1493 1497 149a 149e
14a1 14a2 14a7 14aa 14ad 14b1 14b4 14b5
14ba 14bd 1 14c0 14c5 14c9 14cd 14d1
14d5 14d9 14dd 14e1 14e5 14f1 14f5 14f9
14fc 1500 1504 1506 1 150a 150e 1512
1515 1519 151d 1521 1525 1528 152c 1530
1533 1536 153b 153e 1541 1544 1545 154a
154b 1 154d 1552 1556 155a 155d 1562
1567 156a 156e 156f 1574 1577 157c 157d
1582 1585 158a 158b 1590 1593 1597 1598
159d 15a0 15a5 15a6 15ab 15ae 15b2 15b6
15b9 15bc 15bd 15bf 15c0 15c5 15c6 15cb
15cd 15d1 15d4 15d6 15da 15dc 15e8 15ea
15ec 15ed 15f2 15f6 15f8 1604 1606 160a
160e 1611 1615 1618 161c 161f 1620 1625
1628 162c 1630 1633 1634 1636 1639 163c
163d 1642 1 1645 164a 164e 1652 1655
1659 165d 1660 1663 1668 166b 166e 1671
1672 1677 1678 1 167a 167f 1683 1687
168a 168f 1694 1697 169b 169c 16a1 16a4
16a9 16aa 16af 16b2 16b7 16b8 16bd 16c0
16c4 16c8 16cc 16d0 16d3 16d4 16d6 16db
16dc 16de 16df 16e4 16e5 16ea 16ec 16f0
16f3 16f7 16fb 16fe 1702 1706 1709 170c
1711 1714 1717 171a 171b 1720 1721 1
1723 1728 172c 1730 1733 1738 173d 1740
1744 1745 174a 174b 1750 1752 1756 1759
175d 1761 1764 1768 176c 176f 1773 1774
1779 177b 177f 1782 1786 1789 178d 1791
1793 1797 179a 179b 17a0 17a3 17a6 17aa
17ad 17ae 17b3 17b6 1 17b9 17be 17c2
17c6 17ca 17d6 17da 17de 17e1 17e5 17e9
17eb 1 17ef 17f3 17f7 17fa 17fe 1802
1806 180a 180d 1811 1815 1818 181b 1820
1823 1826 1829 182a 182f 1830 1 1832
1837 183b 183f 1842 1847 184c 184f 1853
1854 1859 185c 1861 1862 1867 186a 186f
1870 1875 1878 187c 187d 1882 1885 188a
188b 1890 1893 1897 189b 189e 18a1 18a2
18a4 18a5 18aa 18ab 18b0 18b2 18b6 18b9
18bb 18bf 18c1 18cd 18cf 18d1 18d2 18d7
18db 18dd 18e9 18eb 18ed 18f1 18f5 18f8
18fc 1900 1904 1908 190b 190c 1911 1914
1918 191d 1921 1923 1927 192a 192e 1932
1936 1939 193c 193d 193f 1943 1947 194b
194f 1952 1955 1956 1958 195c 1960 1964
1968 196c 1970 1973 1974 1976 1979 197c
197d 1982 1986 198a 198e 1992 1995 1998
1999 199b 199e 19a1 19a2 19a4 19a8 19ac
19b0 19b4 19b7 19ba 19bd 19c0 19c4 19c5
19c7 19cb 19cf 19d3 19d7 19da 19db 19dd
19de 19e0 19e3 19e6 19e7 19ec 19f0 19f4
19f8 19fc 1a00 1a04 1a08 1a0c 1a10 1a14
1a18 1a1c 1a20 1a2c 1a30 1a34 1a37 1a3b
1a3f 1a41 1 1a45 1a49 1a4d 1a50 1a54
1a58 1a5c 1a60 1a63 1a67 1a6b 1a6e 1a71
1a76 1a79 1a7c 1a7f 1a80 1a85 1a86 1
1a88 1a8d 1a91 1a95 1a98 1a9d 1aa2 1aa5
1aa9 1aaa 1aaf 1ab2 1ab7 1ab8 1abd 1ac0
1ac5 1ac6 1acb 1ace 1ad2 1ad3 1ad8 1adb
1ae0 1ae1 1ae6 1ae9 1aed 1af1 1af4 1af7
1af8 1afa 1afb 1b00 1b01 1b06 1b08 1b0c
1b0f 1b11 1b15 1b17 1b23 1b25 1b27 1b28
1b2d 1b31 1b33 1b3f 1b41 1b43 1b47 1b4b
1b4f 1b53 1b57 1b5b 1b5f 1b63 1b67 1b6b
1b6f 1b73 1b77 1b7b 1b7f 1b83 1b87 1b8b
1b8f 1b93 1b97 1b9b 1b9f 1ba3 1ba7 1bab
1baf 1bb3 1bb7 1bbb 1bbf 1bc3 1bc7 1bcb
1bcf 1bd3 1bd7 1bdb 1bdf 1be3 1be7 1beb
1bef 1bf3 1bf7 1bfb 1bff 1c03 1c07 1c0b
1c0f 1c13 1c17 1c1b 1c1f 1c23 1c27 1c2b
1c2f 1c33 1c37 1c3b 1c3f 1c43 1c47 1c4b
1c4f 1c53 1c57 1c63 1c67 1c6b 1c6e 1c72
1c76 1c78 1 1c7c 1c80 1c84 1c87 1c8b
1c8f 1c93 1c97 1c9a 1c9e 1ca2 1ca5 1ca8
1cad 1cb0 1cb3 1cb6 1cb7 1cbc 1cbd 1
1cbf 1cc4 1cc8 1ccc 1ccf 1cd4 1cd9 1cdc
1ce0 1ce1 1ce6 1ce9 1cee 1cef 1cf4 1cf7
1cfc 1cfd 1d02 1d05 1d09 1d0a 1d0f 1d12
1d17 1d18 1d1d 1d20 1d24 1d28 1d2b 1d2e
1d2f 1d31 1d32 1d37 1d38 1d3d 1d3f 1d43
1d46 1d48 1d4c 1d4e 1d5a 1d5c 1d5e 1d5f
1d64 1d68 1d6a 1d76 1d78 1d7a 1d7e 1d82
1d85 1d89 1d8d 1d90 1d94 1d97 1d9b 1d9e
1d9f 1da4 1da7 1dab 1daf 1db3 1db7 1dbb
1dbf 1dc3 1dcf 1dd3 1dd7 1dda 1dde 1de2
1de4 1 1de8 1dec 1df0 1df3 1df7 1dfb
1dff 1e03 1e06 1e0a 1e0e 1e11 1e14 1e19
1e1c 1e1f 1e22 1e23 1e28 1e29 1 1e2b
1e30 1e34 1e38 1e3b 1e40 1e45 1e48 1e4c
1e4d 1e52 1e55 1e5a 1e5b 1e60 1e63 1e68
1e69 1e6e 1e71 1e75 1e76 1e7b 1e7e 1e83
1e84 1e89 1e8c 1e90 1e94 1e97 1e9a 1e9b
1e9d 1e9e 1ea3 1ea4 1ea9 1eab 1eaf 1eb2
1eb4 1eb8 1eba 1ec6 1ec8 1eca 1ecb 1ed0
1ed4 1ed6 1ee2 1ee4 1ee8 1eec 1eef 1ef3
1ef6 1efa 1efd 1efe 1f03 1f06 1f0a 1f0d
1f0e 1f13 1f16 1f1a 1f1d 1f21 1f23 1f27
1f2a 1f2e 1f32 1f36 1f3a 1f3e 1f42 1f46
1f4a 1f4e 1f52 1f56 1f62 1f66 1f6a 1f6d
1f71 1f75 1f77 1 1f7b 1f7f 1f83 1f86
1f8a 1f8e 1f92 1f96 1f99 1f9d 1fa1 1fa4
1fa7 1fac 1faf 1fb2 1fb5 1fb6 1fbb 1fbc
1 1fbe 1fc3 1fc7 1fcb 1fce 1fd3 1fd8
1fdb 1fdf 1fe0 1fe5 1fe8 1fed 1fee 1ff3
1ff6 1ffb 1ffc 2001 2004 2008 2009 200e
2011 2016 2017 201c 201f 2023 2027 202a
202d 202e 2030 2031 2036 2037 203c 203e
2042 2045 2047 204b 204d 2059 205b 205d
205e 2063 2067 2069 2075 2077 2079 207d
2081 2084 2088 208c 208f 2092 2097 209a
209d 20a0 20a1 20a6 20a7 1 20a9 20ae
20b2 20b6 20b9 20be 20c3 20c6 20ca 20cb
20d0 20d3 20d8 20d9 20de 20e1 20e6 20e7
20ec 20ef 20f3 20f7 20fb 20ff 2102 2103
2105 210a 210b 210d 210e 2113 2116 211b
211c 2121 2124 2129 212a 212f 2132 2136
2137 213c 213f 2144 2145 214a 214b 2150
2152 2156 2159 215d 2161 2164 2168 216c
216f 2172 2177 217a 217d 2180 2181 2186
2187 1 2189 218e 2192 2196 2199 219e
21a3 21a6 21aa 21ab 21b0 21b1 21b6 21b8
21bc 21bf 21c3 21c7 21ca 21ce 21d2 21d5
21d9 21dd 21de 21e3 21e5 21e9 21ed 21f0
21f2 21f6 21f9 21fd 21ff 2203 2207 220a
220e 2211 2215 2219 221d 2221 2225 2229
2235 2239 223d 2240 2244 2248 224a 1
224e 2252 2256 2259 225d 2261 2265 2269
226c 2270 2274 2277 227a 227f 2282 2285
2288 2289 228e 228f 1 2291 2296 229a
229e 22a1 22a6 22ab 22ae 22b2 22b3 22b8
22bb 22c0 22c1 22c6 22c9 22ce 22cf 22d4
22d7 22db 22dc 22e1 22e4 22e9 22ea 22ef
22f2 22f6 22fa 22fd 2300 2301 2303 2304
2309 230a 230f 2311 2315 2318 231a 231e
2320 232c 232e 2330 2331 2336 233a 233c
2348 234a 234e 2352 2355 2356 2358 235b
235e 235f 2364 2368 236c 2370 2374 2378
2384 2388 238c 238f 2393 2397 2399 1
239d 23a1 23a5 23a8 23ac 23b0 23b4 23b8
23bb 23bf 23c3 23c6 23c9 23ce 23d1 23d4
23d7 23d8 23dd 23de 1 23e0 23e5 23e9
23ed 23f0 23f5 23fa 23fd 2401 2402 2407
240a 240f 2410 2415 2418 241d 241e 2423
2426 242a 242b 2430 2433 2438 2439 243e
2441 2445 2449 244c 244f 2450 2452 2453
2458 2459 245e 2460 2464 2467 2469 246d
246f 247b 247d 247f 2480 2485 2489 248b
2497 2499 249d 24a1 24a4 24a8 24ad 24ae
24b0 24b3 24b6 24b7 24bc 24c0 24c4 24c7
24cb 24cf 24d2 24d5 24da 24dd 24e0 24e3
24e4 24e9 24ea 1 24ec 24f1 24f5 24f9
24fc 2501 2506 2509 250d 250e 2513 2516
251b 251c 2521 2524 2529 252a 252f 2532
2536 253a 253e 2542 2545 2546 2548 254d
254e 2550 2551 2556 2559 255e 255f 2564
2567 256c 256d 2572 2575 2579 257a 257f
2582 2587 2588 258d 258e 2593 2595 2599
259c 25a0 25a4 25a7 25ab 25af 25b2 25b5
25ba 25bd 25c0 25c3 25c4 25c9 25ca 1
25cc 25d1 25d5 25d9 25dc 25e1 25e6 25e9
25ed 25ee 25f3 25f4 25f9 25fb 25ff 2602
2606 260a 260d 2611 2615 2618 261c 2620
2621 2626 2628 262c 262f 2631 2635 2638
263a 263e 2642 2646 264a 264e 2652 2656
265a 265e 2662 2666 2672 2676 267a 267d
2681 2685 2687 1 268b 268f 2693 2696
269a 269e 26a2 26a6 26a9 26ad 26b1 26b4
26b7 26bc 26bf 26c2 26c5 26c6 26cb 26cc
1 26ce 26d3 26d7 26db 26de 26e3 26e8
26eb 26ef 26f0 26f5 26f8 26fd 26fe 2703
2706 270b 270c 2711 2714 2718 2719 271e
2721 2726 2727 272c 272f 2733 2737 273a
273d 273e 2740 2741 2746 2747 274c 274e
2752 2755 2757 275b 275d 2769 276b 276d
276e 2773 2777 2779 2785 2787 278b 278f
2792 2796 2799 279d 27a0 27a1 27a6 27a9
27ad 27b1 27b5 27b9 27bd 27c9 27cd 27d1
27d4 27d8 27dc 27de 1 27e2 27e6 27ea
27ed 27f1 27f5 27f9 27fd 2800 2804 2808
280b 280e 2813 2816 2819 281c 281d 2822
2823 1 2825 282a 282e 2832 2835 283a
283f 2842 2846 2847 284c 284f 2854 2855
285a 285d 2862 2863 2868 286b 286f 2870
2875 2878 287d 287e 2883 2886 288a 288e
2891 2894 2895 2897 2898 289d 289e 28a3
28a5 28a9 28ac 28ae 28b2 28b4 28c0 28c2
28c4 28c5 28ca 28ce 28d0 28dc 28de 28e2
28e6 28e9 28ed 28f0 28f4 28f7 28f8 28fd
2900 2904 2908 290b 290f 2913 2916 2919
291e 2921 2924 2927 2928 292d 292e 1
2930 2935 2939 293d 2940 2945 294a 294d
2951 2952 2957 295a 295f 2960 2965 2968
296d 296e 2973 2976 297a 297e 2982 2986
2989 298a 298c 2991 2992 2994 2995 299a
299d 29a2 29a3 29a8 29ab 29b0 29b1 29b6
29b9 29bd 29be 29c3 29c6 29cb 29cc 29d1
29d2 29d7 29d9 29dd 29e0 29e4 29e8 29eb
29ef 29f3 29f6 29f9 29fe 2a01 2a04 2a07
2a08 2a0d 2a0e 1 2a10 2a15 2a19 2a1d
2a20 2a25 2a2a 2a2d 2a31 2a32 2a37 2a38
2a3d 2a3f 2a43 2a46 2a4a 2a4e 2a51 2a55
2a59 2a5c 2a60 2a64 2a65 2a6a 2a6c 2a70
2a73 2a75 2a79 2a7c 2a7e 2a82 2a86 2a89
2a8d 2a90 2a93 2a94 2a99 2a9d 2aa1 2aa5
2aa9 2aad 2ab1 2ab5 2ab9 2abd 2ac1 2ac5
2ac9 2acc 2acd 2acf 2ad3 2ad7 2ada 2adb
2add 2ae1 2ae5 2ae8 2ae9 2aeb 2aef 2af3
2af6 2af7 2af9 2afd 2b01 2b04 2b05 2b07
2b0b 2b0f 2b12 2b13 2b15 2b19 2b1d 2b20
2b21 2b23 2b27 2b2b 2b2e 2b2f 2b31 2b35
2b39 2b3d 2b3e 2b40 2b44 2b48 2b4c 2b4f
2b50 2b52 2b56 2b59 2b5d 2b60 2b61 2b66
2b6a 2b6e 2b71 2b75 2b79 2b7c 2b7f 2b84
2b87 2b8a 2b8d 2b8e 2b93 2b94 1 2b96
2b9b 2b9f 2ba3 2ba6 2bab 2bb0 2bb3 2bb7
2bb8 2bbd 2bc0 2bc5 2bc6 2bcb 2bce 2bd3
2bd4 2bd9 2bdc 2be0 2be4 2be8 2bec 2bef
2bf0 2bf2 2bf7 2bf8 2bfa 2bfb 2c00 2c01
2c06 2c08 2c0c 2c0f 2c13 2c17 2c1a 2c1e
2c22 2c25 2c28 2c2d 2c30 2c33 2c36 2c37
2c3c 2c3d 1 2c3f 2c44 2c48 2c4c 2c4f
2c54 2c59 2c5c 2c60 2c61 2c66 2c67 2c6c
2c6e 2c72 2c75 2c79 2c7d 2c80 2c84 2c88
2c8b 2c8f 2c90 2c95 2c99 2c9b 2c9f 2ca3
2ca6 2ca7 2ca9 2cac 2caf 2cb0 2cb5 2cb9
2cbd 2cc0 2cc4 2cc8 2ccb 2cce 2cd3 2cd6
2cd9 2cdc 2cdd 2ce2 2ce3 1 2ce5 2cea
2cee 2cf2 2cf5 2cfa 2cff 2d02 2d06 2d07
2d0c 2d0f 2d14 2d15 2d1a 2d1d 2d22 2d23
2d28 2d2b 2d2f 2d33 2d37 2d38 2d3a 2d3f
2d40 2d42 2d43 2d48 2d4b 2d50 2d51 2d56
2d59 2d5e 2d5f 2d64 2d67 2d6b 2d6c 2d71
2d74 2d79 2d7a 2d7f 2d80 2d85 2d87 2d8b
2d8e 2d92 2d96 2d99 2d9d 2da1 2da4 2da7
2dac 2daf 2db2 2db5 2db6 2dbb 2dbc 1
2dbe 2dc3 2dc7 2dcb 2dce 2dd3 2dd8 2ddb
2ddf 2de0 2de5 2de6 2deb 2ded 2df1 2df4
2df8 2dfc 2dff 2e03 2e07 2e0a 2e0b 2e0d
2e11 2e15 2e16 2e1b 2e1d 2e21 2e25 2e28
2e2c 2e30 2e34 2e38 2e3b 2e3c 2e41 2e44
2e48 2e4d 2e51 2e53 2e57 2e5a 2e5e 2e60
2e64 2e68 2e6b 2e6c 2e6e 2e71 2e74 2e75
2e7a 2e7d 2e81 2e85 2e88 2e89 2e8b 2e8e
2e91 2e92 2e97 1 2e9a 2e9f 2ea3 2ea7
2eaa 2eab 2ead 2eb0 2eb3 2eb4 2eb9 2ebc
2ec0 2ec4 2ec7 2ec8 2eca 2ecd 2ed0 2ed1
2ed6 1 2ed9 2ede 2ee2 2ee5 2ee9 2eed
2eef 2ef3 2ef7 2efa 2efb 2efd 2f00 2f03
2f04 2f09 2f0d 2f10 2f14 2f18 2f1a 2f1e
2f22 2f26 2f29 2f2a 2f2c 2f2f 2f32 2f33
2f38 2f3b 2f3f 2f43 2f46 2f47 2f49 2f4c
2f4f 2f50 2f55 1 2f58 2f5d 2f61 2f64
2f68 2f6c 2f6e 2f72 2f76 2f7a 2f7d 2f7e
2f80 2f83 2f86 2f87 2f8c 2f90 2f94 2f98
2f9b 2f9c 2f9e 2fa1 2fa5 2fa9 2fac 2fad
2faf 2fb0 2fb5 2fb9 2fbd 2fc0 2fc4 2fc6
2fca 2fce 2fd1 2fd3 2fd7 2fdb 2fde 2fe2
2fe6 2fe7 2fec 2ff0 2ff4 2ff9 2ffd 3001
3006 300a 300e 3012 3016 3019 301d 3021
3025 3028 3029 302b 302f 3033 3036 3037
3039 303c 303f 3040 3042 3046 304a 304e
3052 3056 3059 305a 305c 3060 3064 3067
3068 306a 306e 3072 3076 3079 307a 307c
307f 3082 3083 3088 308c 3090 3094 3098
309c 30a0 30a4 30a8 30a9 30ab 30af 30b3
30b7 30ba 30bb 30bd 30c0 30c3 30c4 30c9
30cd 30d1 30d4 30d8 30dc 30df 30e2 30e7
30ea 30ed 30f0 30f1 30f6 30f7 1 30f9
30fe 3102 3106 3109 310e 3113 3116 311a
311b 3120 3123 3128 3129 312e 3131 3136
3137 313c 313f 3143 3147 314b 314c 314e
3153 3154 3156 3157 315c 315f 3164 3165
316a 316d 3172 3173 3178 317b 317f 3180
3185 3188 318d 318e 3193 3194 3199 319b
319f 31a2 31a6 31aa 31ad 31b1 31b5 31b8
31bb 31c0 31c3 31c6 31c9 31ca 31cf 31d0
1 31d2 31d7 31db 31df 31e2 31e7 31ec
31ef 31f3 31f4 31f9 31fa 31ff 3201 3205
3208 320c 3210 3213 3217 321b 321e 321f
3221 3225 3229 322a 322f 3231 3235 3238
323c 323d 3241 3245 3249 324d 3251 3255
3259 325d 3261 3265 3269 326d 3271 3275
3279 327d 3281 3285 3289 328d 3291 329d
32a1 32a5 32a8 32ac 32b0 32b2 1 32b6
32ba 32be 32c1 32c5 32c9 32cd 32d1 32d4
32d8 32dc 32df 32e2 32e7 32ea 32ed 32f0
32f1 32f6 32f7 1 32f9 32fe 3302 3306
3309 330e 3313 3316 331a 331b 3320 3323
3328 3329 332e 3331 3336 3337 333c 333f
3343 3344 3349 334c 3351 3352 3357 335a
335e 3362 3365 3368 3369 336b 336c 3371
3372 3377 3379 337d 3380 3382 3386 3388
3394 3396 3398 3399 339e 33a2 33a4 33b0
33b2 33b6 33ba 33bd 33c1 33c4 33c8 33cb
33cc 33d1 33d4 33d8 33db 33dc 33e1 33e4
1 33e7 33ec 33f0 33f3 33f7 33fb 33ff
3402 3403 3405 3408 340b 340c 3411 3415
3419 341d 341f 3423 3426 3428 342c 342f
3433 3436 343a 343e 3441 3445 3449 344c
344f 3450 3455 3459 345d 3460 3463 3464
3466 3469 346e 346f 3474 3478 347c 3480
3484 3488 348c 3490 3494 3498 349c 34a0
34a4 34a8 34ac 34b0 34b4 34b8 34bc 34c0
34c4 34c8 34cc 34d0 34d4 34d8 34dc 34e0
34e4 34f0 34f4 34f8 34fb 34ff 3503 3505
1 3509 350d 3511 3514 3518 351c 3520
3524 3527 352b 352f 3532 3535 353a 353d
3540 3543 3544 3549 354a 1 354c 3551
3555 3559 355c 3561 3566 3569 356d 356e
3573 3576 357b 357c 3581 3584 3589 358a
358f 3592 3596 3597 359c 359f 35a4 35a5
35aa 35ad 35b1 35b5 35b8 35bb 35bc 35be
35bf 35c4 35c5 35ca 35cc 35d0 35d3 35d5
35d9 35db 35e7 35e9 35eb 35ec 35f1 35f5
35f7 3603 3605 3609 360d 3610 3614 3617
361b 361e 361f 3624 3627 362b 362e 3632
3636 363a 363d 363e 3640 3643 3646 3647
364c 364f 3653 3657 365a 365b 365d 3660
3663 3664 3669 1 366c 3671 3675 3679
367d 3681 3685 3689 368d 3691 3695 3699
369d 36a1 36a5 36a9 36ad 36b1 36b5 36b9
36bd 36c1 36c5 36c9 36cd 36d1 36d5 36d9
36e5 36e9 36ed 36f0 36f4 36f8 36fa 1
36fe 3702 3706 3709 370d 3711 3715 3719
371c 3720 3724 3727 372a 372f 3732 3735
3738 3739 373e 373f 1 3741 3746 374a
374e 3751 3756 375b 375e 3762 3763 3768
376b 3770 3771 3776 3779 377e 377f 3784
3787 378b 378c 3791 3794 3799 379a 379f
37a2 37a6 37aa 37ad 37b0 37b1 37b3 37b4
37b9 37ba 37bf 37c1 37c5 37c8 37ca 37ce
37d0 37dc 37de 37e0 37e1 37e6 37ea 37ec
37f8 37fa 37fc 3800 3803 3807 3809 380d
3811 3814 3818 381a 381e 3822 3825 3829
382c 3830 3833 3834 3839 383c 3840 3844
3847 3848 384a 384d 3850 3851 3856 1
3859 385e 3862 3866 386a 386e 3872 3876
387a 387e 3882 3886 388a 388e 3892 3896
389a 389e 38a2 38a6 38aa 38ae 38b2 38b6
38ba 38be 38c2 38c6 38d2 38d6 38da 38dd
38e1 38e5 38e7 1 38eb 38ef 38f3 38f6
38fa 38fe 3902 3906 3909 390d 3911 3914
3917 391c 391f 3922 3925 3926 392b 392c
1 392e 3933 3937 393b 393e 3943 3948
394b 394f 3950 3955 3958 395d 395e 3963
3966 396b 396c 3971 3974 3978 3979 397e
3981 3986 3987 398c 398f 3993 3997 399a
399d 399e 39a0 39a1 39a6 39a7 39ac 39ae
39b2 39b5 39b7 39bb 39bd 39c9 39cb 39cd
39ce 39d3 39d7 39d9 39e5 39e7 39e9 39ed
39f1 39f4 39f6 39fa 39fe 3a02 3a06 3a0a
3a0e 3a12 3a16 3a1a 3a1e 3a22 3a26 3a2a
3a2e 3a32 3a36 3a3a 3a3e 3a42 3a46 3a4a
3a4e 3a52 3a56 3a5a 3a5e 3a6a 3a6e 3a72
3a75 3a79 3a7d 3a7f 1 3a83 3a87 3a8b
3a8e 3a92 3a96 3a9a 3a9e 3aa1 3aa5 3aa9
3aac 3aaf 3ab4 3ab7 3aba 3abd 3abe 3ac3
3ac4 1 3ac6 3acb 3acf 3ad3 3ad6 3adb
3ae0 3ae3 3ae7 3ae8 3aed 3af0 3af5 3af6
3afb 3afe 3b03 3b04 3b09 3b0c 3b10 3b11
3b16 3b19 3b1e 3b1f 3b24 3b27 3b2b 3b2f
3b32 3b35 3b36 3b38 3b39 3b3e 3b3f 3b44
3b46 3b4a 3b4d 3b4f 3b53 3b55 3b61 3b63
3b65 3b66 3b6b 3b6f 3b71 3b7d 3b7f 3b81
3b85 3b89 3b8c 3b8e 3b92 3b96 3b99 3b9c
3b9d 3b9f 3ba2 3ba7 3ba8 3bad 3bb1 3bb5
3bb9 3bbd 3bc1 3bc5 3bc9 3bcd 3bd1 3bd5
3bd9 3bdd 3be1 3be5 3be9 3bed 3bf1 3bf5
3bf9 3bfd 3c01 3c05 3c09 3c0d 3c11 3c1d
3c21 3c25 3c28 3c2c 3c30 3c32 1 3c36
3c3a 3c3e 3c41 3c45 3c49 3c4d 3c51 3c54
3c58 3c5c 3c5f 3c62 3c67 3c6a 3c6d 3c70
3c71 3c76 3c77 1 3c79 3c7e 3c82 3c86
3c89 3c8e 3c93 3c96 3c9a 3c9b 3ca0 3ca3
3ca8 3ca9 3cae 3cb1 3cb6 3cb7 3cbc 3cbf
3cc3 3cc4 3cc9 3ccc 3cd1 3cd2 3cd7 3cda
3cde 3ce2 3ce5 3ce8 3ce9 3ceb 3cec 3cf1
3cf2 3cf7 3cf9 3cfd 3d00 3d02 3d06 3d08
3d14 3d16 3d18 3d19 3d1e 3d22 3d24 3d30
3d32 3d36 3d3a 3d3d 3d41 3d44 3d48 3d4b
3d4c 3d51 3d54 3d58 3d5b 3d5f 3d63 3d67
3d6a 3d6b 3d6d 3d70 3d73 3d74 3d79 3d7c
3d80 3d84 3d87 3d88 3d8a 3d8d 3d90 3d91
3d96 1 3d99 3d9e 3da2 3da6 3daa 3dae
3db2 3db6 3dba 3dbe 3dc2 3dc6 3dca 3dce
3dd2 3dd6 3dda 3dde 3de2 3de6 3dea 3dee
3dfa 3dfe 3e02 3e05 3e09 3e0d 3e0f 1
3e13 3e17 3e1b 3e1e 3e22 3e26 3e2a 3e2e
3e31 3e35 3e39 3e3c 3e3f 3e44 3e47 3e4a
3e4d 3e4e 3e53 3e54 1 3e56 3e5b 3e5f
3e63 3e66 3e6b 3e70 3e73 3e77 3e78 3e7d
3e80 3e85 3e86 3e8b 3e8e 3e93 3e94 3e99
3e9c 3ea0 3ea1 3ea6 3ea9 3eae 3eaf 3eb4
3eb7 3ebb 3ebf 3ec2 3ec5 3ec6 3ec8 3ec9
3ece 3ecf 3ed4 3ed6 3eda 3edd 3edf 3ee3
3ee5 3ef1 3ef3 3ef5 3ef6 3efb 3eff 3f01
3f0d 3f0f 3f11 3f15 3f18 3f1c 3f1e 3f20
3f24 3f28 3f2b 3f2f 3f31 3f35 3f39 3f3c
3f40 3f43 3f47 3f4a 3f4b 3f50 3f53 3f57
3f5b 3f5f 3f63 3f67 3f6b 3f6f 3f73 3f77
3f7b 3f7f 3f83 3f87 3f8b 3f8f 3f93 3f97
3f9b 3f9f 3fa3 3fa7 3fab 3faf 3fbb 3fbf
3fc3 3fc6 3fca 3fce 3fd0 1 3fd4 3fd8
3fdc 3fdf 3fe3 3fe7 3feb 3fef 3ff2 3ff6
3ffa 3ffd 4000 4005 4008 400b 400e 400f
4014 4015 1 4017 401c 4020 4024 4027
402c 4031 4034 4038 4039 403e 4041 4046
4047 404c 404f 4054 4055 405a 405d 4061
4062 4067 406a 406f 4070 4075 4078 407c
4080 4083 4086 4087 4089 408a 408f 4090
4095 4097 409b 409e 40a0 40a4 40a6 40b2
40b4 40b6 40b7 40bc 40c0 40c2 40ce 40d0
40d2 40d6 40da 40dd 40df 40e3 40e7 40eb
40ef 40f3 40f7 40fb 40ff 4103 4107 410b
410f 4113 4117 411b 411f 4123 4127 412b
412f 4133 4137 413b 4147 414b 414f 4152
4156 415a 415c 1 4160 4164 4168 416b
416f 4173 4177 417b 417e 4182 4186 4189
418c 4191 4194 4197 419a 419b 41a0 41a1
1 41a3 41a8 41ac 41b0 41b3 41b8 41bd
41c0 41c4 41c5 41ca 41cd 41d2 41d3 41d8
41db 41e0 41e1 41e6 41e9 41ed 41ee 41f3
41f6 41fb 41fc 4201 4204 4208 420c 420f
4212 4213 4215 4216 421b 421c 4221 4223
4227 422a 422c 4230 4232 423e 4240 4242
4243 4248 424c 424e 425a 425c 425e 4262
4266 4269 426b 426f 4273 4276 427a 427e
4281 4285 4288 428c 428f 4290 4295 4298
429c 42a0 42a3 42a4 42a6 42a9 42ac 42ad
42b2 42b6 42ba 42bd 42c1 42c5 42c8 42cb
42d0 42d3 42d6 42d9 42da 42df 42e0 1
42e2 42e7 42eb 42ef 42f2 42f7 42fc 42ff
4303 4304 4309 430c 4311 4312 4317 431a
431f 4320 4325 4328 432c 4330 4334 4338
433b 433c 433e 4343 4344 4346 4347 434c
434f 4354 4355 435a 435d 4362 4363 4368
436b 436f 4370 4375 4378 437d 437e 4383
4384 4389 438b 438f 4392 4396 439a 439d
43a1 43a5 43a8 43ab 43b0 43b3 43b6 43b9
43ba 43bf 43c0 1 43c2 43c7 43cb 43cf
43d2 43d7 43dc 43df 43e3 43e4 43e9 43ea
43ef 43f1 43f5 43f8 43fc 4400 4403 4407
440b 440e 4412 4416 4417 441c 4420 4422
4426 4429 442a 442f 4432 4436 4439 443c
443d 4442 4446 4449 444d 4451 4455 4459
445d 4461 4465 4469 446d 4471 4475 4479
447d 4481 4485 4489 4495 4499 449d 44a0
44a4 44a8 44aa 1 44ae 44b2 44b6 44b9
44bd 44c1 44c5 44c9 44cc 44d0 44d4 44d7
44da 44df 44e2 44e5 44e8 44e9 44ee 44ef
1 44f1 44f6 44fa 44fe 4501 4506 450b
450e 4512 4513 4518 451b 4520 4521 4526
4529 452e 452f 4534 4537 453b 453c 4541
4544 4549 454a 454f 4552 4556 455a 455d
4560 4561 4563 4564 4569 456a 456f 4571
4575 4578 457a 457e 4580 458c 458e 4590
4591 4596 459a 459c 45a8 45aa 45ac 45b0
45b3 45b7 45bb 45bf 45c3 45c7 45cb 45cf
45d3 45d7 45db 45df 45e3 45e7 45f3 45f7
45fb 45fe 4602 4606 4608 1 460c 4610
4614 4617 461b 461f 4623 4627 462a 462e
4632 4635 4638 463d 4640 4643 4646 4647
464c 464d 1 464f 4654 4658 465c 465f
4664 4669 466c 4670 4671 4676 4679 467e
467f 4684 4687 468c 468d 4692 4695 4699
469a 469f 46a2 46a7 46a8 46ad 46b0 46b4
46b8 46bb 46be 46bf 46c1 46c2 46c7 46c8
46cd 46cf 46d3 46d6 46d8 46dc 46de 46ea
46ec 46ee 46ef 46f4 46f8 46fa 4706 4708
470a 470e 4712 4715 4719 471d 4720 4721
4723 4727 472a 472e 4731 4732 4734 4735
473a 473e 4742 4745 4749 474d 4750 4753
4758 475b 475e 4761 4762 4767 4768 1
476a 476f 4773 4777 477a 477f 4784 4787
478b 478c 4791 4794 4799 479a 479f 47a2
47a7 47a8 47ad 47b0 47b4 47b8 47bc 47c0
47c3 47c4 47c6 47cb 47cc 47ce 47cf 47d4
47d7 47dc 47dd 47e2 47e5 47ea 47eb 47f0
47f3 47f7 47f8 47fd 4800 4805 4806 480b
480c 4811 4813 4817 481a 481e 4822 4825
4829 482d 4830 4833 4838 483b 483e 4841
4842 4847 4848 1 484a 484f 4853 4857
485a 485f 4864 4867 486b 486c 4871 4872
4877 4879 487d 4880 4884 4888 488b 488f
4893 4896 489a 489e 489f 48a4 48a6 48aa
48ad 48af 48b3 48b7 48ba 48be 48c1 48c5
48c9 48cb 48cf 48d3 48d6 48d7 48d9 48dc
48df 48e0 48e5 48e8 48ec 48f0 48f4 48f7
48f8 48fa 48fb 48fd 4900 4903 4906 4907
1 490c 4911 4915 4919 491c 4920 4924
4927 492a 492f 4932 4935 4938 4939 493e
493f 1 4941 4946 494a 494e 4951 4956
495b 495e 4962 4963 4968 496b 4970 4971
4976 4979 497e 497f 4984 4987 498b 498f
4993 4997 499a 499b 499d 49a2 49a3 49a5
49a6 49ab 49ae 49b3 49b4 49b9 49bc 49c1
49c2 49c7 49ca 49ce 49cf 49d4 49d7 49dc
49dd 49e2 49e3 49e8 49ea 49ee 49f1 49f5
49f9 49fc 4a00 4a04 4a07 4a0a 4a0f 4a12
4a15 4a18 4a19 4a1e 4a1f 1 4a21 4a26
4a2a 4a2e 4a31 4a36 4a3b 4a3e 4a42 4a43
4a48 4a49 4a4e 4a50 4a54 4a57 4a5b 4a5f
4a62 4a66 4a6a 4a6d 4a71 4a75 4a76 4a7b
4a7d 4a81 4a85 4a88 4a8c 4a90 4a93 4a96
4a97 4a99 4a9c 4aa1 4aa2 4aa7 4aab 4aaf
4ab3 4ab6 4aba 4abb 4ac0 4ac3 4ac6 4ac7
4ac9 4acd 4ad1 4ad5 4ad9 4add 4ae1 4ae5
4ae9 4aed 4af1 4af5 4af9 4afd 4b01 4b05
4b09 4b0d 4b11 4b15 4b19 4b1d 4b21 4b2d
4b31 4b35 4b38 4b3c 4b40 4b42 1 4b46
4b4a 4b4e 4b51 4b55 4b59 4b5d 4b61 4b64
4b68 4b6c 4b6f 4b72 4b77 4b7a 4b7d 4b80
4b81 4b86 4b87 1 4b89 4b8e 4b92 4b96
4b99 4b9e 4ba3 4ba6 4baa 4bab 4bb0 4bb3
4bb8 4bb9 4bbe 4bc1 4bc6 4bc7 4bcc 4bcf
4bd3 4bd4 4bd9 4bdc 4be1 4be2 4be7 4bea
4bee 4bf2 4bf5 4bf8 4bf9 4bfb 4bfc 4c01
4c02 4c07 4c09 4c0d 4c10 4c12 4c16 4c18
4c24 4c26 4c28 4c29 4c2e 4c32 4c34 4c40
4c42 4c46 4c4a 4c4d 4c51 4c54 4c58 4c5b
4c5c 4c61 4c64 4c68 4c6c 4c6f 4c73 4c77
4c7a 4c7d 4c82 4c85 4c88 4c8b 4c8c 4c91
4c92 1 4c94 4c99 4c9d 4ca1 4ca4 4ca9
4cae 4cb1 4cb5 4cb6 4cbb 4cbe 4cc3 4cc4
4cc9 4ccc 4cd1 4cd2 4cd7 4cda 4cde 4ce2
4ce6 4cea 4ced 4cee 4cf0 4cf5 4cf6 4cf8
4cf9 4cfe 4d01 4d06 4d07 4d0c 4d0f 4d14
4d15 4d1a 4d1d 4d21 4d22 4d27 4d2a 4d2f
4d30 4d35 4d36 4d3b 4d3d 4d41 4d44 4d48
4d4c 4d4f 4d53 4d57 4d5a 4d5d 4d62 4d65
4d68 4d6b 4d6c 4d71 4d72 1 4d74 4d79
4d7d 4d81 4d84 4d89 4d8e 4d91 4d95 4d96
4d9b 4d9c 4da1 4da3 4da7 4daa 4dae 4db2
4db5 4db9 4dbd 4dc0 4dc4 4dc8 4dc9 4dce
4dd0 4dd4 4dd7 4ddb 4ddf 4de2 4de5 4de6
4de8 4deb 4df0 4df1 4df6 4df9 4dfd 4e01
4e04 4e05 4e07 4e0a 4e0d 4e0e 4e13 4e16
4e1a 4e1e 4e21 4e22 4e24 4e28 4e2b 4e2f
4e32 4e33 4e35 4e36 4e3b 1 4e3e 4e43
1 4e46 4e4b 4e4f 4e53 4e56 4e5a 4e5e
4e61 4e64 4e69 4e6c 4e6f 4e72 4e73 4e78
4e79 1 4e7b 4e80 4e84 4e88 4e8b 4e90
4e95 4e98 4e9c 4e9d 4ea2 4ea5 4eaa 4eab
4eb0 4eb3 4eb8 4eb9 4ebe 4ec1 4ec5 4ec9
4ecd 4ed1 4ed4 4ed5 4ed7 4edc 4edd 4edf
4ee0 4ee5 4ee8 4eed 4eee 4ef3 4ef6 4efb
4efc 4f01 4f04 4f08 4f09 4f0e 4f11 4f16
4f17 4f1c 4f1d 4f22 4f24 4f28 4f2b 4f2f
4f33 4f36 4f3a 4f3e 4f41 4f44 4f49 4f4c
4f4f 4f52 4f53 4f58 4f59 1 4f5b 4f60
4f64 4f68 4f6b 4f70 4f75 4f78 4f7c 4f7d
4f82 4f83 4f88 4f8a 4f8e 4f91 4f95 4f99
4f9c 4fa0 4fa4 4fa7 4fab 4faf 4fb0 4fb5
4fb7 4fbb 4fbe 4fc2 4fc6 4fca 4fce 4fd2
4fd6 4fda 4fde 4fe2 4fe6 4fea 4fee 4ffa
4ffe 5002 5005 5009 500d 500f 1 5013
5017 501b 501e 5022 5026 502a 502e 5031
5035 5039 503c 503f 5044 5047 504a 504d
504e 5053 5054 1 5056 505b 505f 5063
5066 506b 5070 5073 5077 5078 507d 5080
5085 5086 508b 508e 5093 5094 5099 509c
50a0 50a1 50a6 50a9 50ae 50af 50b4 50b7
50bb 50bf 50c2 50c5 50c6 50c8 50c9 50ce
50cf 50d4 50d6 50da 50dd 50df 50e3 50e5
50f1 50f3 50f5 50f6 50fb 50ff 5101 510d
510f 5111 5115 5119 511d 5120 5124 5125
512a 512d 5130 5131 5133 5137 513b 513f
5143 5147 514b 5157 515b 515f 5162 5166
516a 516c 1 5170 5174 5178 517b 517f
5183 5187 518b 518e 5192 5196 5199 519c
51a1 51a4 51a7 51aa 51ab 51b0 51b1 1
51b3 51b8 51bc 51c0 51c3 51c8 51cd 51d0
51d4 51d5 51da 51dd 51e2 51e3 51e8 51eb
51f0 51f1 51f6 51f9 51fd 51fe 5203 5206
520b 520c 5211 5214 5218 521c 521f 5222
5223 5225 5226 522b 522c 5231 5233 5237
523a 523c 5240 5242 524e 5250 5252 5253
5258 525c 525e 526a 526c 5270 5274 5277
527b 527e 5282 5285 5286 528b 528e 5292
5296 5299 529d 52a1 52a4 52a7 52ac 52af
52b2 52b5 52b6 52bb 52bc 1 52be 52c3
52c7 52cb 52ce 52d3 52d8 52db 52df 52e0
52e5 52e8 52ed 52ee 52f3 52f6 52fb 52fc
5301 5304 5308 530c 5310 5314 5317 5318
531a 531f 5320 5322 5323 5328 532b 5330
5331 5336 5339 533e 533f 5344 5347 534b
534c 5351 5354 5359 535a 535f 5360 5365
5367 536b 536e 5372 5376 5379 537d 5381
5384 5387 538c 538f 5392 5395 5396 539b
539c 1 539e 53a3 53a7 53ab 53ae 53b3
53b8 53bb 53bf 53c0 53c5 53c6 53cb 53cd
53d1 53d4 53d8 53dc 53df 53e3 53e7 53ea
53ee 53f2 53f3 53f8 53fa 53fe 5401 5405
5409 540d 5411 5415 5419 541d 5421 5425
5429 542d 5431 5435 5439 543d 5441 5445
5449 544d 5451 545d 5461 5465 5468 546c
5470 5472 1 5476 547a 547e 5481 5485
5489 548d 5491 5494 5498 549c 549f 54a2
54a7 54aa 54ad 54b0 54b1 54b6 54b7 1
54b9 54be 54c2 54c6 54c9 54ce 54d3 54d6
54da 54db 54e0 54e3 54e8 54e9 54ee 54f1
54f6 54f7 54fc 54ff 5503 5504 5509 550c
5511 5512 5517 551a 551e 5522 5525 5528
5529 552b 552c 5531 5532 5537 5539 553d
5540 5542 5546 5548 5554 5556 5558 5559
555e 5562 5564 5570 5572 5576 557a 557d
5581 5584 5588 558b 558c 5591 5594 5598
559c 559f 55a0 55a2 55a5 55a8 55a9 55ae
1 55b1 55b6 55ba 55be 55c1 55c5 55c9
55cc 55cf 55d4 55d7 55da 55dd 55de 55e3
55e4 1 55e6 55eb 55ef 55f3 55f6 55fb
5600 5603 5607 5608 560d 5610 5615 5616
561b 561e 5623 5624 5629 562c 5630 5634
5638 563c 563f 5640 5642 5647 5648 564a
564b 5650 5653 5658 5659 565e 5661 5666
5667 566c 566f 5673 5674 5679 567c 5681
5682 5687 5688 568d 568f 5693 5696 569a
569e 56a1 56a5 56a9 56ac 56af 56b4 56b7
56ba 56bd 56be 56c3 56c4 1 56c6 56cb
56cf 56d3 56d6 56db 56e0 56e3 56e7 56e8
56ed 56ee 56f3 56f5 56f9 56fc 5700 5704
5707 570b 570f 5712 5716 571a 571b 5720
5722 5726 5729 572d 5731 5735 5739 573d
5741 5745 5749 574d 5751 5755 5759 5765
5769 576d 5770 5774 5778 577a 1 577e
5782 5786 5789 578d 5791 5795 5799 579c
57a0 57a4 57a7 57aa 57af 57b2 57b5 57b8
57b9 57be 57bf 1 57c1 57c6 57ca 57ce
57d1 57d6 57db 57de 57e2 57e3 57e8 57eb
57f0 57f1 57f6 57f9 57fe 57ff 5804 5807
580b 580c 5811 5814 5819 581a 581f 5822
5826 582a 582d 5830 5831 5833 5834 5839
583a 583f 5841 5845 5848 584a 584e 5850
585c 585e 5860 5861 5866 586a 586c 5878
587a 587c 5880 5884 5887 588b 588f 5893
5897 589b 589e 589f 58a1 58a4 58a7 58a8
58ad 58b1 58b5 58b9 58bd 58c1 58c5 58c9
58cd 58d1 58d5 58e1 58e5 58e9 58ec 58f0
58f4 58f6 1 58fa 58fe 5902 5905 5909
590d 5911 5915 5918 591c 5920 5923 5926
592b 592e 5931 5934 5935 593a 593b 1
593d 5942 5946 594a 594d 5952 5957 595a
595e 595f 5964 5967 596c 596d 5972 5975
597a 597b 5980 5983 5987 5988 598d 5990
5995 5996 599b 599e 59a2 59a6 59a9 59ac
59ad 59af 59b0 59b5 59b6 59bb 59bd 59c1
59c4 59c6 59ca 59cc 59d8 59da 59dc 59dd
59e2 59e6 59e8 59f4 59f6 59fa 59fe 5a02
5a06 5a0a 5a0e 5a12 5a16 5a1a 5a1e 5a2a
5a2e 5a32 5a35 5a39 5a3d 5a3f 1 5a43
5a47 5a4b 5a4e 5a52 5a56 5a5a 5a5e 5a61
5a65 5a69 5a6c 5a6f 5a74 5a77 5a7a 5a7d
5a7e 5a83 5a84 1 5a86 5a8b 5a8f 5a93
5a96 5a9b 5aa0 5aa3 5aa7 5aa8 5aad 5ab0
5ab5 5ab6 5abb 5abe 5ac3 5ac4 5ac9 5acc
5ad0 5ad1 5ad6 5ad9 5ade 5adf 5ae4 5ae7
5aeb 5aef 5af2 5af5 5af6 5af8 5af9 5afe
5aff 5b04 5b06 5b0a 5b0d 5b0f 5b13 5b15
5b21 5b23 5b25 5b26 5b2b 5b2f 5b31 5b3d
5b3f 5b43 5b46 5b4a 5b4e 5b52 5b56 5b5a
5b5e 5b61 5b62 5b64 5b67 5b6a 5b6b 5b70
5b74 5b77 5b7b 5b7d 5b81 5b84 5b88 5b8c
5b90 5b94 5b98 5b9c 5ba0 5ba4 5ba8 5bac
5bb0 5bb4 5bb8 5bbc 5bc0 5bc4 5bc8 5bcc
5bd0 5bd4 5bd8 5bdc 5be0 5be4 5be8 5bec
5bf0 5bf4 5bf8 5bfc 5bff 5c02 5c05 5c08
5c09 5c0b 5c0f 5c13 5c16 5c19 5c1a 5c1f
5c23 5c27 5c2a 5c2b 5c2d 5c30 5c33 5c34
5c39 5c3d 5c41 5c45 5c49 5c55 5c59 5c5e
5c62 5c65 5c66 5c6b 5c6f 5c73 5c76 5c79
5c7d 5c7f 5c83 5c87 5c8a 5c8d 5c91 5c93
5c97 5c9b 5c9e 5ca0 1 5ca4 5ca8 5cac
5caf 5cb3 5cb7 5cbb 5cbf 5cc2 5cc6 5cca
5ccd 5cd0 5cd5 5cd8 5cdb 5cde 5cdf 5ce4
5ce5 1 5ce7 5cec 5cf0 5cf4 5cf7 5cfc
5d01 5d04 5d08 5d09 5d0e 5d11 5d16 5d17
5d1c 5d1f 5d24 5d25 5d2a 5d2d 5d31 5d32
5d37 5d3a 5d3f 5d40 5d45 5d48 5d4c 5d50
5d53 5d56 5d57 5d59 5d5a 5d5f 5d60 5d65
5d67 5d6b 5d6e 5d70 5d74 5d76 5d82 5d84
5d86 5d87 5d8c 5d90 5d92 5d9e 5da0 5da2
5da6 5daa 5dae 5db2 5dbe 5dc2 5dc7 5dcb
5dce 5dcf 5dd4 5dd8 5ddc 5ddf 5de2 5de6
5de8 5dec 5df0 5df3 5df6 5dfa 5dfc 5e00
5e04 5e07 5e09 1 5e0d 5e11 5e15 5e18
5e1c 5e20 5e24 5e28 5e2b 5e2f 5e33 5e36
5e39 5e3e 5e41 5e44 5e47 5e48 5e4d 5e4e
1 5e50 5e55 5e59 5e5d 5e60 5e65 5e6a
5e6d 5e71 5e72 5e77 5e7a 5e7f 5e80 5e85
5e88 5e8d 5e8e 5e93 5e96 5e9a 5e9b 5ea0
5ea3 5ea8 5ea9 5eae 5eb1 5eb5 5eb9 5ebc
5ebf 5ec0 5ec2 5ec3 5ec8 5ec9 5ece 5ed0
5ed4 5ed7 5ed9 5edd 5edf 5eeb 5eed 5eef
5ef0 5ef5 5ef9 5efb 5f07 5f09 5f0b 5f0f
5f13 5f16 5f18 5f1c 5f1f 5f21 5f25 5f29
5f2d 5f31 5f35 5f39 5f3d 5f41 5f44 5f47
5f48 5f4a 5f4d 5f52 5f53 5f58 5f5c 5f60
5f64 5f67 5f6b 5f6d 5f71 5f75 5f79 5f7d
5f80 5f81 5f83 5f87 5f8b 5f8e 5f8f 5f91
5f95 5f97 5f9b 5f9f 5fa2 5fa6 5faa 5fae
5fb2 5fb6 5fba 5fbe 5fc2 5fc6 5fca 5fce
5fd2 5fd6 5fda 5fde 5fe2 5fe6 5fea 5fee
5ff2 5ff6 5ffa 5ffe 6002 6006 600a 600e
6012 6016 601a 601d 6020 6023 6026 6027
6029 602d 6031 6034 6037 6038 603d 6041
6045 6049 604d 6059 605d 6062 6066 6069
606a 606f 6073 6077 607a 607d 6081 6083
6087 608b 608e 6091 6095 6097 609b 609f
60a2 60a4 1 60a8 60ac 60b0 60b3 60b7
60bb 60bf 60c3 60c6 60ca 60ce 60d1 60d4
60d9 60dc 60df 60e2 60e3 60e8 60e9 1
60eb 60f0 60f4 60f8 60fb 6100 6105 6108
610c 610d 6112 6115 611a 611b 6120 6123
6128 6129 612e 6131 6135 6136 613b 613e
6143 6144 6149 614c 6150 6154 6157 615a
615b 615d 615e 6163 6164 6169 616b 616f
6172 6174 6178 617a 6186 6188 618a 618b
6190 6194 6196 61a2 61a4 61a6 61aa 61ad
61af 61b3 61b7 61ba 61bc 61c0 61c4 61c8
61c9 61cb 61ce 61cf 61d1 61d4 61d7 61d8
61dd 61e1 61e4 61e8 61ea 61ee 61f2 61f6
61fa 61fe 61ff 6201 6204 6205 6207 620a
620d 620e 6213 6216 6219 621c 621d 6222
6223 6225 6229 622b 622f 6233 6236 623a
623d 6240 6241 6246 624a 624d 6251 6255
6259 625d 6260 6261 6263 6267 626a 626e
626f 6274 6276 627a 627d 6281 6285 6289
628d 6290 6293 6296 629a 629e 62a1 62a2
62a4 62a7 62aa 62ab 62b0 62b3 62b6 62b7
62bc 62c0 62c1 62c3 62c7 62cb 62cf 62d3
62d6 62d9 62dc 62e0 62e4 62e7 62e8 62ea
62ed 62f0 62f1 62f6 62f9 62fc 62fd 6302
6305 6308 6309 630e 6312 6313 6315 6319
631d 6321 6325 6329 632c 6330 6334 6337
633b 633f 6343 6347 634b 634f 6353 6357
635b 635f 6363 6367 636b 636f 6373 6377
637b 637f 638b 638f 6393 6396 639a 639e
63a0 1 63a4 63a8 63ac 63af 63b3 63b7
63bb 63bf 63c2 63c6 63ca 63cd 63d0 63d5
63d8 63db 63de 63df 63e4 63e5 1 63e7
63ec 63f0 63f4 63f7 63fc 6401 6404 6408
6409 640e 6411 6416 6417 641c 641f 6424
6425 642a 642d 6431 6432 6437 643a 643f
6440 6445 6448 644c 6450 6453 6456 6457
6459 645a 645f 6460 6465 6467 646b 646e
6470 6474 6476 6482 6484 6486 6487 648c
6490 6492 649e 64a0 64a4 64a8 64ab 64ac
64ae 64b1 64b4 64b5 64ba 64bd 64c1 64c4
64c5 64ca 64cd 1 64d0 64d5 64d9 64dc
64e0 64e4 64e8 64eb 64ef 64f3 64f4 64f6
64f9 64fc 64fd 6502 6506 650a 650e 6510
6514 6517 6519 651d 6520 6524 6528 652b
652e 652f 6531 6534 6539 653a 653f 6543
6547 654b 654e 6552 6556 655a 655e 655f
6561 6564 6565 6567 656a 656d 656e 6573
6577 657b 657f 6581 6585 6589 658d 6590
6595 6596 659b 659e 65a1 65a2 65a4 65a8
65ac 65b0 65b4 65b7 65bb 65bc 65c1 65c4
65c7 65c8 65ca 65ce 65d0 65d4 65d8 65db
65dd 65e1 65e5 65e9 65ea 65ec 65ef 65f0
65f2 65f5 65f8 65f9 65fe 6602 6606 660a
660c 6610 6614 6618 661b 6620 6621 6626
6629 662c 662d 662f 6633 6637 663b 663f
6642 6646 6647 664c 664f 6652 6653 6655
6659 665b 665f 6663 6666 6668 666c 6670
6673 6677 667a 667e 6682 6685 6689 668d
6691 6694 6695 6697 669a 669d 669e 66a3
66a7 66aa 66ad 66ae 66b3 66b7 66bb 66be
66c1 66c2 66c4 66c7 66cc 66cd 66d2 66d6
66da 66de 66e2 66e6 66ea 66ee 66f2 66f6
66fa 66fe 6702 6706 670a 670e 6712 6716
671a 671e 6722 6726 672a 672e 6732 6736
673a 673e 6742 674e 6752 6756 6759 675d
6761 6763 1 6767 676b 676f 6772 6776
677a 677e 6782 6785 6789 678d 6790 6793
6798 679b 679e 67a1 67a2 67a7 67a8 1
67aa 67af 67b3 67b7 67ba 67bf 67c4 67c7
67cb 67cc 67d1 67d4 67d9 67da 67df 67e2
67e7 67e8 67ed 67f0 67f4 67f5 67fa 67fd
6802 6803 6808 680b 680f 6813 6816 6819
681a 681c 681d 6822 6823 6828 682a 682e
6831 6833 6837 6839 6845 6847 6849 684a
684f 6853 6855 6861 6863 6867 686b 686e
6872 6875 6879 687c 687d 6882 6885 6889
688c 6890 6894 6898 689b 689c 689e 68a1
68a4 68a5 68aa 68ad 68b1 68b5 68b8 68b9
68bb 68be 68c1 68c2 68c7 1 68ca 68cf
68d3 68d7 68db 68df 68e3 68e7 68eb 68ef
68f3 68f7 68fb 68ff 6903 6907 690b 690f
6913 6917 691b 691f 6923 6927 692b 692f
6933 6937 6943 6947 694b 694e 6952 6956
6958 1 695c 6960 6964 6967 696b 696f
6973 6977 697a 697e 6982 6985 6988 698d
6990 6993 6996 6997 699c 699d 1 699f
69a4 69a8 69ac 69af 69b4 69b9 69bc 69c0
69c1 69c6 69c9 69ce 69cf 69d4 69d7 69dc
69dd 69e2 69e5 69e9 69ea 69ef 69f2 69f7
69f8 69fd 6a00 6a04 6a08 6a0b 6a0e 6a0f
6a11 6a12 6a17 6a18 6a1d 6a1f 6a23 6a26
6a28 6a2c 6a2e 6a3a 6a3c 6a3e 6a3f 6a44
6a48 6a4a 6a56 6a58 6a5a 6a5e 6a61 6a65
6a67 6a6b 6a6f 6a72 6a76 6a78 6a7c 6a80
6a83 6a87 6a8a 6a8e 6a91 6a92 6a97 6a9a
6a9e 6aa2 6aa5 6aa6 6aa8 6aab 6aae 6aaf
6ab4 1 6ab7 6abc 6ac0 6ac4 6ac8 6acc
6ad0 6ad4 6ad8 6adc 6ae0 6ae4 6ae8 6aec
6af0 6af4 6af8 6afc 6b00 6b04 6b08 6b0c
6b10 6b14 6b18 6b1c 6b20 6b24 6b30 6b34
6b38 6b3b 6b3f 6b43 6b45 1 6b49 6b4d
6b51 6b54 6b58 6b5c 6b60 6b64 6b67 6b6b
6b6f 6b72 6b75 6b7a 6b7d 6b80 6b83 6b84
6b89 6b8a 1 6b8c 6b91 6b95 6b99 6b9c
6ba1 6ba6 6ba9 6bad 6bae 6bb3 6bb6 6bbb
6bbc 6bc1 6bc4 6bc9 6bca 6bcf 6bd2 6bd6
6bd7 6bdc 6bdf 6be4 6be5 6bea 6bed 6bf1
6bf5 6bf8 6bfb 6bfc 6bfe 6bff 6c04 6c05
6c0a 6c0c 6c10 6c13 6c15 6c19 6c1b 6c27
6c29 6c2b 6c2c 6c31 6c35 6c37 6c43 6c45
6c47 6c4b 6c4f 6c52 6c54 6c58 6c5c 6c60
6c64 6c68 6c6c 6c70 6c74 6c78 6c7c 6c80
6c84 6c88 6c8c 6c90 6c94 6c98 6c9c 6ca0
6ca4 6ca8 6cac 6cb0 6cb4 6cb8 6cbc 6cc0
6cc4 6cd0 6cd4 6cd8 6cdb 6cdf 6ce3 6ce5
1 6ce9 6ced 6cf1 6cf4 6cf8 6cfc 6d00
6d04 6d07 6d0b 6d0f 6d12 6d15 6d1a 6d1d
6d20 6d23 6d24 6d29 6d2a 1 6d2c 6d31
6d35 6d39 6d3c 6d41 6d46 6d49 6d4d 6d4e
6d53 6d56 6d5b 6d5c 6d61 6d64 6d69 6d6a
6d6f 6d72 6d76 6d77 6d7c 6d7f 6d84 6d85
6d8a 6d8d 6d91 6d95 6d98 6d9b 6d9c 6d9e
6d9f 6da4 6da5 6daa 6dac 6db0 6db3 6db5
6db9 6dbb 6dc7 6dc9 6dcb 6dcc 6dd1 6dd5
6dd7 6de3 6de5 6de7 6deb 6def 6df2 6df4
6df8 6dfc 6dff 6e02 6e03 6e05 6e08 6e0d
6e0e 6e13 6e17 6e1b 6e1f 6e23 6e27 6e2b
6e2f 6e33 6e37 6e3b 6e3f 6e43 6e47 6e4b
6e4f 6e53 6e57 6e5b 6e5f 6e63 6e67 6e6b
6e6f 6e73 6e77 6e7b 6e7f 6e8b 6e8f 6e93
6e96 6e9a 6e9e 6ea0 1 6ea4 6ea8 6eac
6eaf 6eb3 6eb7 6ebb 6ebf 6ec2 6ec6 6eca
6ecd 6ed0 6ed5 6ed8 6edb 6ede 6edf 6ee4
6ee5 1 6ee7 6eec 6ef0 6ef4 6ef7 6efc
6f01 6f04 6f08 6f09 6f0e 6f11 6f16 6f17
6f1c 6f1f 6f24 6f25 6f2a 6f2d 6f31 6f32
6f37 6f3a 6f3f 6f40 6f45 6f48 6f4c 6f50
6f53 6f56 6f57 6f59 6f5a 6f5f 6f60 6f65
6f67 6f6b 6f6e 6f70 6f74 6f76 6f82 6f84
6f86 6f87 6f8c 6f90 6f92 6f9e 6fa0 6fa4
6fa8 6fab 6faf 6fb2 6fb6 6fb9 6fba 6fbf
6fc2 6fc6 6fca 6fcd 6fce 6fd0 6fd3 6fd6
6fd7 6fdc 6fdf 6fe3 6fe7 6fea 6feb 6fed
6ff0 6ff3 6ff4 6ff9 1 6ffc 7001 7005
7009 700d 7011 7015 7019 701d 7021 7025
7029 702d 7031 7035 7039 703d 7041 7045
7049 704d 7051 7055 7059 7065 7069 706d
7070 7074 7078 707a 1 707e 7082 7086
7089 708d 7091 7095 7099 709c 70a0 70a4
70a7 70aa 70af 70b2 70b5 70b8 70b9 70be
70bf 1 70c1 70c6 70ca 70ce 70d1 70d6
70db 70de 70e2 70e3 70e8 70eb 70f0 70f1
70f6 70f9 70fe 70ff 7104 7107 710b 710c
7111 7114 7119 711a 711f 7122 7126 712a
712d 7130 7131 7133 7134 7139 713a 713f
7141 7145 7148 714a 714e 7150 715c 715e
7160 7161 7166 716a 716c 7178 717a 717c
7180 7183 7187 7189 718b 718f 7193 7196
719a 719c 71a0 71a4 71a7 71ab 71ae 71b2
71b5 71b6 71bb 71be 71c2 71c6 71ca 71ce
71d2 71d6 71da 71de 71e2 71e6 71ea 71ee
71f2 71f6 71fa 71fe 7202 7206 720a 720e
7212 7216 721a 721e 7222 722e 7232 7236
7239 723d 7241 7243 1 7247 724b 724f
7252 7256 725a 725e 7262 7265 7269 726d
7270 7273 7278 727b 727e 7281 7282 7287
7288 1 728a 728f 7293 7297 729a 729f
72a4 72a7 72ab 72ac 72b1 72b4 72b9 72ba
72bf 72c2 72c7 72c8 72cd 72d0 72d4 72d5
72da 72dd 72e2 72e3 72e8 72eb 72ef 72f3
72f6 72f9 72fa 72fc 72fd 7302 7303 7308
730a 730e 7311 7313 7317 7319 7325 7327
7329 732a 732f 7333 7335 7341 7343 7345
7349 734d 7350 7352 7356 735a 735e 7362
7366 736a 736e 7372 7376 737a 737e 7382
7386 738a 738e 7392 7396 739a 739e 73a2
73a6 73aa 73ae 73b2 73b6 73c2 73c6 73ca
73cd 73d1 73d5 73d7 1 73db 73df 73e3
73e6 73ea 73ee 73f2 73f6 73f9 73fd 7401
7404 7407 740c 740f 7412 7415 7416 741b
741c 1 741e 7423 7427 742b 742e 7433
7438 743b 743f 7440 7445 7448 744d 744e
7453 7456 745b 745c 7461 7464 7468 7469
746e 7471 7476 7477 747c 747f 7483 7487
748a 748d 748e 7490 7491 7496 7497 749c
749e 74a2 74a5 74a7 74ab 74ad 74b9 74bb
74bd 74be 74c3 74c7 74c9 74d5 74d7 74d9
74dd 74e1 74e4 74e6 74ea 74ee 74f1 74f5
74f9 74fc 7500 7503 7507 750a 750b 7510
7513 7517 751b 751e 751f 7521 7524 7527
7528 752d 7531 7534 7538 753a 753e 7541
7542 7547 754a 754e 7551 7554 7555 755a
755e 7561 7565 7569 756d 7571 7575 7579
757d 7581 7585 7589 758d 7591 7595 7599
759d 75a1 75ad 75b1 75b5 75b8 75bc 75c0
75c2 1 75c6 75ca 75ce 75d1 75d5 75d9
75dd 75e1 75e4 75e8 75ec 75ef 75f2 75f7
75fa 75fd 7600 7601 7606 7607 1 7609
760e 7612 7616 7619 761e 7623 7626 762a
762b 7630 7633 7638 7639 763e 7641 7646
7647 764c 764f 7653 7654 7659 765c 7661
7662 7667 766a 766e 7672 7675 7678 7679
767b 767c 7681 7682 7687 7689 768d 7690
7692 7696 7698 76a4 76a6 76a8 76a9 76ae
76b2 76b4 76c0 76c2 76c4 76c8 76cb 76cf
76d3 76d7 76db 76df 76e3 76e7 76eb 76ef
76f3 76f7 76fb 76ff 770b 770f 7713 7716
771a 771e 7720 1 7724 7728 772c 772f
7733 7737 773b 773f 7742 7746 774a 774d
7750 7755 7758 775b 775e 775f 7764 7765
1 7767 776c 7770 7774 7777 777c 7781
7784 7788 7789 778e 7791 7796 7797 779c
779f 77a4 77a5 77aa 77ad 77b1 77b2 77b7
77ba 77bf 77c0 77c5 77c8 77cc 77d0 77d3
77d6 77d7 77d9 77da 77df 77e0 77e5 77e7
77eb 77ee 77f0 77f4 77f6 7802 7804 7806
7807 780c 7810 7812 781e 7820 7822 7826
782a 782d 7831 7835 7838 7839 783b 783f
7842 7846 7849 784a 784c 784d 7852 7856
785a 785e 7861 7862 7864 7867 786a 786b
7870 7874 7878 787e 7880 7884 7887 7889
788d 7890 7894 7897 789b 789d 78a1 78a5
78a8 78aa 78ae 78b2 78b6 78b9 78ba 78bc
78bf 78c2 78c3 78c8 78cc 78d0 78d6 78d8
78dc 78e0 78e3 78e7 78eb 78ef 78f3 78f6
78fa 78fe 7902 7906 790a 790e 7912 7916
791a 791e 7922 792e 7932 7936 7939 793d
7941 7943 1 7947 794b 794f 7952 7956
795a 795e 7962 7965 7969 796d 7970 7973
7978 797b 797e 7981 7982 7987 7988 1
798a 798f 7993 7997 799a 799f 79a4 79a7
79ab 79ac 79b1 79b4 79b9 79ba 79bf 79c2
79c7 79c8 79cd 79d0 79d4 79d5 79da 79dd
79e2 79e3 79e8 79eb 79ef 79f3 79f6 79f9
79fa 79fc 79fd 7a02 7a03 7a08 7a0a 7a0e
7a11 7a13 7a17 7a19 7a25 7a27 7a29 7a2a
7a2f 7a33 7a35 7a41 7a43 7a47 7a4b 7a4f
7a53 7a57 7a5b 7a5f 7a63 7a67 7a6b 7a77
7a7b 7a7f 7a82 7a86 7a8a 7a8c 1 7a90
7a94 7a98 7a9b 7a9f 7aa3 7aa7 7aab 7aae
7ab2 7ab6 7ab9 7abc 7ac1 7ac4 7ac7 7aca
7acb 7ad0 7ad1 1 7ad3 7ad8 7adc 7ae0
7ae3 7ae8 7aed 7af0 7af4 7af5 7afa 7afd
7b02 7b03 7b08 7b0b 7b10 7b11 7b16 7b19
7b1d 7b1e 7b23 7b26 7b2b 7b2c 7b31 7b34
7b38 7b3c 7b3f 7b42 7b43 7b45 7b46 7b4b
7b4c 7b51 7b53 7b57 7b5a 7b5c 7b60 7b62
7b6e 7b70 7b72 7b73 7b78 7b7c 7b7e 7b8a
7b8c 7b90 7b93 7b97 7b9b 7b9f 7ba3 7ba7
7bab 7bae 7baf 7bb1 7bb4 7bb7 7bb8 7bbd
7bc1 7bc4 7bc8 7bca 7bce 7bd1 7bd5 7bd9
7bdd 7be1 7be5 7be9 7bed 7bf1 7bf5 7bf9
7bfd 7c01 7c05 7c09 7c0d 7c11 7c15 7c19
7c1d 7c21 7c25 7c29 7c2d 7c31 7c35 7c39
7c3d 7c41 7c45 7c49 7c4c 7c4f 7c52 7c55
7c56 7c58 7c5c 7c60 7c63 7c66 7c67 7c6c
7c70 7c74 7c77 7c78 7c7a 7c7d 7c80 7c81
7c86 7c8a 7c8e 7c92 7c96 7ca2 7ca6 7cab
7caf 7cb2 7cb3 7cb8 7cbc 7cc0 7cc3 7cc6
7cca 7ccc 7cd0 7cd4 7cd7 7cda 7cde 7ce0
7ce4 7ce8 7ceb 7ced 1 7cf1 7cf5 7cf9
7cfc 7d00 7d04 7d08 7d0c 7d0f 7d13 7d17
7d1a 7d1d 7d22 7d25 7d28 7d2b 7d2c 7d31
7d32 1 7d34 7d39 7d3d 7d41 7d44 7d49
7d4e 7d51 7d55 7d56 7d5b 7d5e 7d63 7d64
7d69 7d6c 7d71 7d72 7d77 7d7a 7d7e 7d7f
7d84 7d87 7d8c 7d8d 7d92 7d95 7d99 7d9d
7da0 7da3 7da4 7da6 7da7 7dac 7dad 7db2
7db4 7db8 7dbb 7dbd 7dc1 7dc3 7dcf 7dd1
7dd3 7dd4 7dd9 7ddd 7ddf 7deb 7ded 7def
7df3 7df7 7dfb 7dff 7e0b 7e0f 7e14 7e18
7e1b 7e1c 7e21 7e25 7e29 7e2c 7e2f 7e33
7e35 7e39 7e3d 7e40 7e43 7e47 7e49 7e4d
7e51 7e54 7e56 1 7e5a 7e5e 7e62 7e65
7e69 7e6d 7e71 7e75 7e78 7e7c 7e80 7e83
7e86 7e8b 7e8e 7e91 7e94 7e95 7e9a 7e9b
1 7e9d 7ea2 7ea6 7eaa 7ead 7eb2 7eb7
7eba 7ebe 7ebf 7ec4 7ec7 7ecc 7ecd 7ed2
7ed5 7eda 7edb 7ee0 7ee3 7ee7 7ee8 7eed
7ef0 7ef5 7ef6 7efb 7efe 7f02 7f06 7f09
7f0c 7f0d 7f0f 7f10 7f15 7f16 7f1b 7f1d
7f21 7f24 7f26 7f2a 7f2c 7f38 7f3a 7f3c
7f3d 7f42 7f46 7f48 7f54 7f56 7f58 7f5c
7f60 7f63 7f65 7f69 7f6c 7f70 7f72 7f76
7f7a 7f7d 7f7e 7f80 7f83 7f86 7f87 7f8c
7f90 7f94 7f98 7f9c 7fa0 7fa4 7fa8 7fac
7faf 7fb2 7fb3 7fb5 7fb8 7fbd 7fbe 7fc3
7fc7 7fcb 7fcf 7fd2 7fd6 7fd8 7fdc 7fe0
7fe4 7fe7 7fe8 7fea 7fee 7ff0 7ff4 7ff8
7ffb 7fff 8003 8007 800b 800f 8013 8017
801b 801f 8023 8027 802b 802f 8033 8037
803b 803f 8043 8047 804b 804f 8053 8057
805b 805f 8063 8067 806b 806f 8073 8076
8079 807c 807f 8080 8082 8086 808a 808d
8090 8091 8096 809a 809e 80a2 80a6 80b2
80b6 80bb 80bf 80c2 80c3 80c8 80cc 80d0
80d3 80d6 80da 80dc 80e0 80e4 80e7 80ea
80ee 80f0 80f4 80f8 80fb 80fd 1 8101
8105 8109 810c 8110 8114 8118 811c 811f
8123 8127 812a 812d 8132 8135 8138 813b
813c 8141 8142 1 8144 8149 814d 8151
8154 8159 815e 8161 8165 8166 816b 816e
8173 8174 8179 817c 8181 8182 8187 818a
818e 818f 8194 8197 819c 819d 81a2 81a5
81a9 81ad 81b0 81b3 81b4 81b6 81b7 81bc
81bd 81c2 81c4 81c8 81cb 81cd 81d1 81d3
81df 81e1 81e3 81e4 81e9 81ed 81ef 81fb
81fd 81ff 8203 8206 8208 820c 8210 8213
8217 821b 821f 8222 8223 8225 8228 822b
822c 8231 8235 823d 823f 8240 8243 8245
8249 8250 8252 8256 8259 825b 825f 8263
8266 826a 826d 8270 8271 8276 8279 827d
8281 8284 8285 8287 828a 828d 828e 8293
1 8296 829b 829f 82a3 82a6 82a7 82a9
82ac 82af 82b0 82b5 82b9 82bd 82c1 82cd
82d1 82d6 82da 82dd 82de 82e3 82e7 82eb
82ee 82f1 82f5 82f7 82fb 82ff 8302 8305
8309 830b 830f 8313 8316 8318 1 831c
8320 8324 8327 832b 832f 8333 8337 833a
833e 8342 8345 8348 834d 8350 8353 8356
8357 835c 835d 1 835f 8364 8368 836c
836f 8374 8379 837c 8380 8381 8386 8389
838e 838f 8394 8397 839c 839d 83a2 83a5
83a9 83aa 83af 83b2 83b7 83b8 83bd 83c0
83c4 83c8 83cb 83ce 83cf 83d1 83d2 83d7
83d8 83dd 83df 83e3 83e6 83e8 83ec 83ee
83fa 83fc 83fe 83ff 8404 8408 840a 8416
8418 841a 841e 8422 8426 842a 842e 8432
8436 8442 8446 844b 844f 8452 8453 8458
845c 8460 8463 8466 846a 846c 8470 8474
8477 847a 847e 8480 8484 8488 848b 848d
1 8491 8495 8499 849c 84a0 84a4 84a8
84ac 84af 84b3 84b7 84ba 84bd 84c2 84c5
84c8 84cb 84cc 84d1 84d2 1 84d4 84d9
84dd 84e1 84e4 84e9 84ee 84f1 84f5 84f6
84fb 84fe 8503 8504 8509 850c 8511 8512
8517 851a 851e 851f 8524 8527 852c 852d
8532 8535 8539 853d 8540 8543 8544 8546
8547 854c 854d 8552 8554 8558 855b 855d
8561 8563 856f 8571 8573 8574 8579 857d
857f 858b 858d 858f 8593 8597 859a 859e
85a1 85a4 85a5 85aa 85ae 85b2 85b5 85b9
85bd 85c0 85c3 85c8 85cb 85ce 85d1 85d2
85d7 85d8 1 85da 85df 85e3 85e7 85ea
85ef 85f4 85f7 85fb 85fc 8601 8604 8609
860a 860f 8612 8617 8618 861d 8620 8624
8628 862c 8630 8633 8634 8636 863b 863c
863e 863f 8644 8647 864c 864d 8652 8655
865a 865b 8660 8663 8667 8668 866d 8670
8675 8676 867b 867c 8681 8683 8687 868a
868e 8692 8695 8699 869d 86a0 86a3 86a8
86ab 86ae 86b1 86b2 86b7 86b8 1 86ba
86bf 86c3 86c7 86ca 86cf 86d4 86d7 86db
86dc 86e1 86e2 86e7 86e9 86ed 86f0 86f4
86f8 86fb 86ff 8703 8706 870a 870e 870f
8714 8718 871a 871e 8722 8725 8729 872c
872d 8732 8736 873a 873d 8741 8745 8748
874b 8750 8753 8756 8759 875a 875f 8760
1 8762 8767 876b 876f 8772 8777 877c
877f 8783 8784 8789 878c 8791 8792 8797
879a 879f 87a0 87a5 87a8 87ac 87b0 87b4
87b8 87bb 87bc 87be 87c3 87c4 87c6 87c7
87cc 87cf 87d4 87d5 87da 87dd 87e2 87e3
87e8 87eb 87ef 87f0 87f5 87f8 87fd 87fe
8803 8804 8809 880b 880f 8812 8816 881a
881d 8821 8825 8828 882b 8830 8833 8836
8839 883a 883f 8840 1 8842 8847 884b
884f 8852 8857 885c 885f 8863 8864 8869
886a 886f 8871 8875 8878 887c 8880 8883
8887 888b 888e 8892 8896 8897 889c 88a0
88a2 88a6 88aa 88ae 88b1 88b5 88b8 88b9
88be 88c2 88c6 88c9 88cd 88d1 88d4 88d7
88dc 88df 88e2 88e5 88e6 88eb 88ec 1
88ee 88f3 88f7 88fb 88fe 8903 8908 890b
890f 8910 8915 8918 891d 891e 8923 8926
892b 892c 8931 8934 8938 893c 8940 8944
8947 8948 894a 894f 8950 8952 8953 8958
895b 8960 8961 8966 8969 896e 896f 8974
8977 897b 897c 8981 8984 8989 898a 898f
8990 8995 8997 899b 899e 89a2 89a6 89a9
89ad 89b1 89b4 89b7 89bc 89bf 89c2 89c5
89c6 89cb 89cc 1 89ce 89d3 89d7 89db
89de 89e3 89e8 89eb 89ef 89f0 89f5 89f6
89fb 89fd 8a01 8a04 8a08 8a0c 8a0f 8a13
8a17 8a1a 8a1e 8a22 8a23 8a28 8a2a 8a2e
8a32 8a36 8a39 8a3d 8a41 8a44 8a47 8a4c
8a4f 8a52 8a55 8a56 8a5b 8a5c 1 8a5e
8a63 8a67 8a6b 8a6e 8a73 8a78 8a7b 8a7f
8a80 8a85 8a88 8a8d 8a8e 8a93 8a96 8a9b
8a9c 8aa1 8aa4 8aa8 8aac 8ab0 8ab4 8ab7
8ab8 8aba 8abf 8ac0 8ac2 8ac3 8ac8 8acb
8ad0 8ad1 8ad6 8ad9 8ade 8adf 8ae4 8ae7
8aeb 8aec 8af1 8af4 8af9 8afa 8aff 8b00
8b05 8b07 8b0b 8b0e 8b12 8b16 8b19 8b1d
8b21 8b24 8b27 8b2c 8b2f 8b32 8b35 8b36
8b3b 8b3c 1 8b3e 8b43 8b47 8b4b 8b4e
8b53 8b58 8b5b 8b5f 8b60 8b65 8b66 8b6b
8b6d 8b71 8b74 8b78 8b7c 8b7f 8b83 8b87
8b8a 8b8e 8b92 8b93 8b98 8b9a 8b9e 8ba2
8ba5 8ba7 8bab 8bae 8bb2 8bb6 8bba 8bbb
8bbd 8bc0 8bc1 8bc3 8bc6 8bc9 8bca 8bcf
8bd2 8bd6 8bda 8bde 8bdf 8be1 8be4 8be5
8be7 8bea 8bed 8bee 8bf3 1 8bf6 8bfb
8bff 8c03 8c08 8c0d 8c11 8c15 8c19 8c1c
8c1f 8c23 8c27 8c2c 8c2f 8c34 8c35 8c3a
8c3d 8c42 8c43 8c48 8c4b 8c50 8c51 8c56
8c59 8c5e 8c5f 8c64 8c67 8c6c 8c6d 8c72
8c75 8c79 8c7a 8c7f 8c82 8c87 8c88 8c8d
8c90 8c95 8c96 8c9b 8c9e 8ca2 8ca3 8ca8
8cab 8cb0 8cb1 8cb6 8cb9 8cbd 8cbe 8cc3
8cc6 8ccb 8ccc 8cd1 8cd5 8cd9 8cdd 8ce1
8ce6 8cea 8cee 8cf3 8cf7 8cfa 8cfb 8d00
8d04 8d08 8d0b 8d0e 8d12 8d14 8d18 8d1c
8d1f 8d22 8d26 8d28 8d2c 8d30 8d33 8d35
1 8d39 8d3d 8d41 8d44 8d48 8d4c 8d50
8d54 8d57 8d5b 8d5f 8d62 8d65 8d6a 8d6d
8d70 8d73 8d74 8d79 8d7a 1 8d7c 8d81
8d85 8d89 8d8c 8d91 8d96 8d99 8d9d 8d9e
8da3 8da6 8dab 8dac 8db1 8db4 8db9 8dba
8dbf 8dc2 8dc6 8dc7 8dcc 8dcf 8dd4 8dd5
8dda 8ddd 8de1 8de5 8de8 8deb 8dec 8dee
8def 8df4 8df5 8dfa 8dfe 8e02 8e05 8e0a
8e0f 8e12 8e16 8e17 8e1c 8e1d 8e22 8e24
8e28 8e2b 8e2d 8e31 8e33 8e3f 8e41 8e43
8e44 8e49 8e4d 8e4f 8e5b 8e5d 8e61 8e65
8e6a 8e6f 8e73 8e77 8e7b 8e7e 8e81 8e85
8e89 8e8e 8e91 8e96 8e97 8e9c 8e9f 8ea4
8ea5 8eaa 8ead 8eb2 8eb3 8eb8 8ebb 8ec0
8ec1 8ec6 8ec9 8ece 8ecf 8ed4 8ed7 8edb
8edc 8ee1 8ee4 8ee9 8eea 8eef 8ef2 8ef7
8ef8 8efd 8f00 8f04 8f05 8f0a 8f0d 8f12
8f13 8f18 8f1b 8f1f 8f20 8f25 8f28 8f2d
8f2e 8f33 8f37 8f3b 8f3f 8f43 8f48 8f4c
8f50 8f55 8f59 8f5c 8f5d 8f62 8f66 8f6a
8f6d 8f70 8f74 8f76 8f7a 8f7e 8f81 8f84
8f88 8f8a 8f8e 8f92 8f95 8f97 1 8f9b
8f9f 8fa3 8fa6 8faa 8fae 8fb2 8fb6 8fb9
8fbd 8fc1 8fc4 8fc7 8fcc 8fcf 8fd2 8fd5
8fd6 8fdb 8fdc 1 8fde 8fe3 8fe7 8feb
8fee 8ff3 8ff8 8ffb 8fff 9000 9005 9008
900d 900e 9013 9016 901b 901c 9021 9024
9028 9029 902e 9031 9036 9037 903c 903f
9043 9047 904a 904d 904e 9050 9051 9056
9057 905c 9060 9064 9067 906c 9071 9074
9078 9079 907e 907f 9084 9086 908a 908d
908f 9093 9095 90a1 90a3 90a5 90a6 90ab
90af 90b1 90bd 90bf 90c3 90c7 90ca 90ce
90cf 90d4 90d8 90dc 90e1 90e4 90e9 90ea
90ef 90f2 90f7 90f8 90fd 9100 9105 9106
910b 910e 9113 9114 9119 911c 9121 9122
9127 912a 912f 9130 9135 9138 913d 913e
9143 9146 914b 914c 9151 9154 9159 915a
915f 9162 9167 9168 916d 9170 9175 9176
917b 917e 9183 9184 9189 918c 9190 9191
9196 9199 919e 919f 91a4 91a7 91ac 91ad
91b2 91b5 91b9 91ba 91bf 91c2 91c7 91c8
91cd 91d0 91d5 91d6 91db 91de 91e3 91e4
91e9 91ec 91f0 91f1 91f6 91f9 91fe 91ff
9204 9207 920c 920d 9212 9215 921a 921b
9220 9223 9228 9229 922e 9231 9236 9237
923c 923f 9244 9245 924a 924d 9252 9253
9258 925b 9260 9261 9266 9269 926e 926f
9274 9277 927b 927c 9281 9284 9289 928a
928f 9292 9297 9298 929d 92a0 92a5 92a6
92ab 92ae 92b3 92b4 92b9 92bc 92c1 92c2
92c7 92ca 92ce 92cf 92d4 92d7 92dc 92dd
92e2 92e5 92ea 92eb 92f0 92f4 92f8 92fc
9300 9305 9309 930d 9312 9316 9319 931a
931f 9323 9327 932a 932d 9331 9333 9337
933b 933e 9341 9345 9347 934b 934f 9352
9354 1 9358 935c 9360 9363 9367 936b
936f 9373 9376 937a 937e 9381 9384 9389
938c 938f 9392 9393 9398 9399 1 939b
93a0 93a4 93a8 93ab 93b0 93b5 93b8 93bc
93bd 93c2 93c5 93ca 93cb 93d0 93d3 93d8
93d9 93de 93e1 93e5 93e6 93eb 93ee 93f3
93f4 93f9 93fc 9400 9404 9407 940a 940b
940d 940e 9413 9414 9419 941d 9421 9424
9429 942e 9431 9435 9436 943b 943c 9441
9443 9447 944a 944c 9450 9452 945e 9460
9462 9463 9468 946c 946e 947a 947c 9480
9485 9488 948d 948e 9493 9496 949b 949c
94a1 94a4 94a9 94aa 94af 94b2 94b6 94ba
94be 94c1 94c2 94c4 94c5 94c7 94c8 94cd
94d0 94d5 94d6 94db 94de 94e3 94e4 94e9
94ec 94f0 94f4 94f8 94fb 94fc 94fe 94ff
9501 9502 9507 950a 950f 9510 9515 9518
951d 951e 9523 9526 952b 952c 9531 9534
9539 953a 953f 9542 9547 9548 954d 9550
9555 9556 955b 955e 9563 9564 9569 956c
9571 9572 9577 957a 957f 9580 9585 9588
958c 9590 9594 9597 9598 959a 959b 959d
959e 95a3 95a6 95ab 95ac 95b1 95b4 95b9
95ba 95bf 95c2 95c6 95ca 95ce 95d1 95d2
95d4 95d5 95d7 95d8 95dd 95e0 95e5 95e6
95eb 95ee 95f3 95f4 95f9 95fc 9601 9602
9607 960a 960f 9610 9615 9618 961d 961e
9623 9627 962b 962d 9631 9635 9639 963a
963c 963f 9640 9642 9645 9648 9649 964e
9652 9656 965b 9660 9664 9668 966c 966f
9672 9676 967a 967f 9682 9687 9688 968d
9690 9695 9696 969b 969e 96a3 96a4 96a9
96ac 96b1 96b2 96b7 96ba 96bf 96c0 96c5
96c8 96cc 96cd 96d2 96d5 96da 96db 96e0
96e3 96e8 96e9 96ee 96f1 96f5 96f6 96fb
96fe 9703 9704 9709 970d 9711 9715 9719
971e 9722 9726 972b 972f 9732 9733 9738
973c 9740 9743 9746 974a 974c 9750 9754
9757 975a 975e 9760 9764 9768 976b 976d
1 9771 9775 9779 977c 9780 9784 9788
978c 978f 9793 9797 979a 979d 97a2 97a5
97a8 97ab 97ac 97b1 97b2 1 97b4 97b9
97bd 97c1 97c4 97c9 97ce 97d1 97d5 97d6
97db 97de 97e3 97e4 97e9 97ec 97f1 97f2
97f7 97fa 97fe 97ff 9804 9807 980c 980d
9812 9815 9819 981d 9820 9823 9824 9826
9827 982c 982d 9832 9836 983a 983d 9842
9847 984a 984e 984f 9854 9855 985a 985c
9860 9863 9865 9869 986b 9877 9879 987b
987c 9881 9885 9887 9893 9895 9899 989d
98a2 98a7 98ab 98af 98b3 98b6 98b9 98bd
98c1 98c6 98c9 98ce 98cf 98d4 98d7 98dc
98dd 98e2 98e5 98ea 98eb 98f0 98f3 98f8
98f9 98fe 9901 9906 9907 990c 990f 9913
9914 9919 991c 9921 9922 9927 992a 992e
992f 9934 9937 993c 993d 9942 9946 994a
994e 9952 9957 995b 995f 9964 9968 996b
996c 9971 9975 9979 997c 997f 9983 9985
9989 998d 9990 9993 9997 9999 999d 99a1
99a4 99a6 1 99aa 99ae 99b2 99b5 99b9
99bd 99c1 99c5 99c8 99cc 99d0 99d3 99d6
99db 99de 99e1 99e4 99e5 99ea 99eb 1
99ed 99f2 99f6 99fa 99fd 9a02 9a07 9a0a
9a0e 9a0f 9a14 9a17 9a1c 9a1d 9a22 9a25
9a2a 9a2b 9a30 9a33 9a37 9a38 9a3d 9a40
9a45 9a46 9a4b 9a4e 9a52 9a56 9a59 9a5c
9a5d 9a5f 9a60 9a65 9a66 9a6b 9a6f 9a73
9a76 9a7b 9a80 9a83 9a87 9a88 9a8d 9a8e
9a93 9a95 9a99 9a9c 9a9e 9aa2 9aa4 9ab0
9ab2 9ab4 9ab5 9aba 9abe 9ac0 9acc 9ace
9ad2 9ad6 9ad9 9add 9ade 9ae3 9ae7 9aeb
9af0 9af3 9af8 9af9 9afe 9b01 9b06 9b07
9b0c 9b0f 9b14 9b15 9b1a 9b1d 9b22 9b23
9b28 9b2b 9b30 9b31 9b36 9b39 9b3e 9b3f
9b44 9b47 9b4c 9b4d 9b52 9b55 9b5a 9b5b
9b60 9b63 9b68 9b69 9b6e 9b71 9b75 9b76
9b7b 9b7e 9b83 9b84 9b89 9b8c 9b91 9b92
9b97 9b9a 9b9e 9b9f 9ba4 9ba7 9bac 9bad
9bb2 9bb5 9bba 9bbb 9bc0 9bc3 9bc8 9bc9
9bce 9bd1 9bd5 9bd6 9bdb 9bde 9be3 9be4
9be9 9bed 9bf1 9bf5 9bf9 9bfe 9c02 9c06
9c0b 9c0f 9c12 9c13 9c18 9c1c 9c20 9c23
9c26 9c2a 9c2c 9c30 9c34 9c37 9c3a 9c3e
9c40 9c44 9c48 9c4b 9c4d 1 9c51 9c55
9c59 9c5c 9c60 9c64 9c68 9c6c 9c6f 9c73
9c77 9c7a 9c7d 9c82 9c85 9c88 9c8b 9c8c
9c91 9c92 1 9c94 9c99 9c9d 9ca1 9ca4
9ca9 9cae 9cb1 9cb5 9cb6 9cbb 9cbe 9cc3
9cc4 9cc9 9ccc 9cd1 9cd2 9cd7 9cda 9cde
9cdf 9ce4 9ce7 9cec 9ced 9cf2 9cf5 9cf9
9cfd 9d00 9d03 9d04 9d06 9d07 9d0c 9d0d
9d12 9d16 9d1a 9d1d 9d22 9d27 9d2a 9d2e
9d2f 9d34 9d35 9d3a 9d3c 9d40 9d43 9d45
9d49 9d4b 9d57 9d59 9d5b 9d5c 9d61 9d65
9d67 9d73 9d75 9d79 9d7e 9d81 9d86 9d87
9d8c 9d8f 9d94 9d95 9d9a 9d9d 9da2 9da3
9da8 9dab 9daf 9db3 9db7 9dba 9dbb 9dbd
9dbe 9dc0 9dc1 9dc6 9dc9 9dce 9dcf 9dd4
9dd7 9ddb 9ddf 9de3 9de6 9de7 9de9 9dea
9dec 9ded 9df2 9df5 9dfa 9dfb 9e00 9e03
9e08 9e09 9e0e 9e11 9e16 9e17 9e1c 9e1f
9e24 9e25 9e2a 9e2d 9e32 9e33 9e38 9e3c
9e3e 9e42 9e46 9e4a 9e4f 9e54 9e58 9e5c
9e60 9e63 9e66 9e6a 9e6e 9e73 9e76 9e7b
9e7c 9e81 9e84 9e89 9e8a 9e8f 9e92 9e97
9e98 9e9d 9ea0 9ea5 9ea6 9eab 9eae 9eb3
9eb4 9eb9 9ebc 9ec1 9ec2 9ec7 9eca 9ece
9ecf 9ed4 9ed7 9edc 9edd 9ee2 9ee5 9eea
9eeb 9ef0 9ef3 9ef7 9ef8 9efd 9f00 9f05
9f06 9f0b 9f0e 9f13 9f14 9f19 9f1d 9f21
9f25 9f29 9f2e 9f32 9f36 9f3b 9f3f 9f42
9f43 9f48 9f4c 9f50 9f53 9f56 9f5a 9f5c
9f60 9f64 9f67 9f6a 9f6e 9f70 9f74 9f78
9f7b 9f7d 1 9f81 9f85 9f89 9f8c 9f90
9f94 9f98 9f9c 9f9f 9fa3 9fa7 9faa 9fad
9fb2 9fb5 9fb8 9fbb 9fbc 9fc1 9fc2 1
9fc4 9fc9 9fcd 9fd1 9fd4 9fd9 9fde 9fe1
9fe5 9fe6 9feb 9fee 9ff3 9ff4 9ff9 9ffc
a001 a002 a007 a00a a00e a00f a014 a017
a01c a01d a022 a025 a029 a02d a030 a033
a034 a036 a037 a03c a03d a042 a046 a04a
a04d a052 a057 a05a a05e a05f a064 a065
a06a a06c a070 a073 a075 a079 a07b a087
a089 a08b a08c a091 a095 a097 a0a3 a0a5
a0a9 a0ad a0b2 a0b7 a0bb a0bf a0c3 a0c6
a0c9 a0cd a0d1 a0d6 a0d9 a0de a0df a0e4
a0e7 a0ec a0ed a0f2 a0f5 a0fa a0fb a100
a103 a108 a109 a10e a111 a116 a117 a11c
a11f a123 a124 a129 a12c a131 a132 a137
a13a a13e a13f a144 a147 a14c a14d a152
a156 a15a a15e a162 a167 a16b a16f a174
a178 a17b a17c a181 a185 a189 a18c a18f
a193 a195 a199 a19d a1a0 a1a3 a1a7 a1a9
a1ad a1b1 a1b4 a1b6 1 a1ba a1be a1c2
a1c5 a1c9 a1cd a1d1 a1d5 a1d8 a1dc a1e0
a1e3 a1e6 a1eb a1ee a1f1 a1f4 a1f5 a1fa
a1fb 1 a1fd a202 a206 a20a a20d a212
a217 a21a a21e a21f a224 a227 a22c a22d
a232 a235 a23a a23b a240 a243 a247 a248
a24d a250 a255 a256 a25b a25e a262 a266
a269 a26c a26d a26f a270 a275 a276 a27b
a27f a283 a286 a28b a290 a293 a297 a298
a29d a29e a2a3 a2a5 a2a9 a2ac a2ae a2b2
a2b4 a2c0 a2c2 a2c4 a2c5 a2ca a2ce a2d0
a2dc a2de a2e2 a2e6 a2e9 a2ed a2ee a2f3
a2f7 a2fb a300 a303 a308 a309 a30e a311
a316 a317 a31c a31f a324 a325 a32a a32d
a332 a333 a338 a33b a340 a341 a346 a349
a34e a34f a354 a357 a35c a35d a362 a365
a36a a36b a370 a373 a378 a379 a37e a381
a385 a386 a38b a38e a393 a394 a399 a39c
a3a1 a3a2 a3a7 a3aa a3af a3b0 a3b5 a3b8
a3bd a3be a3c3 a3c6 a3ca a3cb a3d0 a3d3
a3d8 a3d9 a3de a3e2 a3e6 a3ea a3ee a3f3
a3f7 a3fb a400 a404 a407 a408 a40d a411
a415 a418 a41b a41f a421 a425 a429 a42c
a42f a433 a435 a439 a43d a440 a442 1
a446 a44a a44e a451 a455 a459 a45d a461
a464 a468 a46c a46f a472 a477 a47a a47d
a480 a481 a486 a487 1 a489 a48e a492
a496 a499 a49e a4a3 a4a6 a4aa a4ab a4b0
a4b3 a4b8 a4b9 a4be a4c1 a4c6 a4c7 a4cc
a4cf a4d3 a4d4 a4d9 a4dc a4e1 a4e2 a4e7
a4ea a4ee a4f2 a4f5 a4f8 a4f9 a4fb a4fc
a501 a502 a507 a50b a50f a512 a517 a51c
a51f a523 a524 a529 a52a a52f a531 a535
a538 a53a a53e a540 a54c a54e a550 a551
a556 a55a a55c a568 a56a a56e a573 a576
a57b a57c a581 a584 a589 a58a a58f a592
a597 a598 a59d a5a0 a5a4 a5a8 a5ac a5af
a5b0 a5b2 a5b3 a5b5 a5b6 a5bb a5be a5c3
a5c4 a5c9 a5cc a5d1 a5d2 a5d7 a5da a5de
a5e2 a5e6 a5e9 a5ea a5ec a5ed a5ef a5f0
a5f5 a5f8 a5fd a5fe a603 a606 a60b a60c
a611 a614 a619 a61a a61f a622 a627 a628
a62d a630 a635 a636 a63b a63f a641 a645
a649 a64c a650 a654 a657 a65b a65f a662
a665 a66a a66d a670 a673 a674 a679 a67a
1 a67c a681 a685 a689 a68c a691 a696
a699 a69d a69e a6a3 a6a4 a6a9 a6ab a6af
a6b2 a6b6 a6ba a6bd a6c1 a6c5 a6c8 a6cb
a6d0 a6d3 a6d6 a6d9 a6da a6df a6e0 1
a6e2 a6e7 a6eb a6ef a6f2 a6f7 a6fc a6ff
a703 a704 a709 a70a a70f a711 a715 a718
a71c a720 a724 a727 a72b a72c a72e a732
a734 a738 a73c a73f a743 a747 a74a a74e
a752 a755 a758 a75d a760 a763 a766 a767
a76c a76d 1 a76f a774 a778 a77c a77f
a784 a789 a78c a790 a791 a796 a797 a79c
a7a0 a7a4 a7a7 a7ac a7b1 a7b4 a7b8 a7bc
a7bf a7c0 a7c5 a7c8 a7cd a7ce a7d3 a7d6
a7da a7de a7e1 a7e2 a7e7 a7e8 a7ed a7ef
a7f3 a7f6 a7fa a7fe a802 a806 a80a a80e
a812 a816 a81a a826 a82b a82f a833 a837
a83b a83d a83e a843 1 a847 a84b a84f
a852 a856 a85a a85e a862 a865 a869 a86d
a870 a873 a878 a87b a87e a881 a882 a887
a888 1 a88a a88f a893 a897 a89a a89f
a8a4 a8a7 a8ab a8ac a8b1 a8b2 a8b7 a8bb
a8bf a8c2 a8c7 a8cc a8cf a8d3 a8d4 a8d9
a8dc a8e1 a8e2 a8e7 a8ea a8ee a8f2 a8f5
a8f8 a8f9 a8fb a8fc a901 a902 a907 a909
a90d a910 a914 a918 a91c a920 a924 a928
a92c a938 a93d a941 a945 a949 a94d a94f
a953 a955 a961 a963 a965 a966 a96b a96f
a971 a97d a981 a983 a984 a98d 
30ce
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 10 :3 6 e :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 14 1d
1c :2 14 :2 4 e 17 16 :2 e :2 4
f 18 17 :2 f :2 4 f 18 17
:2 f :2 4 d 16 15 :2 d :2 4 12
1b 1a :2 12 :2 4 11 1a 19 :2 11
:2 4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 :3 10 :2 4 :3 f :2 4 f
18 17 :2 f :2 4 10 19 18 :2 10
:2 4 10 19 18 :2 10 :2 4 f 18
17 :2 f :2 4 10 19 18 :2 10 :2 4
10 19 18 :2 10 :2 4 :2 c 1b c
:2 4 :2 e 1d e :2 4 :2 b 1a b
:2 4 :2 10 1f 10 :2 4 :2 a 19 a
:2 4 :2 b 1a b :2 4 :2 11 20 11
:2 4 :2 d 1c d :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 c 1b c
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 b 1a b
:2 4 :2 f 1e f :2 4 :2 12 21 12
:2 4 :2 f 1e f :2 4 :2 c 1b c
:2 4 :2 c 1b c :2 4 :2 f 1e f
:2 4 :2 11 20 11 :2 4 :2 11 20 11
:2 4 :2 16 25 16 :2 4 :2 16 25 16
:2 4 :2 b 1a b :2 4 d 16 15
:2 d :2 4 11 1a 19 :2 11 :2 4 :2 f
19 f :2 4 9 12 11 :2 9 :2 4
:2 17 26 17 :2 4 17 1c 1b :2 17
:2 4 18 1d 1c :2 18 :2 4 16 1f
1e :2 16 :2 4 :2 13 22 13 :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 14
1d 1c :2 14 :2 4 15 1e 1d :2 15
:2 4 :2 10 1f 10 :2 4 :2 f 1e f
:2 4 7 10 f :2 7 :2 4 :2 6 1e
6 :2 4 :2 7 1f 7 :2 4 :2 d 25
d :2 4 :2 8 20 8 :2 4 :3 d :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 53 59 5c :2 53 6a 7f 8
:2 6a d 10 :2 6a 17 1a :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
2c 2f :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 2d 30 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 34 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
2f :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 2e :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 34 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 34 :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 40 :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4e 4f :2 4b :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e :2 7 52 :3 4
14 :2 4 14 :2 4 13 :2 4 12 :2 4
10 :2 4 e :2 4 14 :2 4 f :2 4
12 :2 4 e :2 4 e :2 4 11 :2 4
11 :2 4 13 :2 4 11 :2 4 13 :2 4
17 :2 4 14 1d 26 2e :2 1d :2 14
:2 4 13 :2 4 12 :2 4 10 4 :4 8
7 a :2 14 26 :2 30 3c 3f 4e
51 52 :2 4e :2 26 :3 a :2 10 15 21
5f 62 :2 21 6f 72 :2 21 76 79
:2 21 83 86 8f 97 :2 a0 :2 8f b6
:2 86 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4e 51 52 :2 4e :2 26
:3 a :2 10 15 21 5f 62 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 46 :2 7 18
:2 4 :4 8 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b6 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 46
:2 7 1b :2 4 :4 9 8 2a 33 3a
:2 33 48 :2 2a 4b 4d :2 4b 29 :2 8
7 a :2 14 26 :2 30 3c 3f 4e
51 52 :2 4e :2 26 :3 a :2 10 15 21
5f 62 :2 21 6f 72 :2 21 76 79
:2 21 83 86 8f 97 :2 a0 :2 8f b1
:2 86 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4e 51 52 :2 4e :2 26
:3 a :2 10 15 21 5f 62 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 41 :2 7 52
:2 4 :4 9 8 29 32 39 :2 32 48
:2 29 4b 4d :2 4b 28 :2 8 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5f 62
:2 21 6f 72 :2 21 76 79 :2 21 83
86 8f 97 :2 a0 :2 8f b1 :2 86 :2 21
:2 a 55 :2 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5f 62 :2 21 :2 a 55 :3 7
:2 12 28 :2 31 41 :2 7 52 :2 4 7
10 1b :2 7 1e 20 :2 1e 26 2f
37 :2 26 3a 3c :2 3a :2 7 42 4b
53 :2 42 56 58 :2 56 :2 7 a :2 14
26 :2 30 3c 3f 4e 51 52 :2 4e
:2 26 :3 a :2 10 15 21 5f 62 :2 21
6f 72 :2 21 76 79 :2 21 83 86
8f 97 :2 a0 :2 8f b1 :2 86 :2 21 :2 a
55 :2 7 a :2 14 26 :2 30 3c 3f
4e 51 52 :2 4e :2 26 :3 a :2 10 15
21 5f 62 :2 21 :2 a 55 :3 7 :2 12
28 :2 31 41 :2 7 5a :2 4 :4 9 8
7 :4 2b 2a 29 :2 7 11 1c 21
33 3e 43 :2 f :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 8b 8e
:2 27 96 99 :2 27 a5 a8 af b8
bb :2 a8 :2 27 :2 10 5c :2 d :2 a :4 16
:2 a 7 :3 48 b :2 14 1f 1d :2 28
:2 1d a 3d 46 4f :2 3d 52 54
:2 52 3c :2 a d :2 17 29 :2 33 3f
42 51 54 55 :2 51 :2 29 :3 d :2 13
18 24 62 65 :2 24 72 75 :2 24
79 7c :2 24 86 89 92 9a :2 a3
:2 92 c0 :2 89 :2 24 :2 d 58 :2 a d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 62 65
:2 24 :2 d 58 :3 a :2 15 2b :2 34 50
:2 a 57 :3 7 e 7 4 48 :4 c
b a :4 2a 29 28 :2 a 11 23
f :2 a :2 13 1f a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 8b 8e :2 27 96 99
:2 27 a5 a8 af b8 bb :2 a8 :2 27
:2 10 5c :2 d :2 a :4 16 :2 a 7 :4 43
48 :3 4 12 4 :4 8 :2 7 16 7
20 :3 4 10 17 21 24 :2 10 :2 4
12 19 25 28 :2 12 :2 4 13 4
7 10 18 :2 7 1b 1d :2 1b 7
13 1a 21 2e 31 :2 1a 36 39
:2 13 :2 7 15 :2 1e 27 2a 2d 31
:2 15 7 a 18 21 29 :2 18 :2 a
2d 30 :2 2d 14 20 29 3f 48
60 12 20 2b 37 12 20 2d
:2 d :2 16 22 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :4 32 14
16 1f 21 2c 2e 40 42 55
57 d 16 18 2e 37 39 51
53 12 1a 27 38 4a d 18
24 34 3c 3f 47 13 15 22
30 32 3e 47 4f 58 66 6f
7d 86 94 9d aa b3 c4 cd
e0 e9 fe 107 122 12b 143 14c
15d 166 178 181 199 1a2 1b5 1be
1df 1e1 1ee 1f0 :2 d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :7 7 b :2 14 1f 1d :2 28
:2 1d a 14 20 2c 3a 12 20
2d :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 38
e :2 17 22 20 :2 2b :2 20 d :4 11
:2 10 20 10 21 :2 d 17 20 36
3f 57 15 20 2c 15 23 30
:2 10 :2 19 25 10 d :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5b 5e 5f :2 5b :2 32 :3 16 :2 1c 21
2d 6b 6e :2 2d 7b 7e :2 2d 82
85 :2 2d 91 94 :2 2d 9c 9f :2 2d
ab ae b5 be c1 :2 ae :2 2d :2 16
62 :2 13 :2 10 :4 1c :2 10 d :4 3b 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 89
8c 95 9d :2 a6 :2 95 b9 :2 8c :2 27
c1 c4 :2 27 cc cf :2 27 d4 d7
:2 27 e1 e4 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 :2 10 5b :3 d :2 18 2c :2 35 47
52 :2 d :4 a 38 a 1a a :5 7
15 7 11 21 f 10 1d :2 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 8b 8e :2 27 96 99 :2 27 a5
a8 af b8 bb :2 a8 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :3 1f a 13
1f :2 a 22 24 :2 22 14 24 12
13 20 :2 d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 26 d :2 18 1f 2d :2 d 32 34
:2 32 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 89 8c 95 9d :2 a6 :2 95 bb
:2 8c :2 27 c3 c6 :2 27 ce d1 :2 27
d6 d9 :2 27 e6 e9 :2 27 :2 10 5c
:2 d 10 :2 1a 2c :2 36 42 45 54
57 58 :2 54 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 :2 10 5b :3 d :2 18 2c
:2 35 49 57 :2 d 36 :2 a 26 :2 7
1f 11 1a 30 39 51 f 1a
26 f 1d 2a :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 8b 8e
:2 27 96 99 :2 27 a5 a8 af b8
bb :2 a8 :2 27 :2 10 5c :2 d :2 a :4 16
:2 a 7 :3 4 b :2 14 1f 1d :2 28
:2 1d a 23 2e 3e 4e 5b :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :3 38 e :2 17
22 20 :2 2b :2 20 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 b7 :2 8c :2 27 bf c2
:2 27 ca cd :2 27 d2 d5 :2 27 e2
e5 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 45 53 :2 d
3b :2 a 38 :2 7 :4 4 7 b d
:2 b 7 15 :2 7 16 :2 7 15 26
32 3f 48 51 :2 3f 55 5e 66
:2 55 22 2b 37 :2 22 3b 44 4f
:2 3b 53 20 2b :2 53 2f 38 46
:2 2f 4a 53 5e :2 4a 22 2b 37
:2 22 3b 43 4d :2 15 7 a 13
1f :2 a 24 22 :2 2d :2 22 d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 62 65 :2 24
72 75 :2 24 79 7c :2 24 86 89
92 9a :2 a3 :2 92 b4 :2 89 :2 24 :2 d
58 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 62 65 :2 24 :2 d 58 :3 a :2 15
2b :2 34 44 :2 a 7 3c d 16
22 :2 d 25 28 :2 25 d :2 17 29
:2 33 3f 43 52 55 56 :2 52 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 86 89 92
9a :2 92 a7 :2 89 :2 24 af b2 :2 24
ba bd :2 24 c2 c5 :2 24 d2 d5
:2 24 :2 d 59 :2 a d :2 17 29 :2 33
3f 42 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 62 65 :2 24 :2 d 58
:3 a :2 15 29 32 3e :2 29 42 50
:2 a 2a 3c :3 7 16 7 :4 b :2 a
19 a 20 :2 7 4 f b 14
1c :2 b 1f 21 :2 1f a 29 32
3a :2 29 3d 40 :2 3d 28 :2 a b
14 1c :2 b 1f 21 :2 1f a 28
31 39 :2 28 3c 3e :2 3c 27 :3 a
15 a 7 41 d 16 1e :2 d
21 23 :2 21 a 15 a 7 25
41 e 17 1f :2 e 22 24 :2 22
d 2b 34 3c :2 2b 3f 41 :2 3f
2a :2 d a 15 a 7 44 41
d 16 1e :2 d 21 23 :2 21 a
14 1d 29 :2 14 2c 2e 37 3f
:2 2e :2 14 :2 a 15 a 25 41 :2 7
45 f :3 4 :3 17 :2 4 12 :2 4 13
:2 4 d :2 16 22 29 32 3e :2 29
42 :2 4b :2 22 21 5a :2 d :2 4 12
19 22 2e :2 19 32 :2 3b :2 12 4
7 10 18 :2 7 1b 1d :2 1b 7
1a 29 37 3f 4a 54 25 :2 1a
7 a 13 24 :2 a 27 2a :2 27
d :2 17 29 :2 33 3f 43 52 55
56 :2 52 :2 29 :3 d :2 13 18 24 62
65 :2 24 72 75 :2 24 79 7c :2 24
86 89 92 9a :2 92 ac :2 89 :2 24
b4 b7 :2 24 bf c2 :2 24 c7 ca
:2 24 d6 d9 :2 24 :2 d 59 :2 a d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 62 65
:2 24 :2 d 58 :3 a :2 15 29 32 43
:2 29 47 54 :2 a 2c :3 7 15 7
11 15 24 2f 34 44 4f 54
58 f 1b f 10 1d e 18
e 1c e 1e :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 8b 8e
:2 27 96 99 :2 27 a5 a8 af b8
bb :2 a8 :2 27 :2 10 5c :2 d :2 a :4 16
:2 a 7 :3 1f b :2 14 1f 1d :2 28
:2 1d a :4 3e 3d 3c :3 a 18 a
d 16 1f :2 d 22 24 :2 22 d
1d d 26 :2 a 57 :3 7 16 :2 7
12 7 a e 10 :2 e d 14
20 23 :2 d 26 28 :2 26 17 2e
45 4d 54 6d 75 7c 10 18
1f 37 3f 46 60 6e 89 15
26 32 3b 15 16 1e 2f 3b
48 5e :2 10 :2 19 25 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5e 5f :2 5b :2 32 :3 16
:2 1c 21 2d 6b 6e :2 2d 7b 7e
:2 2d 82 85 :2 2d 91 94 :2 2d 9c
9f :2 2d ab ae b5 be c1 :2 ae
:2 2d :2 16 62 :2 13 :2 10 :4 1c :2 10 d
:3 2c 11 :2 1a 25 23 :2 2e :2 23 :2 10
1e 10 14 1d 2b :2 14 2e 30
:2 2e 13 37 40 49 :2 37 4c 4e
:2 4c 36 :2 13 1d 34 4d 55 5c
75 7d 84 16 1e 25 3d 45
4c 68 78 1b 2c 38 1b 1c
24 35 41 4e 64 :2 16 :2 1f 2b
16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 61 64 65
:2 61 :2 38 :3 1c :2 22 27 33 71 74
:2 33 81 84 :2 33 88 8b :2 33 97
9a :2 33 a2 a5 :2 33 b1 b4 bb
c4 c7 :2 b4 :2 33 :2 1c 68 :2 19 :2 16
:4 22 :2 16 13 :4 51 13 22 13 :4 10
d 3e 14 :2 1d 28 26 :2 31 :2 26
13 45 4e 57 :2 45 5a 5c :2 5a
44 :2 13 1a 31 4a 52 59 72
7a 81 13 1b 22 3a 42 49
65 75 18 29 35 18 19 21
32 3e 4b 61 :2 13 :2 1c 28 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 5e 61 62 :2 5e
:2 35 :3 19 :2 1f 24 30 6e 71 :2 30
7e 81 :2 30 85 88 :2 30 94 97
:2 30 9f a2 :2 30 ae b1 b8 c1
c4 :2 b1 :2 30 :2 19 65 :2 16 :2 13 :4 1f
:2 13 10 :4 5f 3e :2 d 2c 17 2e
47 4f 56 6f 77 7e 10 18
1f 37 3f 46 62 72 15 26
32 15 16 1e 2f 3b 48 5e
:2 10 :2 19 25 10 d :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5b 5e 5f :2 5b :2 32 :3 16 :2 1c 21
2d 6b 6e :2 2d 7b 7e :2 2d 82
85 :2 2d 91 94 :2 2d 9c 9f :2 2d
ab ae b5 be c1 :2 ae :2 2d :2 16
62 :2 13 :2 10 :4 1c :2 10 d :7 a 12
d 14 20 23 :2 d 26 28 :2 26
17 2e 44 4c 53 71 79 80
99 a1 a8 c2 ce ec 15 26
31 3a 15 16 1e 2f 3b 48
5e :2 10 :2 19 25 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5e 5f :2 5b :2 32 :3 16 :2 1c
21 2d 6b 6e :2 2d 7b 7e :2 2d
82 85 :2 2d 91 94 :2 2d 9c 9f
:2 2d ab ae b5 be c1 :2 ae :2 2d
:2 16 62 :2 13 :2 10 :4 1c :2 10 d :3 2c
11 :2 1a 25 23 :2 2e :2 23 :2 10 1e
10 14 1d 2b :2 14 2e 30 :2 2e
13 37 40 49 :2 37 4c 4e :2 4c
36 :2 13 1d 34 4d 55 5c 75
7d 84 a0 ac 1b 2c 37 1b
1c 24 35 41 4e 64 :2 16 :2 1f
2b 16 13 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 61 64
65 :2 61 :2 38 :3 1c :2 22 27 33 71
74 :2 33 81 84 :2 33 88 8b :2 33
97 9a :2 33 a2 a5 :2 33 b1 b4
bb c4 c7 :2 b4 :2 33 :2 1c 68 :2 19
:2 16 :4 22 :2 16 13 :4 51 13 22 :2 13
:4 10 d 3e 14 :2 1d 28 26 :2 31
:2 26 13 1a 31 49 51 58 76
7e 85 a0 a8 af cb d7 18
29 34 18 19 21 32 3e 4b
61 :2 13 :2 1c 28 13 10 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5e 61 62 :2 5e :2 35 :3 19 :2 1f
24 30 6e 71 :2 30 7e 81 :2 30
85 88 :2 30 94 97 :2 30 9f a2
:2 30 ae b1 b8 c1 c4 :2 b1 :2 30
:2 19 65 :2 16 :2 13 :4 1f :2 13 10 :4 41
3e :2 d 2c 17 2e 46 4e 55
73 7b 82 9d a5 ac c8 d4
15 26 31 15 16 1e 2f 3b
48 5e :2 10 :2 19 25 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5e 5f :2 5b :2 32 :3 16
:2 1c 21 2d 6b 6e :2 2d 7b 7e
:2 2d 82 85 :2 2d 91 94 :2 2d 9c
9f :2 2d ab ae b5 be c1 :2 ae
:2 2d :2 16 62 :2 13 :2 10 :4 1c :2 10 d
:7 a :4 7 b :2 14 1f 1d :2 28 :2 1d
a d 16 1f :2 d 22 24 :2 22
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 75 78 :2 27 7c 7f :2 27
89 8c 95 9d :2 a6 :2 95 be :2 8c
:2 27 c6 c9 :2 27 d1 d4 :2 27 d9
dc :2 27 e5 e8 :2 27 :2 10 5c :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 :2 10 5b :3 d :2 18 2c :2 35
4c 56 :2 d a 26 :4 11 :2 10 14
16 :2 14 10 20 10 1a 1e 2e
18 19 26 37 4b 17 28 30
37 51 59 60 :2 13 :2 1c 28 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 5e 61 62 :2 5e
:2 35 :3 19 :2 1f 24 30 6e 71 :2 30
7e 81 :2 30 85 88 :2 30 94 97
:2 30 9f a2 :2 30 ae b1 b8 c1
c4 :2 b1 :2 30 :2 19 65 :2 16 :2 13 :4 1f
:2 13 10 :4 18 10 20 10 1a 1e
2e 18 19 26 37 4b 17 23
2b 32 :2 13 :2 1c 28 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5e 61 62 :2 5e :2 35 :3 19
:2 1f 24 30 6e 71 :2 30 7e 81
:2 30 85 88 :2 30 94 97 :2 30 9f
a2 :2 30 ae b1 b8 c1 c4 :2 b1
:2 30 :2 19 65 :2 16 :2 13 :4 1f :2 13 10
:7 d 10 19 27 :2 10 2c 2a 35
3f :2 2c :2 2a 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8c 8f 98 a0 :2 a9
:2 98 c1 :2 8f :2 2a c9 cc :2 2a d4
d7 :2 2a dc df :2 2a e8 eb :2 2a
:2 13 5f :2 10 13 :2 1d 2f :2 39 45
48 57 5a 5b :2 57 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a :2 13 5e :3 10
:2 1b 2f :2 38 4f 59 :2 10 42 :2 d
2e 26 :3 a 18 a 7 38 e
17 23 :2 e 26 28 :2 26 d 30
41 4a 52 :2 41 :2 30 2f 57 5a
:2 57 :3 d :2 17 29 :2 33 3f 43 52
55 56 :2 52 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 86 89 92 9a :2 a3 :2 92 bb
:2 89 :2 24 c3 c6 :2 24 ce d1 :2 24
d6 d9 :2 24 e2 e5 :2 24 :2 d 59
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
62 65 :2 24 :2 d 58 :3 a :2 15 29
:2 32 49 53 :2 a 5c 38 :2 7 a
11 1d 20 :2 a 23 25 :2 23 a
18 1f 2a 2d :2 1f 37 3a :2 18
a 14 1f 2a 35 42 4a 53
5e 69 7c 85 90 9b 12 1f
2d 37 4a 12 13 21 :2 d :2 16
22 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 29 e :2 17 22
20 :2 2b :2 20 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 89 8c 95 9d
:2 a6 :2 95 b9 :2 8c :2 27 c1 c4 :2 27
cc cf :2 27 d4 d7 :2 27 e0 e3
:2 27 :2 10 5c :2 d 10 :2 1a 2c :2 36
42 45 54 57 58 :2 54 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 :2 10 5b
:3 d :2 18 2c :2 35 47 51 :2 d 3b
:2 a e 15 1f 22 :2 e 25 27
:2 25 d 31 3a 4d :2 31 50 52
:2 50 30 5a 10 1e :2 5a 23 21
2c 3f :2 23 :2 21 59 :2 30 2f :2 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 75 78 :2 27 7c 7f :2 27
89 8c 95 9d :2 a6 :2 95 bc :2 8c
:2 27 c4 c7 :2 27 cf d2 :2 27 d7
da :2 27 e3 e6 :2 27 :2 10 5c :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 :2 10 5b :3 d :2 18 2c :2 35
4a 54 :2 d 44 :2 a 14 27 34
45 52 61 12 13 20 2e 46
54 :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :4 29
a 19 20 2c 2f :2 20 39 3c
:2 19 a 14 26 37 46 53 :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :3 7 e :2 17
22 20 :2 2b :2 20 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 b9 :2 8c :2 27 c1 c4
:2 27 cc cf :2 27 d4 d7 :2 27 e0
e3 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 47 51 :2 d
3b :2 a 14 2c 34 3b 59 61
68 82 8a 91 ac b8 12 1e
12 13 1b 2c 38 45 :2 d :2 16
22 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 7 e :2 17 22
20 :2 2b :2 20 d 40 49 52 :2 40
55 57 :2 55 3f :2 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 be :2 8c :2 27 c6 c9
:2 27 d1 d4 :2 27 d9 dc :2 27 e5
e8 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 4c 56 :2 d
5a :2 a 14 27 34 45 52 61
12 13 20 2e 46 54 :2 d :2 16
22 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :8 7 15 7 a
13 1f :2 a 22 24 :2 22 14 1f
2c 34 3b 50 5b 60 74 12
:2 d :2 16 22 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 26 1e
26 2d 45 4d 54 6d :3 12 :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :3 26 a 15
:2 a 19 a d 16 23 :2 d 26
28 :2 26 d 19 d 2a :3 a 16
22 2f 3d 48 52 5e 1b 28
35 42 4f 1b 28 34 3e 46
4f 57 5e 1b 27 34 3f 4a
58 1b 26 32 3e 41 44 4a
:2 16 a d 16 18 :2 16 10 19
26 :2 10 29 2b :2 29 1a 2d 4a
51 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 5e 61 62 :2 5e
:2 35 :3 19 :2 1f 24 30 6e 71 :2 30
7e 81 :2 30 85 88 :2 30 94 97
:2 30 9f a2 :2 30 ae b1 b8 c1
c4 :2 b1 :2 30 :2 19 65 :2 16 :2 13 :4 1f
:2 13 10 :4 2d 1a 2d 4a 51 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5e 61 62 :2 5e :2 35 :3 19
:2 1f 24 30 6e 71 :2 30 7e 81
:2 30 85 88 :2 30 94 97 :2 30 9f
a2 :2 30 ae b1 b8 c1 c4 :2 b1
:2 30 :2 19 65 :2 16 :2 13 :4 1f :2 13 10
:7 d 1a :2 a 26 a 18 :2 a 19
a d 14 20 23 :2 d 26 28
:2 26 d 18 :2 21 d 2c d 18
1f 28 34 :2 1f 38 :2 41 :2 18 d
:5 a 16 22 2f 3d 48 52 5e
1b 28 35 42 4f 1b 28 34
3e 46 4f 57 5e 1b 27 34
3f 4a 58 1b 26 32 3e 41
44 4a :2 16 a d 16 18 :2 16
17 2a 47 4e 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5b
5e 5f :2 5b :2 32 :3 16 :2 1c 21 2d
6b 6e :2 2d 7b 7e :2 2d 82 85
:2 2d 91 94 :2 2d 9c 9f :2 2d ab
ae b5 be c1 :2 ae :2 2d :2 16 62
:2 13 :2 10 :4 1c :2 10 d :4 1a :2 a :4 7
1f a 13 1a :2 13 28 :2 a 2b
2d :2 2b a 16 a 30 a 16
1d 26 2d :2 26 3b :2 1d 3e 40
:2 1d 1c 43 45 :2 1c :2 16 a :4 7
a 13 15 :2 13 a 15 :2 a 10
19 22 :2 10 27 25 30 :2 25 a
d 1b :2 d 19 :2 22 2b 2f 33
3c 45 :2 33 48 4a :2 33 4c 4d
:2 33 50 :2 19 :2 d 1b :2 24 2d 30
33 3c 45 :2 33 48 4a :2 33 4d
4f :2 33 51 52 :2 33 55 :2 1b :2 d
1d :2 d 1b :2 d 18 :2 d 1b d
17 21 25 3a 43 15 16 23
34 3e 14 22 2f 3f :2 10 :2 19
25 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5f
60 :2 5b :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d 7c 7f :2 2d 83 86 :2 2d
92 95 :2 2d 9d a0 :2 2d ac af
b6 bf c2 :2 af :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :3 30 11 1a 23
:2 11 26 28 :2 26 10 :4 31 30 2f
:3 10 1e 10 13 :2 1e 25 33 :2 13
3f 41 :2 3f 13 23 13 43 :2 10
4a :2 d 10 17 23 26 :2 10 29
2b :2 29 10 1e :2 27 10 13 1c
23 :2 1c 31 :2 13 34 36 :2 34 13
22 13 38 13 22 29 35 38
:2 29 41 44 :2 22 :2 13 22 29 35
38 :2 29 42 45 :2 22 13 :4 10 2f
13 1c 23 :2 1c 30 :2 13 33 35
:2 33 13 21 13 37 13 21 28
33 36 :2 28 3f 42 :2 21 :2 13 21
28 33 36 :2 28 40 43 :2 21 13
:4 10 :5 d 1c :2 d 18 d 10 19
25 :2 10 28 2a :2 28 13 17 19
:2 17 16 1d 29 2c :2 16 2f 31
:2 2f 20 37 4e 56 5d 76 7e
85 19 21 28 40 48 4f 69
77 92 1e 2f 3b 44 1e 1f
27 38 44 51 67 :2 19 :2 22 2e
19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 64 68 69
:2 64 :2 3b :3 1f :2 25 2a 36 75 78
:2 36 85 88 :2 36 8c 8f :2 36 9b
9e :2 36 a6 a9 :2 36 b5 b8 bf
c8 cb :2 b8 :2 36 :2 1f 6c :2 1c :2 19
:4 25 :2 19 16 :3 35 1a :2 23 2e 2c
:2 37 :2 2c :2 19 27 19 1d 26 34
:2 1d 37 39 :2 37 1c 40 49 52
:2 40 55 57 :2 55 3f :2 1c 26 3d
56 5e 65 7e 86 8d 1f 27
2e 46 4e 55 71 81 24 35
41 24 25 2d 3e 4a 57 6d
:2 1f :2 28 34 1f 1c :2 24 22 :2 2b
37 22 25 :2 2f 41 :2 4b 57 5b
6a 6e 6f :2 6a :2 41 :3 25 :2 2b 30
3c 7b 7e :2 3c 8b 8e :2 3c 92
95 :2 3c a1 a4 :2 3c ac af :2 3c
bb be c5 ce d1 :2 be :2 3c :2 25
72 :2 22 :2 1f :4 2b :2 1f 1c :4 5a 1c
2b 1c :4 19 16 47 1d :2 26 31
2f :2 3a :2 2f 1c 4e 57 60 :2 4e
63 65 :2 63 4d :2 1c 23 3a 53
5b 62 7b 83 8a 1c 24 2b
43 4b 52 6e 7e 21 32 3e
21 22 2a 3b 47 54 6a :2 1c
:2 25 31 1c 19 :2 21 1f :2 28 34
1f 22 :2 2c 3e :2 48 54 58 67
6b 6c :2 67 :2 3e :3 22 :2 28 2d 39
78 7b :2 39 88 8b :2 39 8f 92
:2 39 9e a1 :2 39 a9 ac :2 39 b8
bb c2 cb ce :2 bb :2 39 :2 22 6f
:2 1f :2 1c :4 28 :2 1c 19 :4 68 47 :2 16
35 20 37 50 58 5f 78 80
87 19 21 28 40 48 4f 6b
7b 1e 2f 3b 48 1f 2c 3d
45 1d 29 36 4c :2 19 :2 22 2e
19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 64 68 69
:2 64 :2 3b :3 1f :2 25 2a 36 75 78
:2 36 85 88 :2 36 8c 8f :2 36 9b
9e :2 36 a6 a9 :2 36 b5 b8 bf
c8 cb :2 b8 :2 36 :2 1f 6c :2 1c :2 19
:4 25 :2 19 16 :7 13 1b 16 1d 29
2c :2 16 2f 31 :2 2f 20 37 4d
55 5c 7a 82 89 a2 aa b1
cb d7 f5 1e 2f 3a 43 55
1f 2c 3d 45 1d 29 36 4c
:2 19 :2 22 2e 19 16 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
64 68 69 :2 64 :2 3b :3 1f :2 25 2a
36 75 78 :2 36 85 88 :2 36 8c
8f :2 36 9b 9e :2 36 a6 a9 :2 36
b5 b8 bf c8 cb :2 b8 :2 36 :2 1f
6c :2 1c :2 19 :4 25 :2 19 16 :3 35 1a
:2 23 2e 2c :2 37 :2 2c 19 1d 26
34 :2 1d 37 39 :2 37 1c 40 49
52 :2 40 55 57 :2 55 3f :2 1c 26
3d 56 5e 65 7e 86 8d a9
b5 24 35 40 4d 25 32 43
4b 23 2f 3c 52 :2 1f :2 28 34
1f 1c :2 24 22 :2 2b 37 22 25
:2 2f 41 :2 4b 57 5b 6a 6e 6f
:2 6a :2 41 :3 25 :2 2b 30 3c 7b 7e
:2 3c 8b 8e :2 3c 92 95 :2 3c a1
a4 :2 3c ac af :2 3c bb be c5
ce d1 :2 be :2 3c :2 25 72 :2 22 :2 1f
:4 2b :2 1f 1c :4 5a 1c 2b :2 1c :4 19
16 47 1d :2 26 31 2f :2 3a :2 2f
1c 23 3a 53 5b 62 80 88
8f aa b2 b9 d5 e1 21 32
3d 4a 22 2f 40 48 20 2c
39 4f :2 1c :2 25 31 1c 19 :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 67 6b 6c :2 67 :2 3e :3 22
:2 28 2d 39 78 7b :2 39 88 8b
:2 39 8f 92 :2 39 9e a1 :2 39 a9
ac :2 39 b8 bb c2 cb ce :2 bb
:2 39 :2 22 6f :2 1f :2 1c :4 28 :2 1c 19
:4 4a 47 :2 16 35 20 37 4f 57
5e 7c 84 8b a6 ae b5 d1
dd 1e 2f 3a 47 1f 2c 3d
45 1d 29 36 4c :2 19 :2 22 2e
19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 64 68 69
:2 64 :2 3b :3 1f :2 25 2a 36 75 78
:2 36 85 88 :2 36 8c 8f :2 36 9b
9e :2 36 a6 a9 :2 36 b5 b8 bf
c8 cb :2 b8 :2 36 :2 1f 6c :2 1c :2 19
:4 25 :2 19 16 :7 13 :4 10 14 :2 1d 28
26 :2 31 :2 26 13 16 1f 28 :2 16
2b 2d :2 2b 16 24 16 2f :4 1a
19 1c 20 22 :2 20 1c 2c 1c
26 2a 3a 24 25 32 43 57
23 34 3c 43 5d 65 6c :2 1f
:2 28 34 1f 1c :2 24 22 :2 2b 37
22 25 :2 2f 41 :2 4b 57 5b 6a
6e 6f :2 6a :2 41 :3 25 :2 2b 30 3c
7b 7e :2 3c 8b 8e :2 3c 92 95
:2 3c a1 a4 :2 3c ac af :2 3c bb
be c5 ce d1 :2 be :2 3c :2 25 72
:2 22 :2 1f :4 2b :2 1f 1c :4 24 1c 2c
1c 26 2a 3a 24 25 32 43
57 23 2f 37 3e :2 1f :2 28 34
1f 1c :2 24 22 :2 2b 37 22 25
:2 2f 41 :2 4b 57 5b 6a 6e 6f
:2 6a :2 41 :3 25 :2 2b 30 3c 7b 7e
:2 3c 8b 8e :2 3c 92 95 :2 3c a1
a4 :2 3c ac af :2 3c bb be c5
ce d1 :2 be :2 3c :2 25 72 :2 22 :2 1f
:4 2b :2 1f 1c :7 19 1c 25 33 :2 1c
38 36 41 4b :2 38 :2 36 1c 27
30 39 :2 27 3c 3e :2 27 1c 21
1c 4e :2 19 37 :3 16 24 16 :4 13
41 13 1e 27 30 :2 1e 33 35
:2 1e 13 18 13 :5 10 1e :2 10 1c
10 1a 25 32 3a 41 56 61
66 :2 18 :2 13 :2 1c 28 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5e 62 63 :2 5e :2 35 :3 19
:2 1f 24 30 6f 72 :2 30 7f 82
:2 30 86 89 :2 30 95 98 :2 30 a0
a3 :2 30 af b2 b9 c2 c5 :2 b2
:2 30 :2 19 66 :2 16 :2 13 :4 1f :2 13 10
:3 2c 24 2c 33 4b 53 5a 73
85 :2 18 :2 13 :2 1c 28 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5e 62 63 :2 5e :2 35 :3 19
:2 1f 24 30 6f 72 :2 30 7f 82
:2 30 86 89 :2 30 95 98 :2 30 a0
a3 :2 30 af b2 b9 c2 c5 :2 b2
:2 30 :2 19 66 :2 16 :2 13 :4 1f :2 13 10
:3 2c 10 1b :2 10 1f 10 13 1c
29 :2 13 2c 2e :2 2c 13 1f 13
30 :3 10 1c 28 35 43 4e 58
64 1b 28 35 42 4f 1b 28
34 3e 46 4f 57 5e 1b 27
34 3f 4a 58 1b 26 32 3e
41 44 4a :2 1c 10 13 1c 1e
:2 1c 16 1f 2c :2 16 2f 31 :2 2f
20 33 50 57 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 64
68 69 :2 64 :2 3b :3 1f :2 25 2a 36
75 78 :2 36 85 88 :2 36 8c 8f
:2 36 9b 9e :2 36 a6 a9 :2 36 b5
b8 bf c8 cb :2 b8 :2 36 :2 1f 6c
:2 1c :2 19 :4 25 :2 19 16 :4 33 20 33
50 57 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 64 68 69
:2 64 :2 3b :3 1f :2 25 2a 36 75 78
:2 36 85 88 :2 36 8c 8f :2 36 9b
9e :2 36 a6 a9 :2 36 b5 b8 bf
c8 cb :2 b8 :2 36 :2 1f 6c :2 1c :2 19
:4 25 :2 19 16 :7 13 20 :2 10 d 2c
13 1c 28 :2 13 2b 2d :2 2b 10
1e :2 10 1f 10 13 1a 26 29
:2 13 2c 2e :2 2c 13 1e :2 27 13
32 13 1e 27 33 :2 1e 13 :5 10
1c 28 35 43 4e 58 64 1b
28 35 42 4f 1b 28 34 3e
46 4f 57 5e 1b 27 34 3f
4a 58 1b 26 32 3e 41 44
4a :2 1c 10 13 1c 1e :2 1c 1d
30 4d 54 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 61 65
66 :2 61 :2 38 :3 1c :2 22 27 33 72
75 :2 33 82 85 :2 33 89 8c :2 33
98 9b :2 33 a3 a6 :2 33 b2 b5
bc c5 c8 :2 b5 :2 33 :2 1c 69 :2 19
:2 16 :4 22 :2 16 13 :4 20 :2 10 2f 2c
:3 d 18 21 2a :2 18 2d 2f :2 18
d f d :3 30 e a 17 :2 7
:4 4 8 11 14 :2 11 7 1c 25
2d :2 1c 30 32 :2 30 1b :2 7 a
13 22 :2 a 25 27 :2 25 19 34
48 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5c 5d :2 58
:2 2f :3 13 :2 19 1e 2a 69 6c :2 2a
79 7c :2 2a 80 83 :2 2a 8f 92
:2 2a 9a 9d :2 2a a9 ac b3 bc
bf :2 ac :2 2a :2 13 60 :2 10 :2 d :4 19
:2 d a :4 29 14 2d 3b 4a 58
13 27 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5c 5d
:2 58 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a 79 7c :2 2a 80 83 :2 2a 8f
92 :2 2a 9a 9d :2 2a a9 ac b3
bc bf :2 ac :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :7 7 a 13 15 :2 13
d :2 17 29 :2 33 3f 43 52 56
57 :2 52 :2 29 :3 d :2 13 18 24 63
66 :2 24 73 76 :2 24 7a 7d :2 24
87 8a 93 9b :2 a4 :2 93 ba :2 8a
:2 24 c2 c5 :2 24 cd d0 :2 24 d5
d8 :2 24 e1 e4 :2 24 :2 d 5a :2 a
d :2 17 29 :2 33 3f 42 51 55
56 :2 51 :2 29 :3 d :2 13 18 24 63
66 :2 24 :2 d 59 :3 a :2 15 29 :2 32
47 51 :2 a 7 19 d 18 16
:2 21 :2 16 d :2 17 29 :2 33 3f 43
52 56 57 :2 52 :2 29 :3 d :2 13 18
24 63 66 :2 24 73 76 :2 24 7a
7d :2 24 87 8a 93 9b :2 a4 :2 93
c3 :2 8a :2 24 cb ce :2 24 d6 d9
:2 24 de e1 :2 24 ea ed :2 24 :2 d
5a :2 a d :2 17 29 :2 33 3f 42
51 55 56 :2 51 :2 29 :3 d :2 13 18
24 63 66 :2 24 :2 d 59 :3 a :2 15
29 :2 32 50 12 :2 a 7 3e 19
d 18 16 :2 21 :2 16 d :2 17 29
:2 33 3f 43 52 56 57 :2 52 :2 29
:3 d :2 13 18 24 63 66 :2 24 73
76 :2 24 7a 7d :2 24 87 8a 93
9b :2 a4 :2 93 c0 :2 8a :2 24 c8 cb
:2 24 d3 d6 :2 24 db de :2 24 e7
ea :2 24 :2 d 5a :2 a d :2 17 29
:2 33 3f 42 51 55 56 :2 51 :2 29
:3 d :2 13 18 24 63 66 :2 24 :2 d
59 :3 a :2 15 29 :2 32 4d 12 :2 a
3b 19 d :2 17 29 :2 33 3f 43
52 56 57 :2 52 :2 29 :3 d :2 13 18
24 63 66 :2 24 73 76 :2 24 7a
7d :2 24 87 8a 93 9b :2 a4 :2 93
bc :2 8a :2 24 c4 c7 :2 24 cf d2
:2 24 d7 da :2 24 e6 e9 :2 24 :2 d
5a :2 a d :2 17 29 :2 33 3f 42
51 55 56 :2 51 :2 29 :3 d :2 13 18
24 63 66 :2 24 :2 d 59 :3 a :2 15
29 :2 32 49 56 :2 a :4 7 35 :2 4
8 11 18 :2 11 25 :2 8 28 2a
:2 28 7 32 3b 42 :2 3b 50 :2 32
53 55 :2 53 31 :3 7 f 19 :3 7
:2 10 1c :2 7 f e 11 :2 f e
11 :2 f e 11 :2 f e 11 :2 f
e 11 :2 f 3e 41 :2 f 4e 51
:2 f e 11 :2 f 2d 30 :2 f 3b
3e :2 f 5a 5d :2 f 13 16 :2 f
7 a 12 1c :2 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
59 5a :2 55 :2 2c :3 10 :2 16 1b 27
66 69 :2 27 76 79 :2 27 7d 80
:2 27 8c 8f :2 27 97 9a :2 27 a6
a9 b0 b9 bc :2 a9 :2 27 :3 10 :2 16
1b 3f 48 4b :2 3f :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 58 7 f 19
:3 7 :2 10 1c :2 7 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d 25 28 :2 d 35
38 :2 d e 11 :2 d 28 2b :2 d
36 39 :2 d 55 58 :2 d 13 16
:2 d 7 a 12 1c :2 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 59 5a :2 55 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :3 10
:2 16 1b 3f 48 4b :2 3f :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 58 7 :2 10
:3 1c :2 7 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d 4e
51 :2 d 13 16 :2 d e 11 :2 d
4b 4e :2 d 13 16 :2 d e 11
:2 d e 11 :2 d 13 16 :2 d 21
24 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d 4f 52 :2 d 13 16 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d 2d 30 :2 d 3c
3f :2 d e 11 :2 d 7 a 12
1c :2 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 59 5a :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8c 8f
:2 27 97 9a :2 27 a6 a9 b0 b9
bc :2 a9 :2 27 :3 10 :2 16 1b 3f 48
4b :2 3f :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 58 7 d e 11 :2 d e
11 :2 d e 11 :2 d 3b 3e 46
4f 58 :2 46 :2 3e :2 d 13 16 :2 d
e 11 :2 d 15 18 20 29 34
:2 20 :2 18 :2 d 13 16 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d 55 58
60 13 1c :2 60 :2 58 :2 d 20 23
:2 d e 11 :2 d 2c 2f 37 40
4b :2 37 :2 2f :2 d 13 16 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d 7 4 58 a 13
1a :2 13 28 :2 a 2b 2d :2 2b 7
f 19 :3 7 :2 10 1c :2 7 f e
11 :2 f e 11 :2 f e 11 :2 f
e 11 :2 f e 11 :2 f 3e 41
:2 f 4e 51 :2 f e 11 :2 f 27
2a :2 f 35 38 :2 f 7 a 12
1c :2 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 59 5a :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8c 8f
:2 27 97 9a :2 27 a6 a9 b0 b9
bc :2 a9 :2 27 :3 10 :2 16 1b 3f 48
4b :2 3f :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 2f 7 f 19 :3 7 :2 10 1c
:2 7 f e 11 :2 f e 11 :2 f
e 11 :2 f e 11 :2 f e 11
:2 f 3b 3e :2 f 4b 4e :2 f 13
16 :2 f 21 24 :2 f 7 a 12
1c :2 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 59 5a :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8c 8f
:2 27 97 9a :2 27 a6 a9 b0 b9
bc :2 a9 :2 27 :3 10 :2 16 1b 3f 48
4b :2 3f :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 2f 7 :2 10 :3 1c :2 7 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d 4e 51 :2 d 13 16 :2 d
e 11 :2 d 4b 4e :2 d 13 16
:2 d e 11 :2 d e 11 :2 d 2e
31 :2 d 3c 3f :2 d 7 a 12
1c :2 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 59 5a :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8c 8f
:2 27 97 9a :2 27 a6 a9 b0 b9
bc :2 a9 :2 27 :3 10 :2 16 1b 3f 48
4b :2 3f :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 2f 7 d e 11 :2 d e
11 :2 d e 11 :2 d 48 4b 53
5c 65 :2 53 :2 4b :2 d 13 16 :2 d
e 11 19 22 2d :2 19 :2 11 :2 d
13 16 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d 7
2f 58 7 f 19 :3 7 :2 10 1c
:2 7 f e 11 :2 f e 11 :2 f
e 11 :2 f e 11 :2 f e 11
:2 f e 11 :2 f 28 2b :2 f 38
3b :2 f e 11 :2 f 2d 30 :2 f
3c 3f :2 f e 11 :2 f 7 a
12 1c :2 a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 55 59 5a
:2 55 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8c
8f :2 27 97 9a :2 27 a6 a9 b0
b9 bc :2 a9 :2 27 :3 10 :2 16 1b 3f
48 4b :2 3f :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 4 7 f 19 :3 7 :2 10
1c :2 7 f e 11 :2 f e 11
:2 f e 11 :2 f e 11 :2 f e
11 :2 f 3b 3e :2 f 4b 4e :2 f
13 16 :2 f 22 25 :2 f 7 a
12 1c :2 a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 55 59 5a
:2 55 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8c
8f :2 27 97 9a :2 27 a6 a9 b0
b9 bc :2 a9 :2 27 :3 10 :2 16 1b 3f
48 4b :2 3f :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 4 7 :2 10 :3 1c :2 7 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d 4e 51 :2 d 13 16
:2 d e 11 :2 d e 11 :2 d e
11 :2 d 2d 30 :2 d 3c 3f :2 d
7 a 12 1c :2 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
59 5a :2 55 :2 2c :3 10 :2 16 1b 27
66 69 :2 27 76 79 :2 27 7d 80
:2 27 8c 8f :2 27 97 9a :2 27 a6
a9 b0 b9 bc :2 a9 :2 27 :3 10 :2 16
1b 3f 48 4b :2 3f :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 4 7 f e
11 :2 f e 11 :2 f e 11 :2 f
13 16 1e 27 30 :2 1e :2 16 :2 f
34 37 :2 f e 11 :2 f 54 57
5f 13 1e :2 5f :2 57 :2 f 13 16
:2 f e 11 :2 f e 11 :2 f e
11 :2 f e 11 :2 f 7 :4 4 7
:2 11 23 :2 2d 39 3c 4b 4f 50
:2 4b :2 23 :3 7 :2 d 12 1e 5d 60
:2 1e :2 7 53 :2 4 7 :2 11 23 :2 2d
39 3c 4b 4f 50 :2 4b :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :2 7 53
:3 4 b :2 16 26 :2 b 4 1 9
12 9 a :2 14 26 :2 30 3c 40
4f 53 54 :2 4f :2 26 :3 a :2 10 15
21 60 63 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 57 :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4c 50 51 :2 4c :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 54 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
30ce
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :7 1b
:7 1c :7 1d :5 1e :5 1f
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :7 42 :7 43
:6 44 :7 45 :6 46 :7 47
:7 48 :7 49 :6 4a :6 4b
:6 4c :7 4d :7 4e :6 4f
:6 50 :7 51 :6 52 :6 53
:6 54 :6 55 :5 56 :7 58
:b 5a :11 5b 5c :2 5b
:2 5c :2 5b :2 5c :2 5b
:2 5d :2 5b :2 5d :2 5b
:2 5d :2 5b :2 5d :2 5b
:2 5e :2 5b :2 5e :2 5b
:2 5e :2 5b :2 5e :2 5b
:2 5f :2 5b :9 5f :2 5b
:2 60 :2 5b :9 60 :2 5b
:2 61 :2 5b :9 61 :2 5b
:2 62 :2 5b :9 62 :2 5b
:2 63 :2 5b :9 63 :2 5b
:2 64 :2 5b :9 64 :2 5b
:2 65 :2 5b :9 65 :2 5b
:2 66 :2 5b :9 66 :2 5b
:2 67 :2 5b :9 67 :2 5b
:2 68 :2 5b :9 68 :2 5b
:2 69 :2 5b :2 69 :2 5b
:2 69 :2 5b :2 69 :2 5b
:2 6a :2 5b :2 6a :2 5b
:2 6a :2 5b :2 6a :2 5b
:2 6a :4 5b :3 5a :11 6d
:b 6e :3 6d :3 76 :3 77
:3 78 :3 79 :3 7b :3 7d
:3 7f :3 81 :3 82 :3 83
:3 84 :3 85 :3 86 :3 87
:3 89 :3 8a :3 8b :a 8c
:3 8d :3 92 :3 93 :5 95
:11 96 :20 97 :3 96 :11 99
:b 9a :3 99 :9 9c :3 95
:5 9f :11 a0 :20 a1 :3 a0
:11 a3 :b a4 :3 a3 :9 a6
:3 9f :15 a9 :11 aa :20 ab
:3 aa :11 ad :b ae :3 ad
:9 b0 :3 a9 :15 b3 :11 b4
:20 b5 :3 b4 :11 b7 :b b8
:3 b7 :9 ba :3 b3 :1f bd
:11 be :20 bf :3 be :11 c1
:b c2 :3 c1 :9 c4 :3 bd
:e c7 :6 c9 ca cb
c9 :5 cc c8 :2 ce
:5 d0 :11 d1 :24 d2 :3 d1
:2 cf :6 ce cd :3 c7
:16 d7 :11 d8 :20 d9 :3 d8
:11 db :b dc :3 db :9 de
:3 d7 :3 e1 e2 c7
:e e2 :2 e4 e5 e4
:5 e6 e3 :2 e8 :5 ea
:11 eb :24 ec :3 eb :2 e9
:6 e8 e7 :4 e2 :3 c7
:3 f2 :5 f3 :3 f4 :3 f3
:8 f7 :8 f8 :3 f9 :9 fb
:d fd :b fe :c 100 :6 102
:4 103 :3 104 102 :5 105
101 :2 107 :5 109 :11 10a
:24 10b :3 10a :2 108 :6 107
106 :4 100 :a 111 :8 112
:5 113 :7 114 :27 115 111
:5 116 110 :2 118 :5 11a
:11 11b :24 11c :3 11b :2 119
:6 118 117 :4 10f :3 100
:a 122 :4 124 :3 125 124
:5 126 123 :2 128 :5 12a
:11 12b :24 12c :3 12b :2 129
:6 128 127 :3 122 :a 131
:5 132 :3 133 :3 132 :5 136
:3 137 :3 138 136 :5 139
135 :2 13b :5 13d :11 13e
:24 13f :3 13e :2 13c :6 13b
13a :4 131 :11 144 :30 145
:3 144 :11 147 :b 148 :3 147
:a 14a 143 :3 131 122
:3 14d 14c :3 122 :3 150
:2 152 153 :2 154 152
:5 155 151 :2 157 :5 159
:11 15a :24 15b :3 15a :2 158
:6 157 156 :3 fb :9 160
:2 162 163 :2 164 162
:5 165 161 :2 167 :5 169
:11 16a :24 16b :3 16a :2 168
:6 167 166 :3 160 :b 170
:11 171 :30 172 :3 171 :11 174
:b 175 :3 174 :a 177 :3 170
:3 160 fb :5 17c :3 17d
:3 17e 17c :5 17f 17b
:2 181 :5 183 :11 184 :24 185
:3 184 :2 182 :6 181 180
:3 17a :a 189 :6 18b :5 18c
18a :2 18e :5 190 :11 191
:24 192 :3 191 :2 18f :6 18e
18d :3 189 :a 196 :11 197
:30 198 :3 197 :11 19a :b 19b
:3 19a :a 19d :3 196 :3 189
17a :3 fb :5 1b0 :3 1b1
:3 1b2 :e 1b3 :b 1b4 :2 1b5
:2 1b4 :a 1b5 :8 1b6 :3 1b3
:b 1b8 :11 1b9 :20 1ba :3 1b9
:11 1bc :b 1bd :3 1bc :9 1bf
1c0 1b8 :9 1c0 :11 1c1
:2e 1c2 :3 1c1 :11 1c4 :b 1c5
:3 1c4 :c 1c7 1c0 :3 1b8
:3 1ca :5 1cb :3 1cc :3 1cb
1ce 1b0 :16 1ce :16 1cf
:3 1d0 1d1 1cf :9 1d1
:3 1d2 1d3 1d1 1cf
:16 1d3 :3 1d4 1d5 1d3
1cf :9 1d5 :f 1d6 :3 1d7
1d5 :3 1cf 1ce :3 1b0
:5 1dc :3 1de :3 1df :14 1e1
:d 1e3 :9 1e5 :7 1e6 1e7
:3 1e6 :9 1e9 :11 1ea :2e 1eb
:3 1ea :11 1ed :b 1ee :3 1ed
:c 1f0 :3 1e9 :3 1f3 :9 1f6
:2 1f7 1f8 :2 1f9 :2 1fa
:2 1fb :2 1fc 1f6 :5 1fd
1f5 :2 1ff :5 201 :11 202
:24 203 :3 202 :2 200 :6 1ff
1fe :3 1e5 :12 208 :3 209
:9 20a :3 20b :3 20a :3 208
:3 20f :3 210 :5 211 :a 212
:8 214 :9 215 :4 216 217
:6 218 214 :5 219 213
:2 21b :5 21d :11 21e :24 21f
:3 21e :2 21c :6 21b 21a
:3 212 :a 224 :3 225 :16 226
:8 228 :8 229 :3 22a 22b
:6 22c 228 :5 22d 227
:2 22f :5 231 :11 232 :24 233
:3 232 :2 230 :6 22f 22e
:4 226 :3 238 237 :3 226
23a 224 :16 23a :8 23c
:8 23d :3 23e 23f :6 240
23c :5 241 23b :2 243
:5 245 :11 246 :24 247 :3 246
:2 244 :6 243 242 :4 23a
:3 224 212 :8 24e :8 24f
:3 250 251 :6 252 24e
:5 253 24d :2 255 :5 257
:11 258 :24 259 :3 258 :2 256
:6 255 254 :4 24c :3 212
211 :a 25f :e 261 :4 262
263 :6 264 261 :5 265
260 :2 267 :5 269 :11 26a
:24 26b :3 26a :2 268 :6 267
266 :3 25f :a 270 :3 271
:16 272 :a 274 :3 275 276
:6 277 274 :5 278 273
:2 27a :5 27c :11 27d :24 27e
:3 27d :2 27b :6 27a 279
:4 272 :3 283 284 282
:3 272 286 270 :a 286
:d 288 :3 289 28a :6 28b
288 :5 28c 287 :2 28e
:5 290 :11 291 :24 292 :3 291
:2 28f :6 28e 28d :4 286
:3 270 25f :d 299 :3 29a
29b :6 29c 299 :5 29d
298 :2 29f :5 2a1 :11 2a2
:24 2a3 :3 2a2 :2 2a0 :6 29f
29e :4 297 :3 25f 25e
:3 211 :a 2aa :9 2ab :11 2ac
:30 2ad :3 2ac :11 2af :b 2b0
:3 2af :a 2b2 2b3 2ab
:5 2b3 :5 2b4 :3 2b5 :3 2b7
2b8 :4 2b9 :7 2ba 2b7
:5 2bb 2b6 :2 2bd :5 2bf
:11 2c0 :24 2c1 :3 2c0 :2 2be
:6 2bd 2bc :4 2b4 :3 2c6
:3 2c8 2c9 :4 2ca :4 2cb
2c8 :5 2cc 2c7 :2 2ce
:5 2d0 :11 2d1 :24 2d2 :3 2d1
:2 2cf :6 2ce 2cd :4 2c5
:3 2b4 :d 2d8 :11 2d9 :30 2da
:3 2d9 :11 2dc :b 2dd :3 2dc
:a 2df :3 2d8 2b3 :3 2ab
:3 2e2 2e3 2aa :19 2e3
:11 2e4 :30 2e5 :3 2e4 :11 2e7
:b 2e8 :3 2e7 :a 2ea 2e3
:3 2aa :a 2ed :c 2ee :d 2f1
:5 2f2 2f3 :2 2f4 2f1
:5 2f5 2f0 :2 2f7 :5 2f9
:11 2fa :24 2fb :3 2fa :2 2f8
:6 2f7 2f6 :3 2ed :a 300
:11 301 :30 302 :3 301 :11 304
:b 305 :3 304 :a 307 :3 300
:16 30a :2 30b :2 30a :8 30b
:6 30a :11 30c :30 30d :3 30c
:11 30f :b 310 :3 30f :a 312
30b :2 30a :6 316 317
:5 318 316 :5 319 315
:2 31b :5 31d :11 31e :24 31f
:3 31e :2 31c :6 31b 31a
:4 2ed :c 324 :6 327 :5 328
326 :2 32a :5 32c :11 32d
:24 32e :3 32d :2 32b :6 32a
329 :3 323 :a 333 :11 334
:30 335 :3 334 :11 337 :b 338
:3 337 :a 33a :3 333 :c 33e
:2 33f 340 :5 341 33e
:5 342 33d :2 344 :5 346
:11 347 :24 348 :3 347 :2 345
:6 344 343 :3 323 :16 34d
:11 34e :30 34f :3 34e :11 351
:b 352 :3 351 :a 354 :3 34d
:6 358 359 :5 35a 358
:5 35b 357 :2 35d :5 35f
:11 360 :24 361 :3 360 :2 35e
:6 35d 35c :4 323 :3 2ed
:3 367 :9 369 :9 36b 36c
36b :5 36d 36a :2 36f
:5 371 :11 372 :24 373 :3 372
:2 370 :6 36f 36e :3 369
:7 379 37a 37b 37c
379 :5 37d 378 :2 37f
:5 381 :11 382 :24 383 :3 382
:2 380 :6 37f 37e :3 369
:3 388 :3 389 :9 38a :3 38b
:3 38a :8 38e :5 38f :8 390
:6 391 :7 392 :3 38e :5 394
:9 395 :5 397 :6 398 :5 399
398 :5 39b 39a :3 398
396 :2 39e :5 3a0 :11 3a1
:24 3a2 :3 3a1 :2 39f :6 39e
39d :4 395 :5 3a8 :6 3a9
:5 3aa 3a9 :5 3ac 3ab
:3 3a9 3a7 :2 3af :5 3b1
:11 3b2 :24 3b3 :3 3b2 :2 3b0
:6 3af 3ae :4 3a6 :3 395
:3 394 369 :3 3bb :3 3bc
:a 3be :5 3bf 3be :d 3c1
3c0 :3 3be :8 3c4 :5 3c5
:8 3c6 :6 3c7 :7 3c8 :3 3c4
:5 3ca :5 3cc :6 3cd :5 3ce
3cd :5 3d0 3cf :3 3cd
3cb :2 3d3 :5 3d5 :11 3d6
:24 3d7 :3 3d6 :2 3d4 :6 3d3
3d2 :6 3ca 3b9 :3 369
1e5 :c 3e0 :3 3e1 3e0
:16 3e3 3e2 :3 3e0 :5 3e5
:3 3e6 :c 3e7 :3 3e8 :17 3eb
:1b 3ed :3 3ef :3 3f0 :3 3f1
:3 3f2 :5 3f5 3f6 :4 3f7
:4 3f8 3f5 :5 3f9 3f4
:2 3fb :5 3fd :11 3fe :24 3ff
:3 3fe :2 3fc :6 3fb 3fa
:3 3e7 :12 404 :3 405 :b 406
:3 407 :3 406 :3 404 :a 40b
:5 40c :c 40d :3 40e 40d
:c 410 :c 411 40f :3 40d
40b :c 414 :3 415 414
:c 417 :c 418 416 :3 414
413 :3 40b :3 41c :3 41d
:9 41f :5 420 :a 421 :8 423
:9 424 :4 425 426 :6 427
423 :5 428 422 :2 42a
:5 42c :11 42d :24 42e :3 42d
:2 42b :6 42a 429 :3 421
:a 433 :3 434 :16 435 :8 437
:8 438 :3 439 43a :6 43b
437 :5 43c 436 :2 43e
:5 440 :11 441 :24 442 :3 441
:2 43f :6 43e 43d :4 435
:3 447 446 :3 435 449
433 :16 449 :8 44b :8 44c
:3 44d 44e :6 44f 44b
:5 450 44a :2 452 :5 454
:11 455 :24 456 :3 455 :2 453
:6 452 451 :4 449 :3 433
421 :8 45d :8 45e :4 45f
:4 460 :4 461 45d :5 462
45c :2 464 :5 466 :11 467
:24 468 :3 467 :2 465 :6 464
463 :4 45b :3 421 420
:a 46e :e 470 :5 471 :4 472
:4 473 470 :5 474 46f
:2 476 :5 478 :11 479 :24 47a
:3 479 :2 477 :6 476 475
:3 46e :a 47f :16 480 :a 482
:4 483 :4 484 :4 485 482
:5 486 481 :2 488 :5 48a
:11 48b :24 48c :3 48b :2 489
:6 488 487 :4 480 :3 491
492 490 :3 480 494
47f :a 494 :d 496 :4 497
:4 498 :4 499 496 :5 49a
495 :2 49c :5 49e :11 49f
:24 4a0 :3 49f :2 49d :6 49c
49b :4 494 :3 47f 46e
:d 4a7 :4 4a8 :4 4a9 :4 4aa
4a7 :5 4ab 4a6 :2 4ad
:5 4af :11 4b0 :24 4b1 :3 4b0
:2 4ae :6 4ad 4ac :4 4a5
:3 46e 46d :3 420 :a 4b8
:9 4b9 :3 4ba 4b9 :5 4bc
:5 4bd :3 4be :3 4c0 4c1
:4 4c2 :7 4c3 4c0 :5 4c4
4bf :2 4c6 :5 4c8 :11 4c9
:24 4ca :3 4c9 :2 4c7 :6 4c6
4c5 :4 4bd :3 4cf :3 4d1
4d2 :4 4d3 :4 4d4 4d1
:5 4d5 4d0 :2 4d7 :5 4d9
:11 4da :24 4db :3 4da :2 4d8
:6 4d7 4d6 :4 4ce :3 4bd
:d 4e0 :b 4e1 :2 4e2 :3 4e0
:3 4bc :3 4e5 4bb :3 4b9
4b8 :b 4e8 :2 4e9 4e7
:3 4b8 :3 4ec :3 4ed :8 4f0
4f1 4f2 4f0 :5 4f3
4ef :2 4f5 :5 4f7 :11 4f8
:24 4f9 :3 4f8 :2 4f6 :6 4f5
4f4 :3 41f :8 4ff 500
501 4ff :5 502 4fe
:2 504 :5 506 :11 507 :24 508
:3 507 :2 505 :6 504 503
:3 41f :3 50d :3 50e :9 50f
:3 510 :3 50f :8 513 :5 514
:8 515 :6 516 :7 517 :3 513
:5 519 :9 51a :5 51c :6 51d
:5 51e 51d :5 520 51f
:3 51d 51b :2 523 :5 525
:11 526 :24 527 :3 526 :2 524
:6 523 522 :4 51a :5 52d
:6 52e :5 52f 52e :5 531
530 :3 52e 52c :2 534
:5 536 :11 537 :24 538 :3 537
:2 535 :6 534 533 :4 52b
:3 51a :3 519 53e 41f
:9 53e :3 53f :3 540 :a 542
:5 543 542 :7 545 544
:3 542 :8 548 :5 549 :8 54a
:6 54b :7 54c :3 548 :5 54d
:5 54f :6 550 :5 551 550
:5 553 552 :3 550 54e
:2 556 :5 558 :11 559 :24 55a
:3 559 :2 557 :6 556 555
:6 54d 53e :3 41f :b 560
561 562 :3 3e7 563
3e7 :3 3e5 3dd :3 1e5
:12 568 :9 569 :4 56b :6 56c
:5 56d 56c :5 56f 56e
:3 56c 56a :2 572 :5 574
:11 575 :24 576 :3 575 :2 573
:6 572 571 :4 569 :5 57c
:2 57d 57c :6 57e :5 57f
57e :5 581 580 :3 57e
57b :2 584 :5 586 :11 587
:24 588 :3 587 :2 585 :6 584
583 :4 57a :3 569 :5 58e
:11 58f :30 590 :3 58f :11 592
:b 593 :3 592 :a 595 596
58e :7 596 :11 597 :30 598
:3 597 :11 59a :b 59b :3 59a
:7 59d 59e :2 59d 59f
596 58e :7 59f :11 5a0
:30 5a1 :3 5a0 :11 5a3 :b 5a4
:3 5a3 :7 5a6 5a7 :2 5a6
59f 58e :11 5a9 :30 5aa
:3 5a9 :11 5ac :b 5ad :3 5ac
:a 5af 5a8 :3 58e :3 568
:1c 5b3 :5 5b5 :5 5b6 :2 5b8
:2 5b9 :2 5b8 :2 5ba :2 5b8
:2 5bb :2 5b8 :2 5bc :2 5b8
:2 5bd :2 5b8 :2 5bd :2 5b8
:2 5bd :2 5b8 :2 5be :2 5b8
:2 5be :2 5b8 :2 5be :2 5b8
:2 5be :2 5b8 :2 5bf :3 5b8
:5 5c2 :6 5c3 :5 5c4 5c3
:5 5c6 5c5 :3 5c3 5c1
:2 5c9 :5 5cb :11 5cc :24 5cd
:b 5ce :3 5cc :2 5ca :6 5c9
5c8 :3 5b3 :5 5d4 :5 5d5
5d7 5d8 :2 5d9 :2 5d8
:2 5da :2 5d8 :2 5db :2 5d8
:2 5dc :2 5d8 :2 5dd :2 5d8
:2 5dd :2 5d8 :2 5dd :2 5d8
:2 5de :2 5d8 :2 5de :2 5d8
:2 5de :2 5d8 :2 5de :2 5d8
:2 5df :2 5d8 5d7 :5 5e2
:6 5e3 :5 5e4 5e3 :5 5e6
5e5 :3 5e3 5e1 :2 5e9
:5 5eb :11 5ec :24 5ed :b 5ee
:3 5ec :2 5ea :6 5e9 5e8
:3 5b3 :7 5f3 5f5 5f6
:2 5f7 :2 5f6 :2 5f8 :2 5f6
:2 5f9 :2 5f6 :2 5fa :2 5f6
:2 5fb :2 5f6 :2 5fc :2 5f6
:2 5fd :2 5f6 :2 5fe :2 5f6
:2 5ff :2 5f6 :2 600 :2 5f6
:2 601 :2 5f6 :2 602 :2 5f6
:2 602 :2 5f6 :2 603 :2 5f6
:2 604 :2 5f6 :2 604 :2 5f6
:2 605 :2 5f6 :2 606 :2 5f6
:2 607 :2 5f6 :2 608 :2 5f6
:2 608 :2 5f6 :2 609 :2 5f6
:2 60a :2 5f6 :2 60b :2 5f6
:2 60c :2 5f6 :2 60d :2 5f6
:2 60e :2 5f6 :2 60f :2 5f6
:2 610 :2 5f6 :2 610 :2 5f6
:2 611 :2 5f6 :2 612 :2 5f6
:2 613 :2 5f6 :2 614 :2 5f6
:2 615 :2 5f6 :2 615 :2 5f6
:2 615 :2 5f6 :2 616 :2 5f6
5f5 :5 619 :6 61a :5 61b
61a :5 61d 61c :3 61a
618 :2 620 :5 622 :11 623
:24 624 :b 625 :3 623 :2 621
:6 620 61f :3 5b3 62a
62b :2 62c :2 62b :2 62d
:2 62b :2 62e :2 62b :9 62e
:2 62b :2 62f :2 62b :2 630
:2 62b :9 630 :2 62b :2 631
:2 62b :2 632 :2 62b :2 633
:2 62b :2 634 :2 62b :2 635
:2 62b :2 636 :2 62b :2 637
:2 62b :2 638 :2 62b :2 639
:2 62b :3 639 :2 63a :4 639
:2 62b :2 63a :2 62b :2 63b
:2 62b :9 63b :2 62b :2 63c
:2 62b :2 63d :2 62b :2 63e
:2 62b :2 63f :2 62b :2 640
:2 62b 62a 641 5b3
:c 641 :5 643 :5 644 :2 646
:2 647 :2 646 :2 648 :2 646
:2 649 :2 646 :2 64a :2 646
:2 64b :2 646 :2 64b :2 646
:2 64b :2 646 :2 64c :2 646
:2 64c :2 646 :2 64c :3 646
:5 64f :6 650 :5 651 650
:5 653 652 :3 650 64e
:2 656 :5 658 :11 659 :24 65a
:b 65b :3 659 :2 657 :6 656
655 :3 641 :5 661 :5 662
:2 664 :2 665 :2 664 :2 666
:2 664 :2 667 :2 664 :2 668
:2 664 :2 669 :2 664 :2 669
:2 664 :2 669 :2 664 :2 66a
:2 664 :2 66a :3 664 :5 66d
:6 66e :5 66f 66e :5 671
670 :3 66e 66c :2 674
:5 676 :11 677 :24 678 :b 679
:3 677 :2 675 :6 674 673
:3 641 :7 67e 67f 680
:2 681 :2 680 :2 682 :2 680
:2 683 :2 680 :2 684 :2 680
:2 685 :2 680 :2 686 :2 680
:2 687 :2 680 :2 688 :2 680
:2 689 :2 680 :2 689 :2 680
:2 68a :2 680 :2 68b :2 680
:2 68b :2 680 :2 68c :2 680
:2 68d :2 680 :2 68e :2 680
:2 68e :2 680 :2 68e :2 680
67f :5 691 :6 692 :5 693
692 :5 695 694 :3 692
690 :2 698 :5 69a :11 69b
:24 69c :b 69d :3 69b :2 699
:6 698 697 :3 641 6a2
6a3 :2 6a4 :2 6a3 :2 6a5
:2 6a3 :2 6a6 :2 6a3 :9 6a6
:2 6a3 :2 6a7 :2 6a3 :9 6a8
:2 6a3 :2 6a9 :2 6a3 :2 6aa
:2 6a3 :2 6ab :2 6a3 :2 6ac
:2 6a3 :2 6ad :2 6a3 6a2
641 5b3 :5 6b0 :5 6b1
:2 6b3 :2 6b4 :2 6b3 :2 6b5
:2 6b3 :2 6b6 :2 6b3 :2 6b7
:2 6b3 :2 6b8 :2 6b3 :2 6b9
:2 6b3 :2 6b9 :2 6b3 :2 6b9
:2 6b3 :2 6ba :2 6b3 :2 6ba
:2 6b3 :2 6ba :2 6b3 :2 6bb
:3 6b3 :5 6be :6 6bf :5 6c0
6bf :5 6c2 6c1 :3 6bf
6bd :2 6c5 :5 6c7 :11 6c8
:24 6c9 :b 6ca :3 6c8 :2 6c6
:6 6c5 6c4 :3 6ae :5 6d0
:5 6d1 :2 6d3 :2 6d4 :2 6d3
:2 6d5 :2 6d3 :2 6d6 :2 6d3
:2 6d7 :2 6d3 :2 6d8 :2 6d3
:2 6d8 :2 6d3 :2 6d8 :2 6d3
:2 6d9 :2 6d3 :2 6d9 :3 6d3
:5 6dc :6 6dd :5 6de 6dd
:5 6e0 6df :3 6dd 6db
:2 6e3 :5 6e5 :11 6e6 :24 6e7
:b 6e8 :3 6e6 :2 6e4 :6 6e3
6e2 :3 6ae :7 6ed 6ef
6f0 :2 6f1 :2 6f0 :2 6f2
:2 6f0 :2 6f3 :2 6f0 :2 6f4
:2 6f0 :2 6f5 :2 6f0 :2 6f6
:2 6f0 :2 6f7 :2 6f0 :2 6f8
:2 6f0 :2 6f9 :2 6f0 :2 6f9
:2 6f0 :2 6fa :2 6f0 :2 6fb
:2 6f0 :2 6fc :2 6f0 :2 6fd
:2 6f0 :2 6fd :2 6f0 :2 6fd
:2 6f0 6ef :5 700 :6 701
:5 702 701 :5 704 703
:3 701 6ff :2 707 :5 709
:11 70a :24 70b :b 70c :3 70a
:2 708 :6 707 706 :3 6ae
:2 711 :2 712 :2 711 :2 713
:2 711 :2 714 :2 711 :9 715
:2 711 :2 715 :2 711 :2 716
:2 711 :3 716 :2 717 :4 716
:2 711 :2 718 :2 711 :2 719
:2 711 :2 71a :2 711 :2 71b
:2 711 :2 71c :3 711 6ae
:3 5b3 :11 720 :b 721 :3 720
:11 723 :b 724 :3 723 :8 726
59 :3 72a :11 72b :b 72c
:17 72d :3 72b :2 72f :3 730
:3 731 732 730 72f
730 :3 733 :3 72a :2 734
:5 736 :11 737 :b 738 :18 739
:3 737 :2 73b 73c :3 73d
73e 73c 73b 73c
:3 73f :2 735 :6 734 729
:7 1 
a98f
4
:3 0 1 :3 0 2
:a 0 30c9 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f 4 :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 30c9 2 44
:2 0 18 :2 0 33
4 :3 0 18 :2 0
31 47 49 :6 0
4c 4a 0 30c7
0 17 :6 0 18
:2 0 37 4 :3 0
35 4e 50 :6 0
53 51 0 30c7
0 19 :6 0 18
:2 0 3b 4 :3 0
39 55 57 :6 0
5a 58 0 30c7
0 1a :6 0 18
:2 0 3f 4 :3 0
3d 5c 5e :6 0
61 5f 0 30c7
0 1b :6 0 18
:2 0 43 4 :3 0
41 63 65 :6 0
68 66 0 30c7
0 1c :6 0 18
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 30c7
0 1d :6 0 20
:2 0 4b 4 :3 0
49 71 73 :6 0
76 74 0 30c7
0 1e :6 0 20
:2 0 4f 4 :3 0
4d 78 7a :6 0
7d 7b 0 30c7
0 1f :6 0 20
:2 0 53 4 :3 0
51 7f 81 :6 0
84 82 0 30c7
0 21 :6 0 59
276 0 57 4
:3 0 55 86 88
:6 0 8b 89 0
30c7 0 22 :6 0
27 :2 0 5b 24
:3 0 8d :7 0 90
8e 0 30c7 0
23 :6 0 24 :3 0
92 :7 0 95 93
0 30c7 0 25
:6 0 18 :2 0 5f
4 :3 0 5d 97
99 :6 0 9c 9a
0 30c7 0 26
:6 0 2a :2 0 63
4 :3 0 61 9e
a0 :6 0 a3 a1
0 30c7 0 28
:6 0 2a :2 0 67
4 :3 0 65 a5
a7 :6 0 aa a8
0 30c7 0 29
:6 0 2a :2 0 6b
4 :3 0 69 ac
ae :6 0 b1 af
0 30c7 0 2b
:6 0 2e :2 0 6f
4 :3 0 6d b3
b5 :6 0 b8 b6
0 30c7 0 2c
:6 0 30 :2 0 73
4 :3 0 71 ba
bc :6 0 bf bd
0 30c7 0 2d
:6 0 30 :2 0 75
8 :3 0 c1 :7 0
c5 c2 c3 30c7
0 2f :6 0 30
:2 0 77 8 :3 0
c7 :7 0 cb c8
c9 30c7 0 31
:6 0 30 :2 0 79
8 :3 0 cd :7 0
d1 ce cf 30c7
0 32 :6 0 30
:2 0 7b 8 :3 0
d3 :7 0 d7 d4
d5 30c7 0 33
:6 0 30 :2 0 7d
8 :3 0 d9 :7 0
dd da db 30c7
0 34 :6 0 30
:2 0 7f 8 :3 0
df :7 0 e3 e0
e1 30c7 0 35
:6 0 30 :2 0 81
8 :3 0 e5 :7 0
e9 e6 e7 30c7
0 36 :6 0 30
:2 0 83 8 :3 0
eb :7 0 ef ec
ed 30c7 0 37
:6 0 30 :2 0 85
8 :3 0 f1 :7 0
f5 f2 f3 30c7
0 38 :6 0 30
:2 0 87 8 :3 0
f7 :7 0 fb f8
f9 30c7 0 39
:6 0 30 :2 0 89
8 :3 0 fd :7 0
101 fe ff 30c7
0 3a :6 0 30
:2 0 8b 8 :3 0
103 :7 0 107 104
105 30c7 0 3b
:6 0 30 :2 0 8d
8 :3 0 109 :7 0
10d 10a 10b 30c7
0 3c :6 0 30
:2 0 8f 8 :3 0
10f :7 0 113 110
111 30c7 0 3d
:6 0 30 :2 0 91
8 :3 0 115 :7 0
119 116 117 30c7
0 3e :6 0 30
:2 0 93 8 :3 0
11b :7 0 11f 11c
11d 30c7 0 3f
:6 0 30 :2 0 95
8 :3 0 121 :7 0
125 122 123 30c7
0 40 :6 0 30
:2 0 97 8 :3 0
127 :7 0 12b 128
129 30c7 0 41
:6 0 30 :2 0 99
8 :3 0 12d :7 0
131 12e 12f 30c7
0 42 :6 0 30
:2 0 9b 8 :3 0
133 :7 0 137 134
135 30c7 0 43
:6 0 30 :2 0 9d
8 :3 0 139 :7 0
13d 13a 13b 30c7
0 44 :6 0 30
:2 0 9f 8 :3 0
13f :7 0 143 140
141 30c7 0 45
:6 0 30 :2 0 a1
8 :3 0 145 :7 0
149 146 147 30c7
0 46 :6 0 30
:2 0 a3 8 :3 0
14b :7 0 14f 14c
14d 30c7 0 47
:6 0 30 :2 0 a5
8 :3 0 151 :7 0
155 152 153 30c7
0 48 :6 0 30
:2 0 a7 8 :3 0
157 :7 0 15b 158
159 30c7 0 49
:6 0 30 :2 0 a9
8 :3 0 15d :7 0
161 15e 15f 30c7
0 4a :6 0 27
:2 0 ab 8 :3 0
163 :7 0 167 164
165 30c7 0 4b
:6 0 27 :2 0 af
4 :3 0 ad 169
16b :6 0 16e 16c
0 30c7 0 4c
:6 0 50 :2 0 b3
4 :3 0 b1 170
172 :6 0 175 173
0 30c7 0 4d
:6 0 52 :2 0 b5
4f :3 0 177 :7 0
17b 178 179 30c7
0 4e :6 0 30
:2 0 b9 4 :3 0
b7 17d 17f :6 0
182 180 0 30c7
0 51 :6 0 18
:2 0 bb 8 :3 0
184 :7 0 188 185
186 30c7 0 53
:6 0 18 :2 0 bf
55 :3 0 bd 18a
18c :6 0 18f 18d
0 30c7 0 54
:6 0 18 :2 0 c3
55 :3 0 c1 191
193 :6 0 196 194
0 30c7 0 56
:6 0 30 :2 0 c7
4 :3 0 c5 198
19a :6 0 19d 19b
0 30c7 0 57
:6 0 30 :2 0 c9
8 :3 0 19f :7 0
1a3 1a0 1a1 30c7
0 58 :6 0 30
:2 0 cb 8 :3 0
1a5 :7 0 1a9 1a6
1a7 30c7 0 59
:6 0 20 :2 0 cd
8 :3 0 1ab :7 0
1af 1ac 1ad 30c7
0 5a :6 0 20
:2 0 d1 4 :3 0
cf 1b1 1b3 :6 0
1b6 1b4 0 30c7
0 5b :6 0 30
:2 0 d5 4 :3 0
d3 1b8 1ba :6 0
1bd 1bb 0 30c7
0 5c :6 0 30
:2 0 d7 8 :3 0
1bf :7 0 1c3 1c0
1c1 30c7 0 5d
:6 0 18 :2 0 d9
8 :3 0 1c5 :7 0
1c9 1c6 1c7 30c7
0 5e :6 0 27
:2 0 dd 4 :3 0
db 1cb 1cd :6 0
1d0 1ce 0 30c7
0 5f :6 0 27
:2 0 df 8 :3 0
1d2 0 2 :5 0
1d6 1d3 1d4 30c7
0 60 :6 0 30
:2 0 e1 8 :3 0
1d8 0 2 :5 0
1dc 1d9 1da 30c7
0 61 :6 0 30
:2 0 e3 8 :3 0
1de 0 2 :5 0
1e2 1df 1e0 30c7
0 62 :6 0 e7
8a1 0 e5 8
:3 0 1e4 0 2
:5 0 1e8 1e5 1e6
30c7 0 63 :6 0
1f5 1f6 0 e9
8 :3 0 1ea :7 0
1ed 1eb 0 30c7
0 64 :6 0 15
:3 0 16 :2 0 4
1ef 1f0 0 1f1
:7 0 1f4 1f2 0
30c7 0 65 :6 0
66 :3 0 67 :3 0
66 :3 0 68 :3 0
1f8 1f9 0 2
:4 0 eb 1fa 1fc
1f7 1fe 1fd :2 0
69 :3 0 6a :3 0
200 201 0 6b
:4 0 66 :3 0 6c
:3 0 204 205 0
2 :4 0 ed 206
208 6d :4 0 6e
:2 0 6f :3 0 ef
20b 20d :3 0 70
:4 0 6e :2 0 71
:4 0 f2 210 212
:3 0 6e :2 0 3
:3 0 f5 214 216
:3 0 6e :2 0 71
:4 0 f8 218 21a
:3 0 6e :2 0 72
:4 0 fb 21c 21e
:3 0 6e :2 0 71
:4 0 fe 220 222
:3 0 6e :2 0 5
:3 0 101 224 226
:3 0 6e :2 0 71
:4 0 104 228 22a
:3 0 6e :2 0 72
:4 0 107 22c 22e
:3 0 6e :2 0 71
:4 0 10a 230 232
:3 0 6e :2 0 6
:3 0 10d 234 236
:3 0 6e :2 0 71
:4 0 110 238 23a
:3 0 6e :2 0 72
:4 0 113 23c 23e
:3 0 6e :2 0 73
:3 0 74 :3 0 7
:3 0 116 242 244
75 :4 0 118 241
247 11b 240 249
:3 0 6e :2 0 72
:4 0 11e 24b 24d
:3 0 6e :2 0 73
:3 0 74 :3 0 9
:3 0 121 251 253
75 :4 0 123 250
256 126 24f 258
:3 0 6e :2 0 72
:4 0 129 25a 25c
:3 0 6e :2 0 73
:3 0 74 :3 0 a
:3 0 12c 260 262
75 :4 0 12e 25f
265 131 25e 267
:3 0 6e :2 0 72
:4 0 134 269 26b
:3 0 6e :2 0 73
:3 0 74 :3 0 b
:3 0 137 26f 271
75 :4 0 139 26e
274 13c 26d 276
:3 0 6e :2 0 72
:4 0 13f 278 27a
:3 0 6e :2 0 73
:3 0 74 :3 0 c
:3 0 142 27e 280
75 :4 0 144 27d
283 147 27c 285
:3 0 6e :2 0 72
:4 0 14a 287 289
:3 0 6e :2 0 73
:3 0 74 :3 0 d
:3 0 14d 28d 28f
75 :4 0 14f 28c
292 152 28b 294
:3 0 6e :2 0 72
:4 0 155 296 298
:3 0 6e :2 0 73
:3 0 74 :3 0 e
:3 0 158 29c 29e
75 :4 0 15a 29b
2a1 15d 29a 2a3
:3 0 6e :2 0 72
:4 0 160 2a5 2a7
:3 0 6e :2 0 73
:3 0 74 :3 0 f
:3 0 163 2ab 2ad
75 :4 0 165 2aa
2b0 168 2a9 2b2
:3 0 6e :2 0 72
:4 0 16b 2b4 2b6
:3 0 6e :2 0 73
:3 0 74 :3 0 10
:3 0 16e 2ba 2bc
75 :4 0 170 2b9
2bf 173 2b8 2c1
:3 0 6e :2 0 72
:4 0 176 2c3 2c5
:3 0 6e :2 0 73
:3 0 74 :3 0 11
:3 0 179 2c9 2cb
75 :4 0 17b 2c8
2ce 17e 2c7 2d0
:3 0 6e :2 0 72
:4 0 181 2d2 2d4
:3 0 6e :2 0 71
:4 0 184 2d6 2d8
:3 0 6e :2 0 12
:3 0 187 2da 2dc
:3 0 6e :2 0 71
:4 0 18a 2de 2e0
:3 0 6e :2 0 72
:4 0 18d 2e2 2e4
:3 0 6e :2 0 71
:4 0 190 2e6 2e8
:3 0 6e :2 0 13
:3 0 193 2ea 2ec
:3 0 6e :2 0 71
:4 0 196 2ee 2f0
:3 0 6e :2 0 76
:4 0 199 2f2 2f4
:3 0 19c 202 2f6
:2 0 2f8 1a1 2f9
1ff 2f8 0 2fa
1a3 0 3027 66
:3 0 67 :3 0 2fb
2fc 0 66 :3 0
77 :3 0 2fe 2ff
0 27 :2 0 2
:4 0 78 :2 0 79
:2 0 27 :2 0 1a5
304 306 :3 0 1a8
300 308 2fd 30a
309 :2 0 69 :3 0
7a :3 0 30c 30d
0 6b :4 0 7b
:4 0 6e :2 0 6f
:3 0 1ac 311 313
:3 0 1af 30e 315
:2 0 317 1b2 318
30b 317 0 319
1b4 0 3027 17
:3 0 3 :3 0 31a
31b 0 3027 1f
:3 0 5 :3 0 31d
31e 0 3027 22
:3 0 6 :3 0 320
321 0 3027 1c
:3 0 13 :3 0 323
324 0 3027 37
:3 0 7 :3 0 326
327 0 3027 35
:3 0 9 :3 0 329
32a 0 3027 36
:3 0 e :3 0 32c
32d 0 3027 38
:3 0 b :3 0 32f
330 0 3027 3a
:3 0 f :3 0 332
333 0 3027 39
:3 0 c :3 0 335
336 0 3027 32
:3 0 11 :3 0 338
339 0 3027 31
:3 0 a :3 0 33b
33c 0 3027 3b
:3 0 d :3 0 33e
33f 0 3027 33
:3 0 10 :3 0 341
342 0 3027 1a
:3 0 17 :3 0 344
345 0 3027 23
:3 0 7c :4 0 347
348 0 3027 19
:4 0 34a 34b 0
3027 5a :3 0 7d
:3 0 73 :3 0 32
:3 0 30 :2 0 1b6
34f 352 1b9 34e
354 34d 355 0
3027 5d :3 0 30
:2 0 357 358 0
3027 4e :3 0 50
:2 0 35a 35b 0
3027 3f :3 0 30
:2 0 35d 35e 0
3027 3 :3 0 7e
:2 0 1bb 361 362
:3 0 363 :2 0 66
:3 0 67 :3 0 365
366 0 66 :3 0
77 :3 0 368 369
0 7f :2 0 2
:4 0 80 :2 0 79
:2 0 27 :2 0 1bd
36e 370 :3 0 1c0
36a 372 367 374
373 :2 0 69 :3 0
7a :3 0 376 377
0 6b :4 0 81
:4 0 6e :2 0 6f
:3 0 1c4 37b 37d
:3 0 6e :2 0 82
:4 0 1c7 37f 381
:3 0 6e :2 0 83
:4 0 1ca 383 385
:3 0 6e :2 0 73
:3 0 74 :3 0 84
:3 0 85 :3 0 38a
38b 0 1cd 389
38d 75 :4 0 1cf
388 390 1d2 387
392 :3 0 1d5 378
394 :2 0 396 1d8
397 375 396 0
398 1da 0 3c1
66 :3 0 67 :3 0
399 39a 0 66
:3 0 77 :3 0 39c
39d 0 27 :2 0
2 :4 0 86 :2 0
79 :2 0 27 :2 0
1dc 3a2 3a4 :3 0
1df 39e 3a6 39b
3a8 3a7 :2 0 69
:3 0 7a :3 0 3aa
3ab 0 6b :4 0
87 :4 0 6e :2 0
6f :3 0 1e3 3af
3b1 :3 0 1e6 3ac
3b3 :2 0 3b5 1e9
3b6 3a9 3b5 0
3b7 1eb 0 3c1
88 :3 0 89 :3 0
3b8 3b9 0 84
:3 0 85 :3 0 3bb
3bc 0 8a :3 0
1ed 3ba 3bf :2 0
3c1 1f0 3c2 364
3c1 0 3c3 1f4
0 3027 12 :3 0
7e :2 0 1f6 3c5
3c6 :3 0 3c7 :2 0
66 :3 0 67 :3 0
3c9 3ca 0 66
:3 0 77 :3 0 3cc
3cd 0 7f :2 0
2 :4 0 8b :2 0
79 :2 0 27 :2 0
1f8 3d2 3d4 :3 0
1fb 3ce 3d6 3cb
3d8 3d7 :2 0 69
:3 0 7a :3 0 3da
3db 0 6b :4 0
8c :4 0 6e :2 0
6f :3 0 1ff 3df
3e1 :3 0 6e :2 0
82 :4 0 202 3e3
3e5 :3 0 6e :2 0
83 :4 0 205 3e7
3e9 :3 0 6e :2 0
73 :3 0 74 :3 0
84 :3 0 85 :3 0
3ee 3ef 0 208
3ed 3f1 75 :4 0
20a 3ec 3f4 20d
3eb 3f6 :3 0 210
3dc 3f8 :2 0 3fa
213 3fb 3d9 3fa
0 3fc 215 0
425 66 :3 0 67
:3 0 3fd 3fe 0
66 :3 0 77 :3 0
400 401 0 27
:2 0 2 :4 0 8d
:2 0 79 :2 0 27
:2 0 217 406 408
:3 0 21a 402 40a
3ff 40c 40b :2 0
69 :3 0 7a :3 0
40e 40f 0 6b
:4 0 8e :4 0 6e
:2 0 6f :3 0 21e
413 415 :3 0 221
410 417 :2 0 419
224 41a 40d 419
0 41b 226 0
425 88 :3 0 89
:3 0 41c 41d 0
84 :3 0 85 :3 0
41f 420 0 8a
:3 0 228 41e 423
:2 0 425 22b 426
3c8 425 0 427
22f 0 3027 6
:3 0 8f :2 0 231
429 42a :3 0 42b
:2 0 73 :3 0 90
:3 0 22 :3 0 233
42e 430 30 :2 0
235 42d 433 91
:2 0 92 :2 0 23a
435 437 :3 0 438
:2 0 42c 43a 439
:2 0 43b :2 0 66
:3 0 67 :3 0 43d
43e 0 66 :3 0
77 :3 0 440 441
0 7f :2 0 2
:4 0 93 :2 0 79
:2 0 27 :2 0 23d
446 448 :3 0 240
442 44a 43f 44c
44b :2 0 69 :3 0
7a :3 0 44e 44f
0 6b :4 0 94
:4 0 6e :2 0 6f
:3 0 244 453 455
:3 0 6e :2 0 82
:4 0 247 457 459
:3 0 6e :2 0 83
:4 0 24a 45b 45d
:3 0 6e :2 0 73
:3 0 74 :3 0 84
:3 0 95 :3 0 462
463 0 24d 461
465 75 :4 0 24f
460 468 252 45f
46a :3 0 255 450
46c :2 0 46e 258
46f 44d 46e 0
470 25a 0 499
66 :3 0 67 :3 0
471 472 0 66
:3 0 77 :3 0 474
475 0 27 :2 0
2 :4 0 96 :2 0
79 :2 0 27 :2 0
25c 47a 47c :3 0
25f 476 47e 473
480 47f :2 0 69
:3 0 7a :3 0 482
483 0 6b :4 0
97 :4 0 6e :2 0
6f :3 0 263 487
489 :3 0 266 484
48b :2 0 48d 269
48e 481 48d 0
48f 26b 0 499
88 :3 0 89 :3 0
490 491 0 84
:3 0 95 :3 0 493
494 0 8a :3 0
26d 492 497 :2 0
499 270 49a 43c
499 0 49b 274
0 3027 5 :3 0
8f :2 0 276 49d
49e :3 0 49f :2 0
73 :3 0 90 :3 0
1f :3 0 278 4a2
4a4 30 :2 0 27a
4a1 4a7 91 :2 0
92 :2 0 27f 4a9
4ab :3 0 4ac :2 0
4a0 4ae 4ad :2 0
4af :2 0 66 :3 0
67 :3 0 4b1 4b2
0 66 :3 0 77
:3 0 4b4 4b5 0
7f :2 0 2 :4 0
98 :2 0 79 :2 0
27 :2 0 282 4ba
4bc :3 0 285 4b6
4be 4b3 4c0 4bf
:2 0 69 :3 0 7a
:3 0 4c2 4c3 0
6b :4 0 99 :4 0
6e :2 0 6f :3 0
289 4c7 4c9 :3 0
6e :2 0 82 :4 0
28c 4cb 4cd :3 0
6e :2 0 83 :4 0
28f 4cf 4d1 :3 0
6e :2 0 73 :3 0
74 :3 0 84 :3 0
95 :3 0 4d6 4d7
0 292 4d5 4d9
75 :4 0 294 4d4
4dc 297 4d3 4de
:3 0 29a 4c4 4e0
:2 0 4e2 29d 4e3
4c1 4e2 0 4e4
29f 0 50d 66
:3 0 67 :3 0 4e5
4e6 0 66 :3 0
77 :3 0 4e8 4e9
0 27 :2 0 2
:4 0 9a :2 0 79
:2 0 27 :2 0 2a1
4ee 4f0 :3 0 2a4
4ea 4f2 4e7 4f4
4f3 :2 0 69 :3 0
7a :3 0 4f6 4f7
0 6b :4 0 9b
:4 0 6e :2 0 6f
:3 0 2a8 4fb 4fd
:3 0 2ab 4f8 4ff
:2 0 501 2ae 502
4f5 501 0 503
2b0 0 50d 88
:3 0 89 :3 0 504
505 0 84 :3 0
95 :3 0 507 508
0 8a :3 0 2b2
506 50b :2 0 50d
2b5 50e 4b0 50d
0 50f 2b9 0
3027 73 :3 0 31
:3 0 30 :2 0 2bb
510 513 9c :2 0
9d :2 0 2c0 515
517 :3 0 73 :3 0
39 :3 0 30 :2 0
2c3 519 51c 9c
:2 0 9d :2 0 2c8
51e 520 :3 0 518
522 521 :2 0 73
:3 0 35 :3 0 30
:2 0 2cb 524 527
9c :2 0 9d :2 0
2d0 529 52b :3 0
523 52d 52c :2 0
66 :3 0 67 :3 0
52f 530 0 66
:3 0 77 :3 0 532
533 0 7f :2 0
2 :4 0 9e :2 0
79 :2 0 27 :2 0
2d3 538 53a :3 0
2d6 534 53c 531
53e 53d :2 0 69
:3 0 7a :3 0 540
541 0 6b :4 0
9f :4 0 6e :2 0
6f :3 0 2da 545
547 :3 0 6e :2 0
82 :4 0 2dd 549
54b :3 0 6e :2 0
83 :4 0 2e0 54d
54f :3 0 6e :2 0
73 :3 0 74 :3 0
84 :3 0 95 :3 0
554 555 0 2e3
553 557 75 :4 0
2e5 552 55a 2e8
551 55c :3 0 2eb
542 55e :2 0 560
2ee 561 53f 560
0 562 2f0 0
58b 66 :3 0 67
:3 0 563 564 0
66 :3 0 77 :3 0
566 567 0 27
:2 0 2 :4 0 a0
:2 0 79 :2 0 27
:2 0 2f2 56c 56e
:3 0 2f5 568 570
565 572 571 :2 0
69 :3 0 7a :3 0
574 575 0 6b
:4 0 a1 :4 0 6e
:2 0 6f :3 0 2f9
579 57b :3 0 2fc
576 57d :2 0 57f
2ff 580 573 57f
0 581 301 0
58b 88 :3 0 89
:3 0 582 583 0
84 :3 0 95 :3 0
585 586 0 8a
:3 0 303 584 589
:2 0 58b 306 58c
52e 58b 0 58d
30a 0 3027 5
:3 0 8f :2 0 30c
58f 590 :3 0 591
:2 0 592 :2 0 6
:3 0 8f :2 0 30e
595 596 :3 0 597
:2 0 598 :2 0 593
59a 599 :2 0 a2
:3 0 a3 :3 0 6
:3 0 a2 :3 0 a3
:3 0 5 :3 0 44
:3 0 a4 :4 0 a5
1 :8 0 5aa 15
:3 0 a6 :3 0 5a5
5a6 0 a7 :3 0
5a7 5a8 0 5aa
310 5f4 a8 :3 0
15 :3 0 a6 :3 0
5ad 5ae 0 a7
:3 0 5af 5b0 0
5ea 66 :3 0 67
:3 0 5b2 5b3 0
66 :3 0 77 :3 0
5b5 5b6 0 a9
:2 0 2 :4 0 aa
:2 0 79 :2 0 27
:2 0 313 5bb 5bd
:3 0 316 5b7 5bf
5b4 5c1 5c0 :2 0
69 :3 0 7a :3 0
5c3 5c4 0 6b
:4 0 ab :4 0 6e
:2 0 6f :3 0 31a
5c8 5ca :3 0 6e
:2 0 82 :4 0 31d
5cc 5ce :3 0 6e
:2 0 ac :4 0 320
5d0 5d2 :3 0 6e
:2 0 a7 :3 0 323
5d4 5d6 :3 0 6e
:2 0 ad :4 0 326
5d8 5da :3 0 6e
:2 0 ae :3 0 af
:3 0 27 :2 0 b0
:2 0 329 5dd 5e1
32d 5dc 5e3 :3 0
330 5c5 5e5 :2 0
5e7 333 5e8 5c2
5e7 0 5e9 335
0 5ea 337 5ed
:3 0 5ed 0 5ed
5ec 5ea 5eb :6 0
5ef 2 :3 0 33a
5f1 33c 5f0 5ef
:2 0 5f2 33e :2 0
5f4 0 5f4 5f3
5aa 5f2 :6 0 66f
1 :3 0 15 :3 0
a6 :3 0 5f6 5f7
0 15 :3 0 9c
:2 0 b1 :3 0 5f9
5fb 0 342 5fa
5fd :3 0 5fe :2 0
73 :3 0 44 :3 0
30 :2 0 345 600
603 91 :2 0 30
:2 0 34a 605 607
:3 0 608 :2 0 5ff
60a 609 :2 0 66
:3 0 67 :3 0 60c
60d 0 66 :3 0
77 :3 0 60f 610
0 7f :2 0 2
:4 0 b2 :2 0 79
:2 0 27 :2 0 34d
615 617 :3 0 350
611 619 60e 61b
61a :2 0 69 :3 0
7a :3 0 61d 61e
0 6b :4 0 b3
:4 0 6e :2 0 6f
:3 0 354 622 624
:3 0 6e :2 0 82
:4 0 357 626 628
:3 0 6e :2 0 83
:4 0 35a 62a 62c
:3 0 6e :2 0 73
:3 0 74 :3 0 84
:3 0 b4 :3 0 631
632 0 35d 630
634 75 :4 0 35f
62f 637 362 62e
639 :3 0 365 61f
63b :2 0 63d 368
63e 61c 63d 0
63f 36a 0 668
66 :3 0 67 :3 0
640 641 0 66
:3 0 77 :3 0 643
644 0 27 :2 0
2 :4 0 b5 :2 0
79 :2 0 27 :2 0
36c 649 64b :3 0
36f 645 64d 642
64f 64e :2 0 69
:3 0 7a :3 0 651
652 0 6b :4 0
b6 :4 0 6e :2 0
6f :3 0 373 656
658 :3 0 376 653
65a :2 0 65c 379
65d 650 65c 0
65e 37b 0 668
88 :3 0 89 :3 0
65f 660 0 84
:3 0 b4 :3 0 662
663 0 8a :3 0
37d 661 666 :2 0
668 380 669 60b
668 0 66a 384
0 66f 63 :3 0
27 :2 0 66b 66c
0 66f b7 :3 0
386 6d5 5 :3 0
7e :2 0 38a 671
672 :3 0 673 :2 0
674 :2 0 6 :3 0
7e :2 0 38c 677
678 :3 0 679 :2 0
67a :2 0 675 67c
67b :2 0 6f :3 0
1f :3 0 a4 :4 0
b8 1 :8 0 687
15 :3 0 a6 :3 0
682 683 0 a7
:3 0 684 685 0
687 38e 6d1 a8
:3 0 15 :3 0 a6
:3 0 68a 68b 0
a7 :3 0 68c 68d
0 6c7 66 :3 0
67 :3 0 68f 690
0 66 :3 0 77
:3 0 692 693 0
a9 :2 0 2 :4 0
b9 :2 0 79 :2 0
27 :2 0 391 698
69a :3 0 394 694
69c 691 69e 69d
:2 0 69 :3 0 7a
:3 0 6a0 6a1 0
6b :4 0 ba :4 0
6e :2 0 6f :3 0
398 6a5 6a7 :3 0
6e :2 0 82 :4 0
39b 6a9 6ab :3 0
6e :2 0 ac :4 0
39e 6ad 6af :3 0
6e :2 0 a7 :3 0
3a1 6b1 6b3 :3 0
6e :2 0 ad :4 0
3a4 6b5 6b7 :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 3a7 6ba
6be 3ab 6b9 6c0
:3 0 3ae 6a2 6c2
:2 0 6c4 3b1 6c5
69f 6c4 0 6c6
3b3 0 6c7 3b5
6ca :3 0 6ca 0
6ca 6c9 6c7 6c8
:6 0 6cc 4 :3 0
3b8 6ce 3ba 6cd
6cc :2 0 6cf 3bc
:2 0 6d1 0 6d1
6d0 687 6cf :6 0
6d3 1 :3 0 3be
6d4 67d 6d3 0
6d6 59b 66f 0
6d6 3c0 0 3027
21 :3 0 1f :3 0
6d7 6d8 0 3027
6 :3 0 7e :2 0
3c3 6db 6dc :3 0
6dd :2 0 22 :3 0
7c :4 0 6df 6e0
0 6e2 3c5 6e3
6de 6e2 0 6e4
3c7 0 3027 1d
:3 0 ae :3 0 1d
:3 0 27 :2 0 18
:2 0 3c9 6e6 6ea
6e5 6eb 0 3027
26 :3 0 ae :3 0
26 :3 0 27 :2 0
27 :2 0 3cd 6ee
6f2 6ed 6f3 0
3027 29 :3 0 12
:3 0 6f5 6f6 0
3027 73 :3 0 32
:3 0 30 :2 0 3d1
6f8 6fb bb :2 0
30 :2 0 3d6 6fd
6ff :3 0 1d :3 0
ae :3 0 ae :3 0
29 :3 0 27 :2 0
18 :2 0 3d9 703
707 27 :2 0 18
:2 0 3dd 702 70b
701 70c 0 aa7
26 :3 0 bc :3 0
bd :3 0 70f 710
0 27 :2 0 27
:2 0 be :2 0 29
:3 0 3e1 711 716
70e 717 0 aa7
bf :3 0 73 :3 0
32 :3 0 30 :2 0
3e6 71a 71d 3e9
719 71f c0 :2 0
30 :2 0 3ed 721
723 :3 0 c1 :3 0
73 :3 0 c2 :3 0
73 :3 0 c3 :3 0
c4 :3 0 17 :3 0
3d :3 0 3e :3 0
43 :3 0 c5 :3 0
c6 :3 0 1a :4 0
c7 1 :8 0 738
15 :3 0 a6 :3 0
733 734 0 a7
:3 0 735 736 0
738 3f0 782 a8
:3 0 15 :3 0 a6
:3 0 73b 73c 0
a7 :3 0 73d 73e
0 778 66 :3 0
67 :3 0 740 741
0 66 :3 0 77
:3 0 743 744 0
a9 :2 0 2 :4 0
c8 :2 0 79 :2 0
27 :2 0 3f3 749
74b :3 0 3f6 745
74d 742 74f 74e
:2 0 69 :3 0 7a
:3 0 751 752 0
6b :4 0 c9 :4 0
6e :2 0 6f :3 0
3fa 756 758 :3 0
6e :2 0 82 :4 0
3fd 75a 75c :3 0
6e :2 0 ac :4 0
400 75e 760 :3 0
6e :2 0 a7 :3 0
403 762 764 :3 0
6e :2 0 ad :4 0
406 766 768 :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 409 76b
76f 40d 76a 771
:3 0 410 753 773
:2 0 775 413 776
750 775 0 777
415 0 778 417
77b :3 0 77b 0
77b 77a 778 779
:6 0 77d 6 :3 0
41a 77f 41c 77e
77d :2 0 780 41e
:2 0 782 0 782
781 738 780 :6 0
784 1 :3 0 420
81d ca :3 0 cb
:3 0 ca :3 0 cc
:3 0 ca :3 0 cd
:3 0 ca :3 0 ce
:3 0 ca :3 0 c1
:3 0 73 :3 0 cf
:3 0 c2 :3 0 73
:3 0 cf :3 0 c3
:3 0 cf :3 0 c4
:3 0 32 :3 0 5d
:3 0 5b :3 0 5c
:3 0 17 :3 0 3d
:3 0 3e :3 0 43
:3 0 c5 :3 0 cf
:3 0 c5 :3 0 ca
:3 0 ca :3 0 c6
:3 0 1a :3 0 ca
:3 0 cb :3 0 84
:3 0 d0 :3 0 84
:3 0 d1 :3 0 84
:3 0 d2 :3 0 84
:3 0 d3 :3 0 84
:3 0 d4 :3 0 84
:3 0 d5 :3 0 84
:3 0 d6 :3 0 84
:3 0 d7 :3 0 84
:3 0 d8 :3 0 84
:3 0 d9 :3 0 84
:3 0 da :3 0 84
:3 0 db :3 0 84
:3 0 dc :3 0 84
:3 0 dd :3 0 84
:3 0 de :3 0 cf
:3 0 c6 :3 0 ca
:3 0 c1 :4 0 df
1 :8 0 7d0 15
:3 0 a6 :3 0 7cb
7cc 0 a7 :3 0
7cd 7ce 0 7d0
422 81a a8 :3 0
15 :3 0 a6 :3 0
7d3 7d4 0 a7
:3 0 7d5 7d6 0
810 66 :3 0 67
:3 0 7d8 7d9 0
66 :3 0 77 :3 0
7db 7dc 0 a9
:2 0 2 :4 0 e0
:2 0 79 :2 0 27
:2 0 425 7e1 7e3
:3 0 428 7dd 7e5
7da 7e7 7e6 :2 0
69 :3 0 7a :3 0
7e9 7ea 0 6b
:4 0 e1 :4 0 6e
:2 0 6f :3 0 42c
7ee 7f0 :3 0 6e
:2 0 82 :4 0 42f
7f2 7f4 :3 0 6e
:2 0 ac :4 0 432
7f6 7f8 :3 0 6e
:2 0 a7 :3 0 435
7fa 7fc :3 0 6e
:2 0 ad :4 0 438
7fe 800 :3 0 6e
:2 0 ae :3 0 af
:3 0 27 :2 0 b0
:2 0 43b 803 807
43f 802 809 :3 0
442 7eb 80b :2 0
80d 445 80e 7e8
80d 0 80f 447
0 810 449 813
:3 0 813 0 813
812 810 811 :6 0
815 8 :3 0 44c
817 44e 816 815
:2 0 818 450 :2 0
81a 0 81a 819
7d0 818 :6 0 81c
1 :3 0 452 81e
724 784 0 81f
0 81c 0 81f
454 0 aa7 15
:3 0 a6 :3 0 820
821 0 15 :3 0
9c :2 0 e2 :3 0
823 825 0 459
824 827 :3 0 828
:2 0 c1 :3 0 e3
:3 0 17 :3 0 5f
:3 0 e4 :3 0 c6
:3 0 1a :4 0 e5
1 :8 0 837 15
:3 0 a6 :3 0 832
833 0 a7 :3 0
834 835 0 837
45c 881 a8 :3 0
15 :3 0 a6 :3 0
83a 83b 0 a7
:3 0 83c 83d 0
877 66 :3 0 67
:3 0 83f 840 0
66 :3 0 77 :3 0
842 843 0 a9
:2 0 2 :4 0 e6
:2 0 79 :2 0 27
:2 0 45f 848 84a
:3 0 462 844 84c
841 84e 84d :2 0
69 :3 0 7a :3 0
850 851 0 6b
:4 0 e7 :4 0 6e
:2 0 6f :3 0 466
855 857 :3 0 6e
:2 0 82 :4 0 469
859 85b :3 0 6e
:2 0 ac :4 0 46c
85d 85f :3 0 6e
:2 0 a7 :3 0 46f
861 863 :3 0 6e
:2 0 ad :4 0 472
865 867 :3 0 6e
:2 0 ae :3 0 af
:3 0 27 :2 0 b0
:2 0 475 86a 86e
479 869 870 :3 0
47c 852 872 :2 0
874 47f 875 84f
874 0 876 481
0 877 483 87a
:3 0 87a 0 87a
879 877 878 :6 0
87c a :3 0 486
87e 488 87d 87c
:2 0 87f 48a :2 0
881 0 881 880
837 87f :6 0 967
1 :3 0 15 :3 0
a6 :3 0 883 884
0 15 :3 0 9c
:2 0 b1 :3 0 886
888 0 48e 887
88a :3 0 88b :2 0
5f :3 0 8f :2 0
491 88e 88f :3 0
890 :2 0 5a :3 0
27 :2 0 892 893
0 895 493 896
891 895 0 897
495 0 8f5 73
:3 0 c2 :3 0 73
:3 0 c3 :3 0 c4
:3 0 3d :3 0 3e
:3 0 43 :3 0 c5
:3 0 c6 :3 0 17
:4 0 e8 1 :8 0
8a9 15 :3 0 a6
:3 0 8a4 8a5 0
a7 :3 0 8a6 8a7
0 8a9 497 8f3
a8 :3 0 15 :3 0
a6 :3 0 8ac 8ad
0 a7 :3 0 8ae
8af 0 8e9 66
:3 0 67 :3 0 8b1
8b2 0 66 :3 0
77 :3 0 8b4 8b5
0 a9 :2 0 2
:4 0 e9 :2 0 79
:2 0 27 :2 0 49a
8ba 8bc :3 0 49d
8b6 8be 8b3 8c0
8bf :2 0 69 :3 0
7a :3 0 8c2 8c3
0 6b :4 0 ea
:4 0 6e :2 0 6f
:3 0 4a1 8c7 8c9
:3 0 6e :2 0 82
:4 0 4a4 8cb 8cd
:3 0 6e :2 0 ac
:4 0 4a7 8cf 8d1
:3 0 6e :2 0 a7
:3 0 4aa 8d3 8d5
:3 0 6e :2 0 ad
:4 0 4ad 8d7 8d9
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 4b0
8dc 8e0 4b4 8db
8e2 :3 0 4b7 8c4
8e4 :2 0 8e6 4ba
8e7 8c1 8e6 0
8e8 4bc 0 8e9
4be 8ec :3 0 8ec
0 8ec 8eb 8e9
8ea :6 0 8ee c
:3 0 4c1 8f0 4c3
8ef 8ee :2 0 8f1
4c5 :2 0 8f3 0
8f3 8f2 8a9 8f1
:6 0 8f5 1 :3 0
4c7 964 66 :3 0
67 :3 0 8f6 8f7
0 66 :3 0 77
:3 0 8f9 8fa 0
18 :2 0 2 :4 0
eb :2 0 79 :2 0
27 :2 0 4ca 8ff
901 :3 0 4cd 8fb
903 8f8 905 904
:2 0 69 :3 0 7a
:3 0 907 908 0
6b :4 0 ec :4 0
6e :2 0 6f :3 0
4d1 90c 90e :3 0
6e :2 0 82 :4 0
4d4 910 912 :3 0
6e :2 0 83 :4 0
4d7 914 916 :3 0
6e :2 0 73 :3 0
74 :3 0 84 :3 0
ed :3 0 91b 91c
0 4da 91a 91e
75 :4 0 4dc 919
921 4df 918 923
:3 0 6e :2 0 ee
:4 0 4e2 925 927
:3 0 6e :2 0 71
:4 0 4e5 929 92b
:3 0 6e :2 0 1a
:3 0 4e8 92d 92f
:3 0 6e :2 0 71
:4 0 4eb 931 933
:3 0 4ee 909 935
:2 0 937 4f1 938
906 937 0 939
4f3 0 963 66
:3 0 67 :3 0 93a
93b 0 66 :3 0
77 :3 0 93d 93e
0 27 :2 0 2
:4 0 ef :2 0 79
:2 0 27 :2 0 4f5
943 945 :3 0 4f8
93f 947 93c 949
948 :2 0 69 :3 0
7a :3 0 94b 94c
0 6b :4 0 f0
:4 0 6e :2 0 6f
:3 0 4fc 950 952
:3 0 4ff 94d 954
:2 0 956 502 957
94a 956 0 958
504 0 963 88
:3 0 f1 :3 0 959
95a 0 84 :3 0
ed :3 0 95c 95d
0 1a :3 0 8a
:3 0 506 95b 961
:2 0 963 50a 965
88c 8f5 0 966
0 963 0 966
50e 0 967 511
96c 5a :3 0 27
:2 0 968 969 0
96b 514 96d 829
967 0 96e 0
96b 0 96e 516
0 aa7 5e :3 0
30 :2 0 96f 970
0 aa7 f2 :3 0
5e :3 0 f3 :3 0
c1 :3 0 17 :4 0
f4 1 :8 0 97d
15 :3 0 a6 :3 0
978 979 0 a7
:3 0 97a 97b 0
97d 519 9c7 a8
:3 0 15 :3 0 a6
:3 0 980 981 0
a7 :3 0 982 983
0 9bd 66 :3 0
67 :3 0 985 986
0 66 :3 0 77
:3 0 988 989 0
a9 :2 0 2 :4 0
f5 :2 0 79 :2 0
27 :2 0 51c 98e
990 :3 0 51f 98a
992 987 994 993
:2 0 69 :3 0 7a
:3 0 996 997 0
6b :4 0 f6 :4 0
6e :2 0 6f :3 0
523 99b 99d :3 0
6e :2 0 82 :4 0
526 99f 9a1 :3 0
6e :2 0 ac :4 0
529 9a3 9a5 :3 0
6e :2 0 a7 :3 0
52c 9a7 9a9 :3 0
6e :2 0 ad :4 0
52f 9ab 9ad :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 532 9b0
9b4 536 9af 9b6
:3 0 539 998 9b8
:2 0 9ba 53c 9bb
995 9ba 0 9bc
53e 0 9bd 540
9c0 :3 0 9c0 0
9c0 9bf 9bd 9be
:6 0 9c2 e :3 0
543 9c4 545 9c3
9c2 :2 0 9c5 547
:2 0 9c7 0 9c7
9c6 97d 9c5 :6 0
aa7 1 :3 0 73
:3 0 5e :3 0 30
:2 0 549 9c9 9cc
bb :2 0 30 :2 0
54e 9ce 9d0 :3 0
f7 :3 0 4d :3 0
c5 :3 0 c6 :3 0
17 :4 0 f8 1
:8 0 9dd 15 :3 0
a6 :3 0 9d8 9d9
0 a7 :3 0 9da
9db 0 9dd 551
a27 a8 :3 0 15
:3 0 a6 :3 0 9e0
9e1 0 a7 :3 0
9e2 9e3 0 a1d
66 :3 0 67 :3 0
9e5 9e6 0 66
:3 0 77 :3 0 9e8
9e9 0 a9 :2 0
2 :4 0 f9 :2 0
79 :2 0 27 :2 0
554 9ee 9f0 :3 0
557 9ea 9f2 9e7
9f4 9f3 :2 0 69
:3 0 7a :3 0 9f6
9f7 0 6b :4 0
fa :4 0 6e :2 0
6f :3 0 55b 9fb
9fd :3 0 6e :2 0
82 :4 0 55e 9ff
a01 :3 0 6e :2 0
ac :4 0 561 a03
a05 :3 0 6e :2 0
a7 :3 0 564 a07
a09 :3 0 6e :2 0
ad :4 0 567 a0b
a0d :3 0 6e :2 0
ae :3 0 af :3 0
27 :2 0 b0 :2 0
56a a10 a14 56e
a0f a16 :3 0 571
9f8 a18 :2 0 a1a
574 a1b 9f5 a1a
0 a1c 576 0
a1d 578 a20 :3 0
a20 0 a20 a1f
a1d a1e :6 0 a22
10 :3 0 57b a24
57d a23 a22 :2 0
a25 57f :2 0 a27
0 a27 a26 9dd
a25 :6 0 aa4 1
:3 0 a2 :3 0 fb
:3 0 a29 a2a 0
4d :3 0 fc :4 0
581 a2b a2e 9c
:2 0 30 :2 0 586
a30 a32 :3 0 66
:3 0 67 :3 0 a34
a35 0 66 :3 0
77 :3 0 a37 a38
0 18 :2 0 2
:4 0 fd :2 0 79
:2 0 27 :2 0 589
a3d a3f :3 0 58c
a39 a41 a36 a43
a42 :2 0 69 :3 0
7a :3 0 a45 a46
0 6b :4 0 fe
:4 0 6e :2 0 6f
:3 0 590 a4a a4c
:3 0 6e :2 0 82
:4 0 593 a4e a50
:3 0 6e :2 0 83
:4 0 596 a52 a54
:3 0 6e :2 0 73
:3 0 74 :3 0 84
:3 0 ff :3 0 a59
a5a 0 599 a58
a5c 75 :4 0 59b
a57 a5f 59e a56
a61 :3 0 6e :2 0
ee :4 0 5a1 a63
a65 :3 0 6e :2 0
71 :4 0 5a4 a67
a69 :3 0 6e :2 0
17 :3 0 5a7 a6b
a6d :3 0 6e :2 0
71 :4 0 5aa a6f
a71 :3 0 5ad a47
a73 :2 0 a75 5b0
a76 a44 a75 0
a77 5b2 0 aa1
66 :3 0 67 :3 0
a78 a79 0 66
:3 0 77 :3 0 a7b
a7c 0 27 :2 0
2 :4 0 100 :2 0
79 :2 0 27 :2 0
5b4 a81 a83 :3 0
5b7 a7d a85 a7a
a87 a86 :2 0 69
:3 0 7a :3 0 a89
a8a 0 6b :4 0
101 :4 0 6e :2 0
6f :3 0 5bb a8e
a90 :3 0 5be a8b
a92 :2 0 a94 5c1
a95 a88 a94 0
a96 5c3 0 aa1
88 :3 0 f1 :3 0
a97 a98 0 84
:3 0 ff :3 0 a9a
a9b 0 17 :3 0
8a :3 0 5c5 a99
a9f :2 0 aa1 5c9
aa2 a33 aa1 0
aa3 5cd 0 aa4
5cf aa5 9d1 aa4
0 aa6 5d2 0
aa7 5d4 be4 73
:3 0 c2 :3 0 73
:3 0 c3 :3 0 c4
:3 0 3d :3 0 3e
:3 0 43 :3 0 c5
:3 0 c6 :3 0 17
:4 0 102 1 :8 0
ab9 15 :3 0 a6
:3 0 ab4 ab5 0
a7 :3 0 ab6 ab7
0 ab9 5dc b03
a8 :3 0 15 :3 0
a6 :3 0 abc abd
0 a7 :3 0 abe
abf 0 af9 66
:3 0 67 :3 0 ac1
ac2 0 66 :3 0
77 :3 0 ac4 ac5
0 a9 :2 0 2
:4 0 103 :2 0 79
:2 0 27 :2 0 5df
aca acc :3 0 5e2
ac6 ace ac3 ad0
acf :2 0 69 :3 0
7a :3 0 ad2 ad3
0 6b :4 0 104
:4 0 6e :2 0 6f
:3 0 5e6 ad7 ad9
:3 0 6e :2 0 82
:4 0 5e9 adb add
:3 0 6e :2 0 ac
:4 0 5ec adf ae1
:3 0 6e :2 0 a7
:3 0 5ef ae3 ae5
:3 0 6e :2 0 ad
:4 0 5f2 ae7 ae9
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 5f5
aec af0 5f9 aeb
af2 :3 0 5fc ad4
af4 :2 0 af6 5ff
af7 ad1 af6 0
af8 601 0 af9
603 afc :3 0 afc
0 afc afb af9
afa :6 0 afe 12
:3 0 606 b00 608
aff afe :2 0 b01
60a :2 0 b03 0
b03 b02 ab9 b01
:6 0 be3 1 :3 0
15 :3 0 a6 :3 0
b05 b06 0 15
:3 0 9c :2 0 e2
:3 0 b08 b0a 0
60e b09 b0c :3 0
b0d :2 0 3d :3 0
3e :3 0 105 :3 0
c6 :3 0 17 :4 0
106 1 :8 0 b1a
15 :3 0 a6 :3 0
b15 b16 0 a7
:3 0 b17 b18 0
b1a 611 b64 a8
:3 0 15 :3 0 a6
:3 0 b1d b1e 0
a7 :3 0 b1f b20
0 b5a 66 :3 0
67 :3 0 b22 b23
0 66 :3 0 77
:3 0 b25 b26 0
a9 :2 0 2 :4 0
107 :2 0 79 :2 0
27 :2 0 614 b2b
b2d :3 0 617 b27
b2f b24 b31 b30
:2 0 69 :3 0 7a
:3 0 b33 b34 0
6b :4 0 108 :4 0
6e :2 0 6f :3 0
61b b38 b3a :3 0
6e :2 0 82 :4 0
61e b3c b3e :3 0
6e :2 0 ac :4 0
621 b40 b42 :3 0
6e :2 0 a7 :3 0
624 b44 b46 :3 0
6e :2 0 ad :4 0
627 b48 b4a :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 62a b4d
b51 62e b4c b53
:3 0 631 b35 b55
:2 0 b57 634 b58
b32 b57 0 b59
636 0 b5a 638
b5d :3 0 b5d 0
b5d b5c b5a b5b
:6 0 b5f 14 :3 0
63b b61 63d b60
b5f :2 0 b62 63f
:2 0 b64 0 b64
b63 b1a b62 :6 0
be0 1 :3 0 15
:3 0 a6 :3 0 b66
b67 0 15 :3 0
9c :2 0 e2 :3 0
b69 b6b 0 643
b6a b6d :3 0 b6e
:2 0 66 :3 0 67
:3 0 b70 b71 0
66 :3 0 77 :3 0
b73 b74 0 18
:2 0 2 :4 0 109
:2 0 79 :2 0 27
:2 0 646 b79 b7b
:3 0 649 b75 b7d
b72 b7f b7e :2 0
69 :3 0 7a :3 0
b81 b82 0 6b
:4 0 10a :4 0 6e
:2 0 6f :3 0 64d
b86 b88 :3 0 6e
:2 0 82 :4 0 650
b8a b8c :3 0 6e
:2 0 83 :4 0 653
b8e b90 :3 0 6e
:2 0 73 :3 0 74
:3 0 84 :3 0 95
:3 0 b95 b96 0
656 b94 b98 75
:4 0 658 b93 b9b
65b b92 b9d :3 0
6e :2 0 ee :4 0
65e b9f ba1 :3 0
6e :2 0 71 :4 0
661 ba3 ba5 :3 0
6e :2 0 17 :3 0
664 ba7 ba9 :3 0
6e :2 0 71 :4 0
667 bab bad :3 0
66a b83 baf :2 0
bb1 66d bb2 b80
bb1 0 bb3 66f
0 bdd 66 :3 0
67 :3 0 bb4 bb5
0 66 :3 0 77
:3 0 bb7 bb8 0
27 :2 0 2 :4 0
10b :2 0 79 :2 0
27 :2 0 671 bbd
bbf :3 0 674 bb9
bc1 bb6 bc3 bc2
:2 0 69 :3 0 7a
:3 0 bc5 bc6 0
6b :4 0 10c :4 0
6e :2 0 6f :3 0
678 bca bcc :3 0
67b bc7 bce :2 0
bd0 67e bd1 bc4
bd0 0 bd2 680
0 bdd 88 :3 0
f1 :3 0 bd3 bd4
0 84 :3 0 95
:3 0 bd6 bd7 0
17 :3 0 8a :3 0
682 bd5 bdb :2 0
bdd 686 bde b6f
bdd 0 bdf 68a
0 be0 68c be1
b0e be0 0 be2
68f 0 be3 691
be5 700 aa7 0
be6 0 be3 0
be6 694 0 3027
63 :3 0 9c :2 0
30 :2 0 699 be8
bea :3 0 21 :3 0
5 :3 0 bec bed
0 d16 22 :3 0
6 :3 0 bef bf0
0 d16 5e :3 0
10d :3 0 21 :3 0
22 :3 0 73 :3 0
38 :3 0 30 :2 0
69c bf6 bf9 73
:3 0 39 :3 0 30
:2 0 69f bfb bfe
73 :3 0 3a :3 0
30 :2 0 6a2 c00
c03 73 :3 0 31
:3 0 30 :2 0 6a5
c05 c08 73 :3 0
3b :3 0 30 :2 0
6a8 c0a c0d 73
:3 0 36 :3 0 30
:2 0 6ab c0f c12
73 :3 0 3d :3 0
30 :2 0 6ae c14
c17 73 :3 0 3e
:3 0 30 :2 0 6b1
c19 c1c 35 :3 0
37 :3 0 41 :3 0
6b4 bf3 c21 bf2
c22 0 d16 73
:3 0 5e :3 0 30
:2 0 6c2 c24 c27
84 :3 0 9c :2 0
95 :3 0 c29 c2b
0 6c7 c2a c2d
:3 0 66 :3 0 67
:3 0 c2f c30 0
66 :3 0 77 :3 0
c32 c33 0 7f
:2 0 2 :4 0 10e
:2 0 79 :2 0 27
:2 0 6ca c38 c3a
:3 0 6cd c34 c3c
c31 c3e c3d :2 0
69 :3 0 7a :3 0
c40 c41 0 6b
:4 0 10f :4 0 6e
:2 0 6f :3 0 6d1
c45 c47 :3 0 6e
:2 0 82 :4 0 6d4
c49 c4b :3 0 6e
:2 0 83 :4 0 6d7
c4d c4f :3 0 6e
:2 0 73 :3 0 74
:3 0 84 :3 0 95
:3 0 c54 c55 0
6da c53 c57 75
:4 0 6dc c52 c5a
6df c51 c5c :3 0
6e2 c42 c5e :2 0
c60 6e5 c61 c3f
c60 0 c62 6e7
0 c8c 66 :3 0
67 :3 0 c63 c64
0 66 :3 0 77
:3 0 c66 c67 0
27 :2 0 2 :4 0
110 :2 0 79 :2 0
27 :2 0 6e9 c6c
c6e :3 0 6ec c68
c70 c65 c72 c71
:2 0 69 :3 0 7a
:3 0 c74 c75 0
6b :4 0 111 :4 0
6e :2 0 6f :3 0
6f0 c79 c7b :3 0
6f3 c76 c7d :2 0
c7f 6f6 c80 c73
c7f 0 c81 6f8
0 c8c 88 :3 0
89 :3 0 c82 c83
0 84 :3 0 95
:3 0 c85 c86 0
8a :3 0 6fa c84
c89 :2 0 c8c b7
:3 0 6fd d05 73
:3 0 5e :3 0 30
:2 0 701 c8d c90
c0 :2 0 30 :2 0
706 c92 c94 :3 0
66 :3 0 67 :3 0
c96 c97 0 66
:3 0 77 :3 0 c99
c9a 0 18 :2 0
2 :4 0 112 :2 0
79 :2 0 27 :2 0
709 c9f ca1 :3 0
70c c9b ca3 c98
ca5 ca4 :2 0 69
:3 0 7a :3 0 ca7
ca8 0 6b :4 0
113 :4 0 6e :2 0
6f :3 0 710 cac
cae :3 0 6e :2 0
82 :4 0 713 cb0
cb2 :3 0 6e :2 0
83 :4 0 716 cb4
cb6 :3 0 6e :2 0
73 :3 0 74 :3 0
5e :3 0 719 cba
cbc 75 :4 0 71b
cb9 cbf 71e cb8
cc1 :3 0 6e :2 0
ee :4 0 721 cc3
cc5 :3 0 6e :2 0
71 :4 0 724 cc7
cc9 :3 0 6e :2 0
17 :3 0 727 ccb
ccd :3 0 6e :2 0
71 :4 0 72a ccf
cd1 :3 0 72d ca9
cd3 :2 0 cd5 730
cd6 ca6 cd5 0
cd7 732 0 d03
66 :3 0 67 :3 0
cd8 cd9 0 66
:3 0 77 :3 0 cdb
cdc 0 27 :2 0
2 :4 0 114 :2 0
79 :2 0 27 :2 0
734 ce1 ce3 :3 0
737 cdd ce5 cda
ce7 ce6 :2 0 69
:3 0 7a :3 0 ce9
cea 0 6b :4 0
115 :4 0 6e :2 0
6f :3 0 73b cee
cf0 :3 0 73e ceb
cf2 :2 0 cf4 741
cf5 ce8 cf4 0
cf6 743 0 d03
88 :3 0 f1 :3 0
cf7 cf8 0 73
:3 0 5e :3 0 30
:2 0 745 cfa cfd
17 :3 0 8a :3 0
748 cf9 d01 :2 0
d03 74c d04 c95
d03 0 d06 c2e
c8c 0 d06 750
0 d16 22 :3 0
22 :3 0 d07 d08
0 d16 22 :3 0
7e :2 0 753 d0b
d0c :3 0 d0d :2 0
22 :3 0 7c :4 0
d0f d10 0 d12
755 d13 d0e d12
0 d14 757 0
d16 b7 :3 0 759
d94 73 :3 0 35
:3 0 30 :2 0 760
d17 d1a bb :2 0
30 :2 0 765 d1c
d1e :3 0 d1f :2 0
73 :3 0 39 :3 0
30 :2 0 768 d21
d24 c0 :2 0 116
:2 0 76d d26 d28
:3 0 d29 :2 0 d20
d2b d2a :2 0 73
:3 0 39 :3 0 30
:2 0 770 d2d d30
9c :2 0 27 :2 0
775 d32 d34 :3 0
d35 :2 0 73 :3 0
39 :3 0 30 :2 0
778 d37 d3a 9c
:2 0 117 :2 0 77d
d3c d3e :3 0 d3f
:2 0 d36 d41 d40
:2 0 38 :3 0 117
:2 0 d43 d44 0
d47 b7 :3 0 780
d90 73 :3 0 39
:3 0 30 :2 0 782
d48 d4b 9c :2 0
30 :2 0 787 d4d
d4f :3 0 38 :3 0
27 :2 0 d51 d52
0 d55 b7 :3 0
78a d56 d50 d55
0 d91 73 :3 0
39 :3 0 30 :2 0
78c d57 d5a 9c
:2 0 118 :2 0 791
d5c d5e :3 0 d5f
:2 0 73 :3 0 39
:3 0 30 :2 0 794
d61 d64 9c :2 0
119 :2 0 799 d66
d68 :3 0 d69 :2 0
d60 d6b d6a :2 0
38 :3 0 27 :2 0
d6d d6e 0 d71
b7 :3 0 79c d72
d6c d71 0 d91
73 :3 0 39 :3 0
30 :2 0 79e d73
d76 9c :2 0 9d
:2 0 7a3 d78 d7a
:3 0 35 :3 0 73
:3 0 3e :3 0 30
:2 0 7a6 d7d d80
11a :2 0 73 :3 0
35 :3 0 30 :2 0
7a9 d83 d86 7ac
d82 d88 :3 0 d7c
d89 0 d8e 38
:3 0 118 :2 0 d8b
d8c 0 d8e 7af
d8f d7b d8e 0
d91 d42 d47 0
d91 7b2 0 d92
7b7 d93 d2c d92
0 d95 beb d16
0 d95 7b9 0
3027 59 :3 0 11b
:4 0 d97 d98 :3 0
d96 d99 0 3027
2b :3 0 7c :4 0
d9b d9c 0 3027
2c :3 0 7c :4 0
d9e d9f 0 3027
34 :3 0 11c :3 0
11d :3 0 da2 da3
0 11e :3 0 73
:3 0 3a :3 0 30
:2 0 7bc da6 da9
84 :3 0 11f :3 0
dab dac 0 7bf
da5 dae daf :2 0
120 :2 0 7c2 da4
db2 da1 db3 0
3027 3a :3 0 11e
:3 0 73 :3 0 3a
:3 0 30 :2 0 7c5
db7 dba 84 :3 0
121 :3 0 dbc dbd
0 7c8 db6 dbf
db5 dc0 0 3027
73 :3 0 32 :3 0
30 :2 0 7cb dc2
dc5 bb :2 0 30
:2 0 7d0 dc7 dc9
:3 0 59 :3 0 122
:3 0 5a :3 0 32
:3 0 1a :3 0 1d
:3 0 1c :3 0 28
:3 0 7d3 dcc dd3
dcb dd4 0 1c03
73 :3 0 59 :3 0
30 :2 0 7da dd6
dd9 c0 :2 0 30
:2 0 7df ddb ddd
:3 0 66 :3 0 67
:3 0 ddf de0 0
66 :3 0 77 :3 0
de2 de3 0 18
:2 0 2 :4 0 123
:2 0 79 :2 0 27
:2 0 7e2 de8 dea
:3 0 7e5 de4 dec
de1 dee ded :2 0
69 :3 0 7a :3 0
df0 df1 0 6b
:4 0 124 :4 0 6e
:2 0 6f :3 0 7e9
df5 df7 :3 0 6e
:2 0 82 :4 0 7ec
df9 dfb :3 0 6e
:2 0 83 :4 0 7ef
dfd dff :3 0 6e
:2 0 73 :3 0 74
:3 0 59 :3 0 7f2
e03 e05 75 :4 0
7f4 e02 e08 7f7
e01 e0a :3 0 6e
:2 0 ee :4 0 7fa
e0c e0e :3 0 6e
:2 0 71 :4 0 7fd
e10 e12 :3 0 6e
:2 0 28 :3 0 800
e14 e16 :3 0 6e
:2 0 71 :4 0 803
e18 e1a :3 0 806
df2 e1c :2 0 e1e
809 e1f def e1e
0 e20 80b 0
e4c 66 :3 0 67
:3 0 e21 e22 0
66 :3 0 77 :3 0
e24 e25 0 27
:2 0 2 :4 0 125
:2 0 79 :2 0 27
:2 0 80d e2a e2c
:3 0 810 e26 e2e
e23 e30 e2f :2 0
69 :3 0 7a :3 0
e32 e33 0 6b
:4 0 126 :4 0 6e
:2 0 6f :3 0 814
e37 e39 :3 0 817
e34 e3b :2 0 e3d
81a e3e e31 e3d
0 e3f 81c 0
e4c 88 :3 0 f1
:3 0 e40 e41 0
73 :3 0 59 :3 0
30 :2 0 81e e43
e46 28 :3 0 8a
:3 0 821 e42 e4a
:2 0 e4c 825 e4d
dde e4c 0 e4e
829 0 1c03 21
:4 0 e4f e50 0
1c03 127 :3 0 128
:3 0 a2 :3 0 a3
:3 0 1f :3 0 a2
:3 0 a3 :3 0 127
:3 0 128 :3 0 21
:3 0 44 :3 0 129
:3 0 c1 :3 0 17
:3 0 12a :3 0 17
:3 0 12b :3 0 1d
:3 0 12c :3 0 26
:4 0 12d 1 :8 0
e6c 15 :3 0 a6
:3 0 e67 e68 0
a7 :3 0 e69 e6a
0 e6c 82b eb6
a8 :3 0 15 :3 0
a6 :3 0 e6f e70
0 a7 :3 0 e71
e72 0 eac 66
:3 0 67 :3 0 e74
e75 0 66 :3 0
77 :3 0 e77 e78
0 a9 :2 0 2
:4 0 12e :2 0 79
:2 0 27 :2 0 82e
e7d e7f :3 0 831
e79 e81 e76 e83
e82 :2 0 69 :3 0
7a :3 0 e85 e86
0 6b :4 0 12f
:4 0 6e :2 0 6f
:3 0 835 e8a e8c
:3 0 6e :2 0 82
:4 0 838 e8e e90
:3 0 6e :2 0 ac
:4 0 83b e92 e94
:3 0 6e :2 0 a7
:3 0 83e e96 e98
:3 0 6e :2 0 ad
:4 0 841 e9a e9c
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 844
e9f ea3 848 e9e
ea5 :3 0 84b e87
ea7 :2 0 ea9 84e
eaa e84 ea9 0
eab 850 0 eac
852 eaf :3 0 eaf
0 eaf eae eac
ead :6 0 eb1 16
:3 0 855 eb3 857
eb2 eb1 :2 0 eb4
859 :2 0 eb6 0
eb6 eb5 e6c eb4
:6 0 1c03 1 :3 0
15 :3 0 a6 :3 0
eb8 eb9 0 15
:3 0 9c :2 0 b1
:3 0 ebb ebd 0
85d ebc ebf :3 0
ec0 :2 0 21 :3 0
8f :2 0 860 ec3
ec4 :3 0 ec5 :2 0
ec6 :2 0 ec1 ec8
ec7 :2 0 46 :3 0
27 :2 0 eca ecb
0 edc 73 :3 0
44 :3 0 30 :2 0
862 ecd ed0 91
:2 0 30 :2 0 867
ed2 ed4 :3 0 1f
:3 0 21 :3 0 ed6
ed7 0 ed9 86a
eda ed5 ed9 0
edb 86c 0 edc
86e edd ec9 edc
0 ede 871 0
1c03 33 :3 0 30
:2 0 edf ee0 0
1c03 44 :3 0 30
:2 0 ee2 ee3 0
1c03 63 :3 0 9c
:2 0 27 :2 0 875
ee6 ee8 :3 0 ae
:3 0 26 :3 0 27
:2 0 27 :2 0 878
eea eee 9c :2 0
30 :4 0 87e ef0
ef2 :3 0 130 :3 0
131 :3 0 132 :3 0
ae :3 0 1f :3 0
132 :3 0 ae :3 0
131 :3 0 132 :3 0
ae :3 0 22 :3 0
132 :3 0 ae :3 0
133 :3 0 134 :3 0
37 :3 0 134 :3 0
19 :3 0 21 :3 0
44 :3 0 47 :3 0
129 :3 0 12a :3 0
17 :3 0 12b :3 0
1d :3 0 12c :3 0
135 :4 0 136 1
:8 0 f16 15 :3 0
a6 :3 0 f11 f12
0 a7 :3 0 f13
f14 0 f16 881
f60 a8 :3 0 15
:3 0 a6 :3 0 f19
f1a 0 a7 :3 0
f1b f1c 0 f56
66 :3 0 67 :3 0
f1e f1f 0 66
:3 0 77 :3 0 f21
f22 0 a9 :2 0
2 :4 0 137 :2 0
79 :2 0 27 :2 0
884 f27 f29 :3 0
887 f23 f2b f20
f2d f2c :2 0 69
:3 0 7a :3 0 f2f
f30 0 6b :4 0
138 :4 0 6e :2 0
6f :3 0 88b f34
f36 :3 0 6e :2 0
82 :4 0 88e f38
f3a :3 0 6e :2 0
ac :4 0 891 f3c
f3e :3 0 6e :2 0
a7 :3 0 894 f40
f42 :3 0 6e :2 0
ad :4 0 897 f44
f46 :3 0 6e :2 0
ae :3 0 af :3 0
27 :2 0 b0 :2 0
89a f49 f4d 89e
f48 f4f :3 0 8a1
f31 f51 :2 0 f53
8a4 f54 f2e f53
0 f55 8a6 0
f56 8a8 f59 :3 0
f59 0 f59 f58
f56 f57 :6 0 f5b
18 :3 0 8ab f5d
8ad f5c f5b :2 0
f5e 8af :2 0 f60
0 f60 f5f f16
f5e :6 0 1081 1
:3 0 15 :3 0 a6
:3 0 f62 f63 0
15 :3 0 9c :2 0
b1 :3 0 f65 f67
0 8b3 f66 f69
:3 0 f6a :2 0 46
:3 0 27 :2 0 f6c
f6d 0 ffa 73
:3 0 47 :3 0 30
:2 0 8b6 f6f f72
9c :2 0 30 :2 0
8bb f74 f76 :3 0
f77 :2 0 73 :3 0
44 :3 0 30 :2 0
8be f79 f7c 9c
:2 0 27 :2 0 8c3
f7e f80 :3 0 f81
:2 0 f78 f83 f82
:2 0 130 :3 0 139
:3 0 132 :3 0 ae
:3 0 1f :3 0 132
:3 0 ae :3 0 139
:3 0 132 :3 0 ae
:3 0 22 :3 0 132
:3 0 ae :3 0 13a
:3 0 13b :3 0 37
:3 0 19 :3 0 21
:3 0 44 :3 0 129
:3 0 12a :3 0 17
:3 0 12b :3 0 1d
:3 0 12c :3 0 135
:4 0 13c 1 :8 0
fa5 15 :3 0 a6
:3 0 fa0 fa1 0
a7 :3 0 fa2 fa3
0 fa5 8c6 fef
a8 :3 0 15 :3 0
a6 :3 0 fa8 fa9
0 a7 :3 0 faa
fab 0 fe5 66
:3 0 67 :3 0 fad
fae 0 66 :3 0
77 :3 0 fb0 fb1
0 a9 :2 0 2
:4 0 13d :2 0 79
:2 0 27 :2 0 8c9
fb6 fb8 :3 0 8cc
fb2 fba faf fbc
fbb :2 0 69 :3 0
7a :3 0 fbe fbf
0 6b :4 0 13e
:4 0 6e :2 0 6f
:3 0 8d0 fc3 fc5
:3 0 6e :2 0 82
:4 0 8d3 fc7 fc9
:3 0 6e :2 0 ac
:4 0 8d6 fcb fcd
:3 0 6e :2 0 a7
:3 0 8d9 fcf fd1
:3 0 6e :2 0 ad
:4 0 8dc fd3 fd5
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 8df
fd8 fdc 8e3 fd7
fde :3 0 8e6 fc0
fe0 :2 0 fe2 8e9
fe3 fbd fe2 0
fe4 8eb 0 fe5
8ed fe8 :3 0 fe8
0 fe8 fe7 fe5
fe6 :6 0 fea 1a
:3 0 8f0 fec 8f2
feb fea :2 0 fed
8f4 :2 0 fef 0
fef fee fa5 fed
:6 0 ff1 1 :3 0
8f6 ff6 33 :3 0
117 :2 0 ff2 ff3
0 ff5 8f8 ff7
f84 ff1 0 ff8
0 ff5 0 ff8
8fa 0 ffa b7
:3 0 8fd 107f 15
:3 0 a6 :3 0 ffb
ffc 0 15 :3 0
9c :2 0 e2 :3 0
ffe 1000 0 902
fff 1002 :3 0 1003
:2 0 73 :3 0 44
:3 0 30 :2 0 905
1005 1008 9c :2 0
27 :2 0 90a 100a
100c :3 0 100d :2 0
1004 100f 100e :2 0
130 :3 0 139 :3 0
132 :3 0 ae :3 0
1f :3 0 132 :3 0
ae :3 0 139 :3 0
132 :3 0 ae :3 0
22 :3 0 132 :3 0
ae :3 0 13a :3 0
13b :3 0 37 :3 0
19 :3 0 21 :3 0
44 :3 0 129 :3 0
12a :3 0 17 :3 0
12b :3 0 1d :3 0
12c :3 0 135 :4 0
13f 1 :8 0 1031
15 :3 0 a6 :3 0
102c 102d 0 a7
:3 0 102e 102f 0
1031 90d 107b a8
:3 0 15 :3 0 a6
:3 0 1034 1035 0
a7 :3 0 1036 1037
0 1071 66 :3 0
67 :3 0 1039 103a
0 66 :3 0 77
:3 0 103c 103d 0
a9 :2 0 2 :4 0
140 :2 0 79 :2 0
27 :2 0 910 1042
1044 :3 0 913 103e
1046 103b 1048 1047
:2 0 69 :3 0 7a
:3 0 104a 104b 0
6b :4 0 141 :4 0
6e :2 0 6f :3 0
917 104f 1051 :3 0
6e :2 0 82 :4 0
91a 1053 1055 :3 0
6e :2 0 ac :4 0
91d 1057 1059 :3 0
6e :2 0 a7 :3 0
920 105b 105d :3 0
6e :2 0 ad :4 0
923 105f 1061 :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 926 1064
1068 92a 1063 106a
:3 0 92d 104c 106c
:2 0 106e 930 106f
1049 106e 0 1070
932 0 1071 934
1074 :3 0 1074 0
1074 1073 1071 1072
:6 0 1076 1c :3 0
937 1078 939 1077
1076 :2 0 1079 93b
:2 0 107b 0 107b
107a 1031 1079 :6 0
107d 1 :3 0 93d
107e 1010 107d 0
1080 f6b ffa 0
1080 93f 0 1081
942 10ef 130 :3 0
139 :3 0 132 :3 0
ae :3 0 1f :3 0
132 :3 0 ae :3 0
139 :3 0 132 :3 0
ae :3 0 22 :3 0
132 :3 0 ae :3 0
13a :3 0 13b :3 0
37 :3 0 19 :3 0
21 :3 0 44 :3 0
129 :3 0 12a :3 0
17 :3 0 12b :3 0
1d :3 0 12c :3 0
135 :4 0 142 1
:8 0 10a2 15 :3 0
a6 :3 0 109d 109e
0 a7 :3 0 109f
10a0 0 10a2 945
10ec a8 :3 0 15
:3 0 a6 :3 0 10a5
10a6 0 a7 :3 0
10a7 10a8 0 10e2
66 :3 0 67 :3 0
10aa 10ab 0 66
:3 0 77 :3 0 10ad
10ae 0 a9 :2 0
2 :4 0 143 :2 0
79 :2 0 27 :2 0
948 10b3 10b5 :3 0
94b 10af 10b7 10ac
10b9 10b8 :2 0 69
:3 0 7a :3 0 10bb
10bc 0 6b :4 0
144 :4 0 6e :2 0
6f :3 0 94f 10c0
10c2 :3 0 6e :2 0
82 :4 0 952 10c4
10c6 :3 0 6e :2 0
ac :4 0 955 10c8
10ca :3 0 6e :2 0
a7 :3 0 958 10cc
10ce :3 0 6e :2 0
ad :4 0 95b 10d0
10d2 :3 0 6e :2 0
ae :3 0 af :3 0
27 :2 0 b0 :2 0
95e 10d5 10d9 962
10d4 10db :3 0 965
10bd 10dd :2 0 10df
968 10e0 10ba 10df
0 10e1 96a 0
10e2 96c 10e5 :3 0
10e5 0 10e5 10e4
10e2 10e3 :6 0 10e7
1e :3 0 96f 10e9
971 10e8 10e7 :2 0
10ea 973 :2 0 10ec
0 10ec 10eb 10a2
10ea :6 0 10ee 1
:3 0 975 10f0 ef3
1081 0 10f1 0
10ee 0 10f1 977
0 10f2 97a 12e2
ae :3 0 26 :3 0
27 :2 0 27 :2 0
97c 10f3 10f7 9c
:2 0 30 :4 0 982
10f9 10fb :3 0 130
:3 0 131 :3 0 132
:3 0 ae :3 0 1f
:3 0 132 :3 0 ae
:3 0 131 :3 0 132
:3 0 ae :3 0 133
:3 0 37 :3 0 134
:3 0 134 :3 0 19
:3 0 21 :3 0 44
:3 0 47 :3 0 129
:3 0 12a :3 0 17
:3 0 12b :3 0 1d
:3 0 12c :3 0 135
:4 0 145 1 :8 0
111c 15 :3 0 a6
:3 0 1117 1118 0
a7 :3 0 1119 111a
0 111c 985 1166
a8 :3 0 15 :3 0
a6 :3 0 111f 1120
0 a7 :3 0 1121
1122 0 115c 66
:3 0 67 :3 0 1124
1125 0 66 :3 0
77 :3 0 1127 1128
0 a9 :2 0 2
:4 0 146 :2 0 79
:2 0 27 :2 0 988
112d 112f :3 0 98b
1129 1131 1126 1133
1132 :2 0 69 :3 0
7a :3 0 1135 1136
0 6b :4 0 147
:4 0 6e :2 0 6f
:3 0 98f 113a 113c
:3 0 6e :2 0 82
:4 0 992 113e 1140
:3 0 6e :2 0 ac
:4 0 995 1142 1144
:3 0 6e :2 0 a7
:3 0 998 1146 1148
:3 0 6e :2 0 ad
:4 0 99b 114a 114c
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 99e
114f 1153 9a2 114e
1155 :3 0 9a5 1137
1157 :2 0 1159 9a8
115a 1134 1159 0
115b 9aa 0 115c
9ac 115f :3 0 115f
0 115f 115e 115c
115d :6 0 1161 20
:3 0 9af 1163 9b1
1162 1161 :2 0 1164
9b3 :2 0 1166 0
1166 1165 111c 1164
:6 0 1273 1 :3 0
15 :3 0 a6 :3 0
1168 1169 0 15
:3 0 9c :2 0 b1
:3 0 116b 116d 0
9b7 116c 116f :3 0
1170 :2 0 46 :3 0
27 :2 0 1172 1173
0 11fb 73 :3 0
47 :3 0 30 :2 0
9ba 1175 1178 9c
:2 0 30 :2 0 9bf
117a 117c :3 0 117d
:2 0 73 :3 0 44
:3 0 30 :2 0 9c2
117f 1182 9c :2 0
27 :2 0 9c7 1184
1186 :3 0 1187 :2 0
117e 1189 1188 :2 0
130 :3 0 139 :3 0
132 :3 0 ae :3 0
1f :3 0 132 :3 0
ae :3 0 13a :3 0
37 :3 0 13b :3 0
19 :3 0 21 :3 0
44 :3 0 129 :3 0
12a :3 0 17 :3 0
12b :3 0 1d :3 0
12c :3 0 135 :4 0
148 1 :8 0 11a5
15 :3 0 a6 :3 0
11a0 11a1 0 a7
:3 0 11a2 11a3 0
11a5 9ca 11ef a8
:3 0 15 :3 0 a6
:3 0 11a8 11a9 0
a7 :3 0 11aa 11ab
0 11e5 66 :3 0
67 :3 0 11ad 11ae
0 66 :3 0 77
:3 0 11b0 11b1 0
a9 :2 0 2 :4 0
149 :2 0 79 :2 0
27 :2 0 9cd 11b6
11b8 :3 0 9d0 11b2
11ba 11af 11bc 11bb
:2 0 69 :3 0 7a
:3 0 11be 11bf 0
6b :4 0 14a :4 0
6e :2 0 6f :3 0
9d4 11c3 11c5 :3 0
6e :2 0 82 :4 0
9d7 11c7 11c9 :3 0
6e :2 0 ac :4 0
9da 11cb 11cd :3 0
6e :2 0 a7 :3 0
9dd 11cf 11d1 :3 0
6e :2 0 ad :4 0
9e0 11d3 11d5 :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 9e3 11d8
11dc 9e7 11d7 11de
:3 0 9ea 11c0 11e0
:2 0 11e2 9ed 11e3
11bd 11e2 0 11e4
9ef 0 11e5 9f1
11e8 :3 0 11e8 0
11e8 11e7 11e5 11e6
:6 0 11ea 22 :3 0
9f4 11ec 9f6 11eb
11ea :2 0 11ed 9f8
:2 0 11ef 0 11ef
11ee 11a5 11ed :6 0
11f1 1 :3 0 9fa
11f7 33 :3 0 117
:2 0 11f2 11f3 0
11f6 0 11f6 9fc
11f8 118a 11f1 0
11f9 0 11f6 0
11f9 9ff 0 11fb
b7 :3 0 a02 1271
15 :3 0 a6 :3 0
11fc 11fd 0 15
:3 0 9c :2 0 e2
:3 0 11ff 1201 0
a07 1200 1203 :3 0
1204 :2 0 130 :3 0
139 :3 0 132 :3 0
ae :3 0 1f :3 0
132 :3 0 ae :3 0
139 :3 0 132 :3 0
ae :3 0 13a :3 0
37 :3 0 13b :3 0
19 :3 0 21 :3 0
44 :3 0 129 :3 0
12a :3 0 17 :3 0
12b :3 0 1d :3 0
12c :3 0 135 :4 0
14b 1 :8 0 1223
15 :3 0 a6 :3 0
121e 121f 0 a7
:3 0 1220 1221 0
1223 a0a 126d a8
:3 0 15 :3 0 a6
:3 0 1226 1227 0
a7 :3 0 1228 1229
0 1263 66 :3 0
67 :3 0 122b 122c
0 66 :3 0 77
:3 0 122e 122f 0
a9 :2 0 2 :4 0
14c :2 0 79 :2 0
27 :2 0 a0d 1234
1236 :3 0 a10 1230
1238 122d 123a 1239
:2 0 69 :3 0 7a
:3 0 123c 123d 0
6b :4 0 14d :4 0
6e :2 0 6f :3 0
a14 1241 1243 :3 0
6e :2 0 82 :4 0
a17 1245 1247 :3 0
6e :2 0 ac :4 0
a1a 1249 124b :3 0
6e :2 0 a7 :3 0
a1d 124d 124f :3 0
6e :2 0 ad :4 0
a20 1251 1253 :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 a23 1256
125a a27 1255 125c
:3 0 a2a 123e 125e
:2 0 1260 a2d 1261
123b 1260 0 1262
a2f 0 1263 a31
1266 :3 0 1266 0
1266 1265 1263 1264
:6 0 1268 24 :3 0
a34 126a a36 1269
1268 :2 0 126b a38
:2 0 126d 0 126d
126c 1223 126b :6 0
126f 1 :3 0 a3a
1270 1205 126f 0
1272 1171 11fb 0
1272 a3c 0 1273
a3f 12de 130 :3 0
139 :3 0 132 :3 0
ae :3 0 1f :3 0
132 :3 0 ae :3 0
139 :3 0 132 :3 0
ae :3 0 13a :3 0
37 :3 0 13b :3 0
19 :3 0 21 :3 0
44 :3 0 129 :3 0
12a :3 0 17 :3 0
12b :3 0 1d :3 0
12c :3 0 135 :4 0
14e 1 :8 0 1291
15 :3 0 a6 :3 0
128c 128d 0 a7
:3 0 128e 128f 0
1291 a42 12db a8
:3 0 15 :3 0 a6
:3 0 1294 1295 0
a7 :3 0 1296 1297
0 12d1 66 :3 0
67 :3 0 1299 129a
0 66 :3 0 77
:3 0 129c 129d 0
a9 :2 0 2 :4 0
14f :2 0 79 :2 0
27 :2 0 a45 12a2
12a4 :3 0 a48 129e
12a6 129b 12a8 12a7
:2 0 69 :3 0 7a
:3 0 12aa 12ab 0
6b :4 0 150 :4 0
6e :2 0 6f :3 0
a4c 12af 12b1 :3 0
6e :2 0 82 :4 0
a4f 12b3 12b5 :3 0
6e :2 0 ac :4 0
a52 12b7 12b9 :3 0
6e :2 0 a7 :3 0
a55 12bb 12bd :3 0
6e :2 0 ad :4 0
a58 12bf 12c1 :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 a5b 12c4
12c8 a5f 12c3 12ca
:3 0 a62 12ac 12cc
:2 0 12ce a65 12cf
12a9 12ce 0 12d0
a67 0 12d1 a69
12d4 :3 0 12d4 0
12d4 12d3 12d1 12d2
:6 0 12d6 26 :3 0
a6c 12d8 a6e 12d7
12d6 :2 0 12d9 a70
:2 0 12db 0 12db
12da 1291 12d9 :6 0
12dd 1 :3 0 a72
12df 10fc 1273 0
12e0 0 12dd 0
12e0 a74 0 12e1
a77 12e3 ee9 10f2
0 12e4 0 12e1
0 12e4 a79 0
1c03 15 :3 0 a6
:3 0 12e5 12e6 0
15 :3 0 9c :2 0
b1 :3 0 12e8 12ea
0 a7e 12e9 12ec
:3 0 12ed :2 0 73
:3 0 44 :3 0 30
:2 0 a81 12ef 12f2
9c :2 0 27 :2 0
a86 12f4 12f6 :3 0
66 :3 0 67 :3 0
12f8 12f9 0 66
:3 0 77 :3 0 12fb
12fc 0 18 :2 0
2 :4 0 151 :2 0
79 :2 0 27 :2 0
a89 1301 1303 :3 0
a8c 12fd 1305 12fa
1307 1306 :2 0 69
:3 0 7a :3 0 1309
130a 0 6b :4 0
152 :4 0 6e :2 0
6f :3 0 a90 130e
1310 :3 0 6e :2 0
82 :4 0 a93 1312
1314 :3 0 6e :2 0
83 :4 0 a96 1316
1318 :3 0 6e :2 0
73 :3 0 74 :3 0
84 :3 0 153 :3 0
131d 131e 0 a99
131c 1320 75 :4 0
a9b 131b 1323 a9e
131a 1325 :3 0 6e
:2 0 ee :4 0 aa1
1327 1329 :3 0 6e
:2 0 71 :4 0 aa4
132b 132d :3 0 6e
:2 0 1d :3 0 aa7
132f 1331 :3 0 6e
:2 0 71 :4 0 aaa
1333 1335 :3 0 aad
130b 1337 :2 0 1339
ab0 133a 1308 1339
0 133b ab2 0
1366 66 :3 0 67
:3 0 133c 133d 0
66 :3 0 77 :3 0
133f 1340 0 27
:2 0 2 :4 0 154
:2 0 79 :2 0 27
:2 0 ab4 1345 1347
:3 0 ab7 1341 1349
133e 134b 134a :2 0
69 :3 0 7a :3 0
134d 134e 0 6b
:4 0 155 :4 0 6e
:2 0 6f :3 0 abb
1352 1354 :3 0 abe
134f 1356 :2 0 1358
ac1 1359 134c 1358
0 135a ac3 0
1366 88 :3 0 f1
:3 0 135b 135c 0
84 :3 0 153 :3 0
135e 135f 0 1d
:3 0 8a :3 0 ac5
135d 1363 :2 0 1366
b7 :3 0 ac9 14ba
19 :3 0 8f :2 0
acd 1368 1369 :3 0
136a :2 0 63 :3 0
9c :2 0 27 :2 0
ad1 136d 136f :3 0
47 :3 0 30 :2 0
1371 1372 0 13d5
156 :3 0 157 :3 0
47 :3 0 158 :3 0
c1 :3 0 17 :3 0
159 :3 0 19 :3 0
15a :3 0 132 :3 0
ae :3 0 1f :3 0
132 :3 0 ae :3 0
22 :4 0 15b 1
:8 0 1389 15 :3 0
a6 :3 0 1384 1385
0 a7 :3 0 1386
1387 0 1389 ad4
13d3 a8 :3 0 15
:3 0 a6 :3 0 138c
138d 0 a7 :3 0
138e 138f 0 13c9
66 :3 0 67 :3 0
1391 1392 0 66
:3 0 77 :3 0 1394
1395 0 a9 :2 0
2 :4 0 15c :2 0
79 :2 0 27 :2 0
ad7 139a 139c :3 0
ada 1396 139e 1393
13a0 139f :2 0 69
:3 0 7a :3 0 13a2
13a3 0 6b :4 0
15d :4 0 6e :2 0
6f :3 0 ade 13a7
13a9 :3 0 6e :2 0
82 :4 0 ae1 13ab
13ad :3 0 6e :2 0
ac :4 0 ae4 13af
13b1 :3 0 6e :2 0
a7 :3 0 ae7 13b3
13b5 :3 0 6e :2 0
ad :4 0 aea 13b7
13b9 :3 0 6e :2 0
ae :3 0 af :3 0
27 :2 0 b0 :2 0
aed 13bc 13c0 af1
13bb 13c2 :3 0 af4
13a4 13c4 :2 0 13c6
af7 13c7 13a1 13c6
0 13c8 af9 0
13c9 afb 13cc :3 0
13cc 0 13cc 13cb
13c9 13ca :6 0 13ce
28 :3 0 afe 13d0
b00 13cf 13ce :2 0
13d1 b02 :2 0 13d3
0 13d3 13d2 1389
13d1 :6 0 13d5 1
:3 0 b04 1438 47
:3 0 30 :2 0 13d6
13d7 0 1437 156
:3 0 157 :3 0 47
:3 0 158 :3 0 c1
:3 0 17 :3 0 159
:3 0 19 :3 0 15a
:3 0 132 :3 0 ae
:3 0 1f :4 0 15e
1 :8 0 13eb 15
:3 0 a6 :3 0 13e6
13e7 0 a7 :3 0
13e8 13e9 0 13eb
b07 1435 a8 :3 0
15 :3 0 a6 :3 0
13ee 13ef 0 a7
:3 0 13f0 13f1 0
142b 66 :3 0 67
:3 0 13f3 13f4 0
66 :3 0 77 :3 0
13f6 13f7 0 a9
:2 0 2 :4 0 15f
:2 0 79 :2 0 27
:2 0 b0a 13fc 13fe
:3 0 b0d 13f8 1400
13f5 1402 1401 :2 0
69 :3 0 7a :3 0
1404 1405 0 6b
:4 0 160 :4 0 6e
:2 0 6f :3 0 b11
1409 140b :3 0 6e
:2 0 82 :4 0 b14
140d 140f :3 0 6e
:2 0 ac :4 0 b17
1411 1413 :3 0 6e
:2 0 a7 :3 0 b1a
1415 1417 :3 0 6e
:2 0 ad :4 0 b1d
1419 141b :3 0 6e
:2 0 ae :3 0 af
:3 0 27 :2 0 b0
:2 0 b20 141e 1422
b24 141d 1424 :3 0
b27 1406 1426 :2 0
1428 b2a 1429 1403
1428 0 142a b2c
0 142b b2e 142e
:3 0 142e 0 142e
142d 142b 142c :6 0
1430 2a :3 0 b31
1432 b33 1431 1430
:2 0 1433 b35 :2 0
1435 0 1435 1434
13eb 1433 :6 0 1437
1 :3 0 b37 1439
1370 13d5 0 143a
0 1437 0 143a
b3a 0 14b8 73
:3 0 47 :3 0 30
:2 0 b3d 143b 143e
73 :3 0 91 :2 0
37 :3 0 30 :2 0
b40 1440 1444 b45
1441 1446 :3 0 66
:3 0 67 :3 0 1448
1449 0 66 :3 0
77 :3 0 144b 144c
0 18 :2 0 2
:4 0 161 :2 0 79
:2 0 27 :2 0 b48
1451 1453 :3 0 b4b
144d 1455 144a 1457
1456 :2 0 69 :3 0
7a :3 0 1459 145a
0 6b :4 0 162
:4 0 6e :2 0 6f
:3 0 b4f 145e 1460
:3 0 6e :2 0 82
:4 0 b52 1462 1464
:3 0 6e :2 0 83
:4 0 b55 1466 1468
:3 0 6e :2 0 73
:3 0 74 :3 0 84
:3 0 153 :3 0 146d
146e 0 b58 146c
1470 75 :4 0 b5a
146b 1473 b5d 146a
1475 :3 0 6e :2 0
ee :4 0 b60 1477
1479 :3 0 6e :2 0
71 :4 0 b63 147b
147d :3 0 6e :2 0
1d :3 0 b66 147f
1481 :3 0 6e :2 0
71 :4 0 b69 1483
1485 :3 0 b6c 145b
1487 :2 0 1489 b6f
148a 1458 1489 0
148b b71 0 14b5
66 :3 0 67 :3 0
148c 148d 0 66
:3 0 77 :3 0 148f
1490 0 27 :2 0
2 :4 0 163 :2 0
79 :2 0 27 :2 0
b73 1495 1497 :3 0
b76 1491 1499 148e
149b 149a :2 0 69
:3 0 7a :3 0 149d
149e 0 6b :4 0
164 :4 0 6e :2 0
6f :3 0 b7a 14a2
14a4 :3 0 b7d 149f
14a6 :2 0 14a8 b80
14a9 149c 14a8 0
14aa b82 0 14b5
88 :3 0 f1 :3 0
14ab 14ac 0 84
:3 0 153 :3 0 14ae
14af 0 1d :3 0
8a :3 0 b84 14ad
14b3 :2 0 14b5 b88
14b6 1447 14b5 0
14b7 b8c 0 14b8
b8e 14b9 136b 14b8
0 14bb 12f7 1366
0 14bb b91 0
14c0 46 :3 0 27
:2 0 14bc 14bd 0
14c0 b7 :3 0 b94
1549 73 :3 0 46
:3 0 30 :2 0 b97
14c1 14c4 9c :2 0
27 :2 0 b9c 14c6
14c8 :3 0 14c9 :2 0
165 :3 0 73 :3 0
32 :3 0 30 :2 0
b9f 14cc 14cf ba2
14cb 14d1 14d2 :2 0
c0 :2 0 30 :2 0
ba6 14d4 14d6 :3 0
14ca 14d8 14d7 :2 0
66 :3 0 67 :3 0
14da 14db 0 66
:3 0 77 :3 0 14dd
14de 0 18 :2 0
2 :4 0 166 :2 0
79 :2 0 27 :2 0
ba9 14e3 14e5 :3 0
bac 14df 14e7 14dc
14e9 14e8 :2 0 69
:3 0 7a :3 0 14eb
14ec 0 6b :4 0
167 :4 0 6e :2 0
6f :3 0 bb0 14f0
14f2 :3 0 6e :2 0
82 :4 0 bb3 14f4
14f6 :3 0 6e :2 0
83 :4 0 bb6 14f8
14fa :3 0 6e :2 0
73 :3 0 74 :3 0
84 :3 0 153 :3 0
14ff 1500 0 bb9
14fe 1502 75 :4 0
bbb 14fd 1505 bbe
14fc 1507 :3 0 6e
:2 0 ee :4 0 bc1
1509 150b :3 0 6e
:2 0 71 :4 0 bc4
150d 150f :3 0 6e
:2 0 1d :3 0 bc7
1511 1513 :3 0 6e
:2 0 71 :4 0 bca
1515 1517 :3 0 bcd
14ed 1519 :2 0 151b
bd0 151c 14ea 151b
0 151d bd2 0
1547 66 :3 0 67
:3 0 151e 151f 0
66 :3 0 77 :3 0
1521 1522 0 27
:2 0 2 :4 0 168
:2 0 79 :2 0 27
:2 0 bd4 1527 1529
:3 0 bd7 1523 152b
1520 152d 152c :2 0
69 :3 0 7a :3 0
152f 1530 0 6b
:4 0 169 :4 0 6e
:2 0 6f :3 0 bdb
1534 1536 :3 0 bde
1531 1538 :2 0 153a
be1 153b 152e 153a
0 153c be3 0
1547 88 :3 0 f1
:3 0 153d 153e 0
84 :3 0 153 :3 0
1540 1541 0 1d
:3 0 8a :3 0 be5
153f 1545 :2 0 1547
be9 1548 14d9 1547
0 154a 12ee 14c0
0 154a bed 0
1c03 ae :3 0 26
:3 0 27 :2 0 27
:2 0 bf0 154b 154f
9c :2 0 30 :4 0
bf6 1551 1553 :3 0
2b :3 0 ae :3 0
2b :3 0 6e :2 0
1d :3 0 bf9 1558
155a :3 0 27 :2 0
2a :2 0 bfc 1556
155e 1555 155f 0
1738 16a :3 0 a2
:3 0 16b :3 0 21
:3 0 16c :3 0 73
:3 0 a2 :3 0 16b
:3 0 16d :3 0 73
:3 0 a2 :3 0 16b
:3 0 16e :3 0 2d
:3 0 48 :3 0 4c
:3 0 49 :3 0 4a
:3 0 16f :3 0 12b
:3 0 1d :4 0 170
1 :8 0 157c 15
:3 0 a6 :3 0 1577
1578 0 a7 :3 0
1579 157a 0 157c
c00 15c6 a8 :3 0
15 :3 0 a6 :3 0
157f 1580 0 a7
:3 0 1581 1582 0
15bc 66 :3 0 67
:3 0 1584 1585 0
66 :3 0 77 :3 0
1587 1588 0 a9
:2 0 2 :4 0 171
:2 0 79 :2 0 27
:2 0 c03 158d 158f
:3 0 c06 1589 1591
1586 1593 1592 :2 0
69 :3 0 7a :3 0
1595 1596 0 6b
:4 0 172 :4 0 6e
:2 0 6f :3 0 c0a
159a 159c :3 0 6e
:2 0 82 :4 0 c0d
159e 15a0 :3 0 6e
:2 0 ac :4 0 c10
15a2 15a4 :3 0 6e
:2 0 a7 :3 0 c13
15a6 15a8 :3 0 6e
:2 0 ad :4 0 c16
15aa 15ac :3 0 6e
:2 0 ae :3 0 af
:3 0 27 :2 0 b0
:2 0 c19 15af 15b3
c1d 15ae 15b5 :3 0
c20 1597 15b7 :2 0
15b9 c23 15ba 1594
15b9 0 15bb c25
0 15bc c27 15bf
:3 0 15bf 0 15bf
15be 15bc 15bd :6 0
15c1 2c :3 0 c2a
15c3 c2c 15c2 15c1
:2 0 15c4 c2e :2 0
15c6 0 15c6 15c5
157c 15c4 :6 0 1738
1 :3 0 15 :3 0
a6 :3 0 15c8 15c9
0 15 :3 0 9c
:2 0 e2 :3 0 15cb
15cd 0 c32 15cc
15cf :3 0 15d0 :2 0
66 :3 0 67 :3 0
15d2 15d3 0 66
:3 0 77 :3 0 15d5
15d6 0 18 :2 0
2 :4 0 173 :2 0
79 :2 0 27 :2 0
c35 15db 15dd :3 0
c38 15d7 15df 15d4
15e1 15e0 :2 0 69
:3 0 7a :3 0 15e3
15e4 0 6b :4 0
174 :4 0 6e :2 0
6f :3 0 c3c 15e8
15ea :3 0 6e :2 0
82 :4 0 c3f 15ec
15ee :3 0 6e :2 0
83 :4 0 c42 15f0
15f2 :3 0 6e :2 0
73 :3 0 74 :3 0
84 :3 0 ed :3 0
15f7 15f8 0 c45
15f6 15fa 75 :4 0
c47 15f5 15fd c4a
15f4 15ff :3 0 6e
:2 0 ee :4 0 c4d
1601 1603 :3 0 6e
:2 0 71 :4 0 c50
1605 1607 :3 0 6e
:2 0 1d :3 0 c53
1609 160b :3 0 6e
:2 0 71 :4 0 c56
160d 160f :3 0 c59
15e5 1611 :2 0 1613
c5c 1614 15e2 1613
0 1615 c5e 0
163f 66 :3 0 67
:3 0 1616 1617 0
66 :3 0 77 :3 0
1619 161a 0 27
:2 0 2 :4 0 175
:2 0 79 :2 0 27
:2 0 c60 161f 1621
:3 0 c63 161b 1623
1618 1625 1624 :2 0
69 :3 0 7a :3 0
1627 1628 0 6b
:4 0 176 :4 0 6e
:2 0 6f :3 0 c67
162c 162e :3 0 c6a
1629 1630 :2 0 1632
c6d 1633 1626 1632
0 1634 c6f 0
163f 88 :3 0 f1
:3 0 1635 1636 0
84 :3 0 ed :3 0
1638 1639 0 1d
:3 0 8a :3 0 c71
1637 163d :2 0 163f
c75 1640 15d1 163f
0 1641 c79 0
1738 ae :3 0 4c
:3 0 27 :2 0 27
:2 0 c7b 1642 1646
9c :2 0 30 :4 0
c81 1648 164a :3 0
164b :2 0 73 :3 0
4a :3 0 30 :2 0
c84 164d 1650 bb
:2 0 30 :2 0 c89
1652 1654 :3 0 1655
:2 0 73 :3 0 48
:3 0 30 :2 0 c8c
1657 165a 73 :3 0
bb :2 0 4a :3 0
30 :2 0 c8f 165c
1660 c94 165d 1662
:3 0 1663 :2 0 1656
1665 1664 :2 0 1666
:2 0 164c 1668 1667
:2 0 66 :3 0 67
:3 0 166a 166b 0
66 :3 0 77 :3 0
166d 166e 0 18
:2 0 2 :4 0 177
:2 0 79 :2 0 27
:2 0 c97 1673 1675
:3 0 c9a 166f 1677
166c 1679 1678 :2 0
69 :3 0 7a :3 0
167b 167c 0 6b
:4 0 178 :4 0 6e
:2 0 6f :3 0 c9e
1680 1682 :3 0 6e
:2 0 82 :4 0 ca1
1684 1686 :3 0 6e
:2 0 83 :4 0 ca4
1688 168a :3 0 6e
:2 0 73 :3 0 74
:3 0 84 :3 0 179
:3 0 168f 1690 0
ca7 168e 1692 75
:4 0 ca9 168d 1695
cac 168c 1697 :3 0
6e :2 0 ee :4 0
caf 1699 169b :3 0
6e :2 0 71 :4 0
cb2 169d 169f :3 0
6e :2 0 1d :3 0
cb5 16a1 16a3 :3 0
6e :2 0 71 :4 0
cb8 16a5 16a7 :3 0
cbb 167d 16a9 :2 0
16ab cbe 16ac 167a
16ab 0 16ad cc0
0 16d7 66 :3 0
67 :3 0 16ae 16af
0 66 :3 0 77
:3 0 16b1 16b2 0
27 :2 0 2 :4 0
17a :2 0 79 :2 0
27 :2 0 cc2 16b7
16b9 :3 0 cc5 16b3
16bb 16b0 16bd 16bc
:2 0 69 :3 0 7a
:3 0 16bf 16c0 0
6b :4 0 17b :4 0
6e :2 0 6f :3 0
cc9 16c4 16c6 :3 0
ccc 16c1 16c8 :2 0
16ca ccf 16cb 16be
16ca 0 16cc cd1
0 16d7 88 :3 0
f1 :3 0 16cd 16ce
0 84 :3 0 179
:3 0 16d0 16d1 0
1d :3 0 8a :3 0
cd3 16cf 16d5 :2 0
16d7 cd7 16d8 1669
16d7 0 16d9 cdb
0 1738 17c :3 0
17d :3 0 17e :3 0
28 :3 0 42 :3 0
1e :3 0 17f :3 0
c6 :3 0 1a :3 0
12c :3 0 12b :3 0
1d :4 0 180 1
:8 0 16ec 15 :3 0
a6 :3 0 16e7 16e8
0 a7 :3 0 16e9
16ea 0 16ec cdd
1736 a8 :3 0 15
:3 0 a6 :3 0 16ef
16f0 0 a7 :3 0
16f1 16f2 0 172c
66 :3 0 67 :3 0
16f4 16f5 0 66
:3 0 77 :3 0 16f7
16f8 0 a9 :2 0
2 :4 0 181 :2 0
79 :2 0 27 :2 0
ce0 16fd 16ff :3 0
ce3 16f9 1701 16f6
1703 1702 :2 0 69
:3 0 7a :3 0 1705
1706 0 6b :4 0
182 :4 0 6e :2 0
6f :3 0 ce7 170a
170c :3 0 6e :2 0
82 :4 0 cea 170e
1710 :3 0 6e :2 0
ac :4 0 ced 1712
1714 :3 0 6e :2 0
a7 :3 0 cf0 1716
1718 :3 0 6e :2 0
ad :4 0 cf3 171a
171c :3 0 6e :2 0
ae :3 0 af :3 0
27 :2 0 b0 :2 0
cf6 171f 1723 cfa
171e 1725 :3 0 cfd
1707 1727 :2 0 1729
d00 172a 1704 1729
0 172b d02 0
172c d04 172f :3 0
172f 0 172f 172e
172c 172d :6 0 1731
2e :3 0 d07 1733
d09 1732 1731 :2 0
1734 d0b :2 0 1736
0 1736 1735 16ec
1734 :6 0 1738 1
:3 0 d0d 1961 2c
:3 0 ae :3 0 2c
:3 0 6e :2 0 1d
:3 0 d13 173c 173e
:3 0 27 :2 0 2a
:2 0 d16 173a 1742
1739 1743 0 1960
183 :3 0 2d :3 0
184 :3 0 185 :3 0
1d :4 0 186 1
:8 0 1750 15 :3 0
a6 :3 0 174b 174c
0 a7 :3 0 174d
174e 0 1750 d1a
179a a8 :3 0 15
:3 0 a6 :3 0 1753
1754 0 a7 :3 0
1755 1756 0 1790
66 :3 0 67 :3 0
1758 1759 0 66
:3 0 77 :3 0 175b
175c 0 a9 :2 0
2 :4 0 187 :2 0
79 :2 0 27 :2 0
d1d 1761 1763 :3 0
d20 175d 1765 175a
1767 1766 :2 0 69
:3 0 7a :3 0 1769
176a 0 6b :4 0
188 :4 0 6e :2 0
6f :3 0 d24 176e
1770 :3 0 6e :2 0
82 :4 0 d27 1772
1774 :3 0 6e :2 0
ac :4 0 d2a 1776
1778 :3 0 6e :2 0
a7 :3 0 d2d 177a
177c :3 0 6e :2 0
ad :4 0 d30 177e
1780 :3 0 6e :2 0
ae :3 0 af :3 0
27 :2 0 b0 :2 0
d33 1783 1787 d37
1782 1789 :3 0 d3a
176b 178b :2 0 178d
d3d 178e 1768 178d
0 178f d3f 0
1790 d41 1793 :3 0
1793 0 1793 1792
1790 1791 :6 0 1795
30 :3 0 d44 1797
d46 1796 1795 :2 0
1798 d48 :2 0 179a
0 179a 1799 1750
1798 :6 0 1960 1
:3 0 15 :3 0 a6
:3 0 179c 179d 0
15 :3 0 9c :2 0
e2 :3 0 179f 17a1
0 d4c 17a0 17a3
:3 0 17a4 :2 0 66
:3 0 67 :3 0 17a6
17a7 0 66 :3 0
77 :3 0 17a9 17aa
0 18 :2 0 2
:4 0 189 :2 0 79
:2 0 27 :2 0 d4f
17af 17b1 :3 0 d52
17ab 17b3 17a8 17b5
17b4 :2 0 69 :3 0
7a :3 0 17b7 17b8
0 6b :4 0 18a
:4 0 6e :2 0 6f
:3 0 d56 17bc 17be
:3 0 6e :2 0 82
:4 0 d59 17c0 17c2
:3 0 6e :2 0 83
:4 0 d5c 17c4 17c6
:3 0 6e :2 0 73
:3 0 74 :3 0 84
:3 0 ed :3 0 17cb
17cc 0 d5f 17ca
17ce 75 :4 0 d61
17c9 17d1 d64 17c8
17d3 :3 0 6e :2 0
ee :4 0 d67 17d5
17d7 :3 0 6e :2 0
71 :4 0 d6a 17d9
17db :3 0 6e :2 0
1d :3 0 d6d 17dd
17df :3 0 6e :2 0
71 :4 0 d70 17e1
17e3 :3 0 d73 17b9
17e5 :2 0 17e7 d76
17e8 17b6 17e7 0
17e9 d78 0 1813
66 :3 0 67 :3 0
17ea 17eb 0 66
:3 0 77 :3 0 17ed
17ee 0 27 :2 0
2 :4 0 18b :2 0
79 :2 0 27 :2 0
d7a 17f3 17f5 :3 0
d7d 17ef 17f7 17ec
17f9 17f8 :2 0 69
:3 0 7a :3 0 17fb
17fc 0 6b :4 0
18c :4 0 6e :2 0
6f :3 0 d81 1800
1802 :3 0 d84 17fd
1804 :2 0 1806 d87
1807 17fa 1806 0
1808 d89 0 1813
88 :3 0 f1 :3 0
1809 180a 0 84
:3 0 ed :3 0 180c
180d 0 1d :3 0
8a :3 0 d8b 180b
1811 :2 0 1813 d8f
1814 17a5 1813 0
1815 d93 0 1960
128 :3 0 132 :3 0
ae :3 0 1f :3 0
132 :3 0 ae :3 0
128 :3 0 132 :3 0
ae :3 0 18d :3 0
18e :3 0 37 :3 0
21 :3 0 44 :3 0
129 :3 0 12a :3 0
17 :3 0 12b :3 0
1d :3 0 12c :4 0
18f 1 :8 0 1830
15 :3 0 a6 :3 0
182b 182c 0 a7
:3 0 182d 182e 0
1830 d95 187a a8
:3 0 15 :3 0 a6
:3 0 1833 1834 0
a7 :3 0 1835 1836
0 1870 66 :3 0
67 :3 0 1838 1839
0 66 :3 0 77
:3 0 183b 183c 0
a9 :2 0 2 :4 0
190 :2 0 79 :2 0
27 :2 0 d98 1841
1843 :3 0 d9b 183d
1845 183a 1847 1846
:2 0 69 :3 0 7a
:3 0 1849 184a 0
6b :4 0 191 :4 0
6e :2 0 6f :3 0
d9f 184e 1850 :3 0
6e :2 0 82 :4 0
da2 1852 1854 :3 0
6e :2 0 ac :4 0
da5 1856 1858 :3 0
6e :2 0 a7 :3 0
da8 185a 185c :3 0
6e :2 0 ad :4 0
dab 185e 1860 :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 dae 1863
1867 db2 1862 1869
:3 0 db5 184b 186b
:2 0 186d db8 186e
1848 186d 0 186f
dba 0 1870 dbc
1873 :3 0 1873 0
1873 1872 1870 1871
:6 0 1875 32 :3 0
dbf 1877 dc1 1876
1875 :2 0 1878 dc3
:2 0 187a 0 187a
1879 1830 1878 :6 0
1960 1 :3 0 15
:3 0 a6 :3 0 187c
187d 0 15 :3 0
9c :2 0 b1 :3 0
187f 1881 0 dc7
1880 1883 :3 0 1884
:2 0 73 :3 0 44
:3 0 30 :2 0 dca
1886 1889 9c :2 0
27 :2 0 dcf 188b
188d :3 0 188e :2 0
1885 1890 188f :2 0
66 :3 0 67 :3 0
1892 1893 0 66
:3 0 77 :3 0 1895
1896 0 18 :2 0
2 :4 0 192 :2 0
79 :2 0 27 :2 0
dd2 189b 189d :3 0
dd5 1897 189f 1894
18a1 18a0 :2 0 69
:3 0 7a :3 0 18a3
18a4 0 6b :4 0
193 :4 0 6e :2 0
6f :3 0 dd9 18a8
18aa :3 0 6e :2 0
82 :4 0 ddc 18ac
18ae :3 0 6e :2 0
83 :4 0 ddf 18b0
18b2 :3 0 6e :2 0
73 :3 0 74 :3 0
84 :3 0 153 :3 0
18b7 18b8 0 de2
18b6 18ba 75 :4 0
de4 18b5 18bd de7
18b4 18bf :3 0 6e
:2 0 ee :4 0 dea
18c1 18c3 :3 0 6e
:2 0 71 :4 0 ded
18c5 18c7 :3 0 6e
:2 0 1d :3 0 df0
18c9 18cb :3 0 6e
:2 0 71 :4 0 df3
18cd 18cf :3 0 df6
18a5 18d1 :2 0 18d3
df9 18d4 18a2 18d3
0 18d5 dfb 0
18ff 66 :3 0 67
:3 0 18d6 18d7 0
66 :3 0 77 :3 0
18d9 18da 0 27
:2 0 2 :4 0 194
:2 0 79 :2 0 27
:2 0 dfd 18df 18e1
:3 0 e00 18db 18e3
18d8 18e5 18e4 :2 0
69 :3 0 7a :3 0
18e7 18e8 0 6b
:4 0 195 :4 0 6e
:2 0 6f :3 0 e04
18ec 18ee :3 0 e07
18e9 18f0 :2 0 18f2
e0a 18f3 18e6 18f2
0 18f4 e0c 0
18ff 88 :3 0 f1
:3 0 18f5 18f6 0
84 :3 0 153 :3 0
18f8 18f9 0 1d
:3 0 8a :3 0 e0e
18f7 18fd :2 0 18ff
e12 1900 1891 18ff
0 1901 e16 0
1960 17c :3 0 17d
:3 0 17e :3 0 28
:3 0 42 :3 0 1e
:3 0 17f :3 0 c6
:3 0 1a :3 0 12c
:3 0 12b :3 0 1d
:4 0 196 1 :8 0
1914 15 :3 0 a6
:3 0 190f 1910 0
a7 :3 0 1911 1912
0 1914 e18 195e
a8 :3 0 15 :3 0
a6 :3 0 1917 1918
0 a7 :3 0 1919
191a 0 1954 66
:3 0 67 :3 0 191c
191d 0 66 :3 0
77 :3 0 191f 1920
0 a9 :2 0 2
:4 0 197 :2 0 79
:2 0 27 :2 0 e1b
1925 1927 :3 0 e1e
1921 1929 191e 192b
192a :2 0 69 :3 0
7a :3 0 192d 192e
0 6b :4 0 198
:4 0 6e :2 0 6f
:3 0 e22 1932 1934
:3 0 6e :2 0 82
:4 0 e25 1936 1938
:3 0 6e :2 0 ac
:4 0 e28 193a 193c
:3 0 6e :2 0 a7
:3 0 e2b 193e 1940
:3 0 6e :2 0 ad
:4 0 e2e 1942 1944
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 e31
1947 194b e35 1946
194d :3 0 e38 192f
194f :2 0 1951 e3b
1952 192c 1951 0
1953 e3d 0 1954
e3f 1957 :3 0 1957
0 1957 1956 1954
1955 :6 0 1959 34
:3 0 e42 195b e44
195a 1959 :2 0 195c
e46 :2 0 195e 0
195e 195d 1914 195c
:6 0 1960 1 :3 0
e48 1962 1554 1738
0 1963 0 1960
0 1963 e4f 0
1c03 21 :3 0 21
:3 0 1964 1965 0
1c03 73 :3 0 46
:3 0 30 :2 0 e52
1967 196a 9c :2 0
27 :2 0 e57 196c
196e :3 0 a2 :3 0
199 :3 0 132 :3 0
ae :3 0 21 :3 0
a2 :3 0 19a :3 0
1f :3 0 21 :3 0
a4 :4 0 19b 1
:8 0 1980 15 :3 0
a6 :3 0 197b 197c
0 a7 :3 0 197d
197e 0 1980 e5a
19ca a8 :3 0 15
:3 0 a6 :3 0 1983
1984 0 a7 :3 0
1985 1986 0 19c0
66 :3 0 67 :3 0
1988 1989 0 66
:3 0 77 :3 0 198b
198c 0 a9 :2 0
2 :4 0 19c :2 0
79 :2 0 27 :2 0
e5d 1991 1993 :3 0
e60 198d 1995 198a
1997 1996 :2 0 69
:3 0 7a :3 0 1999
199a 0 6b :4 0
19d :4 0 6e :2 0
6f :3 0 e64 199e
19a0 :3 0 6e :2 0
82 :4 0 e67 19a2
19a4 :3 0 6e :2 0
ac :4 0 e6a 19a6
19a8 :3 0 6e :2 0
a7 :3 0 e6d 19aa
19ac :3 0 6e :2 0
ad :4 0 e70 19ae
19b0 :3 0 6e :2 0
ae :3 0 af :3 0
27 :2 0 b0 :2 0
e73 19b3 19b7 e77
19b2 19b9 :3 0 e7a
199b 19bb :2 0 19bd
e7d 19be 1998 19bd
0 19bf e7f 0
19c0 e81 19c3 :3 0
19c3 0 19c3 19c2
19c0 19c1 :6 0 19c5
36 :3 0 e84 19c7
e86 19c6 19c5 :2 0
19c8 e88 :2 0 19ca
0 19ca 19c9 1980
19c8 :6 0 1b44 1
:3 0 132 :3 0 ae
:3 0 1f :3 0 132
:3 0 ae :3 0 21
:3 0 1f :3 0 21
:3 0 21 :3 0 a4
:4 0 19e 1 :8 0
19dc 15 :3 0 a6
:3 0 19d7 19d8 0
a7 :3 0 19d9 19da
0 19dc e8a 1a26
a8 :3 0 15 :3 0
a6 :3 0 19df 19e0
0 a7 :3 0 19e1
19e2 0 1a1c 66
:3 0 67 :3 0 19e4
19e5 0 66 :3 0
77 :3 0 19e7 19e8
0 a9 :2 0 2
:4 0 19f :2 0 79
:2 0 27 :2 0 e8d
19ed 19ef :3 0 e90
19e9 19f1 19e6 19f3
19f2 :2 0 69 :3 0
7a :3 0 19f5 19f6
0 6b :4 0 1a0
:4 0 6e :2 0 6f
:3 0 e94 19fa 19fc
:3 0 6e :2 0 82
:4 0 e97 19fe 1a00
:3 0 6e :2 0 ac
:4 0 e9a 1a02 1a04
:3 0 6e :2 0 a7
:3 0 e9d 1a06 1a08
:3 0 6e :2 0 ad
:4 0 ea0 1a0a 1a0c
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 ea3
1a0f 1a13 ea7 1a0e
1a15 :3 0 eaa 19f7
1a17 :2 0 1a19 ead
1a1a 19f4 1a19 0
1a1b eaf 0 1a1c
eb1 1a1f :3 0 1a1f
0 1a1f 1a1e 1a1c
1a1d :6 0 1a21 38
:3 0 eb4 1a23 eb6
1a22 1a21 :2 0 1a24
eb8 :2 0 1a26 0
1a26 1a25 19dc 1a24
:6 0 1b44 1 :3 0
45 :3 0 1a1 :2 0
1a28 1a29 0 1b44
22 :3 0 6 :3 0
1a2b 1a2c 0 1b44
73 :3 0 33 :3 0
30 :2 0 eba 1a2e
1a31 9c :2 0 30
:2 0 ebf 1a33 1a35
:3 0 3f :3 0 118
:2 0 1a37 1a38 0
1a3a ec2 1a3b 1a36
1a3a 0 1a3c ec4
0 1b44 62 :3 0
1a2 :3 0 28 :3 0
17 :3 0 1a :3 0
1d :3 0 4e :3 0
32 :3 0 23 :3 0
23 :3 0 23 :3 0
23 :3 0 21 :3 0
22 :3 0 41 :3 0
37 :3 0 35 :3 0
38 :3 0 39 :3 0
34 :3 0 45 :3 0
26 :3 0 33 :3 0
31 :3 0 3b :3 0
36 :3 0 3f :3 0
3d :3 0 43 :3 0
1c :3 0 30 :2 0
30 :2 0 50 :2 0
50 :2 0 ec6 1a3e
1a5f 1a3d 1a60 0
1b44 62 :3 0 9c
:2 0 30 :2 0 ee9
1a63 1a65 :3 0 73
:3 0 33 :3 0 30
:2 0 eec 1a67 1a6a
9c :2 0 30 :2 0
ef1 1a6c 1a6e :3 0
1a3 :3 0 1a4 :3 0
1a5 :3 0 1d :4 0
1a6 1 :8 0 1a8a
1a7 :4 0 1a75 :3 0
8a :3 0 9c :2 0
ef6 1a78 1a79 :3 0
15 :3 0 a6 :3 0
1a7b 1a7c 0 30
:2 0 1a7d 1a7e 0
1a80 ef9 1a87 15
:3 0 a6 :3 0 1a81
1a82 0 116 :2 0
1a83 1a84 0 1a86
efb 1a88 1a7a 1a80
0 1a89 0 1a86
0 1a89 efd 0
1a8a f00 1ad4 a8
:3 0 15 :3 0 a6
:3 0 1a8d 1a8e 0
a7 :3 0 1a8f 1a90
0 1aca 66 :3 0
67 :3 0 1a92 1a93
0 66 :3 0 77
:3 0 1a95 1a96 0
a9 :2 0 2 :4 0
1a8 :2 0 79 :2 0
27 :2 0 f03 1a9b
1a9d :3 0 f06 1a97
1a9f 1a94 1aa1 1aa0
:2 0 69 :3 0 7a
:3 0 1aa3 1aa4 0
6b :4 0 1a9 :4 0
6e :2 0 6f :3 0
f0a 1aa8 1aaa :3 0
6e :2 0 82 :4 0
f0d 1aac 1aae :3 0
6e :2 0 ac :4 0
f10 1ab0 1ab2 :3 0
6e :2 0 a7 :3 0
f13 1ab4 1ab6 :3 0
6e :2 0 ad :4 0
f16 1ab8 1aba :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 f19 1abd
1ac1 f1d 1abc 1ac3
:3 0 f20 1aa5 1ac5
:2 0 1ac7 f23 1ac8
1aa2 1ac7 0 1ac9
f25 0 1aca f27
1acd :3 0 1acd 0
1acd 1acc 1aca 1acb
:6 0 1acf 3a :3 0
f2a 1ad1 f2c 1ad0
1acf :2 0 1ad2 f2e
:2 0 1ad4 0 1ad4
1ad3 1a8a 1ad2 :6 0
1ad6 1 :3 0 f30
1b3e 1a3 :3 0 1a4
:3 0 1a5 :3 0 1d
:4 0 1aa 1 :8 0
1af1 1a7 :4 0 1adc
:3 0 8a :3 0 9c
:2 0 f34 1adf 1ae0
:3 0 15 :3 0 a6
:3 0 1ae2 1ae3 0
30 :2 0 1ae4 1ae5
0 1ae7 f37 1aee
15 :3 0 a6 :3 0
1ae8 1ae9 0 116
:2 0 1aea 1aeb 0
1aed f39 1aef 1ae1
1ae7 0 1af0 0
1aed 0 1af0 f3b
0 1af1 f3e 1b3b
a8 :3 0 15 :3 0
a6 :3 0 1af4 1af5
0 a7 :3 0 1af6
1af7 0 1b31 66
:3 0 67 :3 0 1af9
1afa 0 66 :3 0
77 :3 0 1afc 1afd
0 a9 :2 0 2
:4 0 1ab :2 0 79
:2 0 27 :2 0 f41
1b02 1b04 :3 0 f44
1afe 1b06 1afb 1b08
1b07 :2 0 69 :3 0
7a :3 0 1b0a 1b0b
0 6b :4 0 1ac
:4 0 6e :2 0 6f
:3 0 f48 1b0f 1b11
:3 0 6e :2 0 82
:4 0 f4b 1b13 1b15
:3 0 6e :2 0 ac
:4 0 f4e 1b17 1b19
:3 0 6e :2 0 a7
:3 0 f51 1b1b 1b1d
:3 0 6e :2 0 ad
:4 0 f54 1b1f 1b21
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 f57
1b24 1b28 f5b 1b23
1b2a :3 0 f5e 1b0c
1b2c :2 0 1b2e f61
1b2f 1b09 1b2e 0
1b30 f63 0 1b31
f65 1b34 :3 0 1b34
0 1b34 1b33 1b31
1b32 :6 0 1b36 3c
:3 0 f68 1b38 f6a
1b37 1b36 :2 0 1b39
f6c :2 0 1b3b 0
1b3b 1b3a 1af1 1b39
:6 0 1b3d 1 :3 0
f6e 1b3f 1a6f 1ad6
0 1b40 0 1b3d
0 1b40 f70 0
1b41 f73 1b42 1a66
1b41 0 1b43 f75
0 1b44 f77 1c00
21 :3 0 1f :3 0
1b45 1b46 0 1bff
22 :3 0 6 :3 0
1b48 1b49 0 1bff
ae :3 0 26 :3 0
27 :2 0 27 :2 0
f7f 1b4b 1b4f 9c
:2 0 27 :4 0 f85
1b51 1b53 :3 0 45
:3 0 84 :3 0 1ad
:3 0 1b56 1b57 0
1b55 1b58 0 1b5a
f88 1b69 45 :3 0
11e :3 0 73 :3 0
3a :3 0 30 :2 0
f8a 1b5d 1b60 84
:3 0 121 :3 0 1b62
1b63 0 f8d 1b5c
1b65 1b5b 1b66 0
1b68 f90 1b6a 1b54
1b5a 0 1b6b 0
1b68 0 1b6b f92
0 1bff 62 :3 0
1a2 :3 0 28 :3 0
17 :3 0 1a :3 0
1d :3 0 4e :3 0
32 :3 0 23 :3 0
23 :3 0 23 :3 0
23 :3 0 21 :3 0
22 :3 0 41 :3 0
37 :3 0 35 :3 0
38 :3 0 39 :3 0
34 :3 0 45 :3 0
26 :3 0 33 :3 0
31 :3 0 3b :3 0
36 :3 0 3f :3 0
3d :3 0 43 :3 0
1c :3 0 30 :2 0
30 :2 0 50 :2 0
50 :2 0 f95 1b6d
1b8e 1b6c 1b8f 0
1bff 62 :3 0 9c
:2 0 30 :2 0 fb8
1b92 1b94 :3 0 1a3
:3 0 1a4 :3 0 1a5
:3 0 1d :4 0 1a6
1 :8 0 1bb0 1a7
:4 0 1b9b :3 0 8a
:3 0 9c :2 0 fbd
1b9e 1b9f :3 0 15
:3 0 a6 :3 0 1ba1
1ba2 0 30 :2 0
1ba3 1ba4 0 1ba6
fc0 1bad 15 :3 0
a6 :3 0 1ba7 1ba8
0 116 :2 0 1ba9
1baa 0 1bac fc2
1bae 1ba0 1ba6 0
1baf 0 1bac 0
1baf fc4 0 1bb0
fc7 1bfa a8 :3 0
15 :3 0 a6 :3 0
1bb3 1bb4 0 a7
:3 0 1bb5 1bb6 0
1bf0 66 :3 0 67
:3 0 1bb8 1bb9 0
66 :3 0 77 :3 0
1bbb 1bbc 0 a9
:2 0 2 :4 0 1ae
:2 0 79 :2 0 27
:2 0 fca 1bc1 1bc3
:3 0 fcd 1bbd 1bc5
1bba 1bc7 1bc6 :2 0
69 :3 0 7a :3 0
1bc9 1bca 0 6b
:4 0 1af :4 0 6e
:2 0 6f :3 0 fd1
1bce 1bd0 :3 0 6e
:2 0 82 :4 0 fd4
1bd2 1bd4 :3 0 6e
:2 0 ac :4 0 fd7
1bd6 1bd8 :3 0 6e
:2 0 a7 :3 0 fda
1bda 1bdc :3 0 6e
:2 0 ad :4 0 fdd
1bde 1be0 :3 0 6e
:2 0 ae :3 0 af
:3 0 27 :2 0 b0
:2 0 fe0 1be3 1be7
fe4 1be2 1be9 :3 0
fe7 1bcb 1beb :2 0
1bed fea 1bee 1bc8
1bed 0 1bef fec
0 1bf0 fee 1bf3
:3 0 1bf3 0 1bf3
1bf2 1bf0 1bf1 :6 0
1bf5 3e :3 0 ff1
1bf7 ff3 1bf6 1bf5
:2 0 1bf8 ff5 :2 0
1bfa 0 1bfa 1bf9
1bb0 1bf8 :6 0 1bfc
1 :3 0 ff7 1bfd
1b95 1bfc 0 1bfe
ff9 0 1bff ffb
1c01 196f 1b44 0
1c02 0 1bff 0
1c02 1001 0 1c03
1004 2565 73 :3 0
90 :3 0 29 :3 0
1011 1c05 1c07 30
:2 0 1013 1c04 1c0a
91 :2 0 18 :2 0
1018 1c0c 1c0e :3 0
64 :3 0 30 :2 0
1c10 1c11 0 1c13
101b 1c2b 64 :3 0
1b0 :3 0 73 :3 0
90 :3 0 29 :3 0
101d 1c17 1c19 30
:2 0 101f 1c16 1c1c
79 :2 0 27 :2 0
1022 1c1e 1c20 :3 0
1c21 :2 0 1b1 :2 0
be :2 0 1025 1c23
1c25 :3 0 1028 1c15
1c27 1c14 1c28 0
1c2a 102a 1c2c 1c0f
1c13 0 1c2d 0
1c2a 0 1c2d 102c
0 2564 64 :3 0
bb :2 0 30 :2 0
1031 1c2f 1c31 :3 0
2f :3 0 30 :2 0
1c33 1c34 0 2561
1b2 :3 0 73 :3 0
2f :3 0 30 :2 0
1034 1c37 1c3a 64
:3 0 91 :2 0 1b3
:3 0 1039 1c3d 1c3f
:3 0 1c40 2560 46
:3 0 30 :2 0 1c42
1c43 0 255e 1d
:3 0 bc :3 0 bd
:3 0 1c46 1c47 0
18 :2 0 18 :2 0
73 :3 0 2f :3 0
30 :2 0 103c 1c4b
1c4e 11a :2 0 be
:2 0 103f 1c50 1c52
:3 0 79 :2 0 27
:2 0 1042 1c54 1c56
:3 0 29 :3 0 1045
1c48 1c59 1c45 1c5a
0 255e 26 :3 0
bc :3 0 bd :3 0
1c5d 1c5e 0 27
:2 0 27 :2 0 73
:3 0 2f :3 0 30
:2 0 104a 1c62 1c65
11a :2 0 be :2 0
104d 1c67 1c69 :3 0
79 :2 0 18 :2 0
1050 1c6b 1c6d :3 0
79 :2 0 27 :2 0
1053 1c6f 1c71 :3 0
29 :3 0 1056 1c5f
1c74 1c5c 1c75 0
255e 1f :3 0 5
:3 0 1c77 1c78 0
255e 46 :3 0 30
:2 0 1c7a 1c7b 0
255e 44 :3 0 30
:2 0 1c7d 1c7e 0
255e 21 :3 0 1f
:3 0 1c80 1c81 0
255e 1b4 :3 0 127
:3 0 1b5 :3 0 44
:3 0 21 :3 0 129
:3 0 c1 :3 0 17
:3 0 12a :3 0 17
:3 0 12b :3 0 1d
:3 0 12c :3 0 26
:4 0 1b6 1 :8 0
1c97 15 :3 0 a6
:3 0 1c92 1c93 0
a7 :3 0 1c94 1c95
0 1c97 105b 1ce1
a8 :3 0 15 :3 0
a6 :3 0 1c9a 1c9b
0 a7 :3 0 1c9c
1c9d 0 1cd7 66
:3 0 67 :3 0 1c9f
1ca0 0 66 :3 0
77 :3 0 1ca2 1ca3
0 a9 :2 0 2
:4 0 1b7 :2 0 79
:2 0 27 :2 0 105e
1ca8 1caa :3 0 1061
1ca4 1cac 1ca1 1cae
1cad :2 0 69 :3 0
7a :3 0 1cb0 1cb1
0 6b :4 0 1b8
:4 0 6e :2 0 6f
:3 0 1065 1cb5 1cb7
:3 0 6e :2 0 82
:4 0 1068 1cb9 1cbb
:3 0 6e :2 0 ac
:4 0 106b 1cbd 1cbf
:3 0 6e :2 0 a7
:3 0 106e 1cc1 1cc3
:3 0 6e :2 0 ad
:4 0 1071 1cc5 1cc7
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 1074
1cca 1cce 1078 1cc9
1cd0 :3 0 107b 1cb2
1cd2 :2 0 1cd4 107e
1cd5 1caf 1cd4 0
1cd6 1080 0 1cd7
1082 1cda :3 0 1cda
0 1cda 1cd9 1cd7
1cd8 :6 0 1cdc 41
:3 0 1085 1cde 1087
1cdd 1cdc :2 0 1cdf
1089 :2 0 1ce1 0
1ce1 1ce0 1c97 1cdf
:6 0 255e 40 :3 0
73 :3 0 44 :3 0
30 :2 0 108b 1ce3
1ce6 bb :2 0 30
:2 0 1090 1ce8 1cea
:3 0 1ceb :2 0 21
:3 0 8f :2 0 1093
1cee 1cef :3 0 1cf0
:2 0 1cf1 :2 0 1cec
1cf3 1cf2 :2 0 46
:3 0 27 :2 0 1cf5
1cf6 0 1d09 a2
:3 0 fb :3 0 1cf8
1cf9 0 1f :3 0
21 :3 0 1095 1cfa
1cfd 91 :2 0 30
:2 0 109a 1cff 1d01
:3 0 1f :3 0 21
:3 0 1d03 1d04 0
1d06 109d 1d07 1d02
1d06 0 1d08 109f
0 1d09 10a1 1d0a
1cf4 1d09 0 1d0b
10a4 0 255e ae
:3 0 26 :3 0 27
:2 0 27 :2 0 10a6
1d0c 1d10 9c :2 0
27 :4 0 10ac 1d12
1d14 :3 0 3a :3 0
84 :3 0 1ad :3 0
1d17 1d18 0 1d16
1d19 0 1d47 73
:3 0 90 :3 0 2c
:3 0 10af 1d1c 1d1e
30 :2 0 10b1 1d1b
1d21 9c :2 0 30
:2 0 10b6 1d23 1d25
:3 0 2c :3 0 1d
:3 0 1d27 1d28 0
1d2a 10b9 1d44 2c
:3 0 ae :3 0 2c
:3 0 6e :2 0 1b9
:4 0 10bb 1d2e 1d30
:3 0 27 :2 0 2a
:2 0 10be 1d2c 1d34
1d2b 1d35 0 1d43
2c :3 0 ae :3 0
2c :3 0 6e :2 0
1d :3 0 10c2 1d3a
1d3c :3 0 27 :2 0
2a :2 0 10c5 1d38
1d40 1d37 1d41 0
1d43 10c9 1d45 1d26
1d2a 0 1d46 0
1d43 0 1d46 10cc
0 1d47 10cf 1d75
73 :3 0 90 :3 0
2b :3 0 10d2 1d49
1d4b 30 :2 0 10d4
1d48 1d4e 9c :2 0
30 :2 0 10d9 1d50
1d52 :3 0 2b :3 0
1d :3 0 1d54 1d55
0 1d57 10dc 1d71
2b :3 0 ae :3 0
2b :3 0 6e :2 0
1b9 :4 0 10de 1d5b
1d5d :3 0 27 :2 0
2a :2 0 10e1 1d59
1d61 1d58 1d62 0
1d70 2b :3 0 ae
:3 0 2b :3 0 6e
:2 0 1d :3 0 10e5
1d67 1d69 :3 0 27
:2 0 2a :2 0 10e8
1d65 1d6d 1d64 1d6e
0 1d70 10ec 1d72
1d53 1d57 0 1d73
0 1d70 0 1d73
10ef 0 1d74 10f2
1d76 1d15 1d47 0
1d77 0 1d74 0
1d77 10f4 0 255e
33 :3 0 30 :2 0
1d78 1d79 0 255e
44 :3 0 30 :2 0
1d7b 1d7c 0 255e
73 :3 0 46 :3 0
30 :2 0 10f7 1d7e
1d81 9c :2 0 27
:2 0 10fc 1d83 1d85
:3 0 63 :3 0 9c
:2 0 27 :2 0 1101
1d88 1d8a :3 0 ae
:3 0 26 :3 0 27
:2 0 27 :2 0 1104
1d8c 1d90 9c :2 0
30 :4 0 110a 1d92
1d94 :3 0 130 :3 0
131 :3 0 132 :3 0
ae :3 0 1f :3 0
132 :3 0 ae :3 0
131 :3 0 132 :3 0
ae :3 0 22 :3 0
132 :3 0 ae :3 0
133 :3 0 134 :3 0
37 :3 0 134 :3 0
19 :3 0 21 :3 0
44 :3 0 47 :3 0
129 :3 0 12a :3 0
17 :3 0 12b :3 0
1d :3 0 12c :3 0
135 :4 0 1ba 1
:8 0 1db8 15 :3 0
a6 :3 0 1db3 1db4
0 a7 :3 0 1db5
1db6 0 1db8 110d
1e02 a8 :3 0 15
:3 0 a6 :3 0 1dbb
1dbc 0 a7 :3 0
1dbd 1dbe 0 1df8
66 :3 0 67 :3 0
1dc0 1dc1 0 66
:3 0 77 :3 0 1dc3
1dc4 0 a9 :2 0
2 :4 0 1bb :2 0
79 :2 0 27 :2 0
1110 1dc9 1dcb :3 0
1113 1dc5 1dcd 1dc2
1dcf 1dce :2 0 69
:3 0 7a :3 0 1dd1
1dd2 0 6b :4 0
1bc :4 0 6e :2 0
6f :3 0 1117 1dd6
1dd8 :3 0 6e :2 0
82 :4 0 111a 1dda
1ddc :3 0 6e :2 0
ac :4 0 111d 1dde
1de0 :3 0 6e :2 0
a7 :3 0 1120 1de2
1de4 :3 0 6e :2 0
ad :4 0 1123 1de6
1de8 :3 0 6e :2 0
ae :3 0 af :3 0
27 :2 0 b0 :2 0
1126 1deb 1def 112a
1dea 1df1 :3 0 112d
1dd3 1df3 :2 0 1df5
1130 1df6 1dd0 1df5
0 1df7 1132 0
1df8 1134 1dfb :3 0
1dfb 0 1dfb 1dfa
1df8 1df9 :6 0 1dfd
43 :3 0 1137 1dff
1139 1dfe 1dfd :2 0
1e00 113b :2 0 1e02
0 1e02 1e01 1db8
1e00 :6 0 1f23 40
:3 0 15 :3 0 a6
:3 0 1e04 1e05 0
15 :3 0 9c :2 0
b1 :3 0 1e07 1e09
0 113f 1e08 1e0b
:3 0 1e0c :2 0 46
:3 0 27 :2 0 1e0e
1e0f 0 1e9c 73
:3 0 47 :3 0 30
:2 0 1142 1e11 1e14
9c :2 0 30 :2 0
1147 1e16 1e18 :3 0
1e19 :2 0 73 :3 0
44 :3 0 30 :2 0
114a 1e1b 1e1e 9c
:2 0 27 :2 0 114f
1e20 1e22 :3 0 1e23
:2 0 1e1a 1e25 1e24
:2 0 130 :3 0 139
:3 0 132 :3 0 ae
:3 0 1f :3 0 132
:3 0 ae :3 0 139
:3 0 132 :3 0 ae
:3 0 22 :3 0 132
:3 0 ae :3 0 13a
:3 0 13b :3 0 37
:3 0 19 :3 0 21
:3 0 44 :3 0 129
:3 0 12a :3 0 17
:3 0 12b :3 0 1d
:3 0 12c :3 0 135
:4 0 1bd 1 :8 0
1e47 15 :3 0 a6
:3 0 1e42 1e43 0
a7 :3 0 1e44 1e45
0 1e47 1152 1e91
a8 :3 0 15 :3 0
a6 :3 0 1e4a 1e4b
0 a7 :3 0 1e4c
1e4d 0 1e87 66
:3 0 67 :3 0 1e4f
1e50 0 66 :3 0
77 :3 0 1e52 1e53
0 a9 :2 0 2
:4 0 1be :2 0 79
:2 0 27 :2 0 1155
1e58 1e5a :3 0 1158
1e54 1e5c 1e51 1e5e
1e5d :2 0 69 :3 0
7a :3 0 1e60 1e61
0 6b :4 0 1bf
:4 0 6e :2 0 6f
:3 0 115c 1e65 1e67
:3 0 6e :2 0 82
:4 0 115f 1e69 1e6b
:3 0 6e :2 0 ac
:4 0 1162 1e6d 1e6f
:3 0 6e :2 0 a7
:3 0 1165 1e71 1e73
:3 0 6e :2 0 ad
:4 0 1168 1e75 1e77
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 116b
1e7a 1e7e 116f 1e79
1e80 :3 0 1172 1e62
1e82 :2 0 1e84 1175
1e85 1e5f 1e84 0
1e86 1177 0 1e87
1179 1e8a :3 0 1e8a
0 1e8a 1e89 1e87
1e88 :6 0 1e8c 45
:3 0 117c 1e8e 117e
1e8d 1e8c :2 0 1e8f
1180 :2 0 1e91 0
1e91 1e90 1e47 1e8f
:6 0 1e93 40 :3 0
1182 1e98 33 :3 0
117 :2 0 1e94 1e95
0 1e97 1184 1e99
1e26 1e93 0 1e9a
0 1e97 0 1e9a
1186 0 1e9c b7
:3 0 1189 1f21 15
:3 0 a6 :3 0 1e9d
1e9e 0 15 :3 0
9c :2 0 e2 :3 0
1ea0 1ea2 0 118e
1ea1 1ea4 :3 0 1ea5
:2 0 73 :3 0 44
:3 0 30 :2 0 1191
1ea7 1eaa 9c :2 0
27 :2 0 1196 1eac
1eae :3 0 1eaf :2 0
1ea6 1eb1 1eb0 :2 0
130 :3 0 139 :3 0
132 :3 0 ae :3 0
1f :3 0 132 :3 0
ae :3 0 139 :3 0
132 :3 0 ae :3 0
22 :3 0 132 :3 0
ae :3 0 13a :3 0
13b :3 0 37 :3 0
19 :3 0 21 :3 0
44 :3 0 129 :3 0
12a :3 0 17 :3 0
12b :3 0 1d :3 0
12c :3 0 135 :4 0
1c0 1 :8 0 1ed3
15 :3 0 a6 :3 0
1ece 1ecf 0 a7
:3 0 1ed0 1ed1 0
1ed3 1199 1f1d a8
:3 0 15 :3 0 a6
:3 0 1ed6 1ed7 0
a7 :3 0 1ed8 1ed9
0 1f13 66 :3 0
67 :3 0 1edb 1edc
0 66 :3 0 77
:3 0 1ede 1edf 0
a9 :2 0 2 :4 0
1c1 :2 0 79 :2 0
27 :2 0 119c 1ee4
1ee6 :3 0 119f 1ee0
1ee8 1edd 1eea 1ee9
:2 0 69 :3 0 7a
:3 0 1eec 1eed 0
6b :4 0 1c2 :4 0
6e :2 0 6f :3 0
11a3 1ef1 1ef3 :3 0
6e :2 0 82 :4 0
11a6 1ef5 1ef7 :3 0
6e :2 0 ac :4 0
11a9 1ef9 1efb :3 0
6e :2 0 a7 :3 0
11ac 1efd 1eff :3 0
6e :2 0 ad :4 0
11af 1f01 1f03 :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 11b2 1f06
1f0a 11b6 1f05 1f0c
:3 0 11b9 1eee 1f0e
:2 0 1f10 11bc 1f11
1eeb 1f10 0 1f12
11be 0 1f13 11c0
1f16 :3 0 1f16 0
1f16 1f15 1f13 1f14
:6 0 1f18 47 :3 0
11c3 1f1a 11c5 1f19
1f18 :2 0 1f1b 11c7
:2 0 1f1d 0 1f1d
1f1c 1ed3 1f1b :6 0
1f1f 40 :3 0 11c9
1f20 1eb2 1f1f 0
1f22 1e0d 1e9c 0
1f22 11cb 0 1f23
11ce 1f93 130 :3 0
139 :3 0 132 :3 0
ae :3 0 1f :3 0
132 :3 0 ae :3 0
139 :3 0 132 :3 0
ae :3 0 22 :3 0
132 :3 0 ae :3 0
13a :3 0 13b :3 0
37 :3 0 19 :3 0
21 :3 0 44 :3 0
129 :3 0 c1 :3 0
17 :3 0 12a :3 0
17 :3 0 12b :3 0
1d :3 0 12c :3 0
135 :4 0 1c3 1
:8 0 1f46 15 :3 0
a6 :3 0 1f41 1f42
0 a7 :3 0 1f43
1f44 0 1f46 11d1
1f90 a8 :3 0 15
:3 0 a6 :3 0 1f49
1f4a 0 a7 :3 0
1f4b 1f4c 0 1f86
66 :3 0 67 :3 0
1f4e 1f4f 0 66
:3 0 77 :3 0 1f51
1f52 0 a9 :2 0
2 :4 0 1c4 :2 0
79 :2 0 27 :2 0
11d4 1f57 1f59 :3 0
11d7 1f53 1f5b 1f50
1f5d 1f5c :2 0 69
:3 0 7a :3 0 1f5f
1f60 0 6b :4 0
1c5 :4 0 6e :2 0
6f :3 0 11db 1f64
1f66 :3 0 6e :2 0
82 :4 0 11de 1f68
1f6a :3 0 6e :2 0
ac :4 0 11e1 1f6c
1f6e :3 0 6e :2 0
a7 :3 0 11e4 1f70
1f72 :3 0 6e :2 0
ad :4 0 11e7 1f74
1f76 :3 0 6e :2 0
ae :3 0 af :3 0
27 :2 0 b0 :2 0
11ea 1f79 1f7d 11ee
1f78 1f7f :3 0 11f1
1f61 1f81 :2 0 1f83
11f4 1f84 1f5e 1f83
0 1f85 11f6 0
1f86 11f8 1f89 :3 0
1f89 0 1f89 1f88
1f86 1f87 :6 0 1f8b
49 :3 0 11fb 1f8d
11fd 1f8c 1f8b :2 0
1f8e 11ff :2 0 1f90
0 1f90 1f8f 1f46
1f8e :6 0 1f92 40
:3 0 1201 1f94 1d95
1f23 0 1f95 0
1f92 0 1f95 1203
0 1f96 1206 218b
ae :3 0 26 :3 0
27 :2 0 27 :2 0
1208 1f97 1f9b 9c
:2 0 30 :4 0 120e
1f9d 1f9f :3 0 130
:3 0 131 :3 0 132
:3 0 ae :3 0 1f
:3 0 132 :3 0 ae
:3 0 131 :3 0 132
:3 0 ae :3 0 133
:3 0 37 :3 0 134
:3 0 134 :3 0 19
:3 0 21 :3 0 44
:3 0 47 :3 0 129
:3 0 c1 :3 0 17
:3 0 12a :3 0 17
:3 0 12b :3 0 1d
:3 0 12c :3 0 135
:4 0 1c6 1 :8 0
1fc2 15 :3 0 a6
:3 0 1fbd 1fbe 0
a7 :3 0 1fbf 1fc0
0 1fc2 1211 200c
a8 :3 0 15 :3 0
a6 :3 0 1fc5 1fc6
0 a7 :3 0 1fc7
1fc8 0 2002 66
:3 0 67 :3 0 1fca
1fcb 0 66 :3 0
77 :3 0 1fcd 1fce
0 a9 :2 0 2
:4 0 1c7 :2 0 79
:2 0 27 :2 0 1214
1fd3 1fd5 :3 0 1217
1fcf 1fd7 1fcc 1fd9
1fd8 :2 0 69 :3 0
7a :3 0 1fdb 1fdc
0 6b :4 0 1c8
:4 0 6e :2 0 6f
:3 0 121b 1fe0 1fe2
:3 0 6e :2 0 82
:4 0 121e 1fe4 1fe6
:3 0 6e :2 0 ac
:4 0 1221 1fe8 1fea
:3 0 6e :2 0 a7
:3 0 1224 1fec 1fee
:3 0 6e :2 0 ad
:4 0 1227 1ff0 1ff2
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 122a
1ff5 1ff9 122e 1ff4
1ffb :3 0 1231 1fdd
1ffd :2 0 1fff 1234
2000 1fda 1fff 0
2001 1236 0 2002
1238 2005 :3 0 2005
0 2005 2004 2002
2003 :6 0 2007 4b
:3 0 123b 2009 123d
2008 2007 :2 0 200a
123f :2 0 200c 0
200c 200b 1fc2 200a
:6 0 211a 40 :3 0
15 :3 0 a6 :3 0
200e 200f 0 15
:3 0 9c :2 0 b1
:3 0 2011 2013 0
1243 2012 2015 :3 0
2016 :2 0 73 :3 0
47 :3 0 30 :2 0
1246 2018 201b 9c
:2 0 30 :2 0 124b
201d 201f :3 0 2020
:2 0 73 :3 0 44
:3 0 30 :2 0 124e
2022 2025 9c :2 0
27 :2 0 1253 2027
2029 :3 0 202a :2 0
2021 202c 202b :2 0
130 :3 0 139 :3 0
132 :3 0 ae :3 0
1f :3 0 132 :3 0
ae :3 0 13a :3 0
37 :3 0 13b :3 0
19 :3 0 21 :3 0
44 :3 0 129 :3 0
c1 :3 0 17 :3 0
12a :3 0 17 :3 0
12b :3 0 1d :3 0
12c :3 0 135 :4 0
1c9 1 :8 0 204a
15 :3 0 a6 :3 0
2045 2046 0 a7
:3 0 2047 2048 0
204a 1256 2094 a8
:3 0 15 :3 0 a6
:3 0 204d 204e 0
a7 :3 0 204f 2050
0 208a 66 :3 0
67 :3 0 2052 2053
0 66 :3 0 77
:3 0 2055 2056 0
a9 :2 0 2 :4 0
1ca :2 0 79 :2 0
27 :2 0 1259 205b
205d :3 0 125c 2057
205f 2054 2061 2060
:2 0 69 :3 0 7a
:3 0 2063 2064 0
6b :4 0 1cb :4 0
6e :2 0 6f :3 0
1260 2068 206a :3 0
6e :2 0 82 :4 0
1263 206c 206e :3 0
6e :2 0 ac :4 0
1266 2070 2072 :3 0
6e :2 0 a7 :3 0
1269 2074 2076 :3 0
6e :2 0 ad :4 0
126c 2078 207a :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 126f 207d
2081 1273 207c 2083
:3 0 1276 2065 2085
:2 0 2087 1279 2088
2062 2087 0 2089
127b 0 208a 127d
208d :3 0 208d 0
208d 208c 208a 208b
:6 0 208f 4d :3 0
1280 2091 1282 2090
208f :2 0 2092 1284
:2 0 2094 0 2094
2093 204a 2092 :6 0
2096 40 :3 0 1286
209c 33 :3 0 117
:2 0 2097 2098 0
209b 0 209b 1288
209d 202d 2096 0
209e 0 209b 0
209e 128b 0 20a0
b7 :3 0 128e 2118
15 :3 0 a6 :3 0
20a1 20a2 0 15
:3 0 9c :2 0 e2
:3 0 20a4 20a6 0
1292 20a5 20a8 :3 0
20a9 :2 0 130 :3 0
139 :3 0 132 :3 0
ae :3 0 1f :3 0
132 :3 0 ae :3 0
139 :3 0 132 :3 0
ae :3 0 13a :3 0
37 :3 0 13b :3 0
19 :3 0 21 :3 0
44 :3 0 129 :3 0
c1 :3 0 17 :3 0
12a :3 0 17 :3 0
12b :3 0 1d :3 0
12c :3 0 135 :4 0
1cc 1 :8 0 20ca
15 :3 0 a6 :3 0
20c5 20c6 0 a7
:3 0 20c7 20c8 0
20ca 1295 2114 a8
:3 0 15 :3 0 a6
:3 0 20cd 20ce 0
a7 :3 0 20cf 20d0
0 210a 66 :3 0
67 :3 0 20d2 20d3
0 66 :3 0 77
:3 0 20d5 20d6 0
a9 :2 0 2 :4 0
1cd :2 0 79 :2 0
27 :2 0 1298 20db
20dd :3 0 129b 20d7
20df 20d4 20e1 20e0
:2 0 69 :3 0 7a
:3 0 20e3 20e4 0
6b :4 0 1ce :4 0
6e :2 0 6f :3 0
129f 20e8 20ea :3 0
6e :2 0 82 :4 0
12a2 20ec 20ee :3 0
6e :2 0 ac :4 0
12a5 20f0 20f2 :3 0
6e :2 0 a7 :3 0
12a8 20f4 20f6 :3 0
6e :2 0 ad :4 0
12ab 20f8 20fa :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 12ae 20fd
2101 12b2 20fc 2103
:3 0 12b5 20e5 2105
:2 0 2107 12b8 2108
20e2 2107 0 2109
12ba 0 210a 12bc
210d :3 0 210d 0
210d 210c 210a 210b
:6 0 210f 4f :3 0
12bf 2111 12c1 2110
210f :2 0 2112 12c3
:2 0 2114 0 2114
2113 20ca 2112 :6 0
2116 40 :3 0 12c5
2117 20aa 2116 0
2119 2017 20a0 0
2119 12c7 0 211a
12ca 2187 130 :3 0
139 :3 0 132 :3 0
ae :3 0 1f :3 0
132 :3 0 ae :3 0
139 :3 0 132 :3 0
ae :3 0 13a :3 0
37 :3 0 13b :3 0
19 :3 0 21 :3 0
44 :3 0 129 :3 0
c1 :3 0 17 :3 0
12a :3 0 17 :3 0
12b :3 0 1d :3 0
12c :3 0 135 :4 0
1cf 1 :8 0 213a
15 :3 0 a6 :3 0
2135 2136 0 a7
:3 0 2137 2138 0
213a 12cd 2184 a8
:3 0 15 :3 0 a6
:3 0 213d 213e 0
a7 :3 0 213f 2140
0 217a 66 :3 0
67 :3 0 2142 2143
0 66 :3 0 77
:3 0 2145 2146 0
a9 :2 0 2 :4 0
1d0 :2 0 79 :2 0
27 :2 0 12d0 214b
214d :3 0 12d3 2147
214f 2144 2151 2150
:2 0 69 :3 0 7a
:3 0 2153 2154 0
6b :4 0 1d1 :4 0
6e :2 0 6f :3 0
12d7 2158 215a :3 0
6e :2 0 82 :4 0
12da 215c 215e :3 0
6e :2 0 ac :4 0
12dd 2160 2162 :3 0
6e :2 0 a7 :3 0
12e0 2164 2166 :3 0
6e :2 0 ad :4 0
12e3 2168 216a :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 12e6 216d
2171 12ea 216c 2173
:3 0 12ed 2155 2175
:2 0 2177 12f0 2178
2152 2177 0 2179
12f2 0 217a 12f4
217d :3 0 217d 0
217d 217c 217a 217b
:6 0 217f 51 :3 0
12f7 2181 12f9 2180
217f :2 0 2182 12fb
:2 0 2184 0 2184
2183 213a 2182 :6 0
2186 40 :3 0 12fd
2188 1fa0 211a 0
2189 0 2186 0
2189 12ff 0 218a
1302 218c 1d8b 1f96
0 218d 0 218a
0 218d 1304 0
248d 15 :3 0 a6
:3 0 218e 218f 0
15 :3 0 9c :2 0
b1 :3 0 2191 2193
0 1309 2192 2195
:3 0 2196 :2 0 73
:3 0 44 :3 0 30
:2 0 130c 2198 219b
9c :2 0 27 :2 0
1311 219d 219f :3 0
46 :3 0 117 :2 0
21a1 21a2 0 21a4
1314 229d 19 :3 0
8f :2 0 1316 21a6
21a7 :3 0 21a8 :2 0
63 :3 0 9c :2 0
27 :2 0 131a 21ab
21ad :3 0 47 :3 0
30 :2 0 21af 21b0
0 2213 156 :3 0
157 :3 0 47 :3 0
158 :3 0 c1 :3 0
17 :3 0 159 :3 0
19 :3 0 15a :3 0
132 :3 0 ae :3 0
1f :3 0 132 :3 0
ae :3 0 22 :4 0
1d2 1 :8 0 21c7
15 :3 0 a6 :3 0
21c2 21c3 0 a7
:3 0 21c4 21c5 0
21c7 131d 2211 a8
:3 0 15 :3 0 a6
:3 0 21ca 21cb 0
a7 :3 0 21cc 21cd
0 2207 66 :3 0
67 :3 0 21cf 21d0
0 66 :3 0 77
:3 0 21d2 21d3 0
a9 :2 0 2 :4 0
1d3 :2 0 79 :2 0
27 :2 0 1320 21d8
21da :3 0 1323 21d4
21dc 21d1 21de 21dd
:2 0 69 :3 0 7a
:3 0 21e0 21e1 0
6b :4 0 1d4 :4 0
6e :2 0 6f :3 0
1327 21e5 21e7 :3 0
6e :2 0 82 :4 0
132a 21e9 21eb :3 0
6e :2 0 ac :4 0
132d 21ed 21ef :3 0
6e :2 0 a7 :3 0
1330 21f1 21f3 :3 0
6e :2 0 ad :4 0
1333 21f5 21f7 :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 1336 21fa
21fe 133a 21f9 2200
:3 0 133d 21e2 2202
:2 0 2204 1340 2205
21df 2204 0 2206
1342 0 2207 1344
220a :3 0 220a 0
220a 2209 2207 2208
:6 0 220c 53 :3 0
1347 220e 1349 220d
220c :2 0 220f 134b
:2 0 2211 0 2211
2210 21c7 220f :6 0
2213 40 :3 0 134d
2276 47 :3 0 30
:2 0 2214 2215 0
2275 156 :3 0 157
:3 0 47 :3 0 158
:3 0 c1 :3 0 17
:3 0 159 :3 0 19
:3 0 15a :3 0 132
:3 0 ae :3 0 1f
:4 0 1d5 1 :8 0
2229 15 :3 0 a6
:3 0 2224 2225 0
a7 :3 0 2226 2227
0 2229 1350 2273
a8 :3 0 15 :3 0
a6 :3 0 222c 222d
0 a7 :3 0 222e
222f 0 2269 66
:3 0 67 :3 0 2231
2232 0 66 :3 0
77 :3 0 2234 2235
0 a9 :2 0 2
:4 0 1d6 :2 0 79
:2 0 27 :2 0 1353
223a 223c :3 0 1356
2236 223e 2233 2240
223f :2 0 69 :3 0
7a :3 0 2242 2243
0 6b :4 0 1d7
:4 0 6e :2 0 6f
:3 0 135a 2247 2249
:3 0 6e :2 0 82
:4 0 135d 224b 224d
:3 0 6e :2 0 ac
:4 0 1360 224f 2251
:3 0 6e :2 0 a7
:3 0 1363 2253 2255
:3 0 6e :2 0 ad
:4 0 1366 2257 2259
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 1369
225c 2260 136d 225b
2262 :3 0 1370 2244
2264 :2 0 2266 1373
2267 2241 2266 0
2268 1375 0 2269
1377 226c :3 0 226c
0 226c 226b 2269
226a :6 0 226e 55
:3 0 137a 2270 137c
226f 226e :2 0 2271
137e :2 0 2273 0
2273 2272 2229 2271
:6 0 2275 40 :3 0
1380 2277 21ae 2213
0 2278 0 2275
0 2278 1383 0
2296 73 :3 0 47
:3 0 30 :2 0 1386
2279 227c 73 :3 0
91 :2 0 37 :3 0
30 :2 0 1389 227e
2282 138e 227f 2284
:3 0 2f :3 0 73
:3 0 2f :3 0 30
:2 0 1391 2287 228a
79 :2 0 27 :2 0
1394 228c 228e :3 0
2286 228f 0 2293
1d8 :3 0 2291 :4 0
2293 1397 2294 2285
2293 0 2295 139a
0 2296 139c 2297
21a9 2296 0 2298
139f 0 229c 46
:3 0 27 :2 0 2299
229a 0 229c 13a1
229e 21a0 21a4 0
229f 0 229c 0
229f 13a4 0 22a0
13a7 22af 2f :3 0
73 :3 0 2f :3 0
30 :2 0 13a9 22a2
22a5 79 :2 0 27
:2 0 13ac 22a7 22a9
:3 0 22a1 22aa 0
22ae 1d8 :3 0 22ac
:4 0 22ae 13af 22b0
2197 22a0 0 22b1
0 22ae 0 22b1
13b2 0 248d 21
:3 0 21 :3 0 22b2
22b3 0 248d 3f
:3 0 30 :2 0 22b5
22b6 0 248d a2
:3 0 199 :3 0 132
:3 0 ae :3 0 21
:3 0 a2 :3 0 19a
:3 0 1f :3 0 21
:3 0 a4 :4 0 1d9
1 :8 0 22c8 15
:3 0 a6 :3 0 22c3
22c4 0 a7 :3 0
22c5 22c6 0 22c8
13b5 2312 a8 :3 0
15 :3 0 a6 :3 0
22cb 22cc 0 a7
:3 0 22cd 22ce 0
2308 66 :3 0 67
:3 0 22d0 22d1 0
66 :3 0 77 :3 0
22d3 22d4 0 a9
:2 0 2 :4 0 1da
:2 0 79 :2 0 27
:2 0 13b8 22d9 22db
:3 0 13bb 22d5 22dd
22d2 22df 22de :2 0
69 :3 0 7a :3 0
22e1 22e2 0 6b
:4 0 1db :4 0 6e
:2 0 6f :3 0 13bf
22e6 22e8 :3 0 6e
:2 0 82 :4 0 13c2
22ea 22ec :3 0 6e
:2 0 ac :4 0 13c5
22ee 22f0 :3 0 6e
:2 0 a7 :3 0 13c8
22f2 22f4 :3 0 6e
:2 0 ad :4 0 13cb
22f6 22f8 :3 0 6e
:2 0 ae :3 0 af
:3 0 27 :2 0 b0
:2 0 13ce 22fb 22ff
13d2 22fa 2301 :3 0
13d5 22e3 2303 :2 0
2305 13d8 2306 22e0
2305 0 2307 13da
0 2308 13dc 230b
:3 0 230b 0 230b
230a 2308 2309 :6 0
230d 57 :3 0 13df
230f 13e1 230e 230d
:2 0 2310 13e3 :2 0
2312 0 2312 2311
22c8 2310 :6 0 248d
40 :3 0 132 :3 0
ae :3 0 1f :3 0
132 :3 0 ae :3 0
21 :3 0 1f :3 0
21 :3 0 21 :3 0
a4 :4 0 1dc 1
:8 0 2324 15 :3 0
a6 :3 0 231f 2320
0 a7 :3 0 2321
2322 0 2324 13e5
236e a8 :3 0 15
:3 0 a6 :3 0 2327
2328 0 a7 :3 0
2329 232a 0 2364
66 :3 0 67 :3 0
232c 232d 0 66
:3 0 77 :3 0 232f
2330 0 a9 :2 0
2 :4 0 1dd :2 0
79 :2 0 27 :2 0
13e8 2335 2337 :3 0
13eb 2331 2339 232e
233b 233a :2 0 69
:3 0 7a :3 0 233d
233e 0 6b :4 0
1de :4 0 6e :2 0
6f :3 0 13ef 2342
2344 :3 0 6e :2 0
82 :4 0 13f2 2346
2348 :3 0 6e :2 0
ac :4 0 13f5 234a
234c :3 0 6e :2 0
a7 :3 0 13f8 234e
2350 :3 0 6e :2 0
ad :4 0 13fb 2352
2354 :3 0 6e :2 0
ae :3 0 af :3 0
27 :2 0 b0 :2 0
13fe 2357 235b 1402
2356 235d :3 0 1405
233f 235f :2 0 2361
1408 2362 233c 2361
0 2363 140a 0
2364 140c 2367 :3 0
2367 0 2367 2366
2364 2365 :6 0 2369
59 :3 0 140f 236b
1411 236a 2369 :2 0
236c 1413 :2 0 236e
0 236e 236d 2324
236c :6 0 248d 40
:3 0 45 :3 0 1a1
:2 0 2370 2371 0
248d 22 :3 0 6
:3 0 2373 2374 0
248d 73 :3 0 33
:3 0 30 :2 0 1415
2376 2379 9c :2 0
30 :2 0 141a 237b
237d :3 0 3f :3 0
118 :2 0 237f 2380
0 2382 141d 2383
237e 2382 0 2384
141f 0 248d 62
:3 0 1a2 :3 0 28
:3 0 17 :3 0 1a
:3 0 1d :3 0 4e
:3 0 32 :3 0 23
:3 0 23 :3 0 23
:3 0 23 :3 0 21
:3 0 22 :3 0 41
:3 0 37 :3 0 35
:3 0 38 :3 0 39
:3 0 34 :3 0 45
:3 0 26 :3 0 33
:3 0 31 :3 0 3b
:3 0 36 :3 0 3f
:3 0 3d :3 0 43
:3 0 1c :3 0 30
:2 0 30 :2 0 50
:2 0 50 :2 0 1421
2386 23a7 2385 23a8
0 248d 62 :3 0
9c :2 0 30 :2 0
1444 23ab 23ad :3 0
73 :3 0 33 :3 0
30 :2 0 1447 23af
23b2 9c :2 0 30
:2 0 144c 23b4 23b6
:3 0 1a3 :3 0 1a4
:3 0 1a5 :3 0 1d
:4 0 1a6 1 :8 0
23d2 1a7 :4 0 23bd
:3 0 8a :3 0 9c
:2 0 1451 23c0 23c1
:3 0 15 :3 0 a6
:3 0 23c3 23c4 0
30 :2 0 23c5 23c6
0 23c8 1454 23cf
15 :3 0 a6 :3 0
23c9 23ca 0 116
:2 0 23cb 23cc 0
23ce 1456 23d0 23c2
23c8 0 23d1 0
23ce 0 23d1 1458
0 23d2 145b 241c
a8 :3 0 15 :3 0
a6 :3 0 23d5 23d6
0 a7 :3 0 23d7
23d8 0 2412 66
:3 0 67 :3 0 23da
23db 0 66 :3 0
77 :3 0 23dd 23de
0 a9 :2 0 2
:4 0 1df :2 0 79
:2 0 27 :2 0 145e
23e3 23e5 :3 0 1461
23df 23e7 23dc 23e9
23e8 :2 0 69 :3 0
7a :3 0 23eb 23ec
0 6b :4 0 1e0
:4 0 6e :2 0 6f
:3 0 1465 23f0 23f2
:3 0 6e :2 0 82
:4 0 1468 23f4 23f6
:3 0 6e :2 0 ac
:4 0 146b 23f8 23fa
:3 0 6e :2 0 a7
:3 0 146e 23fc 23fe
:3 0 6e :2 0 ad
:4 0 1471 2400 2402
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 1474
2405 2409 1478 2404
240b :3 0 147b 23ed
240d :2 0 240f 147e
2410 23ea 240f 0
2411 1480 0 2412
1482 2415 :3 0 2415
0 2415 2414 2412
2413 :6 0 2417 5b
:3 0 1485 2419 1487
2418 2417 :2 0 241a
1489 :2 0 241c 0
241c 241b 23d2 241a
:6 0 241e 40 :3 0
148b 2486 1a3 :3 0
1a4 :3 0 1a5 :3 0
1d :4 0 1aa 1
:8 0 2439 1a7 :4 0
2424 :3 0 8a :3 0
9c :2 0 148f 2427
2428 :3 0 15 :3 0
a6 :3 0 242a 242b
0 30 :2 0 242c
242d 0 242f 1492
2436 15 :3 0 a6
:3 0 2430 2431 0
116 :2 0 2432 2433
0 2435 1494 2437
2429 242f 0 2438
0 2435 0 2438
1496 0 2439 1499
2483 a8 :3 0 15
:3 0 a6 :3 0 243c
243d 0 a7 :3 0
243e 243f 0 2479
66 :3 0 67 :3 0
2441 2442 0 66
:3 0 77 :3 0 2444
2445 0 a9 :2 0
2 :4 0 1e1 :2 0
79 :2 0 27 :2 0
149c 244a 244c :3 0
149f 2446 244e 2443
2450 244f :2 0 69
:3 0 7a :3 0 2452
2453 0 6b :4 0
1e2 :4 0 6e :2 0
6f :3 0 14a3 2457
2459 :3 0 6e :2 0
82 :4 0 14a6 245b
245d :3 0 6e :2 0
ac :4 0 14a9 245f
2461 :3 0 6e :2 0
a7 :3 0 14ac 2463
2465 :3 0 6e :2 0
ad :4 0 14af 2467
2469 :3 0 6e :2 0
ae :3 0 af :3 0
27 :2 0 b0 :2 0
14b2 246c 2470 14b6
246b 2472 :3 0 14b9
2454 2474 :2 0 2476
14bc 2477 2451 2476
0 2478 14be 0
2479 14c0 247c :3 0
247c 0 247c 247b
2479 247a :6 0 247e
5d :3 0 14c3 2480
14c5 247f 247e :2 0
2481 14c7 :2 0 2483
0 2483 2482 2439
2481 :6 0 2485 40
:3 0 14c9 2487 23b7
241e 0 2488 0
2485 0 2488 14cb
0 2489 14ce 248a
23ae 2489 0 248b
14d0 0 248d b7
:3 0 14d2 254d 73
:3 0 46 :3 0 30
:2 0 14de 248e 2491
9c :2 0 30 :2 0
14e3 2493 2495 :3 0
21 :3 0 1f :3 0
2497 2498 0 254b
22 :3 0 6 :3 0
249a 249b 0 254b
ae :3 0 26 :3 0
27 :2 0 27 :2 0
14e6 249d 24a1 9c
:2 0 27 :4 0 14ec
24a3 24a5 :3 0 45
:3 0 84 :3 0 1ad
:3 0 24a8 24a9 0
24a7 24aa 0 24ac
14ef 24b5 45 :3 0
73 :3 0 3a :3 0
30 :2 0 14f1 24ae
24b1 24ad 24b2 0
24b4 14f4 24b6 24a6
24ac 0 24b7 0
24b4 0 24b7 14f6
0 254b 62 :3 0
1a2 :3 0 28 :3 0
17 :3 0 1a :3 0
1d :3 0 4e :3 0
32 :3 0 23 :3 0
23 :3 0 23 :3 0
23 :3 0 21 :3 0
22 :3 0 41 :3 0
37 :3 0 35 :3 0
38 :3 0 39 :3 0
34 :3 0 45 :3 0
26 :3 0 33 :3 0
31 :3 0 3b :3 0
36 :3 0 3f :3 0
3d :3 0 43 :3 0
1c :3 0 30 :2 0
30 :2 0 50 :2 0
50 :2 0 14f9 24b9
24da 24b8 24db 0
254b 62 :3 0 9c
:2 0 30 :2 0 151c
24de 24e0 :3 0 1a3
:3 0 1a4 :3 0 1a5
:3 0 1d :4 0 1a6
1 :8 0 24fc 1a7
:4 0 24e7 :3 0 8a
:3 0 9c :2 0 1521
24ea 24eb :3 0 15
:3 0 a6 :3 0 24ed
24ee 0 30 :2 0
24ef 24f0 0 24f2
1524 24f9 15 :3 0
a6 :3 0 24f3 24f4
0 116 :2 0 24f5
24f6 0 24f8 1526
24fa 24ec 24f2 0
24fb 0 24f8 0
24fb 1528 0 24fc
152b 2546 a8 :3 0
15 :3 0 a6 :3 0
24ff 2500 0 a7
:3 0 2501 2502 0
253c 66 :3 0 67
:3 0 2504 2505 0
66 :3 0 77 :3 0
2507 2508 0 a9
:2 0 2 :4 0 1e3
:2 0 79 :2 0 27
:2 0 152e 250d 250f
:3 0 1531 2509 2511
2506 2513 2512 :2 0
69 :3 0 7a :3 0
2515 2516 0 6b
:4 0 1e4 :4 0 6e
:2 0 6f :3 0 1535
251a 251c :3 0 6e
:2 0 82 :4 0 1538
251e 2520 :3 0 6e
:2 0 ac :4 0 153b
2522 2524 :3 0 6e
:2 0 a7 :3 0 153e
2526 2528 :3 0 6e
:2 0 ad :4 0 1541
252a 252c :3 0 6e
:2 0 ae :3 0 af
:3 0 27 :2 0 b0
:2 0 1544 252f 2533
1548 252e 2535 :3 0
154b 2517 2537 :2 0
2539 154e 253a 2514
2539 0 253b 1550
0 253c 1552 253f
:3 0 253f 0 253f
253e 253c 253d :6 0
2541 5f :3 0 1555
2543 1557 2542 2541
:2 0 2544 1559 :2 0
2546 0 2546 2545
24fc 2544 :6 0 2548
40 :3 0 155b 2549
24e1 2548 0 254a
155d 0 254b 155f
254c 2496 254b 0
254e 1d86 248d 0
254e 1565 0 255e
2f :3 0 73 :3 0
2f :3 0 30 :2 0
1568 2550 2553 79
:2 0 27 :2 0 156b
2555 2557 :3 0 254f
2558 0 255e 1d8
:5 0 255c 61 0
255d 156e 255c 255b
255e 1570 2560 1b3
:3 0 1c41 255e :4 0
2561 1580 2562 1c32
2561 0 2563 1583
0 2564 1585 2566
dca 1c03 0 2567
0 2564 0 2567
1588 0 3027 62
:3 0 c0 :2 0 30
:2 0 158d 2569 256b
:3 0 256c :2 0 73
:3 0 32 :3 0 30
:2 0 1590 256e 2571
bb :2 0 30 :2 0
1595 2573 2575 :3 0
2576 :2 0 256d 2578
2577 :2 0 73 :3 0
42 :3 0 30 :2 0
1598 257a 257d 9c
:2 0 30 :2 0 159d
257f 2581 :3 0 17f
:3 0 17c :3 0 28
:4 0 1e5 1 :8 0
259c 1a7 :4 0 2587
:3 0 8a :3 0 9c
:2 0 15a2 258a 258b
:3 0 15 :3 0 a6
:3 0 258d 258e 0
30 :2 0 258f 2590
0 2592 15a5 2599
15 :3 0 a6 :3 0
2593 2594 0 116
:2 0 2595 2596 0
2598 15a7 259a 258c
2592 0 259b 0
2598 0 259b 15a9
0 259c 15ac 25e6
a8 :3 0 15 :3 0
a6 :3 0 259f 25a0
0 a7 :3 0 25a1
25a2 0 25dc 66
:3 0 67 :3 0 25a4
25a5 0 66 :3 0
77 :3 0 25a7 25a8
0 a9 :2 0 2
:4 0 1e6 :2 0 79
:2 0 27 :2 0 15af
25ad 25af :3 0 15b2
25a9 25b1 25a6 25b3
25b2 :2 0 69 :3 0
7a :3 0 25b5 25b6
0 6b :4 0 1e7
:4 0 6e :2 0 6f
:3 0 15b6 25ba 25bc
:3 0 6e :2 0 82
:4 0 15b9 25be 25c0
:3 0 6e :2 0 ac
:4 0 15bc 25c2 25c4
:3 0 6e :2 0 a7
:3 0 15bf 25c6 25c8
:3 0 6e :2 0 ad
:4 0 15c2 25ca 25cc
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 15c5
25cf 25d3 15c9 25ce
25d5 :3 0 15cc 25b7
25d7 :2 0 25d9 15cf
25da 25b4 25d9 0
25db 15d1 0 25dc
15d3 25df :3 0 25df
0 25df 25de 25dc
25dd :6 0 25e1 61
:3 0 15d6 25e3 15d8
25e2 25e1 :2 0 25e4
15da :2 0 25e6 0
25e6 25e5 259c 25e4
:6 0 25e8 1 :3 0
15dc 2653 17f :3 0
17e :3 0 1e :3 0
17d :3 0 42 :3 0
17c :3 0 28 :4 0
1e8 1 :8 0 2606
1a7 :4 0 25f1 :3 0
8a :3 0 9c :2 0
15e0 25f4 25f5 :3 0
15 :3 0 a6 :3 0
25f7 25f8 0 30
:2 0 25f9 25fa 0
25fc 15e3 2603 15
:3 0 a6 :3 0 25fd
25fe 0 116 :2 0
25ff 2600 0 2602
15e5 2604 25f6 25fc
0 2605 0 2602
0 2605 15e7 0
2606 15ea 2650 a8
:3 0 15 :3 0 a6
:3 0 2609 260a 0
a7 :3 0 260b 260c
0 2646 66 :3 0
67 :3 0 260e 260f
0 66 :3 0 77
:3 0 2611 2612 0
a9 :2 0 2 :4 0
1e9 :2 0 79 :2 0
27 :2 0 15ed 2617
2619 :3 0 15f0 2613
261b 2610 261d 261c
:2 0 69 :3 0 7a
:3 0 261f 2620 0
6b :4 0 1ea :4 0
6e :2 0 6f :3 0
15f4 2624 2626 :3 0
6e :2 0 82 :4 0
15f7 2628 262a :3 0
6e :2 0 ac :4 0
15fa 262c 262e :3 0
6e :2 0 a7 :3 0
15fd 2630 2632 :3 0
6e :2 0 ad :4 0
1600 2634 2636 :3 0
6e :2 0 ae :3 0
af :3 0 27 :2 0
b0 :2 0 1603 2639
263d 1607 2638 263f
:3 0 160a 2621 2641
:2 0 2643 160d 2644
261e 2643 0 2645
160f 0 2646 1611
2649 :3 0 2649 0
2649 2648 2646 2647
:6 0 264b 63 :3 0
1614 264d 1616 264c
264b :2 0 264e 1618
:2 0 2650 0 2650
264f 2606 264e :6 0
2652 1 :3 0 161a
2654 2582 25e8 0
2655 0 2652 0
2655 161c 0 2828
62 :3 0 9c :2 0
116 :2 0 1621 2657
2659 :3 0 66 :3 0
67 :3 0 265b 265c
0 66 :3 0 77
:3 0 265e 265f 0
18 :2 0 2 :4 0
1eb :2 0 79 :2 0
27 :2 0 1624 2664
2666 :3 0 1627 2660
2668 265d 266a 2669
:2 0 69 :3 0 7a
:3 0 266c 266d 0
6b :4 0 1ec :4 0
6e :2 0 6f :3 0
162b 2671 2673 :3 0
6e :2 0 82 :4 0
162e 2675 2677 :3 0
6e :2 0 83 :4 0
1631 2679 267b :3 0
6e :2 0 73 :3 0
74 :3 0 84 :3 0
179 :3 0 2680 2681
0 1634 267f 2683
75 :4 0 1636 267e
2686 1639 267d 2688
:3 0 6e :2 0 ee
:4 0 163c 268a 268c
:3 0 6e :2 0 71
:4 0 163f 268e 2690
:3 0 6e :2 0 1d
:3 0 1642 2692 2694
:3 0 6e :2 0 71
:4 0 1645 2696 2698
:3 0 1648 266e 269a
:2 0 269c 164b 269d
266b 269c 0 269e
164d 0 26c9 66
:3 0 67 :3 0 269f
26a0 0 66 :3 0
77 :3 0 26a2 26a3
0 27 :2 0 2
:4 0 1ed :2 0 79
:2 0 27 :2 0 164f
26a8 26aa :3 0 1652
26a4 26ac 26a1 26ae
26ad :2 0 69 :3 0
7a :3 0 26b0 26b1
0 6b :4 0 1ee
:4 0 6e :2 0 6f
:3 0 1656 26b5 26b7
:3 0 1659 26b2 26b9
:2 0 26bb 165c 26bc
26af 26bb 0 26bd
165e 0 26c9 88
:3 0 f1 :3 0 26be
26bf 0 84 :3 0
179 :3 0 26c1 26c2
0 1d :3 0 8a
:3 0 1660 26c0 26c6
:2 0 26c9 b7 :3 0
1664 2825 62 :3 0
84 :3 0 9c :2 0
1ef :3 0 26cb 26cd
0 166a 26cc 26cf
:3 0 66 :3 0 67
:3 0 26d1 26d2 0
66 :3 0 77 :3 0
26d4 26d5 0 18
:2 0 2 :4 0 1f0
:2 0 79 :2 0 27
:2 0 166d 26da 26dc
:3 0 1670 26d6 26de
26d3 26e0 26df :2 0
69 :3 0 7a :3 0
26e2 26e3 0 6b
:4 0 1f1 :4 0 6e
:2 0 6f :3 0 1674
26e7 26e9 :3 0 6e
:2 0 82 :4 0 1677
26eb 26ed :3 0 6e
:2 0 83 :4 0 167a
26ef 26f1 :3 0 6e
:2 0 73 :3 0 74
:3 0 84 :3 0 1ef
:3 0 26f6 26f7 0
167d 26f5 26f9 75
:4 0 167f 26f4 26fc
1682 26f3 26fe :3 0
6e :2 0 ee :4 0
1685 2700 2702 :3 0
6e :2 0 71 :4 0
1688 2704 2706 :3 0
6e :2 0 1d :3 0
168b 2708 270a :3 0
6e :2 0 71 :4 0
168e 270c 270e :3 0
1691 26e4 2710 :2 0
2712 1694 2713 26e1
2712 0 2714 1696
0 273f 66 :3 0
67 :3 0 2715 2716
0 66 :3 0 77
:3 0 2718 2719 0
27 :2 0 2 :4 0
1f2 :2 0 79 :2 0
27 :2 0 1698 271e
2720 :3 0 169b 271a
2722 2717 2724 2723
:2 0 69 :3 0 7a
:3 0 2726 2727 0
6b :4 0 1f3 :4 0
6e :2 0 6f :3 0
169f 272b 272d :3 0
16a2 2728 272f :2 0
2731 16a5 2732 2725
2731 0 2733 16a7
0 273f 88 :3 0
f1 :3 0 2734 2735
0 84 :3 0 1ef
:3 0 2737 2738 0
1d :3 0 8a :3 0
16a9 2736 273c :2 0
273f b7 :3 0 16ad
2740 26d0 273f 0
2827 62 :3 0 84
:3 0 9c :2 0 1f4
:3 0 2742 2744 0
16b3 2743 2746 :3 0
66 :3 0 67 :3 0
2748 2749 0 66
:3 0 77 :3 0 274b
274c 0 18 :2 0
2 :4 0 1f5 :2 0
79 :2 0 27 :2 0
16b6 2751 2753 :3 0
16b9 274d 2755 274a
2757 2756 :2 0 69
:3 0 7a :3 0 2759
275a 0 6b :4 0
1f6 :4 0 6e :2 0
6f :3 0 16bd 275e
2760 :3 0 6e :2 0
82 :4 0 16c0 2762
2764 :3 0 6e :2 0
83 :4 0 16c3 2766
2768 :3 0 6e :2 0
73 :3 0 74 :3 0
84 :3 0 1f4 :3 0
276d 276e 0 16c6
276c 2770 75 :4 0
16c8 276b 2773 16cb
276a 2775 :3 0 6e
:2 0 ee :4 0 16ce
2777 2779 :3 0 6e
:2 0 71 :4 0 16d1
277b 277d :3 0 6e
:2 0 1d :3 0 16d4
277f 2781 :3 0 6e
:2 0 71 :4 0 16d7
2783 2785 :3 0 16da
275b 2787 :2 0 2789
16dd 278a 2758 2789
0 278b 16df 0
27b5 66 :3 0 67
:3 0 278c 278d 0
66 :3 0 77 :3 0
278f 2790 0 27
:2 0 2 :4 0 1f7
:2 0 79 :2 0 27
:2 0 16e1 2795 2797
:3 0 16e4 2791 2799
278e 279b 279a :2 0
69 :3 0 7a :3 0
279d 279e 0 6b
:4 0 1f8 :4 0 6e
:2 0 6f :3 0 16e8
27a2 27a4 :3 0 16eb
279f 27a6 :2 0 27a8
16ee 27a9 279c 27a8
0 27aa 16f0 0
27b5 88 :3 0 f1
:3 0 27ab 27ac 0
84 :3 0 1f4 :3 0
27ae 27af 0 1d
:3 0 8a :3 0 16f2
27ad 27b3 :2 0 27b5
16f6 27b6 2747 27b5
0 2827 66 :3 0
67 :3 0 27b7 27b8
0 66 :3 0 77
:3 0 27ba 27bb 0
18 :2 0 2 :4 0
1f9 :2 0 79 :2 0
27 :2 0 16fa 27c0
27c2 :3 0 16fd 27bc
27c4 27b9 27c6 27c5
:2 0 69 :3 0 7a
:3 0 27c8 27c9 0
6b :4 0 1fa :4 0
6e :2 0 6f :3 0
1701 27cd 27cf :3 0
6e :2 0 82 :4 0
1704 27d1 27d3 :3 0
6e :2 0 83 :4 0
1707 27d5 27d7 :3 0
6e :2 0 73 :3 0
74 :3 0 84 :3 0
153 :3 0 27dc 27dd
0 170a 27db 27df
75 :4 0 170c 27da
27e2 170f 27d9 27e4
:3 0 6e :2 0 ee
:4 0 1712 27e6 27e8
:3 0 6e :2 0 71
:4 0 1715 27ea 27ec
:3 0 6e :2 0 28
:3 0 1718 27ee 27f0
:3 0 6e :2 0 71
:4 0 171b 27f2 27f4
:3 0 171e 27ca 27f6
:2 0 27f8 1721 27f9
27c7 27f8 0 27fa
1723 0 2824 66
:3 0 67 :3 0 27fb
27fc 0 66 :3 0
77 :3 0 27fe 27ff
0 27 :2 0 2
:4 0 1fb :2 0 79
:2 0 27 :2 0 1725
2804 2806 :3 0 1728
2800 2808 27fd 280a
2809 :2 0 69 :3 0
7a :3 0 280c 280d
0 6b :4 0 1fc
:4 0 6e :2 0 6f
:3 0 172c 2811 2813
:3 0 172f 280e 2815
:2 0 2817 1732 2818
280b 2817 0 2819
1734 0 2824 88
:3 0 f1 :3 0 281a
281b 0 84 :3 0
153 :3 0 281d 281e
0 28 :3 0 8a
:3 0 1736 281c 2822
:2 0 2824 173a 2826
265a 26c9 0 2827
0 2824 0 2827
173e 0 2828 1743
2829 2579 2828 0
282a 1746 0 3027
73 :3 0 90 :3 0
2b :3 0 1748 282c
282e 30 :2 0 174a
282b 2831 bb :2 0
30 :2 0 174f 2833
2835 :3 0 2836 :2 0
73 :3 0 90 :3 0
2c :3 0 1752 2839
283b 30 :2 0 1754
2838 283e bb :2 0
30 :2 0 1759 2840
2842 :3 0 2843 :2 0
2837 2845 2844 :2 0
1fd :3 0 1fe :3 0
1ff :4 0 2849 :4 0
284a :2 0 2b3a 15
:3 0 a6 :3 0 284c
284d 0 30 :2 0
284e 284f 0 2b3a
51 :3 0 200 :4 0
6e :2 0 201 :4 0
175c 2853 2855 :3 0
6e :2 0 202 :4 0
175f 2857 2859 :3 0
6e :2 0 203 :4 0
1762 285b 285d :3 0
6e :2 0 204 :4 0
1765 285f 2861 :3 0
6e :2 0 205 :4 0
1768 2863 2865 :3 0
6e :2 0 17 :3 0
176b 2867 2869 :3 0
6e :2 0 206 :4 0
176e 286b 286d :3 0
6e :2 0 207 :4 0
1771 286f 2871 :3 0
6e :2 0 2b :3 0
1774 2873 2875 :3 0
6e :2 0 208 :4 0
1777 2877 2879 :3 0
6e :2 0 2c :3 0
177a 287b 287d :3 0
6e :2 0 209 :4 0
177d 287f 2881 :3 0
2851 2882 0 2b3a
1fd :3 0 1fe :3 0
51 :3 0 2886 :4 0
2887 :2 0 289e 1a7
:4 0 2889 :3 0 8a
:3 0 9c :2 0 1782
288c 288d :3 0 15
:3 0 a6 :3 0 288f
2890 0 30 :2 0
2891 2892 0 2894
1785 289b 15 :3 0
a6 :3 0 2895 2896
0 116 :2 0 2897
2898 0 289a 1787
289c 288e 2894 0
289d 0 289a 0
289d 1789 0 289e
178c 28f3 a8 :3 0
15 :3 0 a6 :3 0
28a1 28a2 0 a7
:3 0 28a3 28a4 0
28e9 66 :3 0 67
:3 0 28a6 28a7 0
66 :3 0 77 :3 0
28a9 28aa 0 a9
:2 0 2 :4 0 20a
:2 0 79 :2 0 27
:2 0 178f 28af 28b1
:3 0 1792 28ab 28b3
28a8 28b5 28b4 :2 0
69 :3 0 7a :3 0
28b7 28b8 0 6b
:4 0 20b :4 0 6e
:2 0 6f :3 0 1796
28bc 28be :3 0 6e
:2 0 82 :4 0 1799
28c0 28c2 :3 0 6e
:2 0 ac :4 0 179c
28c4 28c6 :3 0 6e
:2 0 a7 :3 0 179f
28c8 28ca :3 0 6e
:2 0 ad :4 0 17a2
28cc 28ce :3 0 6e
:2 0 ae :3 0 af
:3 0 27 :2 0 b0
:2 0 17a5 28d1 28d5
17a9 28d0 28d7 :3 0
17ac 28b9 28d9 :2 0
28e6 69 :3 0 7a
:3 0 28db 28dc 0
6b :4 0 20c :4 0
6e :2 0 51 :3 0
17af 28e0 28e2 :3 0
17b2 28dd 28e4 :2 0
28e6 17b5 28e7 28b6
28e6 0 28e8 17b8
0 28e9 17ba 28ec
:3 0 28ec 0 28ec
28eb 28e9 28ea :6 0
28ee 65 :3 0 17bd
28f0 17bf 28ef 28ee
:2 0 28f1 17c1 :2 0
28f3 0 28f3 28f2
289e 28f1 :6 0 2b3a
1 :3 0 1fd :3 0
1fe :3 0 20d :4 0
28f7 :4 0 28f8 :2 0
2b3a 15 :3 0 a6
:3 0 28fa 28fb 0
30 :2 0 28fc 28fd
0 2b3a 51 :3 0
20e :4 0 6e :2 0
20f :4 0 17c3 2901
2903 :3 0 6e :2 0
210 :4 0 17c6 2905
2907 :3 0 6e :2 0
211 :4 0 17c9 2909
290b :3 0 6e :2 0
212 :4 0 17cc 290d
290f :3 0 6e :2 0
213 :4 0 17cf 2911
2913 :3 0 6e :2 0
17 :3 0 17d2 2915
2917 :3 0 6e :2 0
206 :4 0 17d5 2919
291b :3 0 6e :2 0
214 :4 0 17d8 291d
291f :3 0 6e :2 0
2b :3 0 17db 2921
2923 :3 0 6e :2 0
208 :4 0 17de 2925
2927 :3 0 6e :2 0
2c :3 0 17e1 2929
292b :3 0 6e :2 0
215 :4 0 17e4 292d
292f :3 0 28ff 2930
0 2b3a 1fd :3 0
1fe :3 0 51 :3 0
2934 :4 0 2935 :2 0
294c 1a7 :4 0 2937
:3 0 8a :3 0 9c
:2 0 17e9 293a 293b
:3 0 15 :3 0 a6
:3 0 293d 293e 0
30 :2 0 293f 2940
0 2942 17ec 2949
15 :3 0 a6 :3 0
2943 2944 0 116
:2 0 2945 2946 0
2948 17ee 294a 293c
2942 0 294b 0
2948 0 294b 17f0
0 294c 17f3 29a1
a8 :3 0 15 :3 0
a6 :3 0 294f 2950
0 a7 :3 0 2951
2952 0 2997 66
:3 0 67 :3 0 2954
2955 0 66 :3 0
77 :3 0 2957 2958
0 a9 :2 0 2
:4 0 216 :2 0 79
:2 0 27 :2 0 17f6
295d 295f :3 0 17f9
2959 2961 2956 2963
2962 :2 0 69 :3 0
7a :3 0 2965 2966
0 6b :4 0 217
:4 0 6e :2 0 6f
:3 0 17fd 296a 296c
:3 0 6e :2 0 82
:4 0 1800 296e 2970
:3 0 6e :2 0 ac
:4 0 1803 2972 2974
:3 0 6e :2 0 a7
:3 0 1806 2976 2978
:3 0 6e :2 0 ad
:4 0 1809 297a 297c
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 180c
297f 2983 1810 297e
2985 :3 0 1813 2967
2987 :2 0 2994 69
:3 0 7a :3 0 2989
298a 0 6b :4 0
20c :4 0 6e :2 0
51 :3 0 1816 298e
2990 :3 0 1819 298b
2992 :2 0 2994 181c
2995 2964 2994 0
2996 181f 0 2997
1821 299a :3 0 299a
0 299a 2999 2997
2998 :6 0 299c 67
:3 0 1824 299e 1826
299d 299c :2 0 299f
1828 :2 0 29a1 0
29a1 29a0 294c 299f
:6 0 2b3a 1 :3 0
15 :3 0 a6 :3 0
29a3 29a4 0 218
:4 0 29a6 29a7 :3 0
29a5 29a8 0 2b3a
51 :3 0 219 :4 0
6e :2 0 21a :4 0
182a 29ac 29ae :3 0
6e :2 0 21b :4 0
182d 29b0 29b2 :3 0
6e :2 0 21c :4 0
1830 29b4 29b6 :3 0
6e :2 0 21d :4 0
1833 29b8 29ba :3 0
6e :2 0 21e :4 0
1836 29bc 29be :3 0
6e :2 0 21f :4 0
1839 29c0 29c2 :3 0
6e :2 0 220 :4 0
183c 29c4 29c6 :3 0
6e :2 0 221 :4 0
183f 29c8 29ca :3 0
6e :2 0 222 :4 0
1842 29cc 29ce :3 0
6e :2 0 223 :4 0
1845 29d0 29d2 :3 0
6e :2 0 224 :4 0
1848 29d4 29d6 :3 0
6e :2 0 225 :4 0
184b 29d8 29da :3 0
6e :2 0 17 :3 0
184e 29dc 29de :3 0
6e :2 0 226 :4 0
1851 29e0 29e2 :3 0
6e :2 0 227 :4 0
1854 29e4 29e6 :3 0
6e :2 0 17 :3 0
1857 29e8 29ea :3 0
6e :2 0 228 :4 0
185a 29ec 29ee :3 0
6e :2 0 229 :4 0
185d 29f0 29f2 :3 0
6e :2 0 22a :4 0
1860 29f4 29f6 :3 0
6e :2 0 2b :3 0
1863 29f8 29fa :3 0
6e :2 0 22b :4 0
1866 29fc 29fe :3 0
6e :2 0 22c :4 0
1869 2a00 2a02 :3 0
6e :2 0 22d :4 0
186c 2a04 2a06 :3 0
6e :2 0 22e :4 0
186f 2a08 2a0a :3 0
6e :2 0 22f :4 0
1872 2a0c 2a0e :3 0
6e :2 0 222 :4 0
1875 2a10 2a12 :3 0
6e :2 0 223 :4 0
1878 2a14 2a16 :3 0
6e :2 0 230 :4 0
187b 2a18 2a1a :3 0
6e :2 0 231 :4 0
187e 2a1c 2a1e :3 0
6e :2 0 17 :3 0
1881 2a20 2a22 :3 0
6e :2 0 232 :4 0
1884 2a24 2a26 :3 0
6e :2 0 233 :4 0
1887 2a28 2a2a :3 0
6e :2 0 234 :4 0
188a 2a2c 2a2e :3 0
6e :2 0 235 :4 0
188d 2a30 2a32 :3 0
6e :2 0 236 :4 0
1890 2a34 2a36 :3 0
6e :2 0 2c :3 0
1893 2a38 2a3a :3 0
6e :2 0 22b :4 0
1896 2a3c 2a3e :3 0
6e :2 0 237 :4 0
1899 2a40 2a42 :3 0
29aa 2a43 0 2b3a
1fd :3 0 1fe :3 0
51 :3 0 2a47 :4 0
2a48 :2 0 2a5f 1a7
:4 0 2a4a :3 0 8a
:3 0 9c :2 0 189e
2a4d 2a4e :3 0 15
:3 0 a6 :3 0 2a50
2a51 0 30 :2 0
2a52 2a53 0 2a55
18a1 2a5c 15 :3 0
a6 :3 0 2a56 2a57
0 116 :2 0 2a58
2a59 0 2a5b 18a3
2a5d 2a4f 2a55 0
2a5e 0 2a5b 0
2a5e 18a5 0 2a5f
18a8 2ab4 a8 :3 0
15 :3 0 a6 :3 0
2a62 2a63 0 a7
:3 0 2a64 2a65 0
2aaa 66 :3 0 67
:3 0 2a67 2a68 0
66 :3 0 77 :3 0
2a6a 2a6b 0 a9
:2 0 2 :4 0 238
:2 0 79 :2 0 27
:2 0 18ab 2a70 2a72
:3 0 18ae 2a6c 2a74
2a69 2a76 2a75 :2 0
69 :3 0 7a :3 0
2a78 2a79 0 6b
:4 0 239 :4 0 6e
:2 0 6f :3 0 18b2
2a7d 2a7f :3 0 6e
:2 0 82 :4 0 18b5
2a81 2a83 :3 0 6e
:2 0 ac :4 0 18b8
2a85 2a87 :3 0 6e
:2 0 a7 :3 0 18bb
2a89 2a8b :3 0 6e
:2 0 ad :4 0 18be
2a8d 2a8f :3 0 6e
:2 0 ae :3 0 af
:3 0 27 :2 0 b0
:2 0 18c1 2a92 2a96
18c5 2a91 2a98 :3 0
18c8 2a7a 2a9a :2 0
2aa7 69 :3 0 7a
:3 0 2a9c 2a9d 0
6b :4 0 20c :4 0
6e :2 0 51 :3 0
18cb 2aa1 2aa3 :3 0
18ce 2a9e 2aa5 :2 0
2aa7 18d1 2aa8 2a77
2aa7 0 2aa9 18d4
0 2aaa 18d6 2aad
:3 0 2aad 0 2aad
2aac 2aaa 2aab :6 0
2aaf 69 :3 0 18d9
2ab1 18db 2ab0 2aaf
:2 0 2ab2 18dd :2 0
2ab4 0 2ab4 2ab3
2a5f 2ab2 :6 0 2b3a
1 :3 0 51 :3 0
23a :4 0 6e :2 0
23b :4 0 18df 2ab8
2aba :3 0 6e :2 0
23c :4 0 18e2 2abc
2abe :3 0 6e :2 0
23d :4 0 18e5 2ac0
2ac2 :3 0 6e :2 0
74 :3 0 73 :3 0
38 :3 0 30 :2 0
18e8 2ac6 2ac9 18eb
2ac5 2acb 18ed 2ac4
2acd :3 0 6e :2 0
23e :4 0 18f0 2acf
2ad1 :3 0 6e :2 0
82 :4 0 18f3 2ad3
2ad5 :3 0 6e :2 0
74 :3 0 73 :3 0
3d :3 0 30 :2 0
18f6 2ad9 2adc 18f9
2ad8 2ade 18fb 2ad7
2ae0 :3 0 6e :2 0
23f :4 0 18fe 2ae2
2ae4 :3 0 6e :2 0
240 :4 0 1901 2ae6
2ae8 :3 0 6e :2 0
241 :4 0 1904 2aea
2aec :3 0 6e :2 0
242 :4 0 1907 2aee
2af0 :3 0 6e :2 0
243 :4 0 190a 2af2
2af4 :3 0 6e :2 0
244 :4 0 190d 2af6
2af8 :3 0 6e :2 0
245 :4 0 1910 2afa
2afc :3 0 6e :2 0
246 :4 0 1913 2afe
2b00 :3 0 6e :2 0
247 :4 0 1916 2b02
2b04 :3 0 6e :2 0
74 :3 0 73 :3 0
38 :3 0 30 :2 0
1919 2b08 2b0b 191c
2b07 2b0d 191e 2b06
2b0f :3 0 6e :2 0
248 :4 0 1921 2b11
2b13 :3 0 6e :2 0
249 :4 0 1924 2b15
2b17 :3 0 6e :2 0
74 :3 0 73 :3 0
3d :3 0 30 :2 0
1927 2b1b 2b1e 192a
2b1a 2b20 192c 2b19
2b22 :3 0 6e :2 0
24a :4 0 192f 2b24
2b26 :3 0 6e :2 0
24b :4 0 1932 2b28
2b2a :3 0 6e :2 0
24c :4 0 1935 2b2c
2b2e :3 0 6e :2 0
24d :4 0 1938 2b30
2b32 :3 0 6e :2 0
24e :4 0 193b 2b34
2b36 :3 0 2ab6 2b37
0 2b3a b7 :3 0
193e 2fde 73 :3 0
90 :3 0 2c :3 0
194b 2b3c 2b3e 30
:2 0 194d 2b3b 2b41
9c :2 0 30 :2 0
1952 2b43 2b45 :3 0
1fd :3 0 1fe :3 0
24f :4 0 2b49 :4 0
2b4a :2 0 2d8f 15
:3 0 a6 :3 0 2b4c
2b4d 0 30 :2 0
2b4e 2b4f 0 2d8f
51 :3 0 250 :4 0
6e :2 0 251 :4 0
1955 2b53 2b55 :3 0
6e :2 0 252 :4 0
1958 2b57 2b59 :3 0
6e :2 0 253 :4 0
195b 2b5b 2b5d :3 0
6e :2 0 254 :4 0
195e 2b5f 2b61 :3 0
6e :2 0 205 :4 0
1961 2b63 2b65 :3 0
6e :2 0 17 :3 0
1964 2b67 2b69 :3 0
6e :2 0 206 :4 0
1967 2b6b 2b6d :3 0
6e :2 0 255 :4 0
196a 2b6f 2b71 :3 0
6e :2 0 2b :3 0
196d 2b73 2b75 :3 0
6e :2 0 256 :4 0
1970 2b77 2b79 :3 0
2b51 2b7a 0 2d8f
1fd :3 0 1fe :3 0
51 :3 0 2b7e :4 0
2b7f :2 0 2b96 1a7
:4 0 2b81 :3 0 8a
:3 0 9c :2 0 1975
2b84 2b85 :3 0 15
:3 0 a6 :3 0 2b87
2b88 0 30 :2 0
2b89 2b8a 0 2b8c
1978 2b93 15 :3 0
a6 :3 0 2b8d 2b8e
0 116 :2 0 2b8f
2b90 0 2b92 197a
2b94 2b86 2b8c 0
2b95 0 2b92 0
2b95 197c 0 2b96
197f 2beb a8 :3 0
15 :3 0 a6 :3 0
2b99 2b9a 0 a7
:3 0 2b9b 2b9c 0
2be1 66 :3 0 67
:3 0 2b9e 2b9f 0
66 :3 0 77 :3 0
2ba1 2ba2 0 a9
:2 0 2 :4 0 257
:2 0 79 :2 0 27
:2 0 1982 2ba7 2ba9
:3 0 1985 2ba3 2bab
2ba0 2bad 2bac :2 0
69 :3 0 7a :3 0
2baf 2bb0 0 6b
:4 0 258 :4 0 6e
:2 0 6f :3 0 1989
2bb4 2bb6 :3 0 6e
:2 0 82 :4 0 198c
2bb8 2bba :3 0 6e
:2 0 ac :4 0 198f
2bbc 2bbe :3 0 6e
:2 0 a7 :3 0 1992
2bc0 2bc2 :3 0 6e
:2 0 ad :4 0 1995
2bc4 2bc6 :3 0 6e
:2 0 ae :3 0 af
:3 0 27 :2 0 b0
:2 0 1998 2bc9 2bcd
199c 2bc8 2bcf :3 0
199f 2bb1 2bd1 :2 0
2bde 69 :3 0 7a
:3 0 2bd3 2bd4 0
6b :4 0 20c :4 0
6e :2 0 51 :3 0
19a2 2bd8 2bda :3 0
19a5 2bd5 2bdc :2 0
2bde 19a8 2bdf 2bae
2bde 0 2be0 19ab
0 2be1 19ad 2be4
:3 0 2be4 0 2be4
2be3 2be1 2be2 :6 0
2be6 6b :3 0 19b0
2be8 19b2 2be7 2be6
:2 0 2be9 19b4 :2 0
2beb 0 2beb 2bea
2b96 2be9 :6 0 2d8f
1 :3 0 1fd :3 0
1fe :3 0 20d :4 0
2bef :4 0 2bf0 :2 0
2d8f 15 :3 0 a6
:3 0 2bf2 2bf3 0
30 :2 0 2bf4 2bf5
0 2d8f 51 :3 0
259 :4 0 6e :2 0
25a :4 0 19b6 2bf9
2bfb :3 0 6e :2 0
25b :4 0 19b9 2bfd
2bff :3 0 6e :2 0
25c :4 0 19bc 2c01
2c03 :3 0 6e :2 0
25d :4 0 19bf 2c05
2c07 :3 0 6e :2 0
25e :4 0 19c2 2c09
2c0b :3 0 6e :2 0
17 :3 0 19c5 2c0d
2c0f :3 0 6e :2 0
25f :4 0 19c8 2c11
2c13 :3 0 6e :2 0
2b :3 0 19cb 2c15
2c17 :3 0 6e :2 0
260 :4 0 19ce 2c19
2c1b :3 0 2bf7 2c1c
0 2d8f 1fd :3 0
1fe :3 0 51 :3 0
2c20 :4 0 2c21 :2 0
2c38 1a7 :4 0 2c23
:3 0 8a :3 0 9c
:2 0 19d3 2c26 2c27
:3 0 15 :3 0 a6
:3 0 2c29 2c2a 0
30 :2 0 2c2b 2c2c
0 2c2e 19d6 2c35
15 :3 0 a6 :3 0
2c2f 2c30 0 116
:2 0 2c31 2c32 0
2c34 19d8 2c36 2c28
2c2e 0 2c37 0
2c34 0 2c37 19da
0 2c38 19dd 2c8d
a8 :3 0 15 :3 0
a6 :3 0 2c3b 2c3c
0 a7 :3 0 2c3d
2c3e 0 2c83 66
:3 0 67 :3 0 2c40
2c41 0 66 :3 0
77 :3 0 2c43 2c44
0 a9 :2 0 2
:4 0 261 :2 0 79
:2 0 27 :2 0 19e0
2c49 2c4b :3 0 19e3
2c45 2c4d 2c42 2c4f
2c4e :2 0 69 :3 0
7a :3 0 2c51 2c52
0 6b :4 0 262
:4 0 6e :2 0 6f
:3 0 19e7 2c56 2c58
:3 0 6e :2 0 82
:4 0 19ea 2c5a 2c5c
:3 0 6e :2 0 ac
:4 0 19ed 2c5e 2c60
:3 0 6e :2 0 a7
:3 0 19f0 2c62 2c64
:3 0 6e :2 0 ad
:4 0 19f3 2c66 2c68
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 19f6
2c6b 2c6f 19fa 2c6a
2c71 :3 0 19fd 2c53
2c73 :2 0 2c80 69
:3 0 7a :3 0 2c75
2c76 0 6b :4 0
20c :4 0 6e :2 0
51 :3 0 1a00 2c7a
2c7c :3 0 1a03 2c77
2c7e :2 0 2c80 1a06
2c81 2c50 2c80 0
2c82 1a09 0 2c83
1a0b 2c86 :3 0 2c86
0 2c86 2c85 2c83
2c84 :6 0 2c88 6d
:3 0 1a0e 2c8a 1a10
2c89 2c88 :2 0 2c8b
1a12 :2 0 2c8d 0
2c8d 2c8c 2c38 2c8b
:6 0 2d8f 1 :3 0
15 :3 0 a6 :3 0
2c8f 2c90 0 218
:4 0 2c92 2c93 :3 0
2c91 2c94 0 2d8f
51 :3 0 219 :4 0
6e :2 0 263 :4 0
1a14 2c98 2c9a :3 0
6e :2 0 21c :4 0
1a17 2c9c 2c9e :3 0
6e :2 0 264 :4 0
1a1a 2ca0 2ca2 :3 0
6e :2 0 265 :4 0
1a1d 2ca4 2ca6 :3 0
6e :2 0 220 :4 0
1a20 2ca8 2caa :3 0
6e :2 0 266 :4 0
1a23 2cac 2cae :3 0
6e :2 0 223 :4 0
1a26 2cb0 2cb2 :3 0
6e :2 0 267 :4 0
1a29 2cb4 2cb6 :3 0
6e :2 0 225 :4 0
1a2c 2cb8 2cba :3 0
6e :2 0 17 :3 0
1a2f 2cbc 2cbe :3 0
6e :2 0 226 :4 0
1a32 2cc0 2cc2 :3 0
6e :2 0 227 :4 0
1a35 2cc4 2cc6 :3 0
6e :2 0 17 :3 0
1a38 2cc8 2cca :3 0
6e :2 0 228 :4 0
1a3b 2ccc 2cce :3 0
6e :2 0 229 :4 0
1a3e 2cd0 2cd2 :3 0
6e :2 0 268 :4 0
1a41 2cd4 2cd6 :3 0
6e :2 0 2b :3 0
1a44 2cd8 2cda :3 0
6e :2 0 269 :4 0
1a47 2cdc 2cde :3 0
2c96 2cdf 0 2d8f
1fd :3 0 1fe :3 0
51 :3 0 2ce3 :4 0
2ce4 :2 0 2cfb 1a7
:4 0 2ce6 :3 0 8a
:3 0 9c :2 0 1a4c
2ce9 2cea :3 0 15
:3 0 a6 :3 0 2cec
2ced 0 30 :2 0
2cee 2cef 0 2cf1
1a4f 2cf8 15 :3 0
a6 :3 0 2cf2 2cf3
0 116 :2 0 2cf4
2cf5 0 2cf7 1a51
2cf9 2ceb 2cf1 0
2cfa 0 2cf7 0
2cfa 1a53 0 2cfb
1a56 2d50 a8 :3 0
15 :3 0 a6 :3 0
2cfe 2cff 0 a7
:3 0 2d00 2d01 0
2d46 66 :3 0 67
:3 0 2d03 2d04 0
66 :3 0 77 :3 0
2d06 2d07 0 a9
:2 0 2 :4 0 26a
:2 0 79 :2 0 27
:2 0 1a59 2d0c 2d0e
:3 0 1a5c 2d08 2d10
2d05 2d12 2d11 :2 0
69 :3 0 7a :3 0
2d14 2d15 0 6b
:4 0 26b :4 0 6e
:2 0 6f :3 0 1a60
2d19 2d1b :3 0 6e
:2 0 82 :4 0 1a63
2d1d 2d1f :3 0 6e
:2 0 ac :4 0 1a66
2d21 2d23 :3 0 6e
:2 0 a7 :3 0 1a69
2d25 2d27 :3 0 6e
:2 0 ad :4 0 1a6c
2d29 2d2b :3 0 6e
:2 0 ae :3 0 af
:3 0 27 :2 0 b0
:2 0 1a6f 2d2e 2d32
1a73 2d2d 2d34 :3 0
1a76 2d16 2d36 :2 0
2d43 69 :3 0 7a
:3 0 2d38 2d39 0
6b :4 0 20c :4 0
6e :2 0 51 :3 0
1a79 2d3d 2d3f :3 0
1a7c 2d3a 2d41 :2 0
2d43 1a7f 2d44 2d13
2d43 0 2d45 1a82
0 2d46 1a84 2d49
:3 0 2d49 0 2d49
2d48 2d46 2d47 :6 0
2d4b 6f :3 0 1a87
2d4d 1a89 2d4c 2d4b
:2 0 2d4e 1a8b :2 0
2d50 0 2d50 2d4f
2cfb 2d4e :6 0 2d8f
1 :3 0 51 :3 0
26c :4 0 6e :2 0
26d :4 0 1a8d 2d54
2d56 :3 0 6e :2 0
26e :4 0 1a90 2d58
2d5a :3 0 6e :2 0
26f :4 0 1a93 2d5c
2d5e :3 0 6e :2 0
74 :3 0 73 :3 0
38 :3 0 30 :2 0
1a96 2d62 2d65 1a99
2d61 2d67 1a9b 2d60
2d69 :3 0 6e :2 0
270 :4 0 1a9e 2d6b
2d6d :3 0 6e :2 0
74 :3 0 73 :3 0
3d :3 0 30 :2 0
1aa1 2d71 2d74 1aa4
2d70 2d76 1aa6 2d6f
2d78 :3 0 6e :2 0
271 :4 0 1aa9 2d7a
2d7c :3 0 6e :2 0
240 :4 0 1aac 2d7e
2d80 :3 0 6e :2 0
272 :4 0 1aaf 2d82
2d84 :3 0 6e :2 0
273 :4 0 1ab2 2d86
2d88 :3 0 6e :2 0
274 :4 0 1ab5 2d8a
2d8c :3 0 2d52 2d8d
0 2d8f 1ab8 2d90
2b46 2d8f 0 2fe0
1fd :3 0 1fe :3 0
24f :4 0 2d93 :4 0
2d94 :2 0 2fdd 15
:3 0 a6 :3 0 2d96
2d97 0 30 :2 0
2d98 2d99 0 2fdd
51 :3 0 250 :4 0
6e :2 0 275 :4 0
1ac5 2d9d 2d9f :3 0
6e :2 0 276 :4 0
1ac8 2da1 2da3 :3 0
6e :2 0 277 :4 0
1acb 2da5 2da7 :3 0
6e :2 0 278 :4 0
1ace 2da9 2dab :3 0
6e :2 0 212 :4 0
1ad1 2dad 2daf :3 0
6e :2 0 279 :4 0
1ad4 2db1 2db3 :3 0
6e :2 0 17 :3 0
1ad7 2db5 2db7 :3 0
6e :2 0 27a :4 0
1ada 2db9 2dbb :3 0
6e :2 0 27b :4 0
1add 2dbd 2dbf :3 0
6e :2 0 2c :3 0
1ae0 2dc1 2dc3 :3 0
6e :2 0 27c :4 0
1ae3 2dc5 2dc7 :3 0
6e :2 0 27d :4 0
1ae6 2dc9 2dcb :3 0
2d9b 2dcc 0 2fdd
1fd :3 0 1fe :3 0
51 :3 0 2dd0 :4 0
2dd1 :2 0 2de8 1a7
:4 0 2dd3 :3 0 8a
:3 0 9c :2 0 1aeb
2dd6 2dd7 :3 0 15
:3 0 a6 :3 0 2dd9
2dda 0 30 :2 0
2ddb 2ddc 0 2dde
1aee 2de5 15 :3 0
a6 :3 0 2ddf 2de0
0 116 :2 0 2de1
2de2 0 2de4 1af0
2de6 2dd8 2dde 0
2de7 0 2de4 0
2de7 1af2 0 2de8
1af5 2e3d a8 :3 0
15 :3 0 a6 :3 0
2deb 2dec 0 a7
:3 0 2ded 2dee 0
2e33 66 :3 0 67
:3 0 2df0 2df1 0
66 :3 0 77 :3 0
2df3 2df4 0 a9
:2 0 2 :4 0 27e
:2 0 79 :2 0 27
:2 0 1af8 2df9 2dfb
:3 0 1afb 2df5 2dfd
2df2 2dff 2dfe :2 0
69 :3 0 7a :3 0
2e01 2e02 0 6b
:4 0 27f :4 0 6e
:2 0 6f :3 0 1aff
2e06 2e08 :3 0 6e
:2 0 82 :4 0 1b02
2e0a 2e0c :3 0 6e
:2 0 ac :4 0 1b05
2e0e 2e10 :3 0 6e
:2 0 a7 :3 0 1b08
2e12 2e14 :3 0 6e
:2 0 ad :4 0 1b0b
2e16 2e18 :3 0 6e
:2 0 ae :3 0 af
:3 0 27 :2 0 b0
:2 0 1b0e 2e1b 2e1f
1b12 2e1a 2e21 :3 0
1b15 2e03 2e23 :2 0
2e30 69 :3 0 7a
:3 0 2e25 2e26 0
6b :4 0 20c :4 0
6e :2 0 51 :3 0
1b18 2e2a 2e2c :3 0
1b1b 2e27 2e2e :2 0
2e30 1b1e 2e31 2e00
2e30 0 2e32 1b21
0 2e33 1b23 2e36
:3 0 2e36 0 2e36
2e35 2e33 2e34 :6 0
2e38 71 :3 0 1b26
2e3a 1b28 2e39 2e38
:2 0 2e3b 1b2a :2 0
2e3d 0 2e3d 2e3c
2de8 2e3b :6 0 2fdd
1 :3 0 1fd :3 0
1fe :3 0 20d :4 0
2e41 :4 0 2e42 :2 0
2fdd 15 :3 0 a6
:3 0 2e44 2e45 0
30 :2 0 2e46 2e47
0 2fdd 51 :3 0
259 :4 0 6e :2 0
280 :4 0 1b2c 2e4b
2e4d :3 0 6e :2 0
281 :4 0 1b2f 2e4f
2e51 :3 0 6e :2 0
282 :4 0 1b32 2e53
2e55 :3 0 6e :2 0
283 :4 0 1b35 2e57
2e59 :3 0 6e :2 0
25e :4 0 1b38 2e5b
2e5d :3 0 6e :2 0
17 :3 0 1b3b 2e5f
2e61 :3 0 6e :2 0
25f :4 0 1b3e 2e63
2e65 :3 0 6e :2 0
2c :3 0 1b41 2e67
2e69 :3 0 6e :2 0
284 :4 0 1b44 2e6b
2e6d :3 0 2e49 2e6e
0 2fdd 1fd :3 0
1fe :3 0 51 :3 0
2e72 :4 0 2e73 :2 0
2e8a 1a7 :4 0 2e75
:3 0 8a :3 0 9c
:2 0 1b49 2e78 2e79
:3 0 15 :3 0 a6
:3 0 2e7b 2e7c 0
30 :2 0 2e7d 2e7e
0 2e80 1b4c 2e87
15 :3 0 a6 :3 0
2e81 2e82 0 116
:2 0 2e83 2e84 0
2e86 1b4e 2e88 2e7a
2e80 0 2e89 0
2e86 0 2e89 1b50
0 2e8a 1b53 2edf
a8 :3 0 15 :3 0
a6 :3 0 2e8d 2e8e
0 a7 :3 0 2e8f
2e90 0 2ed5 66
:3 0 67 :3 0 2e92
2e93 0 66 :3 0
77 :3 0 2e95 2e96
0 a9 :2 0 2
:4 0 285 :2 0 79
:2 0 27 :2 0 1b56
2e9b 2e9d :3 0 1b59
2e97 2e9f 2e94 2ea1
2ea0 :2 0 69 :3 0
7a :3 0 2ea3 2ea4
0 6b :4 0 286
:4 0 6e :2 0 6f
:3 0 1b5d 2ea8 2eaa
:3 0 6e :2 0 82
:4 0 1b60 2eac 2eae
:3 0 6e :2 0 ac
:4 0 1b63 2eb0 2eb2
:3 0 6e :2 0 a7
:3 0 1b66 2eb4 2eb6
:3 0 6e :2 0 ad
:4 0 1b69 2eb8 2eba
:3 0 6e :2 0 ae
:3 0 af :3 0 27
:2 0 b0 :2 0 1b6c
2ebd 2ec1 1b70 2ebc
2ec3 :3 0 1b73 2ea5
2ec5 :2 0 2ed2 69
:3 0 7a :3 0 2ec7
2ec8 0 6b :4 0
20c :4 0 6e :2 0
51 :3 0 1b76 2ecc
2ece :3 0 1b79 2ec9
2ed0 :2 0 2ed2 1b7c
2ed3 2ea2 2ed2 0
2ed4 1b7f 0 2ed5
1b81 2ed8 :3 0 2ed8
0 2ed8 2ed7 2ed5
2ed6 :6 0 2eda 73
:3 0 1b84 2edc 1b86
2edb 2eda :2 0 2edd
1b88 :2 0 2edf 0
2edf 2ede 2e8a 2edd
:6 0 2fdd 1 :3 0
15 :3 0 a6 :3 0
2ee1 2ee2 0 218
:4 0 2ee4 2ee5 :3 0
2ee3 2ee6 0 2fdd
51 :3 0 219 :4 0
6e :2 0 263 :4 0
1b8a 2eea 2eec :3 0
6e :2 0 21c :4 0
1b8d 2eee 2ef0 :3 0
6e :2 0 21d :4 0
1b90 2ef2 2ef4 :3 0
6e :2 0 287 :4 0
1b93 2ef6 2ef8 :3 0
6e :2 0 288 :4 0
1b96 2efa 2efc :3 0
6e :2 0 222 :4 0
1b99 2efe 2f00 :3 0
6e :2 0 223 :4 0
1b9c 2f02 2f04 :3 0
6e :2 0 289 :4 0
1b9f 2f06 2f08 :3 0
6e :2 0 225 :4 0
1ba2 2f0a 2f0c :3 0
6e :2 0 17 :3 0
1ba5 2f0e 2f10 :3 0
6e :2 0 232 :4 0
1ba8 2f12 2f14 :3 0
6e :2 0 28a :4 0
1bab 2f16 2f18 :3 0
6e :2 0 235 :4 0
1bae 2f1a 2f1c :3 0
6e :2 0 236 :4 0
1bb1 2f1e 2f20 :3 0
6e :2 0 2c :3 0
1bb4 2f22 2f24 :3 0
6e :2 0 269 :4 0
1bb7 2f26 2f28 :3 0
2ee8 2f29 0 2fdd
1fd :3 0 1fe :3 0
51 :3 0 2f2d :4 0
2f2e :2 0 2f45 1a7
:4 0 2f30 :3 0 8a
:3 0 9c :2 0 1bbc
2f33 2f34 :3 0 15
:3 0 a6 :3 0 2f36
2f37 0 30 :2 0
2f38 2f39 0 2f3b
1bbf 2f42 15 :3 0
a6 :3 0 2f3c 2f3d
0 116 :2 0 2f3e
2f3f 0 2f41 1bc1
2f43 2f35 2f3b 0
2f44 0 2f41 0
2f44 1bc3 0 2f45
1bc6 2f9a a8 :3 0
15 :3 0 a6 :3 0
2f48 2f49 0 a7
:3 0 2f4a 2f4b 0
2f90 66 :3 0 67
:3 0 2f4d 2f4e 0
66 :3 0 77 :3 0
2f50 2f51 0 a9
:2 0 2 :4 0 28b
:2 0 79 :2 0 27
:2 0 1bc9 2f56 2f58
:3 0 1bcc 2f52 2f5a
2f4f 2f5c 2f5b :2 0
69 :3 0 7a :3 0
2f5e 2f5f 0 6b
:4 0 28c :4 0 6e
:2 0 6f :3 0 1bd0
2f63 2f65 :3 0 6e
:2 0 82 :4 0 1bd3
2f67 2f69 :3 0 6e
:2 0 ac :4 0 1bd6
2f6b 2f6d :3 0 6e
:2 0 a7 :3 0 1bd9
2f6f 2f71 :3 0 6e
:2 0 ad :4 0 1bdc
2f73 2f75 :3 0 6e
:2 0 ae :3 0 af
:3 0 27 :2 0 b0
:2 0 1bdf 2f78 2f7c
1be3 2f77 2f7e :3 0
1be6 2f60 2f80 :2 0
2f8d 69 :3 0 7a
:3 0 2f82 2f83 0
6b :4 0 20c :4 0
6e :2 0 51 :3 0
1be9 2f87 2f89 :3 0
1bec 2f84 2f8b :2 0
2f8d 1bef 2f8e 2f5d
2f8d 0 2f8f 1bf2
0 2f90 1bf4 2f93
:3 0 2f93 0 2f93
2f92 2f90 2f91 :6 0
2f95 75 :3 0 1bf7
2f97 1bf9 2f96 2f95
:2 0 2f98 1bfb :2 0
2f9a 0 2f9a 2f99
2f45 2f98 :6 0 2fdd
1 :3 0 51 :3 0
28d :4 0 6e :2 0
26d :4 0 1bfd 2f9e
2fa0 :3 0 6e :2 0
28e :4 0 1c00 2fa2
2fa4 :3 0 6e :2 0
28f :4 0 1c03 2fa6
2fa8 :3 0 6e :2 0
74 :3 0 73 :3 0
38 :3 0 30 :2 0
1c06 2fac 2faf 1c09
2fab 2fb1 1c0b 2faa
2fb3 :3 0 6e :2 0
248 :4 0 1c0e 2fb5
2fb7 :3 0 6e :2 0
290 :4 0 1c11 2fb9
2fbb :3 0 6e :2 0
74 :3 0 73 :3 0
3d :3 0 30 :2 0
1c14 2fbf 2fc2 1c17
2fbe 2fc4 1c19 2fbd
2fc6 :3 0 6e :2 0
291 :4 0 1c1c 2fc8
2fca :3 0 6e :2 0
292 :4 0 1c1f 2fcc
2fce :3 0 6e :2 0
240 :4 0 1c22 2fd0
2fd2 :3 0 6e :2 0
293 :4 0 1c25 2fd4
2fd6 :3 0 6e :2 0
274 :4 0 1c28 2fd8
2fda :3 0 2f9c 2fdb
0 2fdd 1c2b 2fdf
2846 2b3a 0 2fe0
0 2fdd 0 2fe0
1c38 0 3027 66
:3 0 67 :3 0 2fe1
2fe2 0 66 :3 0
77 :3 0 2fe4 2fe5
0 27 :2 0 2
:4 0 294 :2 0 79
:2 0 27 :2 0 1c3c
2fea 2fec :3 0 1c3f
2fe6 2fee 2fe3 2ff0
2fef :2 0 69 :3 0
7a :3 0 2ff2 2ff3
0 6b :4 0 295
:4 0 6e :2 0 6f
:3 0 1c43 2ff7 2ff9
:3 0 1c46 2ff4 2ffb
:2 0 2ffd 1c49 2ffe
2ff1 2ffd 0 2fff
1c4b 0 3027 66
:3 0 67 :3 0 3000
3001 0 66 :3 0
77 :3 0 3003 3004
0 27 :2 0 2
:4 0 296 :2 0 79
:2 0 27 :2 0 1c4d
3009 300b :3 0 1c50
3005 300d 3002 300f
300e :2 0 69 :3 0
7a :3 0 3011 3012
0 6b :4 0 297
:4 0 6e :2 0 6f
:3 0 1c54 3016 3018
:3 0 1c57 3013 301a
:2 0 301c 1c5a 301d
3010 301c 0 301e
1c5c 0 3027 14
:3 0 88 :3 0 298
:3 0 3020 3021 0
51 :3 0 1c5e 3022
3024 3025 :2 0 3027
1c60 30c8 15 :3 0
299 :2 0 4 3028
3029 0 66 :3 0
67 :3 0 302b 302c
0 66 :3 0 77
:3 0 302e 302f 0
a9 :2 0 2 :4 0
29a :2 0 79 :2 0
27 :2 0 1c90 3034
3036 :3 0 1c93 3030
3038 302d 303a 3039
:2 0 69 :3 0 7a
:3 0 303c 303d 0
6b :4 0 29b :4 0
6e :2 0 6f :3 0
1c97 3041 3043 :3 0
1c9a 303e 3045 :2 0
305e 69 :3 0 7a
:3 0 3047 3048 0
6b :4 0 29c :4 0
6e :2 0 15 :3 0
29d :3 0 304d 304e
0 1c9d 304c 3050
:3 0 6e :2 0 ee
:4 0 1ca0 3052 3054
:3 0 6e :2 0 15
:3 0 29e :3 0 3057
3058 0 1ca3 3056
305a :3 0 1ca6 3049
305c :2 0 305e 1ca9
305f 303b 305e 0
3060 1cac 0 3070
29f :3 0 65 :3 0
15 :3 0 29d :3 0
2a0 :3 0 15 :3 0
29e :3 0 5f :3 0
a4 :4 0 2a1 1
:a 0 306c :2 0 3070
3062 306a :2 0 14
:3 0 65 :3 0 306e
:2 0 3070 1cae 3072
1cb2 3071 3070 :2 0
30c6 a8 :3 0 15
:3 0 a6 :3 0 3075
3076 0 a7 :3 0
3077 3078 0 30be
66 :3 0 67 :3 0
307a 307b 0 66
:3 0 77 :3 0 307d
307e 0 a9 :2 0
2 :4 0 2a2 :2 0
79 :2 0 27 :2 0
1cb4 3083 3085 :3 0
1cb7 307f 3087 307c
3089 3088 :2 0 69
:3 0 7a :3 0 308b
308c 0 6b :4 0
2a3 :4 0 6e :2 0
6f :3 0 1cbb 3090
3092 :3 0 1cbe 308d
3094 :2 0 30ae 69
:3 0 7a :3 0 3096
3097 0 6b :4 0
ac :4 0 6e :2 0
a7 :3 0 1cc1 309b
309d :3 0 6e :2 0
ad :4 0 1cc4 309f
30a1 :3 0 6e :2 0
ae :3 0 af :3 0
27 :2 0 b0 :2 0
1cc7 30a4 30a8 1ccb
30a3 30aa :3 0 1cce
3098 30ac :2 0 30ae
1cd1 30af 308a 30ae
0 30b0 1cd4 0
30be 29f :3 0 65
:3 0 2a0 :3 0 15
:3 0 29e :3 0 5f
:3 0 a4 :4 0 2a4
1 :a 0 30ba :2 0
30be 30b2 30b8 :2 0
14 :3 0 65 :3 0
30bc :2 0 30be 1cd6
30c1 :3 0 30c1 0
30c1 30c0 30be 30bf
:6 0 30c3 1 :3 0
1cdb 30c5 1cdd 30c4
30c3 :2 0 30c6 1cdf
:2 0 30c8 1ce2 30c8
30c7 3027 30c6 :6 0
30c9 :2 0 2 44
30c8 30cc :3 0 30cb
30c9 30cd :8 0 
1d27
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
4f 1 4d 1
56 1 54 1
5d 1 5b 1
64 1 62 1
6b 1 69 1
72 1 70 1
79 1 77 1
80 1 7e 1
87 1 85 1
8c 1 91 1
98 1 96 1
9f 1 9d 1
a6 1 a4 1
ad 1 ab 1
b4 1 b2 1
bb 1 b9 1
c0 1 c6 1
cc 1 d2 1
d8 1 de 1
e4 1 ea 1
f0 1 f6 1
fc 1 102 1
108 1 10e 1
114 1 11a 1
120 1 126 1
12c 1 132 1
138 1 13e 1
144 1 14a 1
150 1 156 1
15c 1 162 1
16a 1 168 1
171 1 16f 1
176 1 17e 1
17c 1 183 1
18b 1 189 1
192 1 190 1
199 1 197 1
19e 1 1a4 1
1aa 1 1b2 1
1b0 1 1b9 1
1b7 1 1be 1
1c4 1 1cc 1
1ca 1 1d1 1
1d7 1 1dd 1
1e3 1 1e9 1
1ee 1 1fb 1
207 2 20a 20c
2 20f 211 2
213 215 2 217
219 2 21b 21d
2 21f 221 2
223 225 2 227
229 2 22b 22d
2 22f 231 2
233 235 2 237
239 2 23b 23d
1 243 2 245
246 2 23f 248
2 24a 24c 1
252 2 254 255
2 24e 257 2
259 25b 1 261
2 263 264 2
25d 266 2 268
26a 1 270 2
272 273 2 26c
275 2 277 279
1 27f 2 281
282 2 27b 284
2 286 288 1
28e 2 290 291
2 28a 293 2
295 297 1 29d
2 29f 2a0 2
299 2a2 2 2a4
2a6 1 2ac 2
2ae 2af 2 2a8
2b1 2 2b3 2b5
1 2bb 2 2bd
2be 2 2b7 2c0
2 2c2 2c4 1
2ca 2 2cc 2cd
2 2c6 2cf 2
2d1 2d3 2 2d5
2d7 2 2d9 2db
2 2dd 2df 2
2e1 2e3 2 2e5
2e7 2 2e9 2eb
2 2ed 2ef 2
2f1 2f3 4 203
209 20e 2f5 1
2f7 1 2f9 2
303 305 3 301
302 307 2 310
312 2 30f 314
1 316 1 318
2 350 351 1
353 1 360 2
36d 36f 3 36b
36c 371 2 37a
37c 2 37e 380
2 382 384 1
38c 2 38e 38f
2 386 391 2
379 393 1 395
1 397 2 3a1
3a3 3 39f 3a0
3a5 2 3ae 3b0
2 3ad 3b2 1
3b4 1 3b6 2
3bd 3be 3 398
3b7 3c0 1 3c2
1 3c4 2 3d1
3d3 3 3cf 3d0
3d5 2 3de 3e0
2 3e2 3e4 2
3e6 3e8 1 3f0
2 3f2 3f3 2
3ea 3f5 2 3dd
3f7 1 3f9 1
3fb 2 405 407
3 403 404 409
2 412 414 2
411 416 1 418
1 41a 2 421
422 3 3fc 41b
424 1 426 1
428 1 42f 2
431 432 1 436
2 434 436 2
445 447 3 443
444 449 2 452
454 2 456 458
2 45a 45c 1
464 2 466 467
2 45e 469 2
451 46b 1 46d
1 46f 2 479
47b 3 477 478
47d 2 486 488
2 485 48a 1
48c 1 48e 2
495 496 3 470
48f 498 1 49a
1 49c 1 4a3
2 4a5 4a6 1
4aa 2 4a8 4aa
2 4b9 4bb 3
4b7 4b8 4bd 2
4c6 4c8 2 4ca
4cc 2 4ce 4d0
1 4d8 2 4da
4db 2 4d2 4dd
2 4c5 4df 1
4e1 1 4e3 2
4ed 4ef 3 4eb
4ec 4f1 2 4fa
4fc 2 4f9 4fe
1 500 1 502
2 509 50a 3
4e4 503 50c 1
50e 2 511 512
1 516 2 514
516 2 51a 51b
1 51f 2 51d
51f 2 525 526
1 52a 2 528
52a 2 537 539
3 535 536 53b
2 544 546 2
548 54a 2 54c
54e 1 556 2
558 559 2 550
55b 2 543 55d
1 55f 1 561
2 56b 56d 3
569 56a 56f 2
578 57a 2 577
57c 1 57e 1
580 2 587 588
3 562 581 58a
1 58c 1 58e
1 594 2 5a4
5a9 2 5ba 5bc
3 5b8 5b9 5be
2 5c7 5c9 2
5cb 5cd 2 5cf
5d1 2 5d3 5d5
2 5d7 5d9 3
5de 5df 5e0 2
5db 5e2 2 5c6
5e4 1 5e6 1
5e8 2 5b1 5e9
1 5ed 1 5ac
1 5f1 1 5fc
2 5f8 5fc 2
601 602 1 606
2 604 606 2
614 616 3 612
613 618 2 621
623 2 625 627
2 629 62b 1
633 2 635 636
2 62d 638 2
620 63a 1 63c
1 63e 2 648
64a 3 646 647
64c 2 655 657
2 654 659 1
65b 1 65d 2
664 665 3 63f
65e 667 1 669
3 5f4 66a 66d
1 670 1 676
2 681 686 2
697 699 3 695
696 69b 2 6a4
6a6 2 6a8 6aa
2 6ac 6ae 2
6b0 6b2 2 6b4
6b6 3 6bb 6bc
6bd 2 6b8 6bf
2 6a3 6c1 1
6c3 1 6c5 2
68e 6c6 1 6ca
1 689 1 6ce
1 6d1 2 6d5
6d4 1 6da 1
6e1 1 6e3 3
6e7 6e8 6e9 3
6ef 6f0 6f1 2
6f9 6fa 1 6fe
2 6fc 6fe 3
704 705 706 3
708 709 70a 4
712 713 714 715
2 71b 71c 1
71e 1 722 2
720 722 2 732
737 2 748 74a
3 746 747 74c
2 755 757 2
759 75b 2 75d
75f 2 761 763
2 765 767 3
76c 76d 76e 2
769 770 2 754
772 1 774 1
776 2 73f 777
1 77b 1 73a
1 77f 1 782
2 7ca 7cf 2
7e0 7e2 3 7de
7df 7e4 2 7ed
7ef 2 7f1 7f3
2 7f5 7f7 2
7f9 7fb 2 7fd
7ff 3 804 805
806 2 801 808
2 7ec 80a 1
80c 1 80e 2
7d7 80f 1 813
1 7d2 1 817
1 81a 2 81d
81e 1 826 2
822 826 2 831
836 2 847 849
3 845 846 84b
2 854 856 2
858 85a 2 85c
85e 2 860 862
2 864 866 3
86b 86c 86d 2
868 86f 2 853
871 1 873 1
875 2 83e 876
1 87a 1 839
1 87e 1 889
2 885 889 1
88d 1 894 1
896 2 8a3 8a8
2 8b9 8bb 3
8b7 8b8 8bd 2
8c6 8c8 2 8ca
8cc 2 8ce 8d0
2 8d2 8d4 2
8d6 8d8 3 8dd
8de 8df 2 8da
8e1 2 8c5 8e3
1 8e5 1 8e7
2 8b0 8e8 1
8ec 1 8ab 1
8f0 2 897 8f3
2 8fe 900 3
8fc 8fd 902 2
90b 90d 2 90f
911 2 913 915
1 91d 2 91f
920 2 917 922
2 924 926 2
928 92a 2 92c
92e 2 930 932
2 90a 934 1
936 1 938 2
942 944 3 940
941 946 2 94f
951 2 94e 953
1 955 1 957
3 95e 95f 960
3 939 958 962
2 964 965 2
881 966 1 96a
2 96c 96d 2
977 97c 2 98d
98f 3 98b 98c
991 2 99a 99c
2 99e 9a0 2
9a2 9a4 2 9a6
9a8 2 9aa 9ac
3 9b1 9b2 9b3
2 9ae 9b5 2
999 9b7 1 9b9
1 9bb 2 984
9bc 1 9c0 1
97f 1 9c4 2
9ca 9cb 1 9cf
2 9cd 9cf 2
9d7 9dc 2 9ed
9ef 3 9eb 9ec
9f1 2 9fa 9fc
2 9fe a00 2
a02 a04 2 a06
a08 2 a0a a0c
3 a11 a12 a13
2 a0e a15 2
9f9 a17 1 a19
1 a1b 2 9e4
a1c 1 a20 1
9df 1 a24 2
a2c a2d 1 a31
2 a2f a31 2
a3c a3e 3 a3a
a3b a40 2 a49
a4b 2 a4d a4f
2 a51 a53 1
a5b 2 a5d a5e
2 a55 a60 2
a62 a64 2 a66
a68 2 a6a a6c
2 a6e a70 2
a48 a72 1 a74
1 a76 2 a80
a82 3 a7e a7f
a84 2 a8d a8f
2 a8c a91 1
a93 1 a95 3
a9c a9d a9e 3
a77 a96 aa0 1
aa2 2 a27 aa3
1 aa5 7 70d
718 81f 96e 971
9c7 aa6 2 ab3
ab8 2 ac9 acb
3 ac7 ac8 acd
2 ad6 ad8 2
ada adc 2 ade
ae0 2 ae2 ae4
2 ae6 ae8 3
aed aee aef 2
aea af1 2 ad5
af3 1 af5 1
af7 2 ac0 af8
1 afc 1 abb
1 b00 1 b0b
2 b07 b0b 2
b14 b19 2 b2a
b2c 3 b28 b29
b2e 2 b37 b39
2 b3b b3d 2
b3f b41 2 b43
b45 2 b47 b49
3 b4e b4f b50
2 b4b b52 2
b36 b54 1 b56
1 b58 2 b21
b59 1 b5d 1
b1c 1 b61 1
b6c 2 b68 b6c
2 b78 b7a 3
b76 b77 b7c 2
b85 b87 2 b89
b8b 2 b8d b8f
1 b97 2 b99
b9a 2 b91 b9c
2 b9e ba0 2
ba2 ba4 2 ba6
ba8 2 baa bac
2 b84 bae 1
bb0 1 bb2 2
bbc bbe 3 bba
bbb bc0 2 bc9
bcb 2 bc8 bcd
1 bcf 1 bd1
3 bd8 bd9 bda
3 bb3 bd2 bdc
1 bde 2 b64
bdf 1 be1 2
b03 be2 2 be4
be5 1 be9 2
be7 be9 2 bf7
bf8 2 bfc bfd
2 c01 c02 2
c06 c07 2 c0b
c0c 2 c10 c11
2 c15 c16 2
c1a c1b d bf4
bf5 bfa bff c04
c09 c0e c13 c18
c1d c1e c1f c20
2 c25 c26 1
c2c 2 c28 c2c
2 c37 c39 3
c35 c36 c3b 2
c44 c46 2 c48
c4a 2 c4c c4e
1 c56 2 c58
c59 2 c50 c5b
2 c43 c5d 1
c5f 1 c61 2
c6b c6d 3 c69
c6a c6f 2 c78
c7a 2 c77 c7c
1 c7e 1 c80
2 c87 c88 3
c62 c81 c8a 2
c8e c8f 1 c93
2 c91 c93 2
c9e ca0 3 c9c
c9d ca2 2 cab
cad 2 caf cb1
2 cb3 cb5 1
cbb 2 cbd cbe
2 cb7 cc0 2
cc2 cc4 2 cc6
cc8 2 cca ccc
2 cce cd0 2
caa cd2 1 cd4
1 cd6 2 ce0
ce2 3 cde cdf
ce4 2 ced cef
2 cec cf1 1
cf3 1 cf5 2
cfb cfc 3 cfe
cff d00 3 cd7
cf6 d02 2 d05
d04 1 d0a 1
d11 1 d13 6
bee bf1 c23 d06
d09 d14 2 d18
d19 1 d1d 2
d1b d1d 2 d22
d23 1 d27 2
d25 d27 2 d2e
d2f 1 d33 2
d31 d33 2 d38
d39 1 d3d 2
d3b d3d 1 d45
2 d49 d4a 1
d4e 2 d4c d4e
1 d53 2 d58
d59 1 d5d 2
d5b d5d 2 d62
d63 1 d67 2
d65 d67 1 d6f
2 d74 d75 1
d79 2 d77 d79
2 d7e d7f 2
d84 d85 2 d81
d87 2 d8a d8d
4 d90 d56 d72
d8f 1 d91 2
d94 d93 2 da7
da8 2 daa dad
2 db0 db1 2
db8 db9 2 dbb
dbe 2 dc3 dc4
1 dc8 2 dc6
dc8 6 dcd dce
dcf dd0 dd1 dd2
2 dd7 dd8 1
ddc 2 dda ddc
2 de7 de9 3
de5 de6 deb 2
df4 df6 2 df8
dfa 2 dfc dfe
1 e04 2 e06
e07 2 e00 e09
2 e0b e0d 2
e0f e11 2 e13
e15 2 e17 e19
2 df3 e1b 1
e1d 1 e1f 2
e29 e2b 3 e27
e28 e2d 2 e36
e38 2 e35 e3a
1 e3c 1 e3e
2 e44 e45 3
e47 e48 e49 3
e20 e3f e4b 1
e4d 2 e66 e6b
2 e7c e7e 3
e7a e7b e80 2
e89 e8b 2 e8d
e8f 2 e91 e93
2 e95 e97 2
e99 e9b 3 ea0
ea1 ea2 2 e9d
ea4 2 e88 ea6
1 ea8 1 eaa
2 e73 eab 1
eaf 1 e6e 1
eb3 1 ebe 2
eba ebe 1 ec2
2 ece ecf 1
ed3 2 ed1 ed3
1 ed8 1 eda
2 ecc edb 1
edd 1 ee7 2
ee5 ee7 3 eeb
eec eed 1 ef1
2 eef ef1 2
f10 f15 2 f26
f28 3 f24 f25
f2a 2 f33 f35
2 f37 f39 2
f3b f3d 2 f3f
f41 2 f43 f45
3 f4a f4b f4c
2 f47 f4e 2
f32 f50 1 f52
1 f54 2 f1d
f55 1 f59 1
f18 1 f5d 1
f68 2 f64 f68
2 f70 f71 1
f75 2 f73 f75
2 f7a f7b 1
f7f 2 f7d f7f
2 f9f fa4 2
fb5 fb7 3 fb3
fb4 fb9 2 fc2
fc4 2 fc6 fc8
2 fca fcc 2
fce fd0 2 fd2
fd4 3 fd9 fda
fdb 2 fd6 fdd
2 fc1 fdf 1
fe1 1 fe3 2
fac fe4 1 fe8
1 fa7 1 fec
1 fef 1 ff4
2 ff6 ff7 2
f6e ff8 1 1001
2 ffd 1001 2
1006 1007 1 100b
2 1009 100b 2
102b 1030 2 1041
1043 3 103f 1040
1045 2 104e 1050
2 1052 1054 2
1056 1058 2 105a
105c 2 105e 1060
3 1065 1066 1067
2 1062 1069 2
104d 106b 1 106d
1 106f 2 1038
1070 1 1074 1
1033 1 1078 1
107b 2 107f 107e
2 f60 1080 2
109c 10a1 2 10b2
10b4 3 10b0 10b1
10b6 2 10bf 10c1
2 10c3 10c5 2
10c7 10c9 2 10cb
10cd 2 10cf 10d1
3 10d6 10d7 10d8
2 10d3 10da 2
10be 10dc 1 10de
1 10e0 2 10a9
10e1 1 10e5 1
10a4 1 10e9 1
10ec 2 10ef 10f0
1 10f1 3 10f4
10f5 10f6 1 10fa
2 10f8 10fa 2
1116 111b 2 112c
112e 3 112a 112b
1130 2 1139 113b
2 113d 113f 2
1141 1143 2 1145
1147 2 1149 114b
3 1150 1151 1152
2 114d 1154 2
1138 1156 1 1158
1 115a 2 1123
115b 1 115f 1
111e 1 1163 1
116e 2 116a 116e
2 1176 1177 1
117b 2 1179 117b
2 1180 1181 1
1185 2 1183 1185
2 119f 11a4 2
11b5 11b7 3 11b3
11b4 11b9 2 11c2
11c4 2 11c6 11c8
2 11ca 11cc 2
11ce 11d0 2 11d2
11d4 3 11d9 11da
11db 2 11d6 11dd
2 11c1 11df 1
11e1 1 11e3 2
11ac 11e4 1 11e8
1 11a7 1 11ec
1 11ef 2 11f4
11f5 2 11f7 11f8
2 1174 11f9 1
1202 2 11fe 1202
2 121d 1222 2
1233 1235 3 1231
1232 1237 2 1240
1242 2 1244 1246
2 1248 124a 2
124c 124e 2 1250
1252 3 1257 1258
1259 2 1254 125b
2 123f 125d 1
125f 1 1261 2
122a 1262 1 1266
1 1225 1 126a
1 126d 2 1271
1270 2 1166 1272
2 128b 1290 2
12a1 12a3 3 129f
12a0 12a5 2 12ae
12b0 2 12b2 12b4
2 12b6 12b8 2
12ba 12bc 2 12be
12c0 3 12c5 12c6
12c7 2 12c2 12c9
2 12ad 12cb 1
12cd 1 12cf 2
1298 12d0 1 12d4
1 1293 1 12d8
1 12db 2 12de
12df 1 12e0 2
12e2 12e3 1 12eb
2 12e7 12eb 2
12f0 12f1 1 12f5
2 12f3 12f5 2
1300 1302 3 12fe
12ff 1304 2 130d
130f 2 1311 1313
2 1315 1317 1
131f 2 1321 1322
2 1319 1324 2
1326 1328 2 132a
132c 2 132e 1330
2 1332 1334 2
130c 1336 1 1338
1 133a 2 1344
1346 3 1342 1343
1348 2 1351 1353
2 1350 1355 1
1357 1 1359 3
1360 1361 1362 3
133b 135a 1364 1
1367 1 136e 2
136c 136e 2 1383
1388 2 1399 139b
3 1397 1398 139d
2 13a6 13a8 2
13aa 13ac 2 13ae
13b0 2 13b2 13b4
2 13b6 13b8 3
13bd 13be 13bf 2
13ba 13c1 2 13a5
13c3 1 13c5 1
13c7 2 1390 13c8
1 13cc 1 138b
1 13d0 2 1373
13d3 2 13e5 13ea
2 13fb 13fd 3
13f9 13fa 13ff 2
1408 140a 2 140c
140e 2 1410 1412
2 1414 1416 2
1418 141a 3 141f
1420 1421 2 141c
1423 2 1407 1425
1 1427 1 1429
2 13f2 142a 1
142e 1 13ed 1
1432 2 13d8 1435
2 1438 1439 2
143c 143d 2 1442
1443 1 1445 2
143f 1445 2 1450
1452 3 144e 144f
1454 2 145d 145f
2 1461 1463 2
1465 1467 1 146f
2 1471 1472 2
1469 1474 2 1476
1478 2 147a 147c
2 147e 1480 2
1482 1484 2 145c
1486 1 1488 1
148a 2 1494 1496
3 1492 1493 1498
2 14a1 14a3 2
14a0 14a5 1 14a7
1 14a9 3 14b0
14b1 14b2 3 148b
14aa 14b4 1 14b6
2 143a 14b7 2
14ba 14b9 2 14bb
14be 2 14c2 14c3
1 14c7 2 14c5
14c7 2 14cd 14ce
1 14d0 1 14d5
2 14d3 14d5 2
14e2 14e4 3 14e0
14e1 14e6 2 14ef
14f1 2 14f3 14f5
2 14f7 14f9 1
1501 2 1503 1504
2 14fb 1506 2
1508 150a 2 150c
150e 2 1510 1512
2 1514 1516 2
14ee 1518 1 151a
1 151c 2 1526
1528 3 1524 1525
152a 2 1533 1535
2 1532 1537 1
1539 1 153b 3
1542 1543 1544 3
151d 153c 1546 2
1549 1548 3 154c
154d 154e 1 1552
2 1550 1552 2
1557 1559 3 155b
155c 155d 2 1576
157b 2 158c 158e
3 158a 158b 1590
2 1599 159b 2
159d 159f 2 15a1
15a3 2 15a5 15a7
2 15a9 15ab 3
15b0 15b1 15b2 2
15ad 15b4 2 1598
15b6 1 15b8 1
15ba 2 1583 15bb
1 15bf 1 157e
1 15c3 1 15ce
2 15ca 15ce 2
15da 15dc 3 15d8
15d9 15de 2 15e7
15e9 2 15eb 15ed
2 15ef 15f1 1
15f9 2 15fb 15fc
2 15f3 15fe 2
1600 1602 2 1604
1606 2 1608 160a
2 160c 160e 2
15e6 1610 1 1612
1 1614 2 161e
1620 3 161c 161d
1622 2 162b 162d
2 162a 162f 1
1631 1 1633 3
163a 163b 163c 3
1615 1634 163e 1
1640 3 1643 1644
1645 1 1649 2
1647 1649 2 164e
164f 1 1653 2
1651 1653 2 1658
1659 2 165e 165f
1 1661 2 165b
1661 2 1672 1674
3 1670 1671 1676
2 167f 1681 2
1683 1685 2 1687
1689 1 1691 2
1693 1694 2 168b
1696 2 1698 169a
2 169c 169e 2
16a0 16a2 2 16a4
16a6 2 167e 16a8
1 16aa 1 16ac
2 16b6 16b8 3
16b4 16b5 16ba 2
16c3 16c5 2 16c2
16c7 1 16c9 1
16cb 3 16d2 16d3
16d4 3 16ad 16cc
16d6 1 16d8 2
16e6 16eb 2 16fc
16fe 3 16fa 16fb
1700 2 1709 170b
2 170d 170f 2
1711 1713 2 1715
1717 2 1719 171b
3 1720 1721 1722
2 171d 1724 2
1708 1726 1 1728
1 172a 2 16f3
172b 1 172f 1
16ee 1 1733 5
1560 15c6 1641 16d9
1736 2 173b 173d
3 173f 1740 1741
2 174a 174f 2
1760 1762 3 175e
175f 1764 2 176d
176f 2 1771 1773
2 1775 1777 2
1779 177b 2 177d
177f 3 1784 1785
1786 2 1781 1788
2 176c 178a 1
178c 1 178e 2
1757 178f 1 1793
1 1752 1 1797
1 17a2 2 179e
17a2 2 17ae 17b0
3 17ac 17ad 17b2
2 17bb 17bd 2
17bf 17c1 2 17c3
17c5 1 17cd 2
17cf 17d0 2 17c7
17d2 2 17d4 17d6
2 17d8 17da 2
17dc 17de 2 17e0
17e2 2 17ba 17e4
1 17e6 1 17e8
2 17f2 17f4 3
17f0 17f1 17f6 2
17ff 1801 2 17fe
1803 1 1805 1
1807 3 180e 180f
1810 3 17e9 1808
1812 1 1814 2
182a 182f 2 1840
1842 3 183e 183f
1844 2 184d 184f
2 1851 1853 2
1855 1857 2 1859
185b 2 185d 185f
3 1864 1865 1866
2 1861 1868 2
184c 186a 1 186c
1 186e 2 1837
186f 1 1873 1
1832 1 1877 1
1882 2 187e 1882
2 1887 1888 1
188c 2 188a 188c
2 189a 189c 3
1898 1899 189e 2
18a7 18a9 2 18ab
18ad 2 18af 18b1
1 18b9 2 18bb
18bc 2 18b3 18be
2 18c0 18c2 2
18c4 18c6 2 18c8
18ca 2 18cc 18ce
2 18a6 18d0 1
18d2 1 18d4 2
18de 18e0 3 18dc
18dd 18e2 2 18eb
18ed 2 18ea 18ef
1 18f1 1 18f3
3 18fa 18fb 18fc
3 18d5 18f4 18fe
1 1900 2 190e
1913 2 1924 1926
3 1922 1923 1928
2 1931 1933 2
1935 1937 2 1939
193b 2 193d 193f
2 1941 1943 3
1948 1949 194a 2
1945 194c 2 1930
194e 1 1950 1
1952 2 191b 1953
1 1957 1 1916
1 195b 6 1744
179a 1815 187a 1901
195e 2 1961 1962
2 1968 1969 1
196d 2 196b 196d
2 197a 197f 2
1990 1992 3 198e
198f 1994 2 199d
199f 2 19a1 19a3
2 19a5 19a7 2
19a9 19ab 2 19ad
19af 3 19b4 19b5
19b6 2 19b1 19b8
2 199c 19ba 1
19bc 1 19be 2
1987 19bf 1 19c3
1 1982 1 19c7
2 19d6 19db 2
19ec 19ee 3 19ea
19eb 19f0 2 19f9
19fb 2 19fd 19ff
2 1a01 1a03 2
1a05 1a07 2 1a09
1a0b 3 1a10 1a11
1a12 2 1a0d 1a14
2 19f8 1a16 1
1a18 1 1a1a 2
19e3 1a1b 1 1a1f
1 19de 1 1a23
2 1a2f 1a30 1
1a34 2 1a32 1a34
1 1a39 1 1a3b
20 1a3f 1a40 1a41
1a42 1a43 1a44 1a45
1a46 1a47 1a48 1a49
1a4a 1a4b 1a4c 1a4d
1a4e 1a4f 1a50 1a51
1a52 1a53 1a54 1a55
1a56 1a57 1a58 1a59
1a5a 1a5b 1a5c 1a5d
1a5e 1 1a64 2
1a62 1a64 2 1a68
1a69 1 1a6d 2
1a6b 1a6d 1 1a77
2 1a76 1a77 1
1a7f 1 1a85 2
1a87 1a88 2 1a74
1a89 2 1a9a 1a9c
3 1a98 1a99 1a9e
2 1aa7 1aa9 2
1aab 1aad 2 1aaf
1ab1 2 1ab3 1ab5
2 1ab7 1ab9 3
1abe 1abf 1ac0 2
1abb 1ac2 2 1aa6
1ac4 1 1ac6 1
1ac8 2 1a91 1ac9
1 1acd 1 1a8c
1 1ad1 1 1ad4
1 1ade 2 1add
1ade 1 1ae6 1
1aec 2 1aee 1aef
2 1adb 1af0 2
1b01 1b03 3 1aff
1b00 1b05 2 1b0e
1b10 2 1b12 1b14
2 1b16 1b18 2
1b1a 1b1c 2 1b1e
1b20 3 1b25 1b26
1b27 2 1b22 1b29
2 1b0d 1b2b 1
1b2d 1 1b2f 2
1af8 1b30 1 1b34
1 1af3 1 1b38
1 1b3b 2 1b3e
1b3f 1 1b40 1
1b42 7 19ca 1a26
1a2a 1a2d 1a3c 1a61
1b43 3 1b4c 1b4d
1b4e 1 1b52 2
1b50 1b52 1 1b59
2 1b5e 1b5f 2
1b61 1b64 1 1b67
2 1b69 1b6a 20
1b6e 1b6f 1b70 1b71
1b72 1b73 1b74 1b75
1b76 1b77 1b78 1b79
1b7a 1b7b 1b7c 1b7d
1b7e 1b7f 1b80 1b81
1b82 1b83 1b84 1b85
1b86 1b87 1b88 1b89
1b8a 1b8b 1b8c 1b8d
1 1b93 2 1b91
1b93 1 1b9d 2
1b9c 1b9d 1 1ba5
1 1bab 2 1bad
1bae 2 1b9a 1baf
2 1bc0 1bc2 3
1bbe 1bbf 1bc4 2
1bcd 1bcf 2 1bd1
1bd3 2 1bd5 1bd7
2 1bd9 1bdb 2
1bdd 1bdf 3 1be4
1be5 1be6 2 1be1
1be8 2 1bcc 1bea
1 1bec 1 1bee
2 1bb7 1bef 1
1bf3 1 1bb2 1
1bf7 1 1bfa 1
1bfd 5 1b47 1b4a
1b6b 1b90 1bfe 2
1c00 1c01 c dd5
e4e e51 eb6 ede
ee1 ee4 12e4 154a
1963 1966 1c02 1
1c06 2 1c08 1c09
1 1c0d 2 1c0b
1c0d 1 1c12 1
1c18 2 1c1a 1c1b
2 1c1d 1c1f 2
1c22 1c24 1 1c26
1 1c29 2 1c2b
1c2c 1 1c30 2
1c2e 1c30 2 1c38
1c39 1 1c3c 2
1c3b 1c3c 2 1c4c
1c4d 2 1c4f 1c51
2 1c53 1c55 4
1c49 1c4a 1c57 1c58
2 1c63 1c64 2
1c66 1c68 2 1c6a
1c6c 2 1c6e 1c70
4 1c60 1c61 1c72
1c73 2 1c91 1c96
2 1ca7 1ca9 3
1ca5 1ca6 1cab 2
1cb4 1cb6 2 1cb8
1cba 2 1cbc 1cbe
2 1cc0 1cc2 2
1cc4 1cc6 3 1ccb
1ccc 1ccd 2 1cc8
1ccf 2 1cb3 1cd1
1 1cd3 1 1cd5
2 1c9e 1cd6 1
1cda 1 1c99 1
1cde 2 1ce4 1ce5
1 1ce9 2 1ce7
1ce9 1 1ced 2
1cfb 1cfc 1 1d00
2 1cfe 1d00 1
1d05 1 1d07 2
1cf7 1d08 1 1d0a
3 1d0d 1d0e 1d0f
1 1d13 2 1d11
1d13 1 1d1d 2
1d1f 1d20 1 1d24
2 1d22 1d24 1
1d29 2 1d2d 1d2f
3 1d31 1d32 1d33
2 1d39 1d3b 3
1d3d 1d3e 1d3f 2
1d36 1d42 2 1d44
1d45 2 1d1a 1d46
1 1d4a 2 1d4c
1d4d 1 1d51 2
1d4f 1d51 1 1d56
2 1d5a 1d5c 3
1d5e 1d5f 1d60 2
1d66 1d68 3 1d6a
1d6b 1d6c 2 1d63
1d6f 2 1d71 1d72
1 1d73 2 1d75
1d76 2 1d7f 1d80
1 1d84 2 1d82
1d84 1 1d89 2
1d87 1d89 3 1d8d
1d8e 1d8f 1 1d93
2 1d91 1d93 2
1db2 1db7 2 1dc8
1dca 3 1dc6 1dc7
1dcc 2 1dd5 1dd7
2 1dd9 1ddb 2
1ddd 1ddf 2 1de1
1de3 2 1de5 1de7
3 1dec 1ded 1dee
2 1de9 1df0 2
1dd4 1df2 1 1df4
1 1df6 2 1dbf
1df7 1 1dfb 1
1dba 1 1dff 1
1e0a 2 1e06 1e0a
2 1e12 1e13 1
1e17 2 1e15 1e17
2 1e1c 1e1d 1
1e21 2 1e1f 1e21
2 1e41 1e46 2
1e57 1e59 3 1e55
1e56 1e5b 2 1e64
1e66 2 1e68 1e6a
2 1e6c 1e6e 2
1e70 1e72 2 1e74
1e76 3 1e7b 1e7c
1e7d 2 1e78 1e7f
2 1e63 1e81 1
1e83 1 1e85 2
1e4e 1e86 1 1e8a
1 1e49 1 1e8e
1 1e91 1 1e96
2 1e98 1e99 2
1e10 1e9a 1 1ea3
2 1e9f 1ea3 2
1ea8 1ea9 1 1ead
2 1eab 1ead 2
1ecd 1ed2 2 1ee3
1ee5 3 1ee1 1ee2
1ee7 2 1ef0 1ef2
2 1ef4 1ef6 2
1ef8 1efa 2 1efc
1efe 2 1f00 1f02
3 1f07 1f08 1f09
2 1f04 1f0b 2
1eef 1f0d 1 1f0f
1 1f11 2 1eda
1f12 1 1f16 1
1ed5 1 1f1a 1
1f1d 2 1f21 1f20
2 1e02 1f22 2
1f40 1f45 2 1f56
1f58 3 1f54 1f55
1f5a 2 1f63 1f65
2 1f67 1f69 2
1f6b 1f6d 2 1f6f
1f71 2 1f73 1f75
3 1f7a 1f7b 1f7c
2 1f77 1f7e 2
1f62 1f80 1 1f82
1 1f84 2 1f4d
1f85 1 1f89 1
1f48 1 1f8d 1
1f90 2 1f93 1f94
1 1f95 3 1f98
1f99 1f9a 1 1f9e
2 1f9c 1f9e 2
1fbc 1fc1 2 1fd2
1fd4 3 1fd0 1fd1
1fd6 2 1fdf 1fe1
2 1fe3 1fe5 2
1fe7 1fe9 2 1feb
1fed 2 1fef 1ff1
3 1ff6 1ff7 1ff8
2 1ff3 1ffa 2
1fde 1ffc 1 1ffe
1 2000 2 1fc9
2001 1 2005 1
1fc4 1 2009 1
2014 2 2010 2014
2 2019 201a 1
201e 2 201c 201e
2 2023 2024 1
2028 2 2026 2028
2 2044 2049 2
205a 205c 3 2058
2059 205e 2 2067
2069 2 206b 206d
2 206f 2071 2
2073 2075 2 2077
2079 3 207e 207f
2080 2 207b 2082
2 2066 2084 1
2086 1 2088 2
2051 2089 1 208d
1 204c 1 2091
1 2094 2 2099
209a 2 209c 209d
1 209e 1 20a7
2 20a3 20a7 2
20c4 20c9 2 20da
20dc 3 20d8 20d9
20de 2 20e7 20e9
2 20eb 20ed 2
20ef 20f1 2 20f3
20f5 2 20f7 20f9
3 20fe 20ff 2100
2 20fb 2102 2
20e6 2104 1 2106
1 2108 2 20d1
2109 1 210d 1
20cc 1 2111 1
2114 2 2118 2117
2 200c 2119 2
2134 2139 2 214a
214c 3 2148 2149
214e 2 2157 2159
2 215b 215d 2
215f 2161 2 2163
2165 2 2167 2169
3 216e 216f 2170
2 216b 2172 2
2156 2174 1 2176
1 2178 2 2141
2179 1 217d 1
213c 1 2181 1
2184 2 2187 2188
1 2189 2 218b
218c 1 2194 2
2190 2194 2 2199
219a 1 219e 2
219c 219e 1 21a3
1 21a5 1 21ac
2 21aa 21ac 2
21c1 21c6 2 21d7
21d9 3 21d5 21d6
21db 2 21e4 21e6
2 21e8 21ea 2
21ec 21ee 2 21f0
21f2 2 21f4 21f6
3 21fb 21fc 21fd
2 21f8 21ff 2
21e3 2201 1 2203
1 2205 2 21ce
2206 1 220a 1
21c9 1 220e 2
21b1 2211 2 2223
2228 2 2239 223b
3 2237 2238 223d
2 2246 2248 2
224a 224c 2 224e
2250 2 2252 2254
2 2256 2258 3
225d 225e 225f 2
225a 2261 2 2245
2263 1 2265 1
2267 2 2230 2268
1 226c 1 222b
1 2270 2 2216
2273 2 2276 2277
2 227a 227b 2
2280 2281 1 2283
2 227d 2283 2
2288 2289 2 228b
228d 2 2290 2292
1 2294 2 2278
2295 1 2297 2
2298 229b 2 229d
229e 1 229f 2
22a3 22a4 2 22a6
22a8 2 22ab 22ad
2 22af 22b0 2
22c2 22c7 2 22d8
22da 3 22d6 22d7
22dc 2 22e5 22e7
2 22e9 22eb 2
22ed 22ef 2 22f1
22f3 2 22f5 22f7
3 22fc 22fd 22fe
2 22f9 2300 2
22e4 2302 1 2304
1 2306 2 22cf
2307 1 230b 1
22ca 1 230f 2
231e 2323 2 2334
2336 3 2332 2333
2338 2 2341 2343
2 2345 2347 2
2349 234b 2 234d
234f 2 2351 2353
3 2358 2359 235a
2 2355 235c 2
2340 235e 1 2360
1 2362 2 232b
2363 1 2367 1
2326 1 236b 2
2377 2378 1 237c
2 237a 237c 1
2381 1 2383 20
2387 2388 2389 238a
238b 238c 238d 238e
238f 2390 2391 2392
2393 2394 2395 2396
2397 2398 2399 239a
239b 239c 239d 239e
239f 23a0 23a1 23a2
23a3 23a4 23a5 23a6
1 23ac 2 23aa
23ac 2 23b0 23b1
1 23b5 2 23b3
23b5 1 23bf 2
23be 23bf 1 23c7
1 23cd 2 23cf
23d0 2 23bc 23d1
2 23e2 23e4 3
23e0 23e1 23e6 2
23ef 23f1 2 23f3
23f5 2 23f7 23f9
2 23fb 23fd 2
23ff 2401 3 2406
2407 2408 2 2403
240a 2 23ee 240c
1 240e 1 2410
2 23d9 2411 1
2415 1 23d4 1
2419 1 241c 1
2426 2 2425 2426
1 242e 1 2434
2 2436 2437 2
2423 2438 2 2449
244b 3 2447 2448
244d 2 2456 2458
2 245a 245c 2
245e 2460 2 2462
2464 2 2466 2468
3 246d 246e 246f
2 246a 2471 2
2455 2473 1 2475
1 2477 2 2440
2478 1 247c 1
243b 1 2480 1
2483 2 2486 2487
1 2488 1 248a
b 218d 22b1 22b4
22b7 2312 236e 2372
2375 2384 23a9 248b
2 248f 2490 1
2494 2 2492 2494
3 249e 249f 24a0
1 24a4 2 24a2
24a4 1 24ab 2
24af 24b0 1 24b3
2 24b5 24b6 20
24ba 24bb 24bc 24bd
24be 24bf 24c0 24c1
24c2 24c3 24c4 24c5
24c6 24c7 24c8 24c9
24ca 24cb 24cc 24cd
24ce 24cf 24d0 24d1
24d2 24d3 24d4 24d5
24d6 24d7 24d8 24d9
1 24df 2 24dd
24df 1 24e9 2
24e8 24e9 1 24f1
1 24f7 2 24f9
24fa 2 24e6 24fb
2 250c 250e 3
250a 250b 2510 2
2519 251b 2 251d
251f 2 2521 2523
2 2525 2527 2
2529 252b 3 2530
2531 2532 2 252d
2534 2 2518 2536
1 2538 1 253a
2 2503 253b 1
253f 1 24fe 1
2543 1 2546 1
2549 5 2499 249c
24b7 24dc 254a 2
254d 254c 2 2551
2552 2 2554 2556
1 255a f 1c44
1c5b 1c76 1c79 1c7c
1c7f 1c82 1ce1 1d0b
1d77 1d7a 1d7d 254e
2559 255d 2 1c35
2560 1 2562 2
1c2d 2563 2 2565
2566 1 256a 2
2568 256a 2 256f
2570 1 2574 2
2572 2574 2 257b
257c 1 2580 2
257e 2580 1 2589
2 2588 2589 1
2591 1 2597 2
2599 259a 2 2586
259b 2 25ac 25ae
3 25aa 25ab 25b0
2 25b9 25bb 2
25bd 25bf 2 25c1
25c3 2 25c5 25c7
2 25c9 25cb 3
25d0 25d1 25d2 2
25cd 25d4 2 25b8
25d6 1 25d8 1
25da 2 25a3 25db
1 25df 1 259e
1 25e3 1 25e6
1 25f3 2 25f2
25f3 1 25fb 1
2601 2 2603 2604
2 25f0 2605 2
2616 2618 3 2614
2615 261a 2 2623
2625 2 2627 2629
2 262b 262d 2
262f 2631 2 2633
2635 3 263a 263b
263c 2 2637 263e
2 2622 2640 1
2642 1 2644 2
260d 2645 1 2649
1 2608 1 264d
1 2650 2 2653
2654 1 2658 2
2656 2658 2 2663
2665 3 2661 2662
2667 2 2670 2672
2 2674 2676 2
2678 267a 1 2682
2 2684 2685 2
267c 2687 2 2689
268b 2 268d 268f
2 2691 2693 2
2695 2697 2 266f
2699 1 269b 1
269d 2 26a7 26a9
3 26a5 26a6 26ab
2 26b4 26b6 2
26b3 26b8 1 26ba
1 26bc 3 26c3
26c4 26c5 3 269e
26bd 26c7 1 26ce
2 26ca 26ce 2
26d9 26db 3 26d7
26d8 26dd 2 26e6
26e8 2 26ea 26ec
2 26ee 26f0 1
26f8 2 26fa 26fb
2 26f2 26fd 2
26ff 2701 2 2703
2705 2 2707 2709
2 270b 270d 2
26e5 270f 1 2711
1 2713 2 271d
271f 3 271b 271c
2721 2 272a 272c
2 2729 272e 1
2730 1 2732 3
2739 273a 273b 3
2714 2733 273d 1
2745 2 2741 2745
2 2750 2752 3
274e 274f 2754 2
275d 275f 2 2761
2763 2 2765 2767
1 276f 2 2771
2772 2 2769 2774
2 2776 2778 2
277a 277c 2 277e
2780 2 2782 2784
2 275c 2786 1
2788 1 278a 2
2794 2796 3 2792
2793 2798 2 27a1
27a3 2 27a0 27a5
1 27a7 1 27a9
3 27b0 27b1 27b2
3 278b 27aa 27b4
2 27bf 27c1 3
27bd 27be 27c3 2
27cc 27ce 2 27d0
27d2 2 27d4 27d6
1 27de 2 27e0
27e1 2 27d8 27e3
2 27e5 27e7 2
27e9 27eb 2 27ed
27ef 2 27f1 27f3
2 27cb 27f5 1
27f7 1 27f9 2
2803 2805 3 2801
2802 2807 2 2810
2812 2 280f 2814
1 2816 1 2818
3 281f 2820 2821
3 27fa 2819 2823
4 2825 2740 27b6
2826 2 2655 2827
1 2829 1 282d
2 282f 2830 1
2834 2 2832 2834
1 283a 2 283c
283d 1 2841 2
283f 2841 2 2852
2854 2 2856 2858
2 285a 285c 2
285e 2860 2 2862
2864 2 2866 2868
2 286a 286c 2
286e 2870 2 2872
2874 2 2876 2878
2 287a 287c 2
287e 2880 1 288b
2 288a 288b 1
2893 1 2899 2
289b 289c 2 2888
289d 2 28ae 28b0
3 28ac 28ad 28b2
2 28bb 28bd 2
28bf 28c1 2 28c3
28c5 2 28c7 28c9
2 28cb 28cd 3
28d2 28d3 28d4 2
28cf 28d6 2 28ba
28d8 2 28df 28e1
2 28de 28e3 2
28da 28e5 1 28e7
2 28a5 28e8 1
28ec 1 28a0 1
28f0 2 2900 2902
2 2904 2906 2
2908 290a 2 290c
290e 2 2910 2912
2 2914 2916 2
2918 291a 2 291c
291e 2 2920 2922
2 2924 2926 2
2928 292a 2 292c
292e 1 2939 2
2938 2939 1 2941
1 2947 2 2949
294a 2 2936 294b
2 295c 295e 3
295a 295b 2960 2
2969 296b 2 296d
296f 2 2971 2973
2 2975 2977 2
2979 297b 3 2980
2981 2982 2 297d
2984 2 2968 2986
2 298d 298f 2
298c 2991 2 2988
2993 1 2995 2
2953 2996 1 299a
1 294e 1 299e
2 29ab 29ad 2
29af 29b1 2 29b3
29b5 2 29b7 29b9
2 29bb 29bd 2
29bf 29c1 2 29c3
29c5 2 29c7 29c9
2 29cb 29cd 2
29cf 29d1 2 29d3
29d5 2 29d7 29d9
2 29db 29dd 2
29df 29e1 2 29e3
29e5 2 29e7 29e9
2 29eb 29ed 2
29ef 29f1 2 29f3
29f5 2 29f7 29f9
2 29fb 29fd 2
29ff 2a01 2 2a03
2a05 2 2a07 2a09
2 2a0b 2a0d 2
2a0f 2a11 2 2a13
2a15 2 2a17 2a19
2 2a1b 2a1d 2
2a1f 2a21 2 2a23
2a25 2 2a27 2a29
2 2a2b 2a2d 2
2a2f 2a31 2 2a33
2a35 2 2a37 2a39
2 2a3b 2a3d 2
2a3f 2a41 1 2a4c
2 2a4b 2a4c 1
2a54 1 2a5a 2
2a5c 2a5d 2 2a49
2a5e 2 2a6f 2a71
3 2a6d 2a6e 2a73
2 2a7c 2a7e 2
2a80 2a82 2 2a84
2a86 2 2a88 2a8a
2 2a8c 2a8e 3
2a93 2a94 2a95 2
2a90 2a97 2 2a7b
2a99 2 2aa0 2aa2
2 2a9f 2aa4 2
2a9b 2aa6 1 2aa8
2 2a66 2aa9 1
2aad 1 2a61 1
2ab1 2 2ab7 2ab9
2 2abb 2abd 2
2abf 2ac1 2 2ac7
2ac8 1 2aca 2
2ac3 2acc 2 2ace
2ad0 2 2ad2 2ad4
2 2ada 2adb 1
2add 2 2ad6 2adf
2 2ae1 2ae3 2
2ae5 2ae7 2 2ae9
2aeb 2 2aed 2aef
2 2af1 2af3 2
2af5 2af7 2 2af9
2afb 2 2afd 2aff
2 2b01 2b03 2
2b09 2b0a 1 2b0c
2 2b05 2b0e 2
2b10 2b12 2 2b14
2b16 2 2b1c 2b1d
1 2b1f 2 2b18
2b21 2 2b23 2b25
2 2b27 2b29 2
2b2b 2b2d 2 2b2f
2b31 2 2b33 2b35
c 284b 2850 2883
28f3 28f9 28fe 2931
29a1 29a9 2a44 2ab4
2b38 1 2b3d 2
2b3f 2b40 1 2b44
2 2b42 2b44 2
2b52 2b54 2 2b56
2b58 2 2b5a 2b5c
2 2b5e 2b60 2
2b62 2b64 2 2b66
2b68 2 2b6a 2b6c
2 2b6e 2b70 2
2b72 2b74 2 2b76
2b78 1 2b83 2
2b82 2b83 1 2b8b
1 2b91 2 2b93
2b94 2 2b80 2b95
2 2ba6 2ba8 3
2ba4 2ba5 2baa 2
2bb3 2bb5 2 2bb7
2bb9 2 2bbb 2bbd
2 2bbf 2bc1 2
2bc3 2bc5 3 2bca
2bcb 2bcc 2 2bc7
2bce 2 2bb2 2bd0
2 2bd7 2bd9 2
2bd6 2bdb 2 2bd2
2bdd 1 2bdf 2
2b9d 2be0 1 2be4
1 2b98 1 2be8
2 2bf8 2bfa 2
2bfc 2bfe 2 2c00
2c02 2 2c04 2c06
2 2c08 2c0a 2
2c0c 2c0e 2 2c10
2c12 2 2c14 2c16
2 2c18 2c1a 1
2c25 2 2c24 2c25
1 2c2d 1 2c33
2 2c35 2c36 2
2c22 2c37 2 2c48
2c4a 3 2c46 2c47
2c4c 2 2c55 2c57
2 2c59 2c5b 2
2c5d 2c5f 2 2c61
2c63 2 2c65 2c67
3 2c6c 2c6d 2c6e
2 2c69 2c70 2
2c54 2c72 2 2c79
2c7b 2 2c78 2c7d
2 2c74 2c7f 1
2c81 2 2c3f 2c82
1 2c86 1 2c3a
1 2c8a 2 2c97
2c99 2 2c9b 2c9d
2 2c9f 2ca1 2
2ca3 2ca5 2 2ca7
2ca9 2 2cab 2cad
2 2caf 2cb1 2
2cb3 2cb5 2 2cb7
2cb9 2 2cbb 2cbd
2 2cbf 2cc1 2
2cc3 2cc5 2 2cc7
2cc9 2 2ccb 2ccd
2 2ccf 2cd1 2
2cd3 2cd5 2 2cd7
2cd9 2 2cdb 2cdd
1 2ce8 2 2ce7
2ce8 1 2cf0 1
2cf6 2 2cf8 2cf9
2 2ce5 2cfa 2
2d0b 2d0d 3 2d09
2d0a 2d0f 2 2d18
2d1a 2 2d1c 2d1e
2 2d20 2d22 2
2d24 2d26 2 2d28
2d2a 3 2d2f 2d30
2d31 2 2d2c 2d33
2 2d17 2d35 2
2d3c 2d3e 2 2d3b
2d40 2 2d37 2d42
1 2d44 2 2d02
2d45 1 2d49 1
2cfd 1 2d4d 2
2d53 2d55 2 2d57
2d59 2 2d5b 2d5d
2 2d63 2d64 1
2d66 2 2d5f 2d68
2 2d6a 2d6c 2
2d72 2d73 1 2d75
2 2d6e 2d77 2
2d79 2d7b 2 2d7d
2d7f 2 2d81 2d83
2 2d85 2d87 2
2d89 2d8b c 2b4b
2b50 2b7b 2beb 2bf1
2bf6 2c1d 2c8d 2c95
2ce0 2d50 2d8e 2
2d9c 2d9e 2 2da0
2da2 2 2da4 2da6
2 2da8 2daa 2
2dac 2dae 2 2db0
2db2 2 2db4 2db6
2 2db8 2dba 2
2dbc 2dbe 2 2dc0
2dc2 2 2dc4 2dc6
2 2dc8 2dca 1
2dd5 2 2dd4 2dd5
1 2ddd 1 2de3
2 2de5 2de6 2
2dd2 2de7 2 2df8
2dfa 3 2df6 2df7
2dfc 2 2e05 2e07
2 2e09 2e0b 2
2e0d 2e0f 2 2e11
2e13 2 2e15 2e17
3 2e1c 2e1d 2e1e
2 2e19 2e20 2
2e04 2e22 2 2e29
2e2b 2 2e28 2e2d
2 2e24 2e2f 1
2e31 2 2def 2e32
1 2e36 1 2dea
1 2e3a 2 2e4a
2e4c 2 2e4e 2e50
2 2e52 2e54 2
2e56 2e58 2 2e5a
2e5c 2 2e5e 2e60
2 2e62 2e64 2
2e66 2e68 2 2e6a
2e6c 1 2e77 2
2e76 2e77 1 2e7f
1 2e85 2 2e87
2e88 2 2e74 2e89
2 2e9a 2e9c 3
2e98 2e99 2e9e 2
2ea7 2ea9 2 2eab
2ead 2 2eaf 2eb1
2 2eb3 2eb5 2
2eb7 2eb9 3 2ebe
2ebf 2ec0 2 2ebb
2ec2 2 2ea6 2ec4
2 2ecb 2ecd 2
2eca 2ecf 2 2ec6
2ed1 1 2ed3 2
2e91 2ed4 1 2ed8
1 2e8c 1 2edc
2 2ee9 2eeb 2
2eed 2eef 2 2ef1
2ef3 2 2ef5 2ef7
2 2ef9 2efb 2
2efd 2eff 2 2f01
2f03 2 2f05 2f07
2 2f09 2f0b 2
2f0d 2f0f 2 2f11
2f13 2 2f15 2f17
2 2f19 2f1b 2
2f1d 2f1f 2 2f21
2f23 2 2f25 2f27
1 2f32 2 2f31
2f32 1 2f3a 1
2f40 2 2f42 2f43
2 2f2f 2f44 2
2f55 2f57 3 2f53
2f54 2f59 2 2f62
2f64 2 2f66 2f68
2 2f6a 2f6c 2
2f6e 2f70 2 2f72
2f74 3 2f79 2f7a
2f7b 2 2f76 2f7d
2 2f61 2f7f 2
2f86 2f88 2 2f85
2f8a 2 2f81 2f8c
1 2f8e 2 2f4c
2f8f 1 2f93 1
2f47 1 2f97 2
2f9d 2f9f 2 2fa1
2fa3 2 2fa5 2fa7
2 2fad 2fae 1
2fb0 2 2fa9 2fb2
2 2fb4 2fb6 2
2fb8 2fba 2 2fc0
2fc1 1 2fc3 2
2fbc 2fc5 2 2fc7
2fc9 2 2fcb 2fcd
2 2fcf 2fd1 2
2fd3 2fd5 2 2fd7
2fd9 c 2d95 2d9a
2dcd 2e3d 2e43 2e48
2e6f 2edf 2ee7 2f2a
2f9a 2fdc 3 2fde
2d90 2fdf 2 2fe9
2feb 3 2fe7 2fe8
2fed 2 2ff6 2ff8
2 2ff5 2ffa 1
2ffc 1 2ffe 2
3008 300a 3 3006
3007 300c 2 3015
3017 2 3014 3019
1 301b 1 301d
1 3023 2f 2fa
319 31c 31f 322
325 328 32b 32e
331 334 337 33a
33d 340 343 346
349 34c 356 359
35c 35f 3c3 427
49b 50f 58d 6d6
6d9 6e4 6ec 6f4
6f7 be6 d95 d9a
d9d da0 db4 dc1
2567 282a 2fe0 2fff
301e 3026 2 3033
3035 3 3031 3032
3037 2 3040 3042
2 303f 3044 2
304b 304f 2 3051
3053 2 3055 3059
2 304a 305b 2
3046 305d 1 305f
3 3060 306b 306f
1 302a 2 3082
3084 3 3080 3081
3086 2 308f 3091
2 308e 3093 2
309a 309c 2 309e
30a0 3 30a5 30a6
30a7 2 30a2 30a9
2 3099 30ab 2
3095 30ad 1 30af
4 3079 30b0 30b9
30bd 1 30c1 1
3074 2 3072 30c5
44 4b 52 59
60 67 6e 75
7c 83 8a 8f
94 9b a2 a9
b0 b7 be c4
ca d0 d6 dc
e2 e8 ee f4
fa 100 106 10c
112 118 11e 124
12a 130 136 13c
142 148 14e 154
15a 160 166 16d
174 17a 181 187
18e 195 19c 1a2
1a8 1ae 1b5 1bc
1c2 1c8 1cf 1d5
1db 1e1 1e7 1ec
1f3 
1
4
0 
30cc
0
1
a0
77
55
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 1 36 1
38 1 3a 1 3c 1 3e 1
40 41 40 43 40 45 40 47
40 49 40 4b 40 4d 40 4f
40 51 40 53 40 55 40 57
40 59 40 5b 40 5d 40 5f
1 61 1 63 1 65 1 67
1 69 1 6b 1 6d 1 6f
1 71 1 73 1 75 1 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3b 1 0
13e 1 0
2b 1 0
183 1 0
1dd 1 0
162 1 0
2f 1 0
1c4 1 0
ab 1 0
1ca 1 0
fc 1 0
15c 1 0
d8 1 0
1d7 1 0
27 1 0
189 1 0
1f 1 0
1b 1 0
1e3 1 0
96 1 0
255a 40 61
c0 1 0
9d 1 0
11a 1 0
17c 1 0
12c 1 0
8c 1 0
1e9 1 0
1a4 1 0
13 1 0
f6 1 0
1b0 1 0
ea 1 0
7e 1 0
16f 1 0
168 1 0
a4 1 0
77 1 0
f 1 0
e4 1 0
70 1 0
5b 1 0
3 1 0
c6 1 0
150 1 0
14a 1 0
1b7 1 0
85 1 0
19e 1 0
138 1 0
2 0 1
114 1 0
108 1 0
23 1 0
144 1 0
54 1 0
1d1 1 0
156 1 0
7 1 0
176 1 0
f0 1 0
de 1 0
132 1 0
d2 1 0
197 1 0
1be 1 0
1aa 1 0
cc 1 0
69 1 0
46 1 0
10e 1 0
37 1 0
4d 1 0
b2 1 0
120 1 0
17 1 0
91 1 0
b9 1 0
126 1 0
62 1 0
33 1 0
102 1 0
b 1 0
1ee 1 0
190 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_1;
ALTER FUNCTION SP_SEARCH_1 COMPILE DEBUG;
/*######################################################################################*/
/*######################################################################################*/
/*
#Stored Procedure  :SP_SEARCH_3
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_SEARCH_3 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_3 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1b1
2 :e:
1FUNCTION:
1SP_SEARCH_3:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1TYPE001:
1AND_ROLES:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PROJECT_ID:
132:
1H_TASK_ID:
1H_REC_USER:
1H_RES_ID:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_REC_STATUS:
11:
1H_RES_TYPE:
1H_PA_TIMEPHASE:
1H_ASSIGN_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_AND_ROLES:
18000:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_SD:
1H_FD:
1H_FULL_NAME:
1255:
1H_COUNT:
10:
1H_BITFLAG:
1H_TYPE:
1H_UPDATE:
1H_WORK_TYPE:
1H_CRI:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_DAYS:
1H_DURATION:
1H_NUMBER:
1H_TOTAL:
1H_TOTPR:
1H_PRIORITY:
1H_WEEK:
1H_RES_COST:
1NUMBER:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_REG_COST:
10.00:
1H_REG_SALE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1STMT:
17999:
1H_TABLE_TYPE:
1H_TEMP_VAR:
1I:
1II:
1I_RETURN:
1ISF:
1NUMITEMS:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_3(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1103:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_3(104) :: cplan.sql(4427) :: :
1GETTABLE:
1IS NULL:
18:
1140:
1      RETURN_INVALID:: SP_SEARCH_3(141) :: cplan.sql(4464) :: :
1 :
1STATE:: :
1PMO_CNST:
1ELEMENT_ID_REQUIRED:
1143:
1                EXIT:: SP_SEARCH_3(144) :: cplan.sql(4467) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1IS NOT NULL:
1LENGTH:
1<:
114:
1150:
1      RETURN_INVALID:: SP_SEARCH_3(151) :: cplan.sql(4474) :: :
1INVALID_PARAMS:
1153:
1                EXIT:: SP_SEARCH_3(154) :: cplan.sql(4477) :: :
1160:
1      RETURN_INVALID:: SP_SEARCH_3(161) :: cplan.sql(4484) :: :
1163:
1                EXIT:: SP_SEARCH_3(164) :: cplan.sql(4487) :: :
1=:
15:
1170:
1      RETURN_INVALID:: SP_SEARCH_3(171) :: cplan.sql(4494) :: :
1173:
1                EXIT:: SP_SEARCH_3(174) :: cplan.sql(4497) :: :
1!=:
1SC_SRCH_PARTICIPANT:
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1190:
1           EXCEPTION:: SP_SEARCH_3(191) :: cplan.sql(4514) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1197:
1      RETURN_INVALID:: SP_SEARCH_3(198) :: cplan.sql(4521) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1200:
1                EXIT:: SP_SEARCH_3(201) :: cplan.sql(4524) :: :
1ELSIF:
1SELECT SYSTIMESTAMP INTO h_start_date:n         FROM DUAL:
1216:
1           EXCEPTION:: SP_SEARCH_3(217) :: cplan.sql(4540) :: :
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n         INTO h_per_day, h_per_week, h_priority:n         FROM TMT_WBS WH+
1ERE ELEMENT_ID = h_project_id:
1240:
1           EXCEPTION:: SP_SEARCH_3(241) :: cplan.sql(4564) :: :
1SC_SQL_NO_DATA:
1TMT_POOLS:
1SELECT 480, 2400, 0 INTO h_per_day, h_per_week, h_priority FROM TMT_POOLS WHE+
1RE ELEMENT_ID = h_project_id:
1254:
1           EXCEPTION:: SP_SEARCH_3(255) :: cplan.sql(4578) :: :
1260:
1        RETURN_ERROR:: SP_SEARCH_3(261) :: cplan.sql(4584) :: :
1 ID:: :
1263:
1                EXIT:: SP_SEARCH_3(264) :: cplan.sql(4587) :: :
1PMO_RETURN_ERROR_SP:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1PROJECT_ID:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1280:
1           EXCEPTION:: SP_SEARCH_3(281) :: cplan.sql(4604) :: :
1>:
1REC_STATUS:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1296:
1           EXCEPTION:: SP_SEARCH_3(297) :: cplan.sql(4620) :: :
1STRCMP:
1L:
1303:
1        RETURN_ERROR:: SP_SEARCH_3(304) :: cplan.sql(4627) :: :
1LEV_LOCKED_BY_COPY:
1306:
1                EXIT:: SP_SEARCH_3(307) :: cplan.sql(4630) :: :
1314:
1      RETURN_INVALID:: SP_SEARCH_3(315) :: cplan.sql(4638) :: :
1317:
1                EXIT:: SP_SEARCH_3(318) :: cplan.sql(4641) :: :
1PMO_STPU:
1STRNPCPY:
133:
1ISPROJECTTYPE:
1TYPE_ID:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1SELECT PROJECT_ID, COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2+
1400), PRIORITY:n            INTO h_project_id, h_per_day, h_per_week, h_prior+
1ity:n            FROM TMT_WBS WHERE ELEMENT_ID = h_task_id AND TYPE_ID IN (PM+
1O_CNST.SC_PROJECT,PMO_CNST.SC_PROPOSAL,PMO_CNST.SC_PROJ_TYPE1,PMO_CNST.SC_PRO+
1J_TYPE2,PMO_CNST.SC_PROJ_TYPE3):
1343:
1           EXCEPTION:: SP_SEARCH_3(344) :: cplan.sql(4667) :: :
1350:
1        RETURN_ERROR:: SP_SEARCH_3(351) :: cplan.sql(4674) :: :
1RECORD_NOT_FOUND:
1353:
1                EXIT:: SP_SEARCH_3(354) :: cplan.sql(4677) :: :
1359:
1        RETURN_ERROR:: SP_SEARCH_3(360) :: cplan.sql(4683) :: :
1362:
1                EXIT:: SP_SEARCH_3(363) :: cplan.sql(4686) :: :
1100:
1:
1FC_CALC_DURATION:
1385:
1      RETURN_INVALID:: SP_SEARCH_3(386) :: cplan.sql(4709) :: :
1388:
1                EXIT:: SP_SEARCH_3(389) :: cplan.sql(4712) :: :
1393:
1        RETURN_ERROR:: SP_SEARCH_3(394) :: cplan.sql(4717) :: :
1396:
1                EXIT:: SP_SEARCH_3(397) :: cplan.sql(4720) :: :
12:
13:
14:
1*:
15000:
1418:
1        RETURN_ERROR:: SP_SEARCH_3(419) :: cplan.sql(4742) :: :
1CANNOT_SEARCH_ASSIGN:
1421:
1                EXIT:: SP_SEARCH_3(422) :: cplan.sql(4745) :: :
150:
1TRUNC:
11.5:
1FC_DECLARE_PMO_TMP_SEARCH:
1TSK_ASSIGNMENT_ID:
1TO_DATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TASK_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n            REG+
1ULAR_COST, REGULAR_RATE:n            INTO h_prj_assignment_id, h_SD, h_FD, h_+
1billable, h_capital_expense,:n            h_reg_cost, h_reg_sale:n           +
1 FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project_id AND RESOURCE_I+
1D=h_res_id AND RESOURCE_TYPE='1' AND BIT_FLAG='0':
1472:
1           EXCEPTION:: SP_SEARCH_3(473) :: cplan.sql(4796) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME INTO h_full_name FROM PROFILES WHERE PROFILE_ID = h_res_i+
1d:
1485:
1           EXCEPTION:: SP_SEARCH_3(486) :: cplan.sql(4809) :: :
1492:
1        RETURN_ERROR:: SP_SEARCH_3(493) :: cplan.sql(4816) :: :
1495:
1                EXIT:: SP_SEARCH_3(496) :: cplan.sql(4819) :: :
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1RESOURCE_ASSIGNMENTS:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_assign_id, h_number:n           +
1 FROM RESOURCE_ASSIGNMENTS:n            WHERE ELEMENT_ID = h_task_id AND RESO+
1URCE_TYPE = '1' AND RESOURCE_ID = h_res_id:
1512:
1           EXCEPTION:: SP_SEARCH_3(513) :: cplan.sql(4836) :: :
1NICK_NAME:
1RESOURCES:
1SELECT NICK_NAME INTO h_full_name FROM RESOURCES WHERE RESOURCE_ID = h_res_id:
1525:
1           EXCEPTION:: SP_SEARCH_3(526) :: cplan.sql(4849) :: :
1532:
1        RETURN_ERROR:: SP_SEARCH_3(533) :: cplan.sql(4856) :: :
1535:
1                EXIT:: SP_SEARCH_3(536) :: cplan.sql(4859) :: :
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n            REG+
1ULAR_COST, REGULAR_RATE:n            INTO h_prj_assignment_id, h_SD, h_FD, h_+
1billable, h_capital_expense,:n            h_reg_cost, h_reg_sale:n           +
1 FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project_id AND RESOURCE_I+
1D=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='0':
1555:
1           EXCEPTION:: SP_SEARCH_3(556) :: cplan.sql(4879) :: :
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n               +
1REGULAR_COST, REGULAR_RATE:n               INTO h_prj_assignment_id, h_SD, h_+
1FD, h_billable, h_capital_expense,:n               h_reg_cost, h_reg_sale:n  +
1             FROM TASK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_id+
1 AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
1586:
1           EXCEPTION:: SP_SEARCH_3(587) :: cplan.sql(4910) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_assign_id, h_number:n           +
1 FROM RESOURCE_ASSIGNMENTS:n            WHERE ELEMENT_ID = h_task_id AND RESO+
1URCE_TYPE = '0' AND RESOURCE_ID = h_res_id:
1603:
1           EXCEPTION:: SP_SEARCH_3(604) :: cplan.sql(4927) :: :
1609:
1      RETURN_INVALID:: SP_SEARCH_3(610) :: cplan.sql(4933) :: :
1612:
1                EXIT:: SP_SEARCH_3(613) :: cplan.sql(4936) :: :
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1SC_PARTICIPANT_GROUP:
1SECURITY_ID:
1ELEMENT_TYPE:
1SC_AFFECTED:
1SC_TEAMMEMBER:
1BIT_OR:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT =:n            CASE:n            +
1WHEN SECURITY_ID = h_temp2_security_id AND ELEMENT_TYPE IN (PMO_CNST.SC_PROJE+
1CT,PMO_CNST.SC_PROPOSAL,PMO_CNST.SC_PROJ_TYPE1,PMO_CNST.SC_PROJ_TYPE2,PMO_CNS+
1T.SC_PROJ_TYPE3) THEN PMO_CNST.SC_AFFECTED:n            WHEN SECURITY_ID = h_+
1temp2_security_id THEN PMO_CNST.SC_TEAMMEMBER:n            WHEN SECURITY_ID =+
1 h_temp_security_id THEN PMO_CNST.SC_AFFECTED:n            ELSE PMO_STPU.BIT_+
1OR( PARTICIPANT, PMO_CNST.SC_TEAMMEMBER):n            END, SECURITY_ID =:n   +
1         CASE:n            WHEN SECURITY_ID = h_temp2_security_id THEN  h_tem+
1p_security_id:n            ELSE SECURITY_ID:n            END:n            WHE+
1RE RES_ASSIGNMENT_ID = h_assign_id:
1FOUND:
1647:
1           EXCEPTION:: SP_SEARCH_3(648) :: cplan.sql(4971) :: :
1FC_AFTER_U_RES_ASSIGN:
1SYS_GUID:
1FC_BEFORE_I_RES_ASSIGN:
1TABLE_TYPE:
1REC_USER:
1REC_DATETIME:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE, TABLE_TYPE,:n            RESOURCE_TYPE, RESOURCE_ID, PARTICIPANT+
1, SECURITY_ID, REC_USER, REC_DATETIME):n            VALUES (h_assign_id, h_pr+
1oject_id, h_task_id, h_type, h_table_type,:n            h_res_type, h_res_id,+
1 PMO_CNST.SC_AFFECTED, h_temp_security_id, rec_user001, SYSTIMESTAMP):
1681:
1           EXCEPTION:: SP_SEARCH_3(682) :: cplan.sql(5005) :: :
1TIMEPHASE_PROJECT_ASSIGNMENT:
1SELECT TIMEPHASE_PROJECT_ASSIGNMENT INTO h_pa_timephase FROM PROJECT_DETAILS +
1WHERE PROJECT_ID = h_project_id:
1697:
1           EXCEPTION:: SP_SEARCH_3(698) :: cplan.sql(5021) :: :
1Y:
1-:
1FC_TPHASE_SCHED_ASSIGN:
1SC_SRCH_PROFILE:
1FC_SEARCH_2:
1PMO_TMP_SEARCH:
1PLANNED_SCHED_FLAG:
1RES_ID:
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='0' WHERE RES_ID=h_res_id:
1744:
1           EXCEPTION:: SP_SEARCH_3(745) :: cplan.sql(5068) :: :
1/:
1WHILE:
1LOOP:
1',':
1BAK_START_DT:
1BAK_FINISH_DT:
1TO_TIMESTAMP:
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(+
1BAK_START_DT, 1, 10)) AND TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)):n            +
1      THEN BAK_START_DT + 1      ELSE TO_TIMESTAMP(h_start_date) END:n       +
1           INTO h_start_DT FROM TASK_ASSIGNMENTS:n                  WHERE TAS+
1K_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1':
1802:
1           EXCEPTION:: SP_SEARCH_3(803) :: cplan.sql(5126) :: :
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(+
1BAK_START_DT, 1, 10)) AND TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)):n            +
1      THEN BAK_START_DT + 1      ELSE TO_TIMESTAMP(h_start_date) END:n       +
1           INTO h_start_DT FROM TASK_ASSIGNMENTS:n                  WHERE TAS+
1K_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG+
1='0':
1822:
1           EXCEPTION:: SP_SEARCH_3(823) :: cplan.sql(5146) :: :
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(+
1BAK_START_DT, 1, 10)) AND TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)):n            +
1         THEN BAK_START_DT + 1      ELSE TO_TIMESTAMP(h_start_date) END:n    +
1                 INTO h_start_DT FROM TASK_ASSIGNMENTS:n                     +
1WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND+
1 BIT_FLAG='2':
1839:
1           EXCEPTION:: SP_SEARCH_3(840) :: cplan.sql(5163) :: :
1877:
1           EXCEPTION:: SP_SEARCH_3(878) :: cplan.sql(5201) :: :
1891:
1        RETURN_ERROR:: SP_SEARCH_3(892) :: cplan.sql(5215) :: :
1CANNOT_ASSIGN_FROM_PROJECT_AFF:
1894:
1                EXIT:: SP_SEARCH_3(895) :: cplan.sql(5218) :: :
1SELECT t.RESOURCE_ID AS ELEMENT_ID, t.RES_ASSIGNMENT_ID, p.FULL_NAME AS ELEME+
1NT_NAME, 13 AS TYPE_ID, :
1p.E_MAIL_ADDRESS,b.PLANNED_START,b.PLANNED_FINISH,b.BEST AS PLANNED_EFFORT, :
1a.SCHED_START AS START_DATE, a.SCHED_FINISH AS FINISH_DATE, a.BEST AS WORK, a+
1.SCHED_WORK AS REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR,rs.PLANNED AS PLANNED_WORK,:
1rs.SCHED AS SCHED_WORK, :
1 AS WORK_EFFORT, :
1 AS UNIT_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILIT+
1Y,:
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, rs.PLANNED_SCHED_FLAG, '' AS+
1 OBJECTIVES,'' AS RANK :
1FROM RESOURCE_ASSIGNMENTS t LEFT JOIN TASK_ASSIGNMENTS a ON a.RES_ASSIGNMENT_+
1ID=t.RES_ASSIGNMENT_ID AND a.BIT_FLAG='2' :
1LEFT JOIN TASK_ASSIGNMENTS b ON b.RES_ASSIGNMENT_ID=t.RES_ASSIGNMENT_ID AND b+
1.BIT_FLAG='0' :
1JOIN RESOURCES p ON t.RESOURCE_ID=p.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON t.RESOURCE_ID=rs.RES_ID :
1WHERE t.ELEMENT_ID=':
1' AND t.RESOURCE_TYPE='0' AND t.RESOURCE_ID IN (':
1') AND BITAND(t.PARTICIPANT, 4112) > 0 :
1UNION ALL :
1SELECT r.PROFILE_ID AS ELEMENT_ID, ta.RES_ASSIGNMENT_ID, r.PROFILE_NAME AS EL+
1EMENT_NAME, 41 AS TYPE_ID, :
1'' AS E_MAIL_ADDRESS,ta.PLANNED_START,ta.PLANNED_FINISH,ta.BEST AS PLANNED_EF+
1FORT,:
1STR_1899_12_31_00_00_00:
1 AS START_DATE, :
1 AS FINISH_DATE, 0 AS WORK, 0 AS REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR, :
1rs.PLANNED AS PLANNED_WORK,rs.SCHED AS SCHED_WORK, :
1 AS UNIT_EFFORT,:
1(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY , rs.CONTOUR AS ASSIGN_STRING, rs.PLANNED_SCHED_FLAG, '' A+
1S OBJECTIVES,'' AS RANK :
1FROM TASK_ASSIGNMENTS ta JOIN PROFILES r ON ta.TASK_ID=':
1' AND ta.RESOURCE_TYPE='1' AND ta.RESOURCE_ID IN (':
1') AND r.PROFILE_ID=ta.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON ta.RESOURCE_ID=rs.RES_ID :
1ORDER BY TYPE_ID:
1980:
1                EXIT:: SP_SEARCH_3(981) :: cplan.sql(5304) :: :
1983:
1                EXIT:: SP_SEARCH_3(984) :: cplan.sql(5307) :: :
1PMO_SELECT_READ:
1RETURN_ERROR_EXCEPTION:
1991:
1           EXCEPTION:: SP_SEARCH_3(992) :: cplan.sql(5315) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11003:
1           EXCEPTION:: SP_SEARCH_3(1004) :: cplan.sql(5327) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
1a9e
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 :2 a0 6b 1c 81 b0 :2 a0
6b :2 a0 6b 6e a5 b a 10
:2 a0 6b 6e :2 a0 6b 6e a5 b
6e 7e a0 b4 2e 6e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :4 a0 51
a5 b a5 b d a0 51 d
a0 51 d a0 7e b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c a0 7e b4 2e 5a :3 a0
a5 b 51 a5 b 7e 51 b4
2e 5a a 10 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 19 3c a0
7e b4 2e 5a :3 a0 a5 b 51
a5 b 7e 51 b4 2e 5a a
10 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 51
a5 b 7e 51 b4 2e a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c :2 a0 51 a5 b a0 7e
a0 6b b4 2e 5a a0 7e b4
2e :2 5a a 10 a0 7e b4 2e
:2 5a a 10 :8 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c a0 51 d a0
b7 a0 7e b4 2e :2 5a a0 7e
b4 2e :2 5a a 10 :3 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 d :3 a0 6b :3 a0
51 a5 b :2 a0 6b a5 b 5a
51 a5 b d :4 a0 51 a5 b
:2 a0 6b a5 b 5a d :2 a0 51
a5 b 7e 51 b4 2e :b a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :6 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 19 3c a0 51 d :5 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 6e
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 19 3c b7 a0 7e b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c :2 a0 d :4 a0 :2 51 a5
b :2 51 a5 b d :3 a0 6b :3 51
a0 a5 b d :3 a0 51 a5 b
a5 b 7e 51 b4 2e :18 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c b7 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 19 3c b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 a0 51
d b7 19 3c a0 7e 51 b4
2e :2 a0 d a0 6e d :6 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :3 a0 a5
b d :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 b7 :2 19 3c
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a 52 10 a0 51 d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
a0 51 d a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
52 10 a0 51 d a0 b7 19
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d a0 51 d b7
:2 19 3c b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e a0
51 d b7 :4 a0 51 a5 b 7e
51 b4 2e a5 b d b7 :2 19
3c b7 19 3c :2 a0 b4 2e d
a0 6e d a0 6e d a0 6e
d a0 6e d :3 a0 :2 51 a5 b
d :3 a0 :2 51 a5 b d :2 a0 51
a5 b 7e 51 b4 2e a0 4d
d :2 a0 d :2 a0 :2 51 a5 b 7e
6e b4 2e :19 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :5 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :2 a0 d :a a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 :2 a0 :2 51 a5 b 7e
6e b4 2e :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :2 a0 d :19 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :19 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c :a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 51 :2 a0
51 a5 b :2 a0 6b a0 a5 b
d :2 a0 51 :2 a0 51 a5 b :2 a0
6b a0 a5 b d :25 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 a5
b d b7 :2 a0 b4 2e d :2 a0
51 :2 a0 51 a5 b :2 a0 6b a0
a5 b d :3 a0 6b d a0 51
d :9 a0 a5 b d :18 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e 5a a0 7e b4 2e :2 5a a
10 :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 :2 51 a5 b
7e 6e b4 2e a0 7e 51 b4
2e d :2 a0 6b :b a0 a5 b d
b7 19 3c b7 19 3c :2 a0 d
:2 a0 :2 51 a5 b 7e 6e b4 2e
:3 a0 6b d b7 :3 a0 51 a5 b
d b7 :2 19 3c :1e a0 :4 51 a5 b
d a0 7e 51 b4 2e :4 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 3c b7 a0 6e d a0 6e
d :2 a0 d :3 a0 a5 b 51 a5
b 7e 51 b4 2e a0 51 d
b7 :5 a0 a5 b 51 a5 b 7e
51 b4 2e 5a 7e 51 b4 2e
a5 b d b7 :2 19 3c a0 7e
51 b4 2e a0 51 d :3 a0 51
a5 b a0 7e a0 b4 2e 82
:3 a0 6b :2 51 :2 a0 51 a5 b 7e
51 b4 2e 7e 51 b4 2e a0
a5 b d :3 a0 6b :2 51 :2 a0 51
a5 b 7e 51 b4 2e 7e 51
b4 2e 7e 51 b4 2e a0 a5
b d :2 a0 :2 51 a5 b 7e 6e
b4 2e :3 a0 6b d :3 a0 a5 b
51 a5 b 7e 51 b4 2e :2 a0
d b7 :3 a0 7e 6e b4 2e :2 51
a5 b d :3 a0 7e a0 b4 2e
:2 51 a5 b d b7 :2 19 3c b7
:3 a0 51 a5 b d :3 a0 a5 b
51 a5 b 7e 51 b4 2e :2 a0
d b7 :3 a0 7e 6e b4 2e :2 51
a5 b d :3 a0 7e a0 b4 2e
:2 51 a5 b d b7 :2 19 3c b7
:2 19 3c :2 a0 :2 51 a5 b 7e 6e
b4 2e :13 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 51 d
a0 51 d b7 :14 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:14 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c b7 :2 19
3c :2 a0 d :2 a0 :2 51 a5 b 7e
6e b4 2e :3 a0 6b d b7 :3 a0
51 a5 b d b7 :2 19 3c :2 a0
d :1e a0 :4 51 a5 b d a0 7e
51 b4 2e :4 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c :3 a0
51 a5 b 7e 51 b4 2e d
b7 a0 47 b7 19 3c b7 :2 19
3c a0 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 d b7 19
3c :3 a0 a5 b 51 a5 b 7e
51 b4 2e 5a :3 a0 a5 b 51
a5 b 7e 51 b4 2e 5a a
10 a0 6e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 51 a5 b
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 51 a5 b a5 b b4
2e 7e 6e b4 2e 7e :3 a0 51
a5 b a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e :3 a0 51 a5 b a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 51 a5 b a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e d a0 b7 :3 a0 a5
b 51 a5 b 7e 51 b4 2e
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 51 a5 b a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e d a0 b7 19 :3 a0 a5 b
51 a5 b 7e 51 b4 2e a0
6e 7e 6e b4 2e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 51
a5 b a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e d b7
:2 19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 6b a0 a5 b 65 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
1a9e
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 16a 155
159 15c 15d 165 154 187 175 151
179 17a 182 174 1a4 192 171 196
197 19f 191 1c1 1af 18e 1b3 1b4
1bc 1ae 1de 1cc 1ab 1d0 1d1 1d9
1cb 1fb 1e9 1c8 1ed 1ee 1f6 1e8
218 206 1e5 20a 20b 213 205 234
223 227 22f 202 250 23b 23f 242
243 24b 222 26d 25b 21f 25f 260
268 25a 28a 278 257 27c 27d 285
277 2a7 295 274 299 29a 2a2 294
2c4 2b2 291 2b6 2b7 2bf 2b1 2e1
2cf 2ae 2d3 2d4 2dc 2ce 2fe 2ec
2cb 2f0 2f1 2f9 2eb 31b 309 2e8
30d 30e 316 308 337 326 32a 332
305 34f 33e 342 34a 325 36c 35a
322 35e 35f 367 359 388 377 37b
356 383 376 3a4 393 397 373 39f
392 3c0 3af 3b3 38f 3bb 3ae 3dc
3cb 3cf 3ab 3d7 3ca 3f8 3e7 3eb
3c7 3f3 3e6 414 403 407 3e3 40f
402 430 41f 423 3ff 42b 41e 44c
43b 43f 41b 447 43a 468 457 45b
437 463 456 484 473 477 453 47f
472 4a0 48f 493 46f 49b 48e 4bc
4ab 4af 48b 4b7 4aa 4d8 4c7 4cb
4a7 4d3 4c6 4f4 4e3 4e7 4c3 4ef
4e2 510 4ff 503 4df 50b 4fe 52c
51b 51f 4fb 527 51a 548 537 53b
517 543 536 564 553 557 533 55f
552 580 56f 573 54f 57b 56e 59c
58b 58f 56b 597 58a 5b8 5a7 5ab
587 5b3 5a6 5d4 5c3 5c7 5a3 5cf
5c2 5f0 5df 5e3 5bf 5eb 5de 60c
5fb 5ff 5db 607 5fa 628 617 61b
5f7 623 616 644 633 637 613 63f
632 660 64f 653 62f 65b 64e 67c
66b 66f 64b 677 66a 698 687 68b
667 693 686 6b4 6a3 6a7 683 6af
6a2 6d1 6bf 69f 6c3 6c4 6cc 6be
6ee 6dc 6bb 6e0 6e1 6e9 6db 70a
6f9 6fd 6d8 705 6f8 726 715 719
6f5 721 714 743 731 711 735 736
73e 730 75f 74e 752 72d 75a 74d
77b 76a 76e 74a 776 769 797 786
78a 766 792 785 7b3 7a2 7a6 782
7ae 7a1 7cf 7be 7c2 79e 7ca 7bd
7eb 7da 7de 7ba 7e6 7d9 807 7f6
7fa 802 7d6 826 80e 812 816 819
821 7f5 82d 831 7f2 835 839 83d
840 845 846 1 848 84d 851 855
858 85d 861 865 868 86d 86e 870
875 878 87c 87d 882 887 88a 88f
890 895 898 89c 89d 8a2 8a5 8aa
8ab 8b0 8b3 8b8 8b9 8be 8c1 8c6
8c7 8cc 8cf 8d3 8d4 8d9 8dc 8e1
8e2 8e7 8ea 8ef 8f0 8f5 8f8 8fd
8fe 903 906 90a 90b 910 913 918
919 91e 921 926 927 92c 92f 933
937 93b 93c 93e 943 944 946 947
94c 94f 954 955 95a 95d 961 965
969 96a 96c 971 972 974 975 97a
97d 982 983 988 98b 98f 993 997
998 99a 99f 9a0 9a2 9a3 9a8 9ab
9b0 9b1 9b6 9b9 9bd 9c1 9c5 9c6
9c8 9cd 9ce 9d0 9d1 9d6 9d9 9de
9df 9e4 9e7 9eb 9ef 9f3 9f4 9f6
9fb 9fc 9fe 9ff a04 a07 a0c a0d
a12 a15 a19 a1d a21 a22 a24 a29
a2a a2c a2d a32 a35 a3a a3b a40
a43 a47 a4b a4f a50 a52 a57 a58
a5a a5b a60 a63 a68 a69 a6e a71
a75 a79 a7d a7e a80 a85 a86 a88
a89 a8e a91 a96 a97 a9c a9f aa3
aa7 aab aac aae ab3 ab4 ab6 ab7
abc abf ac4 ac5 aca acd ad1 ad5
ad9 ada adc ae1 ae2 ae4 ae5 aea
aed af2 af3 af8 afb b00 b01 b06
b09 b0d b0e b13 b16 b1b b1c b21
b24 b29 b2a b2f b32 b37 b38 b3d
b40 b44 b45 b4a b4d b52 b53 b58
b5b b60 b61 b66 b67 b6c b6e b72
b75 b79 b7d b80 b84 b88 b8b b8e
b93 b96 b99 b9c b9d ba2 ba3 1
ba5 baa bae bb2 bb5 bba bbf bc2
bc6 bc7 bcc bcd bd2 bd4 bd8 bdb
bdf be3 be7 beb bef bf3 bf7 bfb
bff c03 c07 c0b c0f c13 c17 c1b
c1f c23 c27 c2b c2f c33 c37 c3b
c3f c43 c47 c4b c4f c53 c57 c5b
c5f c63 c67 c6b c6f c73 c77 c7b
c7f c83 c87 c8b c8f c93 c97 c9b
c9f ca2 ca3 ca5 ca6 ca8 cac cb0
cb3 cb7 cbb cbe cc2 cc6 cc9 cca
ccf cd2 cd6 cda cdd ce1 ce5 ce8
ceb cf0 cf3 cf6 cf9 cfa cff d00
1 d02 d07 d0b d0f d12 d17 d1c
d1f d23 d24 d29 d2c d31 d32 d37
d3a d3f d40 d45 d48 d4c d50 d54
d58 d5b d5c d5e d63 d64 d66 d67
d6c d6d d72 d74 d78 d7b d7f d83
d86 d8a d8e d91 d94 d99 d9c d9f
da2 da3 da8 da9 1 dab db0 db4
db8 dbb dc0 dc5 dc8 dcc dcd dd2
dd3 dd8 dda dde de1 de5 de9 dec
df0 df4 df7 dfb dfc e01 e03 e07
e0a e0e e11 e12 e17 e1a e1e e22
e26 e27 e29 e2c e2d e2f e32 e35
e36 e3b 1 e3e e43 e46 e4a e4e
e51 e55 e59 e5c e5f e64 e67 e6a
e6d e6e e73 e74 1 e76 e7b e7f
e83 e86 e8b e90 e93 e97 e98 e9d
ea0 ea5 ea6 eab eae eb3 eb4 eb9
ebc ec0 ec4 ec8 ecc ecf ed0 ed2
ed7 ed8 eda edb ee0 ee1 ee6 ee8
eec eef ef3 ef7 efa efe f02 f05
f08 f0d f10 f13 f16 f17 f1c f1d
1 f1f f24 f28 f2c f2f f34 f39
f3c f40 f41 f46 f47 f4c f4e f52
f55 f59 f5d f60 f64 f68 f6b f6f
f70 f75 f77 f7b f7e f82 f85 f86
f8b f8e f92 f96 f9a f9b f9d fa0
fa1 fa3 fa6 fa9 faa faf 1 fb2
fb7 fba fbe fc2 fc5 fc9 fcd fd0
fd3 fd8 fdb fde fe1 fe2 fe7 fe8
1 fea fef ff3 ff7 ffa fff 1004
1007 100b 100c 1011 1014 1019 101a 101f
1022 1027 1028 102d 1030 1034 1038 103c
1040 1043 1044 1046 104b 104c 104e 104f
1054 1055 105a 105c 1060 1063 1067 106b
106e 1072 1076 1079 107c 1081 1084 1087
108a 108b 1090 1091 1 1093 1098 109c
10a0 10a3 10a8 10ad 10b0 10b4 10b5 10ba
10bb 10c0 10c2 10c6 10c9 10cd 10d1 10d4
10d8 10dc 10df 10e3 10e4 10e9 10eb 10ef
10f2 10f6 10fa 10fd 10fe 1100 1103 1106
1107 110c 1110 1114 1117 1118 111a 111d
1120 1121 1 1126 112b 112f 1133 1136
1137 1139 113c 113f 1140 1 1145 114a
114e 1152 1155 1159 115d 1160 1163 1168
116b 116e 1171 1172 1177 1178 1 117a
117f 1183 1187 118a 118f 1194 1197 119b
119c 11a1 11a4 11a9 11aa 11af 11b2 11b7
11b8 11bd 11c0 11c4 11c8 11cc 11d0 11d3
11d4 11d6 11db 11dc 11de 11df 11e4 11e5
11ea 11ec 11f0 11f3 11f7 11fb 11fe 1202
1206 1209 120c 1211 1214 1217 121a 121b
1220 1221 1 1223 1228 122c 1230 1233
1238 123d 1240 1244 1245 124a 124b 1250
1252 1256 1259 125d 1261 1264 1268 126c
126f 1273 1274 1279 127b 127f 1282 1286
128a 128d 128e 1290 1294 1297 129b 129e
129f 12a4 12a7 12ab 12ae 12af 12b4 12b7
1 12ba 12bf 12c3 12c6 12c7 12cc 12cf
1 12d2 12d7 12db 12df 12e3 12e7 12eb
12ef 12f3 12f7 1303 1307 130b 130e 1312
1316 1318 1 131c 1320 1324 1327 132b
132f 1333 1337 133a 133e 1342 1345 1348
134d 1350 1353 1356 1357 135c 135d 1
135f 1364 1368 136c 136f 1374 1379 137c
1380 1381 1386 1389 138e 138f 1394 1397
139c 139d 13a2 13a5 13a9 13aa 13af 13b2
13b7 13b8 13bd 13c0 13c4 13c8 13cb 13ce
13cf 13d1 13d2 13d7 13d8 13dd 13df 13e3
13e6 13e8 13ec 13ee 13fa 13fc 13fe 13ff
1404 1408 140a 1416 1418 141c 1420 1423
1427 142a 142e 1431 1432 1437 143a 143e
1442 1445 1446 1448 144b 144e 144f 1454
1 1457 145c 1460 1464 1467 146b 146f
1472 1475 147a 147d 1480 1483 1484 1489
148a 1 148c 1491 1495 1499 149c 14a1
14a6 14a9 14ad 14ae 14b3 14b6 14bb 14bc
14c1 14c4 14c9 14ca 14cf 14d2 14d6 14da
14de 14e2 14e5 14e6 14e8 14ed 14ee 14f0
14f1 14f6 14f7 14fc 14fe 1502 1505 1509
150d 1510 1514 1518 151b 151e 1523 1526
1529 152c 152d 1532 1533 1 1535 153a
153e 1542 1545 154a 154f 1552 1556 1557
155c 155d 1562 1564 1568 156b 156f 1573
1576 157a 157e 1581 1585 1586 158b 158d
1591 1594 1598 159b 159f 15a3 15a5 15a9
15ac 15ad 15b2 15b5 15b8 15bc 15bf 15c0
15c5 15c8 1 15cb 15d0 15d4 15d8 15dc
15e8 15ec 15f0 15f3 15f7 15fb 15fd 1
1601 1605 1609 160c 1610 1614 1618 161c
161f 1623 1627 162a 162d 1632 1635 1638
163b 163c 1641 1642 1 1644 1649 164d
1651 1654 1659 165e 1661 1665 1666 166b
166e 1673 1674 1679 167c 1681 1682 1687
168a 168e 168f 1694 1697 169c 169d 16a2
16a5 16a9 16ad 16b0 16b3 16b4 16b6 16b7
16bc 16bd 16c2 16c4 16c8 16cb 16cd 16d1
16d3 16df 16e1 16e3 16e4 16e9 16ed 16ef
16fb 16fd 16ff 1703 1707 170a 170e 1712
1716 171a 171e 1722 1725 1729 172d 1731
1734 1735 1737 173b 173f 1742 1743 1745
1748 174b 174c 174e 1752 1756 175a 175e
1762 1765 1766 1768 176c 1770 1773 1774
1776 1779 177d 1781 1785 1788 1789 178b
178e 1791 1792 1797 179b 179f 17a3 17a7
17ab 17af 17b3 17b7 17bb 17bf 17c3 17cf
17d3 17d7 17da 17de 17e2 17e4 1 17e8
17ec 17f0 17f3 17f7 17fb 17ff 1803 1806
180a 180e 1811 1814 1819 181c 181f 1822
1823 1828 1829 1 182b 1830 1834 1838
183b 1840 1845 1848 184c 184d 1852 1855
185a 185b 1860 1863 1868 1869 186e 1871
1875 1876 187b 187e 1883 1884 1889 188c
1890 1894 1897 189a 189b 189d 189e 18a3
18a4 18a9 18ab 18af 18b2 18b4 18b8 18ba
18c6 18c8 18ca 18cb 18d0 18d4 18d6 18e2
18e4 18e8 18ec 18ef 18f3 18f6 18fa 18fd
18fe 1903 1906 190a 190e 1912 1916 191a
191e 192a 192e 1932 1935 1939 193d 193f
1 1943 1947 194b 194e 1952 1956 195a
195e 1961 1965 1969 196c 196f 1974 1977
197a 197d 197e 1983 1984 1 1986 198b
198f 1993 1996 199b 19a0 19a3 19a7 19a8
19ad 19b0 19b5 19b6 19bb 19be 19c3 19c4
19c9 19cc 19d0 19d1 19d6 19d9 19de 19df
19e4 19e7 19eb 19ef 19f2 19f5 19f6 19f8
19f9 19fe 19ff 1a04 1a06 1a0a 1a0d 1a0f
1a13 1a15 1a21 1a23 1a25 1a26 1a2b 1a2f
1a31 1a3d 1a3f 1a43 1a47 1a4a 1a4e 1a51
1a55 1a58 1a59 1a5e 1a61 1a65 1a69 1a6c
1a70 1a74 1a77 1a7a 1a7f 1a82 1a85 1a88
1a89 1a8e 1a8f 1 1a91 1a96 1a9a 1a9e
1aa1 1aa6 1aab 1aae 1ab2 1ab3 1ab8 1abb
1ac0 1ac1 1ac6 1ac9 1ace 1acf 1ad4 1ad7
1adb 1adf 1ae3 1ae7 1aea 1aeb 1aed 1af2
1af3 1af5 1af6 1afb 1afe 1b03 1b04 1b09
1b0c 1b11 1b12 1b17 1b1a 1b1e 1b1f 1b24
1b27 1b2c 1b2d 1b32 1b33 1b38 1b3a 1b3e
1b41 1b45 1b49 1b4c 1b50 1b54 1b57 1b5a
1b5f 1b62 1b65 1b68 1b69 1b6e 1b6f 1
1b71 1b76 1b7a 1b7e 1b81 1b86 1b8b 1b8e
1b92 1b93 1b98 1b99 1b9e 1ba0 1ba4 1ba7
1bab 1baf 1bb2 1bb6 1bba 1bbd 1bc1 1bc5
1bc6 1bcb 1bcd 1bd1 1bd4 1bd6 1bda 1bdd
1be1 1be4 1be8 1bec 1bf0 1bf4 1bf8 1bfc
1c08 1c0c 1c10 1c13 1c17 1c1b 1c1d 1
1c21 1c25 1c29 1c2c 1c30 1c34 1c38 1c3c
1c3f 1c43 1c47 1c4a 1c4d 1c52 1c55 1c58
1c5b 1c5c 1c61 1c62 1 1c64 1c69 1c6d
1c71 1c74 1c79 1c7e 1c81 1c85 1c86 1c8b
1c8e 1c93 1c94 1c99 1c9c 1ca1 1ca2 1ca7
1caa 1cae 1caf 1cb4 1cb7 1cbc 1cbd 1cc2
1cc5 1cc9 1ccd 1cd0 1cd3 1cd4 1cd6 1cd7
1cdc 1cdd 1ce2 1ce4 1ce8 1ceb 1ced 1cf1
1cf3 1cff 1d01 1d03 1d04 1d09 1d0d 1d0f
1d1b 1d1d 1d21 1d25 1d28 1d29 1d2b 1d2e
1d31 1d32 1d37 1d3b 1d3f 1d43 1d47 1d4b
1d57 1d5b 1d5f 1d62 1d66 1d6a 1d6c 1
1d70 1d74 1d78 1d7b 1d7f 1d83 1d87 1d8b
1d8e 1d92 1d96 1d99 1d9c 1da1 1da4 1da7
1daa 1dab 1db0 1db1 1 1db3 1db8 1dbc
1dc0 1dc3 1dc8 1dcd 1dd0 1dd4 1dd5 1dda
1ddd 1de2 1de3 1de8 1deb 1df0 1df1 1df6
1df9 1dfd 1dfe 1e03 1e06 1e0b 1e0c 1e11
1e14 1e18 1e1c 1e1f 1e22 1e23 1e25 1e26
1e2b 1e2c 1e31 1e33 1e37 1e3a 1e3c 1e40
1e42 1e4e 1e50 1e52 1e53 1e58 1e5c 1e5e
1e6a 1e6c 1e70 1e74 1e77 1e7b 1e80 1e81
1e83 1e86 1e89 1e8a 1e8f 1e93 1e97 1e9a
1e9e 1ea2 1ea5 1ea8 1ead 1eb0 1eb3 1eb6
1eb7 1ebc 1ebd 1 1ebf 1ec4 1ec8 1ecc
1ecf 1ed4 1ed9 1edc 1ee0 1ee1 1ee6 1ee9
1eee 1eef 1ef4 1ef7 1efc 1efd 1f02 1f05
1f09 1f0d 1f11 1f15 1f18 1f19 1f1b 1f20
1f21 1f23 1f24 1f29 1f2c 1f31 1f32 1f37
1f3a 1f3f 1f40 1f45 1f48 1f4c 1f4d 1f52
1f55 1f5a 1f5b 1f60 1f61 1f66 1f68 1f6c
1f6f 1f73 1f77 1f7a 1f7e 1f82 1f85 1f88
1f8d 1f90 1f93 1f96 1f97 1f9c 1f9d 1
1f9f 1fa4 1fa8 1fac 1faf 1fb4 1fb9 1fbc
1fc0 1fc1 1fc6 1fc7 1fcc 1fce 1fd2 1fd5
1fd9 1fdd 1fe0 1fe4 1fe8 1feb 1fef 1ff3
1ff4 1ff9 1ffb 1fff 2002 2004 2008 200b
200d 2011 2014 2015 201a 201d 2021 2025
2028 202c 2030 2033 2036 203b 203e 2041
2044 2045 204a 204b 1 204d 2052 2056
205a 205d 2062 2067 206a 206e 206f 2074
2077 207c 207d 2082 2085 208a 208b 2090
2093 2097 209b 209f 20a3 20a6 20a7 20a9
20ae 20af 20b1 20b2 20b7 20b8 20bd 20bf
20c3 20c6 20ca 20ce 20d1 20d5 20d9 20dc
20df 20e4 20e7 20ea 20ed 20ee 20f3 20f4
1 20f6 20fb 20ff 2103 2106 210b 2110
2113 2117 2118 211d 211e 2123 2125 2129
212c 2130 2134 2137 213b 213f 2142 2146
2147 214c 214e 2152 2155 2159 215d 2161
2165 2169 216d 2171 2174 2177 2178 217a
217d 2180 2181 2183 2187 218b 218f 2193
2196 2199 219c 219f 21a3 21a4 21a6 21aa
21ae 21b2 21b6 21b9 21ba 21bc 21bd 21bf
21c2 21c5 21c6 21cb 21cf 21d3 21d7 21db
21df 21e3 21e7 21eb 21ef 21f3 21f7 21fb
21ff 2203 2207 220b 220f 2213 2217 221b
221f 2223 2227 222b 2237 223b 223f 2242
2246 224a 224c 1 2250 2254 2258 225b
225f 2263 2267 226b 226e 2272 2276 2279
227c 2281 2284 2287 228a 228b 2290 2291
1 2293 2298 229c 22a0 22a3 22a8 22ad
22b0 22b4 22b5 22ba 22bd 22c2 22c3 22c8
22cb 22d0 22d1 22d6 22d9 22dd 22de 22e3
22e6 22eb 22ec 22f1 22f4 22f8 22fc 22ff
2302 2303 2305 2306 230b 230c 2311 2313
2317 231a 231c 2320 2322 232e 2330 2332
2333 2338 233c 233e 234a 234c 2350 2354
2357 235b 235e 2362 2365 2366 236b 236e
2372 2376 2379 237d 2381 2384 2387 238c
238f 2392 2395 2396 239b 239c 1 239e
23a3 23a7 23ab 23ae 23b3 23b8 23bb 23bf
23c0 23c5 23c8 23cd 23ce 23d3 23d6 23db
23dc 23e1 23e4 23e8 23ec 23f0 23f4 23f7
23f8 23fa 23ff 2400 2402 2403 2408 240b
2410 2411 2416 2419 241e 241f 2424 2427
242b 242c 2431 2434 2439 243a 243f 2440
2445 2447 244b 244e 2452 2456 2459 245d
2461 2464 2467 246c 246f 2472 2475 2476
247b 247c 1 247e 2483 2487 248b 248e
2493 2498 249b 249f 24a0 24a5 24a6 24ab
24ad 24b1 24b4 24b8 24bc 24bf 24c3 24c7
24ca 24ce 24d2 24d3 24d8 24da 24de 24e1
24e3 24e7 24eb 24ee 24f2 24f6 24f9 24fc
2501 2504 2507 250a 250b 2510 2511 1
2513 2518 251c 2520 2523 2528 252d 2530
2534 2535 253a 253d 2542 2543 2548 254b
2550 2551 2556 2559 255d 2561 2565 2569
256c 256d 256f 2574 2575 2577 2578 257d
2580 2585 2586 258b 258e 2593 2594 2599
259c 25a0 25a1 25a6 25a9 25ae 25af 25b4
25b5 25ba 25bc 25c0 25c3 25c7 25cb 25ce
25d2 25d6 25d9 25dc 25e1 25e4 25e7 25ea
25eb 25f0 25f1 1 25f3 25f8 25fc 2600
2603 2608 260d 2610 2614 2615 261a 261b
2620 2622 2626 2629 262d 2631 2634 2638
263c 263f 2643 2647 2648 264d 264f 2653
2657 265a 265c 2660 2664 2667 266b 266f
2672 2673 2675 2678 267b 267c 2681 2684
2688 268c 268f 2690 2692 2695 2698 2699
269e 1 26a1 26a6 26aa 26ad 26b1 26b3
26b7 26ba 26be 26c1 26c4 26c5 26ca 26ce
26d2 26d6 26da 26df 26e3 26e7 26eb 26ef
26f3 26f7 26fb 26fe 26ff 2701 2705 2709
270c 270d 270f 2713 2717 271a 271b 271d
2721 2725 2728 2729 272b 272f 2733 2736
2737 2739 273d 2741 2744 2745 2747 274b
274f 2752 2753 2755 2759 275d 2760 2761
2763 2767 276b 276f 2770 2772 2776 277a
277e 2781 2782 2784 2788 278b 278f 2792
2793 2798 279c 27a0 27a3 27a7 27ab 27ae
27b1 27b6 27b9 27bc 27bf 27c0 27c5 27c6
1 27c8 27cd 27d1 27d5 27d8 27dd 27e2
27e5 27e9 27ea 27ef 27f2 27f7 27f8 27fd
2800 2805 2806 280b 280e 2812 2816 281a
281e 2821 2822 2824 2829 282a 282c 282d
2832 2833 2838 283a 283e 2841 2845 2849
284c 2850 2854 2857 285a 285f 2862 2865
2868 2869 286e 286f 1 2871 2876 287a
287e 2881 2886 288b 288e 2892 2893 2898
2899 289e 28a0 28a4 28a7 28ab 28af 28b2
28b6 28ba 28bd 28c1 28c2 28c7 28cb 28cd
28d1 28d5 28d8 28d9 28db 28de 28e1 28e2
28e7 28eb 28ef 28f2 28f6 28fa 28fd 2900
2905 2908 290b 290e 290f 2914 2915 1
2917 291c 2920 2924 2927 292c 2931 2934
2938 2939 293e 2941 2946 2947 294c 294f
2954 2955 295a 295d 2961 2965 2969 296a
296c 2971 2972 2974 2975 297a 297d 2982
2983 2988 298b 2990 2991 2996 2999 299d
299e 29a3 29a6 29ab 29ac 29b1 29b2 29b7
29b9 29bd 29c0 29c4 29c8 29cb 29cf 29d3
29d6 29d9 29de 29e1 29e4 29e7 29e8 29ed
29ee 1 29f0 29f5 29f9 29fd 2a00 2a05
2a0a 2a0d 2a11 2a12 2a17 2a18 2a1d 2a1f
2a23 2a26 2a2a 2a2e 2a31 2a35 2a39 2a3c
2a3d 2a3f 2a43 2a47 2a48 2a4d 2a4f 2a53
2a57 2a5a 2a5c 2a60 2a63 2a67 2a6b 2a6e
2a6f 2a71 2a74 2a77 2a78 2a7d 2a80 2a84
2a88 2a8b 2a8c 2a8e 2a91 2a94 2a95 2a9a
1 2a9d 2aa2 2aa6 2aaa 2aad 2aae 2ab0
2ab3 2ab6 2ab7 2abc 2abf 2ac3 2ac7 2aca
2acb 2acd 2ad0 2ad3 2ad4 2ad9 1 2adc
2ae1 2ae5 2ae8 2aec 2af0 2af2 2af6 2afa
2afd 2afe 2b00 2b03 2b06 2b07 2b0c 2b10
2b13 2b17 2b1b 2b1d 2b21 2b25 2b29 2b2c
2b2d 2b2f 2b32 2b35 2b36 2b3b 2b3e 2b42
2b46 2b49 2b4a 2b4c 2b4f 2b52 2b53 2b58
1 2b5b 2b60 2b64 2b67 2b6b 2b6f 2b71
2b75 2b79 2b7d 2b80 2b81 2b83 2b86 2b89
2b8a 2b8f 2b93 2b97 2b9b 2b9e 2b9f 2ba1
2ba4 2ba8 2bac 2baf 2bb0 2bb2 2bb3 2bb8
2bbc 2bc0 2bc3 2bc7 2bc9 2bcd 2bd1 2bd4
2bd6 2bda 2bdd 2be1 2be5 2be8 2be9 2beb
2bee 2bf1 2bf2 2bf7 2bfb 2bff 2c02 2c03
2c05 2c08 2c0b 2c0c 2c11 2c15 2c19 2c1c
2c20 2c24 2c27 2c2a 2c2f 2c32 2c35 2c38
2c39 2c3e 2c3f 1 2c41 2c46 2c4a 2c4e
2c51 2c56 2c5b 2c5e 2c62 2c63 2c68 2c6b
2c70 2c71 2c76 2c79 2c7e 2c7f 2c84 2c87
2c8b 2c8f 2c93 2c97 2c9a 2c9b 2c9d 2ca2
2ca3 2ca5 2ca6 2cab 2cae 2cb3 2cb4 2cb9
2cbc 2cc1 2cc2 2cc7 2cca 2cce 2ccf 2cd4
2cd7 2cdc 2cdd 2ce2 2ce3 2ce8 2cea 2cee
2cf1 2cf5 2cf9 2cfc 2d00 2d04 2d07 2d0a
2d0f 2d12 2d15 2d18 2d19 2d1e 2d1f 1
2d21 2d26 2d2a 2d2e 2d31 2d36 2d3b 2d3e
2d42 2d43 2d48 2d49 2d4e 2d50 2d54 2d57
2d5b 2d5f 2d62 2d66 2d6a 2d6d 2d71 2d75
2d76 2d7b 2d7d 2d81 2d84 2d88 2d8c 2d8f
2d90 2d92 2d95 2d98 2d99 2d9e 2da2 2da5
2da9 2dab 2daf 2db3 2db7 2dbb 2dbe 2dbf
2dc1 2dc4 2dc7 2dc8 2dcd 2dce 2dd0 2dd4
2dd6 2dda 2dde 2de1 2de3 2de7 2dea 2dee
2df2 2df3 2df8 2dfc 2e00 2e05 2e09 2e0d
2e12 2e16 2e1a 2e1f 2e23 2e27 2e2c 2e30
2e34 2e38 2e3c 2e3f 2e42 2e43 2e45 2e49
2e4d 2e51 2e55 2e58 2e5b 2e5c 2e5e 2e62
2e66 2e6a 2e6d 2e6e 2e70 2e73 2e76 2e77
2e7c 2e80 2e81 2e85 2e89 2e8d 2e91 2e95
2e99 2e9c 2e9f 2ea0 2ea2 2ea5 2eaa 2eab
2eb0 2eb4 2eb8 2ebc 2ec0 2ec4 2ec8 2ecc
2ed0 2ed4 2ed8 2edc 2ee0 2ee4 2ee8 2eec
2ef0 2ef4 2ef8 2efc 2f00 2f04 2f08 2f0c
2f10 2f14 2f20 2f24 2f28 2f2b 2f2f 2f33
2f35 1 2f39 2f3d 2f41 2f44 2f48 2f4c
2f50 2f54 2f57 2f5b 2f5f 2f62 2f65 2f6a
2f6d 2f70 2f73 2f74 2f79 2f7a 1 2f7c
2f81 2f85 2f89 2f8c 2f91 2f96 2f99 2f9d
2f9e 2fa3 2fa6 2fab 2fac 2fb1 2fb4 2fb9
2fba 2fbf 2fc2 2fc6 2fc7 2fcc 2fcf 2fd4
2fd5 2fda 2fdd 2fe1 2fe5 2fe8 2feb 2fec
2fee 2fef 2ff4 2ff5 2ffa 2ffc 3000 3003
3005 3009 300b 3017 3019 301b 301c 3021
3025 3027 3033 3035 3039 303d 3041 3045
3049 3055 3059 305d 3060 3064 3068 306a
1 306e 3072 3076 3079 307d 3081 3085
3089 308c 3090 3094 3097 309a 309f 30a2
30a5 30a8 30a9 30ae 30af 1 30b1 30b6
30ba 30be 30c1 30c6 30cb 30ce 30d2 30d3
30d8 30db 30e0 30e1 30e6 30e9 30ee 30ef
30f4 30f7 30fb 30fc 3101 3104 3109 310a
310f 3112 3116 311a 311d 3120 3121 3123
3124 3129 312a 312f 3131 3135 3138 313a
313e 3140 314c 314e 3150 3151 3156 315a
315c 3168 316a 316e 3172 3175 3179 317c
3180 3183 3184 3189 318c 3190 3194 3197
319b 319f 31a2 31a5 31aa 31ad 31b0 31b3
31b4 31b9 31ba 1 31bc 31c1 31c5 31c9
31cc 31d1 31d6 31d9 31dd 31de 31e3 31e6
31eb 31ec 31f1 31f4 31f9 31fa 31ff 3202
3206 320a 320e 3212 3215 3216 3218 321d
321e 3220 3221 3226 3229 322e 322f 3234
3237 323c 323d 3242 3245 3249 324a 324f
3252 3257 3258 325d 325e 3263 3265 3269
326c 3270 3274 3277 327b 327f 3282 3285
328a 328d 3290 3293 3294 3299 329a 1
329c 32a1 32a5 32a9 32ac 32b1 32b6 32b9
32bd 32be 32c3 32c4 32c9 32cb 32cf 32d2
32d6 32da 32dd 32e1 32e5 32e8 32ec 32f0
32f1 32f6 32f8 32fc 32ff 3303 3307 330b
330f 3313 3317 331b 331f 3323 3327 332b
332f 3333 333f 3343 3347 334a 334e 3352
3354 1 3358 335c 3360 3363 3367 336b
336f 3373 3376 337a 337e 3381 3384 3389
338c 338f 3392 3393 3398 3399 1 339b
33a0 33a4 33a8 33ab 33b0 33b5 33b8 33bc
33bd 33c2 33c5 33ca 33cb 33d0 33d3 33d8
33d9 33de 33e1 33e5 33e6 33eb 33ee 33f3
33f4 33f9 33fc 3400 3404 3407 340a 340b
340d 340e 3413 3414 3419 341b 341f 3422
3424 3428 342a 3436 3438 343a 343b 3440
3444 3446 3452 3454 3458 345a 345e 3462
3465 3468 3469 346b 346e 3473 3474 3479
347d 3481 3485 3489 348d 3499 349d 34a1
34a4 34a8 34ac 34ae 1 34b2 34b6 34ba
34bd 34c1 34c5 34c9 34cd 34d0 34d4 34d8
34db 34de 34e3 34e6 34e9 34ec 34ed 34f2
34f3 1 34f5 34fa 34fe 3502 3505 350a
350f 3512 3516 3517 351c 351f 3524 3525
352a 352d 3532 3533 3538 353b 353f 3540
3545 3548 354d 354e 3553 3556 355a 355e
3561 3564 3565 3567 3568 356d 356e 3573
3575 3579 357c 357e 3582 3584 3590 3592
3594 3595 359a 359e 35a0 35ac 35ae 35b2
35b6 35b9 35bd 35c0 35c4 35c7 35c8 35cd
35d0 35d4 35d8 35db 35df 35e3 35e6 35e9
35ee 35f1 35f4 35f7 35f8 35fd 35fe 1
3600 3605 3609 360d 3610 3615 361a 361d
3621 3622 3627 362a 362f 3630 3635 3638
363d 363e 3643 3646 364a 364e 3652 3656
3659 365a 365c 3661 3662 3664 3665 366a
366d 3672 3673 3678 367b 3680 3681 3686
3689 368d 368e 3693 3696 369b 369c 36a1
36a2 36a7 36a9 36ad 36b0 36b4 36b8 36bb
36bf 36c3 36c6 36c9 36ce 36d1 36d4 36d7
36d8 36dd 36de 1 36e0 36e5 36e9 36ed
36f0 36f5 36fa 36fd 3701 3702 3707 3708
370d 370f 3713 3716 371a 371e 3721 3725
3729 372c 3730 3734 3735 373a 373c 3740
3743 3747 374b 374f 3753 3757 375b 375f
3763 3767 376b 376f 3773 3777 377b 377f
3783 3787 378b 378f 3793 3797 379b 379f
37a3 37a7 37ab 37af 37b3 37bf 37c3 37c7
37ca 37ce 37d2 37d4 1 37d8 37dc 37e0
37e3 37e7 37eb 37ef 37f3 37f6 37fa 37fe
3801 3804 3809 380c 380f 3812 3813 3818
3819 1 381b 3820 3824 3828 382b 3830
3835 3838 383c 383d 3842 3845 384a 384b
3850 3853 3858 3859 385e 3861 3865 3866
386b 386e 3873 3874 3879 387c 3880 3884
3887 388a 388b 388d 388e 3893 3894 3899
389b 389f 38a2 38a4 38a8 38aa 38b6 38b8
38ba 38bb 38c0 38c4 38c6 38d2 38d4 38d8
38dc 38df 38e3 38e6 38ea 38ed 38ee 38f3
38f6 38fa 38fe 3902 3906 390a 390e 3912
3916 391a 391e 3922 3926 392a 392e 3932
3936 393a 393e 3942 3946 394a 394e 3952
3956 395a 3966 396a 396e 3971 3975 3979
397b 1 397f 3983 3987 398a 398e 3992
3996 399a 399d 39a1 39a5 39a8 39ab 39b0
39b3 39b6 39b9 39ba 39bf 39c0 1 39c2
39c7 39cb 39cf 39d2 39d7 39dc 39df 39e3
39e4 39e9 39ec 39f1 39f2 39f7 39fa 39ff
3a00 3a05 3a08 3a0c 3a0d 3a12 3a15 3a1a
3a1b 3a20 3a23 3a27 3a2b 3a2e 3a31 3a32
3a34 3a35 3a3a 3a3b 3a40 3a42 3a46 3a49
3a4b 3a4f 3a51 3a5d 3a5f 3a61 3a62 3a67
3a6b 3a6d 3a79 3a7b 3a7d 3a81 3a84 3a88
3a8c 3a90 3a94 3a98 3a9c 3aa0 3aa4 3aa8
3aac 3ab8 3abc 3ac0 3ac3 3ac7 3acb 3acd
1 3ad1 3ad5 3ad9 3adc 3ae0 3ae4 3ae8
3aec 3aef 3af3 3af7 3afa 3afd 3b02 3b05
3b08 3b0b 3b0c 3b11 3b12 1 3b14 3b19
3b1d 3b21 3b24 3b29 3b2e 3b31 3b35 3b36
3b3b 3b3e 3b43 3b44 3b49 3b4c 3b51 3b52
3b57 3b5a 3b5e 3b5f 3b64 3b67 3b6c 3b6d
3b72 3b75 3b79 3b7d 3b80 3b83 3b84 3b86
3b87 3b8c 3b8d 3b92 3b94 3b98 3b9b 3b9d
3ba1 3ba3 3baf 3bb1 3bb3 3bb4 3bb9 3bbd
3bbf 3bcb 3bcd 3bcf 3bd3 3bd7 3bdb 3bde
3be2 3be6 3be9 3bec 3bf1 3bf4 3bf7 3bfa
3bfb 3c00 3c01 1 3c03 3c08 3c0c 3c10
3c13 3c18 3c1d 3c20 3c24 3c25 3c2a 3c2d
3c32 3c33 3c38 3c3b 3c40 3c41 3c46 3c49
3c4d 3c51 3c55 3c59 3c5c 3c5d 3c5f 3c64
3c65 3c67 3c68 3c6d 3c6e 3c73 3c75 3c79
3c7c 3c80 3c84 3c87 3c8b 3c8f 3c92 3c95
3c9a 3c9d 3ca0 3ca3 3ca4 3ca9 3caa 1
3cac 3cb1 3cb5 3cb9 3cbc 3cc1 3cc6 3cc9
3ccd 3cce 3cd3 3cd4 3cd9 3cdb 3cdf 3ce2
3ce6 3cea 3ced 3cf1 3cf5 3cf8 3cfc 3cfd
3d02 3d04 3d08 3d0c 3d0f 3d13 3d17 3d1a
3d1e 3d21 3d25 3d28 3d29 3d2e 3d31 3d35
3d39 3d3c 3d40 3d44 3d47 3d48 3d4a 3d4e
3d52 3d55 3d59 3d5a 3d5c 3d60 3d64 3d68
3d6b 3d6f 3d73 3d76 3d77 3d79 3d7d 3d81
3d84 3d88 3d89 3d8b 3d8f 3d93 3d97 3d9b
3d9f 3da3 3da7 3dab 3daf 3db3 3db7 3dbb
3dbf 3dc3 3dc7 3dcb 3dcf 3dd3 3dd7 3ddb
3ddf 3de3 3de7 3deb 3def 3df3 3df7 3dfb
3dff 3e03 3e07 3e0b 3e0f 3e13 3e17 3e1b
3e1f 3e23 3e2f 3e33 3e38 3e3c 3e3f 3e40
3e45 3e49 3e4d 3e50 3e53 3e57 3e59 3e5d
3e61 3e64 3e67 3e6b 3e6d 3e71 3e75 3e78
3e7a 1 3e7e 3e82 3e86 3e89 3e8d 3e91
3e95 3e99 3e9c 3ea0 3ea4 3ea7 3eaa 3eaf
3eb2 3eb5 3eb8 3eb9 3ebe 3ebf 1 3ec1
3ec6 3eca 3ece 3ed1 3ed6 3edb 3ede 3ee2
3ee3 3ee8 3eeb 3ef0 3ef1 3ef6 3ef9 3efe
3eff 3f04 3f07 3f0b 3f0c 3f11 3f14 3f19
3f1a 3f1f 3f22 3f26 3f2a 3f2d 3f30 3f31
3f33 3f34 3f39 3f3a 3f3f 3f41 3f45 3f48
3f4a 3f4e 3f50 3f5c 3f5e 3f60 3f61 3f66
3f6a 3f6c 3f78 3f7a 3f7e 3f82 3f86 3f87
3f89 3f8d 3f8f 3f93 3f97 3f98 3f9d 3fa1
3fa5 3fa9 3fac 3fb0 3fb4 3fb7 3fb8 3fba
3fbe 3fc2 3fc5 3fc9 3fca 3fcc 3fd0 3fd4
3fd8 3fdc 3fdf 3fe3 3fe7 3fea 3fee 3ff2
3ff6 3ffa 3ffe 4002 4006 400a 400e 4012
4013 4015 4019 401d 4021 4025 4029 402d
4031 4035 4039 403d 4041 4045 4049 404d
4051 4055 4059 405d 4061 4065 4069 406d
4071 4075 4079 4085 4089 408e 4092 4095
4096 409b 409f 40a3 40a6 40a9 40ad 40af
40b3 40b7 40ba 40bd 40c1 40c3 40c7 40cb
40ce 40d0 1 40d4 40d8 40dc 40df 40e3
40e7 40eb 40ef 40f2 40f6 40fa 40fd 4100
4105 4108 410b 410e 410f 4114 4115 1
4117 411c 4120 4124 4127 412c 4131 4134
4138 4139 413e 4141 4146 4147 414c 414f
4154 4155 415a 415d 4161 4162 4167 416a
416f 4170 4175 4178 417c 4180 4183 4186
4187 4189 418a 418f 4190 4195 4197 419b
419e 41a0 41a4 41a6 41b2 41b4 41b6 41b7
41bc 41c0 41c2 41ce 41d0 41d2 41d6 41da
41dd 41e1 41e5 41e8 41e9 41eb 41ee 41f1
41f2 41f7 41fa 41fe 4201 4202 4207 420a
1 420d 4212 4216 421a 421e 4222 4226
4232 4236 423a 423d 4241 4245 4247 1
424b 424f 4253 4256 425a 425e 4262 4266
4269 426d 4271 4274 4277 427c 427f 4282
4285 4286 428b 428c 1 428e 4293 4297
429b 429e 42a3 42a8 42ab 42af 42b0 42b5
42b8 42bd 42be 42c3 42c6 42cb 42cc 42d1
42d4 42d8 42d9 42de 42e1 42e6 42e7 42ec
42ef 42f3 42f7 42fa 42fd 42fe 4300 4301
4306 4307 430c 430e 4312 4315 4317 431b
431d 4329 432b 432d 432e 4333 4337 4339
4345 4347 434b 434f 4352 4355 4356 4358
435b 4360 4361 4366 436a 436d 4370 4371
4376 437a 437e 4382 4385 4389 438d 4391
4395 4399 439d 43a1 43a5 43a9 43ad 43b1
43b2 43b4 43b8 43ba 43be 43c1 43c3 43c7
43ca 43ce 43d2 43d6 43da 43de 43e1 43e4
43e5 43e7 43ea 43ef 43f0 43f5 43f9 43fd
4401 4404 4408 440a 440e 4412 4416 4419
441a 441c 4420 4422 4426 442a 442d 4431
4435 4439 443d 4441 4445 4449 444d 4451
4455 4459 445d 4461 4465 4469 446d 4471
4475 4479 447d 4481 4485 4489 448d 4491
4495 4499 449d 44a1 44a5 44a8 44ab 44ae
44b1 44b2 44b4 44b8 44bc 44bf 44c2 44c3
44c8 44cc 44d0 44d4 44d8 44e4 44e8 44ed
44f1 44f4 44f5 44fa 44fe 4502 4505 4508
450c 450e 4512 4516 4519 451c 4520 4522
4526 452a 452d 452f 1 4533 4537 453b
453e 4542 4546 454a 454e 4551 4555 4559
455c 455f 4564 4567 456a 456d 456e 4573
4574 1 4576 457b 457f 4583 4586 458b
4590 4593 4597 4598 459d 45a0 45a5 45a6
45ab 45ae 45b3 45b4 45b9 45bc 45c0 45c1
45c6 45c9 45ce 45cf 45d4 45d7 45db 45df
45e2 45e5 45e6 45e8 45e9 45ee 45ef 45f4
45f6 45fa 45fd 45ff 4603 4605 4611 4613
4615 4616 461b 461f 4621 462d 462f 4631
4635 4638 463a 463e 4643 4647 464b 4650
4654 4658 465c 4660 4664 4668 466c 466d
466f 4672 4673 4675 4678 467b 467c 4681
4685 4688 468c 468e 4692 4696 469a 469e
46a2 46a3 46a5 46a8 46a9 46ab 46ae 46b1
46b2 46b7 46ba 46bd 46c0 46c1 46c6 46c7
46c9 46cd 46cf 46d3 46d7 46da 46de 46e1
46e4 46e5 46ea 46ee 46f1 46f5 46f9 46fd
4701 4704 4705 4707 470b 470e 4712 4713
4718 471a 471e 4722 4726 4729 472c 472f
4733 4737 473a 473b 473d 4740 4743 4744
4749 474c 474f 4750 4755 4759 475a 475c
4760 4764 4768 476c 476f 4772 4775 4779
477d 4780 4781 4783 4786 4789 478a 478f
4792 4795 4796 479b 479e 47a1 47a2 47a7
47ab 47ac 47ae 47b2 47b6 47ba 47bd 47c0
47c1 47c3 47c6 47cb 47cc 47d1 47d5 47d9
47dd 47e0 47e4 47e8 47ec 47f0 47f1 47f3
47f6 47f7 47f9 47fc 47ff 4800 4805 4809
480d 4811 4813 4817 481b 481f 4822 4827
4828 482d 4830 4833 4834 4836 483a 483e
4842 4846 4849 484d 484e 4853 4856 4859
485a 485c 4860 4862 4866 486a 486d 486f
4873 4877 487b 487e 487f 4881 4885 4889
488d 4891 4892 4894 4897 4898 489a 489d
48a0 48a1 48a6 48aa 48ae 48b2 48b4 48b8
48bc 48c0 48c3 48c8 48c9 48ce 48d1 48d4
48d5 48d7 48db 48df 48e3 48e7 48ea 48ee
48ef 48f4 48f7 48fa 48fb 48fd 4901 4903
4907 490b 490e 4910 4914 4918 491b 491f
4923 4926 4929 492a 492c 492f 4934 4935
493a 493e 4942 4946 494a 494e 4952 4956
495a 495e 4962 4966 496a 496e 4972 4976
497a 497e 4982 4986 4992 4996 499a 499d
49a1 49a5 49a7 1 49ab 49af 49b3 49b6
49ba 49be 49c2 49c6 49c9 49cd 49d1 49d4
49d7 49dc 49df 49e2 49e5 49e6 49eb 49ec
1 49ee 49f3 49f7 49fb 49fe 4a03 4a08
4a0b 4a0f 4a10 4a15 4a18 4a1d 4a1e 4a23
4a26 4a2b 4a2c 4a31 4a34 4a38 4a39 4a3e
4a41 4a46 4a47 4a4c 4a4f 4a53 4a57 4a5a
4a5d 4a5e 4a60 4a61 4a66 4a67 4a6c 4a6e
4a72 4a75 4a77 4a7b 4a7d 4a89 4a8b 4a8d
4a8e 4a93 4a97 4a99 4aa5 4aa7 4aab 4aae
4ab2 4ab6 4ab9 4abd 4abf 4ac3 4ac7 4acb
4acf 4ad3 4ad7 4adb 4adf 4ae3 4ae7 4aeb
4aef 4af3 4af7 4afb 4aff 4b03 4b07 4b0b
4b0f 4b1b 4b1f 4b23 4b26 4b2a 4b2e 4b30
1 4b34 4b38 4b3c 4b3f 4b43 4b47 4b4b
4b4f 4b52 4b56 4b5a 4b5d 4b60 4b65 4b68
4b6b 4b6e 4b6f 4b74 4b75 1 4b77 4b7c
4b80 4b84 4b87 4b8c 4b91 4b94 4b98 4b99
4b9e 4ba1 4ba6 4ba7 4bac 4baf 4bb4 4bb5
4bba 4bbd 4bc1 4bc2 4bc7 4bca 4bcf 4bd0
4bd5 4bd8 4bdc 4be0 4be3 4be6 4be7 4be9
4bea 4bef 4bf0 4bf5 4bf7 4bfb 4bfe 4c00
4c04 4c06 4c12 4c14 4c16 4c17 4c1c 4c20
4c22 4c2e 4c30 4c34 4c38 4c3b 4c3f 4c42
4c46 4c49 4c4a 4c4f 4c52 4c56 4c5a 4c5e
4c62 4c66 4c6a 4c6e 4c72 4c76 4c7a 4c7e
4c82 4c86 4c8a 4c8e 4c92 4c96 4c9a 4c9e
4ca2 4cae 4cb2 4cb6 4cb9 4cbd 4cc1 4cc3
1 4cc7 4ccb 4ccf 4cd2 4cd6 4cda 4cde
4ce2 4ce5 4ce9 4ced 4cf0 4cf3 4cf8 4cfb
4cfe 4d01 4d02 4d07 4d08 1 4d0a 4d0f
4d13 4d17 4d1a 4d1f 4d24 4d27 4d2b 4d2c
4d31 4d34 4d39 4d3a 4d3f 4d42 4d47 4d48
4d4d 4d50 4d54 4d55 4d5a 4d5d 4d62 4d63
4d68 4d6b 4d6f 4d73 4d76 4d79 4d7a 4d7c
4d7d 4d82 4d83 4d88 4d8a 4d8e 4d91 4d93
4d97 4d99 4da5 4da7 4da9 4daa 4daf 4db3
4db5 4dc1 4dc3 4dc5 4dc9 4dcc 4dce 4dd2
4dd6 4dd9 4ddd 4de1 4de5 4de9 4ded 4df0
4df3 4df4 4df6 4df9 4dfe 4dff 4e04 4e08
4e0c 4e10 4e13 4e17 4e19 4e1d 4e21 4e25
4e28 4e29 4e2b 4e2f 4e31 4e35 4e39 4e3c
4e40 4e44 4e48 4e4c 4e50 4e54 4e58 4e5c
4e60 4e64 4e68 4e6c 4e70 4e74 4e78 4e7c
4e80 4e84 4e88 4e8c 4e90 4e94 4e98 4e9c
4ea0 4ea4 4ea8 4eac 4eb0 4eb4 4eb8 4ebc
4ec0 4ec3 4ec6 4ec9 4ecc 4ecd 4ecf 4ed3
4ed7 4eda 4edd 4ede 4ee3 4ee7 4eeb 4eef
4ef3 4eff 4f03 4f08 4f0c 4f0f 4f10 4f15
4f19 4f1d 4f20 4f23 4f27 4f29 4f2d 4f31
4f34 4f37 4f3b 4f3d 4f41 4f45 4f48 4f4a
1 4f4e 4f52 4f56 4f59 4f5d 4f61 4f65
4f69 4f6c 4f70 4f74 4f77 4f7a 4f7f 4f82
4f85 4f88 4f89 4f8e 4f8f 1 4f91 4f96
4f9a 4f9e 4fa1 4fa6 4fab 4fae 4fb2 4fb3
4fb8 4fbb 4fc0 4fc1 4fc6 4fc9 4fce 4fcf
4fd4 4fd7 4fdb 4fdc 4fe1 4fe4 4fe9 4fea
4fef 4ff2 4ff6 4ffa 4ffd 5000 5001 5003
5004 5009 500a 500f 5011 5015 5018 501a
501e 5020 502c 502e 5030 5031 5036 503a
503c 5048 504a 504c 5050 5053 5057 505b
505f 5062 5063 5065 5068 506b 506c 5071
5075 5077 507b 5082 5084 5088 508b 508d
5091 5095 5098 509c 509f 50a2 50a3 50a8
50ab 50af 50b3 50b6 50b7 50b9 50bc 50bf
50c0 50c5 1 50c8 50cd 50d1 50d5 50d8
50dc 50e0 50e3 50e6 50eb 50ee 50f1 50f4
50f5 50fa 50fb 1 50fd 5102 5106 510a
510d 5112 5117 511a 511e 511f 5124 5127
512c 512d 5132 5135 513a 513b 5140 5143
5147 514b 514f 5153 5156 5157 5159 515e
515f 5161 5162 5167 516a 516f 5170 5175
5178 517d 517e 5183 5186 518a 518b 5190
5193 5198 5199 519e 519f 51a4 51a6 51aa
51ad 51b1 51b5 51b8 51bc 51c0 51c3 51c6
51cb 51ce 51d1 51d4 51d5 51da 51db 1
51dd 51e2 51e6 51ea 51ed 51f2 51f7 51fa
51fe 51ff 5204 5205 520a 520c 5210 5213
5217 521b 521e 5222 5226 5229 522d 5231
5232 5237 5239 523d 5240 5244 5248 524b
524c 524e 5251 5254 5255 525a 525e 5262
5266 5268 526c 526f 5273 5277 527b 527c
527e 5281 5282 5284 5287 528a 528b 5290
5293 5297 529b 529f 52a0 52a2 52a5 52a6
52a8 52ab 52ae 52af 52b4 1 52b7 52bc
52c0 52c5 52c8 52cd 52ce 52d3 52d6 52db
52dc 52e1 52e4 52e9 52ea 52ef 52f2 52f7
52f8 52fd 5300 5304 5308 530c 530f 5310
5312 5313 5315 5316 531b 531e 5323 5324
5329 532c 5330 5334 5338 533b 533c 533e
533f 5341 5342 5347 534a 534f 5350 5355
5358 535c 5360 5364 5367 5368 536a 536b
536d 536e 5373 5376 537b 537c 5381 5384
5389 538a 538f 5392 5397 5398 539d 53a0
53a5 53a6 53ab 53ae 53b3 53b4 53b9 53bc
53c1 53c2 53c7 53ca 53ce 53cf 53d4 53d7
53dc 53dd 53e2 53e5 53e9 53ea 53ef 53f2
53f7 53f8 53fd 5400 5405 5406 540b 540e
5413 5414 5419 541c 5421 5422 5427 542a
542e 5432 5435 5436 543b 543e 5443 5444
5449 544c 5450 5454 5457 5458 545d 5460
5465 5466 546b 546e 5473 5474 5479 547c
5481 5482 5487 548a 548e 5492 5496 5499
549a 549c 549d 549f 54a0 54a5 54a8 54ad
54ae 54b3 54b6 54ba 54be 54c2 54c5 54c6
54c8 54c9 54cb 54cc 54d1 54d4 54d9 54da
54df 54e2 54e7 54e8 54ed 54f0 54f4 54f8
54fc 54ff 5500 5502 5503 5505 5506 550b
550e 5513 5514 5519 551c 5521 5522 5527
552a 552e 552f 5534 5537 553c 553d 5542
5545 5549 554a 554f 5552 5557 5558 555d
5560 5565 5566 556b 556e 5573 5574 5579
557d 5581 5583 5587 558b 558f 5590 5592
5595 5596 5598 559b 559e 559f 55a4 55a8
55ad 55b0 55b5 55b6 55bb 55be 55c3 55c4
55c9 55cc 55d1 55d2 55d7 55da 55df 55e0
55e5 55e8 55ec 55f0 55f4 55f7 55f8 55fa
55fb 55fd 55fe 5603 5606 560b 560c 5611
5614 5618 561c 5620 5623 5624 5626 5627
5629 562a 562f 5632 5637 5638 563d 5640
5644 5648 564c 564f 5650 5652 5653 5655
5656 565b 565e 5663 5664 5669 566c 5671
5672 5677 567a 567f 5680 5685 5688 568d
568e 5693 5696 569b 569c 56a1 56a4 56a9
56aa 56af 56b2 56b6 56b7 56bc 56bf 56c4
56c5 56ca 56cd 56d1 56d2 56d7 56da 56df
56e0 56e5 56e8 56ed 56ee 56f3 56f7 56fb
56fd 5701 5705 5709 570d 570e 5710 5713
5714 5716 5719 571c 571d 5722 5726 572b
572e 5733 5734 5739 573c 5740 5744 5747
5748 574d 5750 5755 5756 575b 575e 5762
5766 5769 576a 576f 5772 5777 5778 577d
5780 5785 5786 578b 578e 5793 5794 5799
579c 57a0 57a4 57a8 57ab 57ac 57ae 57af
57b1 57b2 57b7 57ba 57bf 57c0 57c5 57c8
57cc 57d0 57d4 57d7 57d8 57da 57db 57dd
57de 57e3 57e6 57eb 57ec 57f1 57f4 57f9
57fa 57ff 5802 5806 580a 580e 5811 5812
5814 5815 5817 5818 581d 5820 5825 5826
582b 582e 5833 5834 5839 583c 5840 5841
5846 5849 584e 584f 5854 5857 585b 585c
5861 5864 5869 586a 586f 5872 5877 5878
587d 5880 5885 5886 588b 588f 5891 5895
5899 589c 58a0 58a4 58a7 58ab 58af 58b2
58b5 58ba 58bd 58c0 58c3 58c4 58c9 58ca
1 58cc 58d1 58d5 58d9 58dc 58e1 58e6
58e9 58ed 58ee 58f3 58f4 58f9 58fb 58ff
5902 5906 590a 590d 5911 5915 5918 591b
5920 5923 5926 5929 592a 592f 5930 1
5932 5937 593b 593f 5942 5947 594c 594f
5953 5954 5959 595a 595f 5961 5965 5968
596c 5970 5974 5977 597b 597c 597e 5982
5984 5988 598c 598f 5993 5997 599a 599e
59a2 59a5 59a8 59ad 59b0 59b3 59b6 59b7
59bc 59bd 1 59bf 59c4 59c8 59cc 59cf
59d4 59d9 59dc 59e0 59e1 59e6 59e7 59ec
59f0 59f4 59f7 59fc 5a01 5a04 5a08 5a0c
5a0f 5a10 5a15 5a18 5a1d 5a1e 5a23 5a26
5a2a 5a2e 5a31 5a32 5a37 5a38 5a3d 5a3f
5a43 5a46 5a4a 5a4e 5a52 5a56 5a5a 5a5e
5a62 5a66 5a6a 5a76 5a7b 5a7f 5a83 5a87
5a8b 5a8d 5a8e 5a93 1 5a97 5a9b 5a9f
5aa2 5aa6 5aaa 5aae 5ab2 5ab5 5ab9 5abd
5ac0 5ac3 5ac8 5acb 5ace 5ad1 5ad2 5ad7
5ad8 1 5ada 5adf 5ae3 5ae7 5aea 5aef
5af4 5af7 5afb 5afc 5b01 5b02 5b07 5b0b
5b0f 5b12 5b17 5b1c 5b1f 5b23 5b24 5b29
5b2c 5b31 5b32 5b37 5b3a 5b3e 5b42 5b45
5b48 5b49 5b4b 5b4c 5b51 5b52 5b57 5b59
5b5d 5b60 5b64 5b68 5b6c 5b70 5b74 5b78
5b7c 5b88 5b8d 5b91 5b95 5b99 5b9d 5b9f
5ba3 5ba5 5bb1 5bb3 5bb5 5bb6 5bbb 5bbf
5bc1 5bcd 5bd1 5bd3 5bd4 5bdd 
1a9e
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 10 :3 6 e :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 e 17
16 :2 e :2 4 f 18 17 :2 f :2 4
d 16 15 :2 d :2 4 11 1a 19
:2 11 :2 4 f 18 17 :2 f :2 4 10
19 18 :2 10 :2 4 :3 10 :2 4 11 1a
19 :2 11 :2 4 f 18 17 :2 f :2 4
13 1c 1b :2 13 :2 4 10 19 18
:2 10 :2 4 18 21 20 :2 18 :2 4 10
19 18 :2 10 :2 4 f 18 17 :2 f
:2 4 10 19 18 :2 10 :2 4 :3 9 :2 4
:3 9 :2 4 10 19 18 :2 10 :2 4 :2 c
1b c :2 4 :2 e 1d e :2 4 :2 b
1a b :2 4 :2 d 1c d :2 4 :2 10
1f 10 :2 4 :2 a 19 a :2 4 :2 b
1a b :2 4 :2 11 20 11 :2 4 :2 d
1c d :2 4 :2 c 1b c :2 4 :2 b
1a b :2 4 :2 f 1e f :2 4 :2 e
1d e :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 f 1e f :2 4 :2 b
1a b :2 4 :2 f 1e f :2 4 :2 d
1c d :2 4 :2 c 1b c :2 4 :2 c
1b c :2 4 :2 f 1e f :2 4 :2 b
1a b :2 4 :2 f 19 f :2 4 :2 f
1e f :2 4 :2 16 25 16 :2 4 :2 11
20 11 :2 4 :2 f 19 f :2 4 :2 f
19 f :2 4 :2 17 26 17 :2 4 17
1c 1b :2 17 :2 4 18 1d 1c :2 18
:2 4 :2 13 22 13 :2 4 :2 14 23 14
:2 4 9 12 11 :2 9 :2 4 :2 11 20
11 :2 4 :2 f 1e f :2 4 :2 6 1e
6 :2 4 :2 7 1f 7 :2 4 :2 d 25
d :2 4 :2 8 20 8 :2 4 :3 d :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 53 59 5c :2 53 6a 7f 8
:2 6a d 10 :2 6a 17 1a :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
2c 2f :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 2d 30 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 34 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
2f :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 2e :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 34 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 34 :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 40 :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4e 4f :2 4b :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e :2 7 52 :3 4
14 :2 4 14 :2 4 13 :2 4 12 :2 4
10 :2 4 e :2 4 14 :2 4 f :2 4
12 :2 4 e :2 4 e :2 4 11 :2 4
11 :2 4 13 :2 4 11 :2 4 14 1d
26 2e :2 1d :2 14 :2 4 12 :2 4 10
4 :4 8 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b6 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 46
:2 7 18 :2 4 :4 9 8 2a 33 3a
:2 33 48 :2 2a 4b 4d :2 4b 29 :2 8
7 a :2 14 26 :2 30 3c 3f 4e
51 52 :2 4e :2 26 :3 a :2 10 15 21
5f 62 :2 21 6f 72 :2 21 76 79
:2 21 83 86 8f 97 :2 a0 :2 8f b1
:2 86 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4e 51 52 :2 4e :2 26
:3 a :2 10 15 21 5f 62 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 41 :2 7 52
:2 4 :4 9 8 29 32 39 :2 32 48
:2 29 4b 4d :2 4b 28 :2 8 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5f 62
:2 21 6f 72 :2 21 76 79 :2 21 83
86 8f 97 :2 a0 :2 8f b1 :2 86 :2 21
:2 a 55 :2 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5f 62 :2 21 :2 a 55 :3 7
:2 12 28 :2 31 41 :2 7 52 :2 4 7
10 1b :2 7 1e 20 :2 1e 26 2f
37 :2 26 3a 3c :2 3a :2 7 42 4b
53 :2 42 56 58 :2 56 :2 7 a :2 14
26 :2 30 3c 3f 4e 51 52 :2 4e
:2 26 :3 a :2 10 15 21 5f 62 :2 21
6f 72 :2 21 76 79 :2 21 83 86
8f 97 :2 a0 :2 8f b1 :2 86 :2 21 :2 a
55 :2 7 a :2 14 26 :2 30 3c 3f
4e 51 52 :2 4e :2 26 :3 a :2 10 15
21 5f 62 :2 21 :2 a 55 :3 7 :2 12
28 :2 31 41 :2 7 5a :2 4 8 11
1c :2 8 22 1f :2 2b :2 1f 7 :4 46
45 44 :2 7 :4 14 13 12 :2 7 11
1c 21 33 3e 43 :2 f :2 a :2 13
1f a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 75 78 :2 27 7c 7f :2 27
8b 8e :2 27 96 99 :2 27 a5 a8
af b8 bb :2 a8 :2 27 :2 10 5c :2 d
:2 a :4 16 :2 a 7 :3 31 b :2 14 1f
1d :2 28 :2 1d a 3d 46 4f :2 3d
52 54 :2 52 3c :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 86 89 92
9a :2 a3 :2 92 c0 :2 89 :2 24 :2 d 58
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
62 65 :2 24 :2 d 58 :3 a :2 15 2b
:2 34 50 :2 a 57 :3 7 e 7 4
31 :4 c b a :4 2a 29 28 :2 a
11 23 f :2 a :2 13 1f a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 8b 8e :2 27
96 99 :2 27 a5 a8 af b8 bb
:2 a8 :2 27 :2 10 5c :2 d :2 a :4 16 :2 a
7 :4 43 31 :3 4 12 :2 4 d :2 16
22 29 32 3e :2 29 42 :2 4b :2 22
21 5a :2 d :2 4 13 1a 23 2f
:2 1a 33 :2 3c :2 13 12 4 7 10
18 :2 7 1b 1d :2 1b 11 1a 30
39 51 f 1a 26 f 1d 2a
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 8b 8e :2 27 96 99 :2 27
a5 a8 af b8 bb :2 a8 :2 27 :2 10
5c :2 d :2 a :4 16 :2 a 7 :3 1f b
:2 14 1f 1d :2 28 :2 1d a 26 31
3d 4d 5d 6a :2 d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 38 e :2 17 22 20 :2 2b
:2 20 d 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 89 8c 95 9d :2 a6 :2 95
b7 :2 8c :2 27 bf c2 :2 27 ca cd
:2 27 d2 d5 :2 27 e2 e5 :2 27 :2 10
5c :2 d 10 :2 1a 2c :2 36 42 45
54 57 58 :2 54 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 :2 10 5b :3 d :2 18
2c :2 35 45 53 :2 d 3b :2 a 38
:3 7 15 7 11 21 f 10 1d
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 8b 8e :2 27 96 99 :2 27
a5 a8 af b8 bb :2 a8 :2 27 :2 10
5c :2 d :2 a :4 16 :2 a 7 :3 1f a
13 1f :2 a 22 24 :2 22 14 24
12 13 20 :2 d :2 16 22 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 26 d :2 18 1f 2d :2 d 32
34 :2 32 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 89 8c 95 9d :2 a6 :2 95
bb :2 8c :2 27 c3 c6 :2 27 ce d1
:2 27 d6 d9 :2 27 e6 e9 :2 27 :2 10
5c :2 d 10 :2 1a 2c :2 36 42 45
54 57 58 :2 54 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 :2 10 5b :3 d :2 18
2c :2 35 49 57 :2 d 36 :2 a 26
:2 7 1f :4 b a d :2 17 29 :2 33
3f 42 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 62 65 :2 24 72 75
:2 24 79 7c :2 24 86 89 92 9a
:2 a3 :2 92 b9 :2 89 :2 24 :2 d 58 :2 a
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 62
65 :2 24 :2 d 58 :3 a :2 15 2b :2 34
49 :2 a 1e :3 7 16 :2 7 13 1a
21 2e 31 :2 1a 36 39 :2 13 :2 7
15 :2 1e 27 2a 2d 31 :2 15 7
a 18 21 29 :2 18 :2 a 2d 30
:2 2d 14 20 29 3f 48 60 12
20 2b 37 12 20 2d 3b 47
50 5b 64 70 79 87 90 9e
a7 :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 32
e :2 17 22 20 :2 2b :2 20 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 89
8c 95 9d :2 a6 :2 95 b9 :2 8c :2 27
c1 c4 :2 27 cc cf :2 27 d4 d7
:2 27 e1 e4 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 :2 10 5b :3 d :2 18 2c :2 35 47
52 :2 d 3b :2 a 32 d :2 17 29
:2 33 3f 43 52 55 56 :2 52 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 86 89 92
9a :2 a3 :2 92 b6 :2 89 :2 24 be c1
:2 24 c9 cc :2 24 d1 d4 :2 24 de
e1 :2 24 :2 d 59 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 :2 d
58 :3 a :2 15 29 :2 32 44 4f :2 a
:4 7 :4 4 8 11 1d :2 8 20 22
:2 20 7 2a 33 3b :2 2a 3e 41
:2 3e 29 :3 7 11 7 46 :2 4 7
b d :2 b 7 15 :2 7 16 :2 7
15 26 32 3f 48 51 :2 3f 55
5e 66 :2 55 22 2b 37 :2 22 3b
44 4f :2 3b 53 20 2b :2 53 2f
38 46 :2 2f 4a 53 5e :2 4a 22
2b 37 :2 22 3b 43 4d :2 15 7
a 13 1f :2 a 24 22 :2 2d :2 22
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 62
65 :2 24 72 75 :2 24 79 7c :2 24
86 89 92 9a :2 a3 :2 92 b4 :2 89
:2 24 :2 d 58 :2 a d :2 17 29 :2 33
3f 42 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 62 65 :2 24 :2 d 58
:3 a :2 15 2b :2 34 44 :2 a 7 3c
d 16 22 :2 d 25 28 :2 25 d
:2 17 29 :2 33 3f 43 52 55 56
:2 52 :2 29 :3 d :2 13 18 24 62 65
:2 24 72 75 :2 24 79 7c :2 24 86
89 92 9a :2 92 a7 :2 89 :2 24 af
b2 :2 24 ba bd :2 24 c2 c5 :2 24
d2 d5 :2 24 :2 d 59 :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 62 65 :2 24
:2 d 58 :3 a :2 15 29 32 3e :2 29
42 50 :2 a 2a 3c :2 7 f :2 4
8 11 19 :2 8 1c 1e :2 1c 7
26 2f 37 :2 26 3a 3d :2 3a 25
:2 7 b 14 1c :2 b 1f 21 :2 1f
a 28 31 39 :2 28 3c 3e :2 3c
27 :3 a 15 a 7 41 d 16
1e :2 d 21 23 :2 21 a 15 a
7 25 41 e 17 1f :2 e 22
24 :2 22 d 2b 34 3c :2 2b 3f
41 :2 3f 2a :2 d a 15 a 7
44 41 d 16 1e :2 d 21 23
:2 21 a 14 1d 29 :2 14 2c 2e
37 3f :2 2e :2 14 :2 a 15 a 25
41 :2 7 42 :2 4 7 10 1a :2 7
1d 1f :2 1d a 13 1f :2 a 22
24 :2 22 d :2 17 29 :2 33 3f 43
52 55 56 :2 52 :2 29 :3 d :2 13 18
24 62 65 :2 24 72 75 :2 24 79
7c :2 24 86 89 92 9a :2 a3 :2 92
ba :2 89 :2 24 c2 c5 :2 24 cd d0
:2 24 d5 d8 :2 24 e5 e8 :2 24 :2 d
59 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 62 65 :2 24 :2 d 58 :3 a :2 15
29 :2 32 48 56 :2 a 29 :2 7 a
13 1f :2 a 22 24 :2 22 a 18
a 27 a 18 1e 27 33 :2 1e
36 38 :2 1e :2 18 a :4 7 21 :3 4
:3 17 :2 4 12 :2 4 13 :2 4 13 :2 4
13 :2 4 10 17 21 24 :2 10 :2 4
12 19 25 28 :2 12 4 7 10
18 :2 7 1b 1d :2 1b 7 f :2 7
15 7 a 11 1d 20 :2 a 23
25 :2 23 14 27 2f 36 51 59
60 7c 86 d 1b 12 27 2d
33 3f d 19 12 13 1b 2c
38 45 5b :2 d :2 16 22 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 29 14 26 37 46 53 :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :3 29 e :2 17
22 20 :2 2b :2 20 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 b9 :2 8c :2 27 c1 c4
:2 27 cc cf :2 27 d4 d7 :2 27 e0
e3 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 47 51 :2 d
3b :3 a 19 a 14 27 38 45
12 13 20 2e 46 54 :2 d :2 16
22 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 29 7 29 d
14 20 23 :2 d 26 28 :2 26 14
23 34 44 52 :2 d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 2c e :2 17 22 20 :2 2b
:2 20 d 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 89 8c 95 9d :2 a6 :2 95
b9 :2 8c :2 27 c1 c4 :2 27 cc cf
:2 27 d4 d7 :2 27 e0 e3 :2 27 :2 10
5c :2 d 10 :2 1a 2c :2 36 42 45
54 57 58 :2 54 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 :2 10 5b :3 d :2 18
2c :2 35 47 51 :2 d 3b :3 a 18
a 14 27 2f 36 51 59 60
7c 86 d 1b 12 27 2d 33
3f d 19 12 13 1b 2c 38
45 5b :2 d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 2c e :2 17 22 20 :2 2b :2 20 d
17 2a 32 39 54 5c 63 7f
89 10 1e 15 2a 30 36 42
10 1c 15 16 1e 2f 3b 48
5e :2 10 :2 19 25 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5e 5f :2 5b :2 32 :3 16 :2 1c
21 2d 6b 6e :2 2d 7b 7e :2 2d
82 85 :2 2d 91 94 :2 2d 9c 9f
:2 2d ab ae b5 be c1 :2 ae :2 2d
:2 16 62 :2 13 :2 10 :4 1c :2 10 d :4 3b
:2 a 14 27 38 45 12 13 20
2e 46 54 :2 d :2 16 22 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :4 2c 29 d :2 17 29 :2 33 3f
42 51 54 55 :2 51 :2 29 :3 d :2 13
18 24 62 65 :2 24 72 75 :2 24
79 7c :2 24 86 89 92 9a :2 a3
:2 92 b4 :2 89 :2 24 :2 d 58 :2 a d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 62 65
:2 24 :2 d 58 :3 a :2 15 2b :2 34 44
:2 a :4 7 b :2 14 1f 1d :2 28 :2 1d
:2 a 1d 2b 2e 37 3f :2 2e 43
:2 4c 24 :2 1d :2 a 1d 2b 2e 37
3f :2 2e 43 :2 4c 24 :2 1d a 14
2d 12 20 38 49 52 5d 66
72 7b 89 92 a0 a9 bd c6
12 20 39 42 12 20 38 41
12 1b 23 30 39 :2 12 20 3a
12 13 27 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 38 a 1d 33
:2 1d a 38 a :3 19 :2 a 1d 2b
2e 37 3f :2 2e 43 :2 4c 24 :2 1d
:2 a 20 :2 29 :2 a 1c :2 a 1d 34
42 4c 54 2d 41 4d :2 1d a
19 2e 41 4d 59 67 d 1c
29 36 43 4d 15 22 30 3b
43 d 19 23 2c 39 4d 5a
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :7 7 b 14 21 :2 b 24 26
:2 24 a :4 2f 2e 2d :2 a 14 36
4a 60 6d :2 d :2 16 22 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 42 d 14 24 27 :2 d 2a
2c :2 2a d 1d 1e :2 1d :2 d :2 16
22 39 47 55 6a 2f 35 41
4d 2f 42 :2 22 d 30 :2 a 42
:3 7 15 7 a 11 1d 20 :2 a
23 25 :2 23 a 15 :2 1e a 29
a 15 1e 2a :2 15 a :5 7 13
1f 2c 3a 45 4f 5b 1b 28
35 42 4f 1b 28 34 3e 46
4f 57 5e 1b 27 34 3f 4a
58 1b 26 32 3e 41 44 4a
:2 13 7 a 13 15 :2 13 14 27
44 4b d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :4 17 :2 7 1f 7 15
:2 7 16 :2 7 16 7 a 13 1a
:2 13 28 :2 a 2b 2d :2 2b a 16
a 30 a 16 1d 26 2d :2 26
3b :2 1d 3e 40 :2 1d 1c 43 45
:2 1c :2 16 a :4 7 a 13 15 :2 13
a 15 :2 a 10 19 22 :2 10 27
25 30 :2 25 a d 19 :2 22 2b
2f 33 3c 45 :2 33 48 4a :2 33
4c 4d :2 33 50 :2 19 :2 d 1b :2 24
2d 30 33 3c 45 :2 33 48 4a
:2 33 4d 4f :2 33 51 52 :2 33 55
:2 1b d 10 17 23 26 :2 10 29
2b :2 29 10 1b :2 24 10 13 1c
23 :2 1c 31 :2 13 34 36 :2 34 13
22 13 38 13 22 29 35 38
:2 29 41 44 :2 22 :2 13 22 29 35
38 :2 29 42 45 :2 22 13 :4 10 2f
10 1b 24 30 :2 1b 10 13 1c
23 :2 1c 30 :2 13 33 35 :2 33 13
21 13 37 13 21 28 33 36
:2 28 3f 42 :2 21 :2 13 21 28 33
36 :2 28 40 43 :2 21 13 :4 10 :4 d
10 17 23 26 :2 10 29 2b :2 29
24 2c 33 51 59 60 7a 82
89 18 33 40 18 28 19 21
32 3e 4b :2 13 :2 1c 28 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 5e 61 62 :2 5e :2 35
:3 19 :2 1f 24 30 6e 71 :2 30 7e
81 :2 30 85 88 :2 30 94 97 :2 30
9f a2 :2 30 ae b1 b8 c1 c4
:2 b1 :2 30 :2 19 65 :2 16 :2 13 :4 1f :2 13
10 :3 2f 10 1b :2 10 1f 10 2f
24 2c 33 51 59 60 7a 82
89 18 33 40 18 28 19 21
32 3e 4b 61 :2 13 :2 1c 28 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 5e 61 62 :2 5e
:2 35 :3 19 :2 1f 24 30 6e 71 :2 30
7e 81 :2 30 85 88 :2 30 94 97
:2 30 9f a2 :2 30 ae b1 b8 c1
c4 :2 b1 :2 30 :2 19 65 :2 16 :2 13 :4 1f
:2 13 10 :3 d 14 :2 1d 28 26 :2 31
:2 26 13 27 2f 36 54 5c 63
7d 85 8c 1b 36 43 1b 2b
1c 24 35 41 4e 64 :2 16 :2 1f
2b 16 13 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 61 64
65 :2 61 :2 38 :3 1c :2 22 27 33 71
74 :2 33 81 84 :2 33 88 8b :2 33
97 9a :2 33 a2 a5 :2 33 b1 b4
bb c4 c7 :2 b4 :2 33 :2 1c 68 :2 19
:2 16 :4 22 :2 16 13 :4 41 :2 10 :5 d 1b
d 10 17 23 26 :2 10 29 2b
:2 29 10 1b :2 24 10 2f 10 1b
24 30 :2 1b 10 :5 d 1b :2 d 19
25 32 40 4b 55 61 1b 28
35 42 4f 1b 28 34 3e 46
4f 57 5e 1b 27 34 3f 4a
58 1b 26 32 3e 41 44 4a
:2 19 d 10 19 1b :2 19 1a 2d
4a 51 13 1a 16 22 :3 20 16
:2 1f 2b 16 27 16 :2 1f 2b 16
:4 13 10 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 5e 61 62
:2 5e :2 35 :3 19 :2 1f 24 30 6e 71
:2 30 7e 81 :2 30 85 88 :2 30 94
97 :2 30 9f a2 :2 30 ae b1 b8
c1 c4 :2 b1 :2 30 :2 19 65 :2 16 :2 13
:4 1f :2 13 10 :4 1d :3 d 18 21 2a
:2 18 2d 2f :2 18 d 30 e a
17 :2 7 :4 4 8 11 14 :2 11 7
1c 25 2d :2 1c 30 32 :2 30 1b
:2 7 a :2 14 26 :2 30 3c 40 4f
52 53 :2 4f :2 26 :3 a :2 10 15 21
5f 62 :2 21 6f 72 :2 21 76 79
:2 21 83 86 8f 97 :2 a0 :2 8f c1
:2 86 :2 21 c9 cc :2 21 d4 d7 :2 21
dc df :2 21 eb ee :2 21 :2 a 56
:2 7 a :2 14 26 :2 30 3c 3f 4e
51 52 :2 4e :2 26 :3 a :2 10 15 21
5f 62 :2 21 :2 a 55 :3 7 :2 12 26
:2 2f 4f f :2 7 35 :2 4 7 10
18 :2 7 1b 1d :2 1b 7 17 7
1f :2 4 8 11 18 :2 11 25 :2 8
28 2a :2 28 7 32 3b 42 :2 3b
50 :2 32 53 55 :2 53 31 :3 7 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d 2c 2f 37 40
4a :2 37 :2 2f :2 d 4e 51 :2 d 13
16 1e 27 30 :2 1e :2 16 :2 d 13
16 :2 d e 11 19 22 2d :2 19
:2 11 :2 d 13 16 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d 29 2c :2 d 13
16 :2 d 4e 51 :2 d 13 16 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 1a :2 d 32 35 :2 d
48 4b :2 54 :2 d 13 16 :2 d e
11 :2 d e 11 :2 d 47 4a 52
5b 65 :2 52 :2 4a :2 d 13 16 :2 d
2a 2d 35 3e 47 :2 35 :2 2d :2 d
4b 4e :2 d e 11 :2 d 54 57
5f 13 1e :2 5f :2 57 :2 d 13 16
:2 d e 11 :2 d 4d 50 :2 d 13
16 :2 d 50 53 :2 d 13 16 :2 d
e 11 :2 d e 11 :2 d 7 4
58 a 13 1a :2 13 27 :2 a 2a
2c :2 2a 7 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
2c 2f 37 40 4a :2 37 :2 2f :2 d
4e 51 :2 d 13 16 1e 27 30
:2 1e :2 16 :2 d 13 16 :2 d e 11
19 22 2d :2 19 :2 11 :2 d 13 16
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
29 2c :2 d 13 16 :2 d 4e 51
:2 d 13 16 :2 d e 11 :2 d 7
4 2e 58 a 13 1a :2 13 28
:2 a 2b 2d :2 2b 7 d e 11
:2 d e 11 :2 1a :2 d 32 35 :2 d
48 4b :2 54 :2 d 13 16 :2 d e
11 :2 d e 11 :2 d 47 4a 52
5b 65 :2 52 :2 4a :2 d 13 16 :2 d
2a 2d 35 3e 47 :2 35 :2 2d :2 d
4b 4e :2 d e 11 :2 d 54 57
5f 13 1e :2 5f :2 57 :2 d 13 16
:2 d e 11 :2 d 4d 50 :2 d 13
16 :2 d 50 53 :2 d 13 16 :2 d
e 11 :2 d e 11 :2 d 7 2f
58 :2 4 7 :2 11 23 :2 2d 39 3c
4b 4e 4f :2 4b :2 23 :3 7 :2 d 12
1e 5c 5f :2 1e :2 7 52 :2 4 7
:2 11 23 :2 2d 39 3c 4b 4e 4f
:2 4b :2 23 :3 7 :2 d 12 1e 5c 5f
:2 1e :2 7 52 :3 4 b :2 16 26 :2 b
4 1 9 12 9 a :2 14 26
:2 30 3c 40 4f 52 53 :2 4f :2 26
:3 a :2 10 15 21 5f 62 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 56
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 4c 50 51 :2 4c :2 23
:3 7 :2 d 12 1e 5d 60 :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 54 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
1a9e
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :5 1b
:7 1c :7 1d :7 1e :7 1f
:7 20 :7 21 :7 22 :7 23
:5 24 :5 25 :7 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :7 45 :7 46 :6 47
:6 48 :7 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:5 50 :7 52 :b 54 :11 55
56 :2 55 :2 56 :2 55
:2 56 :2 55 :2 57 :2 55
:2 57 :2 55 :2 57 :2 55
:2 57 :2 55 :2 58 :2 55
:2 58 :2 55 :2 58 :2 55
:2 58 :2 55 :2 59 :2 55
:9 59 :2 55 :2 5a :2 55
:9 5a :2 55 :2 5b :2 55
:9 5b :2 55 :2 5c :2 55
:9 5c :2 55 :2 5d :2 55
:9 5d :2 55 :2 5e :2 55
:9 5e :2 55 :2 5f :2 55
:9 5f :2 55 :2 60 :2 55
:9 60 :2 55 :2 61 :2 55
:9 61 :2 55 :2 62 :2 55
:9 62 :2 55 :2 63 :2 55
:2 63 :2 55 :2 63 :2 55
:2 63 :2 55 :2 64 :2 55
:2 64 :2 55 :2 64 :2 55
:2 64 :2 55 :2 64 :4 55
:3 54 :11 67 :b 68 :3 67
:3 6f :3 70 :3 71 :3 72
:3 74 :3 76 :3 78 :3 7a
:3 7b :3 7c :3 7d :3 7e
:3 7f :3 80 :3 82 :a 83
:3 88 :3 89 :5 8b :11 8c
:20 8d :3 8c :11 8f :b 90
:3 8f :9 92 :3 8b :15 95
:11 96 :20 97 :3 96 :11 99
:b 9a :3 99 :9 9c :3 95
:15 9f :11 a0 :20 a1 :3 a0
:11 a3 :b a4 :3 a3 :9 a6
:3 9f :1f a9 :11 aa :20 ab
:3 aa :11 ad :b ae :3 ad
:9 b0 :3 a9 :14 b3 :6 b4
:2 b3 :6 b6 b7 b8
b6 :5 b9 b5 :2 bb
:5 bd :11 be :24 bf :3 be
:2 bc :6 bb ba :3 b4
:16 c4 :11 c5 :20 c6 :3 c5
:11 c8 :b c9 :3 c8 :9 cb
:3 c4 :3 ce cf b4
:e cf :2 d1 d2 d1
:5 d3 d0 :2 d5 :5 d7
:11 d8 :24 d9 :3 d8 :2 d6
:6 d5 d4 :4 cf b4
:2 b3 :3 df :14 e1 :e e3
:9 e6 :5 e8 :3 e9 :3 ea
e8 :5 eb e7 :2 ed
:5 ef :11 f0 :24 f1 :3 f0
:2 ee :6 ed ec :3 e6
:a f6 :7 f8 :5 f9 f7
:2 fb :5 fd :11 fe :24 ff
:3 fe :2 fc :6 fb fa
:3 f6 :a 103 :11 104 :30 105
:3 104 :11 107 :b 108 :3 107
:a 10a :3 103 :3 f6 :3 10e
:2 110 111 :2 112 110
:5 113 10f :2 115 :5 117
:11 118 :24 119 :3 118 :2 116
:6 115 114 :3 e6 :9 11e
:2 120 121 :2 122 120
:5 123 11f :2 125 :5 127
:11 128 :24 129 :3 128 :2 126
:6 125 124 :3 11e :b 12e
:11 12f :30 130 :3 12f :11 132
:b 133 :3 132 :a 135 :3 12e
:3 11e e6 :5 139 :11 13a
:20 13b :3 13a :11 13d :b 13e
:3 13d :9 140 :3 139 :3 143
:d 147 :b 14b :c 14d :6 14f
:4 150 :e 151 14f :5 152
14e :2 154 :5 156 :11 157
:24 158 :3 157 :2 155 :6 154
153 :3 14d :a 15d :11 15e
:30 15f :3 15e :11 161 :b 162
:3 161 :a 164 :3 15d 14d
:11 167 :30 168 :3 167 :11 16a
:b 16b :3 16a :a 16d 166
:3 14d 138 :3 e6 :16 172
:3 173 :3 172 :5 176 :3 178
:3 179 :e 17b :b 17c :2 17d
:2 17c :a 17d :8 17e :3 17b
:b 180 :11 181 :20 182 :3 181
:11 184 :b 185 :3 184 :9 187
188 180 :9 188 :11 189
:2e 18a :3 189 :11 18c :b 18d
:3 18c :c 18f 188 :3 180
:3 176 :16 192 :16 193 :3 194
195 193 :9 195 :3 196
197 195 193 :16 197
:3 198 199 197 193
:9 199 :f 19a :3 19b 199
:3 193 :3 192 :9 1a0 :9 1a1
:11 1a2 :30 1a3 :3 1a2 :11 1a5
:b 1a6 :3 1a5 :a 1a8 :3 1a1
:9 1aa :3 1ab 1aa :e 1ad
1ac :3 1aa :3 1a0 :5 1b1
:3 1b4 :3 1b5 :3 1b6 :3 1b7
:8 1b9 :8 1bb :9 1c0 :3 1c1
:3 1c2 :a 1c3 :9 1cd :2 1ce
:5 1cf :2 1d0 1d1 :6 1d2
1cd :5 1d3 1cc :2 1d5
:5 1d7 :11 1d8 :24 1d9 :3 1d8
:2 1d6 :6 1d5 1d4 :3 1c3
:6 1df :5 1e0 1de :2 1e2
:5 1e4 :11 1e5 :24 1e6 :3 1e5
:2 1e3 :6 1e2 1e1 :3 1c3
:a 1eb :11 1ec :30 1ed :3 1ec
:11 1ef :b 1f0 :3 1ef :a 1f2
:3 1eb :3 1f5 :4 1f8 1f9
:5 1fa 1f8 :5 1fb 1f7
:2 1fd :5 1ff :11 200 :24 201
:3 200 :2 1fe :6 1fd 1fc
:3 1c3 205 1c3 :a 205
:6 207 :5 208 206 :2 20a
:5 20c :11 20d :24 20e :3 20d
:2 20b :6 20a 209 :3 205
:a 213 :11 214 :30 215 :3 214
:11 217 :b 218 :3 217 :a 21a
:3 213 :3 21d :9 220 :2 221
:5 222 :2 223 224 :6 225
220 :5 226 21f :2 228
:5 22a :11 22b :24 22c :3 22b
:2 229 :6 228 227 :3 205
:a 23d :9 23f :2 240 :5 241
:2 242 243 :6 244 23f
:5 245 23e :2 247 :5 249
:11 24a :24 24b :3 24a :2 248
:6 247 246 :6 23d :4 253
254 :5 255 253 :5 256
252 :2 258 :5 25a :11 25b
:24 25c :3 25b :2 259 :6 258
257 :4 205 1c3 :11 261
:20 262 :3 261 :11 264 :b 265
:3 264 :9 267 260 :3 1c3
:a 26b :b 26c 26d :3 26c
:b 26e 26f :3 26e :2 272
:f 274 :4 275 :4 276 :5 277
278 :3 27a 27b :2 27d
272 :6 27e :5 27f 27e
:5 281 280 :3 27e 271
:2 284 :5 286 :11 287 :24 288
:3 287 :2 285 :6 284 283
:3 26b :6 28d 26b :5 290
:b 292 293 :3 292 :5 295
:3 296 :6 298 :3 299 :3 298
:6 29c :6 29d :5 29e :7 29f
29c :6 2a0 :5 2a1 2a0
:5 2a3 2a2 :3 2a0 29b
:2 2a6 :5 2a8 :11 2a9 :24 2aa
:3 2a9 :2 2a7 :6 2a6 2a5
:4 28e :3 26b :12 2b1 :6 2b3
:5 2b4 2b2 :2 2b6 :5 2b8
:11 2b9 :24 2ba :3 2b9 :2 2b7
:6 2b6 2b5 :3 2b1 :a 2c0
:6 2c1 :8 2c2 :4 2c3 :2 2c4
:3 2c2 :3 2c0 :3 2b1 :3 2c8
:a 2cd :5 2ce 2cd :7 2d1
2cf :3 2cd :8 2d5 :5 2d6
:8 2d7 :6 2d8 :7 2d9 :3 2d5
:5 2dc :5 2de :6 2df :5 2e0
2df :5 2e2 2e1 :3 2df
2dd :2 2e5 :5 2e7 :11 2e8
:24 2e9 :3 2e8 :2 2e6 :6 2e5
2e4 :6 2dc 1c0 :3 2ef
:3 2f0 :3 2f2 :c 2f4 :3 2f5
2f4 :16 2f7 2f6 :3 2f4
:5 2fa :3 2fb :c 2fc :17 2ff
:1b 301 :a 303 :5 304 :c 306
:3 307 306 :c 309 :c 30a
308 :3 306 303 :7 30d
:c 30f :3 310 30f :c 312
:c 313 311 :3 30f 30c
:3 303 :a 317 :9 319 :3 31a
:2 31b :5 31c 319 :5 31d
318 :2 31f :5 321 :11 322
:24 323 :3 322 :2 320 :6 31f
31e :3 317 :3 328 :3 329
317 :9 32d :3 32e :2 32f
:6 330 32d :5 331 32c
:2 333 :5 335 :11 336 :24 337
:3 336 :2 334 :6 333 332
:3 32b :a 33c :9 33e :3 33f
:2 340 :6 341 33e :5 342
33d :2 344 :5 346 :11 347
:24 348 :3 347 :2 345 :6 344
343 :6 33c 32b :3 317
:3 350 :a 352 :5 353 352
:7 355 354 :3 352 :3 358
:8 35a :5 35b :8 35c :6 35d
:7 35e :3 35a :5 361 :5 363
:6 364 :5 365 364 :5 367
366 :3 364 362 :2 36a
:5 36c :11 36d :24 36e :3 36d
:2 36b :6 36a 369 :6 361
:b 374 2fc 375 2fc
:3 2fa 2ee :3 1c0 :12 37a
:11 37b :30 37c :3 37b :11 37e
:b 37f :3 37e :7 381 382
:2 381 :3 37a :9 385 :3 386
:3 385 :1c 38b 38c 38d
:2 38e :2 38d :2 38f :2 38d
:2 390 :2 38d :2 391 :2 38d
:9 391 :2 38d :2 391 :2 38d
:9 392 :2 38d :2 393 :2 38d
:9 394 :2 38d :2 395 :2 38d
:2 396 :2 38d :2 397 :2 38d
:2 398 :2 38d :2 399 :2 38d
:2 39a :2 38d :2 39a :2 38d
:2 39b :2 38d :2 39b :2 38d
:2 39c :2 38d :2 39d :2 38d
:2 39e :2 38d :2 39f :2 38d
:4 3a0 :2 38d :2 3a0 :2 38d
:4 3a0 :2 38d :2 3a1 :2 38d
:2 3a2 :2 38d :2 3a3 :2 38d
:9 3a3 :2 38d :2 3a4 :2 38d
:9 3a4 :2 38d :2 3a4 :2 38d
:2 3a5 :2 38d :3 3a5 :2 3a6
:4 3a5 :2 38d :2 3a7 :2 38d
:2 3a8 :2 38d :2 3a8 :2 38d
:2 3a9 :2 38d :2 3a9 :2 38d
:2 3aa :2 38d :2 3ab :2 38d
:2 3ac :2 38d 38c 3ad
38b :c 3ad 3ae 3af
:2 3b0 :2 3af :2 3b1 :2 3af
:2 3b2 :2 3af :2 3b3 :2 3af
:9 3b3 :2 3af :2 3b3 :2 3af
:9 3b4 :2 3af :2 3b5 :2 3af
:9 3b6 :2 3af :2 3b7 :2 3af
:2 3b8 :2 3af :2 3b9 :2 3af
:2 3ba :2 3af :2 3bb :2 3af
:2 3bc :2 3af :2 3bc :2 3af
:2 3bd :2 3af :2 3bd :2 3af
:2 3be :2 3af :2 3bf :2 3af
3ae 3c0 3ad 38b
:c 3c0 3c1 3c2 :2 3c3
:2 3c2 :4 3c4 :2 3c2 :2 3c4
:2 3c2 :4 3c4 :2 3c2 :2 3c5
:2 3c2 :2 3c6 :2 3c2 :2 3c7
:2 3c2 :9 3c7 :2 3c2 :2 3c8
:2 3c2 :9 3c8 :2 3c2 :2 3c8
:2 3c2 :2 3c9 :2 3c2 :3 3c9
:2 3ca :4 3c9 :2 3c2 :2 3cb
:2 3c2 :2 3cc :2 3c2 :2 3cc
:2 3c2 :2 3cd :2 3c2 :2 3cd
:2 3c2 :2 3ce :2 3c2 :2 3cf
:2 3c2 :2 3d0 :2 3c2 3c1
3c0 :3 38b :11 3d4 :b 3d5
:3 3d4 :11 3d7 :b 3d8 :3 3d7
:8 3da 53 :3 3de :11 3df
:b 3e0 :17 3e1 :3 3df :2 3e3
:3 3e4 :3 3e5 3e6 3e4
3e3 3e4 :3 3e7 :3 3de
:2 3e8 :5 3ea :11 3eb :b 3ec
:18 3ed :3 3eb :2 3ef 3f0
:3 3f1 3f2 3f0 3ef
3f0 :3 3f3 :2 3e9 :6 3e8
3dd :7 1 
5bdf
4
:3 0 1 :3 0 2
:a 0 1a99 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f 4 :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 1a99 2 44
:2 0 18 :2 0 33
4 :3 0 18 :2 0
31 47 49 :6 0
4c 4a 0 1a97
0 17 :6 0 18
:2 0 37 4 :3 0
35 4e 50 :6 0
53 51 0 1a97
0 19 :6 0 18
:2 0 3b 4 :3 0
39 55 57 :6 0
5a 58 0 1a97
0 1a :6 0 1d
:2 0 3f 4 :3 0
3d 5c 5e :6 0
61 5f 0 1a97
0 1b :6 0 1d
:2 0 43 4 :3 0
41 63 65 :6 0
68 66 0 1a97
0 1c :6 0 1d
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 1a97
0 1e :6 0 4d
21f 0 4b 4
:3 0 49 71 73
:6 0 76 74 0
1a97 0 1f :6 0
23 :2 0 51 21
:3 0 78 :7 0 7b
79 0 1a97 0
20 :6 0 4 :3 0
23 :2 0 4f 7d
7f :6 0 82 80
0 1a97 0 22
:6 0 23 :2 0 55
4 :3 0 53 84
86 :6 0 89 87
0 1a97 0 24
:6 0 18 :2 0 59
4 :3 0 57 8b
8d :6 0 90 8e
0 1a97 0 25
:6 0 18 :2 0 5d
4 :3 0 5b 92
94 :6 0 97 95
0 1a97 0 26
:6 0 29 :2 0 61
4 :3 0 5f 99
9b :6 0 9e 9c
0 1a97 0 27
:6 0 29 :2 0 65
4 :3 0 63 a0
a2 :6 0 a5 a3
0 1a97 0 28
:6 0 29 :2 0 69
4 :3 0 67 a7
a9 :6 0 ac aa
0 1a97 0 2a
:6 0 6f 322 0
6d 4 :3 0 6b
ae b0 :6 0 b3
b1 0 1a97 0
2b :6 0 2f :2 0
71 21 :3 0 b5
:7 0 b8 b6 0
1a97 0 2c :6 0
21 :3 0 ba :7 0
bd bb 0 1a97
0 2d :6 0 31
:2 0 75 4 :3 0
73 bf c1 :6 0
c4 c2 0 1a97
0 2e :6 0 31
:2 0 77 8 :3 0
c6 :7 0 ca c7
c8 1a97 0 30
:6 0 31 :2 0 79
8 :3 0 cc :7 0
d0 cd ce 1a97
0 32 :6 0 31
:2 0 7b 8 :3 0
d2 :7 0 d6 d3
d4 1a97 0 33
:6 0 31 :2 0 7d
8 :3 0 d8 :7 0
dc d9 da 1a97
0 34 :6 0 31
:2 0 7f 8 :3 0
de :7 0 e2 df
e0 1a97 0 35
:6 0 31 :2 0 81
8 :3 0 e4 :7 0
e8 e5 e6 1a97
0 36 :6 0 31
:2 0 83 8 :3 0
ea :7 0 ee eb
ec 1a97 0 37
:6 0 31 :2 0 85
8 :3 0 f0 :7 0
f4 f1 f2 1a97
0 38 :6 0 31
:2 0 87 8 :3 0
f6 :7 0 fa f7
f8 1a97 0 39
:6 0 31 :2 0 89
8 :3 0 fc :7 0
100 fd fe 1a97
0 3a :6 0 31
:2 0 8b 8 :3 0
102 :7 0 106 103
104 1a97 0 3b
:6 0 31 :2 0 8d
8 :3 0 108 :7 0
10c 109 10a 1a97
0 3c :6 0 31
:2 0 8f 8 :3 0
10e :7 0 112 10f
110 1a97 0 3d
:6 0 31 :2 0 91
8 :3 0 114 :7 0
118 115 116 1a97
0 3e :6 0 31
:2 0 93 8 :3 0
11a :7 0 11e 11b
11c 1a97 0 3f
:6 0 31 :2 0 95
8 :3 0 120 :7 0
124 121 122 1a97
0 40 :6 0 31
:2 0 97 8 :3 0
126 :7 0 12a 127
128 1a97 0 41
:6 0 31 :2 0 99
8 :3 0 12c :7 0
130 12d 12e 1a97
0 42 :6 0 31
:2 0 9b 8 :3 0
132 :7 0 136 133
134 1a97 0 43
:6 0 31 :2 0 9d
8 :3 0 138 :7 0
13c 139 13a 1a97
0 44 :6 0 31
:2 0 9f 8 :3 0
13e :7 0 142 13f
140 1a97 0 45
:6 0 31 :2 0 a1
8 :3 0 144 :7 0
148 145 146 1a97
0 46 :6 0 31
:2 0 a3 8 :3 0
14a :7 0 14e 14b
14c 1a97 0 47
:6 0 31 :2 0 a5
49 :3 0 150 :7 0
154 151 152 1a97
0 48 :6 0 31
:2 0 a7 8 :3 0
156 :7 0 15a 157
158 1a97 0 4a
:6 0 31 :2 0 a9
8 :3 0 15c :7 0
160 15d 15e 1a97
0 4b :6 0 4e
:2 0 ab 8 :3 0
162 :7 0 166 163
164 1a97 0 4c
:6 0 4e :2 0 ad
49 :3 0 168 :7 0
16c 169 16a 1a97
0 4d :6 0 31
:2 0 af 49 :3 0
16e :7 0 172 16f
170 1a97 0 4f
:6 0 18 :2 0 b1
8 :3 0 174 :7 0
178 175 176 1a97
0 50 :6 0 18
:2 0 b5 52 :3 0
b3 17a 17c :6 0
17f 17d 0 1a97
0 51 :6 0 31
:2 0 b9 52 :3 0
b7 181 183 :6 0
186 184 0 1a97
0 53 :6 0 31
:2 0 bb 8 :3 0
188 :7 0 18c 189
18a 1a97 0 54
:6 0 57 :2 0 bd
8 :3 0 18e :7 0
192 18f 190 1a97
0 55 :6 0 31
:2 0 c1 4 :3 0
bf 194 196 :6 0
199 197 0 1a97
0 56 :6 0 31
:2 0 c3 8 :3 0
19b :7 0 19f 19c
19d 1a97 0 58
:6 0 23 :2 0 c5
8 :3 0 1a1 :7 0
1a5 1a2 1a3 1a97
0 59 :6 0 23
:2 0 c7 8 :3 0
1a7 0 2 :5 0
1ab 1a8 1a9 1a97
0 5a :6 0 31
:2 0 c9 8 :3 0
1ad 0 2 :5 0
1b1 1ae 1af 1a97
0 5b :6 0 31
:2 0 cb 8 :3 0
1b3 0 2 :5 0
1b7 1b4 1b5 1a97
0 5c :6 0 cf
7f2 0 cd 8
:3 0 1b9 0 2
:5 0 1bd 1ba 1bb
1a97 0 5d :6 0
1ca 1cb 0 d1
8 :3 0 1bf :7 0
1c2 1c0 0 1a97
0 5e :6 0 15
:3 0 16 :2 0 4
1c4 1c5 0 1c6
:7 0 1c9 1c7 0
1a97 0 5f :6 0
60 :3 0 61 :3 0
60 :3 0 62 :3 0
1cd 1ce 0 2
:4 0 d3 1cf 1d1
1cc 1d3 1d2 :2 0
63 :3 0 64 :3 0
1d5 1d6 0 65
:4 0 60 :3 0 66
:3 0 1d9 1da 0
2 :4 0 d5 1db
1dd 67 :4 0 68
:2 0 69 :3 0 d7
1e0 1e2 :3 0 6a
:4 0 68 :2 0 6b
:4 0 da 1e5 1e7
:3 0 68 :2 0 3
:3 0 dd 1e9 1eb
:3 0 68 :2 0 6b
:4 0 e0 1ed 1ef
:3 0 68 :2 0 6c
:4 0 e3 1f1 1f3
:3 0 68 :2 0 6b
:4 0 e6 1f5 1f7
:3 0 68 :2 0 5
:3 0 e9 1f9 1fb
:3 0 68 :2 0 6b
:4 0 ec 1fd 1ff
:3 0 68 :2 0 6c
:4 0 ef 201 203
:3 0 68 :2 0 6b
:4 0 f2 205 207
:3 0 68 :2 0 6
:3 0 f5 209 20b
:3 0 68 :2 0 6b
:4 0 f8 20d 20f
:3 0 68 :2 0 6c
:4 0 fb 211 213
:3 0 68 :2 0 6d
:3 0 6e :3 0 7
:3 0 fe 217 219
6f :4 0 100 216
21c 103 215 21e
:3 0 68 :2 0 6c
:4 0 106 220 222
:3 0 68 :2 0 6d
:3 0 6e :3 0 9
:3 0 109 226 228
6f :4 0 10b 225
22b 10e 224 22d
:3 0 68 :2 0 6c
:4 0 111 22f 231
:3 0 68 :2 0 6d
:3 0 6e :3 0 a
:3 0 114 235 237
6f :4 0 116 234
23a 119 233 23c
:3 0 68 :2 0 6c
:4 0 11c 23e 240
:3 0 68 :2 0 6d
:3 0 6e :3 0 b
:3 0 11f 244 246
6f :4 0 121 243
249 124 242 24b
:3 0 68 :2 0 6c
:4 0 127 24d 24f
:3 0 68 :2 0 6d
:3 0 6e :3 0 c
:3 0 12a 253 255
6f :4 0 12c 252
258 12f 251 25a
:3 0 68 :2 0 6c
:4 0 132 25c 25e
:3 0 68 :2 0 6d
:3 0 6e :3 0 d
:3 0 135 262 264
6f :4 0 137 261
267 13a 260 269
:3 0 68 :2 0 6c
:4 0 13d 26b 26d
:3 0 68 :2 0 6d
:3 0 6e :3 0 e
:3 0 140 271 273
6f :4 0 142 270
276 145 26f 278
:3 0 68 :2 0 6c
:4 0 148 27a 27c
:3 0 68 :2 0 6d
:3 0 6e :3 0 f
:3 0 14b 280 282
6f :4 0 14d 27f
285 150 27e 287
:3 0 68 :2 0 6c
:4 0 153 289 28b
:3 0 68 :2 0 6d
:3 0 6e :3 0 10
:3 0 156 28f 291
6f :4 0 158 28e
294 15b 28d 296
:3 0 68 :2 0 6c
:4 0 15e 298 29a
:3 0 68 :2 0 6d
:3 0 6e :3 0 11
:3 0 161 29e 2a0
6f :4 0 163 29d
2a3 166 29c 2a5
:3 0 68 :2 0 6c
:4 0 169 2a7 2a9
:3 0 68 :2 0 6b
:4 0 16c 2ab 2ad
:3 0 68 :2 0 12
:3 0 16f 2af 2b1
:3 0 68 :2 0 6b
:4 0 172 2b3 2b5
:3 0 68 :2 0 6c
:4 0 175 2b7 2b9
:3 0 68 :2 0 6b
:4 0 178 2bb 2bd
:3 0 68 :2 0 13
:3 0 17b 2bf 2c1
:3 0 68 :2 0 6b
:4 0 17e 2c3 2c5
:3 0 68 :2 0 70
:4 0 181 2c7 2c9
:3 0 184 1d7 2cb
:2 0 2cd 189 2ce
1d4 2cd 0 2cf
18b 0 19f7 60
:3 0 61 :3 0 2d0
2d1 0 60 :3 0
71 :3 0 2d3 2d4
0 23 :2 0 2
:4 0 72 :2 0 73
:2 0 23 :2 0 18d
2d9 2db :3 0 190
2d5 2dd 2d2 2df
2de :2 0 63 :3 0
74 :3 0 2e1 2e2
0 65 :4 0 75
:4 0 68 :2 0 69
:3 0 194 2e6 2e8
:3 0 197 2e3 2ea
:2 0 2ec 19a 2ed
2e0 2ec 0 2ee
19c 0 19f7 17
:3 0 3 :3 0 2ef
2f0 0 19f7 1c
:3 0 5 :3 0 2f2
2f3 0 19f7 1f
:3 0 6 :3 0 2f5
2f6 0 19f7 1a
:3 0 13 :3 0 2f8
2f9 0 19f7 39
:3 0 7 :3 0 2fb
2fc 0 19f7 37
:3 0 9 :3 0 2fe
2ff 0 19f7 38
:3 0 e :3 0 301
302 0 19f7 3a
:3 0 b :3 0 304
305 0 19f7 3c
:3 0 f :3 0 307
308 0 19f7 3b
:3 0 c :3 0 30a
30b 0 19f7 33
:3 0 11 :3 0 30d
30e 0 19f7 32
:3 0 a :3 0 310
311 0 19f7 3d
:3 0 d :3 0 313
314 0 19f7 35
:3 0 10 :3 0 316
317 0 19f7 19
:3 0 17 :3 0 319
31a 0 19f7 58
:3 0 76 :3 0 6d
:3 0 33 :3 0 31
:2 0 19e 31e 321
1a1 31d 323 31c
324 0 19f7 48
:3 0 4e :2 0 326
327 0 19f7 34
:3 0 31 :2 0 329
32a 0 19f7 3
:3 0 77 :2 0 1a3
32d 32e :3 0 32f
:2 0 60 :3 0 61
:3 0 331 332 0
60 :3 0 71 :3 0
334 335 0 78
:2 0 2 :4 0 79
:2 0 73 :2 0 23
:2 0 1a5 33a 33c
:3 0 1a8 336 33e
333 340 33f :2 0
63 :3 0 74 :3 0
342 343 0 65
:4 0 7a :4 0 68
:2 0 69 :3 0 1ac
347 349 :3 0 68
:2 0 7b :4 0 1af
34b 34d :3 0 68
:2 0 7c :4 0 1b2
34f 351 :3 0 68
:2 0 6d :3 0 6e
:3 0 7d :3 0 7e
:3 0 356 357 0
1b5 355 359 6f
:4 0 1b7 354 35c
1ba 353 35e :3 0
1bd 344 360 :2 0
362 1c0 363 341
362 0 364 1c2
0 38d 60 :3 0
61 :3 0 365 366
0 60 :3 0 71
:3 0 368 369 0
23 :2 0 2 :4 0
7f :2 0 73 :2 0
23 :2 0 1c4 36e
370 :3 0 1c7 36a
372 367 374 373
:2 0 63 :3 0 74
:3 0 376 377 0
65 :4 0 80 :4 0
68 :2 0 69 :3 0
1cb 37b 37d :3 0
1ce 378 37f :2 0
381 1d1 382 375
381 0 383 1d3
0 38d 81 :3 0
82 :3 0 384 385
0 7d :3 0 7e
:3 0 387 388 0
83 :3 0 1d5 386
38b :2 0 38d 1d8
38e 330 38d 0
38f 1dc 0 19f7
6 :3 0 84 :2 0
1de 391 392 :3 0
393 :2 0 6d :3 0
85 :3 0 1f :3 0
1e0 396 398 31
:2 0 1e2 395 39b
86 :2 0 87 :2 0
1e7 39d 39f :3 0
3a0 :2 0 394 3a2
3a1 :2 0 3a3 :2 0
60 :3 0 61 :3 0
3a5 3a6 0 60
:3 0 71 :3 0 3a8
3a9 0 78 :2 0
2 :4 0 88 :2 0
73 :2 0 23 :2 0
1ea 3ae 3b0 :3 0
1ed 3aa 3b2 3a7
3b4 3b3 :2 0 63
:3 0 74 :3 0 3b6
3b7 0 65 :4 0
89 :4 0 68 :2 0
69 :3 0 1f1 3bb
3bd :3 0 68 :2 0
7b :4 0 1f4 3bf
3c1 :3 0 68 :2 0
7c :4 0 1f7 3c3
3c5 :3 0 68 :2 0
6d :3 0 6e :3 0
7d :3 0 8a :3 0
3ca 3cb 0 1fa
3c9 3cd 6f :4 0
1fc 3c8 3d0 1ff
3c7 3d2 :3 0 202
3b8 3d4 :2 0 3d6
205 3d7 3b5 3d6
0 3d8 207 0
401 60 :3 0 61
:3 0 3d9 3da 0
60 :3 0 71 :3 0
3dc 3dd 0 23
:2 0 2 :4 0 8b
:2 0 73 :2 0 23
:2 0 209 3e2 3e4
:3 0 20c 3de 3e6
3db 3e8 3e7 :2 0
63 :3 0 74 :3 0
3ea 3eb 0 65
:4 0 8c :4 0 68
:2 0 69 :3 0 210
3ef 3f1 :3 0 213
3ec 3f3 :2 0 3f5
216 3f6 3e9 3f5
0 3f7 218 0
401 81 :3 0 82
:3 0 3f8 3f9 0
7d :3 0 8a :3 0
3fb 3fc 0 83
:3 0 21a 3fa 3ff
:2 0 401 21d 402
3a4 401 0 403
221 0 19f7 5
:3 0 84 :2 0 223
405 406 :3 0 407
:2 0 6d :3 0 85
:3 0 1c :3 0 225
40a 40c 31 :2 0
227 409 40f 86
:2 0 87 :2 0 22c
411 413 :3 0 414
:2 0 408 416 415
:2 0 417 :2 0 60
:3 0 61 :3 0 419
41a 0 60 :3 0
71 :3 0 41c 41d
0 78 :2 0 2
:4 0 8d :2 0 73
:2 0 23 :2 0 22f
422 424 :3 0 232
41e 426 41b 428
427 :2 0 63 :3 0
74 :3 0 42a 42b
0 65 :4 0 8e
:4 0 68 :2 0 69
:3 0 236 42f 431
:3 0 68 :2 0 7b
:4 0 239 433 435
:3 0 68 :2 0 7c
:4 0 23c 437 439
:3 0 68 :2 0 6d
:3 0 6e :3 0 7d
:3 0 8a :3 0 43e
43f 0 23f 43d
441 6f :4 0 241
43c 444 244 43b
446 :3 0 247 42c
448 :2 0 44a 24a
44b 429 44a 0
44c 24c 0 475
60 :3 0 61 :3 0
44d 44e 0 60
:3 0 71 :3 0 450
451 0 23 :2 0
2 :4 0 8f :2 0
73 :2 0 23 :2 0
24e 456 458 :3 0
251 452 45a 44f
45c 45b :2 0 63
:3 0 74 :3 0 45e
45f 0 65 :4 0
90 :4 0 68 :2 0
69 :3 0 255 463
465 :3 0 258 460
467 :2 0 469 25b
46a 45d 469 0
46b 25d 0 475
81 :3 0 82 :3 0
46c 46d 0 7d
:3 0 8a :3 0 46f
470 0 83 :3 0
25f 46e 473 :2 0
475 262 476 418
475 0 477 266
0 19f7 6d :3 0
32 :3 0 31 :2 0
268 478 47b 91
:2 0 92 :2 0 26d
47d 47f :3 0 6d
:3 0 3b :3 0 31
:2 0 270 481 484
91 :2 0 92 :2 0
275 486 488 :3 0
480 48a 489 :2 0
6d :3 0 37 :3 0
31 :2 0 278 48c
48f 91 :2 0 92
:2 0 27d 491 493
:3 0 48b 495 494
:2 0 60 :3 0 61
:3 0 497 498 0
60 :3 0 71 :3 0
49a 49b 0 78
:2 0 2 :4 0 93
:2 0 73 :2 0 23
:2 0 280 4a0 4a2
:3 0 283 49c 4a4
499 4a6 4a5 :2 0
63 :3 0 74 :3 0
4a8 4a9 0 65
:4 0 94 :4 0 68
:2 0 69 :3 0 287
4ad 4af :3 0 68
:2 0 7b :4 0 28a
4b1 4b3 :3 0 68
:2 0 7c :4 0 28d
4b5 4b7 :3 0 68
:2 0 6d :3 0 6e
:3 0 7d :3 0 8a
:3 0 4bc 4bd 0
290 4bb 4bf 6f
:4 0 292 4ba 4c2
295 4b9 4c4 :3 0
298 4aa 4c6 :2 0
4c8 29b 4c9 4a7
4c8 0 4ca 29d
0 4f3 60 :3 0
61 :3 0 4cb 4cc
0 60 :3 0 71
:3 0 4ce 4cf 0
23 :2 0 2 :4 0
95 :2 0 73 :2 0
23 :2 0 29f 4d4
4d6 :3 0 2a2 4d0
4d8 4cd 4da 4d9
:2 0 63 :3 0 74
:3 0 4dc 4dd 0
65 :4 0 96 :4 0
68 :2 0 69 :3 0
2a6 4e1 4e3 :3 0
2a9 4de 4e5 :2 0
4e7 2ac 4e8 4db
4e7 0 4e9 2ae
0 4f3 81 :3 0
82 :3 0 4ea 4eb
0 7d :3 0 8a
:3 0 4ed 4ee 0
83 :3 0 2b0 4ec
4f1 :2 0 4f3 2b3
4f4 496 4f3 0
4f5 2b7 0 19f7
6d :3 0 32 :3 0
31 :2 0 2b9 4f6
4f9 7d :3 0 97
:2 0 98 :3 0 4fb
4fd 0 2be 4fc
4ff :3 0 500 :2 0
5 :3 0 84 :2 0
2c1 503 504 :3 0
505 :2 0 506 :2 0
501 508 507 :2 0
6 :3 0 84 :2 0
2c3 50b 50c :3 0
50d :2 0 50e :2 0
509 510 50f :2 0
99 :3 0 9a :3 0
6 :3 0 99 :3 0
9a :3 0 5 :3 0
44 :3 0 9b :4 0
9c 1 :8 0 520
15 :3 0 9d :3 0
51b 51c 0 9e
:3 0 51d 51e 0
520 2c5 56a 9f
:3 0 15 :3 0 9d
:3 0 523 524 0
9e :3 0 525 526
0 560 60 :3 0
61 :3 0 528 529
0 60 :3 0 71
:3 0 52b 52c 0
a0 :2 0 2 :4 0
a1 :2 0 73 :2 0
23 :2 0 2c8 531
533 :3 0 2cb 52d
535 52a 537 536
:2 0 63 :3 0 74
:3 0 539 53a 0
65 :4 0 a2 :4 0
68 :2 0 69 :3 0
2cf 53e 540 :3 0
68 :2 0 7b :4 0
2d2 542 544 :3 0
68 :2 0 a3 :4 0
2d5 546 548 :3 0
68 :2 0 9e :3 0
2d8 54a 54c :3 0
68 :2 0 a4 :4 0
2db 54e 550 :3 0
68 :2 0 a5 :3 0
a6 :3 0 23 :2 0
a7 :2 0 2de 553
557 2e2 552 559
:3 0 2e5 53b 55b
:2 0 55d 2e8 55e
538 55d 0 55f
2ea 0 560 2ec
563 :3 0 563 0
563 562 560 561
:6 0 565 2 :3 0
2ef 567 2f1 566
565 :2 0 568 2f3
:2 0 56a 0 56a
569 520 568 :6 0
5e5 1 :3 0 15
:3 0 9d :3 0 56c
56d 0 15 :3 0
91 :2 0 a8 :3 0
56f 571 0 2f7
570 573 :3 0 574
:2 0 6d :3 0 44
:3 0 31 :2 0 2fa
576 579 86 :2 0
31 :2 0 2ff 57b
57d :3 0 57e :2 0
575 580 57f :2 0
60 :3 0 61 :3 0
582 583 0 60
:3 0 71 :3 0 585
586 0 78 :2 0
2 :4 0 a9 :2 0
73 :2 0 23 :2 0
302 58b 58d :3 0
305 587 58f 584
591 590 :2 0 63
:3 0 74 :3 0 593
594 0 65 :4 0
aa :4 0 68 :2 0
69 :3 0 309 598
59a :3 0 68 :2 0
7b :4 0 30c 59c
59e :3 0 68 :2 0
7c :4 0 30f 5a0
5a2 :3 0 68 :2 0
6d :3 0 6e :3 0
7d :3 0 ab :3 0
5a7 5a8 0 312
5a6 5aa 6f :4 0
314 5a5 5ad 317
5a4 5af :3 0 31a
595 5b1 :2 0 5b3
31d 5b4 592 5b3
0 5b5 31f 0
5de 60 :3 0 61
:3 0 5b6 5b7 0
60 :3 0 71 :3 0
5b9 5ba 0 23
:2 0 2 :4 0 ac
:2 0 73 :2 0 23
:2 0 321 5bf 5c1
:3 0 324 5bb 5c3
5b8 5c5 5c4 :2 0
63 :3 0 74 :3 0
5c7 5c8 0 65
:4 0 ad :4 0 68
:2 0 69 :3 0 328
5cc 5ce :3 0 32b
5c9 5d0 :2 0 5d2
32e 5d3 5c6 5d2
0 5d4 330 0
5de 81 :3 0 82
:3 0 5d5 5d6 0
7d :3 0 ab :3 0
5d8 5d9 0 83
:3 0 332 5d7 5dc
:2 0 5de 335 5df
581 5de 0 5e0
339 0 5e5 5d
:3 0 23 :2 0 5e1
5e2 0 5e5 ae
:3 0 33b 64b 5
:3 0 77 :2 0 33f
5e7 5e8 :3 0 5e9
:2 0 5ea :2 0 6
:3 0 77 :2 0 341
5ed 5ee :3 0 5ef
:2 0 5f0 :2 0 5eb
5f2 5f1 :2 0 69
:3 0 1c :3 0 9b
:4 0 af 1 :8 0
5fd 15 :3 0 9d
:3 0 5f8 5f9 0
9e :3 0 5fa 5fb
0 5fd 343 647
9f :3 0 15 :3 0
9d :3 0 600 601
0 9e :3 0 602
603 0 63d 60
:3 0 61 :3 0 605
606 0 60 :3 0
71 :3 0 608 609
0 a0 :2 0 2
:4 0 b0 :2 0 73
:2 0 23 :2 0 346
60e 610 :3 0 349
60a 612 607 614
613 :2 0 63 :3 0
74 :3 0 616 617
0 65 :4 0 b1
:4 0 68 :2 0 69
:3 0 34d 61b 61d
:3 0 68 :2 0 7b
:4 0 350 61f 621
:3 0 68 :2 0 a3
:4 0 353 623 625
:3 0 68 :2 0 9e
:3 0 356 627 629
:3 0 68 :2 0 a4
:4 0 359 62b 62d
:3 0 68 :2 0 a5
:3 0 a6 :3 0 23
:2 0 a7 :2 0 35c
630 634 360 62f
636 :3 0 363 618
638 :2 0 63a 366
63b 615 63a 0
63c 368 0 63d
36a 640 :3 0 640
0 640 63f 63d
63e :6 0 642 4
:3 0 36d 644 36f
643 642 :2 0 645
371 :2 0 647 0
647 646 5fd 645
:6 0 649 1 :3 0
373 64a 5f3 649
0 64c 511 5e5
0 64c 375 0
19f7 1e :3 0 1c
:3 0 64d 64e 0
19f7 36 :3 0 b2
:3 0 b3 :3 0 651
652 0 b4 :3 0
6d :3 0 3c :3 0
31 :2 0 378 655
658 7d :3 0 b5
:3 0 65a 65b 0
37b 654 65d 65e
:2 0 b6 :2 0 37e
653 661 650 662
0 19f7 3c :3 0
b4 :3 0 6d :3 0
3c :3 0 31 :2 0
381 666 669 7d
:3 0 b7 :3 0 66b
66c 0 384 665
66e 66f :2 0 664
670 0 19f7 6d
:3 0 33 :3 0 31
:2 0 387 672 675
91 :2 0 31 :2 0
38c 677 679 :3 0
6d :3 0 b8 :3 0
6d :3 0 b9 :3 0
ba :3 0 3f :3 0
40 :3 0 46 :3 0
bb :3 0 bc :3 0
17 :4 0 bd 1
:8 0 68c 15 :3 0
9d :3 0 687 688
0 9e :3 0 689
68a 0 68c 38f
6d6 9f :3 0 15
:3 0 9d :3 0 68f
690 0 9e :3 0
691 692 0 6cc
60 :3 0 61 :3 0
694 695 0 60
:3 0 71 :3 0 697
698 0 a0 :2 0
2 :4 0 be :2 0
73 :2 0 23 :2 0
392 69d 69f :3 0
395 699 6a1 696
6a3 6a2 :2 0 63
:3 0 74 :3 0 6a5
6a6 0 65 :4 0
bf :4 0 68 :2 0
69 :3 0 399 6aa
6ac :3 0 68 :2 0
7b :4 0 39c 6ae
6b0 :3 0 68 :2 0
a3 :4 0 39f 6b2
6b4 :3 0 68 :2 0
9e :3 0 3a2 6b6
6b8 :3 0 68 :2 0
a4 :4 0 3a5 6ba
6bc :3 0 68 :2 0
a5 :3 0 a6 :3 0
23 :2 0 a7 :2 0
3a8 6bf 6c3 3ac
6be 6c5 :3 0 3af
6a7 6c7 :2 0 6c9
3b2 6ca 6a4 6c9
0 6cb 3b4 0
6cc 3b6 6cf :3 0
6cf 0 6cf 6ce
6cc 6cd :6 0 6d1
6 :3 0 3b9 6d3
3bb 6d2 6d1 :2 0
6d4 3bd :2 0 6d6
0 6d6 6d5 68c
6d4 :6 0 8ef 1
:3 0 15 :3 0 9d
:3 0 6d8 6d9 0
15 :3 0 91 :2 0
c0 :3 0 6db 6dd
0 3c1 6dc 6df
:3 0 6e0 :2 0 3f
:3 0 40 :3 0 46
:3 0 c1 :3 0 bc
:3 0 17 :4 0 c2
1 :8 0 6ee 15
:3 0 9d :3 0 6e9
6ea 0 9e :3 0
6eb 6ec 0 6ee
3c4 738 9f :3 0
15 :3 0 9d :3 0
6f1 6f2 0 9e
:3 0 6f3 6f4 0
72e 60 :3 0 61
:3 0 6f6 6f7 0
60 :3 0 71 :3 0
6f9 6fa 0 a0
:2 0 2 :4 0 c3
:2 0 73 :2 0 23
:2 0 3c7 6ff 701
:3 0 3ca 6fb 703
6f8 705 704 :2 0
63 :3 0 74 :3 0
707 708 0 65
:4 0 c4 :4 0 68
:2 0 69 :3 0 3ce
70c 70e :3 0 68
:2 0 7b :4 0 3d1
710 712 :3 0 68
:2 0 a3 :4 0 3d4
714 716 :3 0 68
:2 0 9e :3 0 3d7
718 71a :3 0 68
:2 0 a4 :4 0 3da
71c 71e :3 0 68
:2 0 a5 :3 0 a6
:3 0 23 :2 0 a7
:2 0 3dd 721 725
3e1 720 727 :3 0
3e4 709 729 :2 0
72b 3e7 72c 706
72b 0 72d 3e9
0 72e 3eb 731
:3 0 731 0 731
730 72e 72f :6 0
733 8 :3 0 3ee
735 3f0 734 733
:2 0 736 3f2 :2 0
738 0 738 737
6ee 736 :6 0 7b4
1 :3 0 15 :3 0
9d :3 0 73a 73b
0 15 :3 0 91
:2 0 c0 :3 0 73d
73f 0 3f6 73e
741 :3 0 742 :2 0
60 :3 0 61 :3 0
744 745 0 60
:3 0 71 :3 0 747
748 0 18 :2 0
2 :4 0 c5 :2 0
73 :2 0 23 :2 0
3f9 74d 74f :3 0
3fc 749 751 746
753 752 :2 0 63
:3 0 74 :3 0 755
756 0 65 :4 0
c6 :4 0 68 :2 0
69 :3 0 400 75a
75c :3 0 68 :2 0
7b :4 0 403 75e
760 :3 0 68 :2 0
7c :4 0 406 762
764 :3 0 68 :2 0
6d :3 0 6e :3 0
7d :3 0 8a :3 0
769 76a 0 409
768 76c 6f :4 0
40b 767 76f 40e
766 771 :3 0 68
:2 0 c7 :4 0 411
773 775 :3 0 68
:2 0 6b :4 0 414
777 779 :3 0 68
:2 0 17 :3 0 417
77b 77d :3 0 68
:2 0 6b :4 0 41a
77f 781 :3 0 41d
757 783 :2 0 785
420 786 754 785
0 787 422 0
7b1 60 :3 0 61
:3 0 788 789 0
60 :3 0 71 :3 0
78b 78c 0 23
:2 0 2 :4 0 c8
:2 0 73 :2 0 23
:2 0 424 791 793
:3 0 427 78d 795
78a 797 796 :2 0
63 :3 0 74 :3 0
799 79a 0 65
:4 0 c9 :4 0 68
:2 0 69 :3 0 42b
79e 7a0 :3 0 42e
79b 7a2 :2 0 7a4
431 7a5 798 7a4
0 7a6 433 0
7b1 81 :3 0 ca
:3 0 7a7 7a8 0
7d :3 0 8a :3 0
7aa 7ab 0 17
:3 0 83 :3 0 435
7a9 7af :2 0 7b1
439 7b2 743 7b1
0 7b3 43d 0
7b4 43f 7b5 6e1
7b4 0 7b6 442
0 8ef 59 :3 0
31 :2 0 7b7 7b8
0 8ef cb :3 0
59 :3 0 cc :3 0
cd :3 0 17 :4 0
ce 1 :8 0 7c5
15 :3 0 9d :3 0
7c0 7c1 0 9e
:3 0 7c2 7c3 0
7c5 444 80f 9f
:3 0 15 :3 0 9d
:3 0 7c8 7c9 0
9e :3 0 7ca 7cb
0 805 60 :3 0
61 :3 0 7cd 7ce
0 60 :3 0 71
:3 0 7d0 7d1 0
a0 :2 0 2 :4 0
cf :2 0 73 :2 0
23 :2 0 447 7d6
7d8 :3 0 44a 7d2
7da 7cf 7dc 7db
:2 0 63 :3 0 74
:3 0 7de 7df 0
65 :4 0 d0 :4 0
68 :2 0 69 :3 0
44e 7e3 7e5 :3 0
68 :2 0 7b :4 0
451 7e7 7e9 :3 0
68 :2 0 a3 :4 0
454 7eb 7ed :3 0
68 :2 0 9e :3 0
457 7ef 7f1 :3 0
68 :2 0 a4 :4 0
45a 7f3 7f5 :3 0
68 :2 0 a5 :3 0
a6 :3 0 23 :2 0
a7 :2 0 45d 7f8
7fc 461 7f7 7fe
:3 0 464 7e0 800
:2 0 802 467 803
7dd 802 0 804
469 0 805 46b
808 :3 0 808 0
808 807 805 806
:6 0 80a a :3 0
46e 80c 470 80b
80a :2 0 80d 472
:2 0 80f 0 80f
80e 7c5 80d :6 0
8ef 1 :3 0 6d
:3 0 59 :3 0 31
:2 0 474 811 814
d1 :2 0 31 :2 0
479 816 818 :3 0
d2 :3 0 22 :3 0
bb :3 0 bc :3 0
17 :4 0 d3 1
:8 0 825 15 :3 0
9d :3 0 820 821
0 9e :3 0 822
823 0 825 47c
86f 9f :3 0 15
:3 0 9d :3 0 828
829 0 9e :3 0
82a 82b 0 865
60 :3 0 61 :3 0
82d 82e 0 60
:3 0 71 :3 0 830
831 0 a0 :2 0
2 :4 0 d4 :2 0
73 :2 0 23 :2 0
47f 836 838 :3 0
482 832 83a 82f
83c 83b :2 0 63
:3 0 74 :3 0 83e
83f 0 65 :4 0
d5 :4 0 68 :2 0
69 :3 0 486 843
845 :3 0 68 :2 0
7b :4 0 489 847
849 :3 0 68 :2 0
a3 :4 0 48c 84b
84d :3 0 68 :2 0
9e :3 0 48f 84f
851 :3 0 68 :2 0
a4 :4 0 492 853
855 :3 0 68 :2 0
a5 :3 0 a6 :3 0
23 :2 0 a7 :2 0
495 858 85c 499
857 85e :3 0 49c
840 860 :2 0 862
49f 863 83d 862
0 864 4a1 0
865 4a3 868 :3 0
868 0 868 867
865 866 :6 0 86a
c :3 0 4a6 86c
4a8 86b 86a :2 0
86d 4aa :2 0 86f
0 86f 86e 825
86d :6 0 8ec 1
:3 0 99 :3 0 d6
:3 0 871 872 0
22 :3 0 d7 :4 0
4ac 873 876 91
:2 0 31 :2 0 4b1
878 87a :3 0 60
:3 0 61 :3 0 87c
87d 0 60 :3 0
71 :3 0 87f 880
0 18 :2 0 2
:4 0 d8 :2 0 73
:2 0 23 :2 0 4b4
885 887 :3 0 4b7
881 889 87e 88b
88a :2 0 63 :3 0
74 :3 0 88d 88e
0 65 :4 0 d9
:4 0 68 :2 0 69
:3 0 4bb 892 894
:3 0 68 :2 0 7b
:4 0 4be 896 898
:3 0 68 :2 0 7c
:4 0 4c1 89a 89c
:3 0 68 :2 0 6d
:3 0 6e :3 0 7d
:3 0 da :3 0 8a1
8a2 0 4c4 8a0
8a4 6f :4 0 4c6
89f 8a7 4c9 89e
8a9 :3 0 68 :2 0
c7 :4 0 4cc 8ab
8ad :3 0 68 :2 0
6b :4 0 4cf 8af
8b1 :3 0 68 :2 0
17 :3 0 4d2 8b3
8b5 :3 0 68 :2 0
6b :4 0 4d5 8b7
8b9 :3 0 4d8 88f
8bb :2 0 8bd 4db
8be 88c 8bd 0
8bf 4dd 0 8e9
60 :3 0 61 :3 0
8c0 8c1 0 60
:3 0 71 :3 0 8c3
8c4 0 23 :2 0
2 :4 0 db :2 0
73 :2 0 23 :2 0
4df 8c9 8cb :3 0
4e2 8c5 8cd 8c2
8cf 8ce :2 0 63
:3 0 74 :3 0 8d1
8d2 0 65 :4 0
dc :4 0 68 :2 0
69 :3 0 4e6 8d6
8d8 :3 0 4e9 8d3
8da :2 0 8dc 4ec
8dd 8d0 8dc 0
8de 4ee 0 8e9
81 :3 0 ca :3 0
8df 8e0 0 7d
:3 0 da :3 0 8e2
8e3 0 17 :3 0
83 :3 0 4f0 8e1
8e7 :2 0 8e9 4f4
8ea 87b 8e9 0
8eb 4f8 0 8ec
4fa 8ed 819 8ec
0 8ee 4fd 0
8ef 4ff ad2 12
:3 0 77 :2 0 505
8f1 8f2 :3 0 8f3
:2 0 60 :3 0 61
:3 0 8f5 8f6 0
60 :3 0 71 :3 0
8f8 8f9 0 78
:2 0 2 :4 0 dd
:2 0 73 :2 0 23
:2 0 507 8fe 900
:3 0 50a 8fa 902
8f7 904 903 :2 0
63 :3 0 74 :3 0
906 907 0 65
:4 0 de :4 0 68
:2 0 69 :3 0 50e
90b 90d :3 0 68
:2 0 7b :4 0 511
90f 911 :3 0 68
:2 0 7c :4 0 514
913 915 :3 0 68
:2 0 6d :3 0 6e
:3 0 7d :3 0 7e
:3 0 91a 91b 0
517 919 91d 6f
:4 0 519 918 920
51c 917 922 :3 0
51f 908 924 :2 0
926 522 927 905
926 0 928 524
0 951 60 :3 0
61 :3 0 929 92a
0 60 :3 0 71
:3 0 92c 92d 0
23 :2 0 2 :4 0
df :2 0 73 :2 0
23 :2 0 526 932
934 :3 0 529 92e
936 92b 938 937
:2 0 63 :3 0 74
:3 0 93a 93b 0
65 :4 0 e0 :4 0
68 :2 0 69 :3 0
52d 93f 941 :3 0
530 93c 943 :2 0
945 533 946 939
945 0 947 535
0 951 81 :3 0
82 :3 0 948 949
0 7d :3 0 7e
:3 0 94b 94c 0
83 :3 0 537 94a
94f :2 0 951 53a
952 8f4 951 0
953 53e 0 ad1
28 :3 0 12 :3 0
954 955 0 ad1
1b :3 0 a5 :3 0
a5 :3 0 28 :3 0
23 :2 0 18 :2 0
540 959 95d 23
:2 0 18 :2 0 544
958 961 957 962
0 ad1 24 :3 0
e1 :3 0 e2 :3 0
965 966 0 23
:2 0 23 :2 0 e3
:2 0 28 :3 0 548
967 96c 964 96d
0 ad1 e4 :3 0
6d :3 0 33 :3 0
31 :2 0 54d 970
973 550 96f 975
97 :2 0 31 :2 0
554 977 979 :3 0
cd :3 0 6d :3 0
b8 :3 0 6d :3 0
b9 :3 0 ba :3 0
17 :3 0 3f :3 0
40 :3 0 46 :3 0
bb :3 0 bc :3 0
19 :3 0 e5 :3 0
7d :3 0 e6 :3 0
7d :3 0 e7 :3 0
7d :3 0 e8 :3 0
7d :3 0 e9 :3 0
7d :3 0 ea :4 0
eb 1 :8 0 999
15 :3 0 9d :3 0
994 995 0 9e
:3 0 996 997 0
999 557 9e3 9f
:3 0 15 :3 0 9d
:3 0 99c 99d 0
9e :3 0 99e 99f
0 9d9 60 :3 0
61 :3 0 9a1 9a2
0 60 :3 0 71
:3 0 9a4 9a5 0
a0 :2 0 2 :4 0
ec :2 0 73 :2 0
23 :2 0 55a 9aa
9ac :3 0 55d 9a6
9ae 9a3 9b0 9af
:2 0 63 :3 0 74
:3 0 9b2 9b3 0
65 :4 0 ed :4 0
68 :2 0 69 :3 0
561 9b7 9b9 :3 0
68 :2 0 7b :4 0
564 9bb 9bd :3 0
68 :2 0 a3 :4 0
567 9bf 9c1 :3 0
68 :2 0 9e :3 0
56a 9c3 9c5 :3 0
68 :2 0 a4 :4 0
56d 9c7 9c9 :3 0
68 :2 0 a5 :3 0
a6 :3 0 23 :2 0
a7 :2 0 570 9cc
9d0 574 9cb 9d2
:3 0 577 9b4 9d4
:2 0 9d6 57a 9d7
9b1 9d6 0 9d8
57c 0 9d9 57e
9dc :3 0 9dc 0
9dc 9db 9d9 9da
:6 0 9de e :3 0
581 9e0 583 9df
9de :2 0 9e1 585
:2 0 9e3 0 9e3
9e2 999 9e1 :6 0
a5f 1 :3 0 15
:3 0 9d :3 0 9e5
9e6 0 15 :3 0
91 :2 0 c0 :3 0
9e8 9ea 0 589
9e9 9ec :3 0 9ed
:2 0 60 :3 0 61
:3 0 9ef 9f0 0
60 :3 0 71 :3 0
9f2 9f3 0 18
:2 0 2 :4 0 ee
:2 0 73 :2 0 23
:2 0 58c 9f8 9fa
:3 0 58f 9f4 9fc
9f1 9fe 9fd :2 0
63 :3 0 74 :3 0
a00 a01 0 65
:4 0 ef :4 0 68
:2 0 69 :3 0 593
a05 a07 :3 0 68
:2 0 7b :4 0 596
a09 a0b :3 0 68
:2 0 7c :4 0 599
a0d a0f :3 0 68
:2 0 6d :3 0 6e
:3 0 7d :3 0 f0
:3 0 a14 a15 0
59c a13 a17 6f
:4 0 59e a12 a1a
5a1 a11 a1c :3 0
68 :2 0 c7 :4 0
5a4 a1e a20 :3 0
68 :2 0 6b :4 0
5a7 a22 a24 :3 0
68 :2 0 19 :3 0
5aa a26 a28 :3 0
68 :2 0 6b :4 0
5ad a2a a2c :3 0
5b0 a02 a2e :2 0
a30 5b3 a31 9ff
a30 0 a32 5b5
0 a5c 60 :3 0
61 :3 0 a33 a34
0 60 :3 0 71
:3 0 a36 a37 0
23 :2 0 2 :4 0
f1 :2 0 73 :2 0
23 :2 0 5b7 a3c
a3e :3 0 5ba a38
a40 a35 a42 a41
:2 0 63 :3 0 74
:3 0 a44 a45 0
65 :4 0 f2 :4 0
68 :2 0 69 :3 0
5be a49 a4b :3 0
5c1 a46 a4d :2 0
a4f 5c4 a50 a43
a4f 0 a51 5c6
0 a5c 81 :3 0
ca :3 0 a52 a53
0 7d :3 0 f0
:3 0 a55 a56 0
19 :3 0 83 :3 0
5c8 a54 a5a :2 0
a5c 5cc a5d 9ee
a5c 0 a5e 5d0
0 a5f 5d2 ace
60 :3 0 61 :3 0
a60 a61 0 60
:3 0 71 :3 0 a63
a64 0 18 :2 0
2 :4 0 f3 :2 0
73 :2 0 23 :2 0
5d5 a69 a6b :3 0
5d8 a65 a6d a62
a6f a6e :2 0 63
:3 0 74 :3 0 a71
a72 0 65 :4 0
f4 :4 0 68 :2 0
69 :3 0 5dc a76
a78 :3 0 68 :2 0
7b :4 0 5df a7a
a7c :3 0 68 :2 0
7c :4 0 5e2 a7e
a80 :3 0 68 :2 0
6d :3 0 6e :3 0
7d :3 0 f0 :3 0
a85 a86 0 5e5
a84 a88 6f :4 0
5e7 a83 a8b 5ea
a82 a8d :3 0 68
:2 0 c7 :4 0 5ed
a8f a91 :3 0 68
:2 0 6b :4 0 5f0
a93 a95 :3 0 68
:2 0 19 :3 0 5f3
a97 a99 :3 0 68
:2 0 6b :4 0 5f6
a9b a9d :3 0 5f9
a73 a9f :2 0 aa1
5fc aa2 a70 aa1
0 aa3 5fe 0
acd 60 :3 0 61
:3 0 aa4 aa5 0
60 :3 0 71 :3 0
aa7 aa8 0 23
:2 0 2 :4 0 f5
:2 0 73 :2 0 23
:2 0 600 aad aaf
:3 0 603 aa9 ab1
aa6 ab3 ab2 :2 0
63 :3 0 74 :3 0
ab5 ab6 0 65
:4 0 f6 :4 0 68
:2 0 69 :3 0 607
aba abc :3 0 60a
ab7 abe :2 0 ac0
60d ac1 ab4 ac0
0 ac2 60f 0
acd 81 :3 0 ca
:3 0 ac3 ac4 0
7d :3 0 f0 :3 0
ac6 ac7 0 19
:3 0 83 :3 0 611
ac5 acb :2 0 acd
615 acf 97a a5f
0 ad0 0 acd
0 ad0 619 0
ad1 61c ad3 67a
8ef 0 ad4 0
ad1 0 ad4 622
0 19f7 6d :3 0
d :3 0 31 :2 0
625 ad5 ad8 91
:2 0 31 :2 0 62a
ada adc :3 0 add
:2 0 6d :3 0 3b
:3 0 31 :2 0 62d
adf ae2 97 :2 0
f7 :2 0 632 ae4
ae6 :3 0 ae7 :2 0
ade ae9 ae8 :2 0
37 :3 0 31 :2 0
aeb aec 0 aee
635 aef aea aee
0 af0 637 0
19f7 5d :3 0 91
:2 0 31 :2 0 63b
af2 af4 :3 0 1e
:3 0 5 :3 0 af6
af7 0 c11 1f
:3 0 f8 :4 0 af9
afa 0 c11 59
:3 0 f9 :3 0 1e
:3 0 1f :3 0 6d
:3 0 3a :3 0 31
:2 0 63e b00 b03
6d :3 0 3b :3 0
31 :2 0 641 b05
b08 6d :3 0 3c
:3 0 31 :2 0 644
b0a b0d 6d :3 0
32 :3 0 31 :2 0
647 b0f b12 6d
:3 0 3d :3 0 31
:2 0 64a b14 b17
6d :3 0 38 :3 0
31 :2 0 64d b19
b1c 6d :3 0 3f
:3 0 31 :2 0 650
b1e b21 6d :3 0
40 :3 0 31 :2 0
653 b23 b26 37
:3 0 39 :3 0 42
:3 0 656 afd b2b
afc b2c 0 c11
6d :3 0 59 :3 0
31 :2 0 664 b2e
b31 7d :3 0 91
:2 0 8a :3 0 b33
b35 0 669 b34
b37 :3 0 60 :3 0
61 :3 0 b39 b3a
0 60 :3 0 71
:3 0 b3c b3d 0
78 :2 0 2 :4 0
fa :2 0 73 :2 0
23 :2 0 66c b42
b44 :3 0 66f b3e
b46 b3b b48 b47
:2 0 63 :3 0 74
:3 0 b4a b4b 0
65 :4 0 fb :4 0
68 :2 0 69 :3 0
673 b4f b51 :3 0
68 :2 0 7b :4 0
676 b53 b55 :3 0
68 :2 0 7c :4 0
679 b57 b59 :3 0
68 :2 0 6d :3 0
6e :3 0 7d :3 0
8a :3 0 b5e b5f
0 67c b5d b61
6f :4 0 67e b5c
b64 681 b5b b66
:3 0 684 b4c b68
:2 0 b6a 687 b6b
b49 b6a 0 b6c
689 0 b96 60
:3 0 61 :3 0 b6d
b6e 0 60 :3 0
71 :3 0 b70 b71
0 23 :2 0 2
:4 0 fc :2 0 73
:2 0 23 :2 0 68b
b76 b78 :3 0 68e
b72 b7a b6f b7c
b7b :2 0 63 :3 0
74 :3 0 b7e b7f
0 65 :4 0 fd
:4 0 68 :2 0 69
:3 0 692 b83 b85
:3 0 695 b80 b87
:2 0 b89 698 b8a
b7d b89 0 b8b
69a 0 b96 81
:3 0 82 :3 0 b8c
b8d 0 7d :3 0
8a :3 0 b8f b90
0 83 :3 0 69c
b8e b93 :2 0 b96
ae :3 0 69f c0f
6d :3 0 59 :3 0
31 :2 0 6a3 b97
b9a 97 :2 0 31
:2 0 6a8 b9c b9e
:3 0 60 :3 0 61
:3 0 ba0 ba1 0
60 :3 0 71 :3 0
ba3 ba4 0 18
:2 0 2 :4 0 fe
:2 0 73 :2 0 23
:2 0 6ab ba9 bab
:3 0 6ae ba5 bad
ba2 baf bae :2 0
63 :3 0 74 :3 0
bb1 bb2 0 65
:4 0 ff :4 0 68
:2 0 69 :3 0 6b2
bb6 bb8 :3 0 68
:2 0 7b :4 0 6b5
bba bbc :3 0 68
:2 0 7c :4 0 6b8
bbe bc0 :3 0 68
:2 0 6d :3 0 6e
:3 0 59 :3 0 6bb
bc4 bc6 6f :4 0
6bd bc3 bc9 6c0
bc2 bcb :3 0 68
:2 0 c7 :4 0 6c3
bcd bcf :3 0 68
:2 0 6b :4 0 6c6
bd1 bd3 :3 0 68
:2 0 17 :3 0 6c9
bd5 bd7 :3 0 68
:2 0 6b :4 0 6cc
bd9 bdb :3 0 6cf
bb3 bdd :2 0 bdf
6d2 be0 bb0 bdf
0 be1 6d4 0
c0d 60 :3 0 61
:3 0 be2 be3 0
60 :3 0 71 :3 0
be5 be6 0 23
:2 0 2 :4 0 100
:2 0 73 :2 0 23
:2 0 6d6 beb bed
:3 0 6d9 be7 bef
be4 bf1 bf0 :2 0
63 :3 0 74 :3 0
bf3 bf4 0 65
:4 0 101 :4 0 68
:2 0 69 :3 0 6dd
bf8 bfa :3 0 6e0
bf5 bfc :2 0 bfe
6e3 bff bf2 bfe
0 c00 6e5 0
c0d 81 :3 0 ca
:3 0 c01 c02 0
6d :3 0 59 :3 0
31 :2 0 6e7 c04
c07 17 :3 0 83
:3 0 6ea c03 c0b
:2 0 c0d 6ee c0e
b9f c0d 0 c10
b38 b96 0 c10
6f2 0 c11 6f5
c12 af5 c11 0
c13 6fa 0 19f7
6d :3 0 37 :3 0
31 :2 0 6fc c14
c17 d1 :2 0 31
:2 0 701 c19 c1b
:3 0 c1c :2 0 6d
:3 0 3b :3 0 31
:2 0 704 c1e c21
97 :2 0 f7 :2 0
709 c23 c25 :3 0
c26 :2 0 c1d c28
c27 :2 0 6d :3 0
3b :3 0 31 :2 0
70c c2a c2d 91
:2 0 23 :2 0 711
c2f c31 :3 0 c32
:2 0 6d :3 0 3b
:3 0 31 :2 0 714
c34 c37 91 :2 0
102 :2 0 719 c39
c3b :3 0 c3c :2 0
c33 c3e c3d :2 0
3a :3 0 102 :2 0
c40 c41 0 c44
ae :3 0 71c c8d
6d :3 0 3b :3 0
31 :2 0 71e c45
c48 91 :2 0 31
:2 0 723 c4a c4c
:3 0 3a :3 0 23
:2 0 c4e c4f 0
c52 ae :3 0 726
c53 c4d c52 0
c8e 6d :3 0 3b
:3 0 31 :2 0 728
c54 c57 91 :2 0
103 :2 0 72d c59
c5b :3 0 c5c :2 0
6d :3 0 3b :3 0
31 :2 0 730 c5e
c61 91 :2 0 104
:2 0 735 c63 c65
:3 0 c66 :2 0 c5d
c68 c67 :2 0 3a
:3 0 23 :2 0 c6a
c6b 0 c6e ae
:3 0 738 c6f c69
c6e 0 c8e 6d
:3 0 3b :3 0 31
:2 0 73a c70 c73
91 :2 0 92 :2 0
73f c75 c77 :3 0
37 :3 0 6d :3 0
40 :3 0 31 :2 0
742 c7a c7d 105
:2 0 6d :3 0 37
:3 0 31 :2 0 745
c80 c83 748 c7f
c85 :3 0 c79 c86
0 c8b 3a :3 0
103 :2 0 c88 c89
0 c8b 74b c8c
c78 c8b 0 c8e
c3f c44 0 c8e
74e 0 c8f 753
c90 c29 c8f 0
c91 755 0 19f7
6d :3 0 39 :3 0
31 :2 0 757 c92
c95 d1 :2 0 31
:2 0 75c c97 c99
:3 0 6d :3 0 42
:3 0 31 :2 0 75f
c9b c9e d1 :2 0
106 :2 0 764 ca0
ca2 :3 0 60 :3 0
61 :3 0 ca4 ca5
0 60 :3 0 71
:3 0 ca7 ca8 0
18 :2 0 2 :4 0
107 :2 0 73 :2 0
23 :2 0 767 cad
caf :3 0 76a ca9
cb1 ca6 cb3 cb2
:2 0 63 :3 0 74
:3 0 cb5 cb6 0
65 :4 0 108 :4 0
68 :2 0 69 :3 0
76e cba cbc :3 0
68 :2 0 7b :4 0
771 cbe cc0 :3 0
68 :2 0 7c :4 0
774 cc2 cc4 :3 0
68 :2 0 6d :3 0
6e :3 0 7d :3 0
109 :3 0 cc9 cca
0 777 cc8 ccc
6f :4 0 779 cc7
ccf 77c cc6 cd1
:3 0 68 :2 0 c7
:4 0 77f cd3 cd5
:3 0 68 :2 0 6b
:4 0 782 cd7 cd9
:3 0 68 :2 0 17
:3 0 785 cdb cdd
:3 0 68 :2 0 6b
:4 0 788 cdf ce1
:3 0 78b cb7 ce3
:2 0 ce5 78e ce6
cb4 ce5 0 ce7
790 0 d11 60
:3 0 61 :3 0 ce8
ce9 0 60 :3 0
71 :3 0 ceb cec
0 23 :2 0 2
:4 0 10a :2 0 73
:2 0 23 :2 0 792
cf1 cf3 :3 0 795
ced cf5 cea cf7
cf6 :2 0 63 :3 0
74 :3 0 cf9 cfa
0 65 :4 0 10b
:4 0 68 :2 0 69
:3 0 799 cfe d00
:3 0 79c cfb d02
:2 0 d04 79f d05
cf8 d04 0 d06
7a1 0 d11 81
:3 0 ca :3 0 d07
d08 0 7d :3 0
109 :3 0 d0a d0b
0 17 :3 0 83
:3 0 7a3 d09 d0f
:2 0 d11 7a7 d12
ca3 d11 0 d13
7ab 0 d33 6d
:3 0 42 :3 0 31
:2 0 7ad d14 d17
86 :2 0 b6 :2 0
7b2 d19 d1b :3 0
42 :3 0 10c :2 0
d1d d1e 0 d20
7b5 d30 42 :3 0
10d :3 0 6d :3 0
42 :3 0 31 :2 0
7b7 d23 d26 105
:2 0 10e :2 0 7ba
d28 d2a :3 0 7bd
d22 d2c d21 d2d
0 d2f 7bf d31
d1c d20 0 d32
0 d2f 0 d32
7c1 0 d33 7c4
d34 c9a d33 0
d35 7c7 0 19f7
55 :3 0 10f :4 0
d37 d38 :3 0 d36
d39 0 19f7 2a
:3 0 f8 :4 0 d3b
d3c 0 19f7 2b
:3 0 f8 :4 0 d3e
d3f 0 19f7 20
:3 0 f8 :4 0 d41
d42 0 19f7 26
:3 0 f8 :4 0 d44
d45 0 19f7 1b
:3 0 a5 :3 0 1b
:3 0 23 :2 0 18
:2 0 7c9 d48 d4c
d47 d4d 0 19f7
24 :3 0 a5 :3 0
24 :3 0 23 :2 0
23 :2 0 7cd d50
d54 d4f d55 0
19f7 6d :3 0 33
:3 0 31 :2 0 7d1
d57 d5a d1 :2 0
31 :2 0 7d6 d5c
d5e :3 0 2c :4 0
d60 d61 0 1429
1e :3 0 1c :3 0
d63 d64 0 1429
a5 :3 0 24 :3 0
23 :2 0 23 :2 0
7d9 d66 d6a 91
:2 0 23 :4 0 7df
d6c d6e :3 0 110
:3 0 111 :3 0 a5
:3 0 112 :3 0 111
:3 0 a5 :3 0 113
:3 0 114 :3 0 115
:3 0 116 :3 0 117
:3 0 27 :3 0 2c
:3 0 2d :3 0 4a
:3 0 4b :3 0 4d
:3 0 4f :3 0 118
:3 0 119 :3 0 17
:3 0 11a :3 0 1b
:3 0 11b :3 0 11c
:4 0 11d 1 :8 0
d8f 15 :3 0 9d
:3 0 d8a d8b 0
9e :3 0 d8c d8d
0 d8f 7e2 dd9
9f :3 0 15 :3 0
9d :3 0 d92 d93
0 9e :3 0 d94
d95 0 dcf 60
:3 0 61 :3 0 d97
d98 0 60 :3 0
71 :3 0 d9a d9b
0 a0 :2 0 2
:4 0 11e :2 0 73
:2 0 23 :2 0 7e5
da0 da2 :3 0 7e8
d9c da4 d99 da6
da5 :2 0 63 :3 0
74 :3 0 da8 da9
0 65 :4 0 11f
:4 0 68 :2 0 69
:3 0 7ec dad daf
:3 0 68 :2 0 7b
:4 0 7ef db1 db3
:3 0 68 :2 0 a3
:4 0 7f2 db5 db7
:3 0 68 :2 0 9e
:3 0 7f5 db9 dbb
:3 0 68 :2 0 a4
:4 0 7f8 dbd dbf
:3 0 68 :2 0 a5
:3 0 a6 :3 0 23
:2 0 a7 :2 0 7fb
dc2 dc6 7ff dc1
dc8 :3 0 802 daa
dca :2 0 dcc 805
dcd da7 dcc 0
dce 807 0 dcf
809 dd2 :3 0 dd2
0 dd2 dd1 dcf
dd0 :6 0 dd4 10
:3 0 80c dd6 80e
dd5 dd4 :2 0 dd7
810 :2 0 dd9 0
dd9 dd8 d8f dd7
:6 0 f0c 1 :3 0
120 :3 0 2e :3 0
121 :3 0 122 :3 0
1b :4 0 123 1
:8 0 de6 15 :3 0
9d :3 0 de1 de2
0 9e :3 0 de3
de4 0 de6 812
e30 9f :3 0 15
:3 0 9d :3 0 de9
dea 0 9e :3 0
deb dec 0 e26
60 :3 0 61 :3 0
dee def 0 60
:3 0 71 :3 0 df1
df2 0 a0 :2 0
2 :4 0 124 :2 0
73 :2 0 23 :2 0
815 df7 df9 :3 0
818 df3 dfb df0
dfd dfc :2 0 63
:3 0 74 :3 0 dff
e00 0 65 :4 0
125 :4 0 68 :2 0
69 :3 0 81c e04
e06 :3 0 68 :2 0
7b :4 0 81f e08
e0a :3 0 68 :2 0
a3 :4 0 822 e0c
e0e :3 0 68 :2 0
9e :3 0 825 e10
e12 :3 0 68 :2 0
a4 :4 0 828 e14
e16 :3 0 68 :2 0
a5 :3 0 a6 :3 0
23 :2 0 a7 :2 0
82b e19 e1d 82f
e18 e1f :3 0 832
e01 e21 :2 0 e23
835 e24 dfe e23
0 e25 837 0
e26 839 e29 :3 0
e29 0 e29 e28
e26 e27 :6 0 e2b
12 :3 0 83c e2d
83e e2c e2b :2 0
e2e 840 :2 0 e30
0 e30 e2f de6
e2e :6 0 f0c 1
:3 0 15 :3 0 9d
:3 0 e32 e33 0
15 :3 0 91 :2 0
c0 :3 0 e35 e37
0 844 e36 e39
:3 0 e3a :2 0 60
:3 0 61 :3 0 e3c
e3d 0 60 :3 0
71 :3 0 e3f e40
0 18 :2 0 2
:4 0 126 :2 0 73
:2 0 23 :2 0 847
e45 e47 :3 0 84a
e41 e49 e3e e4b
e4a :2 0 63 :3 0
74 :3 0 e4d e4e
0 65 :4 0 127
:4 0 68 :2 0 69
:3 0 84e e52 e54
:3 0 68 :2 0 7b
:4 0 851 e56 e58
:3 0 68 :2 0 7c
:4 0 854 e5a e5c
:3 0 68 :2 0 6d
:3 0 6e :3 0 7d
:3 0 f0 :3 0 e61
e62 0 857 e60
e64 6f :4 0 859
e5f e67 85c e5e
e69 :3 0 68 :2 0
c7 :4 0 85f e6b
e6d :3 0 68 :2 0
6b :4 0 862 e6f
e71 :3 0 68 :2 0
1b :3 0 865 e73
e75 :3 0 68 :2 0
6b :4 0 868 e77
e79 :3 0 86b e4f
e7b :2 0 e7d 86e
e7e e4c e7d 0
e7f 870 0 ea9
60 :3 0 61 :3 0
e80 e81 0 60
:3 0 71 :3 0 e83
e84 0 23 :2 0
2 :4 0 128 :2 0
73 :2 0 23 :2 0
872 e89 e8b :3 0
875 e85 e8d e82
e8f e8e :2 0 63
:3 0 74 :3 0 e91
e92 0 65 :4 0
129 :4 0 68 :2 0
69 :3 0 879 e96
e98 :3 0 87c e93
e9a :2 0 e9c 87f
e9d e90 e9c 0
e9e 881 0 ea9
81 :3 0 ca :3 0
e9f ea0 0 7d
:3 0 f0 :3 0 ea2
ea3 0 1b :3 0
83 :3 0 883 ea1
ea7 :2 0 ea9 887
eaa e3b ea9 0
eab 88b 0 f0c
2b :3 0 1b :3 0
eac ead 0 f0c
12a :3 0 12b :3 0
26 :3 0 43 :3 0
12c :3 0 bc :3 0
19 :3 0 11b :3 0
11a :3 0 1b :4 0
12d 1 :8 0 ebf
15 :3 0 9d :3 0
eba ebb 0 9e
:3 0 ebc ebd 0
ebf 88d f09 9f
:3 0 15 :3 0 9d
:3 0 ec2 ec3 0
9e :3 0 ec4 ec5
0 eff 60 :3 0
61 :3 0 ec7 ec8
0 60 :3 0 71
:3 0 eca ecb 0
a0 :2 0 2 :4 0
12e :2 0 73 :2 0
23 :2 0 890 ed0
ed2 :3 0 893 ecc
ed4 ec9 ed6 ed5
:2 0 63 :3 0 74
:3 0 ed8 ed9 0
65 :4 0 12f :4 0
68 :2 0 69 :3 0
897 edd edf :3 0
68 :2 0 7b :4 0
89a ee1 ee3 :3 0
68 :2 0 a3 :4 0
89d ee5 ee7 :3 0
68 :2 0 9e :3 0
8a0 ee9 eeb :3 0
68 :2 0 a4 :4 0
8a3 eed eef :3 0
68 :2 0 a5 :3 0
a6 :3 0 23 :2 0
a7 :2 0 8a6 ef2
ef6 8aa ef1 ef8
:3 0 8ad eda efa
:2 0 efc 8b0 efd
ed7 efc 0 efe
8b2 0 eff 8b4
f02 :3 0 f02 0
f02 f01 eff f00
:6 0 f04 14 :3 0
8b7 f06 8b9 f05
f04 :2 0 f07 8bb
:2 0 f09 0 f09
f08 ebf f07 :6 0
f0c 1 :3 0 ae
:3 0 8bd 1189 a5
:3 0 24 :3 0 23
:2 0 23 :2 0 8c3
f0d f11 91 :2 0
31 :4 0 8c9 f13
f15 :3 0 130 :3 0
2e :3 0 131 :3 0
11a :3 0 1b :4 0
132 1 :8 0 f22
15 :3 0 9d :3 0
f1d f1e 0 9e
:3 0 f1f f20 0
f22 8cc f6c 9f
:3 0 15 :3 0 9d
:3 0 f25 f26 0
9e :3 0 f27 f28
0 f62 60 :3 0
61 :3 0 f2a f2b
0 60 :3 0 71
:3 0 f2d f2e 0
a0 :2 0 2 :4 0
133 :2 0 73 :2 0
23 :2 0 8cf f33
f35 :3 0 8d2 f2f
f37 f2c f39 f38
:2 0 63 :3 0 74
:3 0 f3b f3c 0
65 :4 0 134 :4 0
68 :2 0 69 :3 0
8d6 f40 f42 :3 0
68 :2 0 7b :4 0
8d9 f44 f46 :3 0
68 :2 0 a3 :4 0
8dc f48 f4a :3 0
68 :2 0 9e :3 0
8df f4c f4e :3 0
68 :2 0 a4 :4 0
8e2 f50 f52 :3 0
68 :2 0 a5 :3 0
a6 :3 0 23 :2 0
a7 :2 0 8e5 f55
f59 8e9 f54 f5b
:3 0 8ec f3d f5d
:2 0 f5f 8ef f60
f3a f5f 0 f61
8f1 0 f62 8f3
f65 :3 0 f65 0
f65 f64 f62 f63
:6 0 f67 16 :3 0
8f6 f69 8f8 f68
f67 :2 0 f6a 8fa
:2 0 f6c 0 f6c
f6b f22 f6a :6 0
112a 1 :3 0 15
:3 0 9d :3 0 f6e
f6f 0 15 :3 0
91 :2 0 c0 :3 0
f71 f73 0 8fe
f72 f75 :3 0 f76
:2 0 60 :3 0 61
:3 0 f78 f79 0
60 :3 0 71 :3 0
f7b f7c 0 18
:2 0 2 :4 0 135
:2 0 73 :2 0 23
:2 0 901 f81 f83
:3 0 904 f7d f85
f7a f87 f86 :2 0
63 :3 0 74 :3 0
f89 f8a 0 65
:4 0 136 :4 0 68
:2 0 69 :3 0 908
f8e f90 :3 0 68
:2 0 7b :4 0 90b
f92 f94 :3 0 68
:2 0 7c :4 0 90e
f96 f98 :3 0 68
:2 0 6d :3 0 6e
:3 0 7d :3 0 f0
:3 0 f9d f9e 0
911 f9c fa0 6f
:4 0 913 f9b fa3
916 f9a fa5 :3 0
68 :2 0 c7 :4 0
919 fa7 fa9 :3 0
68 :2 0 6b :4 0
91c fab fad :3 0
68 :2 0 1b :3 0
91f faf fb1 :3 0
68 :2 0 6b :4 0
922 fb3 fb5 :3 0
925 f8b fb7 :2 0
fb9 928 fba f88
fb9 0 fbb 92a
0 fe5 60 :3 0
61 :3 0 fbc fbd
0 60 :3 0 71
:3 0 fbf fc0 0
23 :2 0 2 :4 0
137 :2 0 73 :2 0
23 :2 0 92c fc5
fc7 :3 0 92f fc1
fc9 fbe fcb fca
:2 0 63 :3 0 74
:3 0 fcd fce 0
65 :4 0 138 :4 0
68 :2 0 69 :3 0
933 fd2 fd4 :3 0
936 fcf fd6 :2 0
fd8 939 fd9 fcc
fd8 0 fda 93b
0 fe5 81 :3 0
ca :3 0 fdb fdc
0 7d :3 0 f0
:3 0 fde fdf 0
1b :3 0 83 :3 0
93d fdd fe3 :2 0
fe5 941 fe6 f77
fe5 0 fe7 945
0 112a 2a :3 0
1b :3 0 fe8 fe9
0 112a 110 :3 0
111 :3 0 a5 :3 0
112 :3 0 111 :3 0
a5 :3 0 113 :3 0
114 :3 0 115 :3 0
116 :3 0 117 :3 0
27 :3 0 2c :3 0
2d :3 0 4a :3 0
4b :3 0 4d :3 0
4f :3 0 118 :3 0
119 :3 0 17 :3 0
11a :3 0 1b :3 0
11b :3 0 11c :4 0
139 1 :8 0 100a
15 :3 0 9d :3 0
1005 1006 0 9e
:3 0 1007 1008 0
100a 947 1054 9f
:3 0 15 :3 0 9d
:3 0 100d 100e 0
9e :3 0 100f 1010
0 104a 60 :3 0
61 :3 0 1012 1013
0 60 :3 0 71
:3 0 1015 1016 0
a0 :2 0 2 :4 0
13a :2 0 73 :2 0
23 :2 0 94a 101b
101d :3 0 94d 1017
101f 1014 1021 1020
:2 0 63 :3 0 74
:3 0 1023 1024 0
65 :4 0 13b :4 0
68 :2 0 69 :3 0
951 1028 102a :3 0
68 :2 0 7b :4 0
954 102c 102e :3 0
68 :2 0 a3 :4 0
957 1030 1032 :3 0
68 :2 0 9e :3 0
95a 1034 1036 :3 0
68 :2 0 a4 :4 0
95d 1038 103a :3 0
68 :2 0 a5 :3 0
a6 :3 0 23 :2 0
a7 :2 0 960 103d
1041 964 103c 1043
:3 0 967 1025 1045
:2 0 1047 96a 1048
1022 1047 0 1049
96c 0 104a 96e
104d :3 0 104d 0
104d 104c 104a 104b
:6 0 104f 18 :3 0
971 1051 973 1050
104f :2 0 1052 975
:2 0 1054 0 1054
1053 100a 1052 :6 0
112a 1 :3 0 15
:3 0 9d :3 0 1056
1057 0 15 :3 0
91 :2 0 c0 :3 0
1059 105b 0 979
105a 105d :3 0 105e
:2 0 110 :3 0 111
:3 0 a5 :3 0 112
:3 0 111 :3 0 a5
:3 0 113 :3 0 114
:3 0 115 :3 0 116
:3 0 117 :3 0 27
:3 0 2c :3 0 2d
:3 0 4a :3 0 4b
:3 0 4d :3 0 4f
:3 0 118 :3 0 119
:3 0 17 :3 0 11a
:3 0 1b :3 0 11b
:3 0 11c :4 0 13c
1 :8 0 107f 15
:3 0 9d :3 0 107a
107b 0 9e :3 0
107c 107d 0 107f
97c 10c9 9f :3 0
15 :3 0 9d :3 0
1082 1083 0 9e
:3 0 1084 1085 0
10bf 60 :3 0 61
:3 0 1087 1088 0
60 :3 0 71 :3 0
108a 108b 0 a0
:2 0 2 :4 0 13d
:2 0 73 :2 0 23
:2 0 97f 1090 1092
:3 0 982 108c 1094
1089 1096 1095 :2 0
63 :3 0 74 :3 0
1098 1099 0 65
:4 0 13e :4 0 68
:2 0 69 :3 0 986
109d 109f :3 0 68
:2 0 7b :4 0 989
10a1 10a3 :3 0 68
:2 0 a3 :4 0 98c
10a5 10a7 :3 0 68
:2 0 9e :3 0 98f
10a9 10ab :3 0 68
:2 0 a4 :4 0 992
10ad 10af :3 0 68
:2 0 a5 :3 0 a6
:3 0 23 :2 0 a7
:2 0 995 10b2 10b6
999 10b1 10b8 :3 0
99c 109a 10ba :2 0
10bc 99f 10bd 1097
10bc 0 10be 9a1
0 10bf 9a3 10c2
:3 0 10c2 0 10c2
10c1 10bf 10c0 :6 0
10c4 1a :3 0 9a6
10c6 9a8 10c5 10c4
:2 0 10c7 9aa :2 0
10c9 0 10c9 10c8
107f 10c7 :6 0 10cb
1 :3 0 9ac 10cc
105f 10cb 0 10cd
9ae 0 112a 12a
:3 0 12b :3 0 26
:3 0 43 :3 0 12c
:3 0 bc :3 0 19
:3 0 11b :3 0 11a
:3 0 1b :4 0 13f
1 :8 0 10de 15
:3 0 9d :3 0 10d9
10da 0 9e :3 0
10db 10dc 0 10de
9b0 1128 9f :3 0
15 :3 0 9d :3 0
10e1 10e2 0 9e
:3 0 10e3 10e4 0
111e 60 :3 0 61
:3 0 10e6 10e7 0
60 :3 0 71 :3 0
10e9 10ea 0 a0
:2 0 2 :4 0 140
:2 0 73 :2 0 23
:2 0 9b3 10ef 10f1
:3 0 9b6 10eb 10f3
10e8 10f5 10f4 :2 0
63 :3 0 74 :3 0
10f7 10f8 0 65
:4 0 141 :4 0 68
:2 0 69 :3 0 9ba
10fc 10fe :3 0 68
:2 0 7b :4 0 9bd
1100 1102 :3 0 68
:2 0 a3 :4 0 9c0
1104 1106 :3 0 68
:2 0 9e :3 0 9c3
1108 110a :3 0 68
:2 0 a4 :4 0 9c6
110c 110e :3 0 68
:2 0 a5 :3 0 a6
:3 0 23 :2 0 a7
:2 0 9c9 1111 1115
9cd 1110 1117 :3 0
9d0 10f9 1119 :2 0
111b 9d3 111c 10f6
111b 0 111d 9d5
0 111e 9d7 1121
:3 0 1121 0 1121
1120 111e 111f :6 0
1123 1c :3 0 9da
1125 9dc 1124 1123
:2 0 1126 9de :2 0
1128 0 1128 1127
10de 1126 :6 0 112a
1 :3 0 9e0 112b
f16 112a 0 118b
60 :3 0 61 :3 0
112c 112d 0 60
:3 0 71 :3 0 112f
1130 0 78 :2 0
2 :4 0 142 :2 0
73 :2 0 23 :2 0
9e7 1135 1137 :3 0
9ea 1131 1139 112e
113b 113a :2 0 63
:3 0 74 :3 0 113d
113e 0 65 :4 0
143 :4 0 68 :2 0
69 :3 0 9ee 1142
1144 :3 0 68 :2 0
7b :4 0 9f1 1146
1148 :3 0 68 :2 0
7c :4 0 9f4 114a
114c :3 0 68 :2 0
6d :3 0 6e :3 0
7d :3 0 8a :3 0
1151 1152 0 9f7
1150 1154 6f :4 0
9f9 114f 1157 9fc
114e 1159 :3 0 9ff
113f 115b :2 0 115d
a02 115e 113c 115d
0 115f a04 0
1188 60 :3 0 61
:3 0 1160 1161 0
60 :3 0 71 :3 0
1163 1164 0 23
:2 0 2 :4 0 144
:2 0 73 :2 0 23
:2 0 a06 1169 116b
:3 0 a09 1165 116d
1162 116f 116e :2 0
63 :3 0 74 :3 0
1171 1172 0 65
:4 0 145 :4 0 68
:2 0 69 :3 0 a0d
1176 1178 :3 0 a10
1173 117a :2 0 117c
a13 117d 1170 117c
0 117e a15 0
1188 81 :3 0 82
:3 0 117f 1180 0
7d :3 0 8a :3 0
1182 1183 0 83
:3 0 a17 1181 1186
:2 0 1188 a1a 118a
d6f f0c 0 118b
0 1188 0 118b
a1e 0 1429 15
:3 0 9d :3 0 118c
118d 0 15 :3 0
91 :2 0 a8 :3 0
118f 1191 0 a24
1190 1193 :3 0 1194
:2 0 55 :3 0 146
:3 0 31 :2 0 6d
:3 0 33 :3 0 31
:2 0 a27 1199 119c
7d :3 0 147 :3 0
119e 119f 0 51
:3 0 a2a 1197 11a2
1196 11a3 0 1241
55 :3 0 146 :3 0
31 :2 0 6d :3 0
33 :3 0 31 :2 0
a2f 11a8 11ab 7d
:3 0 148 :3 0 11ad
11ae 0 53 :3 0
a32 11a6 11b1 11a5
11b2 0 1241 12c
:3 0 12b :3 0 149
:3 0 53 :3 0 14a
:3 0 7d :3 0 e6
:3 0 7d :3 0 e7
:3 0 7d :3 0 e8
:3 0 7d :3 0 e9
:3 0 7d :3 0 ea
:3 0 7d :3 0 14b
:3 0 149 :3 0 53
:3 0 7d :3 0 14c
:3 0 149 :3 0 51
:3 0 7d :3 0 14b
:3 0 e1 :3 0 14d
:3 0 12b :3 0 7d
:3 0 14c :3 0 149
:3 0 149 :3 0 53
:3 0 51 :3 0 149
:3 0 12a :3 0 26
:4 0 14e 1 :8 0
11ef 14f :4 0 11da
:3 0 83 :3 0 91
:2 0 a39 11dd 11de
:3 0 15 :3 0 9d
:3 0 11e0 11e1 0
31 :2 0 11e2 11e3
0 11e5 a3c 11ec
15 :3 0 9d :3 0
11e6 11e7 0 f7
:2 0 11e8 11e9 0
11eb a3e 11ed 11df
11e5 0 11ee 0
11eb 0 11ee a40
0 11ef a43 1239
9f :3 0 15 :3 0
9d :3 0 11f2 11f3
0 9e :3 0 11f4
11f5 0 122f 60
:3 0 61 :3 0 11f7
11f8 0 60 :3 0
71 :3 0 11fa 11fb
0 a0 :2 0 2
:4 0 150 :2 0 73
:2 0 23 :2 0 a46
1200 1202 :3 0 a49
11fc 1204 11f9 1206
1205 :2 0 63 :3 0
74 :3 0 1208 1209
0 65 :4 0 151
:4 0 68 :2 0 69
:3 0 a4d 120d 120f
:3 0 68 :2 0 7b
:4 0 a50 1211 1213
:3 0 68 :2 0 a3
:4 0 a53 1215 1217
:3 0 68 :2 0 9e
:3 0 a56 1219 121b
:3 0 68 :2 0 a4
:4 0 a59 121d 121f
:3 0 68 :2 0 a5
:3 0 a6 :3 0 23
:2 0 a7 :2 0 a5c
1222 1226 a60 1221
1228 :3 0 a63 120a
122a :2 0 122c a66
122d 1207 122c 0
122e a68 0 122f
a6a 1232 :3 0 1232
0 1232 1231 122f
1230 :6 0 1234 1e
:3 0 a6d 1236 a6f
1235 1234 :2 0 1237
a71 :2 0 1239 0
1239 1238 11ef 1237
:6 0 1241 1 :3 0
55 :3 0 152 :3 0
26 :3 0 a73 123c
123e 123b 123f 0
1241 a75 12e5 26
:3 0 153 :4 0 1243
1244 :3 0 1242 1245
0 12e4 55 :3 0
146 :3 0 31 :2 0
6d :3 0 33 :3 0
31 :2 0 a7a 124a
124d 7d :3 0 147
:3 0 124f 1250 0
51 :3 0 a7d 1248
1253 1247 1254 0
12e4 50 :3 0 7d
:3 0 14b :3 0 1257
1258 0 1256 1259
0 12e4 54 :3 0
23 :2 0 125b 125c
0 12e4 55 :3 0
154 :3 0 17 :3 0
1b :3 0 33 :3 0
50 :3 0 51 :3 0
24 :3 0 54 :3 0
a82 125f 1267 125e
1268 0 12e4 12c
:3 0 12a :3 0 cd
:3 0 bc :3 0 14a
:3 0 155 :3 0 11b
:3 0 11a :3 0 12b
:3 0 149 :3 0 156
:3 0 157 :3 0 26
:3 0 17 :3 0 19
:3 0 33 :3 0 58
:3 0 24 :3 0 1b
:3 0 7d :3 0 14b
:3 0 51 :3 0 13
:3 0 69 :4 0 158
1 :8 0 1298 14f
:4 0 1283 :3 0 83
:3 0 91 :2 0 a8c
1286 1287 :3 0 15
:3 0 9d :3 0 1289
128a 0 31 :2 0
128b 128c 0 128e
a8f 1295 15 :3 0
9d :3 0 128f 1290
0 f7 :2 0 1291
1292 0 1294 a91
1296 1288 128e 0
1297 0 1294 0
1297 a93 0 1298
a96 12e2 9f :3 0
15 :3 0 9d :3 0
129b 129c 0 9e
:3 0 129d 129e 0
12d8 60 :3 0 61
:3 0 12a0 12a1 0
60 :3 0 71 :3 0
12a3 12a4 0 a0
:2 0 2 :4 0 159
:2 0 73 :2 0 23
:2 0 a99 12a9 12ab
:3 0 a9c 12a5 12ad
12a2 12af 12ae :2 0
63 :3 0 74 :3 0
12b1 12b2 0 65
:4 0 15a :4 0 68
:2 0 69 :3 0 aa0
12b6 12b8 :3 0 68
:2 0 7b :4 0 aa3
12ba 12bc :3 0 68
:2 0 a3 :4 0 aa6
12be 12c0 :3 0 68
:2 0 9e :3 0 aa9
12c2 12c4 :3 0 68
:2 0 a4 :4 0 aac
12c6 12c8 :3 0 68
:2 0 a5 :3 0 a6
:3 0 23 :2 0 a7
:2 0 aaf 12cb 12cf
ab3 12ca 12d1 :3 0
ab6 12b3 12d3 :2 0
12d5 ab9 12d6 12b0
12d5 0 12d7 abb
0 12d8 abd 12db
:3 0 12db 0 12db
12da 12d8 12d9 :6 0
12dd 20 :3 0 ac0
12df ac2 12de 12dd
:2 0 12e0 ac4 :2 0
12e2 0 12e2 12e1
1298 12e0 :6 0 12e4
1 :3 0 ac6 12e6
1195 1241 0 12e7
0 12e4 0 12e7
acd 0 1429 6d
:3 0 35 :3 0 31
:2 0 ad0 12e8 12eb
91 :2 0 31 :2 0
ad5 12ed 12ef :3 0
12f0 :2 0 2c :3 0
84 :2 0 ad8 12f3
12f4 :3 0 12f5 :2 0
12f6 :2 0 12f1 12f8
12f7 :2 0 15b :3 0
25 :3 0 cc :3 0
cd :3 0 17 :4 0
15c 1 :8 0 1305
15 :3 0 9d :3 0
1300 1301 0 9e
:3 0 1302 1303 0
1305 ada 134f 9f
:3 0 15 :3 0 9d
:3 0 1308 1309 0
9e :3 0 130a 130b
0 1345 60 :3 0
61 :3 0 130d 130e
0 60 :3 0 71
:3 0 1310 1311 0
a0 :2 0 2 :4 0
15d :2 0 73 :2 0
23 :2 0 add 1316
1318 :3 0 ae0 1312
131a 130f 131c 131b
:2 0 63 :3 0 74
:3 0 131e 131f 0
65 :4 0 15e :4 0
68 :2 0 69 :3 0
ae4 1323 1325 :3 0
68 :2 0 7b :4 0
ae7 1327 1329 :3 0
68 :2 0 a3 :4 0
aea 132b 132d :3 0
68 :2 0 9e :3 0
aed 132f 1331 :3 0
68 :2 0 a4 :4 0
af0 1333 1335 :3 0
68 :2 0 a5 :3 0
a6 :3 0 23 :2 0
a7 :2 0 af3 1338
133c af7 1337 133e
:3 0 afa 1320 1340
:2 0 1342 afd 1343
131d 1342 0 1344
aff 0 1345 b01
1348 :3 0 1348 0
1348 1347 1345 1346
:6 0 134a 22 :3 0
b04 134c b06 134b
134a :2 0 134d b08
:2 0 134f 0 134f
134e 1305 134d :6 0
1375 1 :3 0 a5
:3 0 25 :3 0 23
:2 0 23 :2 0 b0a
1351 1355 91 :2 0
15f :4 0 b10 1357
1359 :3 0 4c :3 0
160 :2 0 23 :2 0
b13 135c 135e :3 0
135b 135f 0 1372
15 :3 0 9d :3 0
1361 1362 0 161
:3 0 17 :3 0 17
:3 0 27 :3 0 2c
:3 0 2d :3 0 4d
:3 0 4f :3 0 4c
:3 0 4b :3 0 4a
:3 0 b15 1364 136f
1363 1370 0 1372
b20 1373 135a 1372
0 1374 b23 0
1375 b25 1376 12f9
1375 0 1377 b28
0 1429 1e :3 0
1e :3 0 1378 1379
0 1429 a5 :3 0
24 :3 0 23 :2 0
23 :2 0 b2a 137b
137f 91 :2 0 23
:4 0 b30 1381 1383
:3 0 45 :3 0 7d
:3 0 162 :3 0 1386
1387 0 1385 1388
0 138a b33 1393
45 :3 0 6d :3 0
3c :3 0 31 :2 0
b35 138c 138f 138b
1390 0 1392 b38
1394 1384 138a 0
1395 0 1392 0
1395 b3a 0 1429
5c :3 0 163 :3 0
26 :3 0 17 :3 0
19 :3 0 1b :3 0
48 :3 0 33 :3 0
20 :3 0 20 :3 0
20 :3 0 20 :3 0
1e :3 0 1f :3 0
42 :3 0 39 :3 0
37 :3 0 3a :3 0
3b :3 0 36 :3 0
45 :3 0 24 :3 0
35 :3 0 32 :3 0
3d :3 0 38 :3 0
34 :3 0 3f :3 0
46 :3 0 1a :3 0
31 :2 0 31 :2 0
4e :2 0 4e :2 0
b3d 1397 13b8 1396
13b9 0 1429 5c
:3 0 91 :2 0 31
:2 0 b60 13bc 13be
:3 0 164 :3 0 165
:3 0 166 :3 0 1b
:4 0 167 1 :8 0
13da 14f :4 0 13c5
:3 0 83 :3 0 91
:2 0 b65 13c8 13c9
:3 0 15 :3 0 9d
:3 0 13cb 13cc 0
31 :2 0 13cd 13ce
0 13d0 b68 13d7
15 :3 0 9d :3 0
13d1 13d2 0 f7
:2 0 13d3 13d4 0
13d6 b6a 13d8 13ca
13d0 0 13d9 0
13d6 0 13d9 b6c
0 13da b6f 1424
9f :3 0 15 :3 0
9d :3 0 13dd 13de
0 9e :3 0 13df
13e0 0 141a 60
:3 0 61 :3 0 13e2
13e3 0 60 :3 0
71 :3 0 13e5 13e6
0 a0 :2 0 2
:4 0 168 :2 0 73
:2 0 23 :2 0 b72
13eb 13ed :3 0 b75
13e7 13ef 13e4 13f1
13f0 :2 0 63 :3 0
74 :3 0 13f3 13f4
0 65 :4 0 169
:4 0 68 :2 0 69
:3 0 b79 13f8 13fa
:3 0 68 :2 0 7b
:4 0 b7c 13fc 13fe
:3 0 68 :2 0 a3
:4 0 b7f 1400 1402
:3 0 68 :2 0 9e
:3 0 b82 1404 1406
:3 0 68 :2 0 a4
:4 0 b85 1408 140a
:3 0 68 :2 0 a5
:3 0 a6 :3 0 23
:2 0 a7 :2 0 b88
140d 1411 b8c 140c
1413 :3 0 b8f 13f5
1415 :2 0 1417 b92
1418 13f2 1417 0
1419 b94 0 141a
b96 141d :3 0 141d
0 141d 141c 141a
141b :6 0 141f 24
:3 0 b99 1421 b9b
1420 141f :2 0 1422
b9d :2 0 1424 0
1424 1423 13da 1422
:6 0 1426 1 :3 0
b9f 1427 13bf 1426
0 1428 ba1 0
1429 ba3 172f 2a
:3 0 f8 :4 0 142a
142b 0 172e 2b
:3 0 f8 :4 0 142d
142e 0 172e 28
:3 0 12 :3 0 1430
1431 0 172e 6d
:3 0 85 :3 0 28
:3 0 bad 1434 1436
31 :2 0 baf 1433
1439 86 :2 0 18
:2 0 bb4 143b 143d
:3 0 5e :3 0 31
:2 0 143f 1440 0
1442 bb7 145a 5e
:3 0 10d :3 0 6d
:3 0 85 :3 0 28
:3 0 bb9 1446 1448
31 :2 0 bbb 1445
144b 73 :2 0 23
:2 0 bbe 144d 144f
:3 0 1450 :2 0 16a
:2 0 e3 :2 0 bc1
1452 1454 :3 0 bc4
1444 1456 1443 1457
0 1459 bc6 145b
143e 1442 0 145c
0 1459 0 145c
bc8 0 172e 5e
:3 0 d1 :2 0 31
:2 0 bcd 145e 1460
:3 0 30 :3 0 31
:2 0 1462 1463 0
172b 16b :3 0 6d
:3 0 30 :3 0 31
:2 0 bd0 1466 1469
5e :3 0 86 :2 0
16c :3 0 bd5 146c
146e :3 0 146f 172a
1b :3 0 e1 :3 0
e2 :3 0 1472 1473
0 18 :2 0 18
:2 0 6d :3 0 30
:3 0 31 :2 0 bd8
1477 147a 105 :2 0
e3 :2 0 bdb 147c
147e :3 0 73 :2 0
23 :2 0 bde 1480
1482 :3 0 28 :3 0
be1 1474 1485 1471
1486 0 1728 24
:3 0 e1 :3 0 e2
:3 0 1489 148a 0
23 :2 0 23 :2 0
6d :3 0 30 :3 0
31 :2 0 be6 148e
1491 105 :2 0 e3
:2 0 be9 1493 1495
:3 0 73 :2 0 18
:2 0 bec 1497 1499
:3 0 73 :2 0 23
:2 0 bef 149b 149d
:3 0 28 :3 0 bf2
148b 14a0 1488 14a1
0 1728 a5 :3 0
24 :3 0 23 :2 0
23 :2 0 bf7 14a3
14a7 91 :2 0 23
:4 0 bfd 14a9 14ab
:3 0 45 :3 0 7d
:3 0 162 :3 0 14ae
14af 0 14ad 14b0
0 14de 6d :3 0
85 :3 0 2b :3 0
c00 14b3 14b5 31
:2 0 c02 14b2 14b8
91 :2 0 31 :2 0
c07 14ba 14bc :3 0
2b :3 0 1b :3 0
14be 14bf 0 14c1
c0a 14db 2b :3 0
a5 :3 0 2b :3 0
68 :2 0 16d :4 0
c0c 14c5 14c7 :3 0
23 :2 0 29 :2 0
c0f 14c3 14cb 14c2
14cc 0 14da 2b
:3 0 a5 :3 0 2b
:3 0 68 :2 0 1b
:3 0 c13 14d1 14d3
:3 0 23 :2 0 29
:2 0 c16 14cf 14d7
14ce 14d8 0 14da
c1a 14dc 14bd 14c1
0 14dd 0 14da
0 14dd c1d 0
14de c20 1513 45
:3 0 6d :3 0 3c
:3 0 31 :2 0 c23
14e0 14e3 14df 14e4
0 1512 6d :3 0
85 :3 0 2a :3 0
c26 14e7 14e9 31
:2 0 c28 14e6 14ec
91 :2 0 31 :2 0
c2d 14ee 14f0 :3 0
2a :3 0 1b :3 0
14f2 14f3 0 14f5
c30 150f 2a :3 0
a5 :3 0 2a :3 0
68 :2 0 16d :4 0
c32 14f9 14fb :3 0
23 :2 0 29 :2 0
c35 14f7 14ff 14f6
1500 0 150e 2a
:3 0 a5 :3 0 2a
:3 0 68 :2 0 1b
:3 0 c39 1505 1507
:3 0 23 :2 0 29
:2 0 c3c 1503 150b
1502 150c 0 150e
c40 1510 14f1 14f5
0 1511 0 150e
0 1511 c43 0
1512 c46 1514 14ac
14de 0 1515 0
1512 0 1515 c49
0 1728 a5 :3 0
24 :3 0 23 :2 0
23 :2 0 c4c 1516
151a 91 :2 0 23
:4 0 c52 151c 151e
:3 0 111 :3 0 a5
:3 0 1c :3 0 111
:3 0 a5 :3 0 16e
:3 0 111 :3 0 a5
:3 0 16f :3 0 16e
:3 0 170 :3 0 1c
:3 0 1e :3 0 118
:3 0 119 :3 0 17
:3 0 11a :3 0 1b
:3 0 11b :4 0 171
1 :8 0 1539 15
:3 0 9d :3 0 1534
1535 0 9e :3 0
1536 1537 0 1539
c55 1583 9f :3 0
15 :3 0 9d :3 0
153c 153d 0 9e
:3 0 153e 153f 0
1579 60 :3 0 61
:3 0 1541 1542 0
60 :3 0 71 :3 0
1544 1545 0 a0
:2 0 2 :4 0 172
:2 0 73 :2 0 23
:2 0 c58 154a 154c
:3 0 c5b 1546 154e
1543 1550 154f :2 0
63 :3 0 74 :3 0
1552 1553 0 65
:4 0 173 :4 0 68
:2 0 69 :3 0 c5f
1557 1559 :3 0 68
:2 0 7b :4 0 c62
155b 155d :3 0 68
:2 0 a3 :4 0 c65
155f 1561 :3 0 68
:2 0 9e :3 0 c68
1563 1565 :3 0 68
:2 0 a4 :4 0 c6b
1567 1569 :3 0 68
:2 0 a5 :3 0 a6
:3 0 23 :2 0 a7
:2 0 c6e 156c 1570
c72 156b 1572 :3 0
c75 1554 1574 :2 0
1576 c78 1577 1551
1576 0 1578 c7a
0 1579 c7c 157c
:3 0 157c 0 157c
157b 1579 157a :6 0
157e 27 :3 0 c7f
1580 c81 157f 157e
:2 0 1581 c83 :2 0
1583 0 1583 1582
1539 1581 :6 0 158b
26 :3 0 44 :3 0
31 :2 0 1585 1586
0 158b 35 :3 0
31 :2 0 1588 1589
0 158b c85 1666
111 :3 0 a5 :3 0
1c :3 0 111 :3 0
a5 :3 0 16e :3 0
111 :3 0 a5 :3 0
16f :3 0 16e :3 0
170 :3 0 1c :3 0
1e :3 0 118 :3 0
119 :3 0 17 :3 0
11a :3 0 1b :3 0
11b :3 0 11c :4 0
174 1 :8 0 15a6
15 :3 0 9d :3 0
15a1 15a2 0 9e
:3 0 15a3 15a4 0
15a6 c89 15f0 9f
:3 0 15 :3 0 9d
:3 0 15a9 15aa 0
9e :3 0 15ab 15ac
0 15e6 60 :3 0
61 :3 0 15ae 15af
0 60 :3 0 71
:3 0 15b1 15b2 0
a0 :2 0 2 :4 0
175 :2 0 73 :2 0
23 :2 0 c8c 15b7
15b9 :3 0 c8f 15b3
15bb 15b0 15bd 15bc
:2 0 63 :3 0 74
:3 0 15bf 15c0 0
65 :4 0 176 :4 0
68 :2 0 69 :3 0
c93 15c4 15c6 :3 0
68 :2 0 7b :4 0
c96 15c8 15ca :3 0
68 :2 0 a3 :4 0
c99 15cc 15ce :3 0
68 :2 0 9e :3 0
c9c 15d0 15d2 :3 0
68 :2 0 a4 :4 0
c9f 15d4 15d6 :3 0
68 :2 0 a5 :3 0
a6 :3 0 23 :2 0
a7 :2 0 ca2 15d9
15dd ca6 15d8 15df
:3 0 ca9 15c1 15e1
:2 0 15e3 cac 15e4
15be 15e3 0 15e5
cae 0 15e6 cb0
15e9 :3 0 15e9 0
15e9 15e8 15e6 15e7
:6 0 15eb 29 :3 0
cb3 15ed cb5 15ec
15eb :2 0 15ee cb7
:2 0 15f0 0 15f0
15ef 15a6 15ee :6 0
1665 26 :3 0 15
:3 0 9d :3 0 15f2
15f3 0 15 :3 0
91 :2 0 c0 :3 0
15f5 15f7 0 cbb
15f6 15f9 :3 0 15fa
:2 0 111 :3 0 a5
:3 0 1c :3 0 111
:3 0 a5 :3 0 16e
:3 0 111 :3 0 a5
:3 0 16f :3 0 16e
:3 0 170 :3 0 1c
:3 0 1e :3 0 118
:3 0 119 :3 0 17
:3 0 11a :3 0 1b
:3 0 11b :3 0 11c
:4 0 177 1 :8 0
1616 15 :3 0 9d
:3 0 1611 1612 0
9e :3 0 1613 1614
0 1616 cbe 1660
9f :3 0 15 :3 0
9d :3 0 1619 161a
0 9e :3 0 161b
161c 0 1656 60
:3 0 61 :3 0 161e
161f 0 60 :3 0
71 :3 0 1621 1622
0 a0 :2 0 2
:4 0 178 :2 0 73
:2 0 23 :2 0 cc1
1627 1629 :3 0 cc4
1623 162b 1620 162d
162c :2 0 63 :3 0
74 :3 0 162f 1630
0 65 :4 0 179
:4 0 68 :2 0 69
:3 0 cc8 1634 1636
:3 0 68 :2 0 7b
:4 0 ccb 1638 163a
:3 0 68 :2 0 a3
:4 0 cce 163c 163e
:3 0 68 :2 0 9e
:3 0 cd1 1640 1642
:3 0 68 :2 0 a4
:4 0 cd4 1644 1646
:3 0 68 :2 0 a5
:3 0 a6 :3 0 23
:2 0 a7 :2 0 cd7
1649 164d cdb 1648
164f :3 0 cde 1631
1651 :2 0 1653 ce1
1654 162e 1653 0
1655 ce3 0 1656
ce5 1659 :3 0 1659
0 1659 1658 1656
1657 :6 0 165b 2b
:3 0 ce8 165d cea
165c 165b :2 0 165e
cec :2 0 1660 0
1660 165f 1616 165e
:6 0 1662 26 :3 0
cee 1663 15fb 1662
0 1664 cf0 0
1665 cf2 1667 151f
158b 0 1668 0
1665 0 1668 cf5
0 1728 1e :3 0
1e :3 0 1669 166a
0 1728 a5 :3 0
24 :3 0 23 :2 0
23 :2 0 cf8 166c
1670 91 :2 0 23
:4 0 cfe 1672 1674
:3 0 45 :3 0 7d
:3 0 162 :3 0 1677
1678 0 1676 1679
0 167b d01 1684
45 :3 0 6d :3 0
3c :3 0 31 :2 0
d03 167d 1680 167c
1681 0 1683 d06
1685 1675 167b 0
1686 0 1683 0
1686 d08 0 1728
1e :3 0 1c :3 0
1687 1688 0 1728
5c :3 0 163 :3 0
26 :3 0 17 :3 0
19 :3 0 1b :3 0
48 :3 0 33 :3 0
20 :3 0 20 :3 0
20 :3 0 20 :3 0
1e :3 0 1f :3 0
42 :3 0 39 :3 0
37 :3 0 3a :3 0
3b :3 0 36 :3 0
45 :3 0 24 :3 0
35 :3 0 32 :3 0
3d :3 0 38 :3 0
34 :3 0 3f :3 0
46 :3 0 1a :3 0
31 :2 0 31 :2 0
4e :2 0 4e :2 0
d0b 168b 16ac 168a
16ad 0 1728 5c
:3 0 91 :2 0 31
:2 0 d2e 16b0 16b2
:3 0 164 :3 0 165
:3 0 166 :3 0 1b
:4 0 167 1 :8 0
16ce 14f :4 0 16b9
:3 0 83 :3 0 91
:2 0 d33 16bc 16bd
:3 0 15 :3 0 9d
:3 0 16bf 16c0 0
31 :2 0 16c1 16c2
0 16c4 d36 16cb
15 :3 0 9d :3 0
16c5 16c6 0 f7
:2 0 16c7 16c8 0
16ca d38 16cc 16be
16c4 0 16cd 0
16ca 0 16cd d3a
0 16ce d3d 1718
9f :3 0 15 :3 0
9d :3 0 16d1 16d2
0 9e :3 0 16d3
16d4 0 170e 60
:3 0 61 :3 0 16d6
16d7 0 60 :3 0
71 :3 0 16d9 16da
0 a0 :2 0 2
:4 0 17a :2 0 73
:2 0 23 :2 0 d40
16df 16e1 :3 0 d43
16db 16e3 16d8 16e5
16e4 :2 0 63 :3 0
74 :3 0 16e7 16e8
0 65 :4 0 17b
:4 0 68 :2 0 69
:3 0 d47 16ec 16ee
:3 0 68 :2 0 7b
:4 0 d4a 16f0 16f2
:3 0 68 :2 0 a3
:4 0 d4d 16f4 16f6
:3 0 68 :2 0 9e
:3 0 d50 16f8 16fa
:3 0 68 :2 0 a4
:4 0 d53 16fc 16fe
:3 0 68 :2 0 a5
:3 0 a6 :3 0 23
:2 0 a7 :2 0 d56
1701 1705 d5a 1700
1707 :3 0 d5d 16e9
1709 :2 0 170b d60
170c 16e6 170b 0
170d d62 0 170e
d64 1711 :3 0 1711
0 1711 1710 170e
170f :6 0 1713 2d
:3 0 d67 1715 d69
1714 1713 :2 0 1716
d6b :2 0 1718 0
1718 1717 16ce 1716
:6 0 171a 26 :3 0
d6d 171b 16b3 171a
0 171c d6f 0
1728 30 :3 0 6d
:3 0 30 :3 0 31
:2 0 d71 171e 1721
73 :2 0 23 :2 0
d74 1723 1725 :3 0
171d 1726 0 1728
d77 172a 16c :3 0
1470 1728 :4 0 172b
d82 172c 1461 172b
0 172d d85 0
172e d87 1730 d5f
1429 0 1731 0
172e 0 1731 d8d
0 19f7 5c :3 0
97 :2 0 31 :2 0
d92 1733 1735 :3 0
1736 :2 0 6d :3 0
33 :3 0 31 :2 0
d95 1738 173b d1
:2 0 31 :2 0 d9a
173d 173f :3 0 1740
:2 0 1737 1742 1741
:2 0 60 :3 0 61
:3 0 1744 1745 0
60 :3 0 71 :3 0
1747 1748 0 18
:2 0 2 :4 0 17c
:2 0 73 :2 0 23
:2 0 d9d 174d 174f
:3 0 da0 1749 1751
1746 1753 1752 :2 0
63 :3 0 74 :3 0
1755 1756 0 65
:4 0 17d :4 0 68
:2 0 69 :3 0 da4
175a 175c :3 0 68
:2 0 7b :4 0 da7
175e 1760 :3 0 68
:2 0 7c :4 0 daa
1762 1764 :3 0 68
:2 0 6d :3 0 6e
:3 0 7d :3 0 17e
:3 0 1769 176a 0
dad 1768 176c 6f
:4 0 daf 1767 176f
db2 1766 1771 :3 0
68 :2 0 c7 :4 0
db5 1773 1775 :3 0
68 :2 0 6b :4 0
db8 1777 1779 :3 0
68 :2 0 26 :3 0
dbb 177b 177d :3 0
68 :2 0 6b :4 0
dbe 177f 1781 :3 0
dc1 1757 1783 :2 0
1785 dc4 1786 1754
1785 0 1787 dc6
0 17b1 60 :3 0
61 :3 0 1788 1789
0 60 :3 0 71
:3 0 178b 178c 0
23 :2 0 2 :4 0
17f :2 0 73 :2 0
23 :2 0 dc8 1791
1793 :3 0 dcb 178d
1795 178a 1797 1796
:2 0 63 :3 0 74
:3 0 1799 179a 0
65 :4 0 180 :4 0
68 :2 0 69 :3 0
dcf 179e 17a0 :3 0
dd2 179b 17a2 :2 0
17a4 dd5 17a5 1798
17a4 0 17a6 dd7
0 17b1 81 :3 0
ca :3 0 17a7 17a8
0 7d :3 0 17e
:3 0 17aa 17ab 0
26 :3 0 83 :3 0
dd9 17a9 17af :2 0
17b1 ddd 17b2 1743
17b1 0 17b3 de1
0 19f7 6d :3 0
33 :3 0 31 :2 0
de3 17b4 17b7 d1
:2 0 31 :2 0 de8
17b9 17bb :3 0 17
:3 0 19 :3 0 17bd
17be 0 17c0 deb
17c1 17bc 17c0 0
17c2 ded 0 19f7
6d :3 0 85 :3 0
2a :3 0 def 17c4
17c6 31 :2 0 df1
17c3 17c9 d1 :2 0
31 :2 0 df6 17cb
17cd :3 0 17ce :2 0
6d :3 0 85 :3 0
2b :3 0 df9 17d1
17d3 31 :2 0 dfb
17d0 17d6 d1 :2 0
31 :2 0 e00 17d8
17da :3 0 17db :2 0
17cf 17dd 17dc :2 0
56 :3 0 181 :4 0
68 :2 0 182 :4 0
e03 17e1 17e3 :3 0
68 :2 0 183 :4 0
e06 17e5 17e7 :3 0
68 :2 0 184 :4 0
e09 17e9 17eb :3 0
68 :2 0 185 :4 0
e0c 17ed 17ef :3 0
68 :2 0 6e :3 0
6d :3 0 39 :3 0
31 :2 0 e0f 17f3
17f6 e12 17f2 17f8
e14 17f1 17fa :3 0
68 :2 0 186 :4 0
e17 17fc 17fe :3 0
68 :2 0 6e :3 0
6d :3 0 3a :3 0
31 :2 0 e1a 1802
1805 e1d 1801 1807
e1f 1800 1809 :3 0
68 :2 0 187 :4 0
e22 180b 180d :3 0
68 :2 0 6e :3 0
6d :3 0 3f :3 0
31 :2 0 e25 1811
1814 e28 1810 1816
e2a 180f 1818 :3 0
68 :2 0 188 :4 0
e2d 181a 181c :3 0
68 :2 0 189 :4 0
e30 181e 1820 :3 0
68 :2 0 18a :4 0
e33 1822 1824 :3 0
68 :2 0 18b :4 0
e36 1826 1828 :3 0
68 :2 0 18c :4 0
e39 182a 182c :3 0
68 :2 0 18d :4 0
e3c 182e 1830 :3 0
68 :2 0 17 :3 0
e3f 1832 1834 :3 0
68 :2 0 18e :4 0
e42 1836 1838 :3 0
68 :2 0 2a :3 0
e45 183a 183c :3 0
68 :2 0 18f :4 0
e48 183e 1840 :3 0
68 :2 0 190 :4 0
e4b 1842 1844 :3 0
68 :2 0 191 :4 0
e4e 1846 1848 :3 0
68 :2 0 192 :4 0
e51 184a 184c :3 0
68 :2 0 7d :3 0
193 :3 0 184f 1850
0 e54 184e 1852
:3 0 68 :2 0 194
:4 0 e57 1854 1856
:3 0 68 :2 0 7d
:3 0 193 :3 0 1859
185a 0 e5a 1858
185c :3 0 68 :2 0
195 :4 0 e5d 185e
1860 :3 0 68 :2 0
196 :4 0 e60 1862
1864 :3 0 68 :2 0
197 :4 0 e63 1866
1868 :3 0 68 :2 0
6e :3 0 6d :3 0
39 :3 0 31 :2 0
e66 186c 186f e69
186b 1871 e6b 186a
1873 :3 0 68 :2 0
186 :4 0 e6e 1875
1877 :3 0 68 :2 0
6e :3 0 6d :3 0
3a :3 0 31 :2 0
e71 187b 187e e74
187a 1880 e76 1879
1882 :3 0 68 :2 0
198 :4 0 e79 1884
1886 :3 0 68 :2 0
199 :4 0 e7c 1888
188a :3 0 68 :2 0
6e :3 0 6d :3 0
3f :3 0 31 :2 0
e7f 188e 1891 e82
188d 1893 e84 188c
1895 :3 0 68 :2 0
19a :4 0 e87 1897
1899 :3 0 68 :2 0
19b :4 0 e8a 189b
189d :3 0 68 :2 0
17 :3 0 e8d 189f
18a1 :3 0 68 :2 0
19c :4 0 e90 18a3
18a5 :3 0 68 :2 0
2b :3 0 e93 18a7
18a9 :3 0 68 :2 0
19d :4 0 e96 18ab
18ad :3 0 68 :2 0
19e :4 0 e99 18af
18b1 :3 0 68 :2 0
19f :4 0 e9c 18b3
18b5 :3 0 17df 18b6
0 18b9 ae :3 0
e9f 19af 6d :3 0
85 :3 0 2a :3 0
ea1 18bb 18bd 31
:2 0 ea3 18ba 18c0
d1 :2 0 31 :2 0
ea8 18c2 18c4 :3 0
56 :3 0 181 :4 0
68 :2 0 182 :4 0
eab 18c8 18ca :3 0
68 :2 0 183 :4 0
eae 18cc 18ce :3 0
68 :2 0 184 :4 0
eb1 18d0 18d2 :3 0
68 :2 0 185 :4 0
eb4 18d4 18d6 :3 0
68 :2 0 6e :3 0
6d :3 0 39 :3 0
31 :2 0 eb7 18da
18dd eba 18d9 18df
ebc 18d8 18e1 :3 0
68 :2 0 186 :4 0
ebf 18e3 18e5 :3 0
68 :2 0 6e :3 0
6d :3 0 3a :3 0
31 :2 0 ec2 18e9
18ec ec5 18e8 18ee
ec7 18e7 18f0 :3 0
68 :2 0 187 :4 0
eca 18f2 18f4 :3 0
68 :2 0 6e :3 0
6d :3 0 3f :3 0
31 :2 0 ecd 18f8
18fb ed0 18f7 18fd
ed2 18f6 18ff :3 0
68 :2 0 188 :4 0
ed5 1901 1903 :3 0
68 :2 0 189 :4 0
ed8 1905 1907 :3 0
68 :2 0 18a :4 0
edb 1909 190b :3 0
68 :2 0 18b :4 0
ede 190d 190f :3 0
68 :2 0 18c :4 0
ee1 1911 1913 :3 0
68 :2 0 18d :4 0
ee4 1915 1917 :3 0
68 :2 0 17 :3 0
ee7 1919 191b :3 0
68 :2 0 18e :4 0
eea 191d 191f :3 0
68 :2 0 2a :3 0
eed 1921 1923 :3 0
68 :2 0 18f :4 0
ef0 1925 1927 :3 0
68 :2 0 19f :4 0
ef3 1929 192b :3 0
18c6 192c 0 192f
ae :3 0 ef6 1930
18c5 192f 0 19b0
6d :3 0 85 :3 0
2b :3 0 ef8 1932
1934 31 :2 0 efa
1931 1937 d1 :2 0
31 :2 0 eff 1939
193b :3 0 56 :3 0
191 :4 0 68 :2 0
192 :4 0 f02 193f
1941 :3 0 68 :2 0
7d :3 0 193 :3 0
1944 1945 0 f05
1943 1947 :3 0 68
:2 0 194 :4 0 f08
1949 194b :3 0 68
:2 0 7d :3 0 193
:3 0 194e 194f 0
f0b 194d 1951 :3 0
68 :2 0 195 :4 0
f0e 1953 1955 :3 0
68 :2 0 196 :4 0
f11 1957 1959 :3 0
68 :2 0 197 :4 0
f14 195b 195d :3 0
68 :2 0 6e :3 0
6d :3 0 39 :3 0
31 :2 0 f17 1961
1964 f1a 1960 1966
f1c 195f 1968 :3 0
68 :2 0 186 :4 0
f1f 196a 196c :3 0
68 :2 0 6e :3 0
6d :3 0 3a :3 0
31 :2 0 f22 1970
1973 f25 196f 1975
f27 196e 1977 :3 0
68 :2 0 198 :4 0
f2a 1979 197b :3 0
68 :2 0 199 :4 0
f2d 197d 197f :3 0
68 :2 0 6e :3 0
6d :3 0 3f :3 0
31 :2 0 f30 1983
1986 f33 1982 1988
f35 1981 198a :3 0
68 :2 0 19a :4 0
f38 198c 198e :3 0
68 :2 0 19b :4 0
f3b 1990 1992 :3 0
68 :2 0 17 :3 0
f3e 1994 1996 :3 0
68 :2 0 19c :4 0
f41 1998 199a :3 0
68 :2 0 2b :3 0
f44 199c 199e :3 0
68 :2 0 19d :4 0
f47 19a0 19a2 :3 0
68 :2 0 19e :4 0
f4a 19a4 19a6 :3 0
68 :2 0 19f :4 0
f4d 19a8 19aa :3 0
193d 19ab 0 19ad
f50 19ae 193c 19ad
0 19b0 17de 18b9
0 19b0 f52 0
19f7 60 :3 0 61
:3 0 19b1 19b2 0
60 :3 0 71 :3 0
19b4 19b5 0 23
:2 0 2 :4 0 1a0
:2 0 73 :2 0 23
:2 0 f56 19ba 19bc
:3 0 f59 19b6 19be
19b3 19c0 19bf :2 0
63 :3 0 74 :3 0
19c2 19c3 0 65
:4 0 1a1 :4 0 68
:2 0 69 :3 0 f5d
19c7 19c9 :3 0 f60
19c4 19cb :2 0 19cd
f63 19ce 19c1 19cd
0 19cf f65 0
19f7 60 :3 0 61
:3 0 19d0 19d1 0
60 :3 0 71 :3 0
19d3 19d4 0 23
:2 0 2 :4 0 1a2
:2 0 73 :2 0 23
:2 0 f67 19d9 19db
:3 0 f6a 19d5 19dd
19d2 19df 19de :2 0
63 :3 0 74 :3 0
19e1 19e2 0 65
:4 0 1a3 :4 0 68
:2 0 69 :3 0 f6e
19e6 19e8 :3 0 f71
19e3 19ea :2 0 19ec
f74 19ed 19e0 19ec
0 19ee f76 0
19f7 14 :3 0 81
:3 0 1a4 :3 0 19f0
19f1 0 56 :3 0
f78 19f2 19f4 19f5
:2 0 19f7 f7a 1a98
15 :3 0 1a5 :2 0
4 19f8 19f9 0
60 :3 0 61 :3 0
19fb 19fc 0 60
:3 0 71 :3 0 19fe
19ff 0 a0 :2 0
2 :4 0 1a6 :2 0
73 :2 0 23 :2 0
faa 1a04 1a06 :3 0
fad 1a00 1a08 19fd
1a0a 1a09 :2 0 63
:3 0 74 :3 0 1a0c
1a0d 0 65 :4 0
1a7 :4 0 68 :2 0
69 :3 0 fb1 1a11
1a13 :3 0 fb4 1a0e
1a15 :2 0 1a2e 63
:3 0 74 :3 0 1a17
1a18 0 65 :4 0
1a8 :4 0 68 :2 0
15 :3 0 1a9 :3 0
1a1d 1a1e 0 fb7
1a1c 1a20 :3 0 68
:2 0 c7 :4 0 fba
1a22 1a24 :3 0 68
:2 0 15 :3 0 1aa
:3 0 1a27 1a28 0
fbd 1a26 1a2a :3 0
fc0 1a19 1a2c :2 0
1a2e fc3 1a2f 1a0b
1a2e 0 1a30 fc6
0 1a40 1ab :3 0
5f :3 0 15 :3 0
1a9 :3 0 1ac :3 0
15 :3 0 1aa :3 0
1ad :3 0 9b :4 0
1ae 1 :a 0 1a3c
:2 0 1a40 1a32 1a3a
:2 0 14 :3 0 5f
:3 0 1a3e :2 0 1a40
fc8 1a42 fcc 1a41
1a40 :2 0 1a96 9f
:3 0 15 :3 0 9d
:3 0 1a45 1a46 0
9e :3 0 1a47 1a48
0 1a8e 60 :3 0
61 :3 0 1a4a 1a4b
0 60 :3 0 71
:3 0 1a4d 1a4e 0
a0 :2 0 2 :4 0
1af :2 0 73 :2 0
23 :2 0 fce 1a53
1a55 :3 0 fd1 1a4f
1a57 1a4c 1a59 1a58
:2 0 63 :3 0 74
:3 0 1a5b 1a5c 0
65 :4 0 1b0 :4 0
68 :2 0 69 :3 0
fd5 1a60 1a62 :3 0
fd8 1a5d 1a64 :2 0
1a7e 63 :3 0 74
:3 0 1a66 1a67 0
65 :4 0 a3 :4 0
68 :2 0 9e :3 0
fdb 1a6b 1a6d :3 0
68 :2 0 a4 :4 0
fde 1a6f 1a71 :3 0
68 :2 0 a5 :3 0
a6 :3 0 23 :2 0
a7 :2 0 fe1 1a74
1a78 fe5 1a73 1a7a
:3 0 fe8 1a68 1a7c
:2 0 1a7e feb 1a7f
1a5a 1a7e 0 1a80
fee 0 1a8e 1ab
:3 0 5f :3 0 1ac
:3 0 15 :3 0 1aa
:3 0 1ad :3 0 9b
:4 0 1b1 1 :a 0
1a8a :2 0 1a8e 1a82
1a88 :2 0 14 :3 0
5f :3 0 1a8c :2 0
1a8e ff0 1a91 :3 0
1a91 0 1a91 1a90
1a8e 1a8f :6 0 1a93
1 :3 0 ff5 1a95
ff7 1a94 1a93 :2 0
1a96 ff9 :2 0 1a98
ffc 1a98 1a97 19f7
1a96 :6 0 1a99 :2 0
2 44 1a98 1a9c
:3 0 1a9b 1a99 1a9d
:8 0 
103b
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
4f 1 4d 1
56 1 54 1
5d 1 5b 1
64 1 62 1
6b 1 69 1
72 1 70 1
77 1 7e 1
7c 1 85 1
83 1 8c 1
8a 1 93 1
91 1 9a 1
98 1 a1 1
9f 1 a8 1
a6 1 af 1
ad 1 b4 1
b9 1 c0 1
be 1 c5 1
cb 1 d1 1
d7 1 dd 1
e3 1 e9 1
ef 1 f5 1
fb 1 101 1
107 1 10d 1
113 1 119 1
11f 1 125 1
12b 1 131 1
137 1 13d 1
143 1 149 1
14f 1 155 1
15b 1 161 1
167 1 16d 1
173 1 17b 1
179 1 182 1
180 1 187 1
18d 1 195 1
193 1 19a 1
1a0 1 1a6 1
1ac 1 1b2 1
1b8 1 1be 1
1c3 1 1d0 1
1dc 2 1df 1e1
2 1e4 1e6 2
1e8 1ea 2 1ec
1ee 2 1f0 1f2
2 1f4 1f6 2
1f8 1fa 2 1fc
1fe 2 200 202
2 204 206 2
208 20a 2 20c
20e 2 210 212
1 218 2 21a
21b 2 214 21d
2 21f 221 1
227 2 229 22a
2 223 22c 2
22e 230 1 236
2 238 239 2
232 23b 2 23d
23f 1 245 2
247 248 2 241
24a 2 24c 24e
1 254 2 256
257 2 250 259
2 25b 25d 1
263 2 265 266
2 25f 268 2
26a 26c 1 272
2 274 275 2
26e 277 2 279
27b 1 281 2
283 284 2 27d
286 2 288 28a
1 290 2 292
293 2 28c 295
2 297 299 1
29f 2 2a1 2a2
2 29b 2a4 2
2a6 2a8 2 2aa
2ac 2 2ae 2b0
2 2b2 2b4 2
2b6 2b8 2 2ba
2bc 2 2be 2c0
2 2c2 2c4 2
2c6 2c8 4 1d8
1de 1e3 2ca 1
2cc 1 2ce 2
2d8 2da 3 2d6
2d7 2dc 2 2e5
2e7 2 2e4 2e9
1 2eb 1 2ed
2 31f 320 1
322 1 32c 2
339 33b 3 337
338 33d 2 346
348 2 34a 34c
2 34e 350 1
358 2 35a 35b
2 352 35d 2
345 35f 1 361
1 363 2 36d
36f 3 36b 36c
371 2 37a 37c
2 379 37e 1
380 1 382 2
389 38a 3 364
383 38c 1 38e
1 390 1 397
2 399 39a 1
39e 2 39c 39e
2 3ad 3af 3
3ab 3ac 3b1 2
3ba 3bc 2 3be
3c0 2 3c2 3c4
1 3cc 2 3ce
3cf 2 3c6 3d1
2 3b9 3d3 1
3d5 1 3d7 2
3e1 3e3 3 3df
3e0 3e5 2 3ee
3f0 2 3ed 3f2
1 3f4 1 3f6
2 3fd 3fe 3
3d8 3f7 400 1
402 1 404 1
40b 2 40d 40e
1 412 2 410
412 2 421 423
3 41f 420 425
2 42e 430 2
432 434 2 436
438 1 440 2
442 443 2 43a
445 2 42d 447
1 449 1 44b
2 455 457 3
453 454 459 2
462 464 2 461
466 1 468 1
46a 2 471 472
3 44c 46b 474
1 476 2 479
47a 1 47e 2
47c 47e 2 482
483 1 487 2
485 487 2 48d
48e 1 492 2
490 492 2 49f
4a1 3 49d 49e
4a3 2 4ac 4ae
2 4b0 4b2 2
4b4 4b6 1 4be
2 4c0 4c1 2
4b8 4c3 2 4ab
4c5 1 4c7 1
4c9 2 4d3 4d5
3 4d1 4d2 4d7
2 4e0 4e2 2
4df 4e4 1 4e6
1 4e8 2 4ef
4f0 3 4ca 4e9
4f2 1 4f4 2
4f7 4f8 1 4fe
2 4fa 4fe 1
502 1 50a 2
51a 51f 2 530
532 3 52e 52f
534 2 53d 53f
2 541 543 2
545 547 2 549
54b 2 54d 54f
3 554 555 556
2 551 558 2
53c 55a 1 55c
1 55e 2 527
55f 1 563 1
522 1 567 1
572 2 56e 572
2 577 578 1
57c 2 57a 57c
2 58a 58c 3
588 589 58e 2
597 599 2 59b
59d 2 59f 5a1
1 5a9 2 5ab
5ac 2 5a3 5ae
2 596 5b0 1
5b2 1 5b4 2
5be 5c0 3 5bc
5bd 5c2 2 5cb
5cd 2 5ca 5cf
1 5d1 1 5d3
2 5da 5db 3
5b5 5d4 5dd 1
5df 3 56a 5e0
5e3 1 5e6 1
5ec 2 5f7 5fc
2 60d 60f 3
60b 60c 611 2
61a 61c 2 61e
620 2 622 624
2 626 628 2
62a 62c 3 631
632 633 2 62e
635 2 619 637
1 639 1 63b
2 604 63c 1
640 1 5ff 1
644 1 647 2
64b 64a 2 656
657 2 659 65c
2 65f 660 2
667 668 2 66a
66d 2 673 674
1 678 2 676
678 2 686 68b
2 69c 69e 3
69a 69b 6a0 2
6a9 6ab 2 6ad
6af 2 6b1 6b3
2 6b5 6b7 2
6b9 6bb 3 6c0
6c1 6c2 2 6bd
6c4 2 6a8 6c6
1 6c8 1 6ca
2 693 6cb 1
6cf 1 68e 1
6d3 1 6de 2
6da 6de 2 6e8
6ed 2 6fe 700
3 6fc 6fd 702
2 70b 70d 2
70f 711 2 713
715 2 717 719
2 71b 71d 3
722 723 724 2
71f 726 2 70a
728 1 72a 1
72c 2 6f5 72d
1 731 1 6f0
1 735 1 740
2 73c 740 2
74c 74e 3 74a
74b 750 2 759
75b 2 75d 75f
2 761 763 1
76b 2 76d 76e
2 765 770 2
772 774 2 776
778 2 77a 77c
2 77e 780 2
758 782 1 784
1 786 2 790
792 3 78e 78f
794 2 79d 79f
2 79c 7a1 1
7a3 1 7a5 3
7ac 7ad 7ae 3
787 7a6 7b0 1
7b2 2 738 7b3
1 7b5 2 7bf
7c4 2 7d5 7d7
3 7d3 7d4 7d9
2 7e2 7e4 2
7e6 7e8 2 7ea
7ec 2 7ee 7f0
2 7f2 7f4 3
7f9 7fa 7fb 2
7f6 7fd 2 7e1
7ff 1 801 1
803 2 7cc 804
1 808 1 7c7
1 80c 2 812
813 1 817 2
815 817 2 81f
824 2 835 837
3 833 834 839
2 842 844 2
846 848 2 84a
84c 2 84e 850
2 852 854 3
859 85a 85b 2
856 85d 2 841
85f 1 861 1
863 2 82c 864
1 868 1 827
1 86c 2 874
875 1 879 2
877 879 2 884
886 3 882 883
888 2 891 893
2 895 897 2
899 89b 1 8a3
2 8a5 8a6 2
89d 8a8 2 8aa
8ac 2 8ae 8b0
2 8b2 8b4 2
8b6 8b8 2 890
8ba 1 8bc 1
8be 2 8c8 8ca
3 8c6 8c7 8cc
2 8d5 8d7 2
8d4 8d9 1 8db
1 8dd 3 8e4
8e5 8e6 3 8bf
8de 8e8 1 8ea
2 86f 8eb 1
8ed 5 6d6 7b6
7b9 80f 8ee 1
8f0 2 8fd 8ff
3 8fb 8fc 901
2 90a 90c 2
90e 910 2 912
914 1 91c 2
91e 91f 2 916
921 2 909 923
1 925 1 927
2 931 933 3
92f 930 935 2
93e 940 2 93d
942 1 944 1
946 2 94d 94e
3 928 947 950
1 952 3 95a
95b 95c 3 95e
95f 960 4 968
969 96a 96b 2
971 972 1 974
1 978 2 976
978 2 993 998
2 9a9 9ab 3
9a7 9a8 9ad 2
9b6 9b8 2 9ba
9bc 2 9be 9c0
2 9c2 9c4 2
9c6 9c8 3 9cd
9ce 9cf 2 9ca
9d1 2 9b5 9d3
1 9d5 1 9d7
2 9a0 9d8 1
9dc 1 99b 1
9e0 1 9eb 2
9e7 9eb 2 9f7
9f9 3 9f5 9f6
9fb 2 a04 a06
2 a08 a0a 2
a0c a0e 1 a16
2 a18 a19 2
a10 a1b 2 a1d
a1f 2 a21 a23
2 a25 a27 2
a29 a2b 2 a03
a2d 1 a2f 1
a31 2 a3b a3d
3 a39 a3a a3f
2 a48 a4a 2
a47 a4c 1 a4e
1 a50 3 a57
a58 a59 3 a32
a51 a5b 1 a5d
2 9e3 a5e 2
a68 a6a 3 a66
a67 a6c 2 a75
a77 2 a79 a7b
2 a7d a7f 1
a87 2 a89 a8a
2 a81 a8c 2
a8e a90 2 a92
a94 2 a96 a98
2 a9a a9c 2
a74 a9e 1 aa0
1 aa2 2 aac
aae 3 aaa aab
ab0 2 ab9 abb
2 ab8 abd 1
abf 1 ac1 3
ac8 ac9 aca 3
aa3 ac2 acc 2
ace acf 5 953
956 963 96e ad0
2 ad2 ad3 2
ad6 ad7 1 adb
2 ad9 adb 2
ae0 ae1 1 ae5
2 ae3 ae5 1
aed 1 aef 1
af3 2 af1 af3
2 b01 b02 2
b06 b07 2 b0b
b0c 2 b10 b11
2 b15 b16 2
b1a b1b 2 b1f
b20 2 b24 b25
d afe aff b04
b09 b0e b13 b18
b1d b22 b27 b28
b29 b2a 2 b2f
b30 1 b36 2
b32 b36 2 b41
b43 3 b3f b40
b45 2 b4e b50
2 b52 b54 2
b56 b58 1 b60
2 b62 b63 2
b5a b65 2 b4d
b67 1 b69 1
b6b 2 b75 b77
3 b73 b74 b79
2 b82 b84 2
b81 b86 1 b88
1 b8a 2 b91
b92 3 b6c b8b
b94 2 b98 b99
1 b9d 2 b9b
b9d 2 ba8 baa
3 ba6 ba7 bac
2 bb5 bb7 2
bb9 bbb 2 bbd
bbf 1 bc5 2
bc7 bc8 2 bc1
bca 2 bcc bce
2 bd0 bd2 2
bd4 bd6 2 bd8
bda 2 bb4 bdc
1 bde 1 be0
2 bea bec 3
be8 be9 bee 2
bf7 bf9 2 bf6
bfb 1 bfd 1
bff 2 c05 c06
3 c08 c09 c0a
3 be1 c00 c0c
2 c0f c0e 4
af8 afb b2d c10
1 c12 2 c15
c16 1 c1a 2
c18 c1a 2 c1f
c20 1 c24 2
c22 c24 2 c2b
c2c 1 c30 2
c2e c30 2 c35
c36 1 c3a 2
c38 c3a 1 c42
2 c46 c47 1
c4b 2 c49 c4b
1 c50 2 c55
c56 1 c5a 2
c58 c5a 2 c5f
c60 1 c64 2
c62 c64 1 c6c
2 c71 c72 1
c76 2 c74 c76
2 c7b c7c 2
c81 c82 2 c7e
c84 2 c87 c8a
4 c8d c53 c6f
c8c 1 c8e 1
c90 2 c93 c94
1 c98 2 c96
c98 2 c9c c9d
1 ca1 2 c9f
ca1 2 cac cae
3 caa cab cb0
2 cb9 cbb 2
cbd cbf 2 cc1
cc3 1 ccb 2
ccd cce 2 cc5
cd0 2 cd2 cd4
2 cd6 cd8 2
cda cdc 2 cde
ce0 2 cb8 ce2
1 ce4 1 ce6
2 cf0 cf2 3
cee cef cf4 2
cfd cff 2 cfc
d01 1 d03 1
d05 3 d0c d0d
d0e 3 ce7 d06
d10 1 d12 2
d15 d16 1 d1a
2 d18 d1a 1
d1f 2 d24 d25
2 d27 d29 1
d2b 1 d2e 2
d30 d31 2 d13
d32 1 d34 3
d49 d4a d4b 3
d51 d52 d53 2
d58 d59 1 d5d
2 d5b d5d 3
d67 d68 d69 1
d6d 2 d6b d6d
2 d89 d8e 2
d9f da1 3 d9d
d9e da3 2 dac
dae 2 db0 db2
2 db4 db6 2
db8 dba 2 dbc
dbe 3 dc3 dc4
dc5 2 dc0 dc7
2 dab dc9 1
dcb 1 dcd 2
d96 dce 1 dd2
1 d91 1 dd6
2 de0 de5 2
df6 df8 3 df4
df5 dfa 2 e03
e05 2 e07 e09
2 e0b e0d 2
e0f e11 2 e13
e15 3 e1a e1b
e1c 2 e17 e1e
2 e02 e20 1
e22 1 e24 2
ded e25 1 e29
1 de8 1 e2d
1 e38 2 e34
e38 2 e44 e46
3 e42 e43 e48
2 e51 e53 2
e55 e57 2 e59
e5b 1 e63 2
e65 e66 2 e5d
e68 2 e6a e6c
2 e6e e70 2
e72 e74 2 e76
e78 2 e50 e7a
1 e7c 1 e7e
2 e88 e8a 3
e86 e87 e8c 2
e95 e97 2 e94
e99 1 e9b 1
e9d 3 ea4 ea5
ea6 3 e7f e9e
ea8 1 eaa 2
eb9 ebe 2 ecf
ed1 3 ecd ece
ed3 2 edc ede
2 ee0 ee2 2
ee4 ee6 2 ee8
eea 2 eec eee
3 ef3 ef4 ef5
2 ef0 ef7 2
edb ef9 1 efb
1 efd 2 ec6
efe 1 f02 1
ec1 1 f06 5
dd9 e30 eab eae
f09 3 f0e f0f
f10 1 f14 2
f12 f14 2 f1c
f21 2 f32 f34
3 f30 f31 f36
2 f3f f41 2
f43 f45 2 f47
f49 2 f4b f4d
2 f4f f51 3
f56 f57 f58 2
f53 f5a 2 f3e
f5c 1 f5e 1
f60 2 f29 f61
1 f65 1 f24
1 f69 1 f74
2 f70 f74 2
f80 f82 3 f7e
f7f f84 2 f8d
f8f 2 f91 f93
2 f95 f97 1
f9f 2 fa1 fa2
2 f99 fa4 2
fa6 fa8 2 faa
fac 2 fae fb0
2 fb2 fb4 2
f8c fb6 1 fb8
1 fba 2 fc4
fc6 3 fc2 fc3
fc8 2 fd1 fd3
2 fd0 fd5 1
fd7 1 fd9 3
fe0 fe1 fe2 3
fbb fda fe4 1
fe6 2 1004 1009
2 101a 101c 3
1018 1019 101e 2
1027 1029 2 102b
102d 2 102f 1031
2 1033 1035 2
1037 1039 3 103e
103f 1040 2 103b
1042 2 1026 1044
1 1046 1 1048
2 1011 1049 1
104d 1 100c 1
1051 1 105c 2
1058 105c 2 1079
107e 2 108f 1091
3 108d 108e 1093
2 109c 109e 2
10a0 10a2 2 10a4
10a6 2 10a8 10aa
2 10ac 10ae 3
10b3 10b4 10b5 2
10b0 10b7 2 109b
10b9 1 10bb 1
10bd 2 1086 10be
1 10c2 1 1081
1 10c6 1 10c9
1 10cc 2 10d8
10dd 2 10ee 10f0
3 10ec 10ed 10f2
2 10fb 10fd 2
10ff 1101 2 1103
1105 2 1107 1109
2 110b 110d 3
1112 1113 1114 2
110f 1116 2 10fa
1118 1 111a 1
111c 2 10e5 111d
1 1121 1 10e0
1 1125 6 f6c
fe7 fea 1054 10cd
1128 2 1134 1136
3 1132 1133 1138
2 1141 1143 2
1145 1147 2 1149
114b 1 1153 2
1155 1156 2 114d
1158 2 1140 115a
1 115c 1 115e
2 1168 116a 3
1166 1167 116c 2
1175 1177 2 1174
1179 1 117b 1
117d 2 1184 1185
3 115f 117e 1187
3 1189 112b 118a
1 1192 2 118e
1192 2 119a 119b
4 1198 119d 11a0
11a1 2 11a9 11aa
4 11a7 11ac 11af
11b0 1 11dc 2
11db 11dc 1 11e4
1 11ea 2 11ec
11ed 2 11d9 11ee
2 11ff 1201 3
11fd 11fe 1203 2
120c 120e 2 1210
1212 2 1214 1216
2 1218 121a 2
121c 121e 3 1223
1224 1225 2 1220
1227 2 120b 1229
1 122b 1 122d
2 11f6 122e 1
1232 1 11f1 1
1236 1 123d 4
11a4 11b3 1239 1240
2 124b 124c 4
1249 124e 1251 1252
7 1260 1261 1262
1263 1264 1265 1266
1 1285 2 1284
1285 1 128d 1
1293 2 1295 1296
2 1282 1297 2
12a8 12aa 3 12a6
12a7 12ac 2 12b5
12b7 2 12b9 12bb
2 12bd 12bf 2
12c1 12c3 2 12c5
12c7 3 12cc 12cd
12ce 2 12c9 12d0
2 12b4 12d2 1
12d4 1 12d6 2
129f 12d7 1 12db
1 129a 1 12df
6 1246 1255 125a
125d 1269 12e2 2
12e5 12e6 2 12e9
12ea 1 12ee 2
12ec 12ee 1 12f2
2 12ff 1304 2
1315 1317 3 1313
1314 1319 2 1322
1324 2 1326 1328
2 132a 132c 2
132e 1330 2 1332
1334 3 1339 133a
133b 2 1336 133d
2 1321 133f 1
1341 1 1343 2
130c 1344 1 1348
1 1307 1 134c
3 1352 1353 1354
1 1358 2 1356
1358 1 135d a
1365 1366 1367 1368
1369 136a 136b 136c
136d 136e 2 1360
1371 1 1373 2
134f 1374 1 1376
3 137c 137d 137e
1 1382 2 1380
1382 1 1389 2
138d 138e 1 1391
2 1393 1394 20
1398 1399 139a 139b
139c 139d 139e 139f
13a0 13a1 13a2 13a3
13a4 13a5 13a6 13a7
13a8 13a9 13aa 13ab
13ac 13ad 13ae 13af
13b0 13b1 13b2 13b3
13b4 13b5 13b6 13b7
1 13bd 2 13bb
13bd 1 13c7 2
13c6 13c7 1 13cf
1 13d5 2 13d7
13d8 2 13c4 13d9
2 13ea 13ec 3
13e8 13e9 13ee 2
13f7 13f9 2 13fb
13fd 2 13ff 1401
2 1403 1405 2
1407 1409 3 140e
140f 1410 2 140b
1412 2 13f6 1414
1 1416 1 1418
2 13e1 1419 1
141d 1 13dc 1
1421 1 1424 1
1427 9 d62 d65
118b 12e7 1377 137a
1395 13ba 1428 1
1435 2 1437 1438
1 143c 2 143a
143c 1 1441 1
1447 2 1449 144a
2 144c 144e 2
1451 1453 1 1455
1 1458 2 145a
145b 1 145f 2
145d 145f 2 1467
1468 1 146b 2
146a 146b 2 1478
1479 2 147b 147d
2 147f 1481 4
1475 1476 1483 1484
2 148f 1490 2
1492 1494 2 1496
1498 2 149a 149c
4 148c 148d 149e
149f 3 14a4 14a5
14a6 1 14aa 2
14a8 14aa 1 14b4
2 14b6 14b7 1
14bb 2 14b9 14bb
1 14c0 2 14c4
14c6 3 14c8 14c9
14ca 2 14d0 14d2
3 14d4 14d5 14d6
2 14cd 14d9 2
14db 14dc 2 14b1
14dd 2 14e1 14e2
1 14e8 2 14ea
14eb 1 14ef 2
14ed 14ef 1 14f4
2 14f8 14fa 3
14fc 14fd 14fe 2
1504 1506 3 1508
1509 150a 2 1501
150d 2 150f 1510
2 14e5 1511 2
1513 1514 3 1517
1518 1519 1 151d
2 151b 151d 2
1533 1538 2 1549
154b 3 1547 1548
154d 2 1556 1558
2 155a 155c 2
155e 1560 2 1562
1564 2 1566 1568
3 156d 156e 156f
2 156a 1571 2
1555 1573 1 1575
1 1577 2 1540
1578 1 157c 1
153b 1 1580 3
1583 1587 158a 2
15a0 15a5 2 15b6
15b8 3 15b4 15b5
15ba 2 15c3 15c5
2 15c7 15c9 2
15cb 15cd 2 15cf
15d1 2 15d3 15d5
3 15da 15db 15dc
2 15d7 15de 2
15c2 15e0 1 15e2
1 15e4 2 15ad
15e5 1 15e9 1
15a8 1 15ed 1
15f8 2 15f4 15f8
2 1610 1615 2
1626 1628 3 1624
1625 162a 2 1633
1635 2 1637 1639
2 163b 163d 2
163f 1641 2 1643
1645 3 164a 164b
164c 2 1647 164e
2 1632 1650 1
1652 1 1654 2
161d 1655 1 1659
1 1618 1 165d
1 1660 1 1663
2 15f0 1664 2
1666 1667 3 166d
166e 166f 1 1673
2 1671 1673 1
167a 2 167e 167f
1 1682 2 1684
1685 20 168c 168d
168e 168f 1690 1691
1692 1693 1694 1695
1696 1697 1698 1699
169a 169b 169c 169d
169e 169f 16a0 16a1
16a2 16a3 16a4 16a5
16a6 16a7 16a8 16a9
16aa 16ab 1 16b1
2 16af 16b1 1
16bb 2 16ba 16bb
1 16c3 1 16c9
2 16cb 16cc 2
16b8 16cd 2 16de
16e0 3 16dc 16dd
16e2 2 16eb 16ed
2 16ef 16f1 2
16f3 16f5 2 16f7
16f9 2 16fb 16fd
3 1702 1703 1704
2 16ff 1706 2
16ea 1708 1 170a
1 170c 2 16d5
170d 1 1711 1
16d0 1 1715 1
1718 1 171b 2
171f 1720 2 1722
1724 a 1487 14a2
1515 1668 166b 1686
1689 16ae 171c 1727
2 1464 172a 1
172c 5 142c 142f
1432 145c 172d 2
172f 1730 1 1734
2 1732 1734 2
1739 173a 1 173e
2 173c 173e 2
174c 174e 3 174a
174b 1750 2 1759
175b 2 175d 175f
2 1761 1763 1
176b 2 176d 176e
2 1765 1770 2
1772 1774 2 1776
1778 2 177a 177c
2 177e 1780 2
1758 1782 1 1784
1 1786 2 1790
1792 3 178e 178f
1794 2 179d 179f
2 179c 17a1 1
17a3 1 17a5 3
17ac 17ad 17ae 3
1787 17a6 17b0 1
17b2 2 17b5 17b6
1 17ba 2 17b8
17ba 1 17bf 1
17c1 1 17c5 2
17c7 17c8 1 17cc
2 17ca 17cc 1
17d2 2 17d4 17d5
1 17d9 2 17d7
17d9 2 17e0 17e2
2 17e4 17e6 2
17e8 17ea 2 17ec
17ee 2 17f4 17f5
1 17f7 2 17f0
17f9 2 17fb 17fd
2 1803 1804 1
1806 2 17ff 1808
2 180a 180c 2
1812 1813 1 1815
2 180e 1817 2
1819 181b 2 181d
181f 2 1821 1823
2 1825 1827 2
1829 182b 2 182d
182f 2 1831 1833
2 1835 1837 2
1839 183b 2 183d
183f 2 1841 1843
2 1845 1847 2
1849 184b 2 184d
1851 2 1853 1855
2 1857 185b 2
185d 185f 2 1861
1863 2 1865 1867
2 186d 186e 1
1870 2 1869 1872
2 1874 1876 2
187c 187d 1 187f
2 1878 1881 2
1883 1885 2 1887
1889 2 188f 1890
1 1892 2 188b
1894 2 1896 1898
2 189a 189c 2
189e 18a0 2 18a2
18a4 2 18a6 18a8
2 18aa 18ac 2
18ae 18b0 2 18b2
18b4 1 18b7 1
18bc 2 18be 18bf
1 18c3 2 18c1
18c3 2 18c7 18c9
2 18cb 18cd 2
18cf 18d1 2 18d3
18d5 2 18db 18dc
1 18de 2 18d7
18e0 2 18e2 18e4
2 18ea 18eb 1
18ed 2 18e6 18ef
2 18f1 18f3 2
18f9 18fa 1 18fc
2 18f5 18fe 2
1900 1902 2 1904
1906 2 1908 190a
2 190c 190e 2
1910 1912 2 1914
1916 2 1918 191a
2 191c 191e 2
1920 1922 2 1924
1926 2 1928 192a
1 192d 1 1933
2 1935 1936 1
193a 2 1938 193a
2 193e 1940 2
1942 1946 2 1948
194a 2 194c 1950
2 1952 1954 2
1956 1958 2 195a
195c 2 1962 1963
1 1965 2 195e
1967 2 1969 196b
2 1971 1972 1
1974 2 196d 1976
2 1978 197a 2
197c 197e 2 1984
1985 1 1987 2
1980 1989 2 198b
198d 2 198f 1991
2 1993 1995 2
1997 1999 2 199b
199d 2 199f 19a1
2 19a3 19a5 2
19a7 19a9 1 19ac
3 19af 1930 19ae
2 19b9 19bb 3
19b7 19b8 19bd 2
19c6 19c8 2 19c5
19ca 1 19cc 1
19ce 2 19d8 19da
3 19d6 19d7 19dc
2 19e5 19e7 2
19e4 19e9 1 19eb
1 19ed 1 19f3
2f 2cf 2ee 2f1
2f4 2f7 2fa 2fd
300 303 306 309
30c 30f 312 315
318 31b 325 328
32b 38f 403 477
4f5 64c 64f 663
671 ad4 af0 c13
c91 d35 d3a d3d
d40 d43 d46 d4e
d56 1731 17b3 17c2
19b0 19cf 19ee 19f6
2 1a03 1a05 3
1a01 1a02 1a07 2
1a10 1a12 2 1a0f
1a14 2 1a1b 1a1f
2 1a21 1a23 2
1a25 1a29 2 1a1a
1a2b 2 1a16 1a2d
1 1a2f 3 1a30
1a3b 1a3f 1 19fa
2 1a52 1a54 3
1a50 1a51 1a56 2
1a5f 1a61 2 1a5e
1a63 2 1a6a 1a6c
2 1a6e 1a70 3
1a75 1a76 1a77 2
1a72 1a79 2 1a69
1a7b 2 1a65 1a7d
1 1a7f 4 1a49
1a80 1a89 1a8d 1
1a91 1 1a44 2
1a42 1a95 3e 4b
52 59 60 67
6e 75 7a 81
88 8f 96 9d
a4 ab b2 b7
bc c3 c9 cf
d5 db e1 e7
ed f3 f9 ff
105 10b 111 117
11d 123 129 12f
135 13b 141 147
14d 153 159 15f
165 16b 171 177
17e 185 18b 191
198 19e 1a4 1aa
1b0 1b6 1bc 1c1
1c8 
1
4
0 
1a9c
0
1
50
2f
4e
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 27
26 29 26 2b 26 2d 1 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3b 1 0
13d 1 0
2b 1 0
173 1 0
1b2 1 0
149 1 0
2f 1 0
1a0 1 0
a6 1 0
107 1 0
e3 1 0
1ac 1 0
8a 1 0
27 1 0
161 1 0
179 1 0
98 1 0
1f 1 0
1b 1 0
1b8 1 0
83 1 0
c5 1 0
16d 1 0
91 1 0
d7 1 0
193 1 0
77 1 0
1be 1 0
18d 1 0
13 1 0
101 1 0
f5 1 0
69 1 0
7c 1 0
131 1 0
9f 1 0
62 1 0
f 1 0
ef 1 0
155 1 0
3 1 0
cb 1 0
b9 1 0
70 1 0
187 1 0
137 1 0
15b 1 0
11f 1 0
113 1 0
23 1 0
2 0 1
4d 1 0
1a6 1 0
7 1 0
14f 1 0
fb 1 0
e9 1 0
143 1 0
dd 1 0
19a 1 0
d1 1 0
5b 1 0
46 1 0
119 1 0
37 1 0
ad 1 0
125 1 0
17 1 0
167 1 0
b4 1 0
be 1 0
12b 1 0
54 1 0
33 1 0
10d 1 0
b 1 0
1c3 1 0
180 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_3;
ALTER FUNCTION SP_SEARCH_3 COMPILE DEBUG;
/*
#Stored Procedure  :SP_I_PROFILE
#Short Description :Assign a profile to a task or project
#Description       :used tables: RESOURCE_ASSIGNMENTS, PROFILES
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_I_PROFILE ==
CREATE OR REPLACE FUNCTION SP_I_PROFILE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
9a
2 :e:
1FUNCTION:
1SP_I_PROFILE:
1PRJ_ID:
1VARCHAR2:
1AND_ROLES:
1AND_SKILLS:
1ORG_ID001:
1GEO_ID001:
1POOL_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_UNIQUEID:
132:
1H_AND_ROLES:
18000:
1H_ROLE_ID:
1H_FULL_NAME:
1255:
1H_COUNT:
1PLS_INTEGER:
10:
1H_NUMBER:
1NUMITEMS:
1NUMITEMS001:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_I_PROFILE(:
1':
1, :
1);:
1CHECK_TRACE:
11:
134:
1+:
1FPUT:
1               ENTER:: SP_I_PROFILE(35) :: cplan.sql(5386) :: :
1IS NULL:
18:
141:
1      RETURN_INVALID:: SP_I_PROFILE(42) :: cplan.sql(5393) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
144:
1                EXIT:: SP_I_PROFILE(45) :: cplan.sql(5396) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SUBSTR:
1MAX:
1PROF_NUMBER:
1PROFILES:
1PROJECT_ID:
1ROLE_ID:
1SELECT COALESCE(MAX(PROF_NUMBER),0)+1 INTO h_number:n      FROM PROFILES:n   +
1   WHERE PROJECT_ID=prj_id/**prj_id*/ AND ROLE_ID=h_role_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
165:
1           EXCEPTION:: SP_I_PROFILE(66) :: cplan.sql(5417) :: :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1PMO_ORASTD:
1STRINGCONCAT:
1RTRIM:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1ELEMENT_ID:
1PARENT_ID:
1SELECT PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConca+
1t(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEMENT_NAME), ',+
1 '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(h_number))), ')'):n      IN+
1TO h_full_name FROM TMT_COMPETENCIES TC, TMT_COMPETENCIES TCP:n      WHERE TC+
1.ELEMENT_ID = h_role_id AND TCP.ELEMENT_ID = TC.PARENT_ID:
180:
1           EXCEPTION:: SP_I_PROFILE(81) :: cplan.sql(5432) :: :
1=:
1SC_SQL_NO_DATA:
188:
1        RETURN_ERROR:: SP_I_PROFILE(89) :: cplan.sql(5440) :: :
1RECORD_NOT_FOUND:
1 ID:: :
191:
1                EXIT:: SP_I_PROFILE(92) :: cplan.sql(5443) :: :
1PMO_RETURN_ERROR_SP:
1SYS_GUID:
1PROFILE_ID:
1PROFILE_NAME:
1POOL_ID:
1GEO_ID:
1ORG_ID:
1INSERT INTO PROFILES(PROFILE_ID,PROJECT_ID,ROLE_ID,PROF_NUMBER, PROFILE_NAME,+
1 POOL_ID, GEO_ID, ORG_ID):n      VALUES(h_uniqueID, prj_id, h_role_id, h_numb+
1er, h_full_name, pool_id001, geo_id001, org_id001):
1FOUND:
1100:
1112:
1           EXCEPTION:: SP_I_PROFILE(113) :: cplan.sql(5464) :: :
1SC_SQL_SUCCESS:
1TRUNC:
1LENGTH:
1/:
1>:
1WHILE:
1<:
1LOOP:
1PMO_STPU:
1STRNPCPY:
1*:
1RESOURCE_ASSIGN_ROLES:
1PROFICIENCY_LEVEL_ID:
1PREFERENCE_LEVEL_ID:
1EXPERIENCE_ID:
1LAST_USED_DATETIME:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n               SELECT h_uniqueID, ELEMENT_+
1ID, PROFICIENCY_LEVEL_ID, PREFERENCE_LEVEL_ID,:n               EXPERIENCE_ID,+
1 LAST_USED_DATETIME, TO_CHAR(h_count):n               FROM TMT_COMPETENCIES W+
1HERE ELEMENT_ID = h_role_id:
1143:
1           EXCEPTION:: SP_I_PROFILE(144) :: cplan.sql(5495) :: :
1IS NOT NULL:
1RESOURCE_ASSIGN_SKILLS:
1INSERT INTO RESOURCE_ASSIGN_SKILLS:n                  SELECT h_uniqueID, h_ro+
1le_id, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID,:n                  PREFERENCE_LEV+
1EL_ID, LAST_USED_DATETIME, TO_CHAR(h_count):n                  FROM TMT_COMPE+
1TENCIES WHERE ELEMENT_ID = h_role_id:
1180:
1           EXCEPTION:: SP_I_PROFILE(181) :: cplan.sql(5532) :: :
14:
1192:
1       RETURN_STATUS:: SP_I_PROFILE(193) :: cplan.sql(5544) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1199:
1           EXCEPTION:: SP_I_PROFILE(200) :: cplan.sql(5551) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1211:
1           EXCEPTION:: SP_I_PROFILE(212) :: cplan.sql(5563) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
5d6
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c a0 7e b4 2e :2 5a
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :2 a0 d :4 a0 :2 51 a5 b :2 51
a5 b d :9 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :1f a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :2 a0 b4 2e d
:11 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :5 a0 a5 b 51 a5 b
7e 51 b4 2e 5a 7e 51 b4
2e a5 b d a0 7e 51 b4
2e a0 51 d :3 a0 51 a5 b
a0 7e a0 b4 2e 82 :3 a0 6b
:2 51 :2 a0 51 a5 b 7e 51 b4
2e 7e 51 b4 2e a0 a5 b
d :c a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b 7e 51
b4 2e d b7 a0 47 b7 19
3c a0 7e b4 2e 5a :2 a0 d
:5 a0 a5 b 51 a5 b 7e 51
b4 2e 5a 7e 51 b4 2e a5
b d a0 7e 51 b4 2e a0
51 d :3 a0 51 a5 b a0 7e
a0 b4 2e 82 :3 a0 6b :2 51 :2 a0
51 a5 b 7e 51 b4 2e 7e
51 b4 2e a0 a5 b d :c a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 51 a5 b 7e 51 b4 2e
d b7 a0 47 b7 19 3c b7
19 3c b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
5d6
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d 7c
a2 a6 aa ae b1 b5 d2 bd
c1 c4 c5 cd bc ef dd b9
e1 e2 ea dc 10c fa d9 fe
ff 107 f9 129 117 f6 11b 11c
124 116 145 134 138 113 140 133
161 150 154 130 15c 14f 17d 16c
170 178 14c 195 184 188 190 16b
1b5 1a0 1a4 168 1a8 1b0 19f 1bc
1c0 19c 1c4 1c8 1cc 1cf 1d4 1d5
1 1d7 1dc 1e0 1e4 1e7 1ec 1f0
1f4 1f7 1fc 1fd 1ff 204 207 20b
20c 211 216 219 21e 21f 224 227
22b 22c 231 234 239 23a 23f 242
247 248 24d 250 255 256 25b 25e
262 263 268 26b 270 271 276 279
27e 27f 284 287 28c 28d 292 295
299 29a 29f 2a2 2a7 2a8 2ad 2b0
2b5 2b6 2bb 2be 2c3 2c4 2c9 2cc
2d0 2d1 2d6 2d9 2de 2df 2e4 2e7
2ec 2ed 2f2 2f5 2fa 2fb 300 303
307 308 30d 310 315 316 31b 31e
323 324 329 32c 331 332 337 33a
33e 33f 344 347 34c 34d 352 355
35a 35b 360 363 368 369 36e 371
375 376 37b 37e 383 384 389 38c
391 392 397 398 39d 39f 3a3 3a6
3aa 3ae 3b1 3b5 3b9 3bc 3bf 3c4
3c7 3ca 3cd 3ce 3d3 3d4 1 3d6
3db 3df 3e3 3e6 3eb 3f0 3f3 3f7
3f8 3fd 3fe 403 405 409 40c 410
413 414 419 41c 41f 423 426 427
42c 42f 1 432 437 43b 43f 442
446 44a 44d 450 455 458 45b 45e
45f 464 465 1 467 46c 470 474
477 47c 481 484 488 489 48e 491
496 497 49c 49f 4a4 4a5 4aa 4ad
4b1 4b5 4b9 4bd 4c0 4c1 4c3 4c8
4c9 4cb 4cc 4d1 4d2 4d7 4d9 4dd
4e0 4e4 4e8 4eb 4ef 4f3 4f6 4f9
4fe 501 504 507 508 50d 50e 1
510 515 519 51d 520 525 52a 52d
531 532 537 538 53d 53f 543 546
54a 54e 551 555 559 55c 560 561
566 568 56c 56f 573 577 57b 57f
583 587 58b 58e 591 592 594 597
59a 59b 59d 5a1 5a5 5a9 5ad 5b1
5b5 5b9 5bd 5c1 5c5 5d1 5d5 5d9
5dc 5e0 5e4 5e6 1 5ea 5ee 5f2
5f5 5f9 5fd 601 605 608 60c 610
613 616 61b 61e 621 624 625 62a
62b 1 62d 632 636 63a 63d 642
647 64a 64e 64f 654 657 65c 65d
662 665 66a 66b 670 673 677 678
67d 680 685 686 68b 68e 692 696
699 69c 69d 69f 6a0 6a5 6a6 6ab
6ad 6b1 6b4 6b6 6ba 6bc 6c8 6ca
6cc 6cd 6d2 6d6 6d8 6e4 6e6 6ea
6ee 6f2 6f6 6fa 6fe 702 706 70a
70e 712 716 71a 71e 722 726 72a
72e 732 736 73a 73e 742 746 74a
74e 752 756 75a 75e 762 76e 772
776 779 77d 781 783 1 787 78b
78f 792 796 79a 79e 7a2 7a5 7a9
7ad 7b0 7b3 7b8 7bb 7be 7c1 7c2
7c7 7c8 1 7ca 7cf 7d3 7d7 7da
7df 7e4 7e7 7eb 7ec 7f1 7f4 7f9
7fa 7ff 802 807 808 80d 810 814
815 81a 81d 822 823 828 82b 82f
833 836 839 83a 83c 83d 842 843
848 84a 84e 851 853 857 859 865
867 869 86a 86f 873 875 881 883
887 88b 88e 892 895 899 89c 89d
8a2 8a5 8a9 8ad 8b0 8b4 8b8 8bb
8be 8c3 8c6 8c9 8cc 8cd 8d2 8d3
1 8d5 8da 8de 8e2 8e5 8ea 8ef
8f2 8f6 8f7 8fc 8ff 904 905 90a
90d 912 913 918 91b 91f 923 927
92b 92e 92f 931 936 937 939 93a
93f 942 947 948 94d 950 955 956
95b 95e 962 963 968 96b 970 971
976 977 97c 97e 982 985 989 98d
990 994 998 99b 99e 9a3 9a6 9a9
9ac 9ad 9b2 9b3 1 9b5 9ba 9be
9c2 9c5 9ca 9cf 9d2 9d6 9d7 9dc
9dd 9e2 9e4 9e8 9eb 9ef 9f3 9f6
9fa 9fe a01 a05 a09 a0a a0f a11
a15 a18 a1c a20 a21 a26 a2a a2e
a32 a36 a3a a3e a42 a46 a4a a4e
a52 a56 a5a a5e a62 a66 a6a a6e
a7a a7e a83 a87 a8a a8b a90 a94
a98 a9b a9e aa2 aa4 aa8 aac aaf
ab2 ab6 ab8 abc ac0 ac3 ac5 1
ac9 acd ad1 ad4 ad8 adc ae0 ae4
ae7 aeb aef af2 af5 afa afd b00
b03 b04 b09 b0a 1 b0c b11 b15
b19 b1c b21 b26 b29 b2d b2e b33
b36 b3b b3c b41 b44 b49 b4a b4f
b52 b56 b57 b5c b5f b64 b65 b6a
b6d b71 b75 b78 b7b b7c b7e b7f
b84 b85 b8a b8c b90 b93 b95 b99
b9b ba7 ba9 bab bac bb1 bb5 bb7
bc3 bc5 bc9 bcd bd0 bd4 bd7 bdb
bde bdf be4 be7 beb bef bf3 bf7
bfb bfc bfe c01 c02 c04 c07 c0a
c0b c10 c13 c16 c19 c1a c1f c20
c22 c26 c2a c2d c30 c31 c36 c3a
c3d c41 c45 c49 c4d c50 c51 c53
c57 c5a c5e c5f c64 c66 c6a c6e
c72 c75 c78 c7b c7f c83 c86 c87
c89 c8c c8f c90 c95 c98 c9b c9c
ca1 ca5 ca6 ca8 cac cb0 cb4 cb8
cbc cc0 cc4 cc8 ccc cd0 cd4 cd8
cdc ce8 cec cf1 cf5 cf8 cf9 cfe
d02 d06 d09 d0c d10 d12 d16 d1a
d1d d20 d24 d26 d2a d2e d31 d33
1 d37 d3b d3f d42 d46 d4a d4e
d52 d55 d59 d5d d60 d63 d68 d6b
d6e d71 d72 d77 d78 1 d7a d7f
d83 d87 d8a d8f d94 d97 d9b d9c
da1 da4 da9 daa daf db2 db7 db8
dbd dc0 dc4 dc5 dca dcd dd2 dd3
dd8 ddb ddf de3 de6 de9 dea dec
ded df2 df3 df8 dfa dfe e01 e03
e07 e09 e15 e17 e19 e1a e1f e23
e25 e31 e33 e37 e3b e3f e42 e43
e45 e48 e4b e4c e51 e55 e57 e5b
e62 e64 e68 e6b e6f e72 e73 e78
e7b e7f e83 e87 e8b e8f e93 e97
e9b e9c e9e ea1 ea2 ea4 ea7 eaa
eab eb0 eb3 eb6 eb9 eba ebf ec0
ec2 ec6 eca ecd ed0 ed1 ed6 eda
edd ee1 ee5 ee9 eed ef0 ef1 ef3
ef7 efa efe eff f04 f06 f0a f0e
f12 f15 f18 f1b f1f f23 f26 f27
f29 f2c f2f f30 f35 f38 f3b f3c
f41 f45 f46 f48 f4c f50 f54 f58
f5c f60 f64 f68 f6c f70 f74 f78
f7c f88 f8c f91 f95 f98 f99 f9e
fa2 fa6 fa9 fac fb0 fb2 fb6 fba
fbd fc0 fc4 fc6 fca fce fd1 fd3
1 fd7 fdb fdf fe2 fe6 fea fee
ff2 ff5 ff9 ffd 1000 1003 1008 100b
100e 1011 1012 1017 1018 1 101a 101f
1023 1027 102a 102f 1034 1037 103b 103c
1041 1044 1049 104a 104f 1052 1057 1058
105d 1060 1064 1065 106a 106d 1072 1073
1078 107b 107f 1083 1086 1089 108a 108c
108d 1092 1093 1098 109a 109e 10a1 10a3
10a7 10a9 10b5 10b7 10b9 10ba 10bf 10c3
10c5 10d1 10d3 10d7 10db 10df 10e2 10e3
10e5 10e8 10eb 10ec 10f1 10f5 10f7 10fb
1102 1104 1108 110b 110d 1111 1114 1116
111a 111d 1121 1125 1128 112c 1130 1133
1136 113b 113e 1141 1144 1145 114a 114b
1 114d 1152 1156 115a 115d 1162 1167
116a 116e 116f 1174 1177 117c 117d 1182
1185 118a 118b 1190 1193 1197 119b 119f
11a3 11a6 11a7 11a9 11ae 11af 11b1 11b2
11b7 11ba 11bf 11c0 11c5 11c8 11cd 11ce
11d3 11d6 11da 11db 11e0 11e3 11e8 11e9
11ee 11ef 11f4 11f6 11fa 11fd 1201 1205
1208 120c 1210 1213 1217 121b 121c 1221
1223 1227 122b 122e 1232 1236 1239 123d
1241 1244 1247 124c 124f 1252 1255 1256
125b 125c 1 125e 1263 1267 126b 126e
1273 1278 127b 127f 1280 1285 1286 128b
128f 1293 1296 129b 12a0 12a3 12a7 12ab
12ae 12af 12b4 12b7 12bc 12bd 12c2 12c5
12c9 12cd 12d0 12d1 12d6 12d7 12dc 12de
12e2 12e5 12e9 12ed 12f1 12f5 12f9 12fd
1301 1305 1309 1315 131a 131e 1322 1326
132a 132c 132d 1332 1 1336 133a 133e
1341 1345 1349 134d 1351 1354 1358 135c
135f 1362 1367 136a 136d 1370 1371 1376
1377 1 1379 137e 1382 1386 1389 138e
1393 1396 139a 139b 13a0 13a1 13a6 13aa
13ae 13b1 13b6 13bb 13be 13c2 13c3 13c8
13cb 13d0 13d1 13d6 13d9 13dd 13e1 13e4
13e7 13e8 13ea 13eb 13f0 13f1 13f6 13f8
13fc 13ff 1403 1407 140b 140f 1413 1417
141b 1427 142c 1430 1434 1438 143c 143e
1442 1444 1450 1452 1454 1455 145a 145e
1460 146c 1470 1472 1473 147c 
5d6
2
0 1 a 6 d :3 6 10 :3 6
11 :3 6 10 :3 6 10 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 e 17 16 :2 e :2 4
10 19 18 :2 10 :2 4 :2 c 1b c
:2 4 :2 d 1c d :2 4 :3 d :2 4 :3 10
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 54 5a 5d :2 54 6b 81
8 :2 6b d 10 :2 6b 17 1a :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 28 2b :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 29 2c :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 28 2b :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 28 2b :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 29 2c :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 2a 2d :2 6b
32 35 :2 6b :2 7 4a :2 4 7 :2 11
23 :2 2d 39 3c 4c 4e 4f :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:2 7 52 :2 4 :4 9 8 7 :4 1f 1e
1d :2 7 a :2 14 26 :2 30 3c 3f
4f 51 52 :2 4f :2 26 :3 a :2 10 15
21 5f 62 :2 21 6f 72 :2 21 76
79 :2 21 83 86 8f 97 :2 a0 :2 8f
b1 :2 86 :2 21 :2 a 55 :2 7 a :2 14
26 :2 30 3c 3f 4f 51 52 :2 4f
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:2 a 55 :3 7 :2 12 28 :2 31 41 :2 7
33 :3 4 13 :2 4 11 18 1f 2c
2f :2 18 34 37 :2 11 4 e 17
1b 32 c d 18 2e 36 :2 7
:2 10 1c 7 4 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 53
55 56 :2 53 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 88 8b :2 24 93 96 :2 24 a2
a5 ac b5 b8 :2 a5 :2 24 :2 d 59
:2 a :2 7 :4 13 :2 7 4 :3 1 e 19
26 31 3e 49 56 61 6e 79
86 8c 90 a6 ac af c5 cb
d3 c 1d 2e 32 43 d 10
1d 2b 2f 3c 3f :2 7 :2 10 1c
7 4 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 53 55 56
:2 53 :2 29 :3 d :2 13 18 24 62 65
:2 24 72 75 :2 24 79 7c :2 24 88
8b :2 24 93 96 :2 24 a2 a5 ac
b5 b8 :2 a5 :2 24 :2 d 59 :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1c 1a
:2 25 :2 1a 7 a :2 14 26 :2 30 3c
40 50 52 53 :2 50 :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b3 :2 86 :2 21 bb be :2 21 c6
c9 :2 21 ce d1 :2 21 db de :2 21
:2 a 56 :2 7 a :2 14 26 :2 30 3c
3f 4f 51 52 :2 4f :2 26 :3 a :2 10
15 21 5f 62 :2 21 :2 a 55 :3 7
:2 12 26 :2 2f 41 4c :2 7 35 :3 4
:3 12 4 13 1c 27 32 3a 47
55 5e 66 e 1a 22 2d 37
44 50 5b 7 e a 16 :3 14
a :2 13 1f a 1b a :2 13 1f
a :4 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 53 56
57 :2 53 :2 29 :3 d :2 13 18 24 63
66 :2 24 73 76 :2 24 7a 7d :2 24
89 8c :2 24 94 97 :2 24 a3 a6
ad b6 b9 :2 a6 :2 24 :2 d 5a :2 a
:2 7 :4 13 :2 7 4 :3 1 8 :2 11 1c
1a :2 25 :2 1a :2 7 13 1a 23 2a
:2 23 38 :2 1a 3b 3d :2 1a 19 40
42 :2 19 :2 13 7 a 13 15 :2 13
a 15 :2 a 10 19 22 :2 10 27
25 30 :2 25 a d 1a :2 23 2c
30 34 3d 46 :2 34 49 4b :2 34
4d 4e :2 34 51 :2 1a d 1c 17
23 2f 45 10 1f 33 3b 15
2c 39 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5c 5f 60
:2 5c :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :3 30 d 18 21 2a
:2 18 2d 2f :2 18 d 30 e a
17 :2 7 :4 b :2 a 19 :2 a 19 20
29 30 :2 29 3e :2 20 41 43 :2 20
1f 46 48 :2 1f :2 19 a d 19
1b :2 19 d 18 :2 d 13 1c 25
:2 13 2a 28 36 :2 28 d 10 1d
:2 26 2f 33 37 40 49 :2 37 4c
4e :2 37 50 51 :2 37 54 :2 1d 10
1f 1a 26 31 47 13 28 3c
44 18 2f 3c 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 5f
62 63 :2 5f :2 35 :3 19 :2 1f 24 30
6f 72 :2 30 7f 82 :2 30 86 89
:2 30 95 98 :2 30 a0 a3 :2 30 af
b2 b9 c2 c5 :2 b2 :2 30 :2 19 66
:2 16 :2 13 :4 1f :2 13 10 :3 36 10 1b
24 2d :2 1b 30 32 :2 1b 10 36
11 d 1d :2 a 23 :2 7 35 :2 4
7 :2 11 23 :2 2d 39 3c 4c 4f
50 :2 4c :2 23 :3 7 :2 d 12 1e 5d
60 :2 1e 6d 70 :2 1e 74 77 :2 1e
81 84 8d 95 :2 9e :2 8d a9 :2 84
:2 1e b1 b4 :2 1e bc bf :2 1e c4
c7 :2 1e d2 d5 :2 1e :2 7 53 :3 4
:2 f 21 :2 2a 34 40 :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
50 53 54 :2 50 :2 26 :3 a :2 10 15
21 60 63 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 57 :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4d 50 51 :2 4d :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 54 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
5d6
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 2 :4 a :2 1
:7 c :7 d :7 e :7 f
:6 10 :6 11 :5 12 :5 13
:7 15 :b 17 :11 18 19
:2 18 :2 19 :2 18 :2 19
:2 18 :2 1a :2 18 :2 1a
:2 18 :2 1a :2 18 :2 1a
:2 18 :2 1b :2 18 :2 1b
:2 18 :2 1b :2 18 :2 1b
:2 18 :2 1c :2 18 :2 1c
:2 18 :2 1c :2 18 :2 1c
:2 18 :2 1d :2 18 :2 1d
:2 18 :2 1d :2 18 :2 1d
:2 18 :2 1e :2 18 :2 1e
:2 18 :2 1e :2 18 :2 1e
:2 18 :2 1f :2 18 :2 1f
:2 18 :2 1f :2 18 :2 1f
:2 18 :2 1f :4 18 :3 17
:11 22 :b 23 :3 22 :e 28
:11 29 :20 2a :3 29 :11 2c
:b 2d :3 2c :9 2f :3 28
:3 33 :d 36 :4 39 3a
:4 3b 39 :5 3c 38
:2 3e :5 40 :11 41 :24 42
:3 41 :2 3f :6 3e 3d
:3 16 :13 48 :5 49 :7 4a
48 :5 4b 47 :2 4d
:5 4f :11 50 :24 51 :3 50
:2 4e :6 4d 4c :3 16
:a 57 :11 58 :30 59 :3 58
:11 5b :b 5c :3 5b :a 5e
:3 57 :5 62 :9 65 :8 66
65 :6 67 :5 68 67
:5 6a 69 :3 67 64
:2 6d :5 6f :11 70 :24 71
:3 70 :2 6e :6 6d 6c
:3 16 :a 76 :16 78 :5 79
:3 7a :c 7b :17 7f 82
:4 83 :4 84 :3 85 82
:6 86 :5 87 86 :5 89
88 :3 86 81 :2 8c
:5 8e :11 8f :24 90 :3 8f
:2 8d :6 8c 8b :3 7b
:b 94 7b 95 7b
:3 79 :5 99 :3 9b :16 9c
:5 9e :3 9f :c a0 :17 a4
a7 :4 a8 :4 a9 :3 aa
a7 :6 ab :5 ac ab
:5 ae ad :3 ab a6
:2 b1 :5 b3 :11 b4 :24 b5
:3 b4 :2 b2 :6 b1 b0
:3 a0 :b ba a0 bb
a0 :3 9e :3 99 :3 76
:11 c0 :30 c1 :3 c0 :a c3
16 :3 c6 :11 c7 :b c8
:17 c9 :3 c7 :2 cb :3 cc
:3 cd ce cc cb
cc :3 cf :3 c6 :2 d0
:5 d2 :11 d3 :b d4 :18 d5
:3 d3 :2 d7 d8 :3 d9
da d8 d7 d8
:3 db :2 d1 :6 d0 c5
:7 1 
147e
4
:3 0 1 :3 0 2
:a 0 5d1 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 7
:7 0 11 10 :3 0
4 :3 0 8 :7 0
15 14 :3 0 11
:2 0 f 4 :3 0
9 :7 0 19 18
:3 0 4 :3 0 a
:7 0 1d 1c :3 0
b :3 0 c :3 0
d :2 0 4 21
22 0 1f 23
0 5d1 2 24
:2 0 11 :2 0 1b
4 :3 0 f :2 0
19 27 29 :6 0
2c 2a 0 5cf
0 e :6 0 f
:2 0 1f 4 :3 0
1d 2e 30 :6 0
33 31 0 5cf
0 10 :6 0 14
:2 0 23 4 :3 0
21 35 37 :6 0
3a 38 0 5cf
0 12 :6 0 17
:2 0 27 4 :3 0
25 3c 3e :6 0
41 3f 0 5cf
0 13 :6 0 17
:2 0 29 16 :3 0
43 :7 0 47 44
45 5cf 0 15
:6 0 2d 168 0
2b 16 :3 0 49
:7 0 4d 4a 4b
5cf 0 18 :6 0
59 5a 0 2f
16 :3 0 4f :7 0
52 50 0 5cf
0 19 :6 0 16
:3 0 54 :7 0 57
55 0 5cf 0
1a :6 0 5f 60
0 31 c :3 0
d :2 0 4 5b
:7 0 5e 5c 0
5cf 0 1b :6 0
1c :3 0 1d :3 0
1c :3 0 1e :3 0
62 63 0 2
:4 0 33 64 66
61 68 67 :2 0
1f :3 0 20 :3 0
6a 6b 0 21
:4 0 1c :3 0 22
:3 0 6e 6f 0
2 :4 0 35 70
72 23 :4 0 24
:2 0 25 :3 0 37
75 77 :3 0 26
:4 0 24 :2 0 27
:4 0 3a 7a 7c
:3 0 24 :2 0 3
:3 0 3d 7e 80
:3 0 24 :2 0 27
:4 0 40 82 84
:3 0 24 :2 0 28
:4 0 43 86 88
:3 0 24 :2 0 27
:4 0 46 8a 8c
:3 0 24 :2 0 5
:3 0 49 8e 90
:3 0 24 :2 0 27
:4 0 4c 92 94
:3 0 24 :2 0 28
:4 0 4f 96 98
:3 0 24 :2 0 27
:4 0 52 9a 9c
:3 0 24 :2 0 6
:3 0 55 9e a0
:3 0 24 :2 0 27
:4 0 58 a2 a4
:3 0 24 :2 0 28
:4 0 5b a6 a8
:3 0 24 :2 0 27
:4 0 5e aa ac
:3 0 24 :2 0 7
:3 0 61 ae b0
:3 0 24 :2 0 27
:4 0 64 b2 b4
:3 0 24 :2 0 28
:4 0 67 b6 b8
:3 0 24 :2 0 27
:4 0 6a ba bc
:3 0 24 :2 0 8
:3 0 6d be c0
:3 0 24 :2 0 27
:4 0 70 c2 c4
:3 0 24 :2 0 28
:4 0 73 c6 c8
:3 0 24 :2 0 27
:4 0 76 ca cc
:3 0 24 :2 0 9
:3 0 79 ce d0
:3 0 24 :2 0 27
:4 0 7c d2 d4
:3 0 24 :2 0 28
:4 0 7f d6 d8
:3 0 24 :2 0 27
:4 0 82 da dc
:3 0 24 :2 0 a
:3 0 85 de e0
:3 0 24 :2 0 27
:4 0 88 e2 e4
:3 0 24 :2 0 29
:4 0 8b e6 e8
:3 0 8e 6c ea
:2 0 ec 93 ed
69 ec 0 ee
95 0 52f 1c
:3 0 1d :3 0 ef
f0 0 1c :3 0
2a :3 0 f2 f3
0 2b :2 0 2
:4 0 2c :2 0 2d
:2 0 2b :2 0 97
f8 fa :3 0 9a
f4 fc f1 fe
fd :2 0 1f :3 0
2e :3 0 100 101
0 21 :4 0 2f
:4 0 24 :2 0 25
:3 0 9e 105 107
:3 0 a1 102 109
:2 0 10b a4 10c
ff 10b 0 10d
a6 0 52f 3
:3 0 30 :2 0 a8
10f 110 :3 0 111
:2 0 112 :2 0 5
:3 0 30 :2 0 aa
115 116 :3 0 117
:2 0 118 :2 0 113
11a 119 :2 0 1c
:3 0 1d :3 0 11c
11d 0 1c :3 0
2a :3 0 11f 120
0 31 :2 0 2
:4 0 32 :2 0 2d
:2 0 2b :2 0 ac
125 127 :3 0 af
121 129 11e 12b
12a :2 0 1f :3 0
2e :3 0 12d 12e
0 21 :4 0 33
:4 0 24 :2 0 25
:3 0 b3 132 134
:3 0 24 :2 0 34
:4 0 b6 136 138
:3 0 24 :2 0 35
:4 0 b9 13a 13c
:3 0 24 :2 0 36
:3 0 37 :3 0 38
:3 0 39 :3 0 141
142 0 bc 140
144 3a :4 0 be
13f 147 c1 13e
149 :3 0 c4 12f
14b :2 0 14d c7
14e 12c 14d 0
14f c9 0 178
1c :3 0 1d :3 0
150 151 0 1c
:3 0 2a :3 0 153
154 0 2b :2 0
2 :4 0 3b :2 0
2d :2 0 2b :2 0
cb 159 15b :3 0
ce 155 15d 152
15f 15e :2 0 1f
:3 0 2e :3 0 161
162 0 21 :4 0
3c :4 0 24 :2 0
25 :3 0 d2 166
168 :3 0 d5 163
16a :2 0 16c d8
16d 160 16c 0
16e da 0 178
3d :3 0 3e :3 0
16f 170 0 38
:3 0 39 :3 0 172
173 0 3f :3 0
dc 171 176 :2 0
178 df 179 11b
178 0 17a e3
0 52f 10 :3 0
5 :3 0 17b 17c
0 52f 12 :3 0
40 :3 0 40 :3 0
10 :3 0 2b :2 0
f :2 0 e5 180
184 2b :2 0 f
:2 0 e9 17f 188
17e 189 0 52f
36 :3 0 41 :3 0
42 :3 0 18 :3 0
43 :3 0 44 :3 0
3 :3 0 45 :3 0
12 :4 0 46 1
:8 0 19a c :3 0
47 :3 0 195 196
0 48 :3 0 197
198 0 19a ed
1e4 49 :3 0 c
:3 0 47 :3 0 19d
19e 0 48 :3 0
19f 1a0 0 1da
1c :3 0 1d :3 0
1a2 1a3 0 1c
:3 0 2a :3 0 1a5
1a6 0 4a :2 0
2 :4 0 4b :2 0
2d :2 0 2b :2 0
f0 1ab 1ad :3 0
f3 1a7 1af 1a4
1b1 1b0 :2 0 1f
:3 0 2e :3 0 1b3
1b4 0 21 :4 0
4c :4 0 24 :2 0
25 :3 0 f7 1b8
1ba :3 0 24 :2 0
34 :4 0 fa 1bc
1be :3 0 24 :2 0
4d :4 0 fd 1c0
1c2 :3 0 24 :2 0
48 :3 0 100 1c4
1c6 :3 0 24 :2 0
4e :4 0 103 1c8
1ca :3 0 24 :2 0
40 :3 0 4f :3 0
2b :2 0 50 :2 0
106 1cd 1d1 10a
1cc 1d3 :3 0 10d
1b5 1d5 :2 0 1d7
110 1d8 1b2 1d7
0 1d9 112 0
1da 114 1dd :3 0
1dd 0 1dd 1dc
1da 1db :6 0 1df
2 :3 0 117 1e1
119 1e0 1df :2 0
1e2 11b :2 0 1e4
0 1e4 1e3 19a
1e2 :6 0 52f 1
:3 0 51 :3 0 52
:3 0 51 :3 0 52
:3 0 51 :3 0 52
:3 0 51 :3 0 52
:3 0 51 :3 0 52
:3 0 53 :3 0 54
:3 0 55 :3 0 53
:3 0 56 :3 0 55
:3 0 53 :3 0 37
:3 0 18 :3 0 13
:3 0 57 :3 0 56
:3 0 57 :3 0 54
:3 0 56 :3 0 58
:3 0 12 :3 0 54
:3 0 58 :3 0 56
:3 0 59 :4 0 5a
1 :8 0 20b c
:3 0 47 :3 0 206
207 0 48 :3 0
208 209 0 20b
11d 255 49 :3 0
c :3 0 47 :3 0
20e 20f 0 48
:3 0 210 211 0
24b 1c :3 0 1d
:3 0 213 214 0
1c :3 0 2a :3 0
216 217 0 4a
:2 0 2 :4 0 5b
:2 0 2d :2 0 2b
:2 0 120 21c 21e
:3 0 123 218 220
215 222 221 :2 0
1f :3 0 2e :3 0
224 225 0 21
:4 0 5c :4 0 24
:2 0 25 :3 0 127
229 22b :3 0 24
:2 0 34 :4 0 12a
22d 22f :3 0 24
:2 0 4d :4 0 12d
231 233 :3 0 24
:2 0 48 :3 0 130
235 237 :3 0 24
:2 0 4e :4 0 133
239 23b :3 0 24
:2 0 40 :3 0 4f
:3 0 2b :2 0 50
:2 0 136 23e 242
13a 23d 244 :3 0
13d 226 246 :2 0
248 140 249 223
248 0 24a 142
0 24b 144 24e
:3 0 24e 0 24e
24d 24b 24c :6 0
250 4 :3 0 147
252 149 251 250
:2 0 253 14b :2 0
255 0 255 254
20b 253 :6 0 52f
1 :3 0 c :3 0
47 :3 0 257 258
0 c :3 0 5d
:2 0 5e :3 0 25a
25c 0 14f 25b
25e :3 0 25f :2 0
1c :3 0 1d :3 0
261 262 0 1c
:3 0 2a :3 0 264
265 0 f :2 0
2 :4 0 5f :2 0
2d :2 0 2b :2 0
152 26a 26c :3 0
155 266 26e 263
270 26f :2 0 1f
:3 0 2e :3 0 272
273 0 21 :4 0
60 :4 0 24 :2 0
25 :3 0 159 277
279 :3 0 24 :2 0
34 :4 0 15c 27b
27d :3 0 24 :2 0
35 :4 0 15f 27f
281 :3 0 24 :2 0
36 :3 0 37 :3 0
38 :3 0 61 :3 0
286 287 0 162
285 289 3a :4 0
164 284 28c 167
283 28e :3 0 24
:2 0 62 :4 0 16a
290 292 :3 0 24
:2 0 27 :4 0 16d
294 296 :3 0 24
:2 0 12 :3 0 170
298 29a :3 0 24
:2 0 27 :4 0 173
29c 29e :3 0 176
274 2a0 :2 0 2a2
179 2a3 271 2a2
0 2a4 17b 0
2ce 1c :3 0 1d
:3 0 2a5 2a6 0
1c :3 0 2a :3 0
2a8 2a9 0 2b
:2 0 2 :4 0 63
:2 0 2d :2 0 2b
:2 0 17d 2ae 2b0
:3 0 180 2aa 2b2
2a7 2b4 2b3 :2 0
1f :3 0 2e :3 0
2b6 2b7 0 21
:4 0 64 :4 0 24
:2 0 25 :3 0 184
2bb 2bd :3 0 187
2b8 2bf :2 0 2c1
18a 2c2 2b5 2c1
0 2c3 18c 0
2ce 3d :3 0 65
:3 0 2c4 2c5 0
38 :3 0 61 :3 0
2c7 2c8 0 12
:3 0 3f :3 0 18e
2c6 2cc :2 0 2ce
192 2cf 260 2ce
0 2d0 196 0
52f e :3 0 66
:4 0 2d2 2d3 :3 0
2d1 2d4 0 52f
43 :3 0 67 :3 0
44 :3 0 45 :3 0
42 :3 0 68 :3 0
69 :3 0 6a :3 0
6b :3 0 e :3 0
3 :3 0 12 :3 0
18 :3 0 13 :3 0
9 :3 0 8 :3 0
7 :4 0 6c 1
:8 0 2fd 6d :4 0
2e8 :3 0 3f :3 0
5d :2 0 19a 2eb
2ec :3 0 c :3 0
47 :3 0 2ee 2ef
0 17 :2 0 2f0
2f1 0 2f3 19d
2fa c :3 0 47
:3 0 2f4 2f5 0
6e :2 0 2f6 2f7
0 2f9 19f 2fb
2ed 2f3 0 2fc
0 2f9 0 2fc
1a1 0 2fd 1a4
347 49 :3 0 c
:3 0 47 :3 0 300
301 0 48 :3 0
302 303 0 33d
1c :3 0 1d :3 0
305 306 0 1c
:3 0 2a :3 0 308
309 0 4a :2 0
2 :4 0 6f :2 0
2d :2 0 2b :2 0
1a7 30e 310 :3 0
1aa 30a 312 307
314 313 :2 0 1f
:3 0 2e :3 0 316
317 0 21 :4 0
70 :4 0 24 :2 0
25 :3 0 1ae 31b
31d :3 0 24 :2 0
34 :4 0 1b1 31f
321 :3 0 24 :2 0
4d :4 0 1b4 323
325 :3 0 24 :2 0
48 :3 0 1b7 327
329 :3 0 24 :2 0
4e :4 0 1ba 32b
32d :3 0 24 :2 0
40 :3 0 4f :3 0
2b :2 0 50 :2 0
1bd 330 334 1c1
32f 336 :3 0 1c4
318 338 :2 0 33a
1c7 33b 315 33a
0 33c 1c9 0
33d 1cb 340 :3 0
340 0 340 33f
33d 33e :6 0 342
6 :3 0 1ce 344
1d0 343 342 :2 0
345 1d2 :2 0 347
0 347 346 2fd
345 :6 0 52f 1
:3 0 c :3 0 47
:3 0 349 34a 0
c :3 0 5d :2 0
71 :3 0 34c 34e
0 1d6 34d 350
:3 0 351 :2 0 19
:3 0 72 :3 0 36
:3 0 73 :3 0 10
:3 0 1d9 356 358
17 :2 0 1db 355
35b 2d :2 0 2b
:2 0 1de 35d 35f
:3 0 360 :2 0 74
:2 0 f :2 0 1e1
362 364 :3 0 1e4
354 366 353 367
0 4de 19 :3 0
75 :2 0 2b :2 0
1e8 36a 36c :3 0
15 :3 0 2b :2 0
36e 36f 0 410
76 :3 0 36 :3 0
15 :3 0 17 :2 0
1eb 372 375 19
:3 0 77 :2 0 78
:3 0 1f0 378 37a
:3 0 37b 40f 12
:3 0 79 :3 0 7a
:3 0 37e 37f 0
f :2 0 f :2 0
36 :3 0 15 :3 0
17 :2 0 1f3 383
386 7b :2 0 f
:2 0 1f6 388 38a
:3 0 2d :2 0 2b
:2 0 1f9 38c 38e
:3 0 10 :3 0 1fc
380 391 37d 392
0 40d 7c :3 0
e :3 0 58 :3 0
7d :3 0 7e :3 0
7f :3 0 80 :3 0
37 :3 0 15 :3 0
57 :3 0 58 :3 0
12 :4 0 81 1
:8 0 3b6 6d :4 0
3a1 :3 0 3f :3 0
5d :2 0 203 3a4
3a5 :3 0 c :3 0
47 :3 0 3a7 3a8
0 17 :2 0 3a9
3aa 0 3ac 206
3b3 c :3 0 47
:3 0 3ad 3ae 0
6e :2 0 3af 3b0
0 3b2 208 3b4
3a6 3ac 0 3b5
0 3b2 0 3b5
20a 0 3b6 20d
400 49 :3 0 c
:3 0 47 :3 0 3b9
3ba 0 48 :3 0
3bb 3bc 0 3f6
1c :3 0 1d :3 0
3be 3bf 0 1c
:3 0 2a :3 0 3c1
3c2 0 4a :2 0
2 :4 0 82 :2 0
2d :2 0 2b :2 0
210 3c7 3c9 :3 0
213 3c3 3cb 3c0
3cd 3cc :2 0 1f
:3 0 2e :3 0 3cf
3d0 0 21 :4 0
83 :4 0 24 :2 0
25 :3 0 217 3d4
3d6 :3 0 24 :2 0
34 :4 0 21a 3d8
3da :3 0 24 :2 0
4d :4 0 21d 3dc
3de :3 0 24 :2 0
48 :3 0 220 3e0
3e2 :3 0 24 :2 0
4e :4 0 223 3e4
3e6 :3 0 24 :2 0
40 :3 0 4f :3 0
2b :2 0 50 :2 0
226 3e9 3ed 22a
3e8 3ef :3 0 22d
3d1 3f1 :2 0 3f3
230 3f4 3ce 3f3
0 3f5 232 0
3f6 234 3f9 :3 0
3f9 0 3f9 3f8
3f6 3f7 :6 0 3fb
9 :3 0 237 3fd
239 3fc 3fb :2 0
3fe 23b :2 0 400
0 400 3ff 3b6
3fe :6 0 40d 8
:3 0 15 :3 0 36
:3 0 15 :3 0 17
:2 0 23d 403 406
2d :2 0 2b :2 0
240 408 40a :3 0
402 40b 0 40d
243 40f 78 :3 0
37c 40d :4 0 410
247 411 36d 410
0 412 24a 0
4de 6 :3 0 84
:2 0 24c 414 415
:3 0 416 :2 0 10
:3 0 6 :3 0 418
419 0 4db 1a
:3 0 72 :3 0 36
:3 0 73 :3 0 10
:3 0 24e 41e 420
17 :2 0 250 41d
423 2d :2 0 2b
:2 0 253 425 427
:3 0 428 :2 0 74
:2 0 f :2 0 256
42a 42c :3 0 259
41c 42e 41b 42f
0 4db 1a :3 0
75 :2 0 17 :2 0
25d 432 434 :3 0
15 :3 0 17 :2 0
436 437 0 4d8
76 :3 0 36 :3 0
15 :3 0 17 :2 0
260 43a 43d 1a
:3 0 77 :2 0 78
:3 0 265 440 442
:3 0 443 4d7 12
:3 0 79 :3 0 7a
:3 0 446 447 0
f :2 0 f :2 0
36 :3 0 15 :3 0
17 :2 0 268 44b
44e 7b :2 0 f
:2 0 26b 450 452
:3 0 2d :2 0 2b
:2 0 26e 454 456
:3 0 10 :3 0 271
448 459 445 45a
0 4d5 85 :3 0
e :3 0 12 :3 0
7d :3 0 7f :3 0
7e :3 0 80 :3 0
37 :3 0 15 :3 0
57 :3 0 58 :3 0
12 :4 0 86 1
:8 0 47e 6d :4 0
469 :3 0 3f :3 0
5d :2 0 278 46c
46d :3 0 c :3 0
47 :3 0 46f 470
0 17 :2 0 471
472 0 474 27b
47b c :3 0 47
:3 0 475 476 0
6e :2 0 477 478
0 47a 27d 47c
46e 474 0 47d
0 47a 0 47d
27f 0 47e 282
4c8 49 :3 0 c
:3 0 47 :3 0 481
482 0 48 :3 0
483 484 0 4be
1c :3 0 1d :3 0
486 487 0 1c
:3 0 2a :3 0 489
48a 0 4a :2 0
2 :4 0 87 :2 0
2d :2 0 2b :2 0
285 48f 491 :3 0
288 48b 493 488
495 494 :2 0 1f
:3 0 2e :3 0 497
498 0 21 :4 0
88 :4 0 24 :2 0
25 :3 0 28c 49c
49e :3 0 24 :2 0
34 :4 0 28f 4a0
4a2 :3 0 24 :2 0
4d :4 0 292 4a4
4a6 :3 0 24 :2 0
48 :3 0 295 4a8
4aa :3 0 24 :2 0
4e :4 0 298 4ac
4ae :3 0 24 :2 0
40 :3 0 4f :3 0
2b :2 0 50 :2 0
29b 4b1 4b5 29f
4b0 4b7 :3 0 2a2
499 4b9 :2 0 4bb
2a5 4bc 496 4bb
0 4bd 2a7 0
4be 2a9 4c1 :3 0
4c1 0 4c1 4c0
4be 4bf :6 0 4c3
c :3 0 2ac 4c5
2ae 4c4 4c3 :2 0
4c6 2b0 :2 0 4c8
0 4c8 4c7 47e
4c6 :6 0 4d5 b
:3 0 15 :3 0 36
:3 0 15 :3 0 17
:2 0 2b2 4cb 4ce
2d :2 0 2b :2 0
2b5 4d0 4d2 :3 0
4ca 4d3 0 4d5
2b8 4d7 78 :3 0
444 4d5 :4 0 4d8
2bc 4d9 435 4d8
0 4da 2bf 0
4db 2c1 4dc 417
4db 0 4dd 2c5
0 4de 2c7 4df
352 4de 0 4e0
2cb 0 52f 1c
:3 0 1d :3 0 4e1
4e2 0 1c :3 0
2a :3 0 4e4 4e5
0 89 :2 0 2
:4 0 8a :2 0 2d
:2 0 2b :2 0 2cd
4ea 4ec :3 0 2d0
4e6 4ee 4e3 4f0
4ef :2 0 1f :3 0
2e :3 0 4f2 4f3
0 21 :4 0 8b
:4 0 24 :2 0 25
:3 0 2d4 4f7 4f9
:3 0 24 :2 0 34
:4 0 2d7 4fb 4fd
:3 0 24 :2 0 35
:4 0 2da 4ff 501
:3 0 24 :2 0 36
:3 0 37 :3 0 c
:3 0 47 :3 0 506
507 0 2dd 505
509 3a :4 0 2df
504 50c 2e2 503
50e :3 0 24 :2 0
62 :4 0 2e5 510
512 :3 0 24 :2 0
27 :4 0 2e8 514
516 :3 0 24 :2 0
e :3 0 2eb 518
51a :3 0 24 :2 0
27 :4 0 2ee 51c
51e :3 0 2f1 4f4
520 :2 0 522 2f4
523 4f1 522 0
524 2f6 0 52f
3d :3 0 8c :3 0
525 526 0 c
:3 0 47 :3 0 528
529 0 e :3 0
3f :3 0 2f8 527
52d :2 0 52f 2fc
5d0 c :3 0 8d
:2 0 4 530 531
0 1c :3 0 1d
:3 0 533 534 0
1c :3 0 2a :3 0
536 537 0 4a
:2 0 2 :4 0 8e
:2 0 2d :2 0 2b
:2 0 30a 53c 53e
:3 0 30d 538 540
535 542 541 :2 0
1f :3 0 2e :3 0
544 545 0 21
:4 0 8f :4 0 24
:2 0 25 :3 0 311
549 54b :3 0 314
546 54d :2 0 566
1f :3 0 2e :3 0
54f 550 0 21
:4 0 90 :4 0 24
:2 0 c :3 0 91
:3 0 555 556 0
317 554 558 :3 0
24 :2 0 62 :4 0
31a 55a 55c :3 0
24 :2 0 c :3 0
92 :3 0 55f 560
0 31d 55e 562
:3 0 320 551 564
:2 0 566 323 567
543 566 0 568
326 0 578 93
:3 0 1b :3 0 c
:3 0 91 :3 0 94
:3 0 c :3 0 92
:3 0 95 :3 0 96
:4 0 97 1 :a 0
574 :2 0 578 56a
572 :2 0 b :3 0
1b :3 0 576 :2 0
578 328 57a 32c
579 578 :2 0 5ce
49 :3 0 c :3 0
47 :3 0 57d 57e
0 48 :3 0 57f
580 0 5c6 1c
:3 0 1d :3 0 582
583 0 1c :3 0
2a :3 0 585 586
0 4a :2 0 2
:4 0 98 :2 0 2d
:2 0 2b :2 0 32e
58b 58d :3 0 331
587 58f 584 591
590 :2 0 1f :3 0
2e :3 0 593 594
0 21 :4 0 99
:4 0 24 :2 0 25
:3 0 335 598 59a
:3 0 338 595 59c
:2 0 5b6 1f :3 0
2e :3 0 59e 59f
0 21 :4 0 4d
:4 0 24 :2 0 48
:3 0 33b 5a3 5a5
:3 0 24 :2 0 4e
:4 0 33e 5a7 5a9
:3 0 24 :2 0 40
:3 0 4f :3 0 2b
:2 0 50 :2 0 341
5ac 5b0 345 5ab
5b2 :3 0 348 5a0
5b4 :2 0 5b6 34b
5b7 592 5b6 0
5b8 34e 0 5c6
93 :3 0 1b :3 0
94 :3 0 c :3 0
92 :3 0 95 :3 0
96 :4 0 9a 1
:a 0 5c2 :2 0 5c6
5ba 5c0 :2 0 b
:3 0 1b :3 0 5c4
:2 0 5c6 350 5c9
:3 0 5c9 0 5c9
5c8 5c6 5c7 :6 0
5cb 1 :3 0 355
5cd 357 5cc 5cb
:2 0 5ce 359 :2 0
5d0 35c 5d0 5cf
52f 5ce :6 0 5d1
:2 0 2 24 5d0
5d4 :3 0 5d3 5d1
5d5 :8 0 
366
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 7
6 a e 12
16 1a 1e 1
28 1 26 1
2f 1 2d 1
36 1 34 1
3d 1 3b 1
42 1 48 1
4e 1 53 1
58 1 65 1
71 2 74 76
2 79 7b 2
7d 7f 2 81
83 2 85 87
2 89 8b 2
8d 8f 2 91
93 2 95 97
2 99 9b 2
9d 9f 2 a1
a3 2 a5 a7
2 a9 ab 2
ad af 2 b1
b3 2 b5 b7
2 b9 bb 2
bd bf 2 c1
c3 2 c5 c7
2 c9 cb 2
cd cf 2 d1
d3 2 d5 d7
2 d9 db 2
dd df 2 e1
e3 2 e5 e7
4 6d 73 78
e9 1 eb 1
ed 2 f7 f9
3 f5 f6 fb
2 104 106 2
103 108 1 10a
1 10c 1 10e
1 114 2 124
126 3 122 123
128 2 131 133
2 135 137 2
139 13b 1 143
2 145 146 2
13d 148 2 130
14a 1 14c 1
14e 2 158 15a
3 156 157 15c
2 165 167 2
164 169 1 16b
1 16d 2 174
175 3 14f 16e
177 1 179 3
181 182 183 3
185 186 187 2
194 199 2 1aa
1ac 3 1a8 1a9
1ae 2 1b7 1b9
2 1bb 1bd 2
1bf 1c1 2 1c3
1c5 2 1c7 1c9
3 1ce 1cf 1d0
2 1cb 1d2 2
1b6 1d4 1 1d6
1 1d8 2 1a1
1d9 1 1dd 1
19c 1 1e1 2
205 20a 2 21b
21d 3 219 21a
21f 2 228 22a
2 22c 22e 2
230 232 2 234
236 2 238 23a
3 23f 240 241
2 23c 243 2
227 245 1 247
1 249 2 212
24a 1 24e 1
20d 1 252 1
25d 2 259 25d
2 269 26b 3
267 268 26d 2
276 278 2 27a
27c 2 27e 280
1 288 2 28a
28b 2 282 28d
2 28f 291 2
293 295 2 297
299 2 29b 29d
2 275 29f 1
2a1 1 2a3 2
2ad 2af 3 2ab
2ac 2b1 2 2ba
2bc 2 2b9 2be
1 2c0 1 2c2
3 2c9 2ca 2cb
3 2a4 2c3 2cd
1 2cf 1 2ea
2 2e9 2ea 1
2f2 1 2f8 2
2fa 2fb 2 2e7
2fc 2 30d 30f
3 30b 30c 311
2 31a 31c 2
31e 320 2 322
324 2 326 328
2 32a 32c 3
331 332 333 2
32e 335 2 319
337 1 339 1
33b 2 304 33c
1 340 1 2ff
1 344 1 34f
2 34b 34f 1
357 2 359 35a
2 35c 35e 2
361 363 1 365
1 36b 2 369
36b 2 373 374
1 377 2 376
377 2 384 385
2 387 389 2
38b 38d 4 381
382 38f 390 1
3a3 2 3a2 3a3
1 3ab 1 3b1
2 3b3 3b4 2
3a0 3b5 2 3c6
3c8 3 3c4 3c5
3ca 2 3d3 3d5
2 3d7 3d9 2
3db 3dd 2 3df
3e1 2 3e3 3e5
3 3ea 3eb 3ec
2 3e7 3ee 2
3d2 3f0 1 3f2
1 3f4 2 3bd
3f5 1 3f9 1
3b8 1 3fd 2
404 405 2 407
409 3 393 400
40c 2 370 40f
1 411 1 413
1 41f 2 421
422 2 424 426
2 429 42b 1
42d 1 433 2
431 433 2 43b
43c 1 43f 2
43e 43f 2 44c
44d 2 44f 451
2 453 455 4
449 44a 457 458
1 46b 2 46a
46b 1 473 1
479 2 47b 47c
2 468 47d 2
48e 490 3 48c
48d 492 2 49b
49d 2 49f 4a1
2 4a3 4a5 2
4a7 4a9 2 4ab
4ad 3 4b2 4b3
4b4 2 4af 4b6
2 49a 4b8 1
4ba 1 4bc 2
485 4bd 1 4c1
1 480 1 4c5
2 4cc 4cd 2
4cf 4d1 3 45b
4c8 4d4 2 438
4d7 1 4d9 3
41a 430 4da 1
4dc 3 368 412
4dd 1 4df 2
4e9 4eb 3 4e7
4e8 4ed 2 4f6
4f8 2 4fa 4fc
2 4fe 500 1
508 2 50a 50b
2 502 50d 2
50f 511 2 513
515 2 517 519
2 51b 51d 2
4f5 51f 1 521
1 523 3 52a
52b 52c d ee
10d 17a 17d 18a
1e4 255 2d0 2d5
347 4e0 524 52e
2 53b 53d 3
539 53a 53f 2
548 54a 2 547
54c 2 553 557
2 559 55b 2
55d 561 2 552
563 2 54e 565
1 567 3 568
573 577 1 532
2 58a 58c 3
588 589 58e 2
597 599 2 596
59b 2 5a2 5a4
2 5a6 5a8 3
5ad 5ae 5af 2
5aa 5b1 2 5a1
5b3 2 59d 5b5
1 5b7 4 581
5b8 5c1 5c5 1
5c9 1 57c 2
57a 5cd 9 2b
32 39 40 46
4c 51 56 5d

1
4
0 
5d4
0
1
14
e
11
0 1 2 1 4 1 6 1
8 9 1 b c 1 0 0
0 0 0 0 
1b 1 0
b 1 0
34 1 0
42 1 0
4e 1 0
17 1 0
48 1 0
2d 1 0
13 1 0
f 1 0
26 1 0
3 1 0
53 1 0
2 0 1
7 1 0
3b 1 0
58 1 0
0

/
SHOW ERRORS FUNCTION SP_I_PROFILE;
ALTER FUNCTION SP_I_PROFILE COMPILE DEBUG;
/*######################################################################################*/
/* assign a profile to a task or project, used tables: RESOURCE_ASSIGNMENTS, PROFILES   */
/****************************************************************************************/
/*  RES_ID is profile_id, role_id is role_id in TMT_COMPETENCIES    */
/****************************************************************************************/
/*
#Stored Procedure  :SP_A_TSKPROF
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_TSKPROF ==
CREATE OR REPLACE FUNCTION SP_A_TSKPROF wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
d5
2 :e:
1FUNCTION:
1SP_A_TSKPROF:
1TASK_ID001:
1VARCHAR2:
1RES_ID001:
1ROLE_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_UNIQUEID:
132:
1H_PROJECT_ID:
1H_RES_ID:
1H_AND_ROLES:
18000:
1H_ROLE_ID:
1H_REC_STATUS:
11:
1H_FULL_NAME:
1255:
1H_TYPE:
1PLS_INTEGER:
10:
1H_CRI:
1H_BITFLAG:
1H_NUMBER:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_RES_TYPE:
1H_TEMP_SC_STATE:
1H_TABLE_TYPE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_TSKPROF(:
1':
1, :
1);:
1CHECK_TRACE:
137:
1+:
1FPUT:
1               ENTER:: SP_A_TSKPROF(38) :: cplan.sql(5635) :: :
1IS NULL:
18:
144:
1      RETURN_INVALID:: SP_A_TSKPROF(45) :: cplan.sql(5642) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
147:
1                EXIT:: SP_A_TSKPROF(48) :: cplan.sql(5645) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1PROJECT_ID:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type FROM TMT_WBS WHERE ELEME+
1NT_ID = task_id001:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
160:
1           EXCEPTION:: SP_A_TSKPROF(61) :: cplan.sql(5658) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type FROM TMT_CRI WHERE ELEME+
1NT_ID = task_id001:
174:
1           EXCEPTION:: SP_A_TSKPROF(75) :: cplan.sql(5672) :: :
181:
1        RETURN_ERROR:: SP_A_TSKPROF(82) :: cplan.sql(5679) :: :
1RECORD_NOT_FOUND:
1 ID:: :
184:
1                EXIT:: SP_A_TSKPROF(85) :: cplan.sql(5682) :: :
1PMO_RETURN_ERROR_SP:
1SC_TABLE_CRI:
1SC_TABLE_WBS:
1PROFILE_ID:
1PROFILE_NAME:
1REC_STATUS:
1PROFILES:
1SELECT PROFILE_ID, PROFILE_NAME, REC_STATUS INTO h_res_id, h_full_name, h_rec+
1_status:n      FROM PROFILES WHERE PROFILE_ID = h_res_id:
1107:
1           EXCEPTION:: SP_A_TSKPROF(108) :: cplan.sql(5705) :: :
1MAX:
1PROF_NUMBER:
1ROLE_ID:
1SELECT COALESCE(MAX(PROF_NUMBER),0)+1 INTO h_number:n         FROM PROFILES:n+
1         WHERE PROJECT_ID=h_project_id AND ROLE_ID=h_role_id:
1127:
1           EXCEPTION:: SP_A_TSKPROF(128) :: cplan.sql(5725) :: :
1PMO_ORASTD:
1STRINGCONCAT:
1RTRIM:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1PARENT_ID:
1SELECT PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConca+
1t(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEMENT_NAME), ',+
1 '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(h_number))), ')') INTO h_fu+
1ll_name:n         FROM TMT_COMPETENCIES TC, TMT_COMPETENCIES TCP:n         WH+
1ERE TC.ELEMENT_ID = h_role_id AND TCP.ELEMENT_ID = TC.PARENT_ID:
1142:
1           EXCEPTION:: SP_A_TSKPROF(143) :: cplan.sql(5740) :: :
1149:
1        RETURN_ERROR:: SP_A_TSKPROF(150) :: cplan.sql(5747) :: :
1152:
1                EXIT:: SP_A_TSKPROF(153) :: cplan.sql(5750) :: :
1INSERT INTO PROFILES(PROFILE_ID,PROJECT_ID,ROLE_ID,PROF_NUMBER, PROFILE_NAME)+
1:n         VALUES(h_res_id, h_project_id, h_role_id, h_number, h_full_name):
1FOUND:
1100:
1170:
1           EXCEPTION:: SP_A_TSKPROF(171) :: cplan.sql(5768) :: :
1!=:
1SC_SQL_SUCCESS:
1177:
1        RETURN_ERROR:: SP_A_TSKPROF(178) :: cplan.sql(5775) :: :
1180:
1                EXIT:: SP_A_TSKPROF(181) :: cplan.sql(5778) :: :
1ELSIF:
1ISNOTPROJECTTYPE:
1A:
1RES_ASSIGNMENT_ID:
1RESOURCE_ASSIGNMENTS:
1RESOURCE_ID:
1RESOURCE_TYPE:
1SELECT a.RES_ASSIGNMENT_ID INTO h_uniqueID :n            FROM RESOURCE_ASSIGN+
1MENTS a:n            WHERE a.ELEMENT_ID = task_id001  :n            AND a.RES+
1OURCE_ID = res_id001:n            AND a.RESOURCE_TYPE = '1':
1198:
1           EXCEPTION:: SP_A_TSKPROF(199) :: cplan.sql(5796) :: :
1205:
1        RETURN_ERROR:: SP_A_TSKPROF(206) :: cplan.sql(5803) :: :
1RECORD_ALREADY_ASSIGNED:
1208:
1                EXIT:: SP_A_TSKPROF(209) :: cplan.sql(5806) :: :
1D:
1UPDATE PROFILES SET REC_STATUS = 'U' WHERE PROFILE_ID = h_res_id:
1227:
1           EXCEPTION:: SP_A_TSKPROF(228) :: cplan.sql(5825) :: :
1234:
1        RETURN_ERROR:: SP_A_TSKPROF(235) :: cplan.sql(5832) :: :
1237:
1                EXIT:: SP_A_TSKPROF(238) :: cplan.sql(5835) :: :
1SELECT RES_ASSIGNMENT_ID INTO h_uniqueID :n      FROM RESOURCE_ASSIGNMENTS:n +
1     WHERE ELEMENT_ID = task_id001 :n      AND RESOURCE_ID = h_res_id :n     +
1 AND RESOURCE_TYPE = '1':
1           EXCEPTION:: SP_A_TSKPROF(256) :: cplan.sql(5853) :: :
1ASSIGN_NAMES:
1INSTR:
1LENGTH:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n            ELSE:n  +
1          CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) >+
1 2040 THEN ASSIGN_NAMES:n            ELSE ASSIGN_NAMES || h_full_name || ';'+
1:n            END:n            END:n            WHERE ELEMENT_ID = task_id001:
1284:
1           EXCEPTION:: SP_A_TSKPROF(285) :: cplan.sql(5882) :: :
1UPDATE TMT_CRI SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n            ELSE:n  +
1          CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) >+
1 2040 THEN ASSIGN_NAMES:n            ELSE ASSIGN_NAMES || h_full_name || ';'+
1:n            END:n            END:n            WHERE ELEMENT_ID = task_id001:
1310:
1           EXCEPTION:: SP_A_TSKPROF(311) :: cplan.sql(5908) :: :
1SYS_GUID:
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1ISPROJECTTYPE:
1SC_AFFECTED:
1SC_TEAMMEMBER:
1FC_BEFORE_I_RES_ASSIGN:
1ELEMENT_TYPE:
1PARTICIPANT:
1SECURITY_ID:
1REC_USER:
1REC_DATETIME:
1TABLE_TYPE:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE,:n         RESOURCE_TYPE, RESOURCE_ID, PARTICIPANT, SECURITY_ID, +
1REC_USER, REC_DATETIME,TABLE_TYPE) :n         VALUES (h_uniqueID, h_project_i+
1d,task_id001, h_type, :n         '1', h_res_id, h_temp_participant, h_temp_se+
1curity_id, rec_user001, SYSTIMESTAMP,h_table_type):
1348:
1           EXCEPTION:: SP_A_TSKPROF(349) :: cplan.sql(5946) :: :
1PMO_STPU:
1BIT_OR:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT = PMO_STPU.BIT_OR(PARTICIPANT, PM+
1O_CNST.SC_TEAMMEMBER):n         WHERE RES_ASSIGNMENT_ID = h_uniqueID:
1367:
1           EXCEPTION:: SP_A_TSKPROF(368) :: cplan.sql(5965) :: :
1FC_AFTER_U_RES_ASSIGN:
14:
1376:
1       RETURN_STATUS:: SP_A_TSKPROF(377) :: cplan.sql(5974) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1383:
1           EXCEPTION:: SP_A_TSKPROF(384) :: cplan.sql(5981) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1395:
1           EXCEPTION:: SP_A_TSKPROF(396) :: cplan.sql(5993) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
add
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a 52 10
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :7 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :7 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c a0 51 d :3 a0 6b
d b7 a0 51 d :3 a0 6b d
b7 :2 19 3c :2 a0 d :9 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 d :3 a0 :2 51 a5 b d
:9 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :1f a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c a0 b7 :2 a0
6b a0 7e a0 6b b4 2e 5a
:3 a0 51 a5 b a5 b 7e 51
b4 2e :d a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 19 3c :2 a0 :2 51 a5 b 7e
6e b4 2e :4 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
19 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c a0 51 d :8 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e :f a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :f a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 b4 2e d :4 a0 51 a5
b :2 a0 51 a5 b :2 a0 6b a0
a5 b d :3 a0 51 a5 b a5
b 7e 51 b4 2e :3 a0 6b d
b7 :3 a0 6b d b7 :2 19 3c a0
6e d a0 51 d :9 a0 a5 b
d :16 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 b7 :2 a0 6b a0 7e
a0 6b b4 2e 5a :9 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 a5
b d b7 :2 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
add
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ef
dd bc e1 e2 ea dc 10c fa
d9 fe ff 107 f9 129 117 f6
11b 11c 124 116 146 134 113 138
139 141 133 162 151 155 130 15d
150 17e 16d 171 14d 179 16c 19a
189 18d 169 195 188 1b6 1a5 1a9
185 1b1 1a4 1d2 1c1 1c5 1a1 1cd
1c0 1ef 1dd 1bd 1e1 1e2 1ea 1dc
20b 1fa 1fe 1d9 206 1f9 228 216
1f6 21a 21b 223 215 244 233 237
212 23f 232 260 24f 253 22f 25b
24e 280 26b 26f 24b 273 27b 26a
287 28b 267 28f 293 297 29a 29f
2a0 1 2a2 2a7 2ab 2af 2b2 2b7
2bb 2bf 2c2 2c7 2c8 2ca 2cf 2d2
2d6 2d7 2dc 2e1 2e4 2e9 2ea 2ef
2f2 2f6 2f7 2fc 2ff 304 305 30a
30d 312 313 318 31b 320 321 326
329 32d 32e 333 336 33b 33c 341
344 349 34a 34f 352 357 358 35d
360 364 365 36a 36d 372 373 378
37b 380 381 386 389 38e 38f 394
397 39b 39c 3a1 3a4 3a9 3aa 3af
3b2 3b7 3b8 3bd 3be 3c3 3c5 3c9
3cc 3d0 3d4 3d7 3db 3df 3e2 3e5
3ea 3ed 3f0 3f3 3f4 3f9 3fa 1
3fc 401 405 409 40c 411 416 419
41d 41e 423 424 429 42b 42f 432
436 439 43a 43f 442 445 449 44c
44d 452 455 1 458 45d 461 464
465 46a 46d 1 470 475 479 47d
480 484 488 48b 48e 493 496 499
49c 49d 4a2 4a3 1 4a5 4aa 4ae
4b2 4b5 4ba 4bf 4c2 4c6 4c7 4cc
4cf 4d4 4d5 4da 4dd 4e2 4e3 4e8
4eb 4ef 4f3 4f7 4fb 4fe 4ff 501
506 507 509 50a 50f 510 515 517
51b 51e 522 526 529 52d 531 534
537 53c 53f 542 545 546 54b 54c
1 54e 553 557 55b 55e 563 568
56b 56f 570 575 576 57b 57d 581
584 588 58c 58f 593 597 59a 59e
59f 5a4 5a6 5aa 5ad 5b1 5b5 5b9
5bd 5c1 5c5 5c9 5d5 5d9 5dd 5e0
5e4 5e8 5ea 1 5ee 5f2 5f6 5f9
5fd 601 605 609 60c 610 614 617
61a 61f 622 625 628 629 62e 62f
1 631 636 63a 63e 641 646 64b
64e 652 653 658 65b 660 661 666
669 66e 66f 674 677 67b 67c 681
684 689 68a 68f 692 696 69a 69d
6a0 6a1 6a3 6a4 6a9 6aa 6af 6b1
6b5 6b8 6ba 6be 6c0 6cc 6ce 6d0
6d1 6d6 6da 6dc 6e8 6ea 6ee 6f2
6f5 6f9 6fc 700 703 704 709 70c
710 714 718 71c 720 724 728 734
738 73c 73f 743 747 749 1 74d
751 755 758 75c 760 764 768 76b
76f 773 776 779 77e 781 784 787
788 78d 78e 1 790 795 799 79d
7a0 7a5 7aa 7ad 7b1 7b2 7b7 7ba
7bf 7c0 7c5 7c8 7cd 7ce 7d3 7d6
7da 7db 7e0 7e3 7e8 7e9 7ee 7f1
7f5 7f9 7fc 7ff 800 802 803 808
809 80e 810 814 817 819 81d 81f
82b 82d 82f 830 835 839 83b 847
849 84d 851 854 858 85b 85f 862
863 868 86b 86f 873 876 87a 87e
881 884 889 88c 88f 892 893 898
899 1 89b 8a0 8a4 8a8 8ab 8b0
8b5 8b8 8bc 8bd 8c2 8c5 8ca 8cb
8d0 8d3 8d8 8d9 8de 8e1 8e5 8e9
8ed 8f1 8f4 8f5 8f7 8fc 8fd 8ff
900 905 908 90d 90e 913 916 91b
91c 921 924 928 929 92e 931 936
937 93c 93d 942 944 948 94b 94f
953 956 95a 95e 961 964 969 96c
96f 972 973 978 979 1 97b 980
984 988 98b 990 995 998 99c 99d
9a2 9a3 9a8 9aa 9ae 9b1 9b5 9b9
9bc 9c0 9c4 9c7 9cb 9cf 9d0 9d5
9d7 9db 9de 9e2 9e5 9e9 9ed 9f1
9f5 9f8 9fc 9fe a02 a05 a09 a0d
a11 a15 a18 a1c a1e a22 a26 a29
a2d a31 a35 a39 a3d a41 a45 a49
a4d a51 a55 a59 a65 a69 a6d a70
a74 a78 a7a 1 a7e a82 a86 a89
a8d a91 a95 a99 a9c aa0 aa4 aa7
aaa aaf ab2 ab5 ab8 ab9 abe abf
1 ac1 ac6 aca ace ad1 ad6 adb
ade ae2 ae3 ae8 aeb af0 af1 af6
af9 afe aff b04 b07 b0b b0c b11
b14 b19 b1a b1f b22 b26 b2a b2d
b30 b31 b33 b34 b39 b3a b3f b41
b45 b48 b4a b4e b50 b5c b5e b60
b61 b66 b6a b6c b78 b7a b7e b82
b85 b89 b8c b90 b93 b94 b99 b9c
ba0 ba4 ba8 bac bb0 bb4 bb7 bba
bbb bbd bc1 bc5 bc9 bcd bd1 bd5
bd9 bdd be1 be5 bf1 bf5 bf9 bfc
c00 c04 c06 1 c0a c0e c12 c15
c19 c1d c21 c25 c28 c2c c30 c33
c36 c3b c3e c41 c44 c45 c4a c4b
1 c4d c52 c56 c5a c5d c62 c67
c6a c6e c6f c74 c77 c7c c7d c82
c85 c8a c8b c90 c93 c97 c98 c9d
ca0 ca5 ca6 cab cae cb2 cb6 cb9
cbc cbd cbf cc0 cc5 cc6 ccb ccd
cd1 cd4 cd6 cda cdc ce8 cea cec
ced cf2 cf6 cf8 d04 d06 d0a d0e
d12 d16 d1a d1e d22 d26 d2a d2e
d32 d36 d3a d3e d42 d46 d4a d4e
d52 d56 d5a d5e d62 d66 d6a d6e
d72 d76 d7a d7e d82 d8e d92 d96
d99 d9d da1 da3 1 da7 dab daf
db2 db6 dba dbe dc2 dc5 dc9 dcd
dd0 dd3 dd8 ddb dde de1 de2 de7
de8 1 dea def df3 df7 dfa dff
e04 e07 e0b e0c e11 e14 e19 e1a
e1f e22 e27 e28 e2d e30 e34 e35
e3a e3d e42 e43 e48 e4b e4f e53
e56 e59 e5a e5c e5d e62 e63 e68
e6a e6e e71 e73 e77 e79 e85 e87
e89 e8a e8f e93 e95 ea1 ea3 ea7
eab eae eb2 eb5 eb9 ebc ebd ec2
ec5 ec9 ecd ed0 ed4 ed8 edb ede
ee3 ee6 ee9 eec eed ef2 ef3 1
ef5 efa efe f02 f05 f0a f0f f12
f16 f17 f1c f1f f24 f25 f2a f2d
f32 f33 f38 f3b f3f f43 f47 f4b
f4e f4f f51 f56 f57 f59 f5a f5f
f62 f67 f68 f6d f70 f75 f76 f7b
f7e f82 f83 f88 f8b f90 f91 f96
f97 f9c f9e fa2 fa5 fa9 fad fb0
fb4 fb8 fbb fbe fc3 fc6 fc9 fcc
fcd fd2 fd3 1 fd5 fda fde fe2
fe5 fea fef ff2 ff6 ff7 ffc ffd
1002 1004 1008 100b 100f 1013 1016 101a
101e 1021 1025 1029 102a 102f 1031 1035
1038 103c 1040 1044 1048 104c 1050 1054
1058 105c 1060 1064 1070 1074 1079 107d
1080 1081 1086 108a 108e 1091 1094 1098
109a 109e 10a2 10a5 10a8 10ac 10ae 10b2
10b6 10b9 10bb 1 10bf 10c3 10c7 10ca
10ce 10d2 10d6 10da 10dd 10e1 10e5 10e8
10eb 10f0 10f3 10f6 10f9 10fa 10ff 1100
1 1102 1107 110b 110f 1112 1117 111c
111f 1123 1124 1129 112c 1131 1132 1137
113a 113f 1140 1145 1148 114c 114d 1152
1155 115a 115b 1160 1163 1167 116b 116e
1171 1172 1174 1175 117a 117b 1180 1182
1186 1189 118b 118f 1191 119d 119f 11a1
11a2 11a7 11ab 11ad 11b9 11bb 11bf 11c3
11c6 11ca 11cd 11d1 11d4 11d5 11da 11dd
11e1 11e5 11e8 11ec 11f0 11f3 11f6 11fb
11fe 1201 1204 1205 120a 120b 1 120d
1212 1216 121a 121d 1222 1227 122a 122e
122f 1234 1237 123c 123d 1242 1245 124a
124b 1250 1253 1257 125b 125f 1263 1266
1267 1269 126e 126f 1271 1272 1277 127a
127f 1280 1285 1288 128d 128e 1293 1296
129a 129b 12a0 12a3 12a8 12a9 12ae 12af
12b4 12b6 12ba 12bd 12c1 12c5 12c8 12cc
12d0 12d3 12d6 12db 12de 12e1 12e4 12e5
12ea 12eb 1 12ed 12f2 12f6 12fa 12fd
1302 1307 130a 130e 130f 1314 1315 131a
131c 1320 1323 1327 132b 132e 1332 1336
1339 133d 1341 1342 1347 1349 134d 1350
1354 1356 135a 135e 1361 1365 1368 136c
136f 1370 1375 1378 137c 1380 1384 1387
1388 138a 138b 138d 1390 1393 1394 1399
139d 13a1 13a5 13a9 13ad 13b1 13b5 13b9
13bd 13c1 13c5 13c9 13cd 13d9 13dd 13e1
13e4 13e8 13ec 13ee 1 13f2 13f6 13fa
13fd 1401 1405 1409 140d 1410 1414 1418
141b 141e 1423 1426 1429 142c 142d 1432
1433 1 1435 143a 143e 1442 1445 144a
144f 1452 1456 1457 145c 145f 1464 1465
146a 146d 1472 1473 1478 147b 147f 1480
1485 1488 148d 148e 1493 1496 149a 149e
14a1 14a4 14a5 14a7 14a8 14ad 14ae 14b3
14b5 14b9 14bc 14be 14c2 14c4 14d0 14d2
14d4 14d5 14da 14de 14e0 14ec 14ee 14f2
14f6 14f9 14fd 1500 1504 1507 1508 150d
1510 1514 1518 151b 151f 1523 1526 1529
152e 1531 1534 1537 1538 153d 153e 1
1540 1545 1549 154d 1550 1555 155a 155d
1561 1562 1567 156a 156f 1570 1575 1578
157d 157e 1583 1586 158a 158e 1592 1596
1599 159a 159c 15a1 15a2 15a4 15a5 15aa
15ad 15b2 15b3 15b8 15bb 15c0 15c1 15c6
15c9 15cd 15ce 15d3 15d6 15db 15dc 15e1
15e2 15e7 15e9 15ed 15f0 15f4 15f8 15fb
15ff 1603 1606 1609 160e 1611 1614 1617
1618 161d 161e 1 1620 1625 1629 162d
1630 1635 163a 163d 1641 1642 1647 1648
164d 164f 1653 1656 165a 165e 1661 1665
1669 166c 1670 1674 1675 167a 167c 1680
1683 1685 1689 168c 1690 1694 1697 169a
169b 169d 16a0 16a5 16a6 16ab 16af 16b3
16b7 16bb 16c7 16cb 16d0 16d4 16d7 16d8
16dd 16e1 16e5 16e8 16eb 16ef 16f1 16f5
16f9 16fc 16ff 1703 1705 1709 170d 1710
1712 1 1716 171a 171e 1721 1725 1729
172d 1731 1734 1738 173c 173f 1742 1747
174a 174d 1750 1751 1756 1757 1 1759
175e 1762 1766 1769 176e 1773 1776 177a
177b 1780 1783 1788 1789 178e 1791 1796
1797 179c 179f 17a3 17a4 17a9 17ac 17b1
17b2 17b7 17ba 17be 17c2 17c5 17c8 17c9
17cb 17cc 17d1 17d2 17d7 17d9 17dd 17e0
17e2 17e6 17e8 17f4 17f6 17f8 17f9 17fe
1802 1804 1810 1812 1814 1818 181b 181d
1821 1825 1829 182c 1830 1834 1837 183a
183f 1842 1845 1848 1849 184e 184f 1
1851 1856 185a 185e 1861 1866 186b 186e
1872 1873 1878 187b 1880 1881 1886 1889
188e 188f 1894 1897 189b 189f 18a3 18a7
18aa 18ab 18ad 18b2 18b3 18b5 18b6 18bb
18be 18c3 18c4 18c9 18cc 18d1 18d2 18d7
18da 18de 18df 18e4 18e7 18ec 18ed 18f2
18f3 18f8 18fa 18fe 1901 1905 1909 190c
1910 1914 1917 191a 191f 1922 1925 1928
1929 192e 192f 1 1931 1936 193a 193e
1941 1946 194b 194e 1952 1953 1958 1959
195e 1960 1964 1967 196b 196f 1972 1976
197a 197d 1981 1985 1986 198b 198d 1991
1995 1998 199c 199f 19a3 19a7 19ab 19af
19b3 19b7 19bb 19bf 19c3 19cf 19d3 19d7
19da 19de 19e2 19e4 1 19e8 19ec 19f0
19f3 19f7 19fb 19ff 1a03 1a06 1a0a 1a0e
1a11 1a14 1a19 1a1c 1a1f 1a22 1a23 1a28
1a29 1 1a2b 1a30 1a34 1a38 1a3b 1a40
1a45 1a48 1a4c 1a4d 1a52 1a55 1a5a 1a5b
1a60 1a63 1a68 1a69 1a6e 1a71 1a75 1a76
1a7b 1a7e 1a83 1a84 1a89 1a8c 1a90 1a94
1a97 1a9a 1a9b 1a9d 1a9e 1aa3 1aa4 1aa9
1aab 1aaf 1ab2 1ab4 1ab8 1aba 1ac6 1ac8
1aca 1acb 1ad0 1ad4 1ad6 1ae2 1ae4 1ae8
1aec 1aef 1af3 1af6 1afa 1afd 1afe 1b03
1b06 1b0a 1b0e 1b11 1b12 1b14 1b17 1b1a
1b1b 1b20 1b24 1b28 1b2c 1b30 1b34 1b38
1b3c 1b40 1b44 1b48 1b4c 1b50 1b54 1b58
1b5c 1b68 1b6c 1b71 1b75 1b78 1b79 1b7e
1b82 1b86 1b89 1b8c 1b90 1b92 1b96 1b9a
1b9d 1ba0 1ba4 1ba6 1baa 1bae 1bb1 1bb3
1 1bb7 1bbb 1bbf 1bc2 1bc6 1bca 1bce
1bd2 1bd5 1bd9 1bdd 1be0 1be3 1be8 1beb
1bee 1bf1 1bf2 1bf7 1bf8 1 1bfa 1bff
1c03 1c07 1c0a 1c0f 1c14 1c17 1c1b 1c1c
1c21 1c24 1c29 1c2a 1c2f 1c32 1c37 1c38
1c3d 1c40 1c44 1c45 1c4a 1c4d 1c52 1c53
1c58 1c5b 1c5f 1c63 1c66 1c69 1c6a 1c6c
1c6d 1c72 1c73 1c78 1c7a 1c7e 1c81 1c83
1c87 1c89 1c95 1c97 1c99 1c9a 1c9f 1ca3
1ca5 1cb1 1cb3 1cb7 1cb9 1cbd 1cc1 1cc4
1cc5 1cc7 1cca 1ccd 1cce 1cd3 1cd7 1cdb
1cdf 1ce3 1ce7 1ceb 1cef 1cf3 1cf7 1cfb
1cff 1d03 1d07 1d0b 1d0f 1d1b 1d1f 1d24
1d28 1d2b 1d2c 1d31 1d35 1d39 1d3c 1d3f
1d43 1d45 1d49 1d4d 1d50 1d53 1d57 1d59
1d5d 1d61 1d64 1d66 1 1d6a 1d6e 1d72
1d75 1d79 1d7d 1d81 1d85 1d88 1d8c 1d90
1d93 1d96 1d9b 1d9e 1da1 1da4 1da5 1daa
1dab 1 1dad 1db2 1db6 1dba 1dbd 1dc2
1dc7 1dca 1dce 1dcf 1dd4 1dd7 1ddc 1ddd
1de2 1de5 1dea 1deb 1df0 1df3 1df7 1df8
1dfd 1e00 1e05 1e06 1e0b 1e0e 1e12 1e16
1e19 1e1c 1e1d 1e1f 1e20 1e25 1e26 1e2b
1e2d 1e31 1e34 1e36 1e3a 1e3c 1e48 1e4a
1e4c 1e4d 1e52 1e56 1e58 1e64 1e66 1e68
1e6c 1e70 1e73 1e77 1e7b 1e7c 1e81 1e85
1e89 1e8d 1e91 1e95 1e98 1e99 1e9b 1e9f
1ea3 1ea6 1ea7 1ea9 1ead 1eb1 1eb4 1eb8
1eb9 1ebb 1ebf 1ec3 1ec7 1ecb 1ece 1ecf
1ed1 1ed2 1ed4 1ed7 1eda 1edb 1ee0 1ee4
1ee8 1eec 1eef 1ef3 1ef5 1ef9 1efd 1f01
1f04 1f08 1f0a 1f0e 1f12 1f15 1f19 1f1e
1f22 1f26 1f29 1f2d 1f31 1f35 1f39 1f3d
1f41 1f45 1f49 1f4d 1f51 1f52 1f54 1f58
1f5c 1f60 1f64 1f68 1f6c 1f70 1f74 1f78
1f7c 1f80 1f84 1f88 1f8c 1f90 1f94 1f98
1f9c 1fa0 1fa4 1fa8 1fac 1fb0 1fbc 1fc0
1fc5 1fc9 1fcc 1fcd 1fd2 1fd6 1fda 1fdd
1fe0 1fe4 1fe6 1fea 1fee 1ff1 1ff4 1ff8
1ffa 1ffe 2002 2005 2007 1 200b 200f
2013 2016 201a 201e 2022 2026 2029 202d
2031 2034 2037 203c 203f 2042 2045 2046
204b 204c 1 204e 2053 2057 205b 205e
2063 2068 206b 206f 2070 2075 2078 207d
207e 2083 2086 208b 208c 2091 2094 2098
2099 209e 20a1 20a6 20a7 20ac 20af 20b3
20b7 20ba 20bd 20be 20c0 20c1 20c6 20c7
20cc 20ce 20d2 20d5 20d7 20db 20dd 20e9
20eb 20ed 20ee 20f3 20f7 20f9 2105 2107
210b 210d 2111 2115 2118 211c 211f 2123
2126 2127 212c 212f 2133 2137 213b 213f
2143 2147 214b 214f 2153 215f 2163 2168
216c 216f 2170 2175 2179 217d 2180 2183
2187 2189 218d 2191 2194 2197 219b 219d
21a1 21a5 21a8 21aa 1 21ae 21b2 21b6
21b9 21bd 21c1 21c5 21c9 21cc 21d0 21d4
21d7 21da 21df 21e2 21e5 21e8 21e9 21ee
21ef 1 21f1 21f6 21fa 21fe 2201 2206
220b 220e 2212 2213 2218 221b 2220 2221
2226 2229 222e 222f 2234 2237 223b 223c
2241 2244 2249 224a 224f 2252 2256 225a
225d 2260 2261 2263 2264 2269 226a 226f
2271 2275 2278 227a 227e 2280 228c 228e
2290 2291 2296 229a 229c 22a8 22aa 22ae
22b2 22b6 22b7 22b9 22bd 22bf 22c3 22c7
22ca 22ce 22d2 22d5 22d9 22dd 22e0 22e3
22e8 22eb 22ee 22f1 22f2 22f7 22f8 1
22fa 22ff 2303 2307 230a 230f 2314 2317
231b 231c 2321 2324 2329 232a 232f 2332
2337 2338 233d 2340 2344 2348 234c 2350
2353 2354 2356 235b 235c 235e 235f 2364
2367 236c 236d 2372 2375 237a 237b 2380
2383 2387 2388 238d 2390 2395 2396 239b
239c 23a1 23a3 23a7 23aa 23ae 23b2 23b5
23b9 23bd 23c0 23c4 23c8 23c9 23ce 23d0
23d4 23d8 23db 23df 23e3 23e6 23ea 23ee
23f1 23f4 23f9 23fc 23ff 2402 2403 2408
2409 1 240b 2410 2414 2418 241b 2420
2425 2428 242c 242d 2432 2433 2438 243c
2440 2443 2448 244d 2450 2454 2458 245b
245c 2461 2464 2469 246a 246f 2472 2476
247a 247d 247e 2483 2484 2489 248b 248f
2492 2496 249a 249e 24a2 24a6 24aa 24ae
24b2 24b6 24c2 24c7 24cb 24cf 24d3 24d7
24d9 24da 24df 1 24e3 24e7 24eb 24ee
24f2 24f6 24fa 24fe 2501 2505 2509 250c
250f 2514 2517 251a 251d 251e 2523 2524
1 2526 252b 252f 2533 2536 253b 2540
2543 2547 2548 254d 254e 2553 2557 255b
255e 2563 2568 256b 256f 2570 2575 2578
257d 257e 2583 2586 258a 258e 2591 2594
2595 2597 2598 259d 259e 25a3 25a5 25a9
25ac 25b0 25b4 25b8 25bc 25c0 25c4 25c8
25d4 25d9 25dd 25e1 25e5 25e9 25eb 25ef
25f1 25fd 25ff 2601 2602 2607 260b 260d
2619 261d 261f 2620 2629 
add
2
0 1 a 6 11 :3 6 10 :3 6
11 :3 6 12 :2 6 1 3 a 13
a :2 1 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 d 16 15
:2 d :2 4 10 19 18 :2 10 :2 4 e
17 16 :2 e :2 4 11 1a 19 :2 11
:2 4 10 19 18 :2 10 :2 4 :2 b 1a
b :2 4 :2 a 19 a :2 4 :2 e 1d
e :2 4 :2 d 1c d :2 4 :2 17 26
17 :2 4 17 20 1f :2 17 :2 4 :2 13
22 13 :2 4 14 1d 1c :2 14 :2 4
:2 14 23 14 :2 4 :2 11 20 11 :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 54 5a 5d :2 54 6b 81 8
:2 6b d 10 :2 6b 1b 1e :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
28 2b :2 6b b e :2 6b 13 16
:2 6b 1b 1e :2 6b 29 2c :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
2a 2d :2 6b 32 35 :2 6b :2 7 4a
:2 4 7 :2 11 23 :2 2d 39 3c 4c
4e 4f :2 4c :2 23 :3 7 :2 d 12 1e
5c 5f :2 1e :2 7 52 :2 4 :4 9 8
7 :4 23 22 21 :2 7 :4 3c 3b 3a
:2 7 a :2 14 26 :2 30 3c 3f 4f
51 52 :2 4f :2 26 :3 a :2 10 15 21
5f 62 :2 21 6f 72 :2 21 76 79
:2 21 83 86 8f 97 :2 a0 :2 8f b1
:2 86 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4f 51 52 :2 4f :2 26
:3 a :2 10 15 21 5f 62 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 41 :2 7 51
:2 4 e 1a 27 35 41 4f 5c
:2 7 :2 10 1c 7 4 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
53 55 56 :2 53 :2 29 :3 d :2 13 18
24 62 65 :2 24 72 75 :2 24 79
7c :2 24 88 8b :2 24 93 96 :2 24
a2 a5 ac b5 b8 :2 a5 :2 24 :2 d
59 :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a 7 11 1d
2a 38 44 52 5f :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 58 59
:2 56 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 8b
8e :2 27 96 99 :2 27 a5 a8 af
b8 bb :2 a8 :2 27 :2 10 5c :2 d :2 a
:4 16 :2 a 7 :3 35 b :2 14 1f 1d
:2 28 :2 1d a d :2 17 29 :2 33 3f
43 53 55 56 :2 53 :2 29 :3 d :2 13
18 24 62 65 :2 24 72 75 :2 24
79 7c :2 24 86 89 92 9a :2 a3
:2 92 b6 :2 89 :2 24 be c1 :2 24 c9
cc :2 24 d1 d4 :2 24 df e2 :2 24
:2 d 59 :2 a d :2 17 29 :2 33 3f
42 52 54 55 :2 52 :2 29 :3 d :2 13
18 24 62 65 :2 24 :2 d 58 :3 a
:2 15 29 :2 32 44 50 :2 a 38 :3 7
10 :2 7 17 :2 20 7 35 7 10
:2 7 17 :2 20 7 :5 4 10 4 e
1a 28 38 42 4f c 1b 28
:2 7 :2 10 1c 7 4 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
53 56 57 :2 53 :2 29 :3 d :2 13 18
24 63 66 :2 24 73 76 :2 24 7a
7d :2 24 89 8c :2 24 94 97 :2 24
a3 a6 ad b6 b9 :2 a6 :2 24 :2 d
5a :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a :2 7 16 :2 7
14 1b 28 2b :2 14 7 11 1a
1e 35 f 10 1b 2c 34 :2 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
66 69 :2 27 76 79 :2 27 7d 80
:2 27 8c 8f :2 27 97 9a :2 27 a6
a9 b0 b9 bc :2 a9 :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 35 11 1c
29 34 41 4c 59 64 71 7c
89 8f 93 a9 af b2 c8 ce
d6 ed f 20 24 35 10 13
20 2e 32 3f 42 :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8c
8f :2 27 97 9a :2 27 a6 a9 b0
b9 bc :2 a9 :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 35 b :2 14 1f 1d
:2 28 :2 1d a d :2 17 29 :2 33 3f
43 53 56 57 :2 53 :2 29 :3 d :2 13
18 24 63 66 :2 24 73 76 :2 24
7a 7d :2 24 87 8a 93 9b :2 a4
:2 93 b7 :2 8a :2 24 bf c2 :2 24 ca
cd :2 24 d2 d5 :2 24 de e1 :2 24
:2 d 5a :2 a d :2 17 29 :2 33 3f
42 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 63 66 :2 24 :2 d 59 :3 a
:2 15 29 :2 32 44 4e :2 a 38 :2 7
16 1f 2a 35 3d 4a 11 1b
29 34 3e a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 35 b :2 14 20
1d :2 29 :2 1d a d :2 17 29 :2 33
3f 43 53 56 57 :2 53 :2 29 :3 d
:2 13 18 24 63 66 :2 24 73 76
:2 24 7a 7d :2 24 87 8a 93 9b
:2 a4 :2 93 af :2 8a :2 24 b7 ba :2 24
c2 c5 :2 24 ca cd :2 24 d7 da
:2 24 :2 d 5a :2 a d :2 17 29 :2 33
3f 42 52 55 56 :2 52 :2 29 :3 d
:2 13 18 24 63 66 :2 24 :2 d 59
:3 a :2 15 29 :2 32 3c 47 :2 a 39
:2 7 4 35 b :2 14 1f 1d :2 28
:2 1d :2 a 1b 24 2c :2 1b :2 a 30
33 :2 30 14 16 2d 12 27 13
15 22 11 13 21 11 13 :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 59
5c 5d :2 59 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a 79 7c :2 2a 80 83
:2 2a 8f 92 :2 2a 9a 9d :2 2a a9
ac b3 bc bf :2 ac :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 35 e :2 17
22 20 :2 2b :2 20 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8a 8d 96
9e :2 a7 :2 96 c1 :2 8d :2 27 c9 cc
:2 27 d4 d7 :2 27 dc df :2 27 e9
ec :2 27 :2 10 5d :2 d 10 :2 1a 2c
:2 36 42 45 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 :2 10
5c :3 d :2 18 2c :2 35 4e 59 :2 d
3b :2 a 35 :2 7 a 11 1f 22
:2 a 25 27 :2 25 14 21 38 45
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5c 5d :2 59 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :4 2b :2 7 38 35 a :2 14 26
:2 30 3c 40 50 53 54 :2 50 :2 26
:3 a :2 10 15 21 60 63 :2 21 70
73 :2 21 77 7a :2 21 84 87 90
98 :2 a1 :2 90 b4 :2 87 :2 21 bc bf
:2 21 c7 ca :2 21 cf d2 :2 21 dc
df :2 21 :2 a 57 :2 7 a :2 14 26
:2 30 3c 3f 4f 52 53 :2 4f :2 26
:3 a :2 10 15 21 60 63 :2 21 :2 a
56 :3 7 :2 12 26 :2 2f 41 4c :2 7
:5 4 11 4 e 25 c d 1a
b 19 b :2 7 :2 10 1c 7 4
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 53 56 57 :2 53 :2 29
:3 d :2 13 18 24 63 66 :2 24 73
76 :2 24 7a 7d :2 24 89 8c :2 24
94 97 :2 24 a3 a6 ad b6 b9
:2 a6 :2 24 :2 d 5a :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 a 13 1a :2 a 1d 1f :2 1d
14 20 12 19 27 44 12 19
28 2f 49 12 22 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5c 5d :2 59 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8f 92 :2 2a 9a
9d :2 2a a9 ac b3 bc bf :2 ac
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:3 21 7 21 d 16 1d :2 d 20
22 :2 20 14 20 12 19 27 44
12 19 28 2f 49 12 22 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 59 5c 5d :2 59
:2 2f :3 13 :2 19 1e 2a 69 6c :2 2a
79 7c :2 2a 80 83 :2 2a 8f 92
:2 2a 9a 9d :2 2a a9 ac b3 bc
bf :2 ac :2 2a :2 13 60 :2 10 :2 d :4 19
:2 d a :4 24 21 :3 7 :3 15 :2 7 1a
28 31 3f :2 28 43 4c 54 :2 43
24 :2 2d 42 :2 1a 7 a 18 21
29 :2 18 :2 a 2d 30 :2 2d a 20
:2 29 a 32 a 20 :2 29 a :5 7
1a :2 7 19 :2 7 1a 31 3f 49
51 2d 41 52 :2 1a 7 16 2b
3e 4a 56 a 19 26 33 40
4a 57 12 1e 2b 37 f 19
2d 41 4e 5b a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
66 69 :2 27 76 79 :2 27 7d 80
:2 27 8c 8f :2 27 97 9a :2 27 a6
a9 b0 b9 bc :2 a9 :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 35 4 35
b :2 14 1f 1d :2 28 :2 1d a 11
2a 38 41 48 55 5e 10 24
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 38 7 1a 30 :2 1a 7 38
35 :2 4 7 :2 11 23 :2 2d 39 3c
4c 4f 50 :2 4c :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e 6d 70 :2 1e 74
77 :2 1e 81 84 8d 95 :2 9e :2 8d
a9 :2 84 :2 1e b1 b4 :2 1e bc bf
:2 1e c4 c7 :2 1e d2 d5 :2 1e :2 7
53 :3 4 :2 f 21 :2 2a 34 40 :2 4
1 9 12 9 a :2 14 26 :2 30
3c 40 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 60 63 :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 57 :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 4d 50 51 :2 4d :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
54 :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
add
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:7 c :7 d :7 e :7 f
:6 10 :6 11 :6 12 :6 13
:6 14 :7 15 :6 16 :7 17
:6 18 :6 19 :7 1b :b 1d
:11 1e 1f :2 1e :2 1f
:2 1e :2 1f :2 1e :2 20
:2 1e :2 20 :2 1e :2 20
:2 1e :2 20 :2 1e :2 21
:2 1e :2 21 :2 1e :2 21
:2 1e :2 21 :2 1e :2 22
:2 1e :2 22 :2 1e :2 22
:2 1e :2 22 :2 1e :2 22
:4 1e :3 1d :11 25 :b 26
:3 25 :16 2b :11 2c :20 2d
:3 2c :11 2f :b 30 :3 2f
:9 32 :3 2b :8 36 :5 37
35 :2 39 :5 3b :11 3c
:24 3d :3 3c :2 3a :6 39
38 :3 1c :a 42 :8 44
:5 45 43 :2 47 :5 49
:11 4a :24 4b :3 4a :2 48
:6 47 46 :3 42 :a 50
:11 51 :30 52 :3 51 :11 54
:b 55 :3 54 :a 57 :3 50
:3 59 :5 5a 42 :3 5c
:5 5d 5b :3 42 :3 60
:6 64 :3 65 64 :5 66
63 :2 68 :5 6a :11 6b
:24 6c :3 6b :2 69 :6 68
67 :3 1c :a 71 :3 72
:8 74 :4 77 78 :4 79
77 :5 7a 76 :2 7c
:5 7e :11 7f :24 80 :3 7f
:2 7d :6 7c 7b :3 71
:14 86 :4 87 :7 88 86
:5 89 85 :2 8b :5 8d
:11 8e :24 8f :3 8e :2 8c
:6 8b 8a :3 71 :a 94
:11 95 :30 96 :3 95 :11 98
:b 99 :3 98 :a 9b :3 94
:6 9f :5 a0 9f :6 a1
:5 a2 a1 :5 a4 a3
:3 a1 9e :2 a7 :5 a9
:11 aa :24 ab :3 aa :2 a8
:6 a7 a6 :3 71 :a b0
:11 b1 :30 b2 :3 b1 :11 b4
:b b5 :3 b4 :a b7 :3 b0
b9 71 :a b9 :c ba
:3 bc :2 bd :3 be :3 bf
:2 c0 bc :5 c1 bb
:2 c3 :5 c5 :11 c6 :24 c7
:3 c6 :2 c4 :6 c3 c2
:3 ba :a cc :11 cd :30 ce
:3 cd :11 d0 :b d1 :3 d0
:a d3 :3 cc :3 ba :a d7
:5 d9 :6 da :5 db da
:5 dd dc :3 da d8
:2 e0 :5 e2 :11 e3 :24 e4
:3 e3 :2 e1 :6 e0 df
:6 d7 b9 71 :11 ea
:30 eb :3 ea :11 ed :b ee
:3 ed :a f0 e9 :3 71
:3 f3 :2 f5 f6 :2 f7
:2 f8 f9 f5 :5 fa
f4 :2 fc :5 fe :11 ff
:24 100 :3 ff :2 fd :6 fc
fb :3 1c :a 106 :9 107
:2 109 :4 10b :5 10e :2 10f
:2 112 109 :6 113 :5 114
113 :5 116 115 :3 113
108 :2 119 :5 11b :11 11c
:24 11d :3 11c :2 11a :6 119
118 :3 107 121 107
:9 121 :2 123 :4 125 :5 128
:2 129 :2 12c 123 :6 12d
:5 12e 12d :5 130 12f
:3 12d 122 :2 133 :5 135
:11 136 :24 137 :3 136 :2 134
:6 133 132 :4 121 :3 107
:5 13e :c 13f :4 140 :3 13f
:c 142 :5 143 142 :5 145
144 :3 142 :3 148 :3 149
:6 14b :3 14c :3 14b :5 14f
:7 150 :4 151 :6 152 14f
:6 153 :5 154 153 :5 156
155 :3 153 14e :2 159
:5 15b :11 15c :24 15d :3 15c
:2 15a :6 159 158 :3 106
162 106 :a 162 :7 164
:2 165 164 :6 166 :5 167
166 :5 169 168 :3 166
163 :2 16c :5 16e :11 16f
:24 170 :3 16f :2 16d :6 16c
16b :3 162 :6 175 162
:3 106 :11 178 :30 179 :3 178
:a 17b 1c :3 17e :11 17f
:b 180 :17 181 :3 17f :2 183
:3 184 :3 185 186 184
183 184 :3 187 :3 17e
:2 188 :5 18a :11 18b :b 18c
:18 18d :3 18b :2 18f 190
:3 191 192 190 18f
190 :3 193 :2 189 :6 188
17d :7 1 
262b
4
:3 0 1 :3 0 2
:a 0 ad8 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 15 16 0
b 4 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :3 0
a :2 0 4 13
17 0 ad8 2
18 :2 0 c :2 0
12 4 :3 0 c
:2 0 10 1b 1d
:6 0 20 1e 0
ad6 0 b :6 0
c :2 0 16 4
:3 0 14 22 24
:6 0 27 25 0
ad6 0 d :6 0
10 :2 0 1a 4
:3 0 18 29 2b
:6 0 2e 2c 0
ad6 0 e :6 0
c :2 0 1e 4
:3 0 1c 30 32
:6 0 35 33 0
ad6 0 f :6 0
13 :2 0 22 4
:3 0 20 37 39
:6 0 3c 3a 0
ad6 0 11 :6 0
15 :2 0 26 4
:3 0 24 3e 40
:6 0 43 41 0
ad6 0 12 :6 0
18 :2 0 2a 4
:3 0 28 45 47
:6 0 4a 48 0
ad6 0 14 :6 0
18 :2 0 2c 17
:3 0 4c :7 0 50
4d 4e ad6 0
16 :6 0 18 :2 0
2e 17 :3 0 52
:7 0 56 53 54
ad6 0 19 :6 0
18 :2 0 30 17
:3 0 58 :7 0 5c
59 5a ad6 0
1a :6 0 18 :2 0
32 17 :3 0 5e
:7 0 62 5f 60
ad6 0 1b :6 0
c :2 0 34 17
:3 0 64 :7 0 68
65 66 ad6 0
1c :6 0 18 :2 0
38 4 :3 0 36
6a 6c :6 0 6f
6d 0 ad6 0
1d :6 0 13 :2 0
3a 17 :3 0 71
:7 0 75 72 73
ad6 0 1e :6 0
18 :2 0 3e 4
:3 0 3c 77 79
:6 0 7c 7a 0
ad6 0 1f :6 0
18 :2 0 40 17
:3 0 7e :7 0 82
7f 80 ad6 0
20 :6 0 8a 8b
0 42 17 :3 0
84 :7 0 88 85
86 ad6 0 21
:6 0 90 91 0
44 9 :3 0 a
:2 0 4 8c :7 0
8f 8d 0 ad6
0 22 :6 0 23
:3 0 24 :3 0 23
:3 0 25 :3 0 93
94 0 2 :4 0
46 95 97 92
99 98 :2 0 26
:3 0 27 :3 0 9b
9c 0 28 :4 0
23 :3 0 29 :3 0
9f a0 0 2
:4 0 48 a1 a3
2a :4 0 2b :2 0
2c :3 0 4a a6
a8 :3 0 2d :4 0
2b :2 0 2e :4 0
4d ab ad :3 0
2b :2 0 3 :3 0
50 af b1 :3 0
2b :2 0 2e :4 0
53 b3 b5 :3 0
2b :2 0 2f :4 0
56 b7 b9 :3 0
2b :2 0 2e :4 0
59 bb bd :3 0
2b :2 0 5 :3 0
5c bf c1 :3 0
2b :2 0 2e :4 0
5f c3 c5 :3 0
2b :2 0 2f :4 0
62 c7 c9 :3 0
2b :2 0 2e :4 0
65 cb cd :3 0
2b :2 0 6 :3 0
68 cf d1 :3 0
2b :2 0 2e :4 0
6b d3 d5 :3 0
2b :2 0 2f :4 0
6e d7 d9 :3 0
2b :2 0 2e :4 0
71 db dd :3 0
2b :2 0 7 :3 0
74 df e1 :3 0
2b :2 0 2e :4 0
77 e3 e5 :3 0
2b :2 0 30 :4 0
7a e7 e9 :3 0
7d 9d eb :2 0
ed 82 ee 9a
ed 0 ef 84
0 a36 23 :3 0
24 :3 0 f0 f1
0 23 :3 0 31
:3 0 f3 f4 0
13 :2 0 2 :4 0
32 :2 0 33 :2 0
13 :2 0 86 f9
fb :3 0 89 f5
fd f2 ff fe
:2 0 26 :3 0 34
:3 0 101 102 0
28 :4 0 35 :4 0
2b :2 0 2c :3 0
8d 106 108 :3 0
90 103 10a :2 0
10c 93 10d 100
10c 0 10e 95
0 a36 3 :3 0
36 :2 0 97 110
111 :3 0 112 :2 0
113 :2 0 5 :3 0
36 :2 0 99 116
117 :3 0 118 :2 0
119 :2 0 114 11b
11a :2 0 6 :3 0
36 :2 0 9b 11e
11f :3 0 120 :2 0
121 :2 0 11c 123
122 :2 0 23 :3 0
24 :3 0 125 126
0 23 :3 0 31
:3 0 128 129 0
37 :2 0 2 :4 0
38 :2 0 33 :2 0
13 :2 0 9d 12e
130 :3 0 a0 12a
132 127 134 133
:2 0 26 :3 0 34
:3 0 136 137 0
28 :4 0 39 :4 0
2b :2 0 2c :3 0
a4 13b 13d :3 0
2b :2 0 3a :4 0
a7 13f 141 :3 0
2b :2 0 3b :4 0
aa 143 145 :3 0
2b :2 0 3c :3 0
3d :3 0 3e :3 0
3f :3 0 14a 14b
0 ad 149 14d
40 :4 0 af 148
150 b2 147 152
:3 0 b5 138 154
:2 0 156 b8 157
135 156 0 158
ba 0 181 23
:3 0 24 :3 0 159
15a 0 23 :3 0
31 :3 0 15c 15d
0 13 :2 0 2
:4 0 41 :2 0 33
:2 0 13 :2 0 bc
162 164 :3 0 bf
15e 166 15b 168
167 :2 0 26 :3 0
34 :3 0 16a 16b
0 28 :4 0 42
:4 0 2b :2 0 2c
:3 0 c3 16f 171
:3 0 c6 16c 173
:2 0 175 c9 176
169 175 0 177
cb 0 181 43
:3 0 44 :3 0 178
179 0 3e :3 0
3f :3 0 17b 17c
0 45 :3 0 cd
17a 17f :2 0 181
d0 182 124 181
0 183 d4 0
a36 46 :3 0 47
:3 0 d :3 0 16
:3 0 48 :3 0 49
:3 0 3 :4 0 4a
1 :8 0 191 9
:3 0 4b :3 0 18c
18d 0 4c :3 0
18e 18f 0 191
d6 1db 4d :3 0
9 :3 0 4b :3 0
194 195 0 4c
:3 0 196 197 0
1d1 23 :3 0 24
:3 0 199 19a 0
23 :3 0 31 :3 0
19c 19d 0 4e
:2 0 2 :4 0 4f
:2 0 33 :2 0 13
:2 0 d9 1a2 1a4
:3 0 dc 19e 1a6
19b 1a8 1a7 :2 0
26 :3 0 34 :3 0
1aa 1ab 0 28
:4 0 50 :4 0 2b
:2 0 2c :3 0 e0
1af 1b1 :3 0 2b
:2 0 3a :4 0 e3
1b3 1b5 :3 0 2b
:2 0 51 :4 0 e6
1b7 1b9 :3 0 2b
:2 0 4c :3 0 e9
1bb 1bd :3 0 2b
:2 0 52 :4 0 ec
1bf 1c1 :3 0 2b
:2 0 53 :3 0 54
:3 0 13 :2 0 55
:2 0 ef 1c4 1c8
f3 1c3 1ca :3 0
f6 1ac 1cc :2 0
1ce f9 1cf 1a9
1ce 0 1d0 fb
0 1d1 fd 1d4
:3 0 1d4 0 1d4
1d3 1d1 1d2 :6 0
1d6 2 :3 0 100
1d8 102 1d7 1d6
:2 0 1d9 104 :2 0
1db 0 1db 1da
191 1d9 :6 0 a36
1 :3 0 9 :3 0
4b :3 0 1dd 1de
0 9 :3 0 56
:2 0 57 :3 0 1e0
1e2 0 108 1e1
1e4 :3 0 1e5 :2 0
46 :3 0 47 :3 0
d :3 0 16 :3 0
58 :3 0 49 :3 0
3 :4 0 59 1
:8 0 1f4 9 :3 0
4b :3 0 1ef 1f0
0 4c :3 0 1f1
1f2 0 1f4 10b
23e 4d :3 0 9
:3 0 4b :3 0 1f7
1f8 0 4c :3 0
1f9 1fa 0 234
23 :3 0 24 :3 0
1fc 1fd 0 23
:3 0 31 :3 0 1ff
200 0 4e :2 0
2 :4 0 5a :2 0
33 :2 0 13 :2 0
10e 205 207 :3 0
111 201 209 1fe
20b 20a :2 0 26
:3 0 34 :3 0 20d
20e 0 28 :4 0
5b :4 0 2b :2 0
2c :3 0 115 212
214 :3 0 2b :2 0
3a :4 0 118 216
218 :3 0 2b :2 0
51 :4 0 11b 21a
21c :3 0 2b :2 0
4c :3 0 11e 21e
220 :3 0 2b :2 0
52 :4 0 121 222
224 :3 0 2b :2 0
53 :3 0 54 :3 0
13 :2 0 55 :2 0
124 227 22b 128
226 22d :3 0 12b
20f 22f :2 0 231
12e 232 20c 231
0 233 130 0
234 132 237 :3 0
237 0 237 236
234 235 :6 0 239
4 :3 0 135 23b
137 23a 239 :2 0
23c 139 :2 0 23e
0 23e 23d 1f4
23c :6 0 2c2 1
:3 0 9 :3 0 4b
:3 0 240 241 0
9 :3 0 56 :2 0
57 :3 0 243 245
0 13d 244 247
:3 0 248 :2 0 23
:3 0 24 :3 0 24a
24b 0 23 :3 0
31 :3 0 24d 24e
0 c :2 0 2
:4 0 5c :2 0 33
:2 0 13 :2 0 140
253 255 :3 0 143
24f 257 24c 259
258 :2 0 26 :3 0
34 :3 0 25b 25c
0 28 :4 0 5d
:4 0 2b :2 0 2c
:3 0 147 260 262
:3 0 2b :2 0 3a
:4 0 14a 264 266
:3 0 2b :2 0 3b
:4 0 14d 268 26a
:3 0 2b :2 0 3c
:3 0 3d :3 0 3e
:3 0 5e :3 0 26f
270 0 150 26e
272 40 :4 0 152
26d 275 155 26c
277 :3 0 2b :2 0
5f :4 0 158 279
27b :3 0 2b :2 0
2e :4 0 15b 27d
27f :3 0 2b :2 0
3 :3 0 15e 281
283 :3 0 2b :2 0
2e :4 0 161 285
287 :3 0 164 25d
289 :2 0 28b 167
28c 25a 28b 0
28d 169 0 2b7
23 :3 0 24 :3 0
28e 28f 0 23
:3 0 31 :3 0 291
292 0 13 :2 0
2 :4 0 60 :2 0
33 :2 0 13 :2 0
16b 297 299 :3 0
16e 293 29b 290
29d 29c :2 0 26
:3 0 34 :3 0 29f
2a0 0 28 :4 0
61 :4 0 2b :2 0
2c :3 0 172 2a4
2a6 :3 0 175 2a1
2a8 :2 0 2aa 178
2ab 29e 2aa 0
2ac 17a 0 2b7
43 :3 0 62 :3 0
2ad 2ae 0 3e
:3 0 5e :3 0 2b0
2b1 0 3 :3 0
45 :3 0 17c 2af
2b5 :2 0 2b7 180
2b8 249 2b7 0
2b9 184 0 2c2
19 :3 0 13 :2 0
2ba 2bb 0 2c2
21 :3 0 3e :3 0
63 :3 0 2be 2bf
0 2bd 2c0 0
2c2 186 2cc 19
:3 0 18 :2 0 2c3
2c4 0 2cb 21
:3 0 3e :3 0 64
:3 0 2c7 2c8 0
2c6 2c9 0 2cb
18b 2cd 1e6 2c2
0 2ce 0 2cb
0 2ce 18e 0
a36 e :3 0 5
:3 0 2cf 2d0 0
a36 65 :3 0 66
:3 0 67 :3 0 e
:3 0 14 :3 0 12
:3 0 68 :3 0 65
:3 0 e :4 0 69
1 :8 0 2e1 9
:3 0 4b :3 0 2dc
2dd 0 4c :3 0
2de 2df 0 2e1
191 32b 4d :3 0
9 :3 0 4b :3 0
2e4 2e5 0 4c
:3 0 2e6 2e7 0
321 23 :3 0 24
:3 0 2e9 2ea 0
23 :3 0 31 :3 0
2ec 2ed 0 4e
:2 0 2 :4 0 6a
:2 0 33 :2 0 13
:2 0 194 2f2 2f4
:3 0 197 2ee 2f6
2eb 2f8 2f7 :2 0
26 :3 0 34 :3 0
2fa 2fb 0 28
:4 0 6b :4 0 2b
:2 0 2c :3 0 19b
2ff 301 :3 0 2b
:2 0 3a :4 0 19e
303 305 :3 0 2b
:2 0 51 :4 0 1a1
307 309 :3 0 2b
:2 0 4c :3 0 1a4
30b 30d :3 0 2b
:2 0 52 :4 0 1a7
30f 311 :3 0 2b
:2 0 53 :3 0 54
:3 0 13 :2 0 55
:2 0 1aa 314 318
1ae 313 31a :3 0
1b1 2fc 31c :2 0
31e 1b4 31f 2f9
31e 0 320 1b6
0 321 1b8 324
:3 0 324 0 324
323 321 322 :6 0
326 6 :3 0 1bb
328 1bd 327 326
:2 0 329 1bf :2 0
32b 0 32b 32a
2e1 329 :6 0 a36
1 :3 0 9 :3 0
4b :3 0 32d 32e
0 9 :3 0 56
:2 0 57 :3 0 330
332 0 1c3 331
334 :3 0 335 :2 0
f :3 0 6 :3 0
337 338 0 570
11 :3 0 53 :3 0
f :3 0 13 :2 0
c :2 0 1c6 33b
33f 33a 340 0
570 3c :3 0 6c
:3 0 6d :3 0 1b
:3 0 68 :3 0 46
:3 0 d :3 0 6e
:3 0 11 :4 0 6f
1 :8 0 351 9
:3 0 4b :3 0 34c
34d 0 4c :3 0
34e 34f 0 351
1ca 39b 4d :3 0
9 :3 0 4b :3 0
354 355 0 4c
:3 0 356 357 0
391 23 :3 0 24
:3 0 359 35a 0
23 :3 0 31 :3 0
35c 35d 0 4e
:2 0 2 :4 0 70
:2 0 33 :2 0 13
:2 0 1cd 362 364
:3 0 1d0 35e 366
35b 368 367 :2 0
26 :3 0 34 :3 0
36a 36b 0 28
:4 0 71 :4 0 2b
:2 0 2c :3 0 1d4
36f 371 :3 0 2b
:2 0 3a :4 0 1d7
373 375 :3 0 2b
:2 0 51 :4 0 1da
377 379 :3 0 2b
:2 0 4c :3 0 1dd
37b 37d :3 0 2b
:2 0 52 :4 0 1e0
37f 381 :3 0 2b
:2 0 53 :3 0 54
:3 0 13 :2 0 55
:2 0 1e3 384 388
1e7 383 38a :3 0
1ea 36c 38c :2 0
38e 1ed 38f 369
38e 0 390 1ef
0 391 1f1 394
:3 0 394 0 394
393 391 392 :6 0
396 8 :3 0 1f4
398 1f6 397 396
:2 0 399 1f8 :2 0
39b 0 39b 39a
351 399 :6 0 570
1 :3 0 72 :3 0
73 :3 0 72 :3 0
73 :3 0 72 :3 0
73 :3 0 72 :3 0
73 :3 0 72 :3 0
73 :3 0 74 :3 0
75 :3 0 76 :3 0
74 :3 0 77 :3 0
76 :3 0 74 :3 0
3d :3 0 1b :3 0
14 :3 0 78 :3 0
77 :3 0 78 :3 0
75 :3 0 77 :3 0
49 :3 0 11 :3 0
75 :3 0 49 :3 0
77 :3 0 79 :4 0
7a 1 :8 0 3c2
9 :3 0 4b :3 0
3bd 3be 0 4c
:3 0 3bf 3c0 0
3c2 1fa 40c 4d
:3 0 9 :3 0 4b
:3 0 3c5 3c6 0
4c :3 0 3c7 3c8
0 402 23 :3 0
24 :3 0 3ca 3cb
0 23 :3 0 31
:3 0 3cd 3ce 0
4e :2 0 2 :4 0
7b :2 0 33 :2 0
13 :2 0 1fd 3d3
3d5 :3 0 200 3cf
3d7 3cc 3d9 3d8
:2 0 26 :3 0 34
:3 0 3db 3dc 0
28 :4 0 7c :4 0
2b :2 0 2c :3 0
204 3e0 3e2 :3 0
2b :2 0 3a :4 0
207 3e4 3e6 :3 0
2b :2 0 51 :4 0
20a 3e8 3ea :3 0
2b :2 0 4c :3 0
20d 3ec 3ee :3 0
2b :2 0 52 :4 0
210 3f0 3f2 :3 0
2b :2 0 53 :3 0
54 :3 0 13 :2 0
55 :2 0 213 3f5
3f9 217 3f4 3fb
:3 0 21a 3dd 3fd
:2 0 3ff 21d 400
3da 3ff 0 401
21f 0 402 221
405 :3 0 405 0
405 404 402 403
:6 0 407 a :3 0
224 409 226 408
407 :2 0 40a 228
:2 0 40c 0 40c
40b 3c2 40a :6 0
570 1 :3 0 9
:3 0 4b :3 0 40e
40f 0 9 :3 0
56 :2 0 57 :3 0
411 413 0 22c
412 415 :3 0 416
:2 0 23 :3 0 24
:3 0 418 419 0
23 :3 0 31 :3 0
41b 41c 0 c
:2 0 2 :4 0 7d
:2 0 33 :2 0 13
:2 0 22f 421 423
:3 0 232 41d 425
41a 427 426 :2 0
26 :3 0 34 :3 0
429 42a 0 28
:4 0 7e :4 0 2b
:2 0 2c :3 0 236
42e 430 :3 0 2b
:2 0 3a :4 0 239
432 434 :3 0 2b
:2 0 3b :4 0 23c
436 438 :3 0 2b
:2 0 3c :3 0 3d
:3 0 3e :3 0 5e
:3 0 43d 43e 0
23f 43c 440 40
:4 0 241 43b 443
244 43a 445 :3 0
2b :2 0 5f :4 0
247 447 449 :3 0
2b :2 0 2e :4 0
24a 44b 44d :3 0
2b :2 0 e :3 0
24d 44f 451 :3 0
2b :2 0 2e :4 0
250 453 455 :3 0
253 42b 457 :2 0
459 256 45a 428
459 0 45b 258
0 485 23 :3 0
24 :3 0 45c 45d
0 23 :3 0 31
:3 0 45f 460 0
13 :2 0 2 :4 0
7f :2 0 33 :2 0
13 :2 0 25a 465
467 :3 0 25d 461
469 45e 46b 46a
:2 0 26 :3 0 34
:3 0 46d 46e 0
28 :4 0 80 :4 0
2b :2 0 2c :3 0
261 472 474 :3 0
264 46f 476 :2 0
478 267 479 46c
478 0 47a 269
0 485 43 :3 0
62 :3 0 47b 47c
0 3e :3 0 5e
:3 0 47e 47f 0
e :3 0 45 :3 0
26b 47d 483 :2 0
485 26f 486 417
485 0 487 273
0 570 68 :3 0
65 :3 0 46 :3 0
6e :3 0 6d :3 0
66 :3 0 e :3 0
d :3 0 11 :3 0
1b :3 0 14 :4 0
81 1 :8 0 4a9
82 :4 0 494 :3 0
45 :3 0 56 :2 0
277 497 498 :3 0
9 :3 0 4b :3 0
49a 49b 0 18
:2 0 49c 49d 0
49f 27a 4a6 9
:3 0 4b :3 0 4a0
4a1 0 83 :2 0
4a2 4a3 0 4a5
27c 4a7 499 49f
0 4a8 0 4a5
0 4a8 27e 0
4a9 281 4f3 4d
:3 0 9 :3 0 4b
:3 0 4ac 4ad 0
4c :3 0 4ae 4af
0 4e9 23 :3 0
24 :3 0 4b1 4b2
0 23 :3 0 31
:3 0 4b4 4b5 0
4e :2 0 2 :4 0
84 :2 0 33 :2 0
13 :2 0 284 4ba
4bc :3 0 287 4b6
4be 4b3 4c0 4bf
:2 0 26 :3 0 34
:3 0 4c2 4c3 0
28 :4 0 85 :4 0
2b :2 0 2c :3 0
28b 4c7 4c9 :3 0
2b :2 0 3a :4 0
28e 4cb 4cd :3 0
2b :2 0 51 :4 0
291 4cf 4d1 :3 0
2b :2 0 4c :3 0
294 4d3 4d5 :3 0
2b :2 0 52 :4 0
297 4d7 4d9 :3 0
2b :2 0 53 :3 0
54 :3 0 13 :2 0
55 :2 0 29a 4dc
4e0 29e 4db 4e2
:3 0 2a1 4c4 4e4
:2 0 4e6 2a4 4e7
4c1 4e6 0 4e8
2a6 0 4e9 2a8
4ec :3 0 4ec 0
4ec 4eb 4e9 4ea
:6 0 4ee c :3 0
2ab 4f0 2ad 4ef
4ee :2 0 4f1 2af
:2 0 4f3 0 4f3
4f2 4a9 4f1 :6 0
570 1 :3 0 9
:3 0 4b :3 0 4f5
4f6 0 9 :3 0
86 :2 0 87 :3 0
4f8 4fa 0 2b3
4f9 4fc :3 0 4fd
:2 0 23 :3 0 24
:3 0 4ff 500 0
23 :3 0 31 :3 0
502 503 0 c
:2 0 2 :4 0 88
:2 0 33 :2 0 13
:2 0 2b6 508 50a
:3 0 2b9 504 50c
501 50e 50d :2 0
26 :3 0 34 :3 0
510 511 0 28
:4 0 89 :4 0 2b
:2 0 2c :3 0 2bd
515 517 :3 0 2b
:2 0 3a :4 0 2c0
519 51b :3 0 2b
:2 0 3b :4 0 2c3
51d 51f :3 0 2b
:2 0 3c :3 0 3d
:3 0 9 :3 0 4b
:3 0 524 525 0
2c6 523 527 40
:4 0 2c8 522 52a
2cb 521 52c :3 0
2b :2 0 5f :4 0
2ce 52e 530 :3 0
2b :2 0 2e :4 0
2d1 532 534 :3 0
2b :2 0 5 :3 0
2d4 536 538 :3 0
2b :2 0 2e :4 0
2d7 53a 53c :3 0
2da 512 53e :2 0
540 2dd 541 50f
540 0 542 2df
0 56c 23 :3 0
24 :3 0 543 544
0 23 :3 0 31
:3 0 546 547 0
13 :2 0 2 :4 0
8a :2 0 33 :2 0
13 :2 0 2e1 54c
54e :3 0 2e4 548
550 545 552 551
:2 0 26 :3 0 34
:3 0 554 555 0
28 :4 0 8b :4 0
2b :2 0 2c :3 0
2e8 559 55b :3 0
2eb 556 55d :2 0
55f 2ee 560 553
55f 0 561 2f0
0 56c 43 :3 0
62 :3 0 562 563
0 9 :3 0 4b
:3 0 565 566 0
5 :3 0 45 :3 0
2f2 564 56a :2 0
56c 2f6 56d 4fe
56c 0 56e 2fa
0 570 8c :3 0
2fc 746 9 :3 0
4b :3 0 571 572
0 9 :3 0 56
:2 0 87 :3 0 574
576 0 306 575
578 :3 0 579 :2 0
8d :3 0 3c :3 0
16 :3 0 18 :2 0
309 57c 57f 30c
57b 581 86 :2 0
18 :2 0 310 583
585 :3 0 8e :3 0
8f :3 0 b :3 0
90 :3 0 8e :3 0
8e :3 0 49 :3 0
3 :3 0 8e :3 0
91 :3 0 5 :3 0
8e :3 0 92 :4 0
93 1 :8 0 59a
9 :3 0 4b :3 0
595 596 0 4c
:3 0 597 598 0
59a 313 5e4 4d
:3 0 9 :3 0 4b
:3 0 59d 59e 0
4c :3 0 59f 5a0
0 5da 23 :3 0
24 :3 0 5a2 5a3
0 23 :3 0 31
:3 0 5a5 5a6 0
4e :2 0 2 :4 0
94 :2 0 33 :2 0
13 :2 0 316 5ab
5ad :3 0 319 5a7
5af 5a4 5b1 5b0
:2 0 26 :3 0 34
:3 0 5b3 5b4 0
28 :4 0 95 :4 0
2b :2 0 2c :3 0
31d 5b8 5ba :3 0
2b :2 0 3a :4 0
320 5bc 5be :3 0
2b :2 0 51 :4 0
323 5c0 5c2 :3 0
2b :2 0 4c :3 0
326 5c4 5c6 :3 0
2b :2 0 52 :4 0
329 5c8 5ca :3 0
2b :2 0 53 :3 0
54 :3 0 13 :2 0
55 :2 0 32c 5cd
5d1 330 5cc 5d3
:3 0 333 5b5 5d5
:2 0 5d7 336 5d8
5b2 5d7 0 5d9
338 0 5da 33a
5dd :3 0 5dd 0
5dd 5dc 5da 5db
:6 0 5df e :3 0
33d 5e1 33f 5e0
5df :2 0 5e2 341
:2 0 5e4 0 5e4
5e3 59a 5e2 :6 0
660 1 :3 0 9
:3 0 4b :3 0 5e6
5e7 0 9 :3 0
56 :2 0 87 :3 0
5e9 5eb 0 345
5ea 5ed :3 0 5ee
:2 0 23 :3 0 24
:3 0 5f0 5f1 0
23 :3 0 31 :3 0
5f3 5f4 0 c
:2 0 2 :4 0 96
:2 0 33 :2 0 13
:2 0 348 5f9 5fb
:3 0 34b 5f5 5fd
5f2 5ff 5fe :2 0
26 :3 0 34 :3 0
601 602 0 28
:4 0 97 :4 0 2b
:2 0 2c :3 0 34f
606 608 :3 0 2b
:2 0 3a :4 0 352
60a 60c :3 0 2b
:2 0 3b :4 0 355
60e 610 :3 0 2b
:2 0 3c :3 0 3d
:3 0 3e :3 0 98
:3 0 615 616 0
358 614 618 40
:4 0 35a 613 61b
35d 612 61d :3 0
2b :2 0 5f :4 0
360 61f 621 :3 0
2b :2 0 2e :4 0
363 623 625 :3 0
2b :2 0 5 :3 0
366 627 629 :3 0
2b :2 0 2e :4 0
369 62b 62d :3 0
36c 603 62f :2 0
631 36f 632 600
631 0 633 371
0 65d 23 :3 0
24 :3 0 634 635
0 23 :3 0 31
:3 0 637 638 0
13 :2 0 2 :4 0
99 :2 0 33 :2 0
13 :2 0 373 63d
63f :3 0 376 639
641 636 643 642
:2 0 26 :3 0 34
:3 0 645 646 0
28 :4 0 9a :4 0
2b :2 0 2c :3 0
37a 64a 64c :3 0
37d 647 64e :2 0
650 380 651 644
650 0 652 382
0 65d 43 :3 0
62 :3 0 653 654
0 3e :3 0 98
:3 0 656 657 0
5 :3 0 45 :3 0
384 655 65b :2 0
65d 388 65e 5ef
65d 0 65f 38c
0 660 38e 661
586 660 0 662
391 0 6d6 53
:3 0 12 :3 0 13
:2 0 13 :2 0 393
663 667 56 :2 0
9b :4 0 399 669
66b :3 0 68 :3 0
67 :3 0 65 :3 0
e :4 0 9c 1
:8 0 687 82 :4 0
672 :3 0 45 :3 0
56 :2 0 39e 675
676 :3 0 9 :3 0
4b :3 0 678 679
0 18 :2 0 67a
67b 0 67d 3a1
684 9 :3 0 4b
:3 0 67e 67f 0
83 :2 0 680 681
0 683 3a3 685
677 67d 0 686
0 683 0 686
3a5 0 687 3a8
6d1 4d :3 0 9
:3 0 4b :3 0 68a
68b 0 4c :3 0
68c 68d 0 6c7
23 :3 0 24 :3 0
68f 690 0 23
:3 0 31 :3 0 692
693 0 4e :2 0
2 :4 0 9d :2 0
33 :2 0 13 :2 0
3ab 698 69a :3 0
3ae 694 69c 691
69e 69d :2 0 26
:3 0 34 :3 0 6a0
6a1 0 28 :4 0
9e :4 0 2b :2 0
2c :3 0 3b2 6a5
6a7 :3 0 2b :2 0
3a :4 0 3b5 6a9
6ab :3 0 2b :2 0
51 :4 0 3b8 6ad
6af :3 0 2b :2 0
4c :3 0 3bb 6b1
6b3 :3 0 2b :2 0
52 :4 0 3be 6b5
6b7 :3 0 2b :2 0
53 :3 0 54 :3 0
13 :2 0 55 :2 0
3c1 6ba 6be 3c5
6b9 6c0 :3 0 3c8
6a2 6c2 :2 0 6c4
3cb 6c5 69f 6c4
0 6c6 3cd 0
6c7 3cf 6ca :3 0
6ca 0 6ca 6c9
6c7 6c8 :6 0 6cc
10 :3 0 3d2 6ce
3d4 6cd 6cc :2 0
6cf 3d6 :2 0 6d1
0 6d1 6d0 687
6cf :6 0 6d3 1
:3 0 3d8 6d4 66c
6d3 0 6d5 3da
0 6d6 3dc 6d7
57a 6d6 0 748
23 :3 0 24 :3 0
6d8 6d9 0 23
:3 0 31 :3 0 6db
6dc 0 c :2 0
2 :4 0 9f :2 0
33 :2 0 13 :2 0
3df 6e1 6e3 :3 0
3e2 6dd 6e5 6da
6e7 6e6 :2 0 26
:3 0 34 :3 0 6e9
6ea 0 28 :4 0
a0 :4 0 2b :2 0
2c :3 0 3e6 6ee
6f0 :3 0 2b :2 0
3a :4 0 3e9 6f2
6f4 :3 0 2b :2 0
3b :4 0 3ec 6f6
6f8 :3 0 2b :2 0
3c :3 0 3d :3 0
3e :3 0 5e :3 0
6fd 6fe 0 3ef
6fc 700 40 :4 0
3f1 6fb 703 3f4
6fa 705 :3 0 2b
:2 0 5f :4 0 3f7
707 709 :3 0 2b
:2 0 2e :4 0 3fa
70b 70d :3 0 2b
:2 0 5 :3 0 3fd
70f 711 :3 0 2b
:2 0 2e :4 0 400
713 715 :3 0 403
6eb 717 :2 0 719
406 71a 6e8 719
0 71b 408 0
745 23 :3 0 24
:3 0 71c 71d 0
23 :3 0 31 :3 0
71f 720 0 13
:2 0 2 :4 0 a1
:2 0 33 :2 0 13
:2 0 40a 725 727
:3 0 40d 721 729
71e 72b 72a :2 0
26 :3 0 34 :3 0
72d 72e 0 28
:4 0 a2 :4 0 2b
:2 0 2c :3 0 411
732 734 :3 0 414
72f 736 :2 0 738
417 739 72c 738
0 73a 419 0
745 43 :3 0 62
:3 0 73b 73c 0
3e :3 0 5e :3 0
73e 73f 0 5
:3 0 45 :3 0 41b
73d 743 :2 0 745
41f 747 336 570
0 748 0 745
0 748 423 0
a36 1a :3 0 18
:2 0 749 74a 0
a36 8f :3 0 b
:3 0 90 :3 0 49
:3 0 3 :3 0 91
:3 0 e :3 0 92
:4 0 a3 1 :8 0
75a 9 :3 0 4b
:3 0 755 756 0
4c :3 0 757 758
0 75a 427 7a4
4d :3 0 9 :3 0
4b :3 0 75d 75e
0 4c :3 0 75f
760 0 79a 23
:3 0 24 :3 0 762
763 0 23 :3 0
31 :3 0 765 766
0 4e :2 0 2
:4 0 15 :2 0 33
:2 0 13 :2 0 42a
76b 76d :3 0 42d
767 76f 764 771
770 :2 0 26 :3 0
34 :3 0 773 774
0 28 :4 0 a4
:4 0 2b :2 0 2c
:3 0 431 778 77a
:3 0 2b :2 0 3a
:4 0 434 77c 77e
:3 0 2b :2 0 51
:4 0 437 780 782
:3 0 2b :2 0 4c
:3 0 43a 784 786
:3 0 2b :2 0 52
:4 0 43d 788 78a
:3 0 2b :2 0 53
:3 0 54 :3 0 13
:2 0 55 :2 0 440
78d 791 444 78c
793 :3 0 447 775
795 :2 0 797 44a
798 772 797 0
799 44c 0 79a
44e 79d :3 0 79d
0 79d 79c 79a
79b :6 0 79f 12
:3 0 451 7a1 453
7a0 79f :2 0 7a2
455 :2 0 7a4 0
7a4 7a3 75a 7a2
:6 0 a36 1 :3 0
9 :3 0 4b :3 0
7a6 7a7 0 9
:3 0 56 :2 0 57
:3 0 7a9 7ab 0
459 7aa 7ad :3 0
7ae :2 0 3c :3 0
19 :3 0 18 :2 0
45c 7b0 7b3 56
:2 0 18 :2 0 461
7b5 7b7 :3 0 48
:3 0 a5 :3 0 a6
:3 0 a5 :3 0 14
:3 0 a5 :3 0 a7
:3 0 14 :3 0 a7
:3 0 a5 :3 0 a5
:3 0 a5 :3 0 14
:3 0 49 :3 0 3
:4 0 a8 1 :8 0
7de 82 :4 0 7c9
:3 0 45 :3 0 56
:2 0 466 7cc 7cd
:3 0 9 :3 0 4b
:3 0 7cf 7d0 0
18 :2 0 7d1 7d2
0 7d4 469 7db
9 :3 0 4b :3 0
7d5 7d6 0 83
:2 0 7d7 7d8 0
7da 46b 7dc 7ce
7d4 0 7dd 0
7da 0 7dd 46d
0 7de 470 828
4d :3 0 9 :3 0
4b :3 0 7e1 7e2
0 4c :3 0 7e3
7e4 0 81e 23
:3 0 24 :3 0 7e6
7e7 0 23 :3 0
31 :3 0 7e9 7ea
0 4e :2 0 2
:4 0 a9 :2 0 33
:2 0 13 :2 0 473
7ef 7f1 :3 0 476
7eb 7f3 7e8 7f5
7f4 :2 0 26 :3 0
34 :3 0 7f7 7f8
0 28 :4 0 aa
:4 0 2b :2 0 2c
:3 0 47a 7fc 7fe
:3 0 2b :2 0 3a
:4 0 47d 800 802
:3 0 2b :2 0 51
:4 0 480 804 806
:3 0 2b :2 0 4c
:3 0 483 808 80a
:3 0 2b :2 0 52
:4 0 486 80c 80e
:3 0 2b :2 0 53
:3 0 54 :3 0 13
:2 0 55 :2 0 489
811 815 48d 810
817 :3 0 490 7f9
819 :2 0 81b 493
81c 7f6 81b 0
81d 495 0 81e
497 821 :3 0 821
0 821 820 81e
81f :6 0 823 14
:3 0 49a 825 49c
824 823 :2 0 826
49e :2 0 828 0
828 827 7de 826
:6 0 82b 1 :3 0
8c :3 0 4a0 8a8
3c :3 0 19 :3 0
18 :2 0 4a2 82c
82f 56 :2 0 13
:2 0 4a7 831 833
:3 0 58 :3 0 a5
:3 0 a6 :3 0 a5
:3 0 14 :3 0 a5
:3 0 a7 :3 0 14
:3 0 a7 :3 0 a5
:3 0 a5 :3 0 a5
:3 0 14 :3 0 49
:3 0 3 :4 0 ab
1 :8 0 85a 82
:4 0 845 :3 0 45
:3 0 56 :2 0 4ac
848 849 :3 0 9
:3 0 4b :3 0 84b
84c 0 18 :2 0
84d 84e 0 850
4af 857 9 :3 0
4b :3 0 851 852
0 83 :2 0 853
854 0 856 4b1
858 84a 850 0
859 0 856 0
859 4b3 0 85a
4b6 8a4 4d :3 0
9 :3 0 4b :3 0
85d 85e 0 4c
:3 0 85f 860 0
89a 23 :3 0 24
:3 0 862 863 0
23 :3 0 31 :3 0
865 866 0 4e
:2 0 2 :4 0 ac
:2 0 33 :2 0 13
:2 0 4b9 86b 86d
:3 0 4bc 867 86f
864 871 870 :2 0
26 :3 0 34 :3 0
873 874 0 28
:4 0 ad :4 0 2b
:2 0 2c :3 0 4c0
878 87a :3 0 2b
:2 0 3a :4 0 4c3
87c 87e :3 0 2b
:2 0 51 :4 0 4c6
880 882 :3 0 2b
:2 0 4c :3 0 4c9
884 886 :3 0 2b
:2 0 52 :4 0 4cc
888 88a :3 0 2b
:2 0 53 :3 0 54
:3 0 13 :2 0 55
:2 0 4cf 88d 891
4d3 88c 893 :3 0
4d6 875 895 :2 0
897 4d9 898 872
897 0 899 4db
0 89a 4dd 89d
:3 0 89d 0 89d
89c 89a 89b :6 0
89f 16 :3 0 4e0
8a1 4e2 8a0 89f
:2 0 8a2 4e4 :2 0
8a4 0 8a4 8a3
85a 8a2 :6 0 8a6
1 :3 0 4e6 8a7
834 8a6 0 8a9
7b8 82b 0 8a9
4e8 0 968 b
:3 0 ae :4 0 8ab
8ac :3 0 8aa 8ad
0 968 20 :3 0
af :3 0 3c :3 0
21 :3 0 18 :2 0
4eb 8b1 8b4 3c
:3 0 16 :3 0 18
:2 0 4ee 8b6 8b9
3e :3 0 b0 :3 0
8bb 8bc 0 1d
:3 0 4f1 8b0 8bf
8af 8c0 0 968
b1 :3 0 3c :3 0
16 :3 0 18 :2 0
4f6 8c3 8c6 4f9
8c2 8c8 86 :2 0
18 :2 0 4fd 8ca
8cc :3 0 1c :3 0
3e :3 0 b2 :3 0
8cf 8d0 0 8ce
8d1 0 8d3 500
8da 1c :3 0 3e
:3 0 b3 :3 0 8d5
8d6 0 8d4 8d7
0 8d9 502 8db
8cd 8d3 0 8dc
0 8d9 0 8dc
504 0 968 1f
:3 0 13 :4 0 8dd
8de 0 968 1e
:3 0 13 :2 0 8e0
8e1 0 968 20
:3 0 b4 :3 0 d
:3 0 e :3 0 16
:3 0 1c :3 0 1d
:3 0 1f :3 0 1e
:3 0 507 8e4 8ec
8e3 8ed 0 968
90 :3 0 8f :3 0
46 :3 0 49 :3 0
b5 :3 0 92 :3 0
91 :3 0 b6 :3 0
b7 :3 0 b8 :3 0
b9 :3 0 ba :3 0
b :3 0 d :3 0
3 :3 0 16 :3 0
e :3 0 1c :3 0
1d :3 0 7 :3 0
2c :3 0 21 :4 0
bb 1 :8 0 91b
82 :4 0 906 :3 0
45 :3 0 56 :2 0
511 909 90a :3 0
9 :3 0 4b :3 0
90c 90d 0 18
:2 0 90e 90f 0
911 514 918 9
:3 0 4b :3 0 912
913 0 83 :2 0
914 915 0 917
516 919 90b 911
0 91a 0 917
0 91a 518 0
91b 51b 965 4d
:3 0 9 :3 0 4b
:3 0 91e 91f 0
4c :3 0 920 921
0 95b 23 :3 0
24 :3 0 923 924
0 23 :3 0 31
:3 0 926 927 0
4e :2 0 2 :4 0
bc :2 0 33 :2 0
13 :2 0 51e 92c
92e :3 0 521 928
930 925 932 931
:2 0 26 :3 0 34
:3 0 934 935 0
28 :4 0 bd :4 0
2b :2 0 2c :3 0
525 939 93b :3 0
2b :2 0 3a :4 0
528 93d 93f :3 0
2b :2 0 51 :4 0
52b 941 943 :3 0
2b :2 0 4c :3 0
52e 945 947 :3 0
2b :2 0 52 :4 0
531 949 94b :3 0
2b :2 0 53 :3 0
54 :3 0 13 :2 0
55 :2 0 534 94e
952 538 94d 954
:3 0 53b 936 956
:2 0 958 53e 959
933 958 0 95a
540 0 95b 542
95e :3 0 95e 0
95e 95d 95b 95c
:6 0 960 18 :3 0
545 962 547 961
960 :2 0 963 549
:2 0 965 0 965
964 91b 963 :6 0
968 1 :3 0 8c
:3 0 54b 9e6 9
:3 0 4b :3 0 969
96a 0 9 :3 0
56 :2 0 87 :3 0
96c 96e 0 556
96d 970 :3 0 971
:2 0 90 :3 0 b6
:3 0 be :3 0 bf
:3 0 b6 :3 0 3e
:3 0 b3 :3 0 8f
:3 0 b :4 0 c0
1 :8 0 992 82
:4 0 97d :3 0 45
:3 0 56 :2 0 55b
980 981 :3 0 9
:3 0 4b :3 0 983
984 0 18 :2 0
985 986 0 988
55e 98f 9 :3 0
4b :3 0 989 98a
0 83 :2 0 98b
98c 0 98e 560
990 982 988 0
991 0 98e 0
991 562 0 992
565 9dc 4d :3 0
9 :3 0 4b :3 0
995 996 0 4c
:3 0 997 998 0
9d2 23 :3 0 24
:3 0 99a 99b 0
23 :3 0 31 :3 0
99d 99e 0 4e
:2 0 2 :4 0 c1
:2 0 33 :2 0 13
:2 0 568 9a3 9a5
:3 0 56b 99f 9a7
99c 9a9 9a8 :2 0
26 :3 0 34 :3 0
9ab 9ac 0 28
:4 0 c2 :4 0 2b
:2 0 2c :3 0 56f
9b0 9b2 :3 0 2b
:2 0 3a :4 0 572
9b4 9b6 :3 0 2b
:2 0 51 :4 0 575
9b8 9ba :3 0 2b
:2 0 4c :3 0 578
9bc 9be :3 0 2b
:2 0 52 :4 0 57b
9c0 9c2 :3 0 2b
:2 0 53 :3 0 54
:3 0 13 :2 0 55
:2 0 57e 9c5 9c9
582 9c4 9cb :3 0
585 9ad 9cd :2 0
9cf 588 9d0 9aa
9cf 0 9d1 58a
0 9d2 58c 9d5
:3 0 9d5 0 9d5
9d4 9d2 9d3 :6 0
9d7 1a :3 0 58f
9d9 591 9d8 9d7
:2 0 9da 593 :2 0
9dc 0 9dc 9db
992 9da :6 0 9e4
1 :3 0 20 :3 0
c3 :3 0 b :3 0
595 9df 9e1 9de
9e2 0 9e4 597
9e5 972 9e4 0
9e7 7af 968 0
9e7 59a 0 a36
23 :3 0 24 :3 0
9e8 9e9 0 23
:3 0 31 :3 0 9eb
9ec 0 c4 :2 0
2 :4 0 c5 :2 0
33 :2 0 13 :2 0
59d 9f1 9f3 :3 0
5a0 9ed 9f5 9ea
9f7 9f6 :2 0 26
:3 0 34 :3 0 9f9
9fa 0 28 :4 0
c6 :4 0 2b :2 0
2c :3 0 5a4 9fe
a00 :3 0 2b :2 0
3a :4 0 5a7 a02
a04 :3 0 2b :2 0
3b :4 0 5aa a06
a08 :3 0 2b :2 0
3c :3 0 3d :3 0
9 :3 0 4b :3 0
a0d a0e 0 5ad
a0c a10 40 :4 0
5af a0b a13 5b2
a0a a15 :3 0 2b
:2 0 5f :4 0 5b5
a17 a19 :3 0 2b
:2 0 2e :4 0 5b8
a1b a1d :3 0 2b
:2 0 b :3 0 5bb
a1f a21 :3 0 2b
:2 0 2e :4 0 5be
a23 a25 :3 0 5c1
9fb a27 :2 0 a29
5c4 a2a 9f8 a29
0 a2b 5c6 0
a36 43 :3 0 c7
:3 0 a2c a2d 0
9 :3 0 4b :3 0
a2f a30 0 b
:3 0 45 :3 0 5c8
a2e a34 :2 0 a36
5cc ad7 9 :3 0
c8 :2 0 4 a37
a38 0 23 :3 0
24 :3 0 a3a a3b
0 23 :3 0 31
:3 0 a3d a3e 0
4e :2 0 2 :4 0
c9 :2 0 33 :2 0
13 :2 0 5da a43
a45 :3 0 5dd a3f
a47 a3c a49 a48
:2 0 26 :3 0 34
:3 0 a4b a4c 0
28 :4 0 ca :4 0
2b :2 0 2c :3 0
5e1 a50 a52 :3 0
5e4 a4d a54 :2 0
a6d 26 :3 0 34
:3 0 a56 a57 0
28 :4 0 cb :4 0
2b :2 0 9 :3 0
cc :3 0 a5c a5d
0 5e7 a5b a5f
:3 0 2b :2 0 5f
:4 0 5ea a61 a63
:3 0 2b :2 0 9
:3 0 cd :3 0 a66
a67 0 5ed a65
a69 :3 0 5f0 a58
a6b :2 0 a6d 5f3
a6e a4a a6d 0
a6f 5f6 0 a7f
ce :3 0 22 :3 0
9 :3 0 cc :3 0
cf :3 0 9 :3 0
cd :3 0 d0 :3 0
d1 :4 0 d2 1
:a 0 a7b :2 0 a7f
a71 a79 :2 0 8
:3 0 22 :3 0 a7d
:2 0 a7f 5f8 a81
5fc a80 a7f :2 0
ad5 4d :3 0 9
:3 0 4b :3 0 a84
a85 0 4c :3 0
a86 a87 0 acd
23 :3 0 24 :3 0
a89 a8a 0 23
:3 0 31 :3 0 a8c
a8d 0 4e :2 0
2 :4 0 d3 :2 0
33 :2 0 13 :2 0
5fe a92 a94 :3 0
601 a8e a96 a8b
a98 a97 :2 0 26
:3 0 34 :3 0 a9a
a9b 0 28 :4 0
d4 :4 0 2b :2 0
2c :3 0 605 a9f
aa1 :3 0 608 a9c
aa3 :2 0 abd 26
:3 0 34 :3 0 aa5
aa6 0 28 :4 0
51 :4 0 2b :2 0
4c :3 0 60b aaa
aac :3 0 2b :2 0
52 :4 0 60e aae
ab0 :3 0 2b :2 0
53 :3 0 54 :3 0
13 :2 0 55 :2 0
611 ab3 ab7 615
ab2 ab9 :3 0 618
aa7 abb :2 0 abd
61b abe a99 abd
0 abf 61e 0
acd ce :3 0 22
:3 0 cf :3 0 9
:3 0 cd :3 0 d0
:3 0 d1 :4 0 d5
1 :a 0 ac9 :2 0
acd ac1 ac7 :2 0
8 :3 0 22 :3 0
acb :2 0 acd 620
ad0 :3 0 ad0 0
ad0 acf acd ace
:6 0 ad2 1 :3 0
625 ad4 627 ad3
ad2 :2 0 ad5 629
:2 0 ad7 62c ad7
ad6 a36 ad5 :6 0
ad8 :2 0 2 18
ad7 adb :3 0 ada
ad8 adc :8 0 
63f
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 31
1 2f 1 38
1 36 1 3f
1 3d 1 46
1 44 1 4b
1 51 1 57
1 5d 1 63
1 6b 1 69
1 70 1 78
1 76 1 7d
1 83 1 89
1 96 1 a2
2 a5 a7 2
aa ac 2 ae
b0 2 b2 b4
2 b6 b8 2
ba bc 2 be
c0 2 c2 c4
2 c6 c8 2
ca cc 2 ce
d0 2 d2 d4
2 d6 d8 2
da dc 2 de
e0 2 e2 e4
2 e6 e8 4
9e a4 a9 ea
1 ec 1 ee
2 f8 fa 3
f6 f7 fc 2
105 107 2 104
109 1 10b 1
10d 1 10f 1
115 1 11d 2
12d 12f 3 12b
12c 131 2 13a
13c 2 13e 140
2 142 144 1
14c 2 14e 14f
2 146 151 2
139 153 1 155
1 157 2 161
163 3 15f 160
165 2 16e 170
2 16d 172 1
174 1 176 2
17d 17e 3 158
177 180 1 182
2 18b 190 2
1a1 1a3 3 19f
1a0 1a5 2 1ae
1b0 2 1b2 1b4
2 1b6 1b8 2
1ba 1bc 2 1be
1c0 3 1c5 1c6
1c7 2 1c2 1c9
2 1ad 1cb 1
1cd 1 1cf 2
198 1d0 1 1d4
1 193 1 1d8
1 1e3 2 1df
1e3 2 1ee 1f3
2 204 206 3
202 203 208 2
211 213 2 215
217 2 219 21b
2 21d 21f 2
221 223 3 228
229 22a 2 225
22c 2 210 22e
1 230 1 232
2 1fb 233 1
237 1 1f6 1
23b 1 246 2
242 246 2 252
254 3 250 251
256 2 25f 261
2 263 265 2
267 269 1 271
2 273 274 2
26b 276 2 278
27a 2 27c 27e
2 280 282 2
284 286 2 25e
288 1 28a 1
28c 2 296 298
3 294 295 29a
2 2a3 2a5 2
2a2 2a7 1 2a9
1 2ab 3 2b2
2b3 2b4 3 28d
2ac 2b6 1 2b8
4 23e 2b9 2bc
2c1 2 2c5 2ca
2 2cc 2cd 2
2db 2e0 2 2f1
2f3 3 2ef 2f0
2f5 2 2fe 300
2 302 304 2
306 308 2 30a
30c 2 30e 310
3 315 316 317
2 312 319 2
2fd 31b 1 31d
1 31f 2 2e8
320 1 324 1
2e3 1 328 1
333 2 32f 333
3 33c 33d 33e
2 34b 350 2
361 363 3 35f
360 365 2 36e
370 2 372 374
2 376 378 2
37a 37c 2 37e
380 3 385 386
387 2 382 389
2 36d 38b 1
38d 1 38f 2
358 390 1 394
1 353 1 398
2 3bc 3c1 2
3d2 3d4 3 3d0
3d1 3d6 2 3df
3e1 2 3e3 3e5
2 3e7 3e9 2
3eb 3ed 2 3ef
3f1 3 3f6 3f7
3f8 2 3f3 3fa
2 3de 3fc 1
3fe 1 400 2
3c9 401 1 405
1 3c4 1 409
1 414 2 410
414 2 420 422
3 41e 41f 424
2 42d 42f 2
431 433 2 435
437 1 43f 2
441 442 2 439
444 2 446 448
2 44a 44c 2
44e 450 2 452
454 2 42c 456
1 458 1 45a
2 464 466 3
462 463 468 2
471 473 2 470
475 1 477 1
479 3 480 481
482 3 45b 47a
484 1 486 1
496 2 495 496
1 49e 1 4a4
2 4a6 4a7 2
493 4a8 2 4b9
4bb 3 4b7 4b8
4bd 2 4c6 4c8
2 4ca 4cc 2
4ce 4d0 2 4d2
4d4 2 4d6 4d8
3 4dd 4de 4df
2 4da 4e1 2
4c5 4e3 1 4e5
1 4e7 2 4b0
4e8 1 4ec 1
4ab 1 4f0 1
4fb 2 4f7 4fb
2 507 509 3
505 506 50b 2
514 516 2 518
51a 2 51c 51e
1 526 2 528
529 2 520 52b
2 52d 52f 2
531 533 2 535
537 2 539 53b
2 513 53d 1
53f 1 541 2
54b 54d 3 549
54a 54f 2 558
55a 2 557 55c
1 55e 1 560
3 567 568 569
3 542 561 56b
1 56d 7 339
341 39b 40c 487
4f3 56e 1 577
2 573 577 2
57d 57e 1 580
1 584 2 582
584 2 594 599
2 5aa 5ac 3
5a8 5a9 5ae 2
5b7 5b9 2 5bb
5bd 2 5bf 5c1
2 5c3 5c5 2
5c7 5c9 3 5ce
5cf 5d0 2 5cb
5d2 2 5b6 5d4
1 5d6 1 5d8
2 5a1 5d9 1
5dd 1 59c 1
5e1 1 5ec 2
5e8 5ec 2 5f8
5fa 3 5f6 5f7
5fc 2 605 607
2 609 60b 2
60d 60f 1 617
2 619 61a 2
611 61c 2 61e
620 2 622 624
2 626 628 2
62a 62c 2 604
62e 1 630 1
632 2 63c 63e
3 63a 63b 640
2 649 64b 2
648 64d 1 64f
1 651 3 658
659 65a 3 633
652 65c 1 65e
2 5e4 65f 1
661 3 664 665
666 1 66a 2
668 66a 1 674
2 673 674 1
67c 1 682 2
684 685 2 671
686 2 697 699
3 695 696 69b
2 6a4 6a6 2
6a8 6aa 2 6ac
6ae 2 6b0 6b2
2 6b4 6b6 3
6bb 6bc 6bd 2
6b8 6bf 2 6a3
6c1 1 6c3 1
6c5 2 68e 6c6
1 6ca 1 689
1 6ce 1 6d1
1 6d4 2 662
6d5 2 6e0 6e2
3 6de 6df 6e4
2 6ed 6ef 2
6f1 6f3 2 6f5
6f7 1 6ff 2
701 702 2 6f9
704 2 706 708
2 70a 70c 2
70e 710 2 712
714 2 6ec 716
1 718 1 71a
2 724 726 3
722 723 728 2
731 733 2 730
735 1 737 1
739 3 740 741
742 3 71b 73a
744 3 746 6d7
747 2 754 759
2 76a 76c 3
768 769 76e 2
777 779 2 77b
77d 2 77f 781
2 783 785 2
787 789 3 78e
78f 790 2 78b
792 2 776 794
1 796 1 798
2 761 799 1
79d 1 75c 1
7a1 1 7ac 2
7a8 7ac 2 7b1
7b2 1 7b6 2
7b4 7b6 1 7cb
2 7ca 7cb 1
7d3 1 7d9 2
7db 7dc 2 7c8
7dd 2 7ee 7f0
3 7ec 7ed 7f2
2 7fb 7fd 2
7ff 801 2 803
805 2 807 809
2 80b 80d 3
812 813 814 2
80f 816 2 7fa
818 1 81a 1
81c 2 7e5 81d
1 821 1 7e0
1 825 1 828
2 82d 82e 1
832 2 830 832
1 847 2 846
847 1 84f 1
855 2 857 858
2 844 859 2
86a 86c 3 868
869 86e 2 877
879 2 87b 87d
2 87f 881 2
883 885 2 887
889 3 88e 88f
890 2 88b 892
2 876 894 1
896 1 898 2
861 899 1 89d
1 85c 1 8a1
1 8a4 2 8a8
8a7 2 8b2 8b3
2 8b7 8b8 4
8b5 8ba 8bd 8be
2 8c4 8c5 1
8c7 1 8cb 2
8c9 8cb 1 8d2
1 8d8 2 8da
8db 7 8e5 8e6
8e7 8e8 8e9 8ea
8eb 1 908 2
907 908 1 910
1 916 2 918
919 2 905 91a
2 92b 92d 3
929 92a 92f 2
938 93a 2 93c
93e 2 940 942
2 944 946 2
948 94a 3 94f
950 951 2 94c
953 2 937 955
1 957 1 959
2 922 95a 1
95e 1 91d 1
962 8 8a9 8ae
8c1 8dc 8df 8e2
8ee 965 1 96f
2 96b 96f 1
97f 2 97e 97f
1 987 1 98d
2 98f 990 2
97c 991 2 9a2
9a4 3 9a0 9a1
9a6 2 9af 9b1
2 9b3 9b5 2
9b7 9b9 2 9bb
9bd 2 9bf 9c1
3 9c6 9c7 9c8
2 9c3 9ca 2
9ae 9cc 1 9ce
1 9d0 2 999
9d1 1 9d5 1
994 1 9d9 1
9e0 2 9dc 9e3
2 9e6 9e5 2
9f0 9f2 3 9ee
9ef 9f4 2 9fd
9ff 2 a01 a03
2 a05 a07 1
a0f 2 a11 a12
2 a09 a14 2
a16 a18 2 a1a
a1c 2 a1e a20
2 a22 a24 2
9fc a26 1 a28
1 a2a 3 a31
a32 a33 d ef
10e 183 1db 2ce
2d1 32b 748 74b
7a4 9e7 a2b a35
2 a42 a44 3
a40 a41 a46 2
a4f a51 2 a4e
a53 2 a5a a5e
2 a60 a62 2
a64 a68 2 a59
a6a 2 a55 a6c
1 a6e 3 a6f
a7a a7e 1 a39
2 a91 a93 3
a8f a90 a95 2
a9e aa0 2 a9d
aa2 2 aa9 aab
2 aad aaf 3
ab4 ab5 ab6 2
ab1 ab8 2 aa8
aba 2 aa4 abc
1 abe 4 a88
abf ac8 acc 1
ad0 1 a83 2
a81 ad4 12 1f
26 2d 34 3b
42 49 4f 55
5b 61 67 6e
74 7b 81 87
8e 
1
4
0 
adb
0
1
28
1c
17
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 0 0 0 0
0 0 0 0 0 0 0 0

f 1 0
63 1 0
51 1 0
69 1 0
7 1 0
36 1 0
76 1 0
7d 1 0
b 1 0
3d 1 0
5d 1 0
2f 1 0
1a 1 0
57 1 0
3 1 0
70 1 0
2 0 1
83 1 0
4b 1 0
28 1 0
21 1 0
44 1 0
89 1 0
0

/
SHOW ERRORS FUNCTION SP_A_TSKPROF;
ALTER FUNCTION SP_A_TSKPROF COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_TSKRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_TSKRES ==
CREATE OR REPLACE FUNCTION SP_A_TSKRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
5d
2 :e:
1FUNCTION:
1SP_A_TSKRES:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_PROJECT_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_TSKRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
125:
1+:
1FPUT:
1               ENTER:: SP_A_TSKRES(26) :: cplan.sql(6045) :: :
1IS NULL:
18:
130:
1      RETURN_INVALID:: SP_A_TSKRES(31) :: cplan.sql(6050) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
133:
1                EXIT:: SP_A_TSKRES(34) :: cplan.sql(6053) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_TABLE_WBS:
1TYPE_ID:
1PROJECT_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID, PROJECT_ID INTO h_type_id, h_project_id:n      FROM TMT_WBS W+
1HERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
154:
1           EXCEPTION:: SP_A_TSKRES(55) :: cplan.sql(6074) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
1ASSIGNRESOURCE:
14:
165:
1       RETURN_STATUS:: SP_A_TSKRES(66) :: cplan.sql(6085) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
172:
1           EXCEPTION:: SP_A_TSKRES(73) :: cplan.sql(6092) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
184:
1           EXCEPTION:: SP_A_TSKRES(85) :: cplan.sql(6104) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
29e
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
a0 7e b4 2e :2 5a a0 7e b4
2e :2 5a 52 10 a0 7e b4 2e
:2 5a 52 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c :2 a0 d :2 a0
d :2 a0 d :3 a0 6b d :7 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 b4 2e d :2 a0 6b :7 a0
a5 b d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
29e
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 116 105 109 e4 111 104 132
121 125 101 12d 120 152 13d 141
11d 145 14d 13c 159 15d 139 161
165 169 16c 171 172 1 174 179
17d 181 184 189 18d 191 194 199
19a 19c 1a1 1a4 1a8 1a9 1ae 1b3
1b6 1bb 1bc 1c1 1c4 1c8 1c9 1ce
1d1 1d6 1d7 1dc 1df 1e4 1e5 1ea
1ed 1f2 1f3 1f8 1fb 1ff 200 205
208 20d 20e 213 216 21b 21c 221
224 229 22a 22f 232 236 237 23c
23f 244 245 24a 24d 252 253 258
259 25e 260 264 267 26b 26f 272
276 27a 27d 280 285 288 28b 28e
28f 294 295 1 297 29c 2a0 2a4
2a7 2ac 2b1 2b4 2b8 2b9 2be 2bf
2c4 2c6 2ca 2cd 2d1 2d4 2d5 2da
2dd 2e0 2e4 2e7 2e8 2ed 2f0 1
2f3 2f8 2fc 2ff 300 305 308 1
30b 310 314 318 31b 31f 323 326
329 32e 331 334 337 338 33d 33e
1 340 345 349 34d 350 355 35a
35d 361 362 367 36a 36f 370 375
378 37d 37e 383 386 38a 38e 392
396 399 39a 39c 3a1 3a2 3a4 3a5
3aa 3ab 3b0 3b2 3b6 3b9 3bd 3c1
3c4 3c8 3cc 3cf 3d2 3d7 3da 3dd
3e0 3e1 3e6 3e7 1 3e9 3ee 3f2
3f6 3f9 3fe 403 406 40a 40b 410
411 416 418 41c 41f 423 427 42a
42e 432 435 439 43a 43f 441 445
448 44c 450 454 458 45c 460 464
468 46c 470 474 478 47b 47f 483
487 48b 48f 493 497 49b 4a7 4ab
4af 4b2 4b6 4ba 4bc 1 4c0 4c4
4c8 4cb 4cf 4d3 4d7 4db 4de 4e2
4e6 4e9 4ec 4f1 4f4 4f7 4fa 4fb
500 501 1 503 508 50c 510 513
518 51d 520 524 525 52a 52d 532
533 538 53b 540 541 546 549 54d
54e 553 556 55b 55c 561 564 568
56c 56f 572 573 575 576 57b 57c
581 583 587 58a 58c 590 592 59e
5a0 5a2 5a3 5a8 5ac 5ae 5ba 5bc
5c0 5c4 5c5 5ca 5ce 5d2 5d6 5d9
5dd 5e1 5e5 5e9 5ed 5f1 5f5 5f6
5f8 5fc 600 604 607 60b 60f 612
615 61a 61d 620 623 624 629 62a
1 62c 631 635 639 63c 641 646
649 64d 64e 653 656 65b 65c 661
664 669 66a 66f 672 676 67a 67e
682 685 686 688 68d 68e 690 691
696 699 69e 69f 6a4 6a7 6ac 6ad
6b2 6b5 6b9 6ba 6bf 6c2 6c7 6c8
6cd 6ce 6d3 6d5 6d9 6dc 6e0 6e4
6e7 6eb 6ef 6f2 6f6 6fa 6fb 700
702 706 70a 70d 711 715 718 71c
720 723 726 72b 72e 731 734 735
73a 73b 1 73d 742 746 74a 74d
752 757 75a 75e 75f 764 765 76a
76e 772 775 77a 77f 782 786 78a
78d 78e 793 796 79b 79c 7a1 7a4
7a8 7ac 7af 7b0 7b5 7b6 7bb 7bd
7c1 7c4 7c8 7cc 7d0 7d4 7d8 7dc
7e0 7e4 7e8 7f4 7f9 7fd 801 805
809 80b 80c 811 1 815 819 81d
820 824 828 82c 830 833 837 83b
83e 841 846 849 84c 84f 850 855
856 1 858 85d 861 865 868 86d
872 875 879 87a 87f 880 885 889
88d 890 895 89a 89d 8a1 8a2 8a7
8aa 8af 8b0 8b5 8b8 8bc 8c0 8c3
8c6 8c7 8c9 8ca 8cf 8d0 8d5 8d7
8db 8de 8e2 8e6 8ea 8ee 8f2 8f6
8fa 906 90b 90f 913 917 91b 91d
921 923 92f 931 933 934 939 93d
93f 94b 94f 951 952 95b 
29e
2
0 1 a 6 9 :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 11 1a 19 :2 11 :2 4
f 18 17 :2 f :2 4 12 1b 1a
:2 12 :2 4 :2 11 20 11 :2 4 :2 e 1d
e :2 4 e 17 :3 e 4 7 :2 11
23 :2 2d 3a :2 23 :3 7 :2 d 19 25
:2 2f 43 :2 25 53 59 5c :2 53 6a
7f 8 :2 6a d 10 :2 6a 13 16
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 28 2b :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 2a 2d
:2 6a 32 35 :2 6a :2 7 49 :2 4 7
:2 11 23 :2 2d 39 3c 4b 4d 4e
:2 4b :2 23 :3 7 :2 d 12 1e 5b 5e
:2 1e :2 7 51 :2 4 :4 9 8 7 :4 1b
1a 19 :2 7 :4 34 33 32 :2 7 a
:2 14 26 :2 30 3c 3f 4e 50 51
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 6e 71 :2 21 75 78 :2 21 82
85 8e 96 :2 9f :2 8e b0 :2 85 :2 21
:2 a 54 :2 7 a :2 14 26 :2 30 3c
3f 4e 50 51 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 :2 a 54 :3 7
:2 12 28 :2 31 41 :2 7 4a :3 4 14
:2 4 15 :2 4 12 :2 4 14 :2 1d 4
e 17 27 32 c 1a 27 :2 7
:2 10 1c 7 4 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 52
54 55 :2 52 :2 29 :3 d :2 13 18 24
61 64 :2 24 71 74 :2 24 78 7b
:2 24 87 8a :2 24 92 95 :2 24 a1
a4 ab b4 b7 :2 a4 :2 24 :2 d 58
:2 a :2 7 :4 13 :2 7 4 :3 1 4 :3 f
:2 4 :2 d 19 28 36 41 4f 5e
27 :2 19 4 7 :2 11 23 :2 2d 39
3c 4b 4d 4e :2 4b :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e 6b 6e :2 1e
72 75 :2 1e 7f 82 8b 93 :2 9c
:2 8b a7 :2 82 :2 1e af b2 :2 1e ba
bd :2 1e c2 c5 :2 1e cd d0 :2 1e
:2 7 51 :3 4 :2 f 21 :2 2a 34 3d
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 4f 51 52 :2 4f :2 26
:3 a :2 10 15 21 5e 61 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 55
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 4c 4e 4f :2 4c :2 23
:3 7 :2 d 12 1e 5b 5e :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 52 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
29e
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :6 d :6 e :7 10
:b 12 :11 13 14 :2 13
:2 14 :2 13 :2 14 :2 13
:2 15 :2 13 :2 15 :2 13
:2 15 :2 13 :2 15 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :4 13 :3 12 :11 19
:b 1a :3 19 :16 1d :11 1e
:20 1f :3 1e :11 21 :b 22
:3 21 :9 24 :3 1d :3 29
:3 2a :3 2b :5 2c :4 2f
:3 30 2f :5 31 2e
:2 33 :5 35 :11 36 :24 37
:3 36 :2 34 :6 33 32
:3 11 :5 3c :9 3e 3f
:3 3e :11 41 :30 42 :3 41
:a 44 11 :3 47 :11 48
:b 49 :17 4a :3 48 :2 4c
:3 4d :3 4e 4f 4d
4c 4d :3 50 :3 47
:2 51 :5 53 :11 54 :b 55
:18 56 :3 54 :2 58 59
:3 5a 5b 59 58
59 :3 5c :2 52 :6 51
46 :7 1 
95d
4
:3 0 1 :3 0 2
:a 0 299 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 299 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 297
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 297
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 297
0 d :6 0 b
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 297
0 e :6 0 12
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 297
0 f :6 0 12
:2 0 21 11 :3 0
3a :7 0 3e 3b
3c 297 0 10
:6 0 46 47 0
23 11 :3 0 40
:7 0 44 41 42
297 0 13 :6 0
4c 4d 0 25
8 :3 0 9 :2 0
4 48 :7 0 4b
49 0 297 0
14 :6 0 15 :3 0
16 :3 0 15 :3 0
17 :3 0 4f 50
0 2 :4 0 27
51 53 4e 55
54 :2 0 18 :3 0
19 :3 0 57 58
0 1a :4 0 15
:3 0 1b :3 0 5b
5c 0 2 :4 0
29 5d 5f 1c
:4 0 1d :2 0 1e
:3 0 2b 62 64
:3 0 1f :4 0 1d
:2 0 20 :4 0 2e
67 69 :3 0 1d
:2 0 3 :3 0 31
6b 6d :3 0 1d
:2 0 20 :4 0 34
6f 71 :3 0 1d
:2 0 21 :4 0 37
73 75 :3 0 1d
:2 0 20 :4 0 3a
77 79 :3 0 1d
:2 0 5 :3 0 3d
7b 7d :3 0 1d
:2 0 20 :4 0 40
7f 81 :3 0 1d
:2 0 21 :4 0 43
83 85 :3 0 1d
:2 0 20 :4 0 46
87 89 :3 0 1d
:2 0 6 :3 0 49
8b 8d :3 0 1d
:2 0 20 :4 0 4c
8f 91 :3 0 1d
:2 0 22 :4 0 4f
93 95 :3 0 52
59 97 :2 0 99
57 9a 56 99
0 9b 59 0
1f7 15 :3 0 16
:3 0 9c 9d 0
15 :3 0 23 :3 0
9f a0 0 24
:2 0 2 :4 0 25
:2 0 26 :2 0 24
:2 0 5b a5 a7
:3 0 5e a1 a9
9e ab aa :2 0
18 :3 0 27 :3 0
ad ae 0 1a
:4 0 28 :4 0 1d
:2 0 1e :3 0 62
b2 b4 :3 0 65
af b6 :2 0 b8
68 b9 ac b8
0 ba 6a 0
1f7 3 :3 0 29
:2 0 6c bc bd
:3 0 be :2 0 bf
:2 0 5 :3 0 29
:2 0 6e c2 c3
:3 0 c4 :2 0 c5
:2 0 c0 c7 c6
:2 0 6 :3 0 29
:2 0 70 ca cb
:3 0 cc :2 0 cd
:2 0 c8 cf ce
:2 0 15 :3 0 16
:3 0 d1 d2 0
15 :3 0 23 :3 0
d4 d5 0 2a
:2 0 2 :4 0 2b
:2 0 26 :2 0 24
:2 0 72 da dc
:3 0 75 d6 de
d3 e0 df :2 0
18 :3 0 27 :3 0
e2 e3 0 1a
:4 0 2c :4 0 1d
:2 0 1e :3 0 79
e7 e9 :3 0 1d
:2 0 2d :4 0 7c
eb ed :3 0 1d
:2 0 2e :4 0 7f
ef f1 :3 0 1d
:2 0 2f :3 0 30
:3 0 31 :3 0 32
:3 0 f6 f7 0
82 f5 f9 33
:4 0 84 f4 fc
87 f3 fe :3 0
8a e4 100 :2 0
102 8d 103 e1
102 0 104 8f
0 12d 15 :3 0
16 :3 0 105 106
0 15 :3 0 23
:3 0 108 109 0
24 :2 0 2 :4 0
34 :2 0 26 :2 0
24 :2 0 91 10e
110 :3 0 94 10a
112 107 114 113
:2 0 18 :3 0 27
:3 0 116 117 0
1a :4 0 35 :4 0
1d :2 0 1e :3 0
98 11b 11d :3 0
9b 118 11f :2 0
121 9e 122 115
121 0 123 a0
0 12d 36 :3 0
37 :3 0 124 125
0 31 :3 0 32
:3 0 127 128 0
38 :3 0 a2 126
12b :2 0 12d a5
12e d0 12d 0
12f a9 0 1f7
a :3 0 3 :3 0
130 131 0 1f7
f :3 0 5 :3 0
133 134 0 1f7
e :3 0 6 :3 0
136 137 0 1f7
10 :3 0 31 :3 0
39 :3 0 13a 13b
0 139 13c 0
1f7 3a :3 0 3b
:3 0 13 :3 0 d
:3 0 3c :3 0 3d
:3 0 a :4 0 3e
1 :8 0 14b 8
:3 0 3f :3 0 146
147 0 40 :3 0
148 149 0 14b
ab 195 41 :3 0
8 :3 0 3f :3 0
14e 14f 0 40
:3 0 150 151 0
18b 15 :3 0 16
:3 0 153 154 0
15 :3 0 23 :3 0
156 157 0 42
:2 0 2 :4 0 43
:2 0 26 :2 0 24
:2 0 ae 15c 15e
:3 0 b1 158 160
155 162 161 :2 0
18 :3 0 27 :3 0
164 165 0 1a
:4 0 44 :4 0 1d
:2 0 1e :3 0 b5
169 16b :3 0 1d
:2 0 2d :4 0 b8
16d 16f :3 0 1d
:2 0 45 :4 0 bb
171 173 :3 0 1d
:2 0 40 :3 0 be
175 177 :3 0 1d
:2 0 46 :4 0 c1
179 17b :3 0 1d
:2 0 47 :3 0 48
:3 0 24 :2 0 49
:2 0 c4 17e 182
c8 17d 184 :3 0
cb 166 186 :2 0
188 ce 189 163
188 0 18a d0
0 18b d2 18e
:3 0 18e 0 18e
18d 18b 18c :6 0
190 2 :3 0 d5
192 d7 191 190
:2 0 193 d9 :2 0
195 0 195 194
14b 193 :6 0 1f7
1 :3 0 c :3 0
4a :4 0 198 199
:3 0 197 19a 0
1f7 8 :3 0 3f
:3 0 19c 19d 0
4b :3 0 10 :3 0
13 :3 0 a :3 0
f :3 0 e :3 0
c :3 0 db 19f
1a6 19e 1a7 0
1f7 15 :3 0 16
:3 0 1a9 1aa 0
15 :3 0 23 :3 0
1ac 1ad 0 4c
:2 0 2 :4 0 4d
:2 0 26 :2 0 24
:2 0 e2 1b2 1b4
:3 0 e5 1ae 1b6
1ab 1b8 1b7 :2 0
18 :3 0 27 :3 0
1ba 1bb 0 1a
:4 0 4e :4 0 1d
:2 0 1e :3 0 e9
1bf 1c1 :3 0 1d
:2 0 2d :4 0 ec
1c3 1c5 :3 0 1d
:2 0 2e :4 0 ef
1c7 1c9 :3 0 1d
:2 0 2f :3 0 30
:3 0 8 :3 0 3f
:3 0 1ce 1cf 0
f2 1cd 1d1 33
:4 0 f4 1cc 1d4
f7 1cb 1d6 :3 0
1d :2 0 4f :4 0
fa 1d8 1da :3 0
1d :2 0 20 :4 0
fd 1dc 1de :3 0
1d :2 0 c :3 0
100 1e0 1e2 :3 0
1d :2 0 20 :4 0
103 1e4 1e6 :3 0
106 1bc 1e8 :2 0
1ea 109 1eb 1b9
1ea 0 1ec 10b
0 1f7 36 :3 0
50 :3 0 1ed 1ee
0 8 :3 0 3f
:3 0 1f0 1f1 0
c :3 0 38 :3 0
10d 1ef 1f5 :2 0
1f7 111 298 8
:3 0 51 :2 0 4
1f8 1f9 0 15
:3 0 16 :3 0 1fb
1fc 0 15 :3 0
23 :3 0 1fe 1ff
0 42 :2 0 2
:4 0 52 :2 0 26
:2 0 24 :2 0 11e
204 206 :3 0 121
200 208 1fd 20a
209 :2 0 18 :3 0
27 :3 0 20c 20d
0 1a :4 0 53
:4 0 1d :2 0 1e
:3 0 125 211 213
:3 0 128 20e 215
:2 0 22e 18 :3 0
27 :3 0 217 218
0 1a :4 0 54
:4 0 1d :2 0 8
:3 0 55 :3 0 21d
21e 0 12b 21c
220 :3 0 1d :2 0
4f :4 0 12e 222
224 :3 0 1d :2 0
8 :3 0 56 :3 0
227 228 0 131
226 22a :3 0 134
219 22c :2 0 22e
137 22f 20b 22e
0 230 13a 0
240 57 :3 0 14
:3 0 8 :3 0 55
:3 0 58 :3 0 8
:3 0 56 :3 0 3
:3 0 59 :4 0 5a
1 :a 0 23c :2 0
240 232 23a :2 0
7 :3 0 14 :3 0
23e :2 0 240 13c
242 140 241 240
:2 0 296 41 :3 0
8 :3 0 3f :3 0
245 246 0 40
:3 0 247 248 0
28e 15 :3 0 16
:3 0 24a 24b 0
15 :3 0 23 :3 0
24d 24e 0 42
:2 0 2 :4 0 5b
:2 0 26 :2 0 24
:2 0 142 253 255
:3 0 145 24f 257
24c 259 258 :2 0
18 :3 0 27 :3 0
25b 25c 0 1a
:4 0 5c :4 0 1d
:2 0 1e :3 0 149
260 262 :3 0 14c
25d 264 :2 0 27e
18 :3 0 27 :3 0
266 267 0 1a
:4 0 45 :4 0 1d
:2 0 40 :3 0 14f
26b 26d :3 0 1d
:2 0 46 :4 0 152
26f 271 :3 0 1d
:2 0 47 :3 0 48
:3 0 24 :2 0 49
:2 0 155 274 278
159 273 27a :3 0
15c 268 27c :2 0
27e 15f 27f 25a
27e 0 280 162
0 28e 57 :3 0
14 :3 0 58 :3 0
8 :3 0 56 :3 0
3 :3 0 59 :4 0
5d 1 :a 0 28a
:2 0 28e 282 288
:2 0 7 :3 0 14
:3 0 28c :2 0 28e
164 291 :3 0 291
0 291 290 28e
28f :6 0 293 1
:3 0 169 295 16b
294 293 :2 0 296
16d :2 0 298 170
298 297 1f7 296
:6 0 299 :2 0 2
14 298 29c :3 0
29b 299 29d :8 0

179
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
39 1 3f 1
45 1 52 1
5e 2 61 63
2 66 68 2
6a 6c 2 6e
70 2 72 74
2 76 78 2
7a 7c 2 7e
80 2 82 84
2 86 88 2
8a 8c 2 8e
90 2 92 94
4 5a 60 65
96 1 98 1
9a 2 a4 a6
3 a2 a3 a8
2 b1 b3 2
b0 b5 1 b7
1 b9 1 bb
1 c1 1 c9
2 d9 db 3
d7 d8 dd 2
e6 e8 2 ea
ec 2 ee f0
1 f8 2 fa
fb 2 f2 fd
2 e5 ff 1
101 1 103 2
10d 10f 3 10b
10c 111 2 11a
11c 2 119 11e
1 120 1 122
2 129 12a 3
104 123 12c 1
12e 2 145 14a
2 15b 15d 3
159 15a 15f 2
168 16a 2 16c
16e 2 170 172
2 174 176 2
178 17a 3 17f
180 181 2 17c
183 2 167 185
1 187 1 189
2 152 18a 1
18e 1 14d 1
192 6 1a0 1a1
1a2 1a3 1a4 1a5
2 1b1 1b3 3
1af 1b0 1b5 2
1be 1c0 2 1c2
1c4 2 1c6 1c8
1 1d0 2 1d2
1d3 2 1ca 1d5
2 1d7 1d9 2
1db 1dd 2 1df
1e1 2 1e3 1e5
2 1bd 1e7 1
1e9 1 1eb 3
1f2 1f3 1f4 c
9b ba 12f 132
135 138 13d 195
19b 1a8 1ec 1f6
2 203 205 3
201 202 207 2
210 212 2 20f
214 2 21b 21f
2 221 223 2
225 229 2 21a
22b 2 216 22d
1 22f 3 230
23b 23f 1 1fa
2 252 254 3
250 251 256 2
25f 261 2 25e
263 2 26a 26c
2 26e 270 3
275 276 277 2
272 279 2 269
27b 2 265 27d
1 27f 4 249
280 289 28d 1
291 1 244 2
242 295 8 1b
22 29 30 37
3d 43 4a 
1
4
0 
29c
0
1
14
4
c
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
32 1 0
3 1 0
7 1 0
2 0 1
3f 1 0
1d 1 0
39 1 0
24 1 0
2b 1 0
45 1 0
0

/
SHOW ERRORS FUNCTION SP_A_TSKRES;
ALTER FUNCTION SP_A_TSKRES COMPILE DEBUG;
/*
#Stored Procedure  :SP_A_CRIRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_CRIRES ==
CREATE OR REPLACE FUNCTION SP_A_CRIRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
61
2 :e:
1FUNCTION:
1SP_A_CRIRES:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_CRIRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
124:
1+:
1FPUT:
1               ENTER:: SP_A_CRIRES(25) :: cplan.sql(6153) :: :
1IS NULL:
18:
129:
1      RETURN_INVALID:: SP_A_CRIRES(30) :: cplan.sql(6158) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
1                EXIT:: SP_A_CRIRES(33) :: cplan.sql(6161) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_WBS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
151:
1           EXCEPTION:: SP_A_CRIRES(52) :: cplan.sql(6180) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT TYPE_ID INTO h_type_id FROM TMT_CRI WHERE ELEMENT_ID = h_element_id:
166:
1           EXCEPTION:: SP_A_CRIRES(67) :: cplan.sql(6195) :: :
1SC_TABLE_CRI:
1SC_TABLE_WBS:
1SYS_GUID:
1ASSIGNRESOURCE:
14:
182:
1       RETURN_STATUS:: SP_A_CRIRES(83) :: cplan.sql(6211) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
189:
1           EXCEPTION:: SP_A_CRIRES(90) :: cplan.sql(6218) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1101:
1           EXCEPTION:: SP_A_CRIRES(102) :: cplan.sql(6230) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
300
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c a0 7e b4 2e :2 5a a0 7e
b4 2e :2 5a 52 10 a0 7e b4
2e :2 5a 52 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 b7 19 3c :2 a0 d
:2 a0 d :2 a0 d :5 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 6b d b7 :3 a0
6b d b7 :2 19 3c :2 a0 b4 2e
d :2 a0 6b :7 a0 a5 b d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 a0 6b :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e :2 a0 6b b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :9 a0 12a e9 dd
:2 a0 65 b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c :7 a0 12a e9 dd :2 a0 65
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 68 4f 1d 17 b5 
300
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
115 104 108 e4 110 103 135 120
124 100 128 130 11f 13c 140 11c
144 148 14c 14f 154 155 1 157
15c 160 164 167 16c 170 174 177
17c 17d 17f 184 187 18b 18c 191
196 199 19e 19f 1a4 1a7 1ab 1ac
1b1 1b4 1b9 1ba 1bf 1c2 1c7 1c8
1cd 1d0 1d5 1d6 1db 1de 1e2 1e3
1e8 1eb 1f0 1f1 1f6 1f9 1fe 1ff
204 207 20c 20d 212 215 219 21a
21f 222 227 228 22d 230 235 236
23b 23c 241 243 247 24a 24e 252
255 259 25d 260 263 268 26b 26e
271 272 277 278 1 27a 27f 283
287 28a 28f 294 297 29b 29c 2a1
2a2 2a7 2a9 2ad 2b0 2b4 2b7 2b8
2bd 2c0 2c3 2c7 2ca 2cb 2d0 2d3
1 2d6 2db 2df 2e2 2e3 2e8 2eb
1 2ee 2f3 2f7 2fb 2fe 302 306
309 30c 311 314 317 31a 31b 320
321 1 323 328 32c 330 333 338
33d 340 344 345 34a 34d 352 353
358 35b 360 361 366 369 36d 371
375 379 37c 37d 37f 384 385 387
388 38d 38e 393 395 399 39c 3a0
3a4 3a7 3ab 3af 3b2 3b5 3ba 3bd
3c0 3c3 3c4 3c9 3ca 1 3cc 3d1
3d5 3d9 3dc 3e1 3e6 3e9 3ed 3ee
3f3 3f4 3f9 3fb 3ff 402 406 40a
40d 411 415 418 41c 41d 422 424
428 42b 42f 433 437 43b 43f 443
447 44b 44f 453 457 45b 45f 463
46f 473 477 47a 47e 482 484 1
488 48c 490 493 497 49b 49f 4a3
4a6 4aa 4ae 4b1 4b4 4b9 4bc 4bf
4c2 4c3 4c8 4c9 1 4cb 4d0 4d4
4d8 4db 4e0 4e5 4e8 4ec 4ed 4f2
4f5 4fa 4fb 500 503 508 509 50e
511 515 516 51b 51e 523 524 529
52c 530 534 537 53a 53b 53d 53e
543 544 549 54b 54f 552 554 558
55a 566 568 56a 56b 570 574 576
582 584 588 58c 58f 593 596 59a
59d 59e 5a3 5a6 5aa 5ae 5b2 5b6
5ba 5c6 5ca 5ce 5d1 5d5 5d9 5db
1 5df 5e3 5e7 5ea 5ee 5f2 5f6
5fa 5fd 601 605 608 60b 610 613
616 619 61a 61f 620 1 622 627
62b 62f 632 637 63c 63f 643 644
649 64c 651 652 657 65a 65f 660
665 668 66c 66d 672 675 67a 67b
680 683 687 68b 68e 691 692 694
695 69a 69b 6a0 6a2 6a6 6a9 6ab
6af 6b1 6bd 6bf 6c1 6c2 6c7 6cb
6cd 6d9 6db 6df 6e3 6e7 6ea 6ee
6f0 6f4 6f8 6fc 6ff 703 705 709
70d 710 714 718 719 71e 722 726
72a 72d 731 735 739 73d 741 745
749 74a 74c 750 754 758 75b 75f
763 766 769 76e 771 774 777 778
77d 77e 1 780 785 789 78d 790
795 79a 79d 7a1 7a2 7a7 7aa 7af
7b0 7b5 7b8 7bd 7be 7c3 7c6 7ca
7ce 7d2 7d6 7d9 7da 7dc 7e1 7e2
7e4 7e5 7ea 7ed 7f2 7f3 7f8 7fb
800 801 806 809 80d 80e 813 816
81b 81c 821 822 827 829 82d 830
834 838 83b 83f 843 846 84a 84e
84f 854 856 85a 85e 861 865 869
86c 870 874 877 87a 87f 882 885
888 889 88e 88f 1 891 896 89a
89e 8a1 8a6 8ab 8ae 8b2 8b3 8b8
8b9 8be 8c2 8c6 8c9 8ce 8d3 8d6
8da 8de 8e1 8e2 8e7 8ea 8ef 8f0
8f5 8f8 8fc 900 903 904 909 90a
90f 911 915 918 91c 920 924 928
92c 930 934 938 93c 948 94d 951
955 959 95d 95f 960 965 1 969
96d 971 974 978 97c 980 984 987
98b 98f 992 995 99a 99d 9a0 9a3
9a4 9a9 9aa 1 9ac 9b1 9b5 9b9
9bc 9c1 9c6 9c9 9cd 9ce 9d3 9d4
9d9 9dd 9e1 9e4 9e9 9ee 9f1 9f5
9f6 9fb 9fe a03 a04 a09 a0c a10
a14 a17 a1a a1b a1d a1e a23 a24
a29 a2b a2f a32 a36 a3a a3e a42
a46 a4a a4e a5a a5f a63 a67 a6b
a6f a71 a75 a77 a83 a85 a87 a88
a8d a91 a93 a9f aa3 aa5 aa6 aaf 
300
2
0 1 a 6 9 :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 11 20 11
:2 4 :2 e 1d e :2 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 53 59
5c :2 53 6a 7f 8 :2 6a d 10
:2 6a 13 16 :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 28 2b :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 2a 2d :2 6a 32 35 :2 6a :2 7
49 :2 4 7 :2 11 23 :2 2d 39 3c
4b 4d 4e :2 4b :2 23 :3 7 :2 d 12
1e 5b 5e :2 1e :2 7 51 :2 4 :4 9
8 7 :4 1b 1a 19 :2 7 :4 34 33
32 :2 7 a :2 14 26 :2 30 3c 3f
4e 50 51 :2 4e :2 26 :3 a :2 10 15
21 5e 61 :2 21 6e 71 :2 21 75
78 :2 21 82 85 8e 96 :2 9f :2 8e
b0 :2 85 :2 21 :2 a 54 :2 7 a :2 14
26 :2 30 3c 3f 4e 50 51 :2 4e
:2 26 :3 a :2 10 15 21 5e 61 :2 21
:2 a 54 :3 7 :2 12 28 :2 31 41 :2 7
4a :3 4 14 :2 4 15 :2 4 12 4
e 1b 2a 38 45 :2 7 :2 10 1c
7 4 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 52 54 55
:2 52 :2 29 :3 d :2 13 18 24 61 64
:2 24 71 74 :2 24 78 7b :2 24 87
8a :2 24 92 95 :2 24 a1 a4 ab
b4 b7 :2 a4 :2 24 :2 d 58 :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1c 1a
:2 25 :2 1a 7 11 1e 2d 3b 48
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 57 58 :2 55 :2 2c :3 10 :2 16 1b
27 64 67 :2 27 74 77 :2 27 7b
7e :2 27 8a 8d :2 27 95 98 :2 27
a4 a7 ae b7 ba :2 a7 :2 27 :2 10
5b :2 d :2 a :4 16 :2 a 7 :3 35 7
17 :2 20 7 35 7 17 :2 20 7
:5 4 :3 f :2 4 :2 d 19 28 36 41
4f 5e 27 :2 19 4 7 :2 11 23
:2 2d 39 3c 4b 4d 4e :2 4b :2 23
:3 7 :2 d 12 1e 5b 5e :2 1e 6b
6e :2 1e 72 75 :2 1e 7f 82 8b
93 :2 9c :2 8b a7 :2 82 :2 1e af b2
:2 1e ba bd :2 1e c2 c5 :2 1e cd
d0 :2 1e :2 7 51 :3 4 :2 f 21 :2 2a
34 3d :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 4f 51 52
:2 4f :2 26 :3 a :2 10 15 21 5e 61
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 55 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4c 4f 50
:2 4c :2 23 :3 7 :2 d 12 1e 5c 5f
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 53 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
300
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :6 d :7 f :b 11
:11 12 13 :2 12 :2 13
:2 12 :2 13 :2 12 :2 14
:2 12 :2 14 :2 12 :2 14
:2 12 :2 14 :2 12 :2 15
:2 12 :2 15 :2 12 :2 15
:2 12 :2 15 :2 12 :2 15
:4 12 :3 11 :11 18 :b 19
:3 18 :16 1c :11 1d :20 1e
:3 1d :11 20 :b 21 :3 20
:9 23 :3 1c :3 28 :3 29
:3 2a :6 2d :5 2e 2c
:2 30 :5 32 :11 33 :24 34
:3 33 :2 31 :6 30 2f
:3 10 :a 3a :6 3c :5 3d
3b :2 3f :5 41 :11 42
:24 43 :3 42 :2 40 :6 3f
3e :3 3a :5 48 3a
:5 4a 49 :3 3a :5 4d
:9 4f 50 :3 4f :11 52
:30 53 :3 52 :a 55 10
:3 58 :11 59 :b 5a :17 5b
:3 59 :2 5d :3 5e :3 5f
60 5e 5d 5e
:3 61 :3 58 :2 62 :5 64
:11 65 :b 66 :18 67 :3 65
:2 69 6a :3 6b 6c
6a 69 6a :3 6d
:2 63 :6 62 57 :7 1

ab1
4
:3 0 1 :3 0 2
:a 0 2fb 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 2fb 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 2f9
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 2f9
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 2f9
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 2f9
0 e :6 0 11
:2 0 1d 10 :3 0
33 :7 0 37 34
35 2f9 0 f
:6 0 3f 40 0
1f 10 :3 0 39
:7 0 3d 3a 3b
2f9 0 12 :6 0
45 46 0 21
8 :3 0 9 :2 0
4 41 :7 0 44
42 0 2f9 0
13 :6 0 14 :3 0
15 :3 0 14 :3 0
16 :3 0 48 49
0 2 :4 0 23
4a 4c 47 4e
4d :2 0 17 :3 0
18 :3 0 50 51
0 19 :4 0 14
:3 0 1a :3 0 54
55 0 2 :4 0
25 56 58 1b
:4 0 1c :2 0 1d
:3 0 27 5b 5d
:3 0 1e :4 0 1c
:2 0 1f :4 0 2a
60 62 :3 0 1c
:2 0 3 :3 0 2d
64 66 :3 0 1c
:2 0 1f :4 0 30
68 6a :3 0 1c
:2 0 20 :4 0 33
6c 6e :3 0 1c
:2 0 1f :4 0 36
70 72 :3 0 1c
:2 0 5 :3 0 39
74 76 :3 0 1c
:2 0 1f :4 0 3c
78 7a :3 0 1c
:2 0 20 :4 0 3f
7c 7e :3 0 1c
:2 0 1f :4 0 42
80 82 :3 0 1c
:2 0 6 :3 0 45
84 86 :3 0 1c
:2 0 1f :4 0 48
88 8a :3 0 1c
:2 0 21 :4 0 4b
8c 8e :3 0 4e
52 90 :2 0 92
53 93 4f 92
0 94 55 0
259 14 :3 0 15
:3 0 95 96 0
14 :3 0 22 :3 0
98 99 0 23
:2 0 2 :4 0 24
:2 0 25 :2 0 23
:2 0 57 9e a0
:3 0 5a 9a a2
97 a4 a3 :2 0
17 :3 0 26 :3 0
a6 a7 0 19
:4 0 27 :4 0 1c
:2 0 1d :3 0 5e
ab ad :3 0 61
a8 af :2 0 b1
64 b2 a5 b1
0 b3 66 0
259 3 :3 0 28
:2 0 68 b5 b6
:3 0 b7 :2 0 b8
:2 0 5 :3 0 28
:2 0 6a bb bc
:3 0 bd :2 0 be
:2 0 b9 c0 bf
:2 0 6 :3 0 28
:2 0 6c c3 c4
:3 0 c5 :2 0 c6
:2 0 c1 c8 c7
:2 0 14 :3 0 15
:3 0 ca cb 0
14 :3 0 22 :3 0
cd ce 0 29
:2 0 2 :4 0 2a
:2 0 25 :2 0 23
:2 0 6e d3 d5
:3 0 71 cf d7
cc d9 d8 :2 0
17 :3 0 26 :3 0
db dc 0 19
:4 0 2b :4 0 1c
:2 0 1d :3 0 75
e0 e2 :3 0 1c
:2 0 2c :4 0 78
e4 e6 :3 0 1c
:2 0 2d :4 0 7b
e8 ea :3 0 1c
:2 0 2e :3 0 2f
:3 0 30 :3 0 31
:3 0 ef f0 0
7e ee f2 32
:4 0 80 ed f5
83 ec f7 :3 0
86 dd f9 :2 0
fb 89 fc da
fb 0 fd 8b
0 126 14 :3 0
15 :3 0 fe ff
0 14 :3 0 22
:3 0 101 102 0
23 :2 0 2 :4 0
b :2 0 25 :2 0
23 :2 0 8d 107
109 :3 0 90 103
10b 100 10d 10c
:2 0 17 :3 0 26
:3 0 10f 110 0
19 :4 0 33 :4 0
1c :2 0 1d :3 0
94 114 116 :3 0
97 111 118 :2 0
11a 9a 11b 10e
11a 0 11c 9c
0 126 34 :3 0
35 :3 0 11d 11e
0 30 :3 0 31
:3 0 120 121 0
36 :3 0 9e 11f
124 :2 0 126 a1
127 c9 126 0
128 a5 0 259
a :3 0 3 :3 0
129 12a 0 259
e :3 0 5 :3 0
12c 12d 0 259
d :3 0 6 :3 0
12f 130 0 259
37 :3 0 12 :3 0
38 :3 0 39 :3 0
a :4 0 3a 1
:8 0 13d 8 :3 0
3b :3 0 138 139
0 3c :3 0 13a
13b 0 13d a7
187 3d :3 0 8
:3 0 3b :3 0 140
141 0 3c :3 0
142 143 0 17d
14 :3 0 15 :3 0
145 146 0 14
:3 0 22 :3 0 148
149 0 3e :2 0
2 :4 0 3f :2 0
25 :2 0 23 :2 0
aa 14e 150 :3 0
ad 14a 152 147
154 153 :2 0 17
:3 0 26 :3 0 156
157 0 19 :4 0
40 :4 0 1c :2 0
1d :3 0 b1 15b
15d :3 0 1c :2 0
2c :4 0 b4 15f
161 :3 0 1c :2 0
41 :4 0 b7 163
165 :3 0 1c :2 0
3c :3 0 ba 167
169 :3 0 1c :2 0
42 :4 0 bd 16b
16d :3 0 1c :2 0
43 :3 0 44 :3 0
23 :2 0 45 :2 0
c0 170 174 c4
16f 176 :3 0 c7
158 178 :2 0 17a
ca 17b 155 17a
0 17c cc 0
17d ce 180 :3 0
180 0 180 17f
17d 17e :6 0 182
2 :3 0 d1 184
d3 183 182 :2 0
185 d5 :2 0 187
0 187 186 13d
185 :6 0 259 1
:3 0 8 :3 0 3b
:3 0 189 18a 0
8 :3 0 46 :2 0
47 :3 0 18c 18e
0 d9 18d 190
:3 0 191 :2 0 37
:3 0 12 :3 0 48
:3 0 39 :3 0 a
:4 0 49 1 :8 0
19e 8 :3 0 3b
:3 0 199 19a 0
3c :3 0 19b 19c
0 19e dc 1e8
3d :3 0 8 :3 0
3b :3 0 1a1 1a2
0 3c :3 0 1a3
1a4 0 1de 14
:3 0 15 :3 0 1a6
1a7 0 14 :3 0
22 :3 0 1a9 1aa
0 3e :2 0 2
:4 0 4a :2 0 25
:2 0 23 :2 0 df
1af 1b1 :3 0 e2
1ab 1b3 1a8 1b5
1b4 :2 0 17 :3 0
26 :3 0 1b7 1b8
0 19 :4 0 4b
:4 0 1c :2 0 1d
:3 0 e6 1bc 1be
:3 0 1c :2 0 2c
:4 0 e9 1c0 1c2
:3 0 1c :2 0 41
:4 0 ec 1c4 1c6
:3 0 1c :2 0 3c
:3 0 ef 1c8 1ca
:3 0 1c :2 0 42
:4 0 f2 1cc 1ce
:3 0 1c :2 0 43
:3 0 44 :3 0 23
:2 0 45 :2 0 f5
1d1 1d5 f9 1d0
1d7 :3 0 fc 1b9
1d9 :2 0 1db ff
1dc 1b6 1db 0
1dd 101 0 1de
103 1e1 :3 0 1e1
0 1e1 1e0 1de
1df :6 0 1e3 4
:3 0 106 1e5 108
1e4 1e3 :2 0 1e6
10a :2 0 1e8 0
1e8 1e7 19e 1e6
:6 0 1ef 1 :3 0
f :3 0 30 :3 0
4c :3 0 1eb 1ec
0 1ea 1ed 0
1ef 10c 1f6 f
:3 0 30 :3 0 4d
:3 0 1f1 1f2 0
1f0 1f3 0 1f5
10f 1f7 192 1ef
0 1f8 0 1f5
0 1f8 111 0
259 c :3 0 4e
:4 0 1fa 1fb :3 0
1f9 1fc 0 259
8 :3 0 3b :3 0
1fe 1ff 0 4f
:3 0 f :3 0 12
:3 0 a :3 0 e
:3 0 d :3 0 c
:3 0 114 201 208
200 209 0 259
14 :3 0 15 :3 0
20b 20c 0 14
:3 0 22 :3 0 20e
20f 0 50 :2 0
2 :4 0 51 :2 0
25 :2 0 23 :2 0
11b 214 216 :3 0
11e 210 218 20d
21a 219 :2 0 17
:3 0 26 :3 0 21c
21d 0 19 :4 0
52 :4 0 1c :2 0
1d :3 0 122 221
223 :3 0 1c :2 0
2c :4 0 125 225
227 :3 0 1c :2 0
2d :4 0 128 229
22b :3 0 1c :2 0
2e :3 0 2f :3 0
8 :3 0 3b :3 0
230 231 0 12b
22f 233 32 :4 0
12d 22e 236 130
22d 238 :3 0 1c
:2 0 53 :4 0 133
23a 23c :3 0 1c
:2 0 1f :4 0 136
23e 240 :3 0 1c
:2 0 c :3 0 139
242 244 :3 0 1c
:2 0 1f :4 0 13c
246 248 :3 0 13f
21e 24a :2 0 24c
142 24d 21b 24c
0 24e 144 0
259 34 :3 0 54
:3 0 24f 250 0
8 :3 0 3b :3 0
252 253 0 c
:3 0 36 :3 0 146
251 257 :2 0 259
14a 2fa 8 :3 0
55 :2 0 4 25a
25b 0 14 :3 0
15 :3 0 25d 25e
0 14 :3 0 22
:3 0 260 261 0
3e :2 0 2 :4 0
56 :2 0 25 :2 0
23 :2 0 157 266
268 :3 0 15a 262
26a 25f 26c 26b
:2 0 17 :3 0 26
:3 0 26e 26f 0
19 :4 0 57 :4 0
1c :2 0 1d :3 0
15e 273 275 :3 0
161 270 277 :2 0
290 17 :3 0 26
:3 0 279 27a 0
19 :4 0 58 :4 0
1c :2 0 8 :3 0
59 :3 0 27f 280
0 164 27e 282
:3 0 1c :2 0 53
:4 0 167 284 286
:3 0 1c :2 0 8
:3 0 5a :3 0 289
28a 0 16a 288
28c :3 0 16d 27b
28e :2 0 290 170
291 26d 290 0
292 173 0 2a2
5b :3 0 13 :3 0
8 :3 0 59 :3 0
5c :3 0 8 :3 0
5a :3 0 3 :3 0
5d :4 0 5e 1
:a 0 29e :2 0 2a2
294 29c :2 0 7
:3 0 13 :3 0 2a0
:2 0 2a2 175 2a4
179 2a3 2a2 :2 0
2f8 3d :3 0 8
:3 0 3b :3 0 2a7
2a8 0 3c :3 0
2a9 2aa 0 2f0
14 :3 0 15 :3 0
2ac 2ad 0 14
:3 0 22 :3 0 2af
2b0 0 3e :2 0
2 :4 0 5f :2 0
25 :2 0 23 :2 0
17b 2b5 2b7 :3 0
17e 2b1 2b9 2ae
2bb 2ba :2 0 17
:3 0 26 :3 0 2bd
2be 0 19 :4 0
60 :4 0 1c :2 0
1d :3 0 182 2c2
2c4 :3 0 185 2bf
2c6 :2 0 2e0 17
:3 0 26 :3 0 2c8
2c9 0 19 :4 0
41 :4 0 1c :2 0
3c :3 0 188 2cd
2cf :3 0 1c :2 0
42 :4 0 18b 2d1
2d3 :3 0 1c :2 0
43 :3 0 44 :3 0
23 :2 0 45 :2 0
18e 2d6 2da 192
2d5 2dc :3 0 195
2ca 2de :2 0 2e0
198 2e1 2bc 2e0
0 2e2 19b 0
2f0 5b :3 0 13
:3 0 5c :3 0 8
:3 0 5a :3 0 3
:3 0 5d :4 0 61
1 :a 0 2ec :2 0
2f0 2e4 2ea :2 0
7 :3 0 13 :3 0
2ee :2 0 2f0 19d
2f3 :3 0 2f3 0
2f3 2f2 2f0 2f1
:6 0 2f5 1 :3 0
1a2 2f7 1a4 2f6
2f5 :2 0 2f8 1a6
:2 0 2fa 1a9 2fa
2f9 259 2f8 :6 0
2fb :2 0 2 14
2fa 2fe :3 0 2fd
2fb 2ff :8 0 
1b1
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
3e 1 4b 1
57 2 5a 5c
2 5f 61 2
63 65 2 67
69 2 6b 6d
2 6f 71 2
73 75 2 77
79 2 7b 7d
2 7f 81 2
83 85 2 87
89 2 8b 8d
4 53 59 5e
8f 1 91 1
93 2 9d 9f
3 9b 9c a1
2 aa ac 2
a9 ae 1 b0
1 b2 1 b4
1 ba 1 c2
2 d2 d4 3
d0 d1 d6 2
df e1 2 e3
e5 2 e7 e9
1 f1 2 f3
f4 2 eb f6
2 de f8 1
fa 1 fc 2
106 108 3 104
105 10a 2 113
115 2 112 117
1 119 1 11b
2 122 123 3
fd 11c 125 1
127 2 137 13c
2 14d 14f 3
14b 14c 151 2
15a 15c 2 15e
160 2 162 164
2 166 168 2
16a 16c 3 171
172 173 2 16e
175 2 159 177
1 179 1 17b
2 144 17c 1
180 1 13f 1
184 1 18f 2
18b 18f 2 198
19d 2 1ae 1b0
3 1ac 1ad 1b2
2 1bb 1bd 2
1bf 1c1 2 1c3
1c5 2 1c7 1c9
2 1cb 1cd 3
1d2 1d3 1d4 2
1cf 1d6 2 1ba
1d8 1 1da 1
1dc 2 1a5 1dd
1 1e1 1 1a0
1 1e5 2 1e8
1ee 1 1f4 2
1f6 1f7 6 202
203 204 205 206
207 2 213 215
3 211 212 217
2 220 222 2
224 226 2 228
22a 1 232 2
234 235 2 22c
237 2 239 23b
2 23d 23f 2
241 243 2 245
247 2 21f 249
1 24b 1 24d
3 254 255 256
c 94 b3 128
12b 12e 131 187
1f8 1fd 20a 24e
258 2 265 267
3 263 264 269
2 272 274 2
271 276 2 27d
281 2 283 285
2 287 28b 2
27c 28d 2 278
28f 1 291 3
292 29d 2a1 1
25c 2 2b4 2b6
3 2b2 2b3 2b8
2 2c1 2c3 2
2c0 2c5 2 2cc
2ce 2 2d0 2d2
3 2d7 2d8 2d9
2 2d4 2db 2
2cb 2dd 2 2c7
2df 1 2e1 4
2ab 2e2 2eb 2ef
1 2f3 1 2a6
2 2a4 2f7 7
1b 22 29 30
36 3c 43 
1
4
0 
2fe
0
1
14
6
b
0 1 2 1 4 1 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
3 1 0
7 1 0
38 1 0
2 0 1
1d 1 0
32 1 0
24 1 0
3e 1 0
0

/
SHOW ERRORS FUNCTION SP_A_CRIRES;
ALTER FUNCTION SP_A_CRIRES COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_REQRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_REQRES ==
CREATE OR REPLACE FUNCTION SP_A_REQRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
58
2 :e:
1FUNCTION:
1SP_A_REQRES:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TYPE_ID:
1PLS_INTEGER:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_REQRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
123:
1+:
1FPUT:
1               ENTER:: SP_A_REQRES(24) :: cplan.sql(6280) :: :
1IS NULL:
18:
128:
1      RETURN_INVALID:: SP_A_REQRES(29) :: cplan.sql(6285) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
131:
1                EXIT:: SP_A_REQRES(32) :: cplan.sql(6288) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_WBS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
150:
1           EXCEPTION:: SP_A_REQRES(51) :: cplan.sql(6307) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
14:
162:
1       RETURN_STATUS:: SP_A_REQRES(63) :: cplan.sql(6319) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
169:
1           EXCEPTION:: SP_A_REQRES(70) :: cplan.sql(6326) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
181:
1           EXCEPTION:: SP_A_REQRES(82) :: cplan.sql(6338) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
27b
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c a0 7e b4 2e 5a
a0 7e b4 2e 5a 52 10 a0
7e b4 2e :2 5a 52 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :5 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 b4 2e d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
27b
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
119 104 108 e4 10c 114 103 120
124 100 128 12c 130 133 138 139
1 13b 140 144 148 14b 150 154
158 15b 160 161 163 168 16b 16f
170 175 17a 17d 182 183 188 18b
18f 190 195 198 19d 19e 1a3 1a6
1ab 1ac 1b1 1b4 1b9 1ba 1bf 1c2
1c6 1c7 1cc 1cf 1d4 1d5 1da 1dd
1e2 1e3 1e8 1eb 1f0 1f1 1f6 1f9
1fd 1fe 203 206 20b 20c 211 214
219 21a 21f 220 225 227 22b 22e
232 236 239 23d 241 244 247 24c
24f 252 255 256 25b 25c 1 25e
263 267 26b 26e 273 278 27b 27f
280 285 286 28b 28d 291 294 298
29b 29c 2a1 2a4 2a8 2ab 2ac 2b1
1 2b4 2b9 2bd 2c0 2c1 2c6 2c9
1 2cc 2d1 2d5 2d9 2dc 2e0 2e4
2e7 2ea 2ef 2f2 2f5 2f8 2f9 2fe
2ff 1 301 306 30a 30e 311 316
31b 31e 322 323 328 32b 330 331
336 339 33e 33f 344 347 34b 34f
353 357 35a 35b 35d 362 363 365
366 36b 36c 371 373 377 37a 37e
382 385 389 38d 390 393 398 39b
39e 3a1 3a2 3a7 3a8 1 3aa 3af
3b3 3b7 3ba 3bf 3c4 3c7 3cb 3cc
3d1 3d2 3d7 3d9 3dd 3e0 3e4 3e8
3eb 3ef 3f3 3f6 3fa 3fb 400 402
406 409 40d 411 415 419 41d 421
425 429 42d 431 435 439 43d 441
44d 451 455 458 45c 460 462 1
466 46a 46e 471 475 479 47d 481
484 488 48c 48f 492 497 49a 49d
4a0 4a1 4a6 4a7 1 4a9 4ae 4b2
4b6 4b9 4be 4c3 4c6 4ca 4cb 4d0
4d3 4d8 4d9 4de 4e1 4e6 4e7 4ec
4ef 4f3 4f4 4f9 4fc 501 502 507
50a 50e 512 515 518 519 51b 51c
521 522 527 529 52d 530 532 536
538 544 546 548 549 54e 552 554
560 562 566 56a 56b 570 574 578
57c 57f 583 587 58a 58d 592 595
598 59b 59c 5a1 5a2 1 5a4 5a9
5ad 5b1 5b4 5b9 5be 5c1 5c5 5c6
5cb 5ce 5d3 5d4 5d9 5dc 5e1 5e2
5e7 5ea 5ee 5f2 5f6 5fa 5fd 5fe
600 605 606 608 609 60e 611 616
617 61c 61f 624 625 62a 62d 631
632 637 63a 63f 640 645 646 64b
64d 651 654 658 65c 65f 663 667
66a 66e 672 673 678 67a 67e 682
685 689 68d 690 694 698 69b 69e
6a3 6a6 6a9 6ac 6ad 6b2 6b3 1
6b5 6ba 6be 6c2 6c5 6ca 6cf 6d2
6d6 6d7 6dc 6dd 6e2 6e6 6ea 6ed
6f2 6f7 6fa 6fe 702 705 706 70b
70e 713 714 719 71c 720 724 727
728 72d 72e 733 735 739 73c 740
744 748 74c 750 754 758 75c 760
76c 771 775 779 77d 781 783 784
789 1 78d 791 795 798 79c 7a0
7a4 7a8 7ab 7af 7b3 7b6 7b9 7be
7c1 7c4 7c7 7c8 7cd 7ce 1 7d0
7d5 7d9 7dd 7e0 7e5 7ea 7ed 7f1
7f2 7f7 7f8 7fd 801 805 808 80d
812 815 819 81a 81f 822 827 828
82d 830 834 838 83b 83e 83f 841
842 847 848 84d 84f 853 856 85a
85e 862 866 86a 86e 872 87e 883
887 88b 88f 893 895 899 89b 8a7
8a9 8ab 8ac 8b1 8b5 8b7 8c3 8c7
8c9 8ca 8d3 
27b
2
0 1 a 6 9 :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 e 1d e
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 53 59 5c :2 53 6a 7f
8 :2 6a d 10 :2 6a 13 16 :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 28 2b :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 2a 2d :2 6a
32 35 :2 6a :2 7 49 :2 4 7 :2 11
23 :2 2d 39 3c 4b 4d 4e :2 4b
:2 23 :3 7 :2 d 12 1e 5b 5e :2 1e
:2 7 51 :2 4 :4 8 7 :4 18 17 :2 7
:4 30 2f 2e :2 7 a :2 14 26 :2 30
3c 3f 4e 50 51 :2 4e :2 26 :3 a
:2 10 15 21 5e 61 :2 21 6e 71
:2 21 75 78 :2 21 82 85 8e 96
:2 9f :2 8e b0 :2 85 :2 21 :2 a 54 :2 7
a :2 14 26 :2 30 3c 3f 4e 50
51 :2 4e :2 26 :3 a :2 10 15 21 5e
61 :2 21 :2 a 54 :3 7 :2 12 28 :2 31
41 :2 7 46 :3 4 14 :2 4 15 :2 4
12 4 e 1b 2a 38 45 :2 7
:2 10 1c 7 4 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 52
54 55 :2 52 :2 29 :3 d :2 13 18 24
61 64 :2 24 71 74 :2 24 78 7b
:2 24 87 8a :2 24 92 95 :2 24 a1
a4 ab b4 b7 :2 a4 :2 24 :2 d 58
:2 a :2 7 :4 13 :2 7 4 :3 1 4 :3 f
4 7 :2 11 23 :2 2d 39 3c 4b
4d 4e :2 4b :2 23 :3 7 :2 d 12 1e
5b 5e :2 1e 6b 6e :2 1e 72 75
:2 1e 7f 82 8b 93 :2 9c :2 8b a7
:2 82 :2 1e af b2 :2 1e ba bd :2 1e
c2 c5 :2 1e cd d0 :2 1e :2 7 51
:3 4 :2 f 21 :2 2a 34 3d :2 4 1
9 12 9 a :2 14 26 :2 30 3c
40 4f 51 52 :2 4f :2 26 :3 a :2 10
15 21 5e 61 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 55 :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 4c 4e 4f :2 4c :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 52
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
27b
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :7 e :b 10 :11 11
12 :2 11 :2 12 :2 11
:2 12 :2 11 :2 13 :2 11
:2 13 :2 11 :2 13 :2 11
:2 13 :2 11 :2 14 :2 11
:2 14 :2 11 :2 14 :2 11
:2 14 :2 11 :2 14 :4 11
:3 10 :11 17 :b 18 :3 17
:14 1b :11 1c :20 1d :3 1c
:11 1f :b 20 :3 1f :9 22
:3 1b :3 27 :3 28 :3 29
:6 2c :5 2d 2b :2 2f
:5 31 :11 32 :24 33 :3 32
:2 30 :6 2f 2e :3 f
:5 3a :11 3e :30 3f :3 3e
:a 41 f :3 44 :11 45
:b 46 :17 47 :3 45 :2 49
:3 4a :3 4b 4c 4a
49 4a :3 4d :3 44
:2 4e :5 50 :11 51 :b 52
:18 53 :3 51 :2 55 56
:3 57 58 56 55
56 :3 59 :2 4f :6 4e
43 :7 1 
8d5
4
:3 0 1 :3 0 2
:a 0 276 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 276 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 274
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 274
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 274
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 274
0 e :6 0 39
3a 0 1d 10
:3 0 33 :7 0 37
34 35 274 0
f :6 0 3f 40
0 1f 8 :3 0
9 :2 0 4 3b
:7 0 3e 3c 0
274 0 12 :6 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
42 43 0 2
:4 0 21 44 46
41 48 47 :2 0
16 :3 0 17 :3 0
4a 4b 0 18
:4 0 13 :3 0 19
:3 0 4e 4f 0
2 :4 0 23 50
52 1a :4 0 1b
:2 0 1c :3 0 25
55 57 :3 0 1d
:4 0 1b :2 0 1e
:4 0 28 5a 5c
:3 0 1b :2 0 3
:3 0 2b 5e 60
:3 0 1b :2 0 1e
:4 0 2e 62 64
:3 0 1b :2 0 1f
:4 0 31 66 68
:3 0 1b :2 0 1e
:4 0 34 6a 6c
:3 0 1b :2 0 5
:3 0 37 6e 70
:3 0 1b :2 0 1e
:4 0 3a 72 74
:3 0 1b :2 0 1f
:4 0 3d 76 78
:3 0 1b :2 0 1e
:4 0 40 7a 7c
:3 0 1b :2 0 6
:3 0 43 7e 80
:3 0 1b :2 0 1e
:4 0 46 82 84
:3 0 1b :2 0 20
:4 0 49 86 88
:3 0 :2 4c 8a :2 0
8c 51 8d 49
8c 0 8e 53
0 1d4 13 :3 0
14 :3 0 8f 90
0 13 :3 0 21
:3 0 92 93 0
22 :2 0 2 :4 0
23 :2 0 24 :2 0
22 :2 0 55 98
9a :3 0 58 94
9c 91 9e 9d
:2 0 16 :3 0 25
:3 0 a0 a1 0
18 :4 0 26 :4 0
1b :2 0 1c :3 0
5c a5 a7 :3 0
5f a2 a9 :2 0
ab 62 ac 9f
ab 0 ad 64
0 1d4 3 :3 0
27 :2 0 66 af
b0 :3 0 b1 :2 0
5 :3 0 27 :2 0
68 b4 b5 :3 0
b6 :2 0 b2 b8
b7 :2 0 6 :3 0
27 :2 0 6a bb
bc :3 0 bd :2 0
be :2 0 b9 c0
bf :2 0 13 :3 0
14 :3 0 c2 c3
0 13 :3 0 21
:3 0 c5 c6 0
28 :2 0 2 :4 0
29 :2 0 24 :2 0
22 :2 0 6c cb
cd :3 0 6f c7
cf c4 d1 d0
:2 0 16 :3 0 25
:3 0 d3 d4 0
18 :4 0 2a :4 0
1b :2 0 1c :3 0
73 d8 da :3 0
1b :2 0 2b :4 0
76 dc de :3 0
1b :2 0 2c :4 0
79 e0 e2 :3 0
1b :2 0 2d :3 0
2e :3 0 2f :3 0
30 :3 0 e7 e8
0 7c e6 ea
31 :4 0 7e e5
ed 81 e4 ef
:3 0 84 d5 f1
:2 0 f3 87 f4
d2 f3 0 f5
89 0 11e 13
:3 0 14 :3 0 f6
f7 0 13 :3 0
21 :3 0 f9 fa
0 22 :2 0 2
:4 0 32 :2 0 24
:2 0 22 :2 0 8b
ff 101 :3 0 8e
fb 103 f8 105
104 :2 0 16 :3 0
25 :3 0 107 108
0 18 :4 0 33
:4 0 1b :2 0 1c
:3 0 92 10c 10e
:3 0 95 109 110
:2 0 112 98 113
106 112 0 114
9a 0 11e 34
:3 0 35 :3 0 115
116 0 2f :3 0
30 :3 0 118 119
0 36 :3 0 9c
117 11c :2 0 11e
9f 11f c1 11e
0 120 a3 0
1d4 a :3 0 3
:3 0 121 122 0
1d4 e :3 0 5
:3 0 124 125 0
1d4 d :3 0 6
:3 0 127 128 0
1d4 37 :3 0 f
:3 0 38 :3 0 39
:3 0 a :4 0 3a
1 :8 0 135 8
:3 0 3b :3 0 130
131 0 3c :3 0
132 133 0 135
a5 17f 3d :3 0
8 :3 0 3b :3 0
138 139 0 3c
:3 0 13a 13b 0
175 13 :3 0 14
:3 0 13d 13e 0
13 :3 0 21 :3 0
140 141 0 3e
:2 0 2 :4 0 3f
:2 0 24 :2 0 22
:2 0 a8 146 148
:3 0 ab 142 14a
13f 14c 14b :2 0
16 :3 0 25 :3 0
14e 14f 0 18
:4 0 40 :4 0 1b
:2 0 1c :3 0 af
153 155 :3 0 1b
:2 0 2b :4 0 b2
157 159 :3 0 1b
:2 0 41 :4 0 b5
15b 15d :3 0 1b
:2 0 3c :3 0 b8
15f 161 :3 0 1b
:2 0 42 :4 0 bb
163 165 :3 0 1b
:2 0 43 :3 0 44
:3 0 22 :2 0 45
:2 0 be 168 16c
c2 167 16e :3 0
c5 150 170 :2 0
172 c8 173 14d
172 0 174 ca
0 175 cc 178
:3 0 178 0 178
177 175 176 :6 0
17a 2 :3 0 cf
17c d1 17b 17a
:2 0 17d d3 :2 0
17f 0 17f 17e
135 17d :6 0 1d4
1 :3 0 c :3 0
46 :4 0 182 183
:3 0 181 184 0
1d4 13 :3 0 14
:3 0 186 187 0
13 :3 0 21 :3 0
189 18a 0 47
:2 0 2 :4 0 48
:2 0 24 :2 0 22
:2 0 d5 18f 191
:3 0 d8 18b 193
188 195 194 :2 0
16 :3 0 25 :3 0
197 198 0 18
:4 0 49 :4 0 1b
:2 0 1c :3 0 dc
19c 19e :3 0 1b
:2 0 2b :4 0 df
1a0 1a2 :3 0 1b
:2 0 2c :4 0 e2
1a4 1a6 :3 0 1b
:2 0 2d :3 0 2e
:3 0 8 :3 0 3b
:3 0 1ab 1ac 0
e5 1aa 1ae 31
:4 0 e7 1a9 1b1
ea 1a8 1b3 :3 0
1b :2 0 4a :4 0
ed 1b5 1b7 :3 0
1b :2 0 1e :4 0
f0 1b9 1bb :3 0
1b :2 0 c :3 0
f3 1bd 1bf :3 0
1b :2 0 1e :4 0
f6 1c1 1c3 :3 0
f9 199 1c5 :2 0
1c7 fc 1c8 196
1c7 0 1c9 fe
0 1d4 34 :3 0
4b :3 0 1ca 1cb
0 8 :3 0 3b
:3 0 1cd 1ce 0
c :3 0 36 :3 0
100 1cc 1d2 :2 0
1d4 104 275 8
:3 0 4c :2 0 4
1d5 1d6 0 13
:3 0 14 :3 0 1d8
1d9 0 13 :3 0
21 :3 0 1db 1dc
0 3e :2 0 2
:4 0 4d :2 0 24
:2 0 22 :2 0 10f
1e1 1e3 :3 0 112
1dd 1e5 1da 1e7
1e6 :2 0 16 :3 0
25 :3 0 1e9 1ea
0 18 :4 0 4e
:4 0 1b :2 0 1c
:3 0 116 1ee 1f0
:3 0 119 1eb 1f2
:2 0 20b 16 :3 0
25 :3 0 1f4 1f5
0 18 :4 0 4f
:4 0 1b :2 0 8
:3 0 50 :3 0 1fa
1fb 0 11c 1f9
1fd :3 0 1b :2 0
4a :4 0 11f 1ff
201 :3 0 1b :2 0
8 :3 0 51 :3 0
204 205 0 122
203 207 :3 0 125
1f6 209 :2 0 20b
128 20c 1e8 20b
0 20d 12b 0
21d 52 :3 0 12
:3 0 8 :3 0 50
:3 0 53 :3 0 8
:3 0 51 :3 0 3
:3 0 54 :4 0 55
1 :a 0 219 :2 0
21d 20f 217 :2 0
7 :3 0 12 :3 0
21b :2 0 21d 12d
21f 131 21e 21d
:2 0 273 3d :3 0
8 :3 0 3b :3 0
222 223 0 3c
:3 0 224 225 0
26b 13 :3 0 14
:3 0 227 228 0
13 :3 0 21 :3 0
22a 22b 0 3e
:2 0 2 :4 0 56
:2 0 24 :2 0 22
:2 0 133 230 232
:3 0 136 22c 234
229 236 235 :2 0
16 :3 0 25 :3 0
238 239 0 18
:4 0 57 :4 0 1b
:2 0 1c :3 0 13a
23d 23f :3 0 13d
23a 241 :2 0 25b
16 :3 0 25 :3 0
243 244 0 18
:4 0 41 :4 0 1b
:2 0 3c :3 0 140
248 24a :3 0 1b
:2 0 42 :4 0 143
24c 24e :3 0 1b
:2 0 43 :3 0 44
:3 0 22 :2 0 45
:2 0 146 251 255
14a 250 257 :3 0
14d 245 259 :2 0
25b 150 25c 237
25b 0 25d 153
0 26b 52 :3 0
12 :3 0 53 :3 0
8 :3 0 51 :3 0
3 :3 0 54 :4 0
58 1 :a 0 267
:2 0 26b 25f 265
:2 0 7 :3 0 12
:3 0 269 :2 0 26b
155 26e :3 0 26e
0 26e 26d 26b
26c :6 0 270 1
:3 0 15a 272 15c
271 270 :2 0 273
15e :2 0 275 161
275 274 1d4 273
:6 0 276 :2 0 2
14 275 279 :3 0
278 276 27a :8 0

168
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
45 1 51 2
54 56 2 59
5b 2 5d 5f
2 61 63 2
65 67 2 69
6b 2 6d 6f
2 71 73 2
75 77 2 79
7b 2 7d 7f
2 81 83 2
85 87 4 4d
53 58 89 1
8b 1 8d 2
97 99 3 95
96 9b 2 a4
a6 2 a3 a8
1 aa 1 ac
1 ae 1 b3
1 ba 2 ca
cc 3 c8 c9
ce 2 d7 d9
2 db dd 2
df e1 1 e9
2 eb ec 2
e3 ee 2 d6
f0 1 f2 1
f4 2 fe 100
3 fc fd 102
2 10b 10d 2
10a 10f 1 111
1 113 2 11a
11b 3 f5 114
11d 1 11f 2
12f 134 2 145
147 3 143 144
149 2 152 154
2 156 158 2
15a 15c 2 15e
160 2 162 164
3 169 16a 16b
2 166 16d 2
151 16f 1 171
1 173 2 13c
174 1 178 1
137 1 17c 2
18e 190 3 18c
18d 192 2 19b
19d 2 19f 1a1
2 1a3 1a5 1
1ad 2 1af 1b0
2 1a7 1b2 2
1b4 1b6 2 1b8
1ba 2 1bc 1be
2 1c0 1c2 2
19a 1c4 1 1c6
1 1c8 3 1cf
1d0 1d1 a 8e
ad 120 123 126
129 17f 185 1c9
1d3 2 1e0 1e2
3 1de 1df 1e4
2 1ed 1ef 2
1ec 1f1 2 1f8
1fc 2 1fe 200
2 202 206 2
1f7 208 2 1f3
20a 1 20c 3
20d 218 21c 1
1d7 2 22f 231
3 22d 22e 233
2 23c 23e 2
23b 240 2 247
249 2 24b 24d
3 252 253 254
2 24f 256 2
246 258 2 242
25a 1 25c 4
226 25d 266 26a
1 26e 1 221
2 21f 272 6
1b 22 29 30
36 3d 
1
4
0 
279
0
1
14
4
a
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
3 1 0
7 1 0
32 1 0
1d 1 0
24 1 0
2 0 1
38 1 0
0

/
SHOW ERRORS FUNCTION SP_A_REQRES;
ALTER FUNCTION SP_A_REQRES COMPILE DEBUG;
/*
#Stored Procedure  :SP_A_POOLRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_POOLRES ==
CREATE OR REPLACE FUNCTION SP_A_POOLRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
5a
2 :e:
1FUNCTION:
1SP_A_POOLRES:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_POOLRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
124:
1+:
1FPUT:
1               ENTER:: SP_A_POOLRES(25) :: cplan.sql(6387) :: :
1IS NULL:
18:
129:
1      RETURN_INVALID:: SP_A_POOLRES(30) :: cplan.sql(6392) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
1                EXIT:: SP_A_POOLRES(33) :: cplan.sql(6395) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_TABLE_POL:
1TYPE_ID:
1TMT_POOLS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_POOLS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
152:
1           EXCEPTION:: SP_A_POOLRES(53) :: cplan.sql(6415) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
1ASSIGNRESOURCE:
14:
163:
1       RETURN_STATUS:: SP_A_POOLRES(64) :: cplan.sql(6426) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
170:
1           EXCEPTION:: SP_A_POOLRES(71) :: cplan.sql(6433) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
182:
1           EXCEPTION:: SP_A_POOLRES(83) :: cplan.sql(6445) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
295
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c a0 7e b4 2e :2 5a a0 7e
b4 2e :2 5a 52 10 a0 7e b4
2e :2 5a 52 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 b7 19 3c :2 a0 d
:2 a0 d :2 a0 d :3 a0 6b d :5 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 b4 2e d :2 a0 6b
:7 a0 a5 b d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
295
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
115 104 108 e4 110 103 135 120
124 100 128 130 11f 13c 140 11c
144 148 14c 14f 154 155 1 157
15c 160 164 167 16c 170 174 177
17c 17d 17f 184 187 18b 18c 191
196 199 19e 19f 1a4 1a7 1ab 1ac
1b1 1b4 1b9 1ba 1bf 1c2 1c7 1c8
1cd 1d0 1d5 1d6 1db 1de 1e2 1e3
1e8 1eb 1f0 1f1 1f6 1f9 1fe 1ff
204 207 20c 20d 212 215 219 21a
21f 222 227 228 22d 230 235 236
23b 23c 241 243 247 24a 24e 252
255 259 25d 260 263 268 26b 26e
271 272 277 278 1 27a 27f 283
287 28a 28f 294 297 29b 29c 2a1
2a2 2a7 2a9 2ad 2b0 2b4 2b7 2b8
2bd 2c0 2c3 2c7 2ca 2cb 2d0 2d3
1 2d6 2db 2df 2e2 2e3 2e8 2eb
1 2ee 2f3 2f7 2fb 2fe 302 306
309 30c 311 314 317 31a 31b 320
321 1 323 328 32c 330 333 338
33d 340 344 345 34a 34d 352 353
358 35b 360 361 366 369 36d 371
375 379 37c 37d 37f 384 385 387
388 38d 38e 393 395 399 39c 3a0
3a4 3a7 3ab 3af 3b2 3b5 3ba 3bd
3c0 3c3 3c4 3c9 3ca 1 3cc 3d1
3d5 3d9 3dc 3e1 3e6 3e9 3ed 3ee
3f3 3f4 3f9 3fb 3ff 402 406 40a
40d 411 415 418 41c 41d 422 424
428 42b 42f 433 437 43b 43f 443
447 44b 44f 453 457 45b 45e 462
466 46a 46e 472 476 482 486 48a
48d 491 495 497 1 49b 49f 4a3
4a6 4aa 4ae 4b2 4b6 4b9 4bd 4c1
4c4 4c7 4cc 4cf 4d2 4d5 4d6 4db
4dc 1 4de 4e3 4e7 4eb 4ee 4f3
4f8 4fb 4ff 500 505 508 50d 50e
513 516 51b 51c 521 524 528 529
52e 531 536 537 53c 53f 543 547
54a 54d 54e 550 551 556 557 55c
55e 562 565 567 56b 56d 579 57b
57d 57e 583 587 589 595 597 59b
59f 5a0 5a5 5a9 5ad 5b1 5b4 5b8
5bc 5c0 5c4 5c8 5cc 5d0 5d1 5d3
5d7 5db 5df 5e2 5e6 5ea 5ed 5f0
5f5 5f8 5fb 5fe 5ff 604 605 1
607 60c 610 614 617 61c 621 624
628 629 62e 631 636 637 63c 63f
644 645 64a 64d 651 655 659 65d
660 661 663 668 669 66b 66c 671
674 679 67a 67f 682 687 688 68d
690 694 695 69a 69d 6a2 6a3 6a8
6a9 6ae 6b0 6b4 6b7 6bb 6bf 6c2
6c6 6ca 6cd 6d1 6d5 6d6 6db 6dd
6e1 6e5 6e8 6ec 6f0 6f3 6f7 6fb
6fe 701 706 709 70c 70f 710 715
716 1 718 71d 721 725 728 72d
732 735 739 73a 73f 740 745 749
74d 750 755 75a 75d 761 765 768
769 76e 771 776 777 77c 77f 783
787 78a 78b 790 791 796 798 79c
79f 7a3 7a7 7ab 7af 7b3 7b7 7bb
7bf 7c3 7cf 7d4 7d8 7dc 7e0 7e4
7e6 7e7 7ec 1 7f0 7f4 7f8 7fb
7ff 803 807 80b 80e 812 816 819
81c 821 824 827 82a 82b 830 831
1 833 838 83c 840 843 848 84d
850 854 855 85a 85b 860 864 868
86b 870 875 878 87c 87d 882 885
88a 88b 890 893 897 89b 89e 8a1
8a2 8a4 8a5 8aa 8ab 8b0 8b2 8b6
8b9 8bd 8c1 8c5 8c9 8cd 8d1 8d5
8e1 8e6 8ea 8ee 8f2 8f6 8f8 8fc
8fe 90a 90c 90e 90f 914 918 91a
926 92a 92c 92d 936 
295
2
0 1 a 6 9 :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 11 20 11
:2 4 :2 e 1d e :2 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 54 5a
5d :2 54 6b 81 8 :2 6b d 10
:2 6b 13 16 :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 28 2b :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 2a 2d :2 6b 32 35 :2 6b :2 7
4a :2 4 7 :2 11 23 :2 2d 39 3c
4c 4e 4f :2 4c :2 23 :3 7 :2 d 12
1e 5c 5f :2 1e :2 7 52 :2 4 :4 9
8 7 :4 1b 1a 19 :2 7 :4 34 33
32 :2 7 a :2 14 26 :2 30 3c 3f
4f 51 52 :2 4f :2 26 :3 a :2 10 15
21 5f 62 :2 21 6f 72 :2 21 76
79 :2 21 83 86 8f 97 :2 a0 :2 8f
b1 :2 86 :2 21 :2 a 55 :2 7 a :2 14
26 :2 30 3c 3f 4f 51 52 :2 4f
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:2 a 55 :3 7 :2 12 28 :2 31 41 :2 7
4a :3 4 14 :2 4 15 :2 4 12 :2 4
14 :2 1d 4 e 1b 2a 3a 47
:2 7 :2 10 1c 7 4 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
53 55 56 :2 53 :2 29 :3 d :2 13 18
24 62 65 :2 24 72 75 :2 24 79
7c :2 24 88 8b :2 24 93 96 :2 24
a2 a5 ac b5 b8 :2 a5 :2 24 :2 d
59 :2 a :2 7 :4 13 :2 7 4 :3 1 4
:3 f :2 4 :2 d 19 28 36 41 4f
5e 27 :2 19 4 7 :2 11 23 :2 2d
39 3c 4c 4e 4f :2 4c :2 23 :3 7
:2 d 12 1e 5c 5f :2 1e 6c 6f
:2 1e 73 76 :2 1e 80 83 8c 94
:2 9d :2 8c a8 :2 83 :2 1e b0 b3 :2 1e
bb be :2 1e c3 c6 :2 1e ce d1
:2 1e :2 7 52 :3 4 :2 f 21 :2 2a 34
3d :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 50 52 53 :2 50
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
56 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4d 4f 50 :2 4d
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 53 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
295
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :6 d :7 f :b 11
:11 12 13 :2 12 :2 13
:2 12 :2 13 :2 12 :2 14
:2 12 :2 14 :2 12 :2 14
:2 12 :2 14 :2 12 :2 15
:2 12 :2 15 :2 12 :2 15
:2 12 :2 15 :2 12 :2 15
:4 12 :3 11 :11 18 :b 19
:3 18 :16 1c :11 1d :20 1e
:3 1d :11 20 :b 21 :3 20
:9 23 :3 1c :3 28 :3 29
:3 2a :5 2b :6 2e :5 2f
2d :2 31 :5 33 :11 34
:24 35 :3 34 :2 32 :6 31
30 :3 10 :5 3a :9 3c
3d :3 3c :11 3f :30 40
:3 3f :a 42 10 :3 45
:11 46 :b 47 :17 48 :3 46
:2 4a :3 4b :3 4c 4d
4b 4a 4b :3 4e
:3 45 :2 4f :5 51 :11 52
:b 53 :18 54 :3 52 :2 56
57 :3 58 59 57
56 57 :3 5a :2 50
:6 4f 44 :7 1 
938
4
:3 0 1 :3 0 2
:a 0 290 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 290 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 28e
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 28e
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 28e
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 28e
0 e :6 0 11
:2 0 1d 10 :3 0
33 :7 0 37 34
35 28e 0 f
:6 0 3f 40 0
1f 10 :3 0 39
:7 0 3d 3a 3b
28e 0 12 :6 0
45 46 0 21
8 :3 0 9 :2 0
4 41 :7 0 44
42 0 28e 0
13 :6 0 14 :3 0
15 :3 0 14 :3 0
16 :3 0 48 49
0 2 :4 0 23
4a 4c 47 4e
4d :2 0 17 :3 0
18 :3 0 50 51
0 19 :4 0 14
:3 0 1a :3 0 54
55 0 2 :4 0
25 56 58 1b
:4 0 1c :2 0 1d
:3 0 27 5b 5d
:3 0 1e :4 0 1c
:2 0 1f :4 0 2a
60 62 :3 0 1c
:2 0 3 :3 0 2d
64 66 :3 0 1c
:2 0 1f :4 0 30
68 6a :3 0 1c
:2 0 20 :4 0 33
6c 6e :3 0 1c
:2 0 1f :4 0 36
70 72 :3 0 1c
:2 0 5 :3 0 39
74 76 :3 0 1c
:2 0 1f :4 0 3c
78 7a :3 0 1c
:2 0 20 :4 0 3f
7c 7e :3 0 1c
:2 0 1f :4 0 42
80 82 :3 0 1c
:2 0 6 :3 0 45
84 86 :3 0 1c
:2 0 1f :4 0 48
88 8a :3 0 1c
:2 0 21 :4 0 4b
8c 8e :3 0 4e
52 90 :2 0 92
53 93 4f 92
0 94 55 0
1ee 14 :3 0 15
:3 0 95 96 0
14 :3 0 22 :3 0
98 99 0 23
:2 0 2 :4 0 24
:2 0 25 :2 0 23
:2 0 57 9e a0
:3 0 5a 9a a2
97 a4 a3 :2 0
17 :3 0 26 :3 0
a6 a7 0 19
:4 0 27 :4 0 1c
:2 0 1d :3 0 5e
ab ad :3 0 61
a8 af :2 0 b1
64 b2 a5 b1
0 b3 66 0
1ee 3 :3 0 28
:2 0 68 b5 b6
:3 0 b7 :2 0 b8
:2 0 5 :3 0 28
:2 0 6a bb bc
:3 0 bd :2 0 be
:2 0 b9 c0 bf
:2 0 6 :3 0 28
:2 0 6c c3 c4
:3 0 c5 :2 0 c6
:2 0 c1 c8 c7
:2 0 14 :3 0 15
:3 0 ca cb 0
14 :3 0 22 :3 0
cd ce 0 29
:2 0 2 :4 0 2a
:2 0 25 :2 0 23
:2 0 6e d3 d5
:3 0 71 cf d7
cc d9 d8 :2 0
17 :3 0 26 :3 0
db dc 0 19
:4 0 2b :4 0 1c
:2 0 1d :3 0 75
e0 e2 :3 0 1c
:2 0 2c :4 0 78
e4 e6 :3 0 1c
:2 0 2d :4 0 7b
e8 ea :3 0 1c
:2 0 2e :3 0 2f
:3 0 30 :3 0 31
:3 0 ef f0 0
7e ee f2 32
:4 0 80 ed f5
83 ec f7 :3 0
86 dd f9 :2 0
fb 89 fc da
fb 0 fd 8b
0 126 14 :3 0
15 :3 0 fe ff
0 14 :3 0 22
:3 0 101 102 0
23 :2 0 2 :4 0
b :2 0 25 :2 0
23 :2 0 8d 107
109 :3 0 90 103
10b 100 10d 10c
:2 0 17 :3 0 26
:3 0 10f 110 0
19 :4 0 33 :4 0
1c :2 0 1d :3 0
94 114 116 :3 0
97 111 118 :2 0
11a 9a 11b 10e
11a 0 11c 9c
0 126 34 :3 0
35 :3 0 11d 11e
0 30 :3 0 31
:3 0 120 121 0
36 :3 0 9e 11f
124 :2 0 126 a1
127 c9 126 0
128 a5 0 1ee
a :3 0 3 :3 0
129 12a 0 1ee
e :3 0 5 :3 0
12c 12d 0 1ee
d :3 0 6 :3 0
12f 130 0 1ee
f :3 0 30 :3 0
37 :3 0 133 134
0 132 135 0
1ee 38 :3 0 12
:3 0 39 :3 0 3a
:3 0 a :4 0 3b
1 :8 0 142 8
:3 0 3c :3 0 13d
13e 0 3d :3 0
13f 140 0 142
a7 18c 3e :3 0
8 :3 0 3c :3 0
145 146 0 3d
:3 0 147 148 0
182 14 :3 0 15
:3 0 14a 14b 0
14 :3 0 22 :3 0
14d 14e 0 3f
:2 0 2 :4 0 40
:2 0 25 :2 0 23
:2 0 aa 153 155
:3 0 ad 14f 157
14c 159 158 :2 0
17 :3 0 26 :3 0
15b 15c 0 19
:4 0 41 :4 0 1c
:2 0 1d :3 0 b1
160 162 :3 0 1c
:2 0 2c :4 0 b4
164 166 :3 0 1c
:2 0 42 :4 0 b7
168 16a :3 0 1c
:2 0 3d :3 0 ba
16c 16e :3 0 1c
:2 0 43 :4 0 bd
170 172 :3 0 1c
:2 0 44 :3 0 45
:3 0 23 :2 0 46
:2 0 c0 175 179
c4 174 17b :3 0
c7 15d 17d :2 0
17f ca 180 15a
17f 0 181 cc
0 182 ce 185
:3 0 185 0 185
184 182 183 :6 0
187 2 :3 0 d1
189 d3 188 187
:2 0 18a d5 :2 0
18c 0 18c 18b
142 18a :6 0 1ee
1 :3 0 c :3 0
47 :4 0 18f 190
:3 0 18e 191 0
1ee 8 :3 0 3c
:3 0 193 194 0
48 :3 0 f :3 0
12 :3 0 a :3 0
e :3 0 d :3 0
c :3 0 d7 196
19d 195 19e 0
1ee 14 :3 0 15
:3 0 1a0 1a1 0
14 :3 0 22 :3 0
1a3 1a4 0 49
:2 0 2 :4 0 4a
:2 0 25 :2 0 23
:2 0 de 1a9 1ab
:3 0 e1 1a5 1ad
1a2 1af 1ae :2 0
17 :3 0 26 :3 0
1b1 1b2 0 19
:4 0 4b :4 0 1c
:2 0 1d :3 0 e5
1b6 1b8 :3 0 1c
:2 0 2c :4 0 e8
1ba 1bc :3 0 1c
:2 0 2d :4 0 eb
1be 1c0 :3 0 1c
:2 0 2e :3 0 2f
:3 0 8 :3 0 3c
:3 0 1c5 1c6 0
ee 1c4 1c8 32
:4 0 f0 1c3 1cb
f3 1c2 1cd :3 0
1c :2 0 4c :4 0
f6 1cf 1d1 :3 0
1c :2 0 1f :4 0
f9 1d3 1d5 :3 0
1c :2 0 c :3 0
fc 1d7 1d9 :3 0
1c :2 0 1f :4 0
ff 1db 1dd :3 0
102 1b3 1df :2 0
1e1 105 1e2 1b0
1e1 0 1e3 107
0 1ee 34 :3 0
4d :3 0 1e4 1e5
0 8 :3 0 3c
:3 0 1e7 1e8 0
c :3 0 36 :3 0
109 1e6 1ec :2 0
1ee 10d 28f 8
:3 0 4e :2 0 4
1ef 1f0 0 14
:3 0 15 :3 0 1f2
1f3 0 14 :3 0
22 :3 0 1f5 1f6
0 3f :2 0 2
:4 0 4f :2 0 25
:2 0 23 :2 0 11a
1fb 1fd :3 0 11d
1f7 1ff 1f4 201
200 :2 0 17 :3 0
26 :3 0 203 204
0 19 :4 0 50
:4 0 1c :2 0 1d
:3 0 121 208 20a
:3 0 124 205 20c
:2 0 225 17 :3 0
26 :3 0 20e 20f
0 19 :4 0 51
:4 0 1c :2 0 8
:3 0 52 :3 0 214
215 0 127 213
217 :3 0 1c :2 0
4c :4 0 12a 219
21b :3 0 1c :2 0
8 :3 0 53 :3 0
21e 21f 0 12d
21d 221 :3 0 130
210 223 :2 0 225
133 226 202 225
0 227 136 0
237 54 :3 0 13
:3 0 8 :3 0 52
:3 0 55 :3 0 8
:3 0 53 :3 0 3
:3 0 56 :4 0 57
1 :a 0 233 :2 0
237 229 231 :2 0
7 :3 0 13 :3 0
235 :2 0 237 138
239 13c 238 237
:2 0 28d 3e :3 0
8 :3 0 3c :3 0
23c 23d 0 3d
:3 0 23e 23f 0
285 14 :3 0 15
:3 0 241 242 0
14 :3 0 22 :3 0
244 245 0 3f
:2 0 2 :4 0 58
:2 0 25 :2 0 23
:2 0 13e 24a 24c
:3 0 141 246 24e
243 250 24f :2 0
17 :3 0 26 :3 0
252 253 0 19
:4 0 59 :4 0 1c
:2 0 1d :3 0 145
257 259 :3 0 148
254 25b :2 0 275
17 :3 0 26 :3 0
25d 25e 0 19
:4 0 42 :4 0 1c
:2 0 3d :3 0 14b
262 264 :3 0 1c
:2 0 43 :4 0 14e
266 268 :3 0 1c
:2 0 44 :3 0 45
:3 0 23 :2 0 46
:2 0 151 26b 26f
155 26a 271 :3 0
158 25f 273 :2 0
275 15b 276 251
275 0 277 15e
0 285 54 :3 0
13 :3 0 55 :3 0
8 :3 0 53 :3 0
3 :3 0 56 :4 0
5a 1 :a 0 281
:2 0 285 279 27f
:2 0 7 :3 0 13
:3 0 283 :2 0 285
160 288 :3 0 288
0 288 287 285
286 :6 0 28a 1
:3 0 165 28c 167
28b 28a :2 0 28d
169 :2 0 28f 16c
28f 28e 1ee 28d
:6 0 290 :2 0 2
14 28f 293 :3 0
292 290 294 :8 0

174
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
3e 1 4b 1
57 2 5a 5c
2 5f 61 2
63 65 2 67
69 2 6b 6d
2 6f 71 2
73 75 2 77
79 2 7b 7d
2 7f 81 2
83 85 2 87
89 2 8b 8d
4 53 59 5e
8f 1 91 1
93 2 9d 9f
3 9b 9c a1
2 aa ac 2
a9 ae 1 b0
1 b2 1 b4
1 ba 1 c2
2 d2 d4 3
d0 d1 d6 2
df e1 2 e3
e5 2 e7 e9
1 f1 2 f3
f4 2 eb f6
2 de f8 1
fa 1 fc 2
106 108 3 104
105 10a 2 113
115 2 112 117
1 119 1 11b
2 122 123 3
fd 11c 125 1
127 2 13c 141
2 152 154 3
150 151 156 2
15f 161 2 163
165 2 167 169
2 16b 16d 2
16f 171 3 176
177 178 2 173
17a 2 15e 17c
1 17e 1 180
2 149 181 1
185 1 144 1
189 6 197 198
199 19a 19b 19c
2 1a8 1aa 3
1a6 1a7 1ac 2
1b5 1b7 2 1b9
1bb 2 1bd 1bf
1 1c7 2 1c9
1ca 2 1c1 1cc
2 1ce 1d0 2
1d2 1d4 2 1d6
1d8 2 1da 1dc
2 1b4 1de 1
1e0 1 1e2 3
1e9 1ea 1eb c
94 b3 128 12b
12e 131 136 18c
192 19f 1e3 1ed
2 1fa 1fc 3
1f8 1f9 1fe 2
207 209 2 206
20b 2 212 216
2 218 21a 2
21c 220 2 211
222 2 20d 224
1 226 3 227
232 236 1 1f1
2 249 24b 3
247 248 24d 2
256 258 2 255
25a 2 261 263
2 265 267 3
26c 26d 26e 2
269 270 2 260
272 2 25c 274
1 276 4 240
277 280 284 1
288 1 23b 2
239 28c 7 1b
22 29 30 36
3c 43 
1
4
0 
293
0
1
14
4
b
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
2 0 1
3 1 0
7 1 0
38 1 0
1d 1 0
32 1 0
24 1 0
3e 1 0
0

/
SHOW ERRORS FUNCTION SP_A_POOLRES;
ALTER FUNCTION SP_A_POOLRES COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_DOCRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_DOCRES ==
CREATE OR REPLACE FUNCTION SP_A_DOCRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
7c
2 :e:
1FUNCTION:
1SP_A_DOCRES:
1TABLE_TYPE001:
1PLS_INTEGER:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
10:
1H_TYPE_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_DOCRES(:
1COALESCE:
1TO_CHAR:
1NULL:
1, :
1':
1);:
1CHECK_TRACE:
11:
126:
1+:
1FPUT:
1               ENTER:: SP_A_DOCRES(27) :: cplan.sql(6498) :: :
1IS NULL:
18:
131:
1      RETURN_INVALID:: SP_A_DOCRES(32) :: cplan.sql(6503) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
134:
1                EXIT:: SP_A_DOCRES(35) :: cplan.sql(6506) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1=:
1SC_TABLE_DOC:
1TYPE_ID:
1TMT_DOCUMENTS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_DOCUMENTS WHERE ELEMENT_ID = h_element+
1_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
155:
1           EXCEPTION:: SP_A_DOCRES(56) :: cplan.sql(6527) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1ELSIF:
1SC_TABLE_SCD:
1TMT_ASSIGNED_SCORECARDS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_ASSIGNED_SCORECARDS WHERE ELEMENT_ID =+
1 h_element_id:
168:
1           EXCEPTION:: SP_A_DOCRES(69) :: cplan.sql(6540) :: :
1SC_TABLE_POL_DOC:
1TMT_POOL_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_POOL_DOCUMENTS WHERE ELEMENT_ID = h_el+
1ement_id:
181:
1           EXCEPTION:: SP_A_DOCRES(82) :: cplan.sql(6553) :: :
1SC_TABLE_RES_DOC:
1TMT_RESOURCE_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_RESOURCE_DOCUMENTS WHERE ELEMENT_ID = +
1h_element_id:
194:
1           EXCEPTION:: SP_A_DOCRES(95) :: cplan.sql(6566) :: :
1SC_TABLE_CLN_DOC:
1TMT_CLIENT_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_CLIENT_DOCUMENTS WHERE ELEMENT_ID = h_+
1element_id:
1107:
1           EXCEPTION:: SP_A_DOCRES(108) :: cplan.sql(6579) :: :
1SC_TABLE_AST_DOC:
1TMT_ASSET_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_ASSET_DOCUMENTS WHERE ELEMENT_ID = h_e+
1lement_id:
1120:
1           EXCEPTION:: SP_A_DOCRES(121) :: cplan.sql(6592) :: :
1SC_TABLE_VDR_DOC:
1TMT_VENDOR_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_VENDOR_DOCUMENTS WHERE ELEMENT_ID = h_+
1element_id:
1133:
1           EXCEPTION:: SP_A_DOCRES(134) :: cplan.sql(6605) :: :
1SYS_GUID:
1ASSIGNRESOURCE:
14:
1145:
1       RETURN_STATUS:: SP_A_DOCRES(146) :: cplan.sql(6617) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1152:
1           EXCEPTION:: SP_A_DOCRES(153) :: cplan.sql(6624) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1164:
1           EXCEPTION:: SP_A_DOCRES(165) :: cplan.sql(6636) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
512
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c a0 7e b4 2e :2 5a a0
7e b4 2e :2 5a 52 10 a0 7e
b4 2e :2 5a 52 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 19 3c :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
51 a5 b a0 7e a0 6b b4
2e :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 b7 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 19 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 19 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 19 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 19 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 19 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :2 a0 b4
2e d :2 a0 6b :7 a0 a5 b d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
512
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ef
dd bc e1 e2 ea dc 10b fa
fe d9 106 f9 127 116 11a f6
122 115 147 132 136 112 13a 142
131 14e 152 12e 156 15a 15e 161
166 167 1 169 16e 172 176 179
17e 182 186 189 18e 18f 191 196
199 19d 19e 1a3 1a8 1ab 1af 1b3
1b7 1b8 1ba 1bf 1c0 1c2 1c3 1c8
1cb 1d0 1d1 1d6 1d9 1de 1df 1e4
1e7 1eb 1ec 1f1 1f4 1f9 1fa 1ff
202 207 208 20d 210 215 216 21b
21e 222 223 228 22b 230 231 236
239 23e 23f 244 247 24c 24d 252
255 259 25a 25f 262 267 268 26d
270 275 276 27b 27c 281 283 287
28a 28e 292 295 299 29d 2a0 2a3
2a8 2ab 2ae 2b1 2b2 2b7 2b8 1
2ba 2bf 2c3 2c7 2ca 2cf 2d4 2d7
2db 2dc 2e1 2e2 2e7 2e9 2ed 2f0
2f4 2f7 2f8 2fd 300 303 307 30a
30b 310 313 1 316 31b 31f 322
323 328 32b 1 32e 333 337 33b
33e 342 346 349 34c 351 354 357
35a 35b 360 361 1 363 368 36c
370 373 378 37d 380 384 385 38a
38d 392 393 398 39b 3a0 3a1 3a6
3a9 3ad 3b1 3b5 3b9 3bc 3bd 3bf
3c4 3c5 3c7 3c8 3cd 3ce 3d3 3d5
3d9 3dc 3e0 3e4 3e7 3eb 3ef 3f2
3f5 3fa 3fd 400 403 404 409 40a
1 40c 411 415 419 41c 421 426
429 42d 42e 433 434 439 43b 43f
442 446 44a 44d 451 455 458 45c
45d 462 464 468 46b 46f 473 477
47b 47f 483 487 48b 48f 493 497
49b 49f 4a3 4a6 4a7 4a9 4ad 4b0
4b4 4b7 4b8 4bd 4c1 4c5 4c9 4cd
4d1 4dd 4e1 4e5 4e8 4ec 4f0 4f2
1 4f6 4fa 4fe 501 505 509 50d
511 514 518 51c 51f 522 527 52a
52d 530 531 536 537 1 539 53e
542 546 549 54e 553 556 55a 55b
560 563 568 569 56e 571 576 577
57c 57f 583 584 589 58c 591 592
597 59a 59e 5a2 5a5 5a8 5a9 5ab
5ac 5b1 5b2 5b7 5b9 5bd 5c0 5c2
5c6 5c8 5d4 5d6 5d8 5d9 5de 5e2
5e4 5f0 5f2 5f6 5f8 5fc 600 603
604 606 60a 60d 611 614 615 61a
61e 622 626 62a 62e 63a 63e 642
645 649 64d 64f 1 653 657 65b
65e 662 666 66a 66e 671 675 679
67c 67f 684 687 68a 68d 68e 693
694 1 696 69b 69f 6a3 6a6 6ab
6b0 6b3 6b7 6b8 6bd 6c0 6c5 6c6
6cb 6ce 6d3 6d4 6d9 6dc 6e0 6e1
6e6 6e9 6ee 6ef 6f4 6f7 6fb 6ff
702 705 706 708 709 70e 70f 714
716 71a 71d 71f 723 725 731 733
735 736 73b 73f 741 74d 74f 753
755 759 75d 761 764 765 767 76b
76e 772 775 776 77b 77f 783 787
78b 78f 79b 79f 7a3 7a6 7aa 7ae
7b0 1 7b4 7b8 7bc 7bf 7c3 7c7
7cb 7cf 7d2 7d6 7da 7dd 7e0 7e5
7e8 7eb 7ee 7ef 7f4 7f5 1 7f7
7fc 800 804 807 80c 811 814 818
819 81e 821 826 827 82c 82f 834
835 83a 83d 841 842 847 84a 84f
850 855 858 85c 860 863 866 867
869 86a 86f 870 875 877 87b 87e
880 884 886 892 894 896 897 89c
8a0 8a2 8ae 8b0 8b4 8b6 8ba 8be
8c2 8c5 8c6 8c8 8cc 8cf 8d3 8d6
8d7 8dc 8e0 8e4 8e8 8ec 8f0 8fc
900 904 907 90b 90f 911 1 915
919 91d 920 924 928 92c 930 933
937 93b 93e 941 946 949 94c 94f
950 955 956 1 958 95d 961 965
968 96d 972 975 979 97a 97f 982
987 988 98d 990 995 996 99b 99e
9a2 9a3 9a8 9ab 9b0 9b1 9b6 9b9
9bd 9c1 9c4 9c7 9c8 9ca 9cb 9d0
9d1 9d6 9d8 9dc 9df 9e1 9e5 9e7
9f3 9f5 9f7 9f8 9fd a01 a03 a0f
a11 a15 a17 a1b a1f a23 a26 a27
a29 a2d a30 a34 a37 a38 a3d a41
a45 a49 a4d a51 a5d a61 a65 a68
a6c a70 a72 1 a76 a7a a7e a81
a85 a89 a8d a91 a94 a98 a9c a9f
aa2 aa7 aaa aad ab0 ab1 ab6 ab7
1 ab9 abe ac2 ac6 ac9 ace ad3
ad6 ada adb ae0 ae3 ae8 ae9 aee
af1 af6 af7 afc aff b03 b04 b09
b0c b11 b12 b17 b1a b1e b22 b25
b28 b29 b2b b2c b31 b32 b37 b39
b3d b40 b42 b46 b48 b54 b56 b58
b59 b5e b62 b64 b70 b72 b76 b78
b7c b80 b84 b87 b88 b8a b8e b91
b95 b98 b99 b9e ba2 ba6 baa bae
bb2 bbe bc2 bc6 bc9 bcd bd1 bd3
1 bd7 bdb bdf be2 be6 bea bee
bf2 bf5 bf9 bfd c00 c03 c08 c0b
c0e c11 c12 c17 c18 1 c1a c1f
c23 c27 c2a c2f c34 c37 c3b c3c
c41 c44 c49 c4a c4f c52 c57 c58
c5d c60 c64 c65 c6a c6d c72 c73
c78 c7b c7f c83 c86 c89 c8a c8c
c8d c92 c93 c98 c9a c9e ca1 ca3
ca7 ca9 cb5 cb7 cb9 cba cbf cc3
cc5 cd1 cd3 cd7 cd9 cdd ce1 ce5
ce8 ce9 ceb cef cf2 cf6 cf9 cfa
cff d03 d07 d0b d0f d13 d1f d23
d27 d2a d2e d32 d34 1 d38 d3c
d40 d43 d47 d4b d4f d53 d56 d5a
d5e d61 d64 d69 d6c d6f d72 d73
d78 d79 1 d7b d80 d84 d88 d8b
d90 d95 d98 d9c d9d da2 da5 daa
dab db0 db3 db8 db9 dbe dc1 dc5
dc6 dcb dce dd3 dd4 dd9 ddc de0
de4 de7 dea deb ded dee df3 df4
df9 dfb dff e02 e04 e08 e0a e16
e18 e1a e1b e20 e24 e26 e32 e34
e36 e3a e3e e41 e45 e49 e4a e4f
e53 e57 e5b e5e e62 e66 e6a e6e
e72 e76 e7a e7b e7d e81 e85 e89
e8c e90 e94 e97 e9a e9f ea2 ea5
ea8 ea9 eae eaf 1 eb1 eb6 eba
ebe ec1 ec6 ecb ece ed2 ed3 ed8
edb ee0 ee1 ee6 ee9 eee eef ef4
ef7 efb eff f03 f07 f0a f0b f0d
f12 f13 f15 f16 f1b f1e f23 f24
f29 f2c f31 f32 f37 f3a f3e f3f
f44 f47 f4c f4d f52 f53 f58 f5a
f5e f61 f65 f69 f6c f70 f74 f77
f7b f7f f80 f85 f87 f8b f8f f92
f96 f9a f9d fa1 fa5 fa8 fab fb0
fb3 fb6 fb9 fba fbf fc0 1 fc2
fc7 fcb fcf fd2 fd7 fdc fdf fe3
fe4 fe9 fea fef ff3 ff7 ffa fff
1004 1007 100b 100f 1012 1013 1018 101b
1020 1021 1026 1029 102d 1031 1034 1035
103a 103b 1040 1042 1046 1049 104d 1051
1055 1059 105d 1061 1065 1069 106d 1079
107e 1082 1086 108a 108e 1090 1091 1096
1 109a 109e 10a2 10a5 10a9 10ad 10b1
10b5 10b8 10bc 10c0 10c3 10c6 10cb 10ce
10d1 10d4 10d5 10da 10db 1 10dd 10e2
10e6 10ea 10ed 10f2 10f7 10fa 10fe 10ff
1104 1105 110a 110e 1112 1115 111a 111f
1122 1126 1127 112c 112f 1134 1135 113a
113d 1141 1145 1148 114b 114c 114e 114f
1154 1155 115a 115c 1160 1163 1167 116b
116f 1173 1177 117b 117f 118b 1190 1194
1198 119c 11a0 11a2 11a6 11a8 11b4 11b6
11b8 11b9 11be 11c2 11c4 11d0 11d4 11d6
11d7 11e0 
512
2
0 1 a 6 14 :3 6 9 :3 6
10 :3 6 12 :2 6 1 3 a 13
a :2 1 4 11 1a 19 :2 11 :2 4
c 15 14 :2 c :2 4 f 18 17
:2 f :2 4 12 1b 1a :2 12 :2 4 :2 11
20 11 :2 4 :2 e 1d e :2 4 e
17 :3 e 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
53 59 5c :2 53 6a 7f 8 11
19 :2 11 29 :2 8 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 21 24
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 28 2b :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 2a 2d
:2 6a 32 35 :2 6a :2 7 49 :2 4 7
:2 11 23 :2 2d 39 3c 4b 4d 4e
:2 4b :2 23 :3 7 :2 d 12 1e 5b 5e
:2 1e :2 7 51 :2 4 :4 9 8 7 :4 1b
1a 19 :2 7 :4 34 33 32 :2 7 a
:2 14 26 :2 30 3c 3f 4e 50 51
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 6e 71 :2 21 75 78 :2 21 82
85 8e 96 :2 9f :2 8e b0 :2 85 :2 21
:2 a 54 :2 7 a :2 14 26 :2 30 3c
3f 4e 50 51 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 :2 a 54 :3 7
:2 12 28 :2 31 41 :2 7 4a :3 4 14
:2 4 15 :2 4 12 :2 4 14 4 7
10 1e :2 7 23 21 :2 2c :2 21 11
1e 2d 41 4e :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 57 58 :2 55
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
74 77 :2 27 7b 7e :2 27 8a 8d
:2 27 95 98 :2 27 a4 a7 ae b7
ba :2 a7 :2 27 :2 10 5b :2 d :2 a :4 16
:2 a 7 :3 39 4 39 a 13 21
:2 a 26 24 :2 2f :2 24 11 1e 2d
4b 58 :2 a :2 13 1f a 7 :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 57 58 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 8a 8d :2 27 95
98 :2 27 a4 a7 ae b7 ba :2 a7
:2 27 :2 10 5b :2 d :2 a :4 16 :2 a 7
:3 3c 4 3c 39 a 13 21 :2 a
26 24 :2 2f :2 24 11 1e 2d 46
53 :2 a :2 13 1f a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 57 58 :2 55 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 74 77 :2 27
7b 7e :2 27 8a 8d :2 27 95 98
:2 27 a4 a7 ae b7 ba :2 a7 :2 27
:2 10 5b :2 d :2 a :4 16 :2 a 7 :3 40
4 40 39 a 13 21 :2 a 26
24 :2 2f :2 24 11 1e 2d 4a 57
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 57 58 :2 55 :2 2c :3 10 :2 16 1b
27 64 67 :2 27 74 77 :2 27 7b
7e :2 27 8a 8d :2 27 95 98 :2 27
a4 a7 ae b7 ba :2 a7 :2 27 :2 10
5b :2 d :2 a :4 16 :2 a 7 :3 40 4
40 39 a 13 21 :2 a 26 24
:2 2f :2 24 11 1e 2d 48 55 :2 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 8b 8e :2 27 96 99 :2 27 a5
a8 af b8 bb :2 a8 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :3 40 4 40
39 a 13 21 :2 a 26 24 :2 2f
:2 24 11 1e 2d 47 54 :2 a :2 13
1f a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 75 78 :2 27 7c 7f :2 27
8b 8e :2 27 96 99 :2 27 a5 a8
af b8 bb :2 a8 :2 27 :2 10 5c :2 d
:2 a :4 16 :2 a 7 :3 40 4 40 39
a 13 21 :2 a 26 24 :2 2f :2 24
11 1e 2d 48 55 :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 8b
8e :2 27 96 99 :2 27 a5 a8 af
b8 bb :2 a8 :2 27 :2 10 5c :2 d :2 a
:4 16 :2 a 7 :4 40 39 :3 4 :3 f :2 4
:2 d 19 28 36 41 4f 5e 27
:2 19 4 7 :2 11 23 :2 2d 39 3c
4b 4e 4f :2 4b :2 23 :3 7 :2 d 12
1e 5c 5f :2 1e 6c 6f :2 1e 73
76 :2 1e 80 83 8c 94 :2 9d :2 8c
a8 :2 83 :2 1e b0 b3 :2 1e bb be
:2 1e c3 c6 :2 1e ce d1 :2 1e :2 7
52 :3 4 :2 f 21 :2 2a 34 3d :2 4
1 9 12 9 a :2 14 26 :2 30
3c 40 4f 52 53 :2 4f :2 26 :3 a
:2 10 15 21 5f 62 :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 56 :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 4c 4f 50 :2 4c :2 23 :3 7
:2 d 12 1e 5c 5f :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
53 :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
512
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:7 c :6 d :6 e :7 10
:b 12 :11 13 :8 14 :2 13
:2 15 :2 13 :2 15 :2 13
:2 15 :2 13 :2 15 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :2 13 :2 16 :2 13
:2 17 :2 13 :2 17 :2 13
:2 17 :2 13 :2 17 :2 13
:2 17 :4 13 :3 12 :11 1a
:b 1b :3 1a :16 1e :11 1f
:20 20 :3 1f :11 22 :b 23
:3 22 :9 25 :3 1e :3 2a
:3 2b :3 2c :3 2d :b 2f
:6 31 :5 32 30 :2 34
:5 36 :11 37 :24 38 :3 37
:2 35 :6 34 33 :3 2f
3c 2f :b 3c :6 3e
:5 3f 3d :2 41 :5 43
:11 44 :24 45 :3 44 :2 42
:6 41 40 :3 3c 49
3c 2f :b 49 :6 4b
:5 4c 4a :2 4e :5 50
:11 51 :24 52 :3 51 :2 4f
:6 4e 4d :3 49 56
49 2f :b 56 :6 58
:5 59 57 :2 5b :5 5d
:11 5e :24 5f :3 5e :2 5c
:6 5b 5a :3 56 63
56 2f :b 63 :6 65
:5 66 64 :2 68 :5 6a
:11 6b :24 6c :3 6b :2 69
:6 68 67 :3 63 70
63 2f :b 70 :6 72
:5 73 71 :2 75 :5 77
:11 78 :24 79 :3 78 :2 76
:6 75 74 :3 70 7d
70 2f :b 7d :6 7f
:5 80 7e :2 82 :5 84
:11 85 :24 86 :3 85 :2 83
:6 82 81 :4 7d :3 2f
:5 8c :9 8e 8f :3 8e
:11 91 :30 92 :3 91 :a 94
11 :3 97 :11 98 :b 99
:17 9a :3 98 :2 9c :3 9d
:3 9e 9f 9d 9c
9d :3 a0 :3 97 :2 a1
:5 a3 :11 a4 :b a5 :18 a6
:3 a4 :2 a8 a9 :3 aa
ab a9 a8 a9
:3 ac :2 a2 :6 a1 96
:7 1 
11e2
4
:3 0 1 :3 0 2
:a 0 50d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 15 16 0
b 6 :3 0 8
:7 0 11 10 :3 0
9 :3 0 a :3 0
b :2 0 4 13
17 0 50d 2
18 :2 0 d :2 0
12 6 :3 0 d
:2 0 10 1b 1d
:6 0 20 1e 0
50b 0 c :6 0
d :2 0 16 6
:3 0 14 22 24
:6 0 27 25 0
50b 0 e :6 0
d :2 0 1a 6
:3 0 18 29 2b
:6 0 2e 2c 0
50b 0 f :6 0
12 :2 0 1e 6
:3 0 1c 30 32
:6 0 35 33 0
50b 0 10 :6 0
12 :2 0 20 4
:3 0 37 :7 0 3b
38 39 50b 0
11 :6 0 43 44
0 22 4 :3 0
3d :7 0 41 3e
3f 50b 0 13
:6 0 49 4a 0
24 a :3 0 b
:2 0 4 45 :7 0
48 46 0 50b
0 14 :6 0 15
:3 0 16 :3 0 15
:3 0 17 :3 0 4c
4d 0 2 :4 0
26 4e 50 4b
52 51 :2 0 18
:3 0 19 :3 0 54
55 0 1a :4 0
15 :3 0 1b :3 0
58 59 0 2
:4 0 28 5a 5c
1c :4 0 1d :2 0
1e :3 0 2a 5f
61 :3 0 1f :4 0
1d :2 0 20 :3 0
21 :3 0 3 :3 0
2d 66 68 22
:4 0 2f 65 6b
32 64 6d :3 0
1d :2 0 23 :4 0
35 6f 71 :3 0
1d :2 0 24 :4 0
38 73 75 :3 0
1d :2 0 5 :3 0
3b 77 79 :3 0
1d :2 0 24 :4 0
3e 7b 7d :3 0
1d :2 0 23 :4 0
41 7f 81 :3 0
1d :2 0 24 :4 0
44 83 85 :3 0
1d :2 0 7 :3 0
47 87 89 :3 0
1d :2 0 24 :4 0
4a 8b 8d :3 0
1d :2 0 23 :4 0
4d 8f 91 :3 0
1d :2 0 24 :4 0
50 93 95 :3 0
1d :2 0 8 :3 0
53 97 99 :3 0
1d :2 0 24 :4 0
56 9b 9d :3 0
1d :2 0 25 :4 0
59 9f a1 :3 0
5c 56 a3 :2 0
a5 61 a6 53
a5 0 a7 63
0 46b 15 :3 0
16 :3 0 a8 a9
0 15 :3 0 26
:3 0 ab ac 0
27 :2 0 2 :4 0
28 :2 0 29 :2 0
27 :2 0 65 b1
b3 :3 0 68 ad
b5 aa b7 b6
:2 0 18 :3 0 2a
:3 0 b9 ba 0
1a :4 0 2b :4 0
1d :2 0 1e :3 0
6c be c0 :3 0
6f bb c2 :2 0
c4 72 c5 b8
c4 0 c6 74
0 46b 5 :3 0
2c :2 0 76 c8
c9 :3 0 ca :2 0
cb :2 0 7 :3 0
2c :2 0 78 ce
cf :3 0 d0 :2 0
d1 :2 0 cc d3
d2 :2 0 8 :3 0
2c :2 0 7a d6
d7 :3 0 d8 :2 0
d9 :2 0 d4 db
da :2 0 15 :3 0
16 :3 0 dd de
0 15 :3 0 26
:3 0 e0 e1 0
2d :2 0 2 :4 0
2e :2 0 29 :2 0
27 :2 0 7c e6
e8 :3 0 7f e2
ea df ec eb
:2 0 18 :3 0 2a
:3 0 ee ef 0
1a :4 0 2f :4 0
1d :2 0 1e :3 0
83 f3 f5 :3 0
1d :2 0 30 :4 0
86 f7 f9 :3 0
1d :2 0 31 :4 0
89 fb fd :3 0
1d :2 0 20 :3 0
21 :3 0 32 :3 0
33 :3 0 102 103
0 8c 101 105
22 :4 0 8e 100
108 91 ff 10a
:3 0 94 f0 10c
:2 0 10e 97 10f
ed 10e 0 110
99 0 139 15
:3 0 16 :3 0 111
112 0 15 :3 0
26 :3 0 114 115
0 27 :2 0 2
:4 0 34 :2 0 29
:2 0 27 :2 0 9b
11a 11c :3 0 9e
116 11e 113 120
11f :2 0 18 :3 0
2a :3 0 122 123
0 1a :4 0 35
:4 0 1d :2 0 1e
:3 0 a2 127 129
:3 0 a5 124 12b
:2 0 12d a8 12e
121 12d 0 12f
aa 0 139 36
:3 0 37 :3 0 130
131 0 32 :3 0
33 :3 0 133 134
0 38 :3 0 ac
132 137 :2 0 139
af 13a dc 139
0 13b b3 0
46b c :3 0 5
:3 0 13c 13d 0
46b 10 :3 0 7
:3 0 13f 140 0
46b f :3 0 8
:3 0 142 143 0
46b 11 :3 0 3
:3 0 145 146 0
46b 20 :3 0 11
:3 0 12 :2 0 b5
148 14b 32 :3 0
39 :2 0 3a :3 0
14d 14f 0 ba
14e 151 :3 0 3b
:3 0 13 :3 0 3c
:3 0 3d :3 0 c
:4 0 3e 1 :8 0
15e a :3 0 3f
:3 0 159 15a 0
40 :3 0 15b 15c
0 15e bd 1a8
41 :3 0 a :3 0
3f :3 0 161 162
0 40 :3 0 163
164 0 19e 15
:3 0 16 :3 0 166
167 0 15 :3 0
26 :3 0 169 16a
0 42 :2 0 2
:4 0 43 :2 0 29
:2 0 27 :2 0 c0
16f 171 :3 0 c3
16b 173 168 175
174 :2 0 18 :3 0
2a :3 0 177 178
0 1a :4 0 44
:4 0 1d :2 0 1e
:3 0 c7 17c 17e
:3 0 1d :2 0 30
:4 0 ca 180 182
:3 0 1d :2 0 45
:4 0 cd 184 186
:3 0 1d :2 0 40
:3 0 d0 188 18a
:3 0 1d :2 0 46
:4 0 d3 18c 18e
:3 0 1d :2 0 47
:3 0 48 :3 0 27
:2 0 49 :2 0 d6
191 195 da 190
197 :3 0 dd 179
199 :2 0 19b e0
19c 176 19b 0
19d e2 0 19e
e4 1a1 :3 0 1a1
0 1a1 1a0 19e
19f :6 0 1a3 2
:3 0 e7 1a5 e9
1a4 1a3 :2 0 1a6
eb :2 0 1a8 0
1a8 1a7 15e 1a6
:6 0 1ab 1 :3 0
4a :3 0 ed 409
20 :3 0 11 :3 0
12 :2 0 ef 1ac
1af 32 :3 0 39
:2 0 4b :3 0 1b1
1b3 0 f4 1b2
1b5 :3 0 3b :3 0
13 :3 0 4c :3 0
3d :3 0 c :4 0
4d 1 :8 0 1c2
a :3 0 3f :3 0
1bd 1be 0 40
:3 0 1bf 1c0 0
1c2 f7 20c 41
:3 0 a :3 0 3f
:3 0 1c5 1c6 0
40 :3 0 1c7 1c8
0 202 15 :3 0
16 :3 0 1ca 1cb
0 15 :3 0 26
:3 0 1cd 1ce 0
42 :2 0 2 :4 0
4e :2 0 29 :2 0
27 :2 0 fa 1d3
1d5 :3 0 fd 1cf
1d7 1cc 1d9 1d8
:2 0 18 :3 0 2a
:3 0 1db 1dc 0
1a :4 0 4f :4 0
1d :2 0 1e :3 0
101 1e0 1e2 :3 0
1d :2 0 30 :4 0
104 1e4 1e6 :3 0
1d :2 0 45 :4 0
107 1e8 1ea :3 0
1d :2 0 40 :3 0
10a 1ec 1ee :3 0
1d :2 0 46 :4 0
10d 1f0 1f2 :3 0
1d :2 0 47 :3 0
48 :3 0 27 :2 0
49 :2 0 110 1f5
1f9 114 1f4 1fb
:3 0 117 1dd 1fd
:2 0 1ff 11a 200
1da 1ff 0 201
11c 0 202 11e
205 :3 0 205 0
205 204 202 203
:6 0 207 4 :3 0
121 209 123 208
207 :2 0 20a 125
:2 0 20c 0 20c
20b 1c2 20a :6 0
20f 1 :3 0 4a
:3 0 127 210 1b6
20f 0 40a 20
:3 0 11 :3 0 12
:2 0 129 211 214
32 :3 0 39 :2 0
50 :3 0 216 218
0 12e 217 21a
:3 0 3b :3 0 13
:3 0 51 :3 0 3d
:3 0 c :4 0 52
1 :8 0 227 a
:3 0 3f :3 0 222
223 0 40 :3 0
224 225 0 227
131 271 41 :3 0
a :3 0 3f :3 0
22a 22b 0 40
:3 0 22c 22d 0
267 15 :3 0 16
:3 0 22f 230 0
15 :3 0 26 :3 0
232 233 0 42
:2 0 2 :4 0 53
:2 0 29 :2 0 27
:2 0 134 238 23a
:3 0 137 234 23c
231 23e 23d :2 0
18 :3 0 2a :3 0
240 241 0 1a
:4 0 54 :4 0 1d
:2 0 1e :3 0 13b
245 247 :3 0 1d
:2 0 30 :4 0 13e
249 24b :3 0 1d
:2 0 45 :4 0 141
24d 24f :3 0 1d
:2 0 40 :3 0 144
251 253 :3 0 1d
:2 0 46 :4 0 147
255 257 :3 0 1d
:2 0 47 :3 0 48
:3 0 27 :2 0 49
:2 0 14a 25a 25e
14e 259 260 :3 0
151 242 262 :2 0
264 154 265 23f
264 0 266 156
0 267 158 26a
:3 0 26a 0 26a
269 267 268 :6 0
26c 6 :3 0 15b
26e 15d 26d 26c
:2 0 26f 15f :2 0
271 0 271 270
227 26f :6 0 274
1 :3 0 4a :3 0
161 275 21b 274
0 40a 20 :3 0
11 :3 0 12 :2 0
163 276 279 32
:3 0 39 :2 0 55
:3 0 27b 27d 0
168 27c 27f :3 0
3b :3 0 13 :3 0
56 :3 0 3d :3 0
c :4 0 57 1
:8 0 28c a :3 0
3f :3 0 287 288
0 40 :3 0 289
28a 0 28c 16b
2d6 41 :3 0 a
:3 0 3f :3 0 28f
290 0 40 :3 0
291 292 0 2cc
15 :3 0 16 :3 0
294 295 0 15
:3 0 26 :3 0 297
298 0 42 :2 0
2 :4 0 58 :2 0
29 :2 0 27 :2 0
16e 29d 29f :3 0
171 299 2a1 296
2a3 2a2 :2 0 18
:3 0 2a :3 0 2a5
2a6 0 1a :4 0
59 :4 0 1d :2 0
1e :3 0 175 2aa
2ac :3 0 1d :2 0
30 :4 0 178 2ae
2b0 :3 0 1d :2 0
45 :4 0 17b 2b2
2b4 :3 0 1d :2 0
40 :3 0 17e 2b6
2b8 :3 0 1d :2 0
46 :4 0 181 2ba
2bc :3 0 1d :2 0
47 :3 0 48 :3 0
27 :2 0 49 :2 0
184 2bf 2c3 188
2be 2c5 :3 0 18b
2a7 2c7 :2 0 2c9
18e 2ca 2a4 2c9
0 2cb 190 0
2cc 192 2cf :3 0
2cf 0 2cf 2ce
2cc 2cd :6 0 2d1
8 :3 0 195 2d3
197 2d2 2d1 :2 0
2d4 199 :2 0 2d6
0 2d6 2d5 28c
2d4 :6 0 2d9 1
:3 0 4a :3 0 19b
2da 280 2d9 0
40a 20 :3 0 11
:3 0 12 :2 0 19d
2db 2de 32 :3 0
39 :2 0 5a :3 0
2e0 2e2 0 1a2
2e1 2e4 :3 0 3b
:3 0 13 :3 0 5b
:3 0 3d :3 0 c
:4 0 5c 1 :8 0
2f1 a :3 0 3f
:3 0 2ec 2ed 0
40 :3 0 2ee 2ef
0 2f1 1a5 33b
41 :3 0 a :3 0
3f :3 0 2f4 2f5
0 40 :3 0 2f6
2f7 0 331 15
:3 0 16 :3 0 2f9
2fa 0 15 :3 0
26 :3 0 2fc 2fd
0 42 :2 0 2
:4 0 5d :2 0 29
:2 0 27 :2 0 1a8
302 304 :3 0 1ab
2fe 306 2fb 308
307 :2 0 18 :3 0
2a :3 0 30a 30b
0 1a :4 0 5e
:4 0 1d :2 0 1e
:3 0 1af 30f 311
:3 0 1d :2 0 30
:4 0 1b2 313 315
:3 0 1d :2 0 45
:4 0 1b5 317 319
:3 0 1d :2 0 40
:3 0 1b8 31b 31d
:3 0 1d :2 0 46
:4 0 1bb 31f 321
:3 0 1d :2 0 47
:3 0 48 :3 0 27
:2 0 49 :2 0 1be
324 328 1c2 323
32a :3 0 1c5 30c
32c :2 0 32e 1c8
32f 309 32e 0
330 1ca 0 331
1cc 334 :3 0 334
0 334 333 331
332 :6 0 336 a
:3 0 1cf 338 1d1
337 336 :2 0 339
1d3 :2 0 33b 0
33b 33a 2f1 339
:6 0 33e 1 :3 0
4a :3 0 1d5 33f
2e5 33e 0 40a
20 :3 0 11 :3 0
12 :2 0 1d7 340
343 32 :3 0 39
:2 0 5f :3 0 345
347 0 1dc 346
349 :3 0 3b :3 0
13 :3 0 60 :3 0
3d :3 0 c :4 0
61 1 :8 0 356
a :3 0 3f :3 0
351 352 0 40
:3 0 353 354 0
356 1df 3a0 41
:3 0 a :3 0 3f
:3 0 359 35a 0
40 :3 0 35b 35c
0 396 15 :3 0
16 :3 0 35e 35f
0 15 :3 0 26
:3 0 361 362 0
42 :2 0 2 :4 0
62 :2 0 29 :2 0
27 :2 0 1e2 367
369 :3 0 1e5 363
36b 360 36d 36c
:2 0 18 :3 0 2a
:3 0 36f 370 0
1a :4 0 63 :4 0
1d :2 0 1e :3 0
1e9 374 376 :3 0
1d :2 0 30 :4 0
1ec 378 37a :3 0
1d :2 0 45 :4 0
1ef 37c 37e :3 0
1d :2 0 40 :3 0
1f2 380 382 :3 0
1d :2 0 46 :4 0
1f5 384 386 :3 0
1d :2 0 47 :3 0
48 :3 0 27 :2 0
49 :2 0 1f8 389
38d 1fc 388 38f
:3 0 1ff 371 391
:2 0 393 202 394
36e 393 0 395
204 0 396 206
399 :3 0 399 0
399 398 396 397
:6 0 39b c :3 0
209 39d 20b 39c
39b :2 0 39e 20d
:2 0 3a0 0 3a0
39f 356 39e :6 0
3a3 1 :3 0 4a
:3 0 20f 3a4 34a
3a3 0 40a 20
:3 0 11 :3 0 12
:2 0 211 3a5 3a8
32 :3 0 39 :2 0
64 :3 0 3aa 3ac
0 216 3ab 3ae
:3 0 3b :3 0 13
:3 0 65 :3 0 3d
:3 0 c :4 0 66
1 :8 0 3bb a
:3 0 3f :3 0 3b6
3b7 0 40 :3 0
3b8 3b9 0 3bb
219 405 41 :3 0
a :3 0 3f :3 0
3be 3bf 0 40
:3 0 3c0 3c1 0
3fb 15 :3 0 16
:3 0 3c3 3c4 0
15 :3 0 26 :3 0
3c6 3c7 0 42
:2 0 2 :4 0 67
:2 0 29 :2 0 27
:2 0 21c 3cc 3ce
:3 0 21f 3c8 3d0
3c5 3d2 3d1 :2 0
18 :3 0 2a :3 0
3d4 3d5 0 1a
:4 0 68 :4 0 1d
:2 0 1e :3 0 223
3d9 3db :3 0 1d
:2 0 30 :4 0 226
3dd 3df :3 0 1d
:2 0 45 :4 0 229
3e1 3e3 :3 0 1d
:2 0 40 :3 0 22c
3e5 3e7 :3 0 1d
:2 0 46 :4 0 22f
3e9 3eb :3 0 1d
:2 0 47 :3 0 48
:3 0 27 :2 0 49
:2 0 232 3ee 3f2
236 3ed 3f4 :3 0
239 3d6 3f6 :2 0
3f8 23c 3f9 3d3
3f8 0 3fa 23e
0 3fb 240 3fe
:3 0 3fe 0 3fe
3fd 3fb 3fc :6 0
400 e :3 0 243
402 245 401 400
:2 0 403 247 :2 0
405 0 405 404
3bb 403 :6 0 407
1 :3 0 249 408
3af 407 0 40a
152 1ab 0 40a
24b 0 46b e
:3 0 69 :4 0 40c
40d :3 0 40b 40e
0 46b a :3 0
3f :3 0 410 411
0 6a :3 0 11
:3 0 13 :3 0 c
:3 0 10 :3 0 f
:3 0 e :3 0 253
413 41a 412 41b
0 46b 15 :3 0
16 :3 0 41d 41e
0 15 :3 0 26
:3 0 420 421 0
6b :2 0 2 :4 0
6c :2 0 29 :2 0
27 :2 0 25a 426
428 :3 0 25d 422
42a 41f 42c 42b
:2 0 18 :3 0 2a
:3 0 42e 42f 0
1a :4 0 6d :4 0
1d :2 0 1e :3 0
261 433 435 :3 0
1d :2 0 30 :4 0
264 437 439 :3 0
1d :2 0 31 :4 0
267 43b 43d :3 0
1d :2 0 20 :3 0
21 :3 0 a :3 0
3f :3 0 442 443
0 26a 441 445
22 :4 0 26c 440
448 26f 43f 44a
:3 0 1d :2 0 6e
:4 0 272 44c 44e
:3 0 1d :2 0 24
:4 0 275 450 452
:3 0 1d :2 0 e
:3 0 278 454 456
:3 0 1d :2 0 24
:4 0 27b 458 45a
:3 0 27e 430 45c
:2 0 45e 281 45f
42d 45e 0 460
283 0 46b 36
:3 0 6f :3 0 461
462 0 a :3 0
3f :3 0 464 465
0 e :3 0 38
:3 0 285 463 469
:2 0 46b 289 50c
a :3 0 70 :2 0
4 46c 46d 0
15 :3 0 16 :3 0
46f 470 0 15
:3 0 26 :3 0 472
473 0 42 :2 0
2 :4 0 71 :2 0
29 :2 0 27 :2 0
296 478 47a :3 0
299 474 47c 471
47e 47d :2 0 18
:3 0 2a :3 0 480
481 0 1a :4 0
72 :4 0 1d :2 0
1e :3 0 29d 485
487 :3 0 2a0 482
489 :2 0 4a2 18
:3 0 2a :3 0 48b
48c 0 1a :4 0
73 :4 0 1d :2 0
a :3 0 74 :3 0
491 492 0 2a3
490 494 :3 0 1d
:2 0 6e :4 0 2a6
496 498 :3 0 1d
:2 0 a :3 0 75
:3 0 49b 49c 0
2a9 49a 49e :3 0
2ac 48d 4a0 :2 0
4a2 2af 4a3 47f
4a2 0 4a4 2b2
0 4b4 76 :3 0
14 :3 0 a :3 0
74 :3 0 77 :3 0
a :3 0 75 :3 0
5 :3 0 78 :4 0
79 1 :a 0 4b0
:2 0 4b4 4a6 4ae
:2 0 9 :3 0 14
:3 0 4b2 :2 0 4b4
2b4 4b6 2b8 4b5
4b4 :2 0 50a 41
:3 0 a :3 0 3f
:3 0 4b9 4ba 0
40 :3 0 4bb 4bc
0 502 15 :3 0
16 :3 0 4be 4bf
0 15 :3 0 26
:3 0 4c1 4c2 0
42 :2 0 2 :4 0
7a :2 0 29 :2 0
27 :2 0 2ba 4c7
4c9 :3 0 2bd 4c3
4cb 4c0 4cd 4cc
:2 0 18 :3 0 2a
:3 0 4cf 4d0 0
1a :4 0 7b :4 0
1d :2 0 1e :3 0
2c1 4d4 4d6 :3 0
2c4 4d1 4d8 :2 0
4f2 18 :3 0 2a
:3 0 4da 4db 0
1a :4 0 45 :4 0
1d :2 0 40 :3 0
2c7 4df 4e1 :3 0
1d :2 0 46 :4 0
2ca 4e3 4e5 :3 0
1d :2 0 47 :3 0
48 :3 0 27 :2 0
49 :2 0 2cd 4e8
4ec 2d1 4e7 4ee
:3 0 2d4 4dc 4f0
:2 0 4f2 2d7 4f3
4ce 4f2 0 4f4
2da 0 502 76
:3 0 14 :3 0 77
:3 0 a :3 0 75
:3 0 5 :3 0 78
:4 0 7c 1 :a 0
4fe :2 0 502 4f6
4fc :2 0 9 :3 0
14 :3 0 500 :2 0
502 2dc 505 :3 0
505 0 505 504
502 503 :6 0 507
1 :3 0 2e1 509
2e3 508 507 :2 0
50a 2e5 :2 0 50c
2e8 50c 50b 46b
50a :6 0 50d :2 0
2 18 50c 510
:3 0 50f 50d 511
:8 0 
2f0
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 31
1 2f 1 36
1 3c 1 42
1 4f 1 5b
2 5e 60 1
67 2 69 6a
2 63 6c 2
6e 70 2 72
74 2 76 78
2 7a 7c 2
7e 80 2 82
84 2 86 88
2 8a 8c 2
8e 90 2 92
94 2 96 98
2 9a 9c 2
9e a0 4 57
5d 62 a2 1
a4 1 a6 2
b0 b2 3 ae
af b4 2 bd
bf 2 bc c1
1 c3 1 c5
1 c7 1 cd
1 d5 2 e5
e7 3 e3 e4
e9 2 f2 f4
2 f6 f8 2
fa fc 1 104
2 106 107 2
fe 109 2 f1
10b 1 10d 1
10f 2 119 11b
3 117 118 11d
2 126 128 2
125 12a 1 12c
1 12e 2 135
136 3 110 12f
138 1 13a 2
149 14a 1 150
2 14c 150 2
158 15d 2 16e
170 3 16c 16d
172 2 17b 17d
2 17f 181 2
183 185 2 187
189 2 18b 18d
3 192 193 194
2 18f 196 2
17a 198 1 19a
1 19c 2 165
19d 1 1a1 1
160 1 1a5 1
1a8 2 1ad 1ae
1 1b4 2 1b0
1b4 2 1bc 1c1
2 1d2 1d4 3
1d0 1d1 1d6 2
1df 1e1 2 1e3
1e5 2 1e7 1e9
2 1eb 1ed 2
1ef 1f1 3 1f6
1f7 1f8 2 1f3
1fa 2 1de 1fc
1 1fe 1 200
2 1c9 201 1
205 1 1c4 1
209 1 20c 2
212 213 1 219
2 215 219 2
221 226 2 237
239 3 235 236
23b 2 244 246
2 248 24a 2
24c 24e 2 250
252 2 254 256
3 25b 25c 25d
2 258 25f 2
243 261 1 263
1 265 2 22e
266 1 26a 1
229 1 26e 1
271 2 277 278
1 27e 2 27a
27e 2 286 28b
2 29c 29e 3
29a 29b 2a0 2
2a9 2ab 2 2ad
2af 2 2b1 2b3
2 2b5 2b7 2
2b9 2bb 3 2c0
2c1 2c2 2 2bd
2c4 2 2a8 2c6
1 2c8 1 2ca
2 293 2cb 1
2cf 1 28e 1
2d3 1 2d6 2
2dc 2dd 1 2e3
2 2df 2e3 2
2eb 2f0 2 301
303 3 2ff 300
305 2 30e 310
2 312 314 2
316 318 2 31a
31c 2 31e 320
3 325 326 327
2 322 329 2
30d 32b 1 32d
1 32f 2 2f8
330 1 334 1
2f3 1 338 1
33b 2 341 342
1 348 2 344
348 2 350 355
2 366 368 3
364 365 36a 2
373 375 2 377
379 2 37b 37d
2 37f 381 2
383 385 3 38a
38b 38c 2 387
38e 2 372 390
1 392 1 394
2 35d 395 1
399 1 358 1
39d 1 3a0 2
3a6 3a7 1 3ad
2 3a9 3ad 2
3b5 3ba 2 3cb
3cd 3 3c9 3ca
3cf 2 3d8 3da
2 3dc 3de 2
3e0 3e2 2 3e4
3e6 2 3e8 3ea
3 3ef 3f0 3f1
2 3ec 3f3 2
3d7 3f5 1 3f7
1 3f9 2 3c2
3fa 1 3fe 1
3bd 1 402 1
405 7 409 210
275 2da 33f 3a4
408 6 414 415
416 417 418 419
2 425 427 3
423 424 429 2
432 434 2 436
438 2 43a 43c
1 444 2 446
447 2 43e 449
2 44b 44d 2
44f 451 2 453
455 2 457 459
2 431 45b 1
45d 1 45f 3
466 467 468 c
a7 c6 13b 13e
141 144 147 40a
40f 41c 460 46a
2 477 479 3
475 476 47b 2
484 486 2 483
488 2 48f 493
2 495 497 2
499 49d 2 48e
49f 2 48a 4a1
1 4a3 3 4a4
4af 4b3 1 46e
2 4c6 4c8 3
4c4 4c5 4ca 2
4d3 4d5 2 4d2
4d7 2 4de 4e0
2 4e2 4e4 3
4e9 4ea 4eb 2
4e6 4ed 2 4dd
4ef 2 4d9 4f1
1 4f3 4 4bd
4f4 4fd 501 1
505 1 4b8 2
4b6 509 7 1f
26 2d 34 3a
40 47 
1
4
0 
510
0
1
14
10
c
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
0 0 0 0 
f 1 0
1a 1 0
2f 1 0
7 1 0
b 1 0
3c 1 0
21 1 0
36 1 0
28 1 0
3 1 0
2 0 1
42 1 0
0

/
SHOW ERRORS FUNCTION SP_A_DOCRES;
ALTER FUNCTION SP_A_DOCRES COMPILE DEBUG;
/*****************************************************************************************/
Prompt == FUNCTION FC_U_CREATETMPTABLE ==
CREATE OR REPLACE FUNCTION FC_U_CREATETMPTABLE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1f
2 :e:
1FUNCTION:
1FC_U_CREATETMPTABLE:
1RETURN:
1PLS_INTEGER:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_CREATETMPTABLE();:
1CHECK_TRACE:
11:
18:
1+:
1FPUT:
1               ENTER:: FC_U_CREATETMPTABLE(9) :: cplan.sql(6661) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN01_TEMP:
1PMO_DB2M:
1SC_STATE:
10:
117:
1                EXIT:: FC_U_CREATETMPTABLE(18) :: cplan.sql(6670) :: :
1 :
1STATE:: :
0

0
0
8c
2
0 a0 8d a0 b4 a0 2c 6a
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6e 11e 11d :2 a0 6b 51 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 a4 b1 11 68 4f
1d 17 b5 
8c
2
0 3 f b a 23 27 2b
2f 33 7 37 3b 3f 42 47
48 1 4a 4f 53 57 5a 5f
63 67 6a 6f 70 72 77 7a
7e 7f 84 89 8a 8f 91 95
98 9c a0 a3 a7 ab ae b1
b6 b9 bc bf c0 c5 c6 1
c8 cd d1 d5 d8 dd e2 e5
e9 ea ef f0 f5 f7 fb fe
102 106 10b 110 114 118 11c 11f
122 126 12a 12e 131 135 139 13c
13f 144 147 14a 14d 14e 153 154
1 156 15b 15f 163 166 16b 170
173 177 178 17d 180 185 186 18b
18e 193 194 199 19c 1a0 1a4 1a7
1a8 1ad 1ae 1b3 1b5 1b9 1bc 1c0
1c4 1c8 1cb 1cf 1d1 1d5 1d7 1e3
1e7 1e9 1ea 1f3 
8c
2
0 1 a 1e 0 25 :2 1 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 5b 61 64 :2 5b
72 :2 7 51 :2 4 7 :2 11 23 :2 2d
39 3c 53 54 55 :2 53 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 58
:3 4 c 16 :3 4 :2 d 19 4 7
:2 11 23 :2 2d 39 3c 53 55 56
:2 53 :2 23 :3 7 :2 d 12 1e 63 66
:2 1e 73 76 :2 1e 7a 7d :2 1e 87
8a :2 93 :2 1e :2 7 59 :3 4 b :2 14
4 :9 1 
8c
4
0 :3 1 0 :3 1
:b 4 :12 5 :3 4 :11 8
:b 9 :3 8 :5 e :5 f
:11 11 :19 12 :3 11 :5 14
:2 3 :7 1 
1f5
4
:3 0 1 :3 0 8
9 :2 0 3 :3 0
2 :a 0 87 1
:7 0 4 :3 0 4
5 0 87 2
6 :2 0 5 :3 0
6 :3 0 5 :3 0
7 :3 0 b c
0 2 :4 0 3
d f a 11
10 :2 0 8 :3 0
9 :3 0 13 14
0 a :4 0 5
:3 0 b :3 0 17
18 0 2 :4 0
5 19 1b c
:4 0 d :2 0 e
:3 0 7 1e 20
:3 0 f :4 0 a
15 23 :2 0 25
f 26 12 25
0 27 11 0
83 5 :3 0 6
:3 0 28 29 0
5 :3 0 10 :3 0
2b 2c 0 11
:2 0 2 :4 0 12
:2 0 13 :2 0 11
:2 0 13 31 33
:3 0 16 2d 35
2a 37 36 :2 0
8 :3 0 14 :3 0
39 3a 0 a
:4 0 15 :4 0 d
:2 0 e :3 0 1a
3e 40 :3 0 1d
3b 42 :2 0 44
20 45 38 44
0 46 22 0
83 16 :3 0 17
:3 0 18 :4 0 49
:4 0 4a :2 0 83
19 :3 0 1a :3 0
4c 4d 0 1b
:2 0 4e 4f 0
83 5 :3 0 6
:3 0 51 52 0
5 :3 0 10 :3 0
54 55 0 11
:2 0 2 :4 0 1c
:2 0 13 :2 0 11
:2 0 24 5a 5c
:3 0 27 56 5e
53 60 5f :2 0
8 :3 0 14 :3 0
62 63 0 a
:4 0 1d :4 0 d
:2 0 e :3 0 2b
67 69 :3 0 d
:2 0 1e :4 0 2e
6b 6d :3 0 d
:2 0 1f :4 0 31
6f 71 :3 0 d
:2 0 19 :3 0 1a
:3 0 74 75 0
34 73 77 :3 0
37 64 79 :2 0
7b 3a 7c 61
7b 0 7d 3c
0 83 3 :3 0
19 :3 0 1a :3 0
7f 80 0 81
:2 0 83 3e 86
:3 0 86 0 86
85 83 84 :6 0
87 :2 0 2 6
86 8a :3 0 89
87 8b :8 0 
45
4
:3 0 1 e 1
1a 2 1d 1f
4 16 1c 21
22 1 24 1
26 2 30 32
3 2e 2f 34
2 3d 3f 2
3c 41 1 43
1 45 2 59
5b 3 57 58
5d 2 66 68
2 6a 6c 2
6e 70 2 72
76 2 65 78
1 7a 1 7c
6 27 46 4b
50 7d 82 
1
4
0 
8a
0
1
14
1
1
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
0

/
SHOW ERRORS FUNCTION FC_U_CREATETMPTABLE;
ALTER FUNCTION FC_U_CREATETMPTABLE COMPILE DEBUG;
/************************************************************************************************/
/*****************************************************************************************/
Prompt == FUNCTION FC_U_TSKRES2 ==
CREATE OR REPLACE FUNCTION FC_U_TSKRES2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ed
2 :e:
1FUNCTION:
1FC_U_TSKRES2:
1H_ASSIGN_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1H_AND_ROLES:
1H_AND_SKILLS:
1SH_H_WORK_LOCATION:
1PLS_INTEGER:
1H_START_DATE:
1H_FINISH_DATE:
1SH_H_EFFORT:
1SH_H_WORK:
1SH_H_EUNIT:
1SH_H_UNIT:
1SH_H_WORK_TYPE:
1SH_H_BITFLAG:
1SH_H_CONTOUR:
1SH_H_CONTOUR_TYPE:
1SH_H_OCCURRENCE:
1H_ASSIGN_STRING:
1H_REC_USER:
1RETURN:
1H_WORK_LOCATION:
1H_EFFORT:
1H_WORK:
1H_EUNIT:
1H_UNIT:
1H_WORK_TYPE:
1H_BITFLAG:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_OCCURRENCE:
1H_TASK_ID:
132:
1H_RES_ID:
1H_START_DT:
126:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_LAST_SUBMITTED:
1H_TSK_ASSIGNMENT_ID:
1H_PROJECT_ID:
1H_CALENDAR_ID:
1H_SECURITY_ID:
1H_RES_TYPE:
11:
1H_BIT_FLAG:
1H_FULL_NAME:
1255:
1H_NULL_STR:
1H_MIN_PER_DAY:
10:
1H_TYPE:
1H_PER_WEEK:
1H_CONSIDER:
1H_ROLLUP:
1H_CRI:
1H_TEMP_SC_STATE:
1H_TRANSFED_CRI:
1H_WORK_TODATE:
1H_TEMP_VAR:
1H_TEMP_SECURITY_ID:
1H_TEMP2_SECURITY_ID:
1H_SD:
1H_FD:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DURATION:
1H_PERCENT_UNITS:
1H_SCHED_WORK:
1H_PRIORITY:
1H_UPDATE:
1H_ZERO:
1H_RES_COST:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_TSKRES2(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
194:
1+:
1FPUT:
1               ENTER:: FC_U_TSKRES2(95) :: cplan.sql(6777) :: :
1PMO_CNST:
1>=:
1SC_BIT_30:
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1ELSIF:
1SC_BIT_28:
1SC_BIT_NOT_28:
10.00:
1=:
1PROJECT_ID:
1TASK_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1LAST_SUBMITTED:
1WORK_TODATE:
1TO_DATE:
1SUBSTR:
1SCHED_START:
1SCHED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT:n         PROJECT_ID,:n         TASK_ID,:n         RESOURCE_ID,:n     +
1    RESOURCE_TYPE,:n         LAST_SUBMITTED,:n         WORK_TODATE,:n        +
1 TO_DATE(SubStr(SCHED_START, 1, 10)),:n         TO_DATE(SubStr(SCHED_FINISH, +
11, 10)),:n         BILLABLE,:n         CAPITAL_EXPENSE,:n         REGULAR_COS+
1T,:n         REGULAR_RATE:n         INTO:n         h_project_id,:n         h_+
1task_id,:n         h_res_id,:n         h_res_type,:n         h_last_submitted+
1,:n         h_work_todate,:n         h_SD,:n         h_FD,:n         h_billab+
1le,:n         h_capital_expense,:n         h_reg_cost,:n         h_reg_sale:n+
1         FROM TASK_ASSIGNMENTS:n         WHERE TSK_ASSIGNMENT_ID = h_tsk_assi+
1gnment_id:
1PMO_DB2M:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1163:
1           EXCEPTION:: FC_U_TSKRES2(164) :: cplan.sql(6846) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1170:
1                EXIT:: FC_U_TSKRES2(171) :: cplan.sql(6853) :: :
1RECORD_NOT_FOUND:
1ELEMENT_ID:
1ELEMENT_TYPE:
1SECURITY_ID:
1CRI_SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1RES_ASSIGNMENT_ID:
1SELECT PROJECT_ID, ELEMENT_ID, RESOURCE_ID, ELEMENT_TYPE, :n         RESOURCE+
1_TYPE, SECURITY_ID, CASE WHEN CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END:n    +
1     INTO h_project_id, h_task_id, h_res_id, h_type,:n         h_res_type, h_+
1security_id, h_transfed_cri:n         FROM RESOURCE_ASSIGNMENTS :n         WH+
1ERE RES_ASSIGNMENT_ID = h_assign_id:
1188:
1           EXCEPTION:: FC_U_TSKRES2(189) :: cplan.sql(6871) :: :
1195:
1                EXIT:: FC_U_TSKRES2(196) :: cplan.sql(6878) :: :
1ISWBSTRANSFEREDDELIV:
1!=:
1200:
1                EXIT:: FC_U_TSKRES2(201) :: cplan.sql(6883) :: :
1TASK_ASSIGNMENT_ERROR:
1WORK_LOCATION:
1UPDATE RESOURCE_ASSIGNMENTS SET WORK_LOCATION = h_work_location:n         WHE+
1RE RES_ASSIGNMENT_ID = h_assign_id:
1FOUND:
1TRUE:
1100:
1218:
1           EXCEPTION:: FC_U_TSKRES2(219) :: cplan.sql(6901) :: :
1ISPROJECTTYPE:
1NOT:
1SELECT TSK_ASSIGNMENT_ID INTO h_tsk_assignment_id:n            FROM TASK_ASSI+
1GNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
1233:
1           EXCEPTION:: FC_U_TSKRES2(234) :: cplan.sql(6916) :: :
1SC_SQL_SUCCESS:
1240:
1                EXIT:: FC_U_TSKRES2(241) :: cplan.sql(6923) :: :
1RECORD_ALREADY_ASSIGNED:
1FC_AFTER_U_RES_ASSIGN:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1CALENDAR_ID:
1PRIORITY:
1TMT_WBS:
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), CALEND+
1AR_ID, PRIORITY:n      INTO h_min_per_day, h_per_week, h_calendar_id, h_prior+
1ity:n      FROM TMT_WBS WHERE ELEMENT_ID = h_project_id:
1260:
1           EXCEPTION:: FC_U_TSKRES2(261) :: cplan.sql(6943) :: :
1>:
15:
1*:
1IS NULL:
1SUM:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1DAY_YEAR:
1SELECT SUM(AVAILABLE_MIN) INTO h_effort FROM CALENDAR_DAY_OF_YEAR:n          +
1     WHERE ELEMENT_ID=h_project_id AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_star+
1t_date, 1, 10)) AND TO_DATE(SubStr(h_finish_date, 1, 10)):
1286:
1           EXCEPTION:: FC_U_TSKRES2(287) :: cplan.sql(6969) :: :
160:
12:
13:
1303:
1                EXIT:: FC_U_TSKRES2(304) :: cplan.sql(6986) :: :
1SC_BIT_NOT_30:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1BIT_FLAG:
1SELECT TSK_ASSIGNMENT_ID, UNRESOLVED_START, UNRESOLVED_FINISH, PLANNED_WORK+S+
1CHED_WORK, BIT_FLAG:n         INTO h_tsk_assignment_id, h_start_DT, h_finish_+
1DT, h_sched_work, h_bit_flag:n         FROM TASK_ASSIGNMENTS:n         WHERE +
1PROJECT_ID = h_project_id AND TASK_ID = h_project_id AND RESOURCE_ID = h_res_+
1id:
1324:
1           EXCEPTION:: FC_U_TSKRES2(325) :: cplan.sql(7007) :: :
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1BIT_OR:
1<:
1FC_DECLARE_PMO_TMP_SEARCH:
1SC_SRCH_FROM_PROJECT:
1FC_SEARCH_2:
1ETC:
1UPDATE TASK_ASSIGNMENTS SET ETC = h_effort:n                  WHERE RES_ASSIG+
1NMENT_ID = h_assign_id:
1373:
1           EXCEPTION:: FC_U_TSKRES2(374) :: cplan.sql(7056) :: :
1379:
1                EXIT:: FC_U_TSKRES2(380) :: cplan.sql(7062) :: :
1U_TSKRES2:
1110:
1RESOURCE_UNAVAILABLE:
1473:
1                EXIT:: FC_U_TSKRES2(474) :: cplan.sql(7156) :: :
1STATE:: :
0

0
0
aa8
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 8f
a0 b0 3d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 90
:3 a0 b0 3f 90 :3 a0 b0 3f b4
:2 a0 2c 6a a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 51 a5 b a0 7e
a0 6b b4 2e :3 a0 6b :3 a0 51
a5 b :2 a0 6b a5 b 5a 51
a5 b d :4 a0 51 a5 b :2 a0
6b a5 b d a0 51 d a0
51 d a0 b7 :2 a0 51 a5 b
a0 7e a0 6b b4 2e :4 a0 51
a5 b :2 a0 6b a5 b 5a d
:4 a0 51 a5 b :2 a0 6b a5 b
5a d a0 51 d b7 19 :3 a0
51 a5 b d a0 51 d a0
51 d b7 :2 19 3c a0 51 d
a0 6e d a0 51 d a0 4d
d a0 4d d a0 4d d a0
4d d a0 51 d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d :1f a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c b7 :11 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 a0
b7 :3 a0 51 a5 b a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 :2 19 3c :5 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 51 a5
b a5 b 5a 7e 51 b4 2e
7e b4 2e :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 19 3c
b7 19 3c :3 a0 a5 b d b7
:2 19 3c :d a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
a0 7e b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d b7 19 3c b7 :d a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 a0 51 a5 b
7e 51 b4 2e :3 a0 51 a5 b
7e 51 b4 2e d a0 b7 :2 a0
51 a5 b 7e 51 b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d b7 :2 19 3c b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :4 a0 51 a5 b
:2 a0 6b a5 b 5a d a0 b7
:2 a0 :2 51 a5 b 7e 6e b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :12 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 7e b4 2e 5a a 10 :4 a0
51 a5 b :2 a0 6b a5 b 5a
d :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 :2 51 a5 b 7e 6e b4
2e :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 19 3c a0
51 d b7 19 3c b7 :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
5a d b7 19 3c :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e a 10 :2 a0 :2 51 a5
b 7e 6e b4 2e a0 51 d
b7 19 3c :2 a0 b4 2e d :3 a0
6b d :20 a0 51 a5 b :3 51 a5
b d b7 19 3c :5 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c a0 51 65 b7 19 3c b7
:2 19 3c b7 19 3c b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 5a 52 10
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b :2 a0 51 a5 b :2 a0 51
a5 b a5 b 5a d b7 19
3c :18 a0 :2 51 a5 b d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b :2 a0 51 a5 b :2 a0 51
a5 b a5 b 5a d b7 19
3c :18 a0 :2 51 a5 b d b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
a 10 :2 a0 6b :2 a0 6b d b7
:2 19 3c :2 a0 6b 7e 51 b4 2e
:2 a0 6b 51 d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 a4 b1 11 68 4f
1d 17 b5 
aa8
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 73 6f 37
7b 8c 80 84 88 6e 93 a8
9c a0 a4 6b af b8 b4 9b
c0 cd c9 98 d5 de da c8
e6 f3 ef c5 fb 104 100 ee
10c 119 115 eb 121 12a 126 114
132 13f 13b 111 147 150 14c 13a
158 16d 161 165 169 137 174 185
179 17d 181 160 18c 15d 191 195
199 19d 1ba 1a5 1a9 1b1 1b5 1a4
1da 1c5 1c9 1d1 1d5 1a1 1f6 1e1
1e5 1ed 1f1 1c4 216 201 205 20d
211 1c1 232 21d 221 229 22d 200
252 23d 241 249 24d 1fd 26e 259
25d 265 269 23c 28e 279 27d 285
289 239 2aa 295 299 2a1 2a5 278
2ca 2b5 2b9 2c1 2c5 275 2e6 2d1
2d5 2d8 2d9 2e1 2b4 303 2f1 2b1
2f5 2f6 2fe 2f0 320 30e 2ed 312
313 31b 30d 33d 32b 30a 32f 330
338 32a 359 348 34c 354 327 371
360 364 36c 347 38e 37c 344 380
381 389 37b 3ab 399 378 39d 39e
3a6 398 3c8 3b6 395 3ba 3bb 3c3
3b5 3e5 3d3 3b2 3d7 3d8 3e0 3d2
402 3f0 3cf 3f4 3f5 3fd 3ef 41f
40d 3ec 411 412 41a 40c 43c 42a
409 42e 42f 437 429 459 447 426
44b 44c 454 446 475 464 468 443
470 463 491 480 484 460 48c 47f
4ad 49c 4a0 47c 4a8 49b 4c9 4b8
4bc 498 4c4 4b7 4e5 4d4 4d8 4b4
4e0 4d3 501 4f0 4f4 4d0 4fc 4ef
51d 50c 510 4ec 518 50b 539 528
52c 508 534 527 555 544 548 524
550 543 571 560 564 540 56c 55f
58e 57c 55c 580 581 589 57b 5ab
599 578 59d 59e 5a6 598 5c7 5b6
5ba 5c2 595 5df 5ce 5d2 5da 5b5
5fb 5ea 5ee 5b2 5f6 5e9 617 606
60a 5e6 612 605 633 622 626 602
62e 621 64f 63e 642 61e 64a 63d
66b 65a 65e 63a 666 659 687 676
67a 656 682 675 6a3 692 696 672
69e 691 6bf 6ae 6b2 68e 6ba 6ad
6db 6ca 6ce 6aa 6d6 6c9 6f7 6e6
6ea 6c6 6f2 6e5 713 702 706 6e2
70e 701 72f 71e 722 6fe 72a 71d
736 73a 71a 73e 742 746 749 74e
74f 1 751 756 75a 75e 761 766
76a 76e 771 776 777 779 77e 781
785 786 78b 790 793 798 799 79e
7a1 7a5 7a6 7ab 7ae 7b3 7b4 7b9
7bc 7c1 7c2 7c7 7ca 7cf 7d0 7d5
7d8 7dc 7dd 7e2 7e5 7ea 7eb 7f0
7f3 7f8 7f9 7fe 801 806 807 80c
80f 813 814 819 81c 821 822 827
82a 82f 830 835 838 83c 840 844
845 847 84c 84d 84f 850 855 858
85d 85e 863 866 86b 86c 871 874
878 879 87e 881 886 887 88c 88f
894 895 89a 89d 8a2 8a3 8a8 8ab
8af 8b0 8b5 8b8 8bd 8be 8c3 8c6
8cb 8cc 8d1 8d4 8d8 8dc 8e0 8e1
8e3 8e8 8e9 8eb 8ec 8f1 8f4 8f9
8fa 8ff 902 906 90a 90e 90f 911
916 917 919 91a 91f 922 927 928
92d 930 934 938 93c 93d 93f 944
945 947 948 94d 950 955 956 95b
95e 962 966 96a 96b 96d 972 973
975 976 97b 97e 983 984 989 98c
990 994 998 999 99b 9a0 9a1 9a3
9a4 9a9 9ac 9b1 9b2 9b7 9ba 9be
9c2 9c6 9c7 9c9 9ce 9cf 9d1 9d2
9d7 9da 9df 9e0 9e5 9e8 9ec 9f0
9f4 9f5 9f7 9fc 9fd 9ff a00 a05
a08 a0d a0e a13 a16 a1a a1e a22
a23 a25 a2a a2b a2d a2e a33 a36
a3b a3c a41 a44 a48 a4c a50 a51
a53 a58 a59 a5b a5c a61 a64 a69
a6a a6f a72 a77 a78 a7d a80 a84
a85 a8a a8d a92 a93 a98 a9b aa0
aa1 aa6 aa9 aae aaf ab4 ab7 abb
abc ac1 ac4 ac9 aca acf ad2 ad7
ad8 add ade ae3 ae5 ae9 aec af0
af4 af7 afb aff b02 b05 b0a b0d
b10 b13 b14 b19 b1a 1 b1c b21
b25 b29 b2c b31 b36 b39 b3d b3e
b43 b44 b49 b4b b4f b52 b56 b5a
b5d b5e b60 b64 b67 b6b b6e b6f
b74 b78 b7c b80 b83 b87 b8b b8f
b92 b93 b95 b99 b9d ba0 ba1 ba3
ba6 ba9 baa bac bb0 bb4 bb8 bbc
bc0 bc3 bc4 bc6 bca bce bd1 bd2
bd4 bd8 bdc bdf be3 be7 bea bee
bf2 bf4 bf8 bfc bff c00 c02 c06
c09 c0d c10 c11 c16 c1a c1e c22
c26 c29 c2a c2c c30 c34 c37 c38
c3a c3d c41 c45 c49 c4d c51 c54
c55 c57 c5b c5f c62 c63 c65 c68
c6c c70 c73 c77 c79 c7d c81 c85
c89 c8c c8d c8f c93 c97 c9a c9e
ca2 ca5 ca9 cab caf cb3 cb6 cba
cbd cc1 cc5 cca cce cd2 cd5 cd9
cdd cde ce2 ce6 ce7 ceb cef cf0
cf4 cf8 cf9 cfd d01 d04 d08 d0c
d10 d13 d14 d16 d19 d1c d1d d22
d26 d2a d2e d32 d36 d3a d3e d42
d46 d4a d4e d52 d56 d5a d5e d62
d66 d6a d6e d72 d76 d7a d7e d82
d86 d8a d8e d92 d96 d9a d9e da2
da6 daa db6 dba dbe dc1 dc5 dc9
dcb 1 dcf dd3 dd7 dda dde de2
de6 dea ded df1 df5 df8 dfb e00
e03 e06 e09 e0a e0f e10 1 e12
e17 e1b e1f e22 e27 e2c e2f e33
e34 e39 e3c e41 e42 e47 e4a e4f
e50 e55 e58 e5c e5d e62 e65 e6a
e6b e70 e73 e77 e7b e7e e81 e82
e84 e85 e8a e8b e90 e92 e96 e99
e9b e9f ea1 ead eaf eb1 eb2 eb7
ebb ebd ec9 ecb ecf ed3 ed6 eda
edd ee1 ee4 ee5 eea eed ef1 ef5
ef8 efc f00 f03 f06 f0b f0e f11
f14 f15 f1a f1b 1 f1d f22 f26
f2a f2d f32 f37 f3a f3e f3f f44
f45 f4a f4c f50 f53 f57 f5b f5f
f62 f66 f68 f6c f6f f71 f75 f79
f7d f81 f85 f89 f8d f91 f95 f99
f9d fa1 fa5 fa9 fad fb1 fb5 fc1
fc5 fc9 fcc fd0 fd4 fd6 1 fda
fde fe2 fe5 fe9 fed ff1 ff5 ff8
ffc 1000 1003 1006 100b 100e 1011 1014
1015 101a 101b 1 101d 1022 1026 102a
102d 1032 1037 103a 103e 103f 1044 1047
104c 104d 1052 1055 105a 105b 1060 1063
1067 1068 106d 1070 1075 1076 107b 107e
1082 1086 1089 108c 108d 108f 1090 1095
1096 109b 109d 10a1 10a4 10a6 10aa 10ac
10b8 10ba 10bc 10bd 10c2 10c6 10c8 10d4
10d6 10da 10de 10e1 10e5 10e8 10ec 10ef
10f0 10f5 10f8 10fc 1100 1103 1107 110b
110e 1111 1116 1119 111c 111f 1120 1125
1126 1 1128 112d 1131 1135 1138 113d
1142 1145 1149 114a 114f 1150 1155 1157
115b 115e 1162 1166 116a 116d 1171 1175
1177 117b 117f 1183 1186 1187 1189 118a
118c 118f 1192 1193 1198 119c 11a0 11a3
11a7 11ab 11ae 11b1 11b6 11b9 11bc 11bf
11c0 11c5 11c6 1 11c8 11cd 11d1 11d5
11d8 11dd 11e2 11e5 11e9 11ea 11ef 11f0
11f5 11f7 11fb 11fe 1202 1206 120a 120d
1211 1213 1217 121b 121e 1222 1226 122a
122e 1232 123e 1242 1247 124b 124e 124f
1254 1258 125c 125f 1262 1266 1268 126c
1270 1273 1276 127a 127c 1280 1284 1287
1289 1 128d 1291 1295 1298 129c 12a0
12a4 12a8 12ab 12af 12b3 12b6 12b9 12be
12c1 12c4 12c7 12c8 12cd 12ce 1 12d0
12d5 12d9 12dd 12e0 12e5 12ea 12ed 12f1
12f2 12f7 12fa 12ff 1300 1305 1308 130d
130e 1313 1316 131a 131b 1320 1323 1328
1329 132e 1331 1335 1339 133c 133f 1340
1342 1343 1348 1349 134e 1350 1354 1357
1359 135d 135f 136b 136d 136f 1370 1375
1379 137b 1387 1389 138d 1391 1395 1398
1399 139b 139c 139e 13a1 13a4 13a7 13a8
13ad 13b0 13b1 13b6 13ba 13be 13c2 13c6
13ca 13d6 13da 13de 13e1 13e5 13e9 13eb
1 13ef 13f3 13f7 13fa 13fe 1402 1406
140a 140d 1411 1415 1418 141b 1420 1423
1426 1429 142a 142f 1430 1 1432 1437
143b 143f 1442 1447 144c 144f 1453 1454
1459 145c 1461 1462 1467 146a 146f 1470
1475 1478 147c 147d 1482 1485 148a 148b
1490 1493 1497 149b 149e 14a1 14a2 14a4
14a5 14aa 14ab 14b0 14b2 14b6 14b9 14bb
14bf 14c1 14cd 14cf 14d1 14d2 14d7 14db
14dd 14e9 14eb 14ef 14f3 14f6 14fa 14fd
1501 1504 1505 150a 150d 1511 1515 1518
151c 1520 1523 1526 152b 152e 1531 1534
1535 153a 153b 1 153d 1542 1546 154a
154d 1552 1557 155a 155e 155f 1564 1565
156a 156c 1570 1573 1577 157b 157f 1582
1586 1588 158c 158f 1591 1595 1598 159c
15a0 15a4 15a5 15a7 15ab 15ad 15b1 15b5
15b8 15bc 15c0 15c4 15c8 15cc 15d0 15d4
15d8 15dc 15e0 15e4 15e8 15ec 15f8 15fc
1600 1603 1607 160b 160d 1 1611 1615
1619 161c 1620 1624 1628 162c 162f 1633
1637 163a 163d 1642 1645 1648 164b 164c
1651 1652 1 1654 1659 165d 1661 1664
1669 166e 1671 1675 1676 167b 167e 1683
1684 1689 168c 1691 1692 1697 169a 169e
169f 16a4 16a7 16ac 16ad 16b2 16b5 16b9
16bd 16c0 16c3 16c4 16c6 16c7 16cc 16cd
16d2 16d4 16d8 16db 16dd 16e1 16e3 16ef
16f1 16f3 16f4 16f9 16fd 16ff 170b 170d
1711 1715 1718 1719 171b 171e 1721 1722
1727 172b 172f 1732 1733 1735 1738 173b
173c 1741 1744 1748 174c 174f 1750 1752
1755 1758 1759 175e 1 1761 1766 176a
176e 1772 1775 1776 1778 177b 177f 1783
1786 1787 1789 178a 178f 1793 1795 1799
179c 17a0 17a4 17a7 17a8 17aa 17ad 17b0
17b1 17b6 17ba 17bd 17be 17c3 17c6 17ca
17ce 17d1 17d2 17d4 17d7 17da 17db 17e0
17e4 17e8 17ec 17ef 17f0 17f2 17f5 17f9
17fd 1800 1801 1803 1804 1809 180d 180f
1813 1816 1818 181c 1820 1824 1828 182c
1830 1834 1838 183c 1840 1844 1848 184c
1858 185c 1860 1863 1867 186b 186d 1
1871 1875 1879 187c 1880 1884 1888 188c
188f 1893 1897 189a 189d 18a2 18a5 18a8
18ab 18ac 18b1 18b2 1 18b4 18b9 18bd
18c1 18c4 18c9 18ce 18d1 18d5 18d6 18db
18de 18e3 18e4 18e9 18ec 18f1 18f2 18f7
18fa 18fe 18ff 1904 1907 190c 190d 1912
1915 1919 191d 1920 1923 1924 1926 1927
192c 192d 1932 1934 1938 193b 193d 1941
1943 194f 1951 1953 1954 1959 195d 195f
196b 196d 196f 1973 1977 197a 197c 1980
1984 1987 1988 198a 198d 1990 1991 1996
199a 199e 19a2 19a5 19a6 19a8 19ab 19ae
19af 19b4 19b8 19bc 19be 19c2 19c6 19c9
19ca 19cc 19cf 19d2 19d3 19d8 19dc 19e0
19e4 19e7 19e8 19ea 19ed 19f1 19f5 19f8
19f9 19fb 19fc 1a01 1a05 1a09 1a0b 1a0f
1a13 1a17 1a1a 1a1b 1a1d 1a20 1a23 1a24
1a29 1a2d 1a31 1a35 1a38 1a39 1a3b 1a3e
1a42 1a46 1a49 1a4a 1a4c 1a4d 1a52 1a56
1a58 1a5c 1a60 1a63 1a65 1a69 1a6d 1a70
1a74 1a78 1a7b 1a7c 1a7e 1a81 1a84 1a85
1a8a 1a8e 1a92 1a95 1a99 1a9d 1aa0 1aa3
1aa8 1aab 1aae 1ab1 1ab2 1ab7 1ab8 1
1aba 1abf 1ac3 1ac7 1aca 1acf 1ad4 1ad7
1adb 1adc 1ae1 1ae2 1ae7 1ae9 1aed 1af0
1af4 1af8 1afc 1aff 1b03 1b05 1b09 1b0c
1b0e 1b12 1b15 1b19 1b1d 1b20 1b21 1b23
1b26 1b29 1b2a 1b2f 1b33 1b37 1b3b 1b3f
1b42 1b43 1b45 1b49 1b4d 1b50 1b51 1b53
1b56 1b5a 1b5e 1b60 1b64 1b68 1b6b 1b6e
1b6f 1b71 1b74 1b79 1b7a 1b7f 1b82 1b86
1b8a 1b8d 1b8e 1b90 1b93 1b96 1b97 1b9c
1 1b9f 1ba4 1ba8 1bac 1bb0 1bb4 1bb8
1bbc 1bc0 1bc4 1bc8 1bcc 1bd0 1bd4 1bd8
1bdc 1be0 1be4 1be8 1bec 1bf8 1bfc 1c00
1c03 1c07 1c0b 1c0d 1 1c11 1c15 1c19
1c1c 1c20 1c24 1c28 1c2c 1c2f 1c33 1c37
1c3a 1c3d 1c42 1c45 1c48 1c4b 1c4c 1c51
1c52 1 1c54 1c59 1c5d 1c61 1c64 1c69
1c6e 1c71 1c75 1c76 1c7b 1c7e 1c83 1c84
1c89 1c8c 1c91 1c92 1c97 1c9a 1c9e 1c9f
1ca4 1ca7 1cac 1cad 1cb2 1cb5 1cb9 1cbd
1cc0 1cc3 1cc4 1cc6 1cc7 1ccc 1ccd 1cd2
1cd4 1cd8 1cdb 1cdd 1ce1 1ce3 1cef 1cf1
1cf3 1cf4 1cf9 1cfd 1cff 1d0b 1d0d 1d11
1d15 1d18 1d1c 1d1f 1d23 1d26 1d27 1d2c
1d2f 1d33 1d36 1d37 1d3c 1 1d3f 1d44
1d48 1d4c 1d50 1d54 1d57 1d58 1d5a 1d5e
1d62 1d65 1d66 1d68 1d6b 1d6f 1d73 1d77
1d7a 1d7e 1d82 1d85 1d86 1d88 1d8b 1d8e
1d8f 1d94 1d97 1d9b 1d9f 1da2 1da6 1daa
1dad 1dae 1db0 1db3 1db6 1db7 1dbc 1
1dbf 1dc4 1dc8 1dcc 1dcf 1dd2 1dd3 1dd5
1dd8 1ddd 1dde 1de3 1de7 1deb 1dee 1def
1df1 1df4 1df7 1df8 1dfd 1e01 1e04 1e08
1e0a 1e0e 1e11 1e15 1e18 1e1c 1e1e 1e22
1e25 1e27 1e2b 1e2f 1e32 1e33 1e35 1e38
1e3b 1e3c 1e41 1e45 1e49 1e4d 1e50 1e54
1e58 1e5b 1e5c 1e5e 1e62 1e66 1e69 1e6a
1e6c 1e6f 1e73 1e75 1e79 1e7c 1e80 1e84
1e87 1e88 1e8a 1e8e 1e91 1e95 1e98 1e99
1e9b 1e9c 1ea1 1ea5 1ea9 1eac 1ead 1eaf
1eb2 1eb5 1eb6 1ebb 1ebf 1ec3 1ec6 1eca
1ece 1ed1 1ed2 1ed4 1ed7 1eda 1edb 1
1ee0 1ee5 1ee9 1eed 1ef0 1ef3 1ef4 1ef6
1ef9 1efe 1eff 1f04 1f08 1f0b 1f0f 1f11
1f15 1f18 1f1c 1f20 1f21 1f26 1f2a 1f2e
1f32 1f36 1f39 1f3d 1f41 1f45 1f49 1f4d
1f51 1f55 1f59 1f5d 1f61 1f65 1f69 1f6d
1f71 1f75 1f79 1f7d 1f81 1f85 1f89 1f8d
1f91 1f95 1f99 1f9d 1fa1 1fa5 1fa9 1fad
1fb1 1fb5 1fb9 1fbd 1fc0 1fc1 1fc3 1fc6
1fc9 1fcc 1fcd 1fcf 1fd3 1fd5 1fd9 1fdc
1fe0 1fe4 1fe8 1fec 1ff0 1ffc 2000 2005
2009 200c 200d 2012 2016 201a 201d 2020
2024 2026 202a 202e 2031 2034 2038 203a
203e 2042 2045 2047 1 204b 204f 2053
2056 205a 205e 2062 2066 2069 206d 2071
2074 2077 207c 207f 2082 2085 2086 208b
208c 1 208e 2093 2097 209b 209e 20a3
20a8 20ab 20af 20b0 20b5 20b8 20bd 20be
20c3 20c6 20cb 20cc 20d1 20d4 20d8 20d9
20de 20e1 20e6 20e7 20ec 20ef 20f3 20f7
20fa 20fd 20fe 2100 2101 2106 2107 210c
210e 2112 2115 2117 211b 211d 2129 212b
212d 212e 2133 2137 2139 2145 2147 214b
214f 2152 2156 215a 215d 2160 2165 2168
216b 216e 216f 2174 2175 1 2177 217c
2180 2184 2187 218c 2191 2194 2198 2199
219e 219f 21a4 21a6 21aa 21ad 21b1 21b4
21b8 21ba 21be 21c1 21c3 21c7 21cb 21ce
21d0 21d4 21d7 21d9 21dd 21e1 21e4 21e8
21ec 21ef 21f0 21f2 21f5 21f8 21f9 21fe
2201 2205 2209 220c 220d 220f 2213 2216
221a 221d 221e 2220 2221 2226 1 2229
222e 2232 2236 2239 223a 223c 223f 2242
2243 2248 224c 2250 2254 2257 225b 225f
2262 2263 2265 2269 226d 2270 2271 2273
2274 2276 2279 227d 227f 2283 2286 228a
228e 2292 2296 229a 229e 22a2 22a6 22aa
22ae 22b2 22b6 22ba 22be 22c2 22c6 22ca
22ce 22d2 22d6 22da 22de 22e2 22e6 22e9
22ec 22ed 22ef 22f3 22f7 22f9 22fd 2301
2304 2305 2307 230a 230d 230e 2313 2317
231b 231e 231f 2321 2324 2327 2328 232d
2331 2335 2339 233c 2340 2344 2347 2348
234a 234e 2352 2355 2356 2358 2359 235b
235e 2362 2364 2368 236b 236f 2373 2377
237b 237f 2383 2387 238b 238f 2393 2397
239b 239f 23a3 23a7 23ab 23af 23b3 23b7
23bb 23bf 23c3 23c7 23cb 23ce 23d1 23d2
23d4 23d8 23da 23de 23e2 23e5 23e9 23ed
23f0 23f1 23f3 23f6 23f9 23fa 23ff 2403
2407 240a 240e 2412 2415 2419 241d 241f
2423 2427 242a 242b 242d 2430 2433 2434
2439 243d 2441 2444 2445 2447 244a 244d
244e 1 2453 2458 245c 2460 2463 2467
246b 246e 2472 2474 2478 247c 247f 2483
2487 248a 248d 2490 2491 2496 249a 249e
24a1 24a4 24a8 24aa 24ae 24b1 24b5 24b9
24bc 24c0 24c4 24c7 24ca 24cf 24d2 24d5
24d8 24d9 24de 24df 1 24e1 24e6 24ea
24ee 24f1 24f6 24fb 24fe 2502 2503 2508
250b 2510 2511 2516 2519 251e 251f 2524
2527 252b 252f 2532 2533 2538 2539 253e
2540 2544 2547 254b 254f 2553 2556 255a
255c 2560 2562 256e 2572 2574 2575 257e 
aa8
2
0 1 a 6 15 19 20 :3 6
15 19 20 :3 6 16 1a 21 :3 6
19 :3 6 16 1a 21 :3 6 17 1b
22 :3 6 12 :3 6 10 :3 6 11 :3 6
10 :3 6 15 :3 6 13 :3 6 13 :3 6
18 :3 6 16 :3 6 19 1d 24 :3 6
14 18 1f :2 6 1 3 a :2 1
4 :2 14 23 14 :2 4 :2 d 1c d
:2 4 :2 b 1a b :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 10 1f 10
:2 4 :2 e 1d e :2 4 :2 e 1d e
:2 4 :2 13 22 13 :2 4 :2 11 20 11
:2 4 e 17 16 :2 e :2 4 d 16
15 :2 d :2 4 f 18 17 :2 f :2 4
10 19 18 :2 10 :2 4 :3 10 :2 4 :3 15
:2 4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 12 1b 1a :2 12 :2 4
12 1b 1a :2 12 :2 4 f 18 17
:2 f :2 4 f 18 17 :2 f :2 4 10
19 18 :2 10 :2 4 f 18 17 :2 f
:2 4 :2 12 21 12 :2 4 :2 b 1a b
:2 4 :2 f 1e f :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 a 19 a
:2 4 :2 14 23 14 :2 4 :2 13 22 13
:2 4 :2 12 21 12 :2 4 :2 f 1e f
:2 4 17 20 1f :2 17 :2 4 18 21
20 :2 18 :2 4 :3 9 :2 4 :3 9 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 :2 f
1e f :2 4 :2 16 25 16 :2 4 :2 11
20 11 :2 4 :2 f 1e f :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 :2 f
1e f :2 4 :2 d 1c d :2 4 :2 b
1a b :2 4 :2 f 19 f 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 54 5a 5d :2 54
6b 81 8 :2 6b d 10 :2 6b 1c
1f :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 2a 2d :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 2b
2e :2 6b b e :2 6b 13 16 1f
27 :2 1f 3c :2 16 :2 6b b e :2 6b
13 16 :2 6b 1b 1e :2 6b 2b 2e
:2 6b b e :2 6b 13 16 :2 6b 1b
1e :2 6b 2c 2f :2 6b b e :2 6b
13 16 1f 27 :2 1f 35 :2 16 :2 6b
b e :2 6b 13 16 1f 27 :2 1f
33 :2 16 :2 6b b e :2 6b 13 16
1f 27 :2 1f 34 :2 16 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 33 :2 16
:2 6b b e :2 6b 13 16 1f 27
:2 1f 38 :2 16 :2 6b b e :2 6b 13
16 1f 27 :2 1f 36 :2 16 :2 6b b
e :2 6b 13 16 1f 27 :2 1f 36
:2 16 :2 6b b e :2 6b 13 16 1f
27 :2 1f 3b :2 16 :2 6b b e :2 6b
13 16 1f 27 :2 1f 39 :2 16 :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 2e 31 :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 29 2c :2 6b
31 34 :2 6b :2 7 4a :2 4 7 :2 11
23 :2 2d 39 3c 4c 4e 4f :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:2 7 52 :2 4 7 10 1b :2 7 21
1e :2 2a :2 1e 7 10 :2 19 25 2c
35 40 :2 2c 44 :2 4d :2 25 24 5c
:2 10 :2 7 15 1c 25 30 :2 1c 34
:2 3d :2 15 :2 7 14 :2 7 13 7 4
34 a 13 1e :2 a 24 21 :2 2d
:2 21 7 14 1b 24 2f :2 1b 33
:2 3c :2 14 13 :2 7 15 1c 25 30
:2 1c 34 :2 3d :2 15 14 :2 7 15 7
37 34 7 15 1e 29 :2 15 :2 7
14 :2 7 13 7 :5 4 12 :2 4 12
:2 4 15 :2 4 18 :2 4 c :2 4 c
:2 4 12 :2 4 12 4 7 10 1b
:2 7 1e 20 :2 1e 7 1e 7 :7 a
12 19 a 12 19 :10 a f 10
24 fffa a :2 13 1f a 7 :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :2 10 5d :2 d :2 a :4 16 :2 a 7
:3 22 b :2 14 1f 1d :2 28 :2 1d a
d :2 17 29 :2 33 3f 42 52 55
56 :2 52 :2 29 :3 d :2 13 18 24 63
66 :2 24 :2 d 59 :3 a 11 :2 1a a
38 :2 7 22 11 1d 29 36 a
19 30 f 1d 28 32 a 16
25 f 10 24 :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8c 8f
:2 27 97 9a :2 27 a6 a9 b0 b9
bc :2 a9 :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 4 b :2 14 1f 1d :2 28
:2 1d a d :2 17 29 :2 33 3f 42
52 55 56 :2 52 :2 29 :3 d :2 13 18
24 63 66 :2 24 :2 d 59 :3 a 11
:2 1a a 7 38 d 22 2b 33
:2 22 :2 d 37 3a :2 37 d :2 17 29
:2 33 3f 42 52 55 56 :2 52 :2 29
:3 d :2 13 18 24 63 66 :2 24 :2 d
59 :3 a 11 :2 1a a 3c 38 :2 7
11 2a 3a 10 24 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 4 f
1d 26 2e :2 1d :2 f e 33 36
:2 33 :3 a 14 2b 12 29 3d :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 59
5c 5d :2 59 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a 79 7c :2 2a 80 83
:2 2a 8f 92 :2 2a 9a 9d :2 2a a9
ac b3 bc bf :2 ac :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 38 e :2 17
22 20 :2 2b :2 20 d 10 :2 1a 2c
:2 36 42 45 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 :2 10
5c :3 d 14 :2 1d d 3b :2 a 38
:3 7 1a 30 :2 1a 7 :4 4 e 17
2d 36 4e 5b c 1b 27 36
c 1a 27 :2 7 :2 10 1c 7 4
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 53 56 57 :2 53 :2 29
:3 d :2 13 18 24 63 66 :2 24 73
76 :2 24 7a 7d :2 24 89 8c :2 24
94 97 :2 24 a3 a6 ad b6 b9
:2 a6 :2 24 :2 d 5a :2 a :2 7 :4 13 :2 7
4 :3 1 7 10 1a :2 7 1d 1f
:2 1d b 14 1c :2 b 1f 21 :2 1f
a 29 32 3a :2 29 3d 3f :2 3d
28 :3 a 14 1d 2c :2 14 2f 31
3a 42 :2 31 :2 14 a 42 :2 7 a
13 1d :2 a 20 22 :2 20 :4 e d
10 19 21 :2 10 24 26 :2 24 10
1c 25 33 :2 1c 36 38 41 49
:2 38 :2 1c 10 28 :2 d 25 17 1b
2f 3d 16 21 32 43 4b 52
6c 74 7b :2 10 :2 19 25 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5c 5f 60 :2 5c :2 32
:3 16 :2 1c 21 2d 6c 6f :2 2d 7c
7f :2 2d 83 86 :2 2d 92 95 :2 2d
9d a0 :2 2d ac af b6 bf c2
:2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10
d :7 a 24 d 16 1f :2 d 22
24 :2 22 d 19 22 2c :2 19 2f
31 :2 19 d a 26 10 19 22
:2 10 25 27 :2 25 d 19 22 31
:2 19 34 36 3f 49 :2 36 :2 19 d
a 29 26 10 19 22 :2 10 25
27 :2 25 d 19 22 2e :2 19 31
33 3c 46 :2 33 :2 19 d 29 26
:2 a :4 7 a 13 1d :2 a 20 22
:2 20 d :2 17 29 :2 33 3f 42 52
55 56 :2 52 :2 29 :3 d :2 13 18 24
63 66 :2 24 :2 d 59 :3 a 11 :2 1a
a 24 :2 7 21 :2 4 7 10 1b
:2 7 1e 20 :2 1e 7 15 1c 25
30 :2 1c 34 :2 3d :2 15 14 7 4
22 b 12 1e 21 :2 b 24 26
:2 24 a 30 39 46 :2 30 49 4b
:2 49 2f :2 a 11 24 36 49 56
62 f 24 30 3d 4b f 10
1d 2e 38 49 57 :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8c
8f :2 27 97 9a :2 27 a6 a9 b0
b9 bc :2 a9 :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 4e b :2 14 1f 1d
:2 28 :2 1d a :4 3d 3c :3 a 18 1f
28 33 :2 1f 37 :2 40 :2 18 17 a
e :2 19 21 2f 3b :2 e 3f 42
:2 3f d 4a :2 55 5d 12 21 :2 4a
25 28 :2 25 49 :2 d 10 17 23
26 :2 10 29 2b :2 29 13 1c 26
:2 13 29 2b :2 29 13 20 13 2d
:3 10 1f 10 2f :2 d 2b 10 19
24 :2 10 27 29 :2 27 10 1f :2 28
2f 38 44 :2 2f 48 :2 51 :2 1f 1e
10 2b :2 d 10 19 27 :2 10 2c
2a 35 3f :2 2c :2 2a 13 1c 2a
:2 13 2d 2f :2 2d 35 :2 40 48 56
63 :2 35 67 6a :2 67 :2 13 16 1d
29 2c :2 16 2f 31 :2 2f 16 22
16 35 :3 13 :3 26 :2 13 21 :2 2a :2 13
26 32 3f 4d 58 62 6e 22
2f 3d 49 55 22 2f 37 45
4d 56 5e 22 2e 3a 47 52
22 30 3a 49 55 22 2b 3a
:2 22 3e 41 47 :2 26 13 6c :2 10
1a 2f 35 19 2d 13 1a 16
22 :3 20 16 :2 1f 2b 16 27 16
:2 1f 2b 16 :4 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
5f 62 63 :2 5f :2 35 :3 19 :2 1f 24
30 6f 72 :2 30 7f 82 :2 30 86
89 :2 30 95 98 :2 30 a0 a3 :2 30
af b2 b9 c2 c5 :2 b2 :2 30 :2 19
66 :2 16 :2 13 :4 1f :2 13 10 :3 42 13
:2 1d 2f :2 39 45 48 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a :2 13 5f :3 10 17 10 42 :2 d
:4 a 5e :2 7 4e 22 :2 4 8 11
1c :2 8 1f 21 :2 1f 7 28 31
3f :2 28 44 42 4d 5c :2 44 :2 42
27 :2 7 a 13 1d :2 a 20 23
:2 20 a 18 :2 21 28 31 3c :2 28
40 49 53 :2 40 :2 18 17 a 25
:3 7 1a 24 31 3f 4a 54 20
2e 3c 4b 55 5d 20 28 34
41 4c 57 20 2e 3a 4b 57
20 26 :2 1a 7 4 60 a 13
1e :2 a 21 23 :2 21 a 13 1d
:2 a 20 23 :2 20 a 18 :2 21 28
31 3c :2 28 40 49 53 :2 40 :2 18
17 a 25 :3 7 1a 24 39 47
52 5c 20 2e 3c 4b 55 5d
20 28 34 41 4c 57 20 2e
3a 4b 57 20 26 :2 1a 7 25
60 :2 4 7 10 21 :2 7 24 26
:2 24 7 :2 10 1c :2 25 7 4 2a
a 13 24 :2 a 27 2a :2 27 30
39 4a :2 30 4d 50 :2 4d :2 a 7
:2 10 1c :2 25 7 54 2a :2 4 7
:2 10 19 1b :2 19 7 :2 10 1c 7
1f :2 4 7 :2 11 23 :2 2d 39 3c
4c 4f 50 :2 4c :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e 6d 70 :2 1e 74
77 :2 1e 81 84 :2 8d :2 1e :2 7 53
:3 4 b :2 14 4 :9 1 
aa8
4
0 :2 1 :6 3 :6 4
:6 5 :4 6 :6 7 :6 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :6 12 :6 13 2
:2 14 :2 1 :6 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:7 20 :7 21 :7 22 :7 23
:5 24 :5 25 :7 26 :7 27
:7 28 :7 29 :7 2a :7 2b
:7 2c :7 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:7 38 :7 39 :5 3a :5 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:b 49 :11 4a 4b :2 4a
:2 4b :2 4a :2 4b :2 4a
:2 4c :2 4a :2 4c :2 4a
:2 4c :2 4a :2 4c :2 4a
:2 4d :2 4a :2 4d :2 4a
:2 4d :2 4a :2 4d :2 4a
:2 4e :2 4a :9 4e :2 4a
:2 4f :2 4a :2 4f :2 4a
:2 4f :2 4a :2 4f :2 4a
:2 50 :2 4a :2 50 :2 4a
:2 50 :2 4a :2 50 :2 4a
:2 51 :2 4a :9 51 :2 4a
:2 52 :2 4a :9 52 :2 4a
:2 53 :2 4a :9 53 :2 4a
:2 54 :2 4a :9 54 :2 4a
:2 55 :2 4a :9 55 :2 4a
:2 56 :2 4a :9 56 :2 4a
:2 57 :2 4a :9 57 :2 4a
:2 58 :2 4a :9 58 :2 4a
:2 59 :2 4a :9 59 :2 4a
:2 5a :2 4a :2 5a :2 4a
:2 5a :2 4a :2 5a :2 4a
:2 5b :2 4a :2 5b :2 4a
:2 5b :2 4a :2 5b :2 4a
:2 5b :4 4a :3 49 :11 5e
:b 5f :3 5e :b 64 :14 65
:d 67 :3 68 :3 69 6a
64 :b 6a :e 6b :e 6d
:3 6f 6a 64 :7 71
:3 72 :3 73 70 :3 64
:3 76 :3 77 :3 78 :3 79
:3 7a :3 7b :3 7c :3 7d
:9 7f :3 80 83 84
85 86 87 88
:3 89 :3 8a 8b 8c
8d 8e 90 91
92 93 94 95
96 97 98 99
9a 9b 9c :2 9d
83 :5 9e 81 :2 a0
:5 a2 :11 a3 :24 a4 :3 a3
:2 a1 :6 a0 9f :3 7f
:a a9 :11 aa :b ab :3 aa
:5 ad :3 a9 7f :4 b1
:3 b2 :4 b3 :3 b4 b5
:2 b6 b1 :5 b7 b0
:2 b9 :5 bb :11 bc :24 bd
:3 bc :2 ba :6 b9 b8
:3 af :a c2 :11 c3 :b c4
:3 c3 :5 c6 c7 c2
:c c7 :11 c8 :b c9 :3 c8
:5 cb c7 :3 c2 :3 cf
:2 d0 cf :6 d1 :5 d2
d1 :5 d4 d3 :3 d1
ce :2 d7 :5 d9 :11 da
:24 db :3 da :2 d8 :6 d7
d6 :3 af :10 e0 :2 e2
:3 e3 e2 :5 e4 e1
:2 e6 :5 e8 :11 e9 :24 ea
:3 e9 :2 e7 :6 e6 e5
:3 e0 :a ef :11 f0 :b f1
:3 f0 :5 f3 :3 ef :3 e0
:6 f7 af :3 7f :6 fc
:4 fd :3 fe fc :5 ff
fb :2 101 :5 103 :11 104
:24 105 :3 104 :2 102 :6 101
100 :3 48 :9 10a :16 10b
:f 10c :3 10b :9 10f :5 111
:9 112 :f 113 :3 112 111
:4 117 :9 118 117 :5 119
116 :2 11b :5 11d :11 11e
:24 11f :3 11e :2 11c :6 11b
11a :4 115 :3 111 10f
:9 125 :b 126 127 125
:9 127 :f 128 129 127
125 :9 129 :f 12a 129
:3 125 124 :3 10f :9 12e
:11 12f :b 130 :3 12f :5 132
:3 12e :3 10a :9 136 :e 137
139 136 :17 139 :6 13b
:5 13c 13d :6 13e 13b
:5 13f 13a :2 141 :5 143
:11 144 :24 145 :3 144 :2 142
:6 141 140 :3 139 :11 14a
:e 14b :11 14d :2 14e :2 14d
:4 14e :3 14d :a 14f :9 150
:3 151 :3 150 :3 153 :3 14f
14e :9 156 :10 157 :3 156
:d 15a :17 15b :a 15c :3 15d
:3 15c :5 15f :5 160 :8 161
:5 162 :7 163 :5 164 :5 165
:8 166 :3 161 :3 15b :3 16a
:2 16b 16a :6 16c :5 16d
16c :5 16f 16e :3 16c
169 :2 172 :5 174 :11 175
:24 176 :3 175 :2 173 :6 172
171 :3 15a :11 17b :b 17c
:3 17b :3 17e :3 15a 155
:3 14d :3 14a 139 :3 136
:1a 184 :9 185 :12 186 :3 185
:7 18a :6 18b :6 18c :5 18d
:2 18e :3 18a 18f 184
:9 18f :9 190 :12 191 :3 190
:7 1c7 :6 1c8 :6 1c9 :5 1ca
:2 1cb :3 1c7 18f :3 184
:9 1cf :7 1d0 1d1 1cf
:14 1d1 :7 1d2 1d1 :3 1cf
:7 1d5 :5 1d6 :3 1d5 :11 1d9
:19 1da :3 1d9 :5 1dc :2 48
:7 1 
2580
4
:3 0 1 :3 0 2
:a 0 aa3 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
6 :3 0 8 :5 0
1 13 12 :3 0
d 98 0 b
a :3 0 9 :7 0
17 16 :3 0 4
:3 0 5 :3 0 6
:3 0 b :5 0 1
1d 1c :3 0 11
c5 0 f 4
:3 0 5 :3 0 6
:3 0 c :5 0 1
23 22 :3 0 a
:3 0 d :7 0 27
26 :3 0 15 eb
0 13 a :3 0
e :7 0 2b 2a
:3 0 a :3 0 f
:7 0 2f 2e :3 0
19 111 0 17
a :3 0 10 :7 0
33 32 :3 0 a
:3 0 11 :7 0 37
36 :3 0 1d 137
0 1b a :3 0
12 :7 0 3b 3a
:3 0 a :3 0 13
:7 0 3f 3e :3 0
21 15d 0 1f
a :3 0 14 :7 0
43 42 :3 0 a
:3 0 15 :7 0 47
46 :3 0 25 :2 0
23 4 :3 0 5
:3 0 6 :3 0 16
:5 0 1 4d 4c
:3 0 4 :3 0 5
:3 0 6 :3 0 17
:5 0 1 53 52
:3 0 18 :3 0 a
:3 0 55 57 0
aa3 2 58 :2 0
39 1c1 0 37
a :3 0 5b :7 0
9 :3 0 5f 5c
5d aa1 0 19
:6 0 3d 1fd 0
3b a :3 0 61
:7 0 d :3 0 65
62 63 aa1 0
1a :6 0 a :3 0
67 :7 0 e :3 0
6b 68 69 aa1
0 1b :6 0 41
239 0 3f a
:3 0 6d :7 0 f
:3 0 71 6e 6f
aa1 0 1c :6 0
a :3 0 73 :7 0
10 :3 0 77 74
75 aa1 0 1d
:6 0 45 275 0
43 a :3 0 79
:7 0 11 :3 0 7d
7a 7b aa1 0
1e :6 0 a :3 0
7f :7 0 12 :3 0
83 80 81 aa1
0 1f :6 0 49
2b1 0 47 a
:3 0 85 :7 0 13
:3 0 89 86 87
aa1 0 20 :6 0
a :3 0 8b :7 0
14 :3 0 8f 8c
8d aa1 0 21
:6 0 24 :2 0 4d
a :3 0 91 :7 0
15 :3 0 95 92
93 aa1 0 22
:6 0 6 :3 0 24
:2 0 4b 97 99
:6 0 9c 9a 0
aa1 0 23 :6 0
27 :2 0 51 6
:3 0 4f 9e a0
:6 0 a3 a1 0
aa1 0 25 :6 0
27 :2 0 55 6
:3 0 53 a5 a7
:6 0 aa a8 0
aa1 0 26 :6 0
5b 344 0 59
6 :3 0 57 ac
ae :6 0 b1 af
0 aa1 0 28
:6 0 24 :2 0 5d
2a :3 0 b3 :7 0
b6 b4 0 aa1
0 29 :6 0 2a
:3 0 b8 :7 0 bb
b9 0 aa1 0
2b :6 0 24 :2 0
61 6 :3 0 5f
bd bf :6 0 c2
c0 0 aa1 0
2c :6 0 24 :2 0
65 6 :3 0 63
c4 c6 :6 0 c9
c7 0 aa1 0
2d :6 0 24 :2 0
69 6 :3 0 67
cb cd :6 0 d0
ce 0 aa1 0
2e :6 0 31 :2 0
6d 6 :3 0 6b
d2 d4 :6 0 d7
d5 0 aa1 0
2f :6 0 31 :2 0
71 6 :3 0 6f
d9 db :6 0 de
dc 0 aa1 0
30 :6 0 34 :2 0
75 6 :3 0 73
e0 e2 :6 0 e5
e3 0 aa1 0
32 :6 0 31 :2 0
79 6 :3 0 77
e7 e9 :6 0 ec
ea 0 aa1 0
33 :6 0 37 :2 0
7d 6 :3 0 7b
ee f0 :6 0 f3
f1 0 aa1 0
35 :6 0 37 :2 0
7f a :3 0 f5
:7 0 f9 f6 f7
aa1 0 36 :6 0
37 :2 0 81 a
:3 0 fb :7 0 ff
fc fd aa1 0
38 :6 0 37 :2 0
83 a :3 0 101
:7 0 105 102 103
aa1 0 39 :6 0
37 :2 0 85 a
:3 0 107 :7 0 10b
108 109 aa1 0
3a :6 0 37 :2 0
87 a :3 0 10d
:7 0 111 10e 10f
aa1 0 3b :6 0
37 :2 0 89 a
:3 0 113 :7 0 117
114 115 aa1 0
3c :6 0 37 :2 0
8b a :3 0 119
:7 0 11d 11a 11b
aa1 0 3d :6 0
37 :2 0 8d a
:3 0 11f :7 0 123
120 121 aa1 0
3e :6 0 37 :2 0
8f a :3 0 125
:7 0 129 126 127
aa1 0 3f :6 0
24 :2 0 91 a
:3 0 12b :7 0 12f
12c 12d aa1 0
40 :6 0 24 :2 0
95 6 :3 0 93
131 133 :6 0 136
134 0 aa1 0
41 :6 0 9b 5b2
0 99 6 :3 0
97 138 13a :6 0
13d 13b 0 aa1
0 42 :6 0 37
:2 0 9d 2a :3 0
13f :7 0 142 140
0 aa1 0 43
:6 0 2a :3 0 144
:7 0 147 145 0
aa1 0 44 :6 0
37 :2 0 9f 46
:3 0 149 :7 0 14d
14a 14b aa1 0
45 :6 0 37 :2 0
a1 46 :3 0 14f
:7 0 153 150 151
aa1 0 47 :6 0
37 :2 0 a3 a
:3 0 155 :7 0 159
156 157 aa1 0
48 :6 0 37 :2 0
a5 a :3 0 15b
:7 0 15f 15c 15d
aa1 0 49 :6 0
37 :2 0 a7 a
:3 0 161 :7 0 165
162 163 aa1 0
4a :6 0 37 :2 0
a9 a :3 0 167
:7 0 16b 168 169
aa1 0 4b :6 0
37 :2 0 ab a
:3 0 16d :7 0 171
16e 16f aa1 0
4c :6 0 37 :2 0
ad a :3 0 173
:7 0 177 174 175
aa1 0 4d :6 0
37 :2 0 af a
:3 0 179 :7 0 17d
17a 17b aa1 0
4e :6 0 37 :2 0
b1 a :3 0 17f
:7 0 183 180 181
aa1 0 4f :6 0
37 :2 0 b3 a
:3 0 185 :7 0 189
186 187 aa1 0
50 :6 0 190 191
0 b5 46 :3 0
18b :7 0 18f 18c
18d aa1 0 51
:6 0 52 :3 0 53
:3 0 52 :3 0 54
:3 0 193 194 0
2 :4 0 b7 195
197 192 199 198
:2 0 55 :3 0 56
:3 0 19b 19c 0
57 :4 0 52 :3 0
58 :3 0 19f 1a0
0 2 :4 0 b9
1a1 1a3 59 :4 0
5a :2 0 5b :3 0
bb 1a6 1a8 :3 0
5c :4 0 5a :2 0
5d :4 0 be 1ab
1ad :3 0 5a :2 0
3 :3 0 c1 1af
1b1 :3 0 5a :2 0
5d :4 0 c4 1b3
1b5 :3 0 5a :2 0
5e :4 0 c7 1b7
1b9 :3 0 5a :2 0
5d :4 0 ca 1bb
1bd :3 0 5a :2 0
7 :3 0 cd 1bf
1c1 :3 0 5a :2 0
5d :4 0 d0 1c3
1c5 :3 0 5a :2 0
5e :4 0 d3 1c7
1c9 :3 0 5a :2 0
5d :4 0 d6 1cb
1cd :3 0 5a :2 0
8 :3 0 d9 1cf
1d1 :3 0 5a :2 0
5d :4 0 dc 1d3
1d5 :3 0 5a :2 0
5e :4 0 df 1d7
1d9 :3 0 5a :2 0
5f :3 0 60 :3 0
9 :3 0 e2 1dd
1df 61 :4 0 e4
1dc 1e2 e7 1db
1e4 :3 0 5a :2 0
5e :4 0 ea 1e6
1e8 :3 0 5a :2 0
5d :4 0 ed 1ea
1ec :3 0 5a :2 0
b :3 0 f0 1ee
1f0 :3 0 5a :2 0
5d :4 0 f3 1f2
1f4 :3 0 5a :2 0
5e :4 0 f6 1f6
1f8 :3 0 5a :2 0
5d :4 0 f9 1fa
1fc :3 0 5a :2 0
c :3 0 fc 1fe
200 :3 0 5a :2 0
5d :4 0 ff 202
204 :3 0 5a :2 0
5e :4 0 102 206
208 :3 0 5a :2 0
5f :3 0 60 :3 0
d :3 0 105 20c
20e 61 :4 0 107
20b 211 10a 20a
213 :3 0 5a :2 0
5e :4 0 10d 215
217 :3 0 5a :2 0
5f :3 0 60 :3 0
e :3 0 110 21b
21d 61 :4 0 112
21a 220 115 219
222 :3 0 5a :2 0
5e :4 0 118 224
226 :3 0 5a :2 0
5f :3 0 60 :3 0
f :3 0 11b 22a
22c 61 :4 0 11d
229 22f 120 228
231 :3 0 5a :2 0
5e :4 0 123 233
235 :3 0 5a :2 0
5f :3 0 60 :3 0
10 :3 0 126 239
23b 61 :4 0 128
238 23e 12b 237
240 :3 0 5a :2 0
5e :4 0 12e 242
244 :3 0 5a :2 0
5f :3 0 60 :3 0
11 :3 0 131 248
24a 61 :4 0 133
247 24d 136 246
24f :3 0 5a :2 0
5e :4 0 139 251
253 :3 0 5a :2 0
5f :3 0 60 :3 0
12 :3 0 13c 257
259 61 :4 0 13e
256 25c 141 255
25e :3 0 5a :2 0
5e :4 0 144 260
262 :3 0 5a :2 0
5f :3 0 60 :3 0
13 :3 0 147 266
268 61 :4 0 149
265 26b 14c 264
26d :3 0 5a :2 0
5e :4 0 14f 26f
271 :3 0 5a :2 0
5f :3 0 60 :3 0
14 :3 0 152 275
277 61 :4 0 154
274 27a 157 273
27c :3 0 5a :2 0
5e :4 0 15a 27e
280 :3 0 5a :2 0
5f :3 0 60 :3 0
15 :3 0 15d 284
286 61 :4 0 15f
283 289 162 282
28b :3 0 5a :2 0
5e :4 0 165 28d
28f :3 0 5a :2 0
5d :4 0 168 291
293 :3 0 5a :2 0
16 :3 0 16b 295
297 :3 0 5a :2 0
5d :4 0 16e 299
29b :3 0 5a :2 0
5e :4 0 171 29d
29f :3 0 5a :2 0
5d :4 0 174 2a1
2a3 :3 0 5a :2 0
17 :3 0 177 2a5
2a7 :3 0 5a :2 0
5d :4 0 17a 2a9
2ab :3 0 5a :2 0
62 :4 0 17d 2ad
2af :3 0 180 19d
2b1 :2 0 2b3 185
2b4 19a 2b3 0
2b5 187 0 a9f
52 :3 0 53 :3 0
2b6 2b7 0 52
:3 0 63 :3 0 2b9
2ba 0 31 :2 0
2 :4 0 64 :2 0
65 :2 0 31 :2 0
189 2bf 2c1 :3 0
18c 2bb 2c3 2b8
2c5 2c4 :2 0 55
:3 0 66 :3 0 2c7
2c8 0 57 :4 0
67 :4 0 5a :2 0
5b :3 0 190 2cc
2ce :3 0 193 2c9
2d0 :2 0 2d2 196
2d3 2c6 2d2 0
2d4 198 0 a9f
5f :3 0 1f :3 0
37 :2 0 19a 2d5
2d8 68 :3 0 69
:2 0 6a :3 0 2da
2dc 0 19f 2db
2de :3 0 3c :3 0
6b :3 0 6c :3 0
2e1 2e2 0 6d
:3 0 5f :3 0 1f
:3 0 37 :2 0 1a2
2e5 2e8 68 :3 0
6e :3 0 2ea 2eb
0 1a5 2e4 2ed
2ee :2 0 6f :2 0
1a8 2e3 2f1 2e0
2f2 0 308 3a
:3 0 6d :3 0 5f
:3 0 1f :3 0 37
:2 0 1ab 2f6 2f9
68 :3 0 70 :3 0
2fb 2fc 0 1ae
2f5 2fe 2f4 2ff
0 308 1f :3 0
37 :2 0 301 302
0 308 3b :3 0
37 :2 0 304 305
0 308 71 :3 0
1b1 343 5f :3 0
1f :3 0 37 :2 0
1b6 309 30c 68
:3 0 69 :2 0 72
:3 0 30e 310 0
1bb 30f 312 :3 0
3b :3 0 6d :3 0
5f :3 0 1f :3 0
37 :2 0 1be 316
319 68 :3 0 72
:3 0 31b 31c 0
1c1 315 31e 31f
:2 0 314 320 0
333 1f :3 0 6d
:3 0 5f :3 0 1f
:3 0 37 :2 0 1c4
324 327 68 :3 0
73 :3 0 329 32a
0 1c7 323 32c
32d :2 0 322 32e
0 333 3a :3 0
37 :2 0 330 331
0 333 1ca 334
313 333 0 345
3a :3 0 5f :3 0
1f :3 0 37 :2 0
1ce 336 339 335
33a 0 342 1f
:3 0 37 :2 0 33c
33d 0 342 3b
:3 0 37 :2 0 33f
340 0 342 1d1
344 2df 308 0
345 0 342 0
345 1d5 0 a9f
4b :3 0 37 :2 0
346 347 0 a9f
30 :3 0 37 :4 0
349 34a 0 a9f
3f :3 0 37 :2 0
34c 34d 0 a9f
2b :4 0 34f 350
0 a9f 43 :4 0
352 353 0 a9f
44 :4 0 355 356
0 a9f 35 :4 0
358 359 0 a9f
51 :3 0 74 :2 0
35b 35c 0 a9f
5f :3 0 1f :3 0
37 :2 0 1d9 35e
361 75 :2 0 31
:2 0 1de 363 365
:3 0 2c :3 0 3
:3 0 367 368 0
40c 76 :3 0 77
:3 0 78 :3 0 79
:3 0 7a :3 0 7b
:3 0 7c :3 0 7d
:3 0 7e :3 0 7c
:3 0 7d :3 0 7f
:3 0 80 :3 0 81
:3 0 82 :3 0 83
:3 0 2d :3 0 23
:3 0 25 :3 0 30
:3 0 2b :3 0 3f
:3 0 43 :3 0 44
:3 0 48 :3 0 49
:3 0 45 :3 0 47
:3 0 84 :3 0 85
:3 0 2c :4 0 86
1 :8 0 38f 87
:3 0 88 :3 0 38a
38b 0 89 :3 0
38c 38d 0 38f
1e1 3d9 8a :3 0
87 :3 0 88 :3 0
392 393 0 89
:3 0 394 395 0
3cf 52 :3 0 53
:3 0 397 398 0
52 :3 0 63 :3 0
39a 39b 0 8b
:2 0 2 :4 0 8c
:2 0 65 :2 0 31
:2 0 1e4 3a0 3a2
:3 0 1e7 39c 3a4
399 3a6 3a5 :2 0
55 :3 0 66 :3 0
3a8 3a9 0 57
:4 0 8d :4 0 5a
:2 0 5b :3 0 1eb
3ad 3af :3 0 5a
:2 0 8e :4 0 1ee
3b1 3b3 :3 0 5a
:2 0 8f :4 0 1f1
3b5 3b7 :3 0 5a
:2 0 89 :3 0 1f4
3b9 3bb :3 0 5a
:2 0 90 :4 0 1f7
3bd 3bf :3 0 5a
:2 0 7d :3 0 91
:3 0 31 :2 0 92
:2 0 1fa 3c2 3c6
1fe 3c1 3c8 :3 0
201 3aa 3ca :2 0
3cc 204 3cd 3a7
3cc 0 3ce 206
0 3cf 208 3d2
:3 0 3d2 0 3d2
3d1 3cf 3d0 :6 0
3d4 2 :3 0 20b
3d6 20d 3d5 3d4
:2 0 3d7 20f :2 0
3d9 0 3d9 3d8
38f 3d7 :6 0 40c
1 :3 0 87 :3 0
88 :3 0 3db 3dc
0 87 :3 0 75
:2 0 93 :3 0 3de
3e0 0 213 3df
3e2 :3 0 3e3 :2 0
52 :3 0 53 :3 0
3e5 3e6 0 52
:3 0 63 :3 0 3e8
3e9 0 31 :2 0
2 :4 0 94 :2 0
65 :2 0 31 :2 0
216 3ee 3f0 :3 0
219 3ea 3f2 3e7
3f4 3f3 :2 0 55
:3 0 66 :3 0 3f6
3f7 0 57 :4 0
95 :4 0 5a :2 0
5b :3 0 21d 3fb
3fd :3 0 220 3f8
3ff :2 0 401 223
402 3f5 401 0
403 225 0 409
18 :3 0 68 :3 0
96 :3 0 405 406
0 407 :2 0 409
227 40a 3e4 409
0 40b 22a 0
40c 22c 5dd 76
:3 0 97 :3 0 78
:3 0 98 :3 0 79
:3 0 99 :3 0 9a
:3 0 2d :3 0 23
:3 0 25 :3 0 38
:3 0 30 :3 0 2f
:3 0 3e :3 0 9b
:3 0 9c :3 0 3
:4 0 9d 1 :8 0
424 87 :3 0 88
:3 0 41f 420 0
89 :3 0 421 422
0 424 230 46e
8a :3 0 87 :3 0
88 :3 0 427 428
0 89 :3 0 429
42a 0 464 52
:3 0 53 :3 0 42c
42d 0 52 :3 0
63 :3 0 42f 430
0 8b :2 0 2
:4 0 9e :2 0 65
:2 0 31 :2 0 233
435 437 :3 0 236
431 439 42e 43b
43a :2 0 55 :3 0
66 :3 0 43d 43e
0 57 :4 0 9f
:4 0 5a :2 0 5b
:3 0 23a 442 444
:3 0 5a :2 0 8e
:4 0 23d 446 448
:3 0 5a :2 0 8f
:4 0 240 44a 44c
:3 0 5a :2 0 89
:3 0 243 44e 450
:3 0 5a :2 0 90
:4 0 246 452 454
:3 0 5a :2 0 7d
:3 0 91 :3 0 31
:2 0 92 :2 0 249
457 45b 24d 456
45d :3 0 250 43f
45f :2 0 461 253
462 43c 461 0
463 255 0 464
257 467 :3 0 467
0 467 466 464
465 :6 0 469 4
:3 0 25a 46b 25c
46a 469 :2 0 46c
25e :2 0 46e 0
46e 46d 424 46c
:6 0 5dc 1 :3 0
87 :3 0 88 :3 0
470 471 0 87
:3 0 75 :2 0 93
:3 0 473 475 0
262 474 477 :3 0
478 :2 0 52 :3 0
53 :3 0 47a 47b
0 52 :3 0 63
:3 0 47d 47e 0
31 :2 0 2 :4 0
a0 :2 0 65 :2 0
31 :2 0 265 483
485 :3 0 268 47f
487 47c 489 488
:2 0 55 :3 0 66
:3 0 48b 48c 0
57 :4 0 a1 :4 0
5a :2 0 5b :3 0
26c 490 492 :3 0
26f 48d 494 :2 0
496 272 497 48a
496 0 498 274
0 49f 18 :3 0
68 :3 0 96 :3 0
49a 49b 0 49c
:2 0 49f 71 :3 0
276 4d2 a2 :3 0
5f :3 0 38 :3 0
37 :2 0 279 4a1
4a4 27c 4a0 4a6
a3 :2 0 37 :2 0
280 4a8 4aa :3 0
52 :3 0 53 :3 0
4ac 4ad 0 52
:3 0 63 :3 0 4af
4b0 0 31 :2 0
2 :4 0 a4 :2 0
65 :2 0 31 :2 0
283 4b5 4b7 :3 0
286 4b1 4b9 4ae
4bb 4ba :2 0 55
:3 0 66 :3 0 4bd
4be 0 57 :4 0
a5 :4 0 5a :2 0
5b :3 0 28a 4c2
4c4 :3 0 28d 4bf
4c6 :2 0 4c8 290
4c9 4bc 4c8 0
4ca 292 0 4d0
18 :3 0 68 :3 0
a6 :3 0 4cc 4cd
0 4ce :2 0 4d0
294 4d1 4ab 4d0
0 4d3 479 49f
0 4d3 297 0
5dc 9b :3 0 a7
:3 0 19 :3 0 9c
:3 0 3 :4 0 a8
1 :8 0 4ef a9
:4 0 4da :3 0 aa
:3 0 75 :2 0 29c
4dd 4de :3 0 87
:3 0 88 :3 0 4e0
4e1 0 37 :2 0
4e2 4e3 0 4e5
29f 4ec 87 :3 0
88 :3 0 4e6 4e7
0 ab :2 0 4e8
4e9 0 4eb 2a1
4ed 4df 4e5 0
4ee 0 4eb 0
4ee 2a3 0 4ef
2a6 539 8a :3 0
87 :3 0 88 :3 0
4f2 4f3 0 89
:3 0 4f4 4f5 0
52f 52 :3 0 53
:3 0 4f7 4f8 0
52 :3 0 63 :3 0
4fa 4fb 0 8b
:2 0 2 :4 0 ac
:2 0 65 :2 0 31
:2 0 2a9 500 502
:3 0 2ac 4fc 504
4f9 506 505 :2 0
55 :3 0 66 :3 0
508 509 0 57
:4 0 ad :4 0 5a
:2 0 5b :3 0 2b0
50d 50f :3 0 5a
:2 0 8e :4 0 2b3
511 513 :3 0 5a
:2 0 8f :4 0 2b6
515 517 :3 0 5a
:2 0 89 :3 0 2b9
519 51b :3 0 5a
:2 0 90 :4 0 2bc
51d 51f :3 0 5a
:2 0 7d :3 0 91
:3 0 31 :2 0 92
:2 0 2bf 522 526
2c3 521 528 :3 0
2c6 50a 52a :2 0
52c 2c9 52d 507
52c 0 52e 2cb
0 52f 2cd 532
:3 0 532 0 532
531 52f 530 :6 0
534 6 :3 0 2d0
536 2d2 535 534
:2 0 537 2d4 :2 0
539 0 539 538
4ef 537 :6 0 5dc
1 :3 0 ae :3 0
5f :3 0 38 :3 0
37 :2 0 2d6 53c
53f 2d9 53b 541
542 :2 0 a3 :2 0
37 :2 0 2dd 544
546 :3 0 af :2 0
2e0 548 549 :3 0
85 :3 0 2c :3 0
84 :3 0 9c :3 0
3 :4 0 b0 1
:8 0 556 87 :3 0
88 :3 0 551 552
0 89 :3 0 553
554 0 556 2e2
5a0 8a :3 0 87
:3 0 88 :3 0 559
55a 0 89 :3 0
55b 55c 0 596
52 :3 0 53 :3 0
55e 55f 0 52
:3 0 63 :3 0 561
562 0 8b :2 0
2 :4 0 b1 :2 0
65 :2 0 31 :2 0
2e5 567 569 :3 0
2e8 563 56b 560
56d 56c :2 0 55
:3 0 66 :3 0 56f
570 0 57 :4 0
b2 :4 0 5a :2 0
5b :3 0 2ec 574
576 :3 0 5a :2 0
8e :4 0 2ef 578
57a :3 0 5a :2 0
8f :4 0 2f2 57c
57e :3 0 5a :2 0
89 :3 0 2f5 580
582 :3 0 5a :2 0
90 :4 0 2f8 584
586 :3 0 5a :2 0
7d :3 0 91 :3 0
31 :2 0 92 :2 0
2fb 589 58d 2ff
588 58f :3 0 302
571 591 :2 0 593
305 594 56e 593
0 595 307 0
596 309 599 :3 0
599 0 599 598
596 597 :6 0 59b
8 :3 0 30c 59d
30e 59c 59b :2 0
59e 310 :2 0 5a0
0 5a0 59f 556
59e :6 0 5d3 1
:3 0 87 :3 0 88
:3 0 5a2 5a3 0
87 :3 0 75 :2 0
b3 :3 0 5a5 5a7
0 314 5a6 5a9
:3 0 5aa :2 0 52
:3 0 53 :3 0 5ac
5ad 0 52 :3 0
63 :3 0 5af 5b0
0 31 :2 0 2
:4 0 b4 :2 0 65
:2 0 31 :2 0 317
5b5 5b7 :3 0 31a
5b1 5b9 5ae 5bb
5ba :2 0 55 :3 0
66 :3 0 5bd 5be
0 57 :4 0 b5
:4 0 5a :2 0 5b
:3 0 31e 5c2 5c4
:3 0 321 5bf 5c6
:2 0 5c8 324 5c9
5bc 5c8 0 5ca
326 0 5d0 18
:3 0 68 :3 0 b6
:3 0 5cc 5cd 0
5ce :2 0 5d0 328
5d1 5ab 5d0 0
5d2 32b 0 5d3
32d 5d4 54a 5d3
0 5d5 330 0
5dc 3d :3 0 b7
:3 0 3 :3 0 332
5d7 5d9 5d6 5da
0 5dc 334 5de
366 40c 0 5df
0 5dc 0 5df
33a 0 a9f 5f
:3 0 b8 :3 0 5f
:3 0 b9 :3 0 ba
:3 0 bb :3 0 36
:3 0 39 :3 0 2e
:3 0 4e :3 0 bc
:3 0 97 :3 0 2d
:4 0 bd 1 :8 0
5f3 87 :3 0 88
:3 0 5ee 5ef 0
89 :3 0 5f0 5f1
0 5f3 33d 63d
8a :3 0 87 :3 0
88 :3 0 5f6 5f7
0 89 :3 0 5f8
5f9 0 633 52
:3 0 53 :3 0 5fb
5fc 0 52 :3 0
63 :3 0 5fe 5ff
0 8b :2 0 2
:4 0 be :2 0 65
:2 0 31 :2 0 340
604 606 :3 0 343
600 608 5fd 60a
609 :2 0 55 :3 0
66 :3 0 60c 60d
0 57 :4 0 bf
:4 0 5a :2 0 5b
:3 0 347 611 613
:3 0 5a :2 0 8e
:4 0 34a 615 617
:3 0 5a :2 0 8f
:4 0 34d 619 61b
:3 0 5a :2 0 89
:3 0 350 61d 61f
:3 0 5a :2 0 90
:4 0 353 621 623
:3 0 5a :2 0 7d
:3 0 91 :3 0 31
:2 0 92 :2 0 356
626 62a 35a 625
62c :3 0 35d 60e
62e :2 0 630 360
631 60b 630 0
632 362 0 633
364 636 :3 0 636
0 636 635 633
634 :6 0 638 a
:3 0 367 63a 369
639 638 :2 0 63b
36b :2 0 63d 0
63d 63c 5f3 63b
:6 0 a9f 1 :3 0
5f :3 0 3b :3 0
37 :2 0 36d 63f
642 75 :2 0 37
:2 0 372 644 646
:3 0 5f :3 0 1b
:3 0 37 :2 0 375
648 64b c0 :2 0
37 :2 0 37a 64d
64f :3 0 650 :2 0
5f :3 0 1d :3 0
37 :2 0 37d 652
655 75 :2 0 c1
:2 0 382 657 659
:3 0 65a :2 0 651
65c 65b :2 0 1b
:3 0 5f :3 0 36
:3 0 37 :2 0 385
65f 662 c2 :2 0
5f :3 0 1b :3 0
37 :2 0 388 665
668 38b 664 66a
:3 0 65e 66b 0
66d 38e 66e 65d
66d 0 66f 390
0 77f 5f :3 0
1a :3 0 37 :2 0
392 670 673 75
:2 0 37 :2 0 397
675 677 :3 0 c
:3 0 c3 :2 0 39a
67a 67b :3 0 67c
:2 0 5f :3 0 1b
:3 0 37 :2 0 39c
67e 681 c0 :2 0
37 :2 0 3a1 683
685 :3 0 1a :3 0
5f :3 0 22 :3 0
37 :2 0 3a4 688
68b c2 :2 0 5f
:3 0 1b :3 0 37
:2 0 3a7 68e 691
3aa 68d 693 :3 0
687 694 0 696
3ad 697 686 696
0 698 3af 0
699 3b1 6fa c4
:3 0 c5 :3 0 1a
:3 0 c6 :3 0 97
:3 0 2d :3 0 c7
:3 0 7c :3 0 7d
:3 0 b :3 0 7c
:3 0 7d :3 0 c
:4 0 c8 1 :8 0
6ad 87 :3 0 88
:3 0 6a8 6a9 0
89 :3 0 6aa 6ab
0 6ad 3b3 6f7
8a :3 0 87 :3 0
88 :3 0 6b0 6b1
0 89 :3 0 6b2
6b3 0 6ed 52
:3 0 53 :3 0 6b5
6b6 0 52 :3 0
63 :3 0 6b8 6b9
0 8b :2 0 2
:4 0 c9 :2 0 65
:2 0 31 :2 0 3b6
6be 6c0 :3 0 3b9
6ba 6c2 6b7 6c4
6c3 :2 0 55 :3 0
66 :3 0 6c6 6c7
0 57 :4 0 ca
:4 0 5a :2 0 5b
:3 0 3bd 6cb 6cd
:3 0 5a :2 0 8e
:4 0 3c0 6cf 6d1
:3 0 5a :2 0 8f
:4 0 3c3 6d3 6d5
:3 0 5a :2 0 89
:3 0 3c6 6d7 6d9
:3 0 5a :2 0 90
:4 0 3c9 6db 6dd
:3 0 5a :2 0 7d
:3 0 91 :3 0 31
:2 0 92 :2 0 3cc
6e0 6e4 3d0 6df
6e6 :3 0 3d3 6c8
6e8 :2 0 6ea 3d6
6eb 6c5 6ea 0
6ec 3d8 0 6ed
3da 6f0 :3 0 6f0
0 6f0 6ef 6ed
6ee :6 0 6f2 c
:3 0 3dd 6f4 3df
6f3 6f2 :2 0 6f5
3e1 :2 0 6f7 0
6f7 6f6 6ad 6f5
:6 0 6f9 1 :3 0
3e3 6fb 67d 699
0 6fc 0 6f9
0 6fc 3e5 0
6fd 3e8 74c 5f
:3 0 1c :3 0 37
:2 0 3ea 6fe 701
75 :2 0 31 :2 0
3ef 703 705 :3 0
1a :3 0 5f :3 0
1a :3 0 37 :2 0
3f2 708 70b c2
:2 0 cb :2 0 3f5
70d 70f :3 0 707
710 0 713 71
:3 0 3f8 749 5f
:3 0 1c :3 0 37
:2 0 3fa 714 717
75 :2 0 cc :2 0
3ff 719 71b :3 0
1a :3 0 5f :3 0
36 :3 0 37 :2 0
402 71e 721 c2
:2 0 5f :3 0 1a
:3 0 37 :2 0 405
724 727 408 723
729 :3 0 71d 72a
0 72d 71 :3 0
40b 72e 71c 72d
0 74a 5f :3 0
1c :3 0 37 :2 0
40d 72f 732 75
:2 0 cd :2 0 412
734 736 :3 0 1a
:3 0 5f :3 0 39
:3 0 37 :2 0 415
739 73c c2 :2 0
5f :3 0 1a :3 0
37 :2 0 418 73f
742 41b 73e 744
:3 0 738 745 0
747 41e 748 737
747 0 74a 706
713 0 74a 420
0 74b 424 74d
678 6fd 0 74e
0 74b 0 74e
426 0 77f 5f
:3 0 1a :3 0 37
:2 0 429 74f 752
75 :2 0 37 :2 0
42e 754 756 :3 0
52 :3 0 53 :3 0
758 759 0 52
:3 0 63 :3 0 75b
75c 0 31 :2 0
2 :4 0 ce :2 0
65 :2 0 31 :2 0
431 761 763 :3 0
434 75d 765 75a
767 766 :2 0 55
:3 0 66 :3 0 769
76a 0 57 :4 0
cf :4 0 5a :2 0
5b :3 0 438 76e
770 :3 0 43b 76b
772 :2 0 774 43e
775 768 774 0
776 440 0 77c
18 :3 0 68 :3 0
a6 :3 0 778 779
0 77a :2 0 77c
442 77d 757 77c
0 77e 445 0
77f 447 780 647
77f 0 781 44b
0 a9f 5f :3 0
1f :3 0 37 :2 0
44d 782 785 75
:2 0 cc :2 0 452
787 789 :3 0 1f
:3 0 6d :3 0 5f
:3 0 1f :3 0 37
:2 0 455 78d 790
68 :3 0 d0 :3 0
792 793 0 458
78c 795 796 :2 0
78b 797 0 79a
71 :3 0 45b 98c
7d :3 0 30 :3 0
31 :2 0 31 :2 0
45d 79b 79f 75
:2 0 37 :4 0 463
7a1 7a3 :3 0 7a4
:2 0 5f :3 0 1e
:3 0 37 :2 0 466
7a6 7a9 75 :2 0
37 :2 0 46b 7ab
7ad :3 0 7ae :2 0
7a5 7b0 7af :2 0
85 :3 0 d1 :3 0
d2 :3 0 d3 :3 0
d4 :3 0 d5 :3 0
2c :3 0 26 :3 0
28 :3 0 4d :3 0
32 :3 0 84 :3 0
76 :3 0 2d :3 0
77 :3 0 2d :3 0
78 :3 0 25 :4 0
d6 1 :8 0 7ca
87 :3 0 88 :3 0
7c5 7c6 0 89
:3 0 7c7 7c8 0
7ca 46e 814 8a
:3 0 87 :3 0 88
:3 0 7cd 7ce 0
89 :3 0 7cf 7d0
0 80a 52 :3 0
53 :3 0 7d2 7d3
0 52 :3 0 63
:3 0 7d5 7d6 0
8b :2 0 2 :4 0
d7 :2 0 65 :2 0
31 :2 0 471 7db
7dd :3 0 474 7d7
7df 7d4 7e1 7e0
:2 0 55 :3 0 66
:3 0 7e3 7e4 0
57 :4 0 d8 :4 0
5a :2 0 5b :3 0
478 7e8 7ea :3 0
5a :2 0 8e :4 0
47b 7ec 7ee :3 0
5a :2 0 8f :4 0
47e 7f0 7f2 :3 0
5a :2 0 89 :3 0
481 7f4 7f6 :3 0
5a :2 0 90 :4 0
484 7f8 7fa :3 0
5a :2 0 7d :3 0
91 :3 0 31 :2 0
92 :2 0 487 7fd
801 48b 7fc 803
:3 0 48e 7e5 805
:2 0 807 491 808
7e2 807 0 809
493 0 80a 495
80d :3 0 80d 0
80d 80c 80a 80b
:6 0 80f e :3 0
498 811 49a 810
80f :2 0 812 49c
:2 0 814 0 814
813 7ca 812 :6 0
98a 1 :3 0 87
:3 0 88 :3 0 816
817 0 87 :3 0
75 :2 0 b3 :3 0
819 81b 0 4a0
81a 81d :3 0 81e
:2 0 2c :3 0 d9
:2 0 4a3 821 822
:3 0 823 :2 0 81f
825 824 :2 0 1f
:3 0 6d :3 0 5f
:3 0 1f :3 0 37
:2 0 4a5 829 82c
68 :3 0 d0 :3 0
82e 82f 0 4a8
828 831 832 :2 0
827 833 0 987
da :3 0 db :3 0
835 836 0 b
:3 0 26 :3 0 dc
:2 0 4ab 837 83b
69 :2 0 37 :2 0
4b1 83d 83f :3 0
840 :2 0 da :3 0
db :3 0 842 843
0 28 :3 0 c
:3 0 dc :2 0 4b4
844 848 69 :2 0
37 :2 0 4ba 84a
84c :3 0 84d :2 0
841 84f 84e :2 0
7d :3 0 32 :3 0
31 :2 0 31 :2 0
4bd 851 855 75
:2 0 cc :4 0 4c3
857 859 :3 0 5f
:3 0 3b :3 0 37
:2 0 4c6 85b 85e
75 :2 0 37 :2 0
4cb 860 862 :3 0
1f :3 0 cc :2 0
864 865 0 867
4ce 868 863 867
0 869 4d0 0
86d 1e :3 0 cc
:2 0 86a 86b 0
86d 4d2 86e 85a
86d 0 86f 4d5
0 870 4d7 984
5f :3 0 1f :3 0
37 :2 0 4d9 871
874 75 :2 0 31
:2 0 4de 876 878
:3 0 3a :3 0 6b
:3 0 dd :3 0 87b
87c 0 5f :3 0
3a :3 0 37 :2 0
4e1 87e 881 68
:3 0 6a :3 0 883
884 0 4e4 87d
886 887 :2 0 87a
888 0 88a 4e7
88b 879 88a 0
88c 4e9 0 983
5f :3 0 4d :3 0
37 :2 0 4eb 88d
890 5f :3 0 de
:2 0 1a :3 0 37
:2 0 4ee 892 896
4f3 893 898 :3 0
5f :3 0 4d :3 0
37 :2 0 4f6 89a
89d c0 :2 0 37
:2 0 4fb 89f 8a1
:3 0 da :3 0 db
:3 0 8a3 8a4 0
b :3 0 28 :3 0
dc :2 0 4fe 8a5
8a9 69 :2 0 37
:2 0 504 8ab 8ad
:3 0 8a2 8af 8ae
:2 0 7d :3 0 32
:3 0 31 :2 0 31
:2 0 507 8b1 8b5
75 :2 0 37 :4 0
50d 8b7 8b9 :3 0
4f :3 0 cd :2 0
8bb 8bc 0 8be
510 8bf 8ba 8be
0 8c0 512 0
8f4 3d :3 0 df
:4 0 8c2 8c3 :3 0
8c1 8c4 0 8f4
3a :3 0 68 :3 0
e0 :3 0 8c7 8c8
0 8c6 8c9 0
8f4 3d :3 0 e1
:3 0 3 :3 0 2d
:3 0 23 :3 0 25
:3 0 51 :3 0 38
:3 0 7 :3 0 8
:3 0 35 :3 0 35
:3 0 b :3 0 28
:3 0 50 :3 0 4d
:3 0 1b :3 0 1c
:3 0 1d :3 0 50
:3 0 3a :3 0 30
:3 0 1e :3 0 1f
:3 0 20 :3 0 22
:3 0 4f :3 0 36
:3 0 4e :3 0 17
:3 0 5f :3 0 36
:3 0 37 :2 0 514
8e9 8ec 37 :2 0
74 :2 0 74 :2 0
517 8cc 8f1 8cb
8f2 0 8f4 538
8f5 8b0 8f4 0
8f6 53d 0 980
84 :3 0 e2 :3 0
1a :3 0 9c :3 0
3 :4 0 e3 1
:8 0 912 a9 :4 0
8fd :3 0 aa :3 0
75 :2 0 541 900
901 :3 0 87 :3 0
88 :3 0 903 904
0 37 :2 0 905
906 0 908 544
90f 87 :3 0 88
:3 0 909 90a 0
ab :2 0 90b 90c
0 90e 546 910
902 908 0 911
0 90e 0 911
548 0 912 54b
95c 8a :3 0 87
:3 0 88 :3 0 915
916 0 89 :3 0
917 918 0 952
52 :3 0 53 :3 0
91a 91b 0 52
:3 0 63 :3 0 91d
91e 0 8b :2 0
2 :4 0 e4 :2 0
65 :2 0 31 :2 0
54e 923 925 :3 0
551 91f 927 91c
929 928 :2 0 55
:3 0 66 :3 0 92b
92c 0 57 :4 0
e5 :4 0 5a :2 0
5b :3 0 555 930
932 :3 0 5a :2 0
8e :4 0 558 934
936 :3 0 5a :2 0
8f :4 0 55b 938
93a :3 0 5a :2 0
89 :3 0 55e 93c
93e :3 0 5a :2 0
90 :4 0 561 940
942 :3 0 5a :2 0
7d :3 0 91 :3 0
31 :2 0 92 :2 0
564 945 949 568
944 94b :3 0 56b
92d 94d :2 0 94f
56e 950 92a 94f
0 951 570 0
952 572 955 :3 0
955 0 955 954
952 953 :6 0 957
10 :3 0 575 959
577 958 957 :2 0
95a 579 :2 0 95c
0 95c 95b 912
95a :6 0 980 1
:3 0 52 :3 0 53
:3 0 95e 95f 0
52 :3 0 63 :3 0
961 962 0 31
:2 0 2 :4 0 e6
:2 0 65 :2 0 31
:2 0 57b 967 969
:3 0 57e 963 96b
960 96d 96c :2 0
55 :3 0 66 :3 0
96f 970 0 57
:4 0 e7 :4 0 5a
:2 0 5b :3 0 582
974 976 :3 0 585
971 978 :2 0 97a
588 97b 96e 97a
0 97c 58a 0
980 18 :3 0 37
:2 0 97e :2 0 980
58c 981 899 980
0 982 591 0
983 593 985 850
870 0 986 0
983 0 986 596
0 987 599 988
826 987 0 989
59c 0 98a 59e
98b 7b1 98a 0
98d 78a 79a 0
98d 5a1 0 a9f
5f :3 0 1f :3 0
37 :2 0 5a4 98e
991 75 :2 0 37
:2 0 5a9 993 995
:3 0 996 :2 0 5f
:3 0 22 :3 0 37
:2 0 5ac 998 99b
5f :3 0 75 :2 0
3f :3 0 37 :2 0
5af 99d 9a1 5b4
99e 9a3 :3 0 9a4
:2 0 997 9a6 9a5
:2 0 5f :3 0 3b
:3 0 37 :2 0 5b7
9a8 9ab a3 :2 0
37 :2 0 5bc 9ad
9af :3 0 1f :3 0
6b :3 0 dd :3 0
9b2 9b3 0 5f
:3 0 1f :3 0 37
:2 0 5bf 9b5 9b8
5f :3 0 3b :3 0
37 :2 0 5c2 9ba
9bd 5c5 9b4 9bf
9c0 :2 0 9b1 9c1
0 9c3 5c8 9c4
9b0 9c3 0 9c5
5ca 0 9e4 3d
:3 0 e8 :3 0 3
:3 0 2d :3 0 23
:3 0 25 :3 0 7
:3 0 8 :3 0 b
:3 0 c :3 0 1a
:3 0 1b :3 0 1c
:3 0 1d :3 0 30
:3 0 1e :3 0 1f
:3 0 20 :3 0 21
:3 0 22 :3 0 3a
:3 0 16 :3 0 17
:3 0 36 :3 0 74
:2 0 74 :2 0 5cc
9c7 9e0 9c6 9e1
0 9e4 71 :3 0
5e5 a2b 5f :3 0
1f :3 0 37 :2 0
5e8 9e5 9e8 75
:2 0 31 :2 0 5ed
9ea 9ec :3 0 5f
:3 0 3b :3 0 37
:2 0 5f0 9ee 9f1
a3 :2 0 37 :2 0
5f5 9f3 9f5 :3 0
1f :3 0 6b :3 0
dd :3 0 9f8 9f9
0 5f :3 0 1f
:3 0 37 :2 0 5f8
9fb 9fe 5f :3 0
3b :3 0 37 :2 0
5fb a00 a03 5fe
9fa a05 a06 :2 0
9f7 a07 0 a09
601 a0a 9f6 a09
0 a0b 603 0
a29 3d :3 0 e8
:3 0 2c :3 0 2d
:3 0 23 :3 0 25
:3 0 7 :3 0 8
:3 0 b :3 0 c
:3 0 1a :3 0 1b
:3 0 1c :3 0 1d
:3 0 30 :3 0 1e
:3 0 1f :3 0 20
:3 0 21 :3 0 22
:3 0 3a :3 0 16
:3 0 17 :3 0 36
:3 0 74 :2 0 74
:2 0 605 a0d a26
a0c a27 0 a29
61e a2a 9ed a29
0 a2c 9a7 9e4
0 a2c 621 0
a9f 5f :3 0 3d
:3 0 37 :2 0 624
a2d a30 75 :2 0
e9 :2 0 629 a32
a34 :3 0 87 :3 0
88 :3 0 a36 a37
0 68 :3 0 ea
:3 0 a39 a3a 0
a38 a3b 0 a3e
71 :3 0 62c a5c
5f :3 0 3d :3 0
37 :2 0 62e a3f
a42 a3 :2 0 37
:2 0 633 a44 a46
:3 0 5f :3 0 3d
:3 0 37 :2 0 636
a48 a4b a3 :2 0
ab :2 0 63b a4d
a4f :3 0 a47 a51
a50 :2 0 87 :3 0
88 :3 0 a53 a54
0 68 :3 0 a6
:3 0 a56 a57 0
a55 a58 0 a5a
63e a5b a52 a5a
0 a5d a35 a3e
0 a5d 640 0
a9f 87 :3 0 88
:3 0 a5e a5f 0
75 :2 0 ab :2 0
645 a61 a63 :3 0
87 :3 0 88 :3 0
a65 a66 0 37
:2 0 a67 a68 0
a6a 648 a6b a64
a6a 0 a6c 64a
0 a9f 52 :3 0
53 :3 0 a6d a6e
0 52 :3 0 63
:3 0 a70 a71 0
31 :2 0 2 :4 0
eb :2 0 65 :2 0
31 :2 0 64c a76
a78 :3 0 64f a72
a7a a6f a7c a7b
:2 0 55 :3 0 66
:3 0 a7e a7f 0
57 :4 0 ec :4 0
5a :2 0 5b :3 0
653 a83 a85 :3 0
5a :2 0 8e :4 0
656 a87 a89 :3 0
5a :2 0 ed :4 0
659 a8b a8d :3 0
5a :2 0 87 :3 0
88 :3 0 a90 a91
0 65c a8f a93
:3 0 65f a80 a95
:2 0 a97 662 a98
a7d a97 0 a99
664 0 a9f 18
:3 0 87 :3 0 88
:3 0 a9b a9c 0
a9d :2 0 a9f 666
aa2 :3 0 aa2 67b
aa2 aa1 a9f aa0
:6 0 aa3 :2 0 2
58 aa2 aa6 :3 0
aa5 aa3 aa7 :8 0

6ae
4
:3 0 1 3 1
9 1 f 1
15 1 19 1
1f 1 25 1
29 1 2d 1
31 1 35 1
39 1 3d 1
41 1 45 1
49 1 4f 11
8 e 14 18
1e 24 28 2c
30 34 38 3c
40 44 48 4e
54 1 5a 1
60 1 66 1
6c 1 72 1
78 1 7e 1
84 1 8a 1
90 1 98 1
96 1 9f 1
9d 1 a6 1
a4 1 ad 1
ab 1 b2 1
b7 1 be 1
bc 1 c5 1
c3 1 cc 1
ca 1 d3 1
d1 1 da 1
d8 1 e1 1
df 1 e8 1
e6 1 ef 1
ed 1 f4 1
fa 1 100 1
106 1 10c 1
112 1 118 1
11e 1 124 1
12a 1 132 1
130 1 139 1
137 1 13e 1
143 1 148 1
14e 1 154 1
15a 1 160 1
166 1 16c 1
172 1 178 1
17e 1 184 1
18a 1 196 1
1a2 2 1a5 1a7
2 1aa 1ac 2
1ae 1b0 2 1b2
1b4 2 1b6 1b8
2 1ba 1bc 2
1be 1c0 2 1c2
1c4 2 1c6 1c8
2 1ca 1cc 2
1ce 1d0 2 1d2
1d4 2 1d6 1d8
1 1de 2 1e0
1e1 2 1da 1e3
2 1e5 1e7 2
1e9 1eb 2 1ed
1ef 2 1f1 1f3
2 1f5 1f7 2
1f9 1fb 2 1fd
1ff 2 201 203
2 205 207 1
20d 2 20f 210
2 209 212 2
214 216 1 21c
2 21e 21f 2
218 221 2 223
225 1 22b 2
22d 22e 2 227
230 2 232 234
1 23a 2 23c
23d 2 236 23f
2 241 243 1
249 2 24b 24c
2 245 24e 2
250 252 1 258
2 25a 25b 2
254 25d 2 25f
261 1 267 2
269 26a 2 263
26c 2 26e 270
1 276 2 278
279 2 272 27b
2 27d 27f 1
285 2 287 288
2 281 28a 2
28c 28e 2 290
292 2 294 296
2 298 29a 2
29c 29e 2 2a0
2a2 2 2a4 2a6
2 2a8 2aa 2
2ac 2ae 4 19e
1a4 1a9 2b0 1
2b2 1 2b4 2
2be 2c0 3 2bc
2bd 2c2 2 2cb
2cd 2 2ca 2cf
1 2d1 1 2d3
2 2d6 2d7 1
2dd 2 2d9 2dd
2 2e6 2e7 2
2e9 2ec 2 2ef
2f0 2 2f7 2f8
2 2fa 2fd 4
2f3 300 303 306
2 30a 30b 1
311 2 30d 311
2 317 318 2
31a 31d 2 325
326 2 328 32b
3 321 32f 332
2 337 338 3
33b 33e 341 3
343 334 344 2
35f 360 1 364
2 362 364 2
389 38e 2 39f
3a1 3 39d 39e
3a3 2 3ac 3ae
2 3b0 3b2 2
3b4 3b6 2 3b8
3ba 2 3bc 3be
3 3c3 3c4 3c5
2 3c0 3c7 2
3ab 3c9 1 3cb
1 3cd 2 396
3ce 1 3d2 1
391 1 3d6 1
3e1 2 3dd 3e1
2 3ed 3ef 3
3eb 3ec 3f1 2
3fa 3fc 2 3f9
3fe 1 400 1
402 2 403 408
1 40a 3 369
3d9 40b 2 41e
423 2 434 436
3 432 433 438
2 441 443 2
445 447 2 449
44b 2 44d 44f
2 451 453 3
458 459 45a 2
455 45c 2 440
45e 1 460 1
462 2 42b 463
1 467 1 426
1 46b 1 476
2 472 476 2
482 484 3 480
481 486 2 48f
491 2 48e 493
1 495 1 497
2 498 49d 2
4a2 4a3 1 4a5
1 4a9 2 4a7
4a9 2 4b4 4b6
3 4b2 4b3 4b8
2 4c1 4c3 2
4c0 4c5 1 4c7
1 4c9 2 4ca
4cf 2 4d2 4d1
1 4dc 2 4db
4dc 1 4e4 1
4ea 2 4ec 4ed
2 4d9 4ee 2
4ff 501 3 4fd
4fe 503 2 50c
50e 2 510 512
2 514 516 2
518 51a 2 51c
51e 3 523 524
525 2 520 527
2 50b 529 1
52b 1 52d 2
4f6 52e 1 532
1 4f1 1 536
2 53d 53e 1
540 1 545 2
543 545 1 547
2 550 555 2
566 568 3 564
565 56a 2 573
575 2 577 579
2 57b 57d 2
57f 581 2 583
585 3 58a 58b
58c 2 587 58e
2 572 590 1
592 1 594 2
55d 595 1 599
1 558 1 59d
1 5a8 2 5a4
5a8 2 5b4 5b6
3 5b2 5b3 5b8
2 5c1 5c3 2
5c0 5c5 1 5c7
1 5c9 2 5ca
5cf 1 5d1 2
5a0 5d2 1 5d4
1 5d8 5 46e
4d3 539 5d5 5db
2 5dd 5de 2
5ed 5f2 2 603
605 3 601 602
607 2 610 612
2 614 616 2
618 61a 2 61c
61e 2 620 622
3 627 628 629
2 624 62b 2
60f 62d 1 62f
1 631 2 5fa
632 1 636 1
5f5 1 63a 2
640 641 1 645
2 643 645 2
649 64a 1 64e
2 64c 64e 2
653 654 1 658
2 656 658 2
660 661 2 666
667 2 663 669
1 66c 1 66e
2 671 672 1
676 2 674 676
1 679 2 67f
680 1 684 2
682 684 2 689
68a 2 68f 690
2 68c 692 1
695 1 697 1
698 2 6a7 6ac
2 6bd 6bf 3
6bb 6bc 6c1 2
6ca 6cc 2 6ce
6d0 2 6d2 6d4
2 6d6 6d8 2
6da 6dc 3 6e1
6e2 6e3 2 6de
6e5 2 6c9 6e7
1 6e9 1 6eb
2 6b4 6ec 1
6f0 1 6af 1
6f4 1 6f7 2
6fa 6fb 1 6fc
2 6ff 700 1
704 2 702 704
2 709 70a 2
70c 70e 1 711
2 715 716 1
71a 2 718 71a
2 71f 720 2
725 726 2 722
728 1 72b 2
730 731 1 735
2 733 735 2
73a 73b 2 740
741 2 73d 743
1 746 3 749
72e 748 1 74a
2 74c 74d 2
750 751 1 755
2 753 755 2
760 762 3 75e
75f 764 2 76d
76f 2 76c 771
1 773 1 775
2 776 77b 1
77d 3 66f 74e
77e 1 780 2
783 784 1 788
2 786 788 2
78e 78f 2 791
794 1 798 3
79c 79d 79e 1
7a2 2 7a0 7a2
2 7a7 7a8 1
7ac 2 7aa 7ac
2 7c4 7c9 2
7da 7dc 3 7d8
7d9 7de 2 7e7
7e9 2 7eb 7ed
2 7ef 7f1 2
7f3 7f5 2 7f7
7f9 3 7fe 7ff
800 2 7fb 802
2 7e6 804 1
806 1 808 2
7d1 809 1 80d
1 7cc 1 811
1 81c 2 818
81c 1 820 2
82a 82b 2 82d
830 3 838 839
83a 1 83e 2
83c 83e 3 845
846 847 1 84b
2 849 84b 3
852 853 854 1
858 2 856 858
2 85c 85d 1
861 2 85f 861
1 866 1 868
2 869 86c 1
86e 1 86f 2
872 873 1 877
2 875 877 2
87f 880 2 882
885 1 889 1
88b 2 88e 88f
2 894 895 1
897 2 891 897
2 89b 89c 1
8a0 2 89e 8a0
3 8a6 8a7 8a8
1 8ac 2 8aa
8ac 3 8b2 8b3
8b4 1 8b8 2
8b6 8b8 1 8bd
1 8bf 2 8ea
8eb 20 8cd 8ce
8cf 8d0 8d1 8d2
8d3 8d4 8d5 8d6
8d7 8d8 8d9 8da
8db 8dc 8dd 8de
8df 8e0 8e1 8e2
8e3 8e4 8e5 8e6
8e7 8e8 8ed 8ee
8ef 8f0 4 8c0
8c5 8ca 8f3 1
8f5 1 8ff 2
8fe 8ff 1 907
1 90d 2 90f
910 2 8fc 911
2 922 924 3
920 921 926 2
92f 931 2 933
935 2 937 939
2 93b 93d 2
93f 941 3 946
947 948 2 943
94a 2 92e 94c
1 94e 1 950
2 919 951 1
955 1 914 1
959 2 966 968
3 964 965 96a
2 973 975 2
972 977 1 979
1 97b 4 8f6
95c 97c 97f 1
981 2 88c 982
2 984 985 2
834 986 1 988
2 814 989 2
98c 98b 2 98f
990 1 994 2
992 994 2 999
99a 2 99f 9a0
1 9a2 2 99c
9a2 2 9a9 9aa
1 9ae 2 9ac
9ae 2 9b6 9b7
2 9bb 9bc 2
9b9 9be 1 9c2
1 9c4 18 9c8
9c9 9ca 9cb 9cc
9cd 9ce 9cf 9d0
9d1 9d2 9d3 9d4
9d5 9d6 9d7 9d8
9d9 9da 9db 9dc
9dd 9de 9df 2
9c5 9e2 2 9e6
9e7 1 9eb 2
9e9 9eb 2 9ef
9f0 1 9f4 2
9f2 9f4 2 9fc
9fd 2 a01 a02
2 9ff a04 1
a08 1 a0a 18
a0e a0f a10 a11
a12 a13 a14 a15
a16 a17 a18 a19
a1a a1b a1c a1d
a1e a1f a20 a21
a22 a23 a24 a25
2 a0b a28 2
a2b a2a 2 a2e
a2f 1 a33 2
a31 a33 1 a3c
2 a40 a41 1
a45 2 a43 a45
2 a49 a4a 1
a4e 2 a4c a4e
1 a59 2 a5c
a5b 1 a62 2
a60 a62 1 a69
1 a6b 2 a75
a77 3 a73 a74
a79 2 a82 a84
2 a86 a88 2
a8a a8c 2 a8e
a92 2 a81 a94
1 a96 1 a98
14 2b5 2d4 345
348 34b 34e 351
354 357 35a 35d
5df 63d 781 98d
a2c a5d a6c a99
a9e 32 5e 64
6a 70 76 7c
82 88 8e 94
9b a2 a9 b0
b5 ba c1 c8
cf d6 dd e4
eb f2 f8 fe
104 10a 110 116
11c 122 128 12e
135 13c 141 146
14c 152 158 15e
164 16a 170 176
17c 182 188 18e

1
4
0 
aa6
0
1
14
11
44
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 0 0 0 
ca 1 0
2 0 1
12a 1 0
41 1 0
39 1 0
f4 1 0
106 1 0
15 1 0
112 1 0
1f 1 0
bc 1 0
29 1 0
160 1 0
130 1 0
25 1 0
d8 1 0
14e 1 0
3 1 0
17e 1 0
b2 1 0
118 1 0
16c 1 0
10c 1 0
b7 1 0
72 1 0
f 1 0
a4 1 0
60 1 0
3d 1 0
8a 1 0
19 1 0
9 1 0
90 1 0
154 1 0
11e 1 0
d1 1 0
7e 1 0
2d 1 0
184 1 0
172 1 0
143 1 0
ab 1 0
15a 1 0
100 1 0
96 1 0
45 1 0
124 1 0
18a 1 0
6c 1 0
66 1 0
178 1 0
df 1 0
78 1 0
fa 1 0
c3 1 0
9d 1 0
35 1 0
5a 1 0
148 1 0
13e 1 0
31 1 0
e6 1 0
166 1 0
4f 1 0
49 1 0
84 1 0
137 1 0
ed 1 0
0

/
SHOW ERRORS FUNCTION FC_U_TSKRES2;
ALTER FUNCTION FC_U_TSKRES2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_TSKRES2
#Short Description :Update resource/profile assignment
#Description       :Gets call from FC_SEARCH_2
#Table Name        :
#Parameters        :
 $$if bitflag  = 0 then insert new assignment (assign_id = RES_ASSIGNMENT_ID)
               = 1 then update an existing assignment (assign_id = TSK_ASSIGNMENT_ID)
               = 2 then insert new assignment using project assignment (assign_id = RES_ASSIGNMENT_ID)
               = 3 then reject a profile replacement, uncommit everything
               = 9 MSP
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_TSKRES2 ==
CREATE OR REPLACE FUNCTION SP_U_TSKRES2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
71
2 :e:
1FUNCTION:
1SP_U_TSKRES2:
1ASSIGN_ID:
1VARCHAR2:
1AND_ROLES:
1AND_SKILLS:
1WORK_LOCATION001:
1PLS_INTEGER:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1WORK001:
1EUNIT:
1UNIT:
1WORK_TYPE:
1BITFLAG001:
1CONTOUR001:
1CONTOUR_TYPE001:
1OCCURRENCE:
1ASSIGN_STRING001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ASSIGN_ID:
132:
1H_AND_ROLES:
18000:
1H_AND_SKILLS:
1H_WORK_LOCATION:
10:
1H_START_DATE:
126:
1H_FINISH_DATE:
1H_EFFORT:
1H_WORK:
1H_EUNIT:
1H_UNIT:
1H_WORK_TYPE:
1H_BITFLAG:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_OCCURRENCE:
1H_ASSIGN_STRING:
18192:
1H_REC_USER:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_TSKRES2(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
164:
1+:
1FPUT:
1               ENTER:: SP_U_TSKRES2(65) :: cplan.sql(7244) :: :
1IS NULL:
18:
172:
1      RETURN_INVALID:: SP_U_TSKRES2(73) :: cplan.sql(7252) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
175:
1                EXIT:: SP_U_TSKRES2(76) :: cplan.sql(7255) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_STATE:
1FC_U_TSKRES2:
14:
1105:
1       RETURN_STATUS:: SP_U_TSKRES2(106) :: cplan.sql(7285) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
116:
1113:
1           EXCEPTION:: SP_U_TSKRES2(114) :: cplan.sql(7293) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
1125:
1           EXCEPTION:: SP_U_TSKRES2(126) :: cplan.sql(7305) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
3ca
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
52 10 a0 7e b4 2e :2 5a 52
10 a0 7e b4 2e :2 5a 52 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 6b :12 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
3ca
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 13a
160 164 168 16c 16f 173 190 17b
17f 182 183 18b 17a 1ad 19b 177
19f 1a0 1a8 19a 1ca 1b8 197 1bc
1bd 1c5 1b7 1e6 1d5 1d9 1b4 1e1
1d4 203 1f1 1d1 1f5 1f6 1fe 1f0
220 20e 1ed 212 213 21b 20d 23c
22b 22f 20a 237 22a 258 247 24b
227 253 246 274 263 267 243 26f
262 290 27f 283 25f 28b 27e 2ac
29b 29f 27b 2a7 29a 2c8 2b7 2bb
297 2c3 2b6 2e4 2d3 2d7 2b3 2df
2d2 300 2ef 2f3 2cf 2fb 2ee 31c
30b 30f 2eb 317 30a 339 327 307
32b 32c 334 326 356 344 323 348
349 351 343 372 361 365 340 36d
360 392 37d 381 35d 385 38d 37c
399 39d 379 3a1 3a5 3a9 3ac 3b1
3b2 1 3b4 3b9 3bd 3c1 3c4 3c9
3cd 3d1 3d4 3d9 3da 3dc 3e1 3e4
3e8 3e9 3ee 3f3 3f6 3fb 3fc 401
404 408 409 40e 411 416 417 41c
41f 424 425 42a 42d 432 433 438
43b 43f 440 445 448 44d 44e 453
456 45b 45c 461 464 469 46a 46f
472 476 477 47c 47f 484 485 48a
48d 492 493 498 49b 49f 4a3 4a7
4a8 4aa 4af 4b0 4b2 4b3 4b8 4bb
4c0 4c1 4c6 4c9 4ce 4cf 4d4 4d7
4db 4dc 4e1 4e4 4e9 4ea 4ef 4f2
4f7 4f8 4fd 500 505 506 50b 50e
512 513 518 51b 520 521 526 529
52e 52f 534 537 53b 53f 543 544
546 54b 54c 54e 54f 554 557 55c
55d 562 565 569 56d 571 572 574
579 57a 57c 57d 582 585 58a 58b
590 593 597 59b 59f 5a0 5a2 5a7
5a8 5aa 5ab 5b0 5b3 5b8 5b9 5be
5c1 5c5 5c9 5cd 5ce 5d0 5d5 5d6
5d8 5d9 5de 5e1 5e6 5e7 5ec 5ef
5f3 5f7 5fb 5fc 5fe 603 604 606
607 60c 60f 614 615 61a 61d 621
625 629 62a 62c 631 632 634 635
63a 63d 642 643 648 64b 64f 653
657 658 65a 65f 660 662 663 668
66b 670 671 676 679 67d 681 685
686 688 68d 68e 690 691 696 699
69e 69f 6a4 6a7 6ab 6af 6b3 6b4
6b6 6bb 6bc 6be 6bf 6c4 6c7 6cc
6cd 6d2 6d5 6da 6db 6e0 6e3 6e7
6e8 6ed 6f0 6f5 6f6 6fb 6fe 703
704 709 70c 711 712 717 71a 71e
71f 724 727 72c 72d 732 735 73a
73b 740 741 746 748 74c 74f 753
757 75a 75e 762 765 768 76d 770
773 776 777 77c 77d 1 77f 784
788 78c 78f 794 799 79c 7a0 7a1
7a6 7a7 7ac 7ae 7b2 7b5 7b9 7bc
7bd 7c2 7c5 7c8 7cc 7cf 7d0 7d5
7d8 1 7db 7e0 7e4 7e7 7e8 7ed
7f0 1 7f3 7f8 7fc 7ff 800 805
808 1 80b 810 814 818 81b 81f
823 826 829 82e 831 834 837 838
83d 83e 1 840 845 849 84d 850
855 85a 85d 861 862 867 86a 86f
870 875 878 87d 87e 883 886 88a
88e 892 896 899 89a 89c 8a1 8a2
8a4 8a5 8aa 8ab 8b0 8b2 8b6 8b9
8bd 8c1 8c4 8c8 8cc 8cf 8d2 8d7
8da 8dd 8e0 8e1 8e6 8e7 1 8e9
8ee 8f2 8f6 8f9 8fe 903 906 90a
90b 910 911 916 918 91c 91f 923
927 92a 92e 932 935 939 93a 93f
941 945 948 94c 950 954 958 95c
960 964 968 96c 970 974 978 97c
980 984 988 98c 990 994 998 99c
9a0 9a4 9a8 9ac 9b0 9b4 9b8 9bc
9c0 9c4 9c8 9cc 9d0 9d4 9d8 9dc
9e0 9e4 9e8 9ec 9f0 9f4 9f8 9fc
a00 a04 a08 a0c a10 a14 a18 a1c
a1f a23 a27 a2b a2f a33 a37 a3b
a3f a43 a47 a4b a4f a53 a57 a5b
a5f a63 a67 a68 a6a a6e a72 a76
a79 a7d a81 a84 a87 a8c a8f a92
a95 a96 a9b a9c 1 a9e aa3 aa7
aab aae ab3 ab8 abb abf ac0 ac5
ac8 acd ace ad3 ad6 adb adc ae1
ae4 ae8 aec af0 af4 af7 af8 afa
aff b00 b02 b03 b08 b0b b10 b11
b16 b19 b1e b1f b24 b27 b2b b2c
b31 b34 b39 b3a b3f b40 b45 b47
b4b b4e b52 b56 b59 b5d b61 b64
b68 b6c b6d b72 b74 b78 b7c b7f
b83 b87 b8a b8e b92 b95 b98 b9d
ba0 ba3 ba6 ba7 bac bad 1 baf
bb4 bb8 bbc bbf bc4 bc9 bcc bd0
bd1 bd6 bd7 bdc be0 be4 be7 bec
bf1 bf4 bf8 bfc bff c00 c05 c08
c0d c0e c13 c16 c1a c1e c21 c22
c27 c28 c2d c2f c33 c36 c3a c3e
c42 c46 c4a c4e c52 c56 c5a c66
c6b c6f c73 c77 c7b c7d c7e c83
1 c87 c8b c8f c92 c96 c9a c9e
ca2 ca5 ca9 cad cb0 cb3 cb8 cbb
cbe cc1 cc2 cc7 cc8 1 cca ccf
cd3 cd7 cda cdf ce4 ce7 ceb cec
cf1 cf2 cf7 cfb cff d02 d07 d0c
d0f d13 d14 d19 d1c d21 d22 d27
d2a d2e d32 d35 d38 d39 d3b d3c
d41 d42 d47 d49 d4d d50 d54 d58
d5c d60 d64 d68 d6c d78 d7d d81
d85 d89 d8d d8f d93 d95 da1 da3
da5 da6 dab daf db1 dbd dc1 dc3
dc4 dcd 
3ca
2
0 1 a 6 10 :3 6 10 :3 6
11 :3 6 17 :3 6 14 :3 6 15 :3 6
10 :3 6 e :3 6 c :3 6 b :3 6
10 :3 6 11 :3 6 11 :3 6 16 :3 6
11 :3 6 17 :3 6 12 :2 6 1 3
a 13 a :2 1 4 10 19 18
:2 10 :2 4 10 19 18 :2 10 :2 4 11
1a 19 :2 11 :2 4 :2 14 23 14 :2 4
11 1a 19 :2 11 :2 4 12 1b 1a
:2 12 :2 4 :2 d 1c d :2 4 :2 b 1a
b :2 4 :2 c 1b c :2 4 :2 b 1a
b :2 4 :2 10 1f 10 :2 4 :2 e 1d
e :2 4 :2 e 1d e :2 4 :2 13 22
13 :2 4 :2 11 20 11 :2 4 14 1d
1c :2 14 :2 4 f 18 17 :2 f :2 4
:2 14 23 14 :2 4 e 17 :3 e 4
7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 54 5a 5d
:2 54 6b 81 8 :2 6b d 10 :2 6b
1a 1d :2 6b b e :2 6b 13 16
:2 6b 1b 1e :2 6b 28 2b :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
29 2c :2 6b b e :2 6b 13 16
1f 27 :2 1f 3a :2 16 :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 2c
2f :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 2d 30 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 33 :2 16
:2 6b b e :2 6b 13 16 1f 27
:2 1f 31 :2 16 :2 6b b e :2 6b 13
16 1f 27 :2 1f 2f :2 16 :2 6b b
e :2 6b 13 16 1f 27 :2 1f 2e
:2 16 :2 6b b e :2 6b 13 16 1f
27 :2 1f 33 :2 16 :2 6b b e :2 6b
13 16 1f 27 :2 1f 34 :2 16 :2 6b
b e :2 6b 13 16 1f 27 :2 1f
34 :2 16 :2 6b b e :2 6b 13 16
1f 27 :2 1f 39 :2 16 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 34 :2 16
:2 6b b e :2 6b 13 16 :2 6b 1b
1e :2 6b 2f 32 :2 6b b e :2 6b
13 16 :2 6b 1b 1e :2 6b 2a 2d
:2 6b 32 35 :2 6b :2 7 4a :2 4 7
:2 11 23 :2 2d 39 3c 4c 4e 4f
:2 4c :2 23 :3 7 :2 d 12 1e 5c 5f
:2 1e :2 7 52 :2 4 :4 9 8 7 :4 22
21 20 :2 7 :4 3f 3e 3d :2 7 :4 f
e d :2 7 a :2 14 26 :2 30 3c
3f 4f 51 52 :2 4f :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b1 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4f 51 52
:2 4f :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 41
:2 7 2a :3 4 13 :2 4 13 :2 4 14
:2 4 14 :2 4 15 :2 4 17 :2 4 12
:2 4 17 :2 4 10 :2 4 e :2 4 f
:2 4 e :2 4 13 :2 4 11 :2 4 11
:2 4 16 :2 4 14 :2 4 :2 d 19 26
33 40 4e 25 33 42 4c 54
5d 25 32 3d 48 58 25 36
:2 19 4 7 :2 11 23 :2 2d 39 3c
4c 4f 50 :2 4c :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e 6d 70 :2 1e 74
77 :2 1e 81 84 8d 95 :2 9e :2 8d
a9 :2 84 :2 1e b1 b4 :2 1e bc bf
:2 1e c4 c7 :2 1e d3 d6 :2 1e :2 7
53 :3 4 :2 f 21 :2 2a 34 41 :2 4
1 9 12 9 a :2 14 26 :2 30
3c 40 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 60 63 :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 57 :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 4d 50 51 :2 4d :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
54 :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
3ca
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 2
:4 14 :2 1 :7 16 :7 17
:7 18 :6 19 :7 1a :7 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :7 25 :7 26 :6 27
:7 29 :b 2b :11 2c 2d
:2 2c :2 2d :2 2c :2 2d
:2 2c :2 2e :2 2c :2 2e
:2 2c :2 2e :2 2c :2 2e
:2 2c :2 2f :2 2c :2 2f
:2 2c :2 2f :2 2c :2 2f
:2 2c :2 30 :2 2c :9 30
:2 2c :2 31 :2 2c :2 31
:2 2c :2 31 :2 2c :2 31
:2 2c :2 32 :2 2c :2 32
:2 2c :2 32 :2 2c :2 32
:2 2c :2 33 :2 2c :9 33
:2 2c :2 34 :2 2c :9 34
:2 2c :2 35 :2 2c :9 35
:2 2c :2 36 :2 2c :9 36
:2 2c :2 37 :2 2c :9 37
:2 2c :2 38 :2 2c :9 38
:2 2c :2 39 :2 2c :9 39
:2 2c :2 3a :2 2c :9 3a
:2 2c :2 3b :2 2c :9 3b
:2 2c :2 3c :2 2c :2 3c
:2 2c :2 3c :2 2c :2 3c
:2 2c :2 3d :2 2c :2 3d
:2 2c :2 3d :2 2c :2 3d
:2 2c :2 3d :4 2c :3 2b
:11 40 :b 41 :3 40 :16 46
:6 47 :2 46 :11 48 :20 49
:3 48 :11 4b :b 4c :3 4b
:9 4e 47 :2 46 :3 51
:3 52 :3 53 :3 54 :3 55
:3 56 :3 57 :3 59 :3 5a
:3 5b :3 5c :3 5d :3 5e
:3 5f :3 60 :3 61 :3 62
:8 64 :6 65 :5 66 :2 67
:3 64 :11 69 :30 6a :3 69
:a 6c 2a :3 70 :11 71
:b 72 :17 73 :3 71 :2 75
:3 76 :3 77 78 76
75 76 :3 79 :3 70
:2 7a :5 7c :11 7d :b 7e
:18 7f :3 7d :2 81 82
:3 83 84 82 81
82 :3 85 :2 7b :6 7a
6f :7 1 
dcf
4
:3 0 1 :3 0 2
:a 0 3c5 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
4 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 4
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 8
:3 0 12 :7 0 39
38 :3 0 8 :3 0
13 :7 0 3d 3c
:3 0 25 :2 0 23
4 :3 0 14 :7 0
41 40 :3 0 4
:3 0 15 :7 0 45
44 :3 0 16 :3 0
17 :3 0 18 :2 0
4 49 4a 0
47 4b 0 3c5
2 4c :2 0 1c
:2 0 39 4 :3 0
1a :2 0 37 4f
51 :6 0 54 52
0 3c3 0 19
:6 0 1c :2 0 3d
4 :3 0 3b 56
58 :6 0 5b 59
0 3c3 0 1b
:6 0 1f :2 0 41
4 :3 0 3f 5d
5f :6 0 62 60
0 3c3 0 1d
:6 0 21 :2 0 43
8 :3 0 64 :7 0
68 65 66 3c3
0 1e :6 0 21
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 3c3
0 20 :6 0 1f
:2 0 4b 4 :3 0
49 71 73 :6 0
76 74 0 3c3
0 22 :6 0 1f
:2 0 4d 8 :3 0
78 :7 0 7c 79
7a 3c3 0 23
:6 0 1f :2 0 4f
8 :3 0 7e :7 0
82 7f 80 3c3
0 24 :6 0 1f
:2 0 51 8 :3 0
84 :7 0 88 85
86 3c3 0 25
:6 0 1f :2 0 53
8 :3 0 8a :7 0
8e 8b 8c 3c3
0 26 :6 0 1f
:2 0 55 8 :3 0
90 :7 0 94 91
92 3c3 0 27
:6 0 1f :2 0 57
8 :3 0 96 :7 0
9a 97 98 3c3
0 28 :6 0 1f
:2 0 59 8 :3 0
9c :7 0 a0 9d
9e 3c3 0 29
:6 0 1f :2 0 5b
8 :3 0 a2 :7 0
a6 a3 a4 3c3
0 2a :6 0 2d
:2 0 5d 8 :3 0
a8 :7 0 ac a9
aa 3c3 0 2b
:6 0 1a :2 0 61
4 :3 0 5f ae
b0 :6 0 b3 b1
0 3c3 0 2c
:6 0 1f :2 0 65
4 :3 0 63 b5
b7 :6 0 ba b8
0 3c3 0 2e
:6 0 c2 c3 0
67 8 :3 0 bc
:7 0 c0 bd be
3c3 0 2f :6 0
c8 c9 0 69
17 :3 0 18 :2 0
4 c4 :7 0 c7
c5 0 3c3 0
30 :6 0 31 :3 0
32 :3 0 31 :3 0
33 :3 0 cb cc
0 2 :4 0 6b
cd cf ca d1
d0 :2 0 34 :3 0
35 :3 0 d3 d4
0 36 :4 0 31
:3 0 37 :3 0 d7
d8 0 2 :4 0
6d d9 db 38
:4 0 39 :2 0 3a
:3 0 6f de e0
:3 0 3b :4 0 39
:2 0 3c :4 0 72
e3 e5 :3 0 39
:2 0 3 :3 0 75
e7 e9 :3 0 39
:2 0 3c :4 0 78
eb ed :3 0 39
:2 0 3d :4 0 7b
ef f1 :3 0 39
:2 0 3c :4 0 7e
f3 f5 :3 0 39
:2 0 5 :3 0 81
f7 f9 :3 0 39
:2 0 3c :4 0 84
fb fd :3 0 39
:2 0 3d :4 0 87
ff 101 :3 0 39
:2 0 3c :4 0 8a
103 105 :3 0 39
:2 0 6 :3 0 8d
107 109 :3 0 39
:2 0 3c :4 0 90
10b 10d :3 0 39
:2 0 3d :4 0 93
10f 111 :3 0 39
:2 0 3e :3 0 3f
:3 0 7 :3 0 96
115 117 40 :4 0
98 114 11a 9b
113 11c :3 0 39
:2 0 3d :4 0 9e
11e 120 :3 0 39
:2 0 3c :4 0 a1
122 124 :3 0 39
:2 0 9 :3 0 a4
126 128 :3 0 39
:2 0 3c :4 0 a7
12a 12c :3 0 39
:2 0 3d :4 0 aa
12e 130 :3 0 39
:2 0 3c :4 0 ad
132 134 :3 0 39
:2 0 a :3 0 b0
136 138 :3 0 39
:2 0 3c :4 0 b3
13a 13c :3 0 39
:2 0 3d :4 0 b6
13e 140 :3 0 39
:2 0 3e :3 0 3f
:3 0 b :3 0 b9
144 146 40 :4 0
bb 143 149 be
142 14b :3 0 39
:2 0 3d :4 0 c1
14d 14f :3 0 39
:2 0 3e :3 0 3f
:3 0 c :3 0 c4
153 155 40 :4 0
c6 152 158 c9
151 15a :3 0 39
:2 0 3d :4 0 cc
15c 15e :3 0 39
:2 0 3e :3 0 3f
:3 0 d :3 0 cf
162 164 40 :4 0
d1 161 167 d4
160 169 :3 0 39
:2 0 3d :4 0 d7
16b 16d :3 0 39
:2 0 3e :3 0 3f
:3 0 e :3 0 da
171 173 40 :4 0
dc 170 176 df
16f 178 :3 0 39
:2 0 3d :4 0 e2
17a 17c :3 0 39
:2 0 3e :3 0 3f
:3 0 f :3 0 e5
180 182 40 :4 0
e7 17f 185 ea
17e 187 :3 0 39
:2 0 3d :4 0 ed
189 18b :3 0 39
:2 0 3e :3 0 3f
:3 0 10 :3 0 f0
18f 191 40 :4 0
f2 18e 194 f5
18d 196 :3 0 39
:2 0 3d :4 0 f8
198 19a :3 0 39
:2 0 3e :3 0 3f
:3 0 11 :3 0 fb
19e 1a0 40 :4 0
fd 19d 1a3 100
19c 1a5 :3 0 39
:2 0 3d :4 0 103
1a7 1a9 :3 0 39
:2 0 3e :3 0 3f
:3 0 12 :3 0 106
1ad 1af 40 :4 0
108 1ac 1b2 10b
1ab 1b4 :3 0 39
:2 0 3d :4 0 10e
1b6 1b8 :3 0 39
:2 0 3e :3 0 3f
:3 0 13 :3 0 111
1bc 1be 40 :4 0
113 1bb 1c1 116
1ba 1c3 :3 0 39
:2 0 3d :4 0 119
1c5 1c7 :3 0 39
:2 0 3c :4 0 11c
1c9 1cb :3 0 39
:2 0 14 :3 0 11f
1cd 1cf :3 0 39
:2 0 3c :4 0 122
1d1 1d3 :3 0 39
:2 0 3d :4 0 125
1d5 1d7 :3 0 39
:2 0 3c :4 0 128
1d9 1db :3 0 39
:2 0 15 :3 0 12b
1dd 1df :3 0 39
:2 0 3c :4 0 12e
1e1 1e3 :3 0 39
:2 0 41 :4 0 131
1e5 1e7 :3 0 134
d5 1e9 :2 0 1eb
139 1ec d2 1eb
0 1ed 13b 0
323 31 :3 0 32
:3 0 1ee 1ef 0
31 :3 0 42 :3 0
1f1 1f2 0 43
:2 0 2 :4 0 44
:2 0 45 :2 0 43
:2 0 13d 1f7 1f9
:3 0 140 1f3 1fb
1f0 1fd 1fc :2 0
34 :3 0 46 :3 0
1ff 200 0 36
:4 0 47 :4 0 39
:2 0 3a :3 0 144
204 206 :3 0 147
201 208 :2 0 20a
14a 20b 1fe 20a
0 20c 14c 0
323 3 :3 0 48
:2 0 14e 20e 20f
:3 0 210 :2 0 211
:2 0 9 :3 0 48
:2 0 150 214 215
:3 0 216 :2 0 217
:2 0 212 219 218
:2 0 a :3 0 48
:2 0 152 21c 21d
:3 0 21e :2 0 21f
:2 0 21a 221 220
:2 0 14 :3 0 48
:2 0 154 224 225
:3 0 226 :2 0 227
:2 0 222 229 228
:2 0 31 :3 0 32
:3 0 22b 22c 0
31 :3 0 42 :3 0
22e 22f 0 49
:2 0 2 :4 0 4a
:2 0 45 :2 0 43
:2 0 156 234 236
:3 0 159 230 238
22d 23a 239 :2 0
34 :3 0 46 :3 0
23c 23d 0 36
:4 0 4b :4 0 39
:2 0 3a :3 0 15d
241 243 :3 0 39
:2 0 4c :4 0 160
245 247 :3 0 39
:2 0 4d :4 0 163
249 24b :3 0 39
:2 0 3e :3 0 3f
:3 0 4e :3 0 4f
:3 0 250 251 0
166 24f 253 40
:4 0 168 24e 256
16b 24d 258 :3 0
16e 23e 25a :2 0
25c 171 25d 23b
25c 0 25e 173
0 287 31 :3 0
32 :3 0 25f 260
0 31 :3 0 42
:3 0 262 263 0
43 :2 0 2 :4 0
50 :2 0 45 :2 0
43 :2 0 175 268
26a :3 0 178 264
26c 261 26e 26d
:2 0 34 :3 0 46
:3 0 270 271 0
36 :4 0 51 :4 0
39 :2 0 3a :3 0
17c 275 277 :3 0
17f 272 279 :2 0
27b 182 27c 26f
27b 0 27d 184
0 287 52 :3 0
53 :3 0 27e 27f
0 4e :3 0 4f
:3 0 281 282 0
54 :3 0 186 280
285 :2 0 287 189
288 22a 287 0
289 18d 0 323
19 :3 0 3 :3 0
28a 28b 0 323
1b :3 0 5 :3 0
28d 28e 0 323
1d :3 0 6 :3 0
290 291 0 323
20 :3 0 9 :3 0
293 294 0 323
22 :3 0 a :3 0
296 297 0 323
2c :3 0 14 :3 0
299 29a 0 323
2e :3 0 15 :3 0
29c 29d 0 323
1e :3 0 7 :3 0
29f 2a0 0 323
23 :3 0 b :3 0
2a2 2a3 0 323
24 :3 0 c :3 0
2a5 2a6 0 323
25 :3 0 d :3 0
2a8 2a9 0 323
26 :3 0 e :3 0
2ab 2ac 0 323
27 :3 0 f :3 0
2ae 2af 0 323
28 :3 0 10 :3 0
2b1 2b2 0 323
29 :3 0 11 :3 0
2b4 2b5 0 323
2a :3 0 12 :3 0
2b7 2b8 0 323
2b :3 0 13 :3 0
2ba 2bb 0 323
17 :3 0 55 :3 0
2bd 2be 0 56
:3 0 19 :3 0 1b
:3 0 1d :3 0 1e
:3 0 20 :3 0 22
:3 0 23 :3 0 24
:3 0 25 :3 0 26
:3 0 27 :3 0 28
:3 0 29 :3 0 2a
:3 0 2b :3 0 2c
:3 0 2e :3 0 18f
2c0 2d2 2bf 2d3
0 323 31 :3 0
32 :3 0 2d5 2d6
0 31 :3 0 42
:3 0 2d8 2d9 0
57 :2 0 2 :4 0
58 :2 0 45 :2 0
43 :2 0 1a1 2de
2e0 :3 0 1a4 2da
2e2 2d7 2e4 2e3
:2 0 34 :3 0 46
:3 0 2e6 2e7 0
36 :4 0 59 :4 0
39 :2 0 3a :3 0
1a8 2eb 2ed :3 0
39 :2 0 4c :4 0
1ab 2ef 2f1 :3 0
39 :2 0 4d :4 0
1ae 2f3 2f5 :3 0
39 :2 0 3e :3 0
3f :3 0 17 :3 0
55 :3 0 2fa 2fb
0 1b1 2f9 2fd
40 :4 0 1b3 2f8
300 1b6 2f7 302
:3 0 39 :2 0 5a
:4 0 1b9 304 306
:3 0 39 :2 0 3c
:4 0 1bc 308 30a
:3 0 39 :2 0 19
:3 0 1bf 30c 30e
:3 0 39 :2 0 3c
:4 0 1c2 310 312
:3 0 1c5 2e8 314
:2 0 316 1c8 317
2e5 316 0 318
1ca 0 323 52
:3 0 5b :3 0 319
31a 0 17 :3 0
55 :3 0 31c 31d
0 19 :3 0 54
:3 0 1cc 31b 321
:2 0 323 1d0 3c4
17 :3 0 5c :2 0
4 324 325 0
31 :3 0 32 :3 0
327 328 0 31
:3 0 42 :3 0 32a
32b 0 5d :2 0
2 :4 0 5e :2 0
45 :2 0 43 :2 0
1e8 330 332 :3 0
1eb 32c 334 329
336 335 :2 0 34
:3 0 46 :3 0 338
339 0 36 :4 0
5f :4 0 39 :2 0
3a :3 0 1ef 33d
33f :3 0 1f2 33a
341 :2 0 35a 34
:3 0 46 :3 0 343
344 0 36 :4 0
60 :4 0 39 :2 0
17 :3 0 61 :3 0
349 34a 0 1f5
348 34c :3 0 39
:2 0 5a :4 0 1f8
34e 350 :3 0 39
:2 0 17 :3 0 62
:3 0 353 354 0
1fb 352 356 :3 0
1fe 345 358 :2 0
35a 201 35b 337
35a 0 35c 204
0 36c 63 :3 0
30 :3 0 17 :3 0
61 :3 0 64 :3 0
17 :3 0 62 :3 0
65 :3 0 66 :4 0
67 1 :a 0 368
:2 0 36c 35e 366
:2 0 16 :3 0 30
:3 0 36a :2 0 36c
206 36e 20a 36d
36c :2 0 3c2 68
:3 0 17 :3 0 55
:3 0 371 372 0
69 :3 0 373 374
0 3ba 31 :3 0
32 :3 0 376 377
0 31 :3 0 42
:3 0 379 37a 0
5d :2 0 2 :4 0
6a :2 0 45 :2 0
43 :2 0 20c 37f
381 :3 0 20f 37b
383 378 385 384
:2 0 34 :3 0 46
:3 0 387 388 0
36 :4 0 6b :4 0
39 :2 0 3a :3 0
213 38c 38e :3 0
216 389 390 :2 0
3aa 34 :3 0 46
:3 0 392 393 0
36 :4 0 6c :4 0
39 :2 0 69 :3 0
219 397 399 :3 0
39 :2 0 6d :4 0
21c 39b 39d :3 0
39 :2 0 6e :3 0
6f :3 0 43 :2 0
70 :2 0 21f 3a0
3a4 223 39f 3a6
:3 0 226 394 3a8
:2 0 3aa 229 3ab
386 3aa 0 3ac
22c 0 3ba 63
:3 0 30 :3 0 64
:3 0 17 :3 0 62
:3 0 65 :3 0 66
:4 0 71 1 :a 0
3b6 :2 0 3ba 3ae
3b4 :2 0 16 :3 0
30 :3 0 3b8 :2 0
3ba 22e 3bd :3 0
3bd 0 3bd 3bc
3ba 3bb :6 0 3bf
1 :3 0 233 3c1
235 3c0 3bf :2 0
3c2 237 :2 0 3c4
23a 3c4 3c3 323
3c2 :6 0 3c5 :2 0
2 4c 3c4 3c8
:3 0 3c7 3c5 3c9
:8 0 
24e
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 11
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 1 50 1
4e 1 57 1
55 1 5e 1
5c 1 63 1
6b 1 69 1
72 1 70 1
77 1 7d 1
83 1 89 1
8f 1 95 1
9b 1 a1 1
a7 1 af 1
ad 1 b6 1
b4 1 bb 1
c1 1 ce 1
da 2 dd df
2 e2 e4 2
e6 e8 2 ea
ec 2 ee f0
2 f2 f4 2
f6 f8 2 fa
fc 2 fe 100
2 102 104 2
106 108 2 10a
10c 2 10e 110
1 116 2 118
119 2 112 11b
2 11d 11f 2
121 123 2 125
127 2 129 12b
2 12d 12f 2
131 133 2 135
137 2 139 13b
2 13d 13f 1
145 2 147 148
2 141 14a 2
14c 14e 1 154
2 156 157 2
150 159 2 15b
15d 1 163 2
165 166 2 15f
168 2 16a 16c
1 172 2 174
175 2 16e 177
2 179 17b 1
181 2 183 184
2 17d 186 2
188 18a 1 190
2 192 193 2
18c 195 2 197
199 1 19f 2
1a1 1a2 2 19b
1a4 2 1a6 1a8
1 1ae 2 1b0
1b1 2 1aa 1b3
2 1b5 1b7 1
1bd 2 1bf 1c0
2 1b9 1c2 2
1c4 1c6 2 1c8
1ca 2 1cc 1ce
2 1d0 1d2 2
1d4 1d6 2 1d8
1da 2 1dc 1de
2 1e0 1e2 2
1e4 1e6 4 d6
dc e1 1e8 1
1ea 1 1ec 2
1f6 1f8 3 1f4
1f5 1fa 2 203
205 2 202 207
1 209 1 20b
1 20d 1 213
1 21b 1 223
2 233 235 3
231 232 237 2
240 242 2 244
246 2 248 24a
1 252 2 254
255 2 24c 257
2 23f 259 1
25b 1 25d 2
267 269 3 265
266 26b 2 274
276 2 273 278
1 27a 1 27c
2 283 284 3
25e 27d 286 1
288 11 2c1 2c2
2c3 2c4 2c5 2c6
2c7 2c8 2c9 2ca
2cb 2cc 2cd 2ce
2cf 2d0 2d1 2
2dd 2df 3 2db
2dc 2e1 2 2ea
2ec 2 2ee 2f0
2 2f2 2f4 1
2fc 2 2fe 2ff
2 2f6 301 2
303 305 2 307
309 2 30b 30d
2 30f 311 2
2e9 313 1 315
1 317 3 31e
31f 320 17 1ed
20c 289 28c 28f
292 295 298 29b
29e 2a1 2a4 2a7
2aa 2ad 2b0 2b3
2b6 2b9 2bc 2d4
318 322 2 32f
331 3 32d 32e
333 2 33c 33e
2 33b 340 2
347 34b 2 34d
34f 2 351 355
2 346 357 2
342 359 1 35b
3 35c 367 36b
1 326 2 37e
380 3 37c 37d
382 2 38b 38d
2 38a 38f 2
396 398 2 39a
39c 3 3a1 3a2
3a3 2 39e 3a5
2 395 3a7 2
391 3a9 1 3ab
4 375 3ac 3b5
3b9 1 3bd 1
370 2 36e 3c1
13 53 5a 61
67 6e 75 7b
81 87 8d 93
99 9f a5 ab
b2 b9 bf c6

1
4
0 
3c8
0
1
14
2
25
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
43 1 0
2b 1 0
b 1 0
70 1 0
3b 1 0
27 1 0
23 1 0
4e 1 0
f 1 0
bb 1 0
2 0 1
1f 1 0
89 1 0
5c 1 0
77 1 0
a1 1 0
69 1 0
55 1 0
1b 1 0
a7 1 0
95 1 0
3 1 0
33 1 0
13 1 0
83 1 0
7d 1 0
8f 1 0
37 1 0
7 1 0
63 1 0
2f 1 0
b4 1 0
3f 1 0
ad 1 0
9b 1 0
17 1 0
c1 1 0
0

/
SHOW ERRORS FUNCTION SP_U_TSKRES2;
ALTER FUNCTION SP_U_TSKRES2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_ASSIGN_MSP
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_ASSIGN_MSP ==
CREATE OR REPLACE FUNCTION SP_ASSIGN_MSP wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
19d
2 :e:
1FUNCTION:
1SP_ASSIGN_MSP:
1ID:
1VARCHAR2:
1ACTION_TYPE:
1PLS_INTEGER:
1TASK_ID001:
1START_DT001:
1FINISH_DT001:
1EFFORT001:
1ASSIGN_STRING001:
1WORK_TODATE001:
1PERCENT_COMPLETE001:
1EETC:
1DATA_FLAG:
1UNITS:
1CONTOUR_TYPE001:
1BASELINE_START001:
1BASELINE_FINISH001:
1BASELINE_DURATION001:
1BASELINE_WORK001:
1ACTUAL_START001:
1ACTUAL_FINISH001:
1ACTUAL_EFFORT001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_NAME:
1255:
1H_FULL_NAME:
1H_MESSAGE:
116384:
1H_SUBJECT:
12048:
1H_REVISION:
116:
1H_TEMP_ID:
132:
1H_TEMP_ID2:
1H_WKF_DEF_ID:
1H_UNIQUEID:
1H_RA_ID:
1H_RESOURCE_ID:
1H_PROJECT_ID:
1H_TASK_ID:
1H_REC_USER:
1H_TYPE_ID:
10:
1H_WORK_LOCATION:
1H_ZERO:
1H_TWO:
12:
1H_WORK:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_UNITS:
1H_PER_DAY:
1480:
1H_IMPEX_ROLLUP:
1H_EFFORT:
1H_COUNT:
1H_TOTAL:
1H_MINUTES:
1H_DATA_FLAG:
1H_WORK_TODATE:
1H_DAYOFYEAR:
1DATE:
1H_FINISH_D:
1H_TSK_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_NULL_STR:
11:
1H_START_DATE:
1TIMESTAMP:
1H_START_DT:
1H_ACTUAL_START:
1H_FINISH_DT:
1H_REC_DT:
1H_LOCK_DT:
1H_ASSIGN_STRING:
18192:
1H_TABLE_TYPE:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_OCCURRENCE:
1H_BIT_MINUTES:
1H_ACTION_TYPE:
1H_ETC:
1H_SD:
1H_FD:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_PERCENT_UNITS:
1CURSOR:
1C_H_WBS:
1ELEMENT_NAME:
1RTRIM:
1TO_CHAR:
1MAJOR_REVISION:
1MINOR_REVISION:
1TMT_WBS:
1PROJECT_ID:
1ELEMENT_ID:
1REC_DATETIME:
1ROWNUM:
1SELECT * FROM (SELECT ELEMENT_NAME,RTRIM(TO_CHAR(MAJOR_REVISION)) || '.' || R+
1TRIM(TO_CHAR(MINOR_REVISION)):n         FROM TMT_WBS:n         WHERE PROJECT_+
1ID = h_project_id AND ELEMENT_ID = h_task_id:n         ORDER BY REC_DATETIME +
1DESC ) WHERE ROWNUM<=1:
1CAF:
1SCHED_MIN:
1DAY_YEAR:
1ACTUAL_FLAG:
1TASK_DAY_OF_YEAR:
1TSK_ASSIGNMENT_ID:
1ACTUAL_MIN:
1SELECT SCHED_MIN, DAY_YEAR, ACTUAL_FLAG:n         FROM TASK_DAY_OF_YEAR:n    +
1     WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id:n         FOR UPDATE OF ACTUAL_MIN,ACTUAL_FLAG:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ASSIGN_MSP(:
1':
1, :
1COALESCE:
1NULL:
1);:
1CHECK_TRACE:
1123:
1+:
1FPUT:
1               ENTER:: SP_ASSIGN_MSP(124) :: cplan.sql(7453) :: :
1IS NULL:
1<:
1>:
13:
18:
1129:
1      RETURN_INVALID:: SP_ASSIGN_MSP(130) :: cplan.sql(7459) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1132:
1                EXIT:: SP_ASSIGN_MSP(133) :: cplan.sql(7462) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1139:
1      RETURN_INVALID:: SP_ASSIGN_MSP(140) :: cplan.sql(7469) :: :
1142:
1                EXIT:: SP_ASSIGN_MSP(143) :: cplan.sql(7472) :: :
1265:
1LENGTH:
1SC_ASSIGN_STRING_LENGTH:
1=:
1171:
1      RETURN_INVALID:: SP_ASSIGN_MSP(172) :: cplan.sql(7501) :: :
1174:
1                EXIT:: SP_ASSIGN_MSP(175) :: cplan.sql(7504) :: :
1TYPE_ID:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type_id:n            FROM TMT+
1_WBS WHERE ELEMENT_ID = h_task_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
1192:
1           EXCEPTION:: SP_ASSIGN_MSP(193) :: cplan.sql(7522) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
1GETTABLE:
1ASSIGNRESOURCE:
1COUNT:
1DUAL:
1PROFILES:
1PROFILE_ID:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL:n               WHERE EXISTS (SEL+
1ECT 'X' FROM PROFILES:n               WHERE PROJECT_ID = h_project_id AND PRO+
1FILE_ID = h_resource_id):
1216:
1           EXCEPTION:: SP_ASSIGN_MSP(217) :: cplan.sql(7546) :: :
1!=:
15:
11*5:
1IS NOT NULL:
1TO_TIMESTAMP:
1PMO_ORASTD:
1DB2TIMESTAMP:
1SELECT TO_TIMESTAMP(PMO_ORASTD.DB2TIMESTAMP(h_start_DT)) + (5 / 1440.0) INTO +
1h_finish_DT FROM DUAL:
1235:
1           EXCEPTION:: SP_ASSIGN_MSP(236) :: cplan.sql(7565) :: :
1ISWBSDELIV:
1TASK_ID:
1RESOURCE_ID:
1WORK_TODATE:
1PROJECT_ASSIGNMENT_ID:
1UNITS_MSP:
1C_EFFORT:
1C_CONTOUR:
1CONTOUR_TYPE:
1TASK_ASSIGNMENTS:
1SELECT PROJECT_ID, TASK_ID, RESOURCE_ID, WORK_TODATE, PROJECT_ASSIGNMENT_ID,+
1:n            UNITS_MSP, C_EFFORT, C_CONTOUR, CONTOUR_TYPE, REC_DATETIME:n   +
1         INTO h_project_id, h_task_id, h_resource_id, h_work_todate, h_prj_as+
1signment_id,:n            h_percent_units, h_work, h_contour, h_contour_type,+
1 h_rec_DT:n            FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_ra_i+
1d:
1262:
1           EXCEPTION:: SP_ASSIGN_MSP(263) :: cplan.sql(7592) :: :
1SC_SQL_SUCCESS:
1-:
1279:
1        RETURN_ERROR:: SP_ASSIGN_MSP(280) :: cplan.sql(7609) :: :
1 ID:: :
1282:
1                EXIT:: SP_ASSIGN_MSP(283) :: cplan.sql(7612) :: :
1PMO_RETURN_ERROR_SP:
1291:
1      RETURN_INVALID:: SP_ASSIGN_MSP(292) :: cplan.sql(7621) :: :
1294:
1                EXIT:: SP_ASSIGN_MSP(295) :: cplan.sql(7624) :: :
1SC_BIT_28:
1103079040:
1MINUTE_PER_DAY:
1SELECT COALESCE(MINUTE_PER_DAY, 480) INTO h_per_day FROM TMT_WBS WHERE ELEMEN+
1T_ID = h_task_id:
1317:
1           EXCEPTION:: SP_ASSIGN_MSP(318) :: cplan.sql(7647) :: :
1TRUNC:
1/:
1*:
110000:
10.4:
1BITAND:
1FC_U_TSKRES2:
1ETC:
1PROPOSED_START:
1SCHED_START:
1PROPOSED_FINISH:
1SCHED_FINISH:
1PROPOSED_WORK:
1SCHED_WORK:
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                        PROPOSED_STA+
1RT = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n +
1                       WHERE PROJECT_ID = h_project_id AND TASK_ID = h_task_i+
1d AND RESOURCE_ID = h_resource_id:
1FOUND:
1100:
1385:
1           EXCEPTION:: SP_ASSIGN_MSP(386) :: cplan.sql(7715) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                        PROPOSED_STA+
1RT = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n +
1                       WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1421:
1           EXCEPTION:: SP_ASSIGN_MSP(422) :: cplan.sql(7751) :: :
1MILESTONE_PERCENT:
1ACTUAL_START:
1ACTUAL_FINISH:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1              UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n          +
1           PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOS+
1ED_WORK = SCHED_WORK,:n                     ACTUAL_START = h_start_DT, ACTUAL+
1_FINISH = h_finish_DT,:n                     WORK_TODATE = work_todate001,:n +
1                    ETC = eetc:n                     WHERE TSK_ASSIGNMENT_ID +
1= h_ra_id:
1456:
1           EXCEPTION:: SP_ASSIGN_MSP(457) :: cplan.sql(7786) :: :
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = SCHED_MIN, ACTUAL_FLAG = 1:n        +
1             WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_ra_id:
1474:
1           EXCEPTION:: SP_ASSIGN_MSP(475) :: cplan.sql(7804) :: :
1LAST_SUBMITTED:
1UPDATE TASK_ASSIGNMENTS SET LAST_SUBMITTED = h_finish_DT:n                   +
1  WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1492:
1           EXCEPTION:: SP_ASSIGN_MSP(493) :: cplan.sql(7822) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                     PROPOSED_START +
1= SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n    +
1                 WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1511:
1           EXCEPTION:: SP_ASSIGN_MSP(512) :: cplan.sql(7841) :: :
1SC_NOT_32:
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                     PROPOSED_START +
1= SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n    +
1                 WHERE PROJECT_ID = h_project_id AND TASK_ID = h_task_id AND +
1RESOURCE_ID = h_resource_id:
1542:
1           EXCEPTION:: SP_ASSIGN_MSP(543) :: cplan.sql(7872) :: :
1SELECT SUBSTR(h_lock_DT,1,10) || '-' || SUBSTR(h_lock_DT,12,2) || '.' || SUBS+
1TR(h_lock_DT,15,2) || '.' || SUBSTR(h_lock_DT,18,9) INTO h_lock_DT FROM DUAL:
1562:
1           EXCEPTION:: SP_ASSIGN_MSP(563) :: cplan.sql(7892) :: :
1STRNCMP:
119:
1SC_TASK:
1TMT_WORKFLOW_CYCLES:
1PARENT_ID:
1SELECT ELEMENT_ID INTO h_wkf_def_id:n                        FROM TMT_WORKFLO+
1W_CYCLES:n                        WHERE PARENT_ID = 'NOTIFICATION':
1581:
1           EXCEPTION:: SP_ASSIGN_MSP(582) :: cplan.sql(7911) :: :
1FC_A_NOTIFICATION:
1OPEN:
1CLOSE:
1613:
1           EXCEPTION:: SP_ASSIGN_MSP(614) :: cplan.sql(7943) :: :
1FULL_NAME:
1RESOURCES:
1SELECT FULL_NAME INTO h_full_name FROM RESOURCES:n                           +
1WHERE RESOURCE_ID = h_resource_id:
1627:
1           EXCEPTION:: SP_ASSIGN_MSP(628) :: cplan.sql(7957) :: :
1Import of assignment failed.:
1Import cannot modify assignment for resource:: :
1 on the task:::
1. Assignment was modified in Timesheets during the time of export of the proj+
1ect.:
1FC_U_WORKFLOW:
1648:
1        RETURN_ERROR:: SP_ASSIGN_MSP(649) :: cplan.sql(7978) :: :
1651:
1                EXIT:: SP_ASSIGN_MSP(652) :: cplan.sql(7981) :: :
1681:
1           EXCEPTION:: SP_ASSIGN_MSP(682) :: cplan.sql(8011) :: :
1692:
1        RETURN_ERROR:: SP_ASSIGN_MSP(693) :: cplan.sql(8022) :: :
1695:
1                EXIT:: SP_ASSIGN_MSP(696) :: cplan.sql(8025) :: :
1RES_ASSIGNMENT_ID:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,+
1PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actual_st+
1art001,:n                        ACTUAL_FINISH = actual_finish001,:n         +
1               WORK_TODATE = actual_effort001:n                        WHERE +
1RES_ASSIGNMENT_ID = h_ra_id:
1728:
1           EXCEPTION:: SP_ASSIGN_MSP(729) :: cplan.sql(8058) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units,:n                        CONTOUR_TYPE =+
1 h_contour_type:n                        WHERE RES_ASSIGNMENT_ID = h_ra_id:
1748:
1           EXCEPTION:: SP_ASSIGN_MSP(749) :: cplan.sql(8078) :: :
1BASELINE3_START:
1BASELINE3_SCH_FLAG:
1BASELINE3_FINISH:
1BASELINE3_DURATION:
1BASELINE3_WORK:
1BASELINE2_START:
1BASELINE1_START:
1BASELINE2_FINISH:
1BASELINE1_FINISH:
1BASELINE2_DURATION:
1BASELINE1_DURATION:
1BASELINE2_WORK:
1BASELINE1_WORK:
1B_REGULAR_COST:
1REGULAR_COST:
1B_REGULAR_RATE:
1REGULAR_RATE:
1B_SPECIAL_COST:
1SPECIAL_COST:
1B_SPECIAL_RATE:
1SPECIAL_RATE:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = R+
1EGULAR_RATE, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n +
1                       :n                        BASELINE3_SCH_FLAG = 1,:n   +
1                     PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FIN+
1ISH,PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actua+
1l_start001,:n                        ACTUAL_FINISH = actual_finish001,:n     +
1                   WORK_TODATE = actual_effort001:n                        WH+
1ERE RES_ASSIGNMENT_ID = h_ra_id:
1791:
1           EXCEPTION:: SP_ASSIGN_MSP(792) :: cplan.sql(8121) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = R+
1EGULAR_RATE, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n +
1                       :n                        BASELINE3_SCH_FLAG = 1:n    +
1                    WHERE RES_ASSIGNMENT_ID = h_ra_id:
1828:
1           EXCEPTION:: SP_ASSIGN_MSP(829) :: cplan.sql(8158) :: :
1ELSIF:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1           UNITS_MSP = h_units,:n                  CONTOUR_TYPE = h_contour_t+
1ype:n                  WHERE RES_ASSIGNMENT_ID = h_ra_id:
1850:
1           EXCEPTION:: SP_ASSIGN_MSP(851) :: cplan.sql(8180) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,+
1PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actual_st+
1art001,:n                        ACTUAL_FINISH = actual_finish001,:n         +
1               WORK_TODATE = actual_effort001:n                        WHERE +
1TSK_ASSIGNMENT_ID = h_ra_id:
1878:
1           EXCEPTION:: SP_ASSIGN_MSP(879) :: cplan.sql(8208) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001:n                        WHERE +
1TSK_ASSIGNMENT_ID = h_ra_id:
1898:
1           EXCEPTION:: SP_ASSIGN_MSP(899) :: cplan.sql(8228) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = R+
1EGULAR_RATE, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n +
1                       :n                        BASELINE3_SCH_FLAG = 1,:n   +
1                     PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FIN+
1ISH,PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actua+
1l_start001,:n                        ACTUAL_FINISH = actual_finish001,:n     +
1                   WORK_TODATE = actual_effort001:n                        WH+
1ERE TSK_ASSIGNMENT_ID = h_ra_id:
1941:
1           EXCEPTION:: SP_ASSIGN_MSP(942) :: cplan.sql(8271) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001,:n                        BASEL+
1INE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(baseline_star+
1t001) ELSE BASELINE3_START END,:n                        BASELINE3_FINISH = C+
1ASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(baseline_finish001) ELSE BA+
1SELINE3_FINISH END,:n                        BASELINE3_DURATION = CASE WHEN B+
1ASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BASELINE3_DURATION END,+
1:n                        BASELINE3_WORK = CASE WHEN BASELINE3_SCH_FLAG = 0 T+
1HEN baseline_work001 ELSE BASELINE3_WORK END,:n                        :n    +
1                    BASELINE2_START = BASELINE1_START,:n                     +
1   BASELINE2_FINISH = BASELINE1_FINISH,:n                        BASELINE2_DU+
1RATION = BASELINE1_DURATION,:n                        BASELINE2_WORK = BASELI+
1NE1_WORK,:n                        :n                        BASELINE1_START +
1= baseline_start001,:n                        BASELINE1_FINISH = baseline_fin+
1ish001,:n                        BASELINE1_DURATION = baseline_duration001,:n+
1                        BASELINE1_WORK = baseline_work001,:n                 +
1       B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = REGULAR_RATE, B_SPECIA+
1L_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n                      +
1  :n                        BASELINE3_SCH_FLAG = 1:n                        W+
1HERE TSK_ASSIGNMENT_ID = h_ra_id:
1978:
1           EXCEPTION:: SP_ASSIGN_MSP(979) :: cplan.sql(8308) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001,:n                        ETC =+
1 h_effort - work_todate001:n                        WHERE TSK_ASSIGNMENT_ID =+
1 h_ra_id:
11003:
1           EXCEPTION:: SP_ASSIGN_MSP(1004) :: cplan.sql(8333) :: :
11023:
1           EXCEPTION:: SP_ASSIGN_MSP(1024) :: cplan.sql(8353) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1              UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n          +
1           WORK_TODATE = work_todate001:n                     WHERE TSK_ASSIG+
1NMENT_ID = h_ra_id:
11044:
1           EXCEPTION:: SP_ASSIGN_MSP(1045) :: cplan.sql(8374) :: :
1:
1TO_DATE:
1BILLABLE:
1CAPITAL_EXPENSE:
1SELECT TSK_ASSIGNMENT_ID, SCHED_WORK, TASK_ID, TO_DATE(SubStr(SCHED_START, 1,+
1 10)), TO_DATE(SubStr(SCHED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGUL+
1AR_COST, REGULAR_RATE:n                  INTO h_tsk_assignment_id, h_effort, +
1h_task_id, h_SD, h_FD, h_billable, h_capital_expense, h_reg_cost, h_reg_sale+
1:n                  FROM TASK_ASSIGNMENTS:n                  WHERE RES_ASSIGN+
1MENT_ID = h_ra_id:
11073:
1           EXCEPTION:: SP_ASSIGN_MSP(1074) :: cplan.sql(8403) :: :
1SELECT SCHED_WORK, TASK_ID, TO_DATE(SubStr(SCHED_START, 1, 10)), TO_DATE(SubS+
1tr(SCHED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULAR_COST, REGULAR_RA+
1TE:n                  INTO h_effort, h_task_id, h_SD, h_FD, h_billable, h_cap+
1ital_expense, h_reg_cost, h_reg_sale:n                  FROM TASK_ASSIGNMENTS+
1:n                  WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11090:
1           EXCEPTION:: SP_ASSIGN_MSP(1091) :: cplan.sql(8420) :: :
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = SCHED_MIN, ACTUAL_FLAG = 1:n        +
1             WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_as+
1signment_id:
11113:
1           EXCEPTION:: SP_ASSIGN_MSP(1114) :: cplan.sql(8443) :: :
1MAX:
1UPDATE TASK_ASSIGNMENTS SET WORK_TODATE = SCHED_WORK,:n                     L+
1AST_SUBMITTED = (SELECT MAX(DAY_YEAR) FROM TASK_DAY_OF_YEAR:n                +
1     WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id):n                     WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11133:
1           EXCEPTION:: SP_ASSIGN_MSP(1134) :: cplan.sql(8463) :: :
1LOOP:
1EXIT:
1>=:
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = h_minutes, ACTUAL_FLAG = 1 WHERE CUR+
1RENT OF CAF:
11190:
1           EXCEPTION:: SP_ASSIGN_MSP(1191) :: cplan.sql(8520) :: :
11211:
1           EXCEPTION:: SP_ASSIGN_MSP(1212) :: cplan.sql(8541) :: :
1UPDATE TASK_ASSIGNMENTS SET LAST_SUBMITTED = h_finish_D WHERE TSK_ASSIGNMENT_+
1ID = h_tsk_assignment_id:
11230:
1           EXCEPTION:: SP_ASSIGN_MSP(1231) :: cplan.sql(8560) :: :
1FC_GENERATE_TS_ALL:
1FC_GENERATE_TS_MSP:
14:
11326:
1       RETURN_STATUS:: SP_ASSIGN_MSP(1327) :: cplan.sql(8656) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
11334:
1           EXCEPTION:: SP_ASSIGN_MSP(1335) :: cplan.sql(8664) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11346:
1           EXCEPTION:: SP_ASSIGN_MSP(1347) :: cplan.sql(8676) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
1cc5
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a0 f4 b4 bf c8 :e a0
12a bd b7 11 a4 b1 a0 f4
b4 bf c8 :a a0 12a bd b7 11
a4 b1 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e :2 5a :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a 52 10
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c a0 4d d a0 4d d a0
51 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d a0 51
d :3 a0 a5 b 51 a5 b a0
7e a0 6b b4 2e :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 a0 7e b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :7 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 b4 2e d :4 a0 51 a5
b a5 b d :2 a0 6b :7 a0 a5
b d :2 a0 6b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 a0
51 d :8 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
a0 51 d a0 6e d a0 7e
b4 2e 5a :6 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c b7 19 3c b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e 5a
:3 a0 51 a5 b a5 b 5a 7e
51 b4 2e a 10 a0 51 d
b7 19 3c b7 :2 a0 d :17 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e 5a a
10 a0 4d d a0 7e 51 b4
2e d b7 19 3c b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 6b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
a0 7e b4 2e 5a a0 7e b4
2e 5a 52 10 a0 7e b4 2e
5a 52 10 a0 7e b4 2e 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c :3 a0 6b d :2 a0
51 a5 b 7e 51 b4 2e a0
51 d b7 19 3c :6 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:4 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e 5a 7e 51 b4 2e
5a 7e 51 b4 2e a5 b d
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e a0 51 d a0
51 d b7 a0 51 d b7 :2 19
3c b7 19 3c a0 4d d :3 a0
51 a5 b 51 a5 b 5a 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :12 a0 a5 b
d :2 a0 6b 7e 51 b4 2e :f a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 :2 a0 6b :12 a0 a5
b d b7 :2 19 3c b7 :3 a0 51
a5 b 7e 51 b4 2e d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :12 a0 a5 b d :2 a0 6b 7e
51 b4 2e :b a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
:2 a0 6b :12 a0 a5 b d b7 :2 19
3c b7 :2 19 3c :2 a0 6b 7e 51
b4 2e 5a :3 a0 51 a5 b 51
a5 b 5a 7e 51 b4 2e 5a
a 10 :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :17 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :8 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :5 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 19 3c
b7 :4 a0 51 a5 b :2 a0 6b a5
b d :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :12 a0 a5 b d
:2 a0 6b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :f a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c b7 a0 7e b4 2e 5a :2 a0
d :a a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
d a0 51 d :4 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :8 a0
a5 b d :2 a0 51 a5 b 7e
51 b4 2e a0 4d d a0 4d
d a0 4d d a0 4d d a0
4d d :2 a0 e9 dd b3 :3 a0 e9
d3 5 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 e9 c1 :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :5 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
6e d a0 6e d :3 a0 7e a0
b4 2e :2 51 a5 b d :3 a0 7e
6e b4 2e :2 51 a5 b d :3 a0
7e a0 b4 2e :2 51 a5 b d
:3 a0 7e 6e b4 2e :2 51 a5 b
d :11 a0 a5 b d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :2 a0 51 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b 51
:2 a0 a5 57 b7 19 3c b7 19
3c b7 19 3c :3 a0 51 a5 b
7e 51 b4 2e d :2 a0 6b :12 a0
a5 b d :2 a0 6b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:b a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 :2 19 3c b7
:2 19 3c :2 a0 6b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :2 a0 d :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
a0 51 d b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e :3 a0 51
a5 b 51 a5 b 5a 7e 51
b4 2e a0 7e b4 2e 5a a0
7e b4 2e 5a :15 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 a0 7e b4 2e 5a
:40 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :34 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :2 19
3c a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :9 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:3 a0 51 a5 b 51 a5 b 5a
7e 51 b4 2e a0 7e b4 2e
5a a0 7e b4 2e 5a :15 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:b a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 a0 7e b4
2e 5a :40 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :36 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :2 19 3c a0 b7 :2 a0 51 a5
b 7e 51 b4 2e a0 7e b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e :e a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 :2 19 3c
b7 :2 19 3c a0 7e b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 a0
6e d a0 4d d a0 51 d
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e :19 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 a0
d :17 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :8 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :d a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 a0 e9
dd b3 :5 a0 e9 d3 5 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b 7e 51
b4 2e a0 2b b7 19 3c :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :3 a0 51 a5 b d
b7 :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e 7e :2 a0 51 a5
b b4 2e d b7 :2 19 3c b7
19 3c :5 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 d b7 19 3c
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e a0 2b b7 19
3c b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
5a a0 7e b4 2e :2 5a a 10
:5 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 :2 19 3c :2 a0
51 a5 b 7e 51 b4 2e :3 a0
51 a5 b 51 a5 b 5a 7e
51 b4 2e :4 a0 a5 b d b7
:4 a0 a5 b d b7 :2 19 3c b7
19 3c b7 19 3c b7 19 3c
b7 19 3c :2 a0 6b 7e 51 b4
2e :2 a0 6b 51 d b7 19 3c
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
1cc5
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 168
164 13a 170 179 175 163 181 18e
18a 160 196 19f 19b 189 1a7 186
1ac 1b0 1b4 1b8 1bb 1bf 1dc 1c7
1cb 1ce 1cf 1d7 1c6 1f9 1e7 1c3
1eb 1ec 1f4 1e6 216 204 1e3 208
209 211 203 233 221 200 225 226
22e 220 250 23e 21d 242 243 24b
23d 26d 25b 23a 25f 260 268 25a
28a 278 257 27c 27d 285 277 2a7
295 274 299 29a 2a2 294 2c4 2b2
291 2b6 2b7 2bf 2b1 2e1 2cf 2ae
2d3 2d4 2dc 2ce 2fe 2ec 2cb 2f0
2f1 2f9 2eb 31b 309 2e8 30d 30e
316 308 338 326 305 32a 32b 333
325 355 343 322 347 348 350 342
371 360 364 33f 36c 35f 38d 37c
380 35c 388 37b 3a9 398 39c 378
3a4 397 3c5 3b4 3b8 394 3c0 3b3
3e1 3d0 3d4 3b0 3dc 3cf 3fd 3ec
3f0 3cc 3f8 3eb 419 408 40c 3e8
414 407 435 424 428 404 430 423
451 440 444 420 44c 43f 46d 45c
460 43c 468 45b 489 478 47c 458
484 477 4a5 494 498 474 4a0 493
4c1 4b0 4b4 490 4bc 4af 4dd 4cc
4d0 4ac 4d8 4cb 4f9 4e8 4ec 4c8
4f4 4e7 515 504 508 4e4 510 503
531 520 524 52c 500 549 538 53c
544 51f 566 554 51c 558 559 561
553 583 571 550 575 576 57e 570
5a0 58e 56d 592 593 59b 58d 5bc
5ab 5af 5b7 58a 5d4 5c3 5c7 5cf
5aa 5f0 5df 5e3 5eb 5a7 608 5f7
5fb 603 5de 624 613 617 61f 5db
63c 62b 62f 637 612 659 647 60f
64b 64c 654 646 675 664 668 643
670 663 691 680 684 660 68c 67f
6ad 69c 6a0 67c 6a8 69b 6c9 6b8
6bc 698 6c4 6b7 6e5 6d4 6d8 6b4
6e0 6d3 701 6f0 6f4 6d0 6fc 6ef
71d 70c 710 6ec 718 70b 739 728
72c 734 708 751 740 744 74c 727
76d 75c 760 724 768 75b 789 778
77c 758 784 777 7a5 794 798 774
7a0 793 7c1 7b0 7b4 790 7bc 7af
7dd 7cc 7d0 7ac 7d8 7cb 7f9 7e8
7ec 7c8 7f4 7e7 800 804 7e4 815
818 81c 820 824 828 82c 830 834
838 83c 840 844 848 84c 850 854
860 865 867 873 877 879 87d 88e
88f 892 896 89a 89e 8a2 8a6 8aa
8ae 8b2 8b6 8ba 8be 8ca 8cf 8d1
8dd 8e1 8ff 8e7 8eb 8ef 8f2 8fa
8e6 906 90a 8e3 90e 912 916 919
91e 91f 1 921 926 92a 92e 931
936 93a 93e 941 946 947 949 94e
951 955 956 95b 960 963 968 969
96e 971 975 976 97b 97e 983 984
989 98c 991 992 997 99a 99e 9a2
9a6 9a7 9a9 9ae 9af 9b1 9b2 9b7
9ba 9bf 9c0 9c5 9c8 9cd 9ce 9d3
9d6 9da 9db 9e0 9e3 9e8 9e9 9ee
9f1 9f6 9f7 9fc 9ff a04 a05 a0a
a0d a11 a12 a17 a1a a1f a20 a25
a28 a2d a2e a33 a36 a3b a3c a41
a44 a48 a49 a4e a51 a56 a57 a5c
a5f a64 a65 a6a a6d a71 a75 a79
a7a a7c a81 a82 a84 a85 a8a a8d
a92 a93 a98 a9b aa0 aa1 aa6 aa9
aad aae ab3 ab6 abb abc ac1 ac4
ac9 aca acf ad2 ad6 ada ade adf
ae1 ae6 ae7 ae9 aea aef af2 af7
af8 afd b00 b04 b08 b0c b0d b0f
b14 b15 b17 b18 b1d b20 b25 b26
b2b b2e b32 b36 b3a b3b b3d b42
b43 b45 b46 b4b b4e b53 b54 b59
b5c b60 b64 b68 b69 b6b b70 b71
b73 b74 b79 b7c b81 b82 b87 b8a
b8e b92 b96 b97 b99 b9e b9f ba1
ba2 ba7 baa baf bb0 bb5 bb8 bbc
bc0 bc4 bc5 bc7 bcc bcd bcf bd0
bd5 bd8 bdd bde be3 be6 beb bec
bf1 bf4 bf8 bf9 bfe c01 c06 c07
c0c c0f c14 c15 c1a c1d c22 c23
c28 c2b c2f c30 c35 c38 c3d c3e
c43 c46 c4b c4c c51 c54 c58 c5c
c60 c61 c63 c68 c69 c6b c6c c71
c74 c79 c7a c7f c82 c86 c8a c8e
c8f c91 c96 c97 c99 c9a c9f ca2
ca7 ca8 cad cb0 cb5 cb6 cbb cbe
cc2 cc3 cc8 ccb cd0 cd1 cd6 cd9
cde cdf ce4 ce7 cec ced cf2 cf5
cf9 cfa cff d02 d07 d08 d0d d10
d15 d16 d1b d1e d22 d26 d2a d2b
d2d d32 d33 d35 d36 d3b d3e d43
d44 d49 d4c d51 d52 d57 d5a d5e
d5f d64 d67 d6c d6d d72 d75 d7a
d7b d80 d81 d86 d88 d8c d8f d93
d97 d9a d9e da2 da5 da8 dad db0
db3 db6 db7 dbc dbd 1 dbf dc4
dc8 dcc dcf dd4 dd9 ddc de0 de1
de6 de7 dec dee df2 df5 df9 dfc
dfd e02 e05 e08 e0c e10 e13 e14
e16 e19 e1c e1d e22 e25 e29 e2d
e30 e31 e33 e36 e39 e3a e3f 1
e42 e47 1 e4a e4f e53 e57 e5a
e5e e62 e65 e68 e6d e70 e73 e76
e77 e7c e7d 1 e7f e84 e88 e8c
e8f e94 e99 e9c ea0 ea1 ea6 ea9
eae eaf eb4 eb7 ebc ebd ec2 ec5
ec9 ecd ed1 ed5 ed8 ed9 edb ee0
ee1 ee3 ee4 ee9 eea eef ef1 ef5
ef8 efc f00 f03 f07 f0b f0e f11
f16 f19 f1c f1f f20 f25 f26 1
f28 f2d f31 f35 f38 f3d f42 f45
f49 f4a f4f f50 f55 f57 f5b f5e
f62 f66 f69 f6d f71 f74 f78 f79
f7e f80 f84 f87 f8b f8e f8f f94
f97 f9a f9e fa1 fa2 fa7 faa 1
fad fb2 fb6 fb9 fba fbf fc2 1
fc5 fca fce fd2 fd5 fd9 fdd fe0
fe3 fe8 feb fee ff1 ff2 ff7 ff8
1 ffa fff 1003 1007 100a 100f 1014
1017 101b 101c 1021 1024 1029 102a 102f
1032 1037 1038 103d 1040 1044 1048 104c
1050 1053 1054 1056 105b 105c 105e 105f
1064 1065 106a 106c 1070 1073 1077 107b
107e 1082 1086 1089 108c 1091 1094 1097
109a 109b 10a0 10a1 1 10a3 10a8 10ac
10b0 10b3 10b8 10bd 10c0 10c4 10c5 10ca
10cb 10d0 10d2 10d6 10d9 10dd 10e1 10e4
10e8 10ec 10ef 10f3 10f4 10f9 10fb 10ff
1102 1106 1107 110b 110f 1110 1114 1118
111b 111f 1123 1127 112b 112f 1133 1137
113b 113f 1143 1147 114b 114f 1153 1157
115b 115f 1163 1167 116b 116f 1173 1177
117b 117f 1183 1187 118b 118f 1193 1197
119b 119e 11a2 11a6 11aa 11ae 11af 11b1
11b4 11b5 11b7 11bb 11be 11c2 11c5 11c6
11cb 11cf 11d3 11d6 11d7 11d9 11dc 11df
11e0 11e5 11e8 11ec 11f0 11f3 11f4 11f6
11f9 11fc 11fd 1202 1 1205 120a 120e
1211 1212 1217 121a 121e 1222 1225 1229
122d 1230 1233 1238 123b 123e 1241 1242
1247 1248 1 124a 124f 1253 1257 125a
125f 1264 1267 126b 126c 1271 1274 1279
127a 127f 1282 1287 1288 128d 1290 1294
1298 129c 12a0 12a3 12a4 12a6 12ab 12ac
12ae 12af 12b4 12b5 12ba 12bc 12c0 12c3
12c7 12cb 12ce 12d2 12d6 12d9 12dc 12e1
12e4 12e7 12ea 12eb 12f0 12f1 1 12f3
12f8 12fc 1300 1303 1308 130d 1310 1314
1315 131a 131b 1320 1322 1326 1329 132d
1331 1334 1338 133c 133f 1343 1344 1349
134b 134f 1352 1356 135a 135e 1362 1366
136a 136e 1372 1376 137a 137e 1382 1386
138a 138e 1392 139e 13a2 13a6 13a9 13ad
13b1 13b3 1 13b7 13bb 13bf 13c2 13c6
13ca 13ce 13d2 13d5 13d9 13dd 13e0 13e3
13e8 13eb 13ee 13f1 13f2 13f7 13f8 1
13fa 13ff 1403 1407 140a 140f 1414 1417
141b 141c 1421 1424 1429 142a 142f 1432
1437 1438 143d 1440 1444 1445 144a 144d
1452 1453 1458 145b 145f 1463 1466 1469
146a 146c 146d 1472 1473 1478 147a 147e
1481 1483 1487 1489 1495 1497 1499 149a
149f 14a3 14a5 14b1 14b3 14b7 14bb 14bc
14c1 14c5 14c9 14cd 14d1 14d5 14d8 14d9
14db 14dc 14de 14e2 14e6 14ea 14ed 14f1
14f5 14f9 14fd 1501 1505 1509 150a 150c
1510 1514 1518 151b 151e 1521 1522 1527
152a 152e 1532 1535 1536 1538 153b 153e
153f 1544 1 1547 154c 1550 1554 1557
1558 155a 155d 1560 1561 1566 1 1569
156e 1572 1575 1579 157d 1581 1585 1589
158d 1591 1595 1599 15a5 15a9 15ad 15b0
15b4 15b8 15ba 1 15be 15c2 15c6 15c9
15cd 15d1 15d5 15d9 15dc 15e0 15e4 15e7
15ea 15ef 15f2 15f5 15f8 15f9 15fe 15ff
1 1601 1606 160a 160e 1611 1616 161b
161e 1622 1623 1628 162b 1630 1631 1636
1639 163e 163f 1644 1647 164b 164c 1651
1654 1659 165a 165f 1662 1666 166a 166d
1670 1671 1673 1674 1679 167a 167f 1681
1685 1688 168a 168e 1690 169c 169e 16a0
16a1 16a6 16aa 16ac 16b8 16ba 16be 16c2
16c5 16c6 16c8 16cb 16ce 16cf 16d4 16d8
16db 16df 16e3 16e6 16ea 16ee 16f3 16f7
16fb 16fe 16ff 1704 1707 170b 170f 1713
1717 171b 171f 172b 172f 1733 1736 173a
173e 1740 1 1744 1748 174c 174f 1753
1757 175b 175f 1762 1766 176a 176d 1770
1775 1778 177b 177e 177f 1784 1785 1
1787 178c 1790 1794 1797 179c 17a1 17a4
17a8 17a9 17ae 17b1 17b6 17b7 17bc 17bf
17c4 17c5 17ca 17cd 17d1 17d2 17d7 17da
17df 17e0 17e5 17e8 17ec 17f0 17f3 17f6
17f7 17f9 17fa 17ff 1800 1805 1807 180b
180e 1810 1814 1816 1822 1824 1826 1827
182c 1830 1832 183e 1840 1842 1846 1849
184b 184f 1852 1854 1858 185b 185f 1863
1866 1867 1869 186c 186f 1870 1875 1878
187c 1880 1884 1887 1888 188a 188b 188d
1890 1893 1896 1897 1 189c 18a1 18a5
18a8 18ac 18ae 18b2 18b5 18b7 18bb 18bf
18c3 18c7 18cb 18cf 18d3 18d7 18db 18df
18e3 18e7 18eb 18ef 18f3 18f7 18fb 18ff
1903 1907 190b 190f 1913 1917 191b 191f
192b 192f 1933 1936 193a 193e 1940 1
1944 1948 194c 194f 1953 1957 195b 195f
1962 1966 196a 196d 1970 1975 1978 197b
197e 197f 1984 1985 1 1987 198c 1990
1994 1997 199c 19a1 19a4 19a8 19a9 19ae
19b1 19b6 19b7 19bc 19bf 19c4 19c5 19ca
19cd 19d1 19d2 19d7 19da 19df 19e0 19e5
19e8 19ec 19f0 19f3 19f6 19f7 19f9 19fa
19ff 1a00 1a05 1a07 1a0b 1a0e 1a10 1a14
1a16 1a22 1a24 1a26 1a27 1a2c 1a30 1a32
1a3e 1a40 1a44 1a48 1a4b 1a4f 1a52 1a56
1a59 1a5a 1a5f 1a62 1a66 1a6a 1a6d 1a6e
1a70 1a74 1a77 1a7b 1a7e 1a7f 1a81 1a82
1a87 1 1a8a 1a8f 1a93 1a94 1a98 1a9c
1a9f 1aa2 1aa3 1aa8 1aac 1aae 1ab2 1ab5
1ab7 1abb 1abf 1ac2 1ac6 1aca 1acd 1ace
1ad0 1ad3 1ad6 1ad7 1adc 1ae0 1ae4 1ae7
1aea 1aed 1aee 1af3 1af7 1afb 1afe 1b02
1b06 1b09 1b0c 1b11 1b14 1b17 1b1a 1b1b
1b20 1b21 1 1b23 1b28 1b2c 1b30 1b33
1b38 1b3d 1b40 1b44 1b45 1b4a 1b4d 1b52
1b53 1b58 1b5b 1b60 1b61 1b66 1b69 1b6d
1b71 1b75 1b79 1b7c 1b7d 1b7f 1b84 1b85
1b87 1b88 1b8d 1b90 1b95 1b96 1b9b 1b9e
1ba3 1ba4 1ba9 1bac 1bb0 1bb1 1bb6 1bb9
1bbe 1bbf 1bc4 1bc5 1bca 1bcc 1bd0 1bd3
1bd7 1bdb 1bde 1be2 1be6 1be9 1bec 1bf1
1bf4 1bf7 1bfa 1bfb 1c00 1c01 1 1c03
1c08 1c0c 1c10 1c13 1c18 1c1d 1c20 1c24
1c25 1c2a 1c2b 1c30 1c32 1c36 1c39 1c3d
1c41 1c44 1c48 1c4c 1c4f 1c53 1c57 1c58
1c5d 1c5f 1c63 1c66 1c6a 1c6d 1c6e 1c73
1c76 1c7a 1c7d 1c7e 1c83 1 1c86 1c8b
1c8f 1c92 1c93 1c98 1 1c9b 1ca0 1ca4
1ca7 1ca8 1cad 1 1cb0 1cb5 1cb9 1cbd
1cc0 1cc4 1cc8 1ccb 1cce 1cd3 1cd6 1cd9
1cdc 1cdd 1ce2 1ce3 1 1ce5 1cea 1cee
1cf2 1cf5 1cfa 1cff 1d02 1d06 1d07 1d0c
1d0f 1d14 1d15 1d1a 1d1d 1d22 1d23 1d28
1d2b 1d2f 1d33 1d37 1d3b 1d3e 1d3f 1d41
1d46 1d47 1d49 1d4a 1d4f 1d50 1d55 1d57
1d5b 1d5e 1d62 1d66 1d69 1d6d 1d71 1d74
1d77 1d7c 1d7f 1d82 1d85 1d86 1d8b 1d8c
1 1d8e 1d93 1d97 1d9b 1d9e 1da3 1da8
1dab 1daf 1db0 1db5 1db6 1dbb 1dbd 1dc1
1dc4 1dc8 1dcc 1dcf 1dd3 1dd7 1dda 1dde
1ddf 1de4 1de6 1dea 1ded 1df1 1df5 1df9
1dfc 1e00 1e04 1e08 1e0b 1e0c 1e0e 1e11
1e14 1e15 1e1a 1e1e 1e21 1e25 1e27 1e2b
1e2e 1e32 1e36 1e3a 1e3e 1e42 1e46 1e52
1e56 1e5a 1e5d 1e61 1e65 1e67 1 1e6b
1e6f 1e73 1e76 1e7a 1e7e 1e82 1e86 1e89
1e8d 1e91 1e94 1e97 1e9c 1e9f 1ea2 1ea5
1ea6 1eab 1eac 1 1eae 1eb3 1eb7 1ebb
1ebe 1ec3 1ec8 1ecb 1ecf 1ed0 1ed5 1ed8
1edd 1ede 1ee3 1ee6 1eeb 1eec 1ef1 1ef4
1ef8 1ef9 1efe 1f01 1f06 1f07 1f0c 1f0f
1f13 1f17 1f1a 1f1d 1f1e 1f20 1f21 1f26
1f27 1f2c 1f2e 1f32 1f35 1f37 1f3b 1f3d
1f49 1f4b 1f4d 1f4e 1f53 1f57 1f59 1f65
1f67 1f6b 1f6f 1f72 1f73 1f75 1f78 1f7b
1f7c 1f81 1f85 1f89 1f8d 1f91 1f94 1f95
1f97 1f9a 1f9e 1fa2 1fa5 1fa6 1fa8 1fa9
1fae 1fb1 1fb4 1fb7 1fb8 1fbd 1fc0 1fc3
1fc6 1fc7 1fcc 1fcd 1fcf 1fd3 1fd7 1fdb
1fde 1fdf 1fe1 1fe5 1fe8 1fec 1fef 1ff0
1ff2 1ff3 1ff8 1ffc 1fff 2003 2007 200a
200e 2010 2014 2017 201b 201d 2021 2025
2028 202a 202e 2031 2035 2036 203a 203e
2042 2046 2049 204a 204c 204f 2050 2052
2055 2058 205b 205c 2061 2065 2069 206c
206d 206f 2072 2075 2076 207b 207f 2083
2086 2087 2089 208c 208f 2090 2095 2099
209d 20a0 20a4 20a8 20ac 20b0 20b4 20b8
20bc 20c0 20c4 20c8 20cc 20d0 20d4 20d8
20dc 20e0 20e4 20e8 20e9 20eb 20ef 20f3
20f7 20fa 20fd 2100 2101 2106 210a 210e
2112 2116 211a 211e 2122 2126 212a 212e
2132 2136 213a 213e 2142 214e 2152 2157
215b 215e 215f 2164 2168 216c 216f 2172
2176 2178 217c 2180 2183 2186 218a 218c
2190 2194 2197 2199 1 219d 21a1 21a5
21a8 21ac 21b0 21b4 21b8 21bb 21bf 21c3
21c6 21c9 21ce 21d1 21d4 21d7 21d8 21dd
21de 1 21e0 21e5 21e9 21ed 21f0 21f5
21fa 21fd 2201 2202 2207 220a 220f 2210
2215 2218 221d 221e 2223 2226 222a 222b
2230 2233 2238 2239 223e 2241 2245 2249
224c 224f 2250 2252 2253 2258 2259 225e
2260 2264 2267 2269 226d 226f 227b 227d
227f 2280 2285 2289 228b 2297 2299 229b
229f 22a2 22a4 22a8 22ac 22af 22b3 22b7
22bb 22bf 22c3 22c7 22cb 22cf 22d3 22d7
22db 22df 22e3 22e7 22eb 22ef 22f3 22f7
22f8 22fa 22fe 2300 2304 2308 230b 230d
2311 2315 2319 231c 231d 231f 2322 2325
2326 232b 232f 2333 2337 233a 233b 233d
2340 2343 2344 2349 234d 2351 2354 2358
235c 2360 2364 2368 236c 2370 2374 2378
237c 2380 2384 2388 238c 2390 2394 2398
239c 239d 239f 23a3 23a7 23ab 23ae 23b1
23b4 23b5 23ba 23be 23c2 23c6 23ca 23ce
23d2 23d6 23da 23de 23e2 23e6 23f2 23f6
23fb 23ff 2402 2403 2408 240c 2410 2413
2416 241a 241c 2420 2424 2427 242a 242e
2430 2434 2438 243b 243d 1 2441 2445
2449 244c 2450 2454 2458 245c 245f 2463
2467 246a 246d 2472 2475 2478 247b 247c
2481 2482 1 2484 2489 248d 2491 2494
2499 249e 24a1 24a5 24a6 24ab 24ae 24b3
24b4 24b9 24bc 24c1 24c2 24c7 24ca 24ce
24cf 24d4 24d7 24dc 24dd 24e2 24e5 24e9
24ed 24f0 24f3 24f4 24f6 24f7 24fc 24fd
2502 2504 2508 250b 250d 2511 2513 251f
2521 2523 2524 2529 252d 252f 253b 253d
253f 2543 2546 2548 254c 2550 2553 2557
255b 255f 2563 2567 256b 256f 2573 2577
257b 257f 2583 2587 258b 258f 2593 2597
259b 259c 259e 25a2 25a4 25a8 25ac 25af
25b1 25b5 25b9 25bc 25c0 25c4 25c7 25ca
25cd 25ce 25d3 25d6 25da 25de 25e2 25e5
25e6 25e8 25eb 25ec 25ee 25f1 25f4 25f7
25f8 25fd 1 2600 2605 2609 260d 2610
2611 2613 2617 261a 261e 2621 2622 2624
2625 262a 262d 2631 2635 2638 2639 263b
263e 2641 2642 2647 1 264a 264f 2653
2657 265a 265b 265d 2660 2663 2664 2669
1 266c 2671 2675 2679 267d 2681 2685
2689 268d 2691 2695 2699 269d 26a1 26a5
26a9 26ad 26b1 26b5 26b9 26bd 26c1 26c5
26c9 26cd 26d9 26dd 26e2 26e6 26e9 26ea
26ef 26f3 26f7 26fa 26fd 2701 2703 2707
270b 270e 2711 2715 2717 271b 271f 2722
2724 1 2728 272c 2730 2733 2737 273b
273f 2743 2746 274a 274e 2751 2754 2759
275c 275f 2762 2763 2768 2769 1 276b
2770 2774 2778 277b 2780 2785 2788 278c
278d 2792 2795 279a 279b 27a0 27a3 27a8
27a9 27ae 27b1 27b5 27b6 27bb 27be 27c3
27c4 27c9 27cc 27d0 27d4 27d7 27da 27db
27dd 27de 27e3 27e4 27e9 27eb 27ef 27f2
27f4 27f8 27fa 2806 2808 280a 280b 2810
2814 2816 2822 2824 2828 282c 2830 2834
2838 283c 2840 2844 2850 2854 2859 285d
2860 2861 2866 286a 286e 2871 2874 2878
287a 287e 2882 2885 2888 288c 288e 2892
2896 2899 289b 1 289f 28a3 28a7 28aa
28ae 28b2 28b6 28ba 28bd 28c1 28c5 28c8
28cb 28d0 28d3 28d6 28d9 28da 28df 28e0
1 28e2 28e7 28eb 28ef 28f2 28f7 28fc
28ff 2903 2904 2909 290c 2911 2912 2917
291a 291f 2920 2925 2928 292c 292d 2932
2935 293a 293b 2940 2943 2947 294b 294e
2951 2952 2954 2955 295a 295b 2960 2962
2966 2969 296b 296f 2971 297d 297f 2981
2982 2987 298b 298d 2999 299b 299f 29a3
29a7 29ab 29af 29bb 29bf 29c4 29c8 29cb
29cc 29d1 29d5 29d9 29dc 29df 29e3 29e5
29e9 29ed 29f0 29f3 29f7 29f9 29fd 2a01
2a04 2a06 1 2a0a 2a0e 2a12 2a15 2a19
2a1d 2a21 2a25 2a28 2a2c 2a30 2a33 2a36
2a3b 2a3e 2a41 2a44 2a45 2a4a 2a4b 1
2a4d 2a52 2a56 2a5a 2a5d 2a62 2a67 2a6a
2a6e 2a6f 2a74 2a77 2a7c 2a7d 2a82 2a85
2a8a 2a8b 2a90 2a93 2a97 2a98 2a9d 2aa0
2aa5 2aa6 2aab 2aae 2ab2 2ab6 2ab9 2abc
2abd 2abf 2ac0 2ac5 2ac6 2acb 2acd 2ad1
2ad4 2ad6 2ada 2adc 2ae8 2aea 2aec 2aed
2af2 2af6 2af8 2b04 2b06 2b08 2b0c 2b10
2b14 2b18 2b1c 2b20 2b24 2b28 2b2c 2b30
2b34 2b40 2b44 2b49 2b4d 2b50 2b51 2b56
2b5a 2b5e 2b61 2b64 2b68 2b6a 2b6e 2b72
2b75 2b78 2b7c 2b7e 2b82 2b86 2b89 2b8b
1 2b8f 2b93 2b97 2b9a 2b9e 2ba2 2ba6
2baa 2bad 2bb1 2bb5 2bb8 2bbb 2bc0 2bc3
2bc6 2bc9 2bca 2bcf 2bd0 1 2bd2 2bd7
2bdb 2bdf 2be2 2be7 2bec 2bef 2bf3 2bf4
2bf9 2bfc 2c01 2c02 2c07 2c0a 2c0f 2c10
2c15 2c18 2c1c 2c1d 2c22 2c25 2c2a 2c2b
2c30 2c33 2c37 2c3b 2c3e 2c41 2c42 2c44
2c45 2c4a 2c4b 2c50 2c52 2c56 2c59 2c5b
2c5f 2c61 2c6d 2c6f 2c71 2c72 2c77 2c7b
2c7d 2c89 2c8b 2c8d 2c91 2c95 2c98 2c9a
2c9e 2ca1 2ca3 2ca7 2cab 2caf 2cb3 2cb6
2cb7 2cb9 2cbd 2cc1 2cc4 2cc5 2cc7 2ccb
2ccf 2cd3 2cd6 2cd7 2cd9 2cdc 2cdf 2ce0
2ce5 2ce9 2ced 2cf0 2cf4 2cf8 2cfc 2d00
2d04 2d08 2d0c 2d10 2d14 2d18 2d1c 2d20
2d24 2d28 2d2c 2d30 2d34 2d38 2d39 2d3b
2d3f 2d43 2d47 2d4a 2d4d 2d50 2d51 2d56
2d59 2d5d 2d61 2d64 2d65 2d67 2d6a 2d6d
2d6e 2d73 1 2d76 2d7b 2d7f 2d83 2d86
2d87 2d89 2d8c 2d8f 2d90 2d95 1 2d98
2d9d 2da1 2da5 2da9 2dad 2db1 2db5 2db9
2dbd 2dc1 2dc5 2dc9 2dcd 2dd1 2dd5 2dd9
2de5 2de9 2dee 2df2 2df5 2df6 2dfb 2dff
2e03 2e06 2e09 2e0d 2e0f 2e13 2e17 2e1a
2e1d 2e21 2e23 2e27 2e2b 2e2e 2e30 1
2e34 2e38 2e3c 2e3f 2e43 2e47 2e4b 2e4f
2e52 2e56 2e5a 2e5d 2e60 2e65 2e68 2e6b
2e6e 2e6f 2e74 2e75 1 2e77 2e7c 2e80
2e84 2e87 2e8c 2e91 2e94 2e98 2e99 2e9e
2ea1 2ea6 2ea7 2eac 2eaf 2eb4 2eb5 2eba
2ebd 2ec1 2ec2 2ec7 2eca 2ecf 2ed0 2ed5
2ed8 2edc 2ee0 2ee3 2ee6 2ee7 2ee9 2eea
2eef 2ef0 2ef5 2ef7 2efb 2efe 2f00 2f04
2f06 2f12 2f14 2f16 2f17 2f1c 2f20 2f22
2f2e 2f30 2f32 2f36 2f39 2f3b 2f3f 2f42
2f43 2f48 2f4b 2f4f 2f53 2f57 2f5b 2f5f
2f63 2f67 2f6b 2f6f 2f73 2f77 2f7b 2f7f
2f8b 2f8f 2f93 2f96 2f9a 2f9e 2fa0 1
2fa4 2fa8 2fac 2faf 2fb3 2fb7 2fbb 2fbf
2fc2 2fc6 2fca 2fcd 2fd0 2fd5 2fd8 2fdb
2fde 2fdf 2fe4 2fe5 1 2fe7 2fec 2ff0
2ff4 2ff7 2ffc 3001 3004 3008 3009 300e
3011 3016 3017 301c 301f 3024 3025 302a
302d 3031 3032 3037 303a 303f 3040 3045
3048 304c 3050 3053 3056 3057 3059 305a
305f 3060 3065 3067 306b 306e 3070 3074
3076 3082 3084 3086 3087 308c 3090 3092
309e 30a0 30a4 30a8 30ab 30af 30b3 30b6
30b7 30b9 30bc 30bf 30c0 30c5 30c9 30cd
30d1 30d4 30d8 30dc 30df 30e3 30e7 30eb
30ef 30f3 30ff 3103 3107 310a 310e 3112
3114 1 3118 311c 3120 3123 3127 312b
312f 3133 3136 313a 313e 3141 3144 3149
314c 314f 3152 3153 3158 3159 1 315b
3160 3164 3168 316b 3170 3175 3178 317c
317d 3182 3185 318a 318b 3190 3193 3198
3199 319e 31a1 31a5 31a6 31ab 31ae 31b3
31b4 31b9 31bc 31c0 31c4 31c7 31ca 31cb
31cd 31ce 31d3 31d4 31d9 31db 31df 31e2
31e4 31e8 31ea 31f6 31f8 31fa 31fb 3200
3204 3206 3212 3214 3218 321c 3220 3224
3228 322c 3230 3234 3235 3237 323b 323f
3243 3246 3247 3249 324c 324f 3250 3255
3259 325a 325e 3262 3263 3267 326b 326c
3270 3274 3275 3279 327d 327e 3282 3286
328a 328f 3293 3294 3298 329c 32a0 32a5
32aa 32ae 32b2 32b6 32bb 32bf 32c3 32c6
32c9 32cd 32cf 32d3 32d7 32da 32dd 32e1
32e3 32e7 32eb 32ee 32f2 32f6 32fb 32fd
3301 3305 3308 330c 3310 3312 1 3316
331a 331e 3321 3325 3329 332d 3331 3334
3338 333c 333f 3342 3347 334a 334d 3350
3351 3356 3357 1 3359 335e 3362 3366
3369 336e 3373 3376 337a 337b 3380 3383
3388 3389 338e 3391 3396 3397 339c 339f
33a3 33a4 33a9 33ac 33b1 33b2 33b7 33ba
33be 33c2 33c5 33c8 33c9 33cb 33cc 33d1
33d2 33d7 33d9 33dd 33e0 33e2 33e6 33e8
33f4 33f6 33f8 33f9 33fe 3402 3404 3410
3412 3416 341a 341e 3422 3426 3432 3436
343a 343d 3441 3445 3447 1 344b 344f
3453 3456 345a 345e 3462 3466 3469 346d
3471 3474 3477 347c 347f 3482 3485 3486
348b 348c 1 348e 3493 3497 349b 349e
34a3 34a8 34ab 34af 34b0 34b5 34b8 34bd
34be 34c3 34c6 34cb 34cc 34d1 34d4 34d8
34d9 34de 34e1 34e6 34e7 34ec 34ef 34f3
34f7 34fa 34fd 34fe 3500 3501 3506 3507
350c 350e 3512 3515 3517 351b 351d 3529
352b 352d 352e 3533 3537 3539 3545 3547
354b 3550 3554 3558 355d 3561 3565 3569
356d 3570 3574 3575 357a 357d 3580 3581
3583 3587 358b 358f 3593 3596 359b 359c
35a1 35a4 35a7 35a8 35aa 35ae 35b2 35b6
35ba 35bd 35c1 35c2 35c7 35ca 35cd 35ce
35d0 35d4 35d8 35dc 35e0 35e3 35e8 35e9
35ee 35f1 35f4 35f5 35f7 35fb 35ff 3603
3607 360b 360f 3613 3617 361b 361f 3623
3627 362b 362f 3633 3637 363b 363f 3640
3642 3646 364a 364e 3651 3655 3659 365c
365f 3664 3667 366a 366d 366e 3673 3674
1 3676 367b 367f 3683 3686 368b 3690
3693 3697 3698 369d 36a0 36a5 36a6 36ab
36ae 36b3 36b4 36b9 36bc 36c0 36c4 36c7
36c8 36ca 36cf 36d0 36d2 36d3 36d8 36db
36e0 36e1 36e6 36e9 36ee 36ef 36f4 36f7
36fb 36fc 3701 3704 3709 370a 370f 3710
3715 3717 371b 371e 3722 3726 3729 372d
3731 3734 3737 373c 373f 3742 3745 3746
374b 374c 1 374e 3753 3757 375b 375e
3763 3768 376b 376f 3770 3775 3776 377b
377d 3781 3784 3788 378c 378f 3792 3796
379a 379b 37a0 37a2 37a6 37a9 37ab 37af
37b2 37b4 37b8 37bb 37bf 37c3 37c7 37ca
37cb 37cd 37d0 37d3 37d4 37d9 37dd 37e1
37e5 37e8 37ec 37f0 37f4 37f8 37fc 3800
3804 3808 380c 3810 3814 3818 381c 3820
3824 3828 382c 3830 3831 3833 3837 383b
383f 3842 3845 3848 3849 384e 3851 3855
3859 385c 385d 385f 3862 3865 3866 386b
1 386e 3873 3877 387b 387e 387f 3881
3884 3887 3888 388d 1 3890 3895 3899
389d 38a1 38a5 38a9 38ad 38b1 38b5 38b9
38bd 38c1 38cd 38d1 38d6 38da 38dd 38de
38e3 38e7 38eb 38ee 38f1 38f5 38f7 38fb
38ff 3902 3905 3909 390b 390f 3913 3916
3918 1 391c 3920 3924 3927 392b 392f
3933 3937 393a 393e 3942 3945 3948 394d
3950 3953 3956 3957 395c 395d 1 395f
3964 3968 396c 396f 3974 3979 397c 3980
3981 3986 3989 398e 398f 3994 3997 399c
399d 39a2 39a5 39a9 39aa 39af 39b2 39b7
39b8 39bd 39c0 39c4 39c8 39cb 39ce 39cf
39d1 39d2 39d7 39d8 39dd 39df 39e3 39e6
39e8 39ec 39ee 39fa 39fc 39fe 39ff 3a04
3a08 3a0a 3a16 3a18 3a1a 3a1e 3a21 3a23
3a27 3a2b 3a2e 3a30 3a34 3a38 3a3b 3a3f
3a43 3a46 3a49 3a4c 3a4d 3a52 3a56 3a5a
3a5d 3a61 3a65 3a68 3a6b 3a70 3a73 3a76
3a79 3a7a 3a7f 3a80 1 3a82 3a87 3a8b
3a8f 3a92 3a97 3a9c 3a9f 3aa3 3aa4 3aa9
3aac 3ab1 3ab2 3ab7 3aba 3abf 3ac0 3ac5
3ac8 3acc 3ad0 3ad4 3ad8 3adb 3adc 3ade
3ae3 3ae4 3ae6 3ae7 3aec 3aef 3af4 3af5
3afa 3afd 3b02 3b03 3b08 3b0b 3b0f 3b10
3b15 3b18 3b1d 3b1e 3b23 3b24 3b29 3b2b
3b2f 3b32 3b36 3b3a 3b3d 3b41 3b45 3b48
3b4b 3b50 3b53 3b56 3b59 3b5a 3b5f 3b60
1 3b62 3b67 3b6b 3b6f 3b72 3b77 3b7c
3b7f 3b83 3b84 3b89 3b8a 3b8f 3b91 3b95
3b98 3b9c 3ba0 3ba3 3ba7 3bab 3bae 3bb2
3bb6 3bb7 3bbc 3bbe 3bc2 3bc5 3bc9 3bcd
3bd1 3bd5 3bd9 3bdc 3bdd 3bdf 3be2 3be5
3be6 3beb 3bee 3bf2 3bf6 3bf9 3bfa 3bfc
3bff 3c02 3c03 3c08 1 3c0b 3c10 3c14
3c17 3c1b 3c1d 3c21 3c24 3c28 3c2c 3c2f
3c30 3c32 3c35 3c38 3c39 3c3e 3c42 3c46
3c4a 3c4d 3c4e 3c50 3c53 3c54 3c56 3c59
3c5c 3c5f 3c60 3c65 3c69 3c6c 3c6d 3c72
3c75 3c79 3c7c 3c7d 3c82 3c85 3c89 3c8d
3c91 3c95 3c99 3c9d 3ca1 3ca5 3ca9 3cad
3cb1 3cb5 3cb9 3cbd 3cc1 3cc5 3cc9 3ccd
3cd1 3cd5 3cd9 3ce5 3ce9 3cee 3cf2 3cf5
3cf6 3cfb 3cff 3d03 3d06 3d09 3d0d 3d0f
3d13 3d17 3d1a 3d1d 3d21 3d23 3d27 3d2b
3d2e 3d30 1 3d34 3d38 3d3c 3d3f 3d43
3d47 3d4b 3d4f 3d52 3d56 3d5a 3d5d 3d60
3d65 3d68 3d6b 3d6e 3d6f 3d74 3d75 1
3d77 3d7c 3d80 3d84 3d87 3d8c 3d91 3d94
3d98 3d99 3d9e 3da1 3da6 3da7 3dac 3daf
3db4 3db5 3dba 3dbd 3dc1 3dc2 3dc7 3dca
3dcf 3dd0 3dd5 3dd8 3ddc 3de0 3de3 3de6
3de7 3de9 3dea 3def 3df0 3df5 3df7 3dfb
3dfe 3e00 3e04 3e06 3e12 3e14 3e16 3e17
3e1c 3e20 3e22 3e2e 3e30 3e32 3e36 3e3a
3e3e 3e42 3e46 3e4a 3e4e 3e52 3e56 3e62
3e66 3e6b 3e6f 3e72 3e73 3e78 3e7c 3e80
3e83 3e86 3e8a 3e8c 3e90 3e94 3e97 3e9a
3e9e 3ea0 3ea4 3ea8 3eab 3ead 1 3eb1
3eb5 3eb9 3ebc 3ec0 3ec4 3ec8 3ecc 3ecf
3ed3 3ed7 3eda 3edd 3ee2 3ee5 3ee8 3eeb
3eec 3ef1 3ef2 1 3ef4 3ef9 3efd 3f01
3f04 3f09 3f0e 3f11 3f15 3f16 3f1b 3f1e
3f23 3f24 3f29 3f2c 3f31 3f32 3f37 3f3a
3f3e 3f3f 3f44 3f47 3f4c 3f4d 3f52 3f55
3f59 3f5d 3f60 3f63 3f64 3f66 3f67 3f6c
3f6d 3f72 3f74 3f78 3f7b 3f7d 3f81 3f83
3f8f 3f91 3f93 3f94 3f99 3f9d 3f9f 3fab
3fad 3faf 3fb3 3fb7 3fba 3fbc 3fc0 3fc3
3fc4 3fc9 3fcc 3fd0 3fd4 3fd8 3fdc 3fe0
3fe4 3fe8 3fec 3ff0 3ff4 3ff8 3ffc 4000
4004 4008 400c 4010 4014 4018 401c 4020
4024 4028 402c 4030 4034 4038 403c 4040
4044 4048 404c 4050 4054 4058 405c 4060
4064 4068 406c 4070 4074 4078 407c 4080
4084 4088 408c 4090 4094 4098 409c 40a0
40a4 40a8 40ac 40b0 40b4 40b8 40bc 40c0
40c4 40c8 40cc 40d8 40dc 40e1 40e5 40e8
40e9 40ee 40f2 40f6 40f9 40fc 4100 4102
4106 410a 410d 4110 4114 4116 411a 411e
4121 4123 1 4127 412b 412f 4132 4136
413a 413e 4142 4145 4149 414d 4150 4153
4158 415b 415e 4161 4162 4167 4168 1
416a 416f 4173 4177 417a 417f 4184 4187
418b 418c 4191 4194 4199 419a 419f 41a2
41a7 41a8 41ad 41b0 41b4 41b5 41ba 41bd
41c2 41c3 41c8 41cb 41cf 41d3 41d6 41d9
41da 41dc 41dd 41e2 41e3 41e8 41ea 41ee
41f1 41f3 41f7 41f9 4205 4207 4209 420a
420f 4213 4215 4221 4223 4225 4229 422d
4231 4235 4239 423d 4241 4245 4249 424d
4251 4255 4259 425d 4261 4265 4269 426d
4271 4275 4279 427d 4281 4285 4289 428d
4291 4295 4299 429d 42a1 42a5 42a9 42ad
42b1 42b5 42b9 42bd 42c1 42c5 42c9 42cd
42d1 42d5 42d9 42dd 42e1 42e5 42e9 42ed
42f1 42f5 4301 4305 430a 430e 4311 4312
4317 431b 431f 4322 4325 4329 432b 432f
4333 4336 4339 433d 433f 4343 4347 434a
434c 1 4350 4354 4358 435b 435f 4363
4367 436b 436e 4372 4376 4379 437c 4381
4384 4387 438a 438b 4390 4391 1 4393
4398 439c 43a0 43a3 43a8 43ad 43b0 43b4
43b5 43ba 43bd 43c2 43c3 43c8 43cb 43d0
43d1 43d6 43d9 43dd 43de 43e3 43e6 43eb
43ec 43f1 43f4 43f8 43fc 43ff 4402 4403
4405 4406 440b 440c 4411 4413 4417 441a
441c 4420 4422 442e 4430 4432 4433 4438
443c 443e 444a 444c 444e 4452 4456 4459
445b 445f 4463 4466 446a 446c 4470 4474
4477 4478 447a 447d 4480 4481 4486 448a
448e 4492 4496 449a 449e 44a2 44a6 44aa
44b6 44ba 44bf 44c3 44c6 44c7 44cc 44d0
44d4 44d7 44da 44de 44e0 44e4 44e8 44eb
44ee 44f2 44f4 44f8 44fc 44ff 4501 1
4505 4509 450d 4510 4514 4518 451c 4520
4523 4527 452b 452e 4531 4536 4539 453c
453f 4540 4545 4546 1 4548 454d 4551
4555 4558 455d 4562 4565 4569 456a 456f
4572 4577 4578 457d 4580 4585 4586 458b
458e 4592 4593 4598 459b 45a0 45a1 45a6
45a9 45ad 45b1 45b4 45b7 45b8 45ba 45bb
45c0 45c1 45c6 45c8 45cc 45cf 45d1 45d5
45d7 45e3 45e5 45e7 45e8 45ed 45f1 45f3
45ff 4601 4603 4607 460b 460e 4610 4614
4618 461c 461f 4620 4622 4625 4626 4628
462b 462e 4631 4632 4637 463b 463e 463f
4644 4647 464b 464e 464f 4654 4657 465b
465f 4663 4667 466b 466f 4673 4677 467b
467f 4683 4687 468b 468f 4693 4697 469b
469f 46a3 46a7 46ab 46b7 46bb 46c0 46c4
46c7 46c8 46cd 46d1 46d5 46d8 46db 46df
46e1 46e5 46e9 46ec 46ef 46f3 46f5 46f9
46fd 4700 4702 1 4706 470a 470e 4711
4715 4719 471d 4721 4724 4728 472c 472f
4732 4737 473a 473d 4740 4741 4746 4747
1 4749 474e 4752 4756 4759 475e 4763
4766 476a 476b 4770 4773 4778 4779 477e
4781 4786 4787 478c 478f 4793 4794 4799
479c 47a1 47a2 47a7 47aa 47ae 47b2 47b5
47b8 47b9 47bb 47bc 47c1 47c2 47c7 47c9
47cd 47d0 47d2 47d6 47d8 47e4 47e6 47e8
47e9 47ee 47f2 47f4 4800 4802 4804 4808
480c 4810 4814 4818 481c 4820 4824 4828
482c 4830 483c 4840 4845 4849 484c 484d
4852 4856 485a 485d 4860 4864 4866 486a
486e 4871 4874 4878 487a 487e 4882 4885
4887 1 488b 488f 4893 4896 489a 489e
48a2 48a6 48a9 48ad 48b1 48b4 48b7 48bc
48bf 48c2 48c5 48c6 48cb 48cc 1 48ce
48d3 48d7 48db 48de 48e3 48e8 48eb 48ef
48f0 48f5 48f8 48fd 48fe 4903 4906 490b
490c 4911 4914 4918 4919 491e 4921 4926
4927 492c 492f 4933 4937 493a 493d 493e
4940 4941 4946 4947 494c 494e 4952 4955
4957 495b 495d 4969 496b 496d 496e 4973
4977 4979 4985 4987 4989 498d 4991 4994
4996 499a 499d 499e 49a3 49a6 49aa 49ae
49b2 49b6 49ba 49be 49c2 49c6 49ca 49ce
49d2 49d6 49da 49de 49e2 49e6 49ea 49ee
49f2 49f6 49fa 49fe 4a02 4a06 4a0a 4a0e
4a12 4a16 4a1a 4a1e 4a22 4a26 4a2a 4a2e
4a32 4a36 4a3a 4a3e 4a42 4a46 4a4a 4a4e
4a52 4a56 4a5a 4a5e 4a62 4a66 4a6a 4a6e
4a72 4a76 4a7a 4a7e 4a82 4a86 4a8a 4a8e
4a92 4a96 4a9a 4a9e 4aa2 4aa6 4ab2 4ab6
4abb 4abf 4ac2 4ac3 4ac8 4acc 4ad0 4ad3
4ad6 4ada 4adc 4ae0 4ae4 4ae7 4aea 4aee
4af0 4af4 4af8 4afb 4afd 1 4b01 4b05
4b09 4b0c 4b10 4b14 4b18 4b1c 4b1f 4b23
4b27 4b2a 4b2d 4b32 4b35 4b38 4b3b 4b3c
4b41 4b42 1 4b44 4b49 4b4d 4b51 4b54
4b59 4b5e 4b61 4b65 4b66 4b6b 4b6e 4b73
4b74 4b79 4b7c 4b81 4b82 4b87 4b8a 4b8e
4b8f 4b94 4b97 4b9c 4b9d 4ba2 4ba5 4ba9
4bad 4bb0 4bb3 4bb4 4bb6 4bb7 4bbc 4bbd
4bc2 4bc4 4bc8 4bcb 4bcd 4bd1 4bd3 4bdf
4be1 4be3 4be4 4be9 4bed 4bef 4bfb 4bfd
4bff 4c03 4c07 4c0b 4c0f 4c13 4c17 4c1b
4c1f 4c23 4c27 4c2b 4c2f 4c33 4c37 4c3b
4c3f 4c43 4c47 4c4b 4c4f 4c53 4c57 4c5b
4c5f 4c63 4c67 4c6b 4c6f 4c73 4c77 4c7b
4c7f 4c83 4c87 4c8b 4c8f 4c93 4c97 4c9b
4c9f 4ca3 4ca7 4cab 4caf 4cb3 4cb7 4cbb
4cbf 4cc3 4cc7 4ccb 4ccf 4cd3 4cd7 4ce3
4ce7 4cec 4cf0 4cf3 4cf4 4cf9 4cfd 4d01
4d04 4d07 4d0b 4d0d 4d11 4d15 4d18 4d1b
4d1f 4d21 4d25 4d29 4d2c 4d2e 1 4d32
4d36 4d3a 4d3d 4d41 4d45 4d49 4d4d 4d50
4d54 4d58 4d5b 4d5e 4d63 4d66 4d69 4d6c
4d6d 4d72 4d73 1 4d75 4d7a 4d7e 4d82
4d85 4d8a 4d8f 4d92 4d96 4d97 4d9c 4d9f
4da4 4da5 4daa 4dad 4db2 4db3 4db8 4dbb
4dbf 4dc0 4dc5 4dc8 4dcd 4dce 4dd3 4dd6
4dda 4dde 4de1 4de4 4de5 4de7 4de8 4ded
4dee 4df3 4df5 4df9 4dfc 4dfe 4e02 4e04
4e10 4e12 4e14 4e15 4e1a 4e1e 4e20 4e2c
4e2e 4e30 4e34 4e38 4e3b 4e3d 4e41 4e45
4e48 4e4c 4e4e 4e52 4e56 4e59 4e5a 4e5c
4e5f 4e62 4e63 4e68 4e6c 4e6f 4e70 4e75
4e78 4e7c 4e80 4e83 4e84 4e86 4e89 4e8c
4e8d 4e92 4e96 4e9a 4e9e 4ea2 4ea6 4eaa
4eae 4eb2 4eb6 4eba 4ebe 4ec2 4ec6 4eca
4ed6 4eda 4edf 4ee3 4ee6 4ee7 4eec 4ef0
4ef4 4ef7 4efa 4efe 4f00 4f04 4f08 4f0b
4f0e 4f12 4f14 4f18 4f1c 4f1f 4f21 1
4f25 4f29 4f2d 4f30 4f34 4f38 4f3c 4f40
4f43 4f47 4f4b 4f4e 4f51 4f56 4f59 4f5c
4f5f 4f60 4f65 4f66 1 4f68 4f6d 4f71
4f75 4f78 4f7d 4f82 4f85 4f89 4f8a 4f8f
4f92 4f97 4f98 4f9d 4fa0 4fa5 4fa6 4fab
4fae 4fb2 4fb3 4fb8 4fbb 4fc0 4fc1 4fc6
4fc9 4fcd 4fd1 4fd4 4fd7 4fd8 4fda 4fdb
4fe0 4fe1 4fe6 4fe8 4fec 4fef 4ff1 4ff5
4ff7 5003 5005 5007 5008 500d 5011 5013
501f 5021 5023 5027 502b 502f 5033 5037
503b 503f 5043 5047 504b 504f 505b 505f
5064 5068 506b 506c 5071 5075 5079 507c
507f 5083 5085 5089 508d 5090 5093 5097
5099 509d 50a1 50a4 50a6 1 50aa 50ae
50b2 50b5 50b9 50bd 50c1 50c5 50c8 50cc
50d0 50d3 50d6 50db 50de 50e1 50e4 50e5
50ea 50eb 1 50ed 50f2 50f6 50fa 50fd
5102 5107 510a 510e 510f 5114 5117 511c
511d 5122 5125 512a 512b 5130 5133 5137
5138 513d 5140 5145 5146 514b 514e 5152
5156 5159 515c 515d 515f 5160 5165 5166
516b 516d 5171 5174 5176 517a 517c 5188
518a 518c 518d 5192 5196 5198 51a4 51a6
51a8 51ac 51b0 51b3 51b5 51b9 51bd 51c1
51c5 51c9 51cd 51d1 51d5 51d9 51dd 51e1
51ed 51f1 51f6 51fa 51fd 51fe 5203 5207
520b 520e 5211 5215 5217 521b 521f 5222
5225 5229 522b 522f 5233 5236 5238 1
523c 5240 5244 5247 524b 524f 5253 5257
525a 525e 5262 5265 5268 526d 5270 5273
5276 5277 527c 527d 1 527f 5284 5288
528c 528f 5294 5299 529c 52a0 52a1 52a6
52a9 52ae 52af 52b4 52b7 52bc 52bd 52c2
52c5 52c9 52ca 52cf 52d2 52d7 52d8 52dd
52e0 52e4 52e8 52eb 52ee 52ef 52f1 52f2
52f7 52f8 52fd 52ff 5303 5306 5308 530c
530e 531a 531c 531e 531f 5324 5328 532a
5336 5338 533a 533e 5342 5345 5347 534b
534f 5352 5354 5358 535c 535f 5363 5366
5367 536c 536f 5373 5377 537a 537b 537d
5380 5383 5384 5389 1 538c 5391 5394
5398 539c 539f 53a0 53a2 53a5 53a8 53a9
53ae 1 53b1 53b6 53ba 53bf 53c3 53c7
53c8 53cc 53d0 53d3 53d7 53db 53de 53e2
53e6 53ea 53ed 53ee 53f0 53f3 53f6 53f7
53fc 5400 5404 5408 540c 5410 5414 5418
541c 5420 5424 5428 542c 5430 5434 5438
543c 5440 5444 5448 544c 5450 5454 5458
545c 5460 546c 5470 5474 5477 547b 547f
5481 1 5485 5489 548d 5490 5494 5498
549c 54a0 54a3 54a7 54ab 54ae 54b1 54b6
54b9 54bc 54bf 54c0 54c5 54c6 1 54c8
54cd 54d1 54d5 54d8 54dd 54e2 54e5 54e9
54ea 54ef 54f2 54f7 54f8 54fd 5500 5505
5506 550b 550e 5512 5513 5518 551b 5520
5521 5526 5529 552d 5531 5534 5537 5538
553a 553b 5540 5541 5546 5548 554c 554f
5551 5555 5557 5563 5565 5567 5568 556d
5571 5573 557f 5581 5583 5587 558b 558f
5593 5597 559b 559f 55a3 55a7 55ab 55af
55b3 55b7 55bb 55bf 55c3 55c7 55cb 55cf
55d3 55d7 55db 55df 55e3 55e7 55eb 55f7
55fb 55ff 5602 5606 560a 560c 1 5610
5614 5618 561b 561f 5623 5627 562b 562e
5632 5636 5639 563c 5641 5644 5647 564a
564b 5650 5651 1 5653 5658 565c 5660
5663 5668 566d 5670 5674 5675 567a 567d
5682 5683 5688 568b 5690 5691 5696 5699
569d 569e 56a3 56a6 56ab 56ac 56b1 56b4
56b8 56bc 56bf 56c2 56c3 56c5 56c6 56cb
56cc 56d1 56d3 56d7 56da 56dc 56e0 56e2
56ee 56f0 56f2 56f3 56f8 56fc 56fe 570a
570c 570e 5712 5716 5719 571d 5721 5724
5728 572b 572f 5732 5733 5738 573b 573f
5743 5746 5747 5749 574d 5750 5754 5757
5758 575a 575b 5760 5763 5767 576b 576e
576f 5771 5774 5777 5778 577d 1 5780
5785 5789 578d 5790 5791 5793 5796 5799
579a 579f 1 57a2 57a7 57ab 57af 57b3
57b7 57bb 57bf 57c3 57c7 57d3 57d7 57dc
57e0 57e3 57e4 57e9 57ed 57f1 57f4 57f7
57fb 57fd 5801 5805 5808 580b 580f 5811
5815 5819 581c 581e 1 5822 5826 582a
582d 5831 5835 5839 583d 5840 5844 5848
584b 584e 5853 5856 5859 585c 585d 5862
5863 1 5865 586a 586e 5872 5875 587a
587f 5882 5886 5887 588c 588f 5894 5895
589a 589d 58a2 58a3 58a8 58ab 58af 58b0
58b5 58b8 58bd 58be 58c3 58c6 58ca 58ce
58d1 58d4 58d5 58d7 58d8 58dd 58de 58e3
58e5 58e9 58ec 58ee 58f2 58f4 5900 5902
5904 5905 590a 590e 5910 591c 591e 5922
5926 592a 592e 5932 5936 593a 593e 5942
5946 594a 594e 5952 595e 5962 5967 596b
596e 596f 5974 5978 597c 597f 5982 5986
5988 598c 5990 5993 5996 599a 599c 59a0
59a4 59a7 59a9 1 59ad 59b1 59b5 59b8
59bc 59c0 59c4 59c8 59cb 59cf 59d3 59d6
59d9 59de 59e1 59e4 59e7 59e8 59ed 59ee
1 59f0 59f5 59f9 59fd 5a00 5a05 5a0a
5a0d 5a11 5a12 5a17 5a1a 5a1f 5a20 5a25
5a28 5a2d 5a2e 5a33 5a36 5a3a 5a3b 5a40
5a43 5a48 5a49 5a4e 5a51 5a55 5a59 5a5c
5a5f 5a60 5a62 5a63 5a68 5a69 5a6e 5a70
5a74 5a77 5a79 5a7d 5a7f 5a8b 5a8d 5a8f
5a90 5a95 5a99 5a9b 5aa7 5aa9 5aab 5aaf
5ab3 5ab8 5abc 5abd 5ac1 5ac5 5ac9 5acd
5ad1 5ad6 5adb 5adf 5ae3 5ae7 5aec 5af0
5af4 5af7 5afa 5afe 5b00 5b04 5b08 5b0b
5b0e 5b12 5b14 5b18 5b1c 5b1f 5b23 5b27
5b2a 5b2d 5b30 5b31 5b36 5b3a 5b40 5b42
5b46 5b49 5b4d 5b51 5b55 5b58 5b59 5b5b
5b5e 5b62 5b66 5b69 5b6a 5b6c 5b6d 5b72
5b76 5b7a 5b7e 5b81 5b82 5b84 5b87 5b8a
5b8b 5b90 5b94 5b98 5b9b 5b9c 5b9e 5ba2
5ba5 5ba9 5bac 5bad 5baf 5bb0 5bb5 5bb9
5bbd 5bc0 5bc1 5bc3 5bc7 5bca 5bce 5bd1
5bd2 5bd4 5bd5 5bda 5bde 5be2 5be6 5be9
5bea 5bec 5bf0 5bf2 5bf6 5bfa 5bfe 5c01
5c02 5c04 5c07 5c0b 5c0f 5c12 5c13 5c15
5c16 5c1b 5c1e 5c22 5c26 5c29 5c2a 5c2c
5c2d 5c32 5c36 5c38 5c3c 5c40 5c43 5c45
5c49 5c4c 5c50 5c54 5c58 5c5c 5c60 5c6c
5c70 5c75 5c79 5c7c 5c7d 5c82 5c86 5c8a
5c8d 5c90 5c94 5c96 5c9a 5c9e 5ca1 5ca4
5ca8 5caa 5cae 5cb2 5cb5 5cb7 1 5cbb
5cbf 5cc3 5cc6 5cca 5cce 5cd2 5cd6 5cd9
5cdd 5ce1 5ce4 5ce7 5cec 5cef 5cf2 5cf5
5cf6 5cfb 5cfc 1 5cfe 5d03 5d07 5d0b
5d0e 5d13 5d18 5d1b 5d1f 5d20 5d25 5d28
5d2d 5d2e 5d33 5d36 5d3b 5d3c 5d41 5d44
5d48 5d49 5d4e 5d51 5d56 5d57 5d5c 5d5f
5d63 5d67 5d6a 5d6d 5d6e 5d70 5d71 5d76
5d77 5d7c 5d7e 5d82 5d85 5d87 5d8b 5d8d
5d99 5d9b 5d9d 5d9e 5da3 5da7 5da9 5db5
5db7 5dbb 5dbf 5dc3 5dc5 5dc9 5dcc 5dd0
5dd4 5dd7 5dd8 5dda 5dde 5de1 5de5 5de8
5de9 5deb 5dec 5df1 5df5 5dfb 5dfd 5e01
5e04 5e06 5e0a 5e11 5e15 5e19 5e1e 5e20
5e24 5e28 5e2b 5e2f 5e33 5e35 1 5e39
5e3d 5e41 5e44 5e48 5e4c 5e50 5e54 5e57
5e5b 5e5f 5e62 5e65 5e6a 5e6d 5e70 5e73
5e74 5e79 5e7a 1 5e7c 5e81 5e85 5e89
5e8c 5e91 5e96 5e99 5e9d 5e9e 5ea3 5ea6
5eab 5eac 5eb1 5eb4 5eb9 5eba 5ebf 5ec2
5ec6 5ec7 5ecc 5ecf 5ed4 5ed5 5eda 5edd
5ee1 5ee5 5ee8 5eeb 5eec 5eee 5eef 5ef4
5ef5 5efa 5efc 5f00 5f03 5f05 5f09 5f0b
5f17 5f19 5f1b 5f1c 5f21 5f25 5f27 5f33
5f35 5f39 5f3d 5f40 5f41 5f43 5f46 5f49
5f4a 5f4f 5f52 5f56 5f59 5f5a 5f5f 5f62
1 5f65 5f6a 5f6e 5f72 5f76 5f7a 5f7e
5f8a 5f8e 5f93 5f97 5f9a 5f9b 5fa0 5fa4
5fa8 5fab 5fae 5fb2 5fb4 5fb8 5fbc 5fbf
5fc2 5fc6 5fc8 5fcc 5fd0 5fd3 5fd5 1
5fd9 5fdd 5fe1 5fe4 5fe8 5fec 5ff0 5ff4
5ff7 5ffb 5fff 6002 6005 600a 600d 6010
6013 6014 6019 601a 1 601c 6021 6025
6029 602c 6031 6036 6039 603d 603e 6043
6046 604b 604c 6051 6054 6059 605a 605f
6062 6066 6067 606c 606f 6074 6075 607a
607d 6081 6085 6088 608b 608c 608e 608f
6094 6095 609a 609c 60a0 60a3 60a5 60a9
60ab 60b7 60b9 60bb 60bc 60c1 60c5 60c7
60d3 60d5 60d7 60db 60de 60e0 60e4 60e8
60eb 60ef 60f3 60f6 60f7 60f9 60fc 60ff
6100 6105 6109 610d 6111 6114 6115 6117
611a 611b 611d 6120 6123 6126 6127 612c
6130 6134 6138 613c 613d 613f 6143 6145
6149 614d 6151 6155 6156 6158 615c 615e
6162 6166 6169 616b 616f 6172 6174 6178
617b 617d 6181 6184 6186 618a 618d 6191
6195 6198 619b 619e 619f 61a4 61a8 61ac
61af 61b2 61b6 61b8 61bc 61bf 61c1 61c5
61c8 61cc 61d0 61d3 61d7 61db 61de 61e1
61e6 61e9 61ec 61ef 61f0 61f5 61f6 1
61f8 61fd 6201 6205 6208 620d 6212 6215
6219 621a 621f 6222 6227 6228 622d 6230
6235 6236 623b 623e 6242 6246 624a 624e
6251 6252 6254 6259 625a 625c 625d 6262
6265 626a 626b 6270 6273 6278 6279 627e
6281 6285 6286 628b 628e 6293 6294 6299
629a 629f 62a1 62a5 62a8 62ac 62b0 62b3
62b7 62bb 62be 62c2 62c6 62c7 62cc 62ce
62d2 62d6 62d9 62dd 62e1 62e4 62e8 62ec
62ef 62f2 62f7 62fa 62fd 6300 6301 6306
6307 1 6309 630e 6312 6316 6319 631e
6323 6326 632a 632b 6330 6331 6336 633a
633e 6341 6346 634b 634e 6352 6356 6359
635a 635f 6362 6367 6368 636d 6370 6374
6378 637b 637c 6381 6382 6387 6389 638d
6390 6394 6398 639c 63a0 63a4 63a8 63ac
63b0 63b4 63c0 63c5 63c9 63cd 63d1 63d5
63d7 63d8 63dd 1 63e1 63e5 63e9 63ec
63f0 63f4 63f8 63fc 63ff 6403 6407 640a
640d 6412 6415 6418 641b 641c 6421 6422
1 6424 6429 642d 6431 6434 6439 643e
6441 6445 6446 644b 644c 6451 6455 6459
645c 6461 6466 6469 646d 646e 6473 6476
647b 647c 6481 6484 6488 648c 648f 6492
6493 6495 6496 649b 649c 64a1 64a3 64a7
64aa 64ae 64b2 64b6 64ba 64be 64c2 64c6
64d2 64d7 64db 64df 64e3 64e7 64e9 64ed
64ef 64fb 64fd 64ff 6500 6505 6509 650b
6517 651b 651d 651e 6527 
1cc5
2
0 1 a 6 9 :3 6 12 :3 6
11 :3 6 12 :3 6 13 :3 6 10 :3 6
17 :3 6 15 :3 6 1a :3 6 b :3 6
10 :3 6 c :3 6 16 :3 6 18 :3 6
19 :3 6 1b :3 6 17 :3 6 16 :3 6
17 :3 6 17 :3 6 12 :2 6 1 3
a 13 a :2 1 4 13 1c 1b
:2 13 :2 4 10 19 18 :2 10 :2 4 e
17 16 :2 e :2 4 e 17 16 :2 e
:2 4 f 18 17 :2 f :2 4 e 17
16 :2 e :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 f 18 17
:2 f :2 4 c 15 14 :2 c :2 4 12
1b 1a :2 12 :2 4 11 1a 19 :2 11
:2 4 e 17 16 :2 e :2 4 f 18
17 :2 f :2 4 :2 e 1d e :2 4 :2 14
23 14 :2 4 :2 b 1a b :2 4 :2 a
19 a :2 4 :2 b 1a b :2 4 :2 e
1d e :2 4 :2 13 22 13 :2 4 :2 c
1b c :2 4 :2 e 1d e :2 4 :2 13
22 13 :2 4 :2 d 1c d :2 4 :2 c
1b c :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 10 1f 10 :2 4 :2 12
21 12 :2 4 :3 10 :2 4 :3 f :2 4 18
21 20 :2 18 :2 4 18 21 20 :2 18
:2 4 f 18 17 :2 f :2 4 :3 11 :2 4
:3 f :2 4 :3 13 :2 4 :3 10 :2 4 :3 d :2 4
:3 e :2 4 14 1d 1c :2 14 :2 4 :2 11
20 11 :2 4 :2 f 1e f :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 :2 12
21 12 :2 4 :2 12 21 12 :2 4 :2 a
19 a :2 4 :3 9 :2 4 :3 9 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 :2 f
1e f :2 4 :2 16 25 16 :2 4 :2 11
20 11 :2 4 :2 14 23 14 4 7
e 0 :2 7 20 2d 33 3b 56
5c 64 f 10 1d 2e 3b 13
2d a :6 7 e 0 :2 7 11 1c
26 f 10 1d 2e 42 18 23
a :5 7 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 55 5b 5e :2 55
6c 83 8 :2 6c d 10 :2 6c 13
16 :2 6c b e :2 6c 13 16 1f
27 :2 1f 35 :2 16 :2 6c b e :2 6c
13 16 :2 6c 1b 1e :2 6c 29 2c
:2 6c b e :2 6c 13 16 :2 6c 1b
1e :2 6c 2a 2d :2 6c b e :2 6c
13 16 :2 6c 1b 1e :2 6c 2b 2e
:2 6c b e :2 6c 13 16 1f 27
:2 1f 33 :2 16 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 2f 32 :2 6c
b e :2 6c 13 16 1f 27 :2 1f
38 :2 16 :2 6c b e :2 6c 13 16
1f 27 :2 1f 3d :2 16 :2 6c b e
:2 6c 13 16 1f 27 :2 1f 2e :2 16
:2 6c b e :2 6c 13 16 1f 27
:2 1f 33 :2 16 :2 6c b e :2 6c 13
16 1f 27 :2 1f 2f :2 16 :2 6c b
e :2 6c 13 16 1f 27 :2 1f 39
:2 16 :2 6c b e :2 6c 13 16 :2 6c
1b 1e :2 6c 30 33 :2 6c b e
:2 6c 13 16 :2 6c 1b 1e :2 6c 31
34 :2 6c b e :2 6c 13 16 1f
27 :2 1f 3e :2 16 :2 6c b e :2 6c
13 16 1f 27 :2 1f 3a :2 16 :2 6c
b e :2 6c 13 16 :2 6c 1b 1e
:2 6c 2e 31 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 2f 32 :2 6c
b e :2 6c 13 16 1f 27 :2 1f
3a :2 16 :2 6c b e :2 6c 13 16
:2 6c 1b 1e :2 6c 2a 2d :2 6c 32
35 :2 6c :2 7 4b :2 4 7 :2 11 23
:2 2d 39 3c 4d 50 51 :2 4d :2 23
:3 7 :2 d 12 1e 5e 61 :2 1e :2 7
54 :2 4 :4 9 8 7 24 2d 3a
:2 24 3d 3f :2 3d 23 46 a 17
:2 46 1a 1c :2 1a 45 :2 23 22 :2 7
a :2 14 26 :2 30 3c 3f 50 53
54 :2 50 :2 26 :3 a :2 10 15 21 61
64 :2 21 71 74 :2 21 78 7b :2 21
85 88 91 99 :2 a2 :2 91 b3 :2 88
:2 21 :2 a 57 :2 7 a :2 14 26 :2 30
3c 3f 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 61 64 :2 21 :2 a 57
:3 7 :2 12 28 :2 31 41 :2 7 20 :2 4
:4 9 8 7 :4 1b 1a 19 :2 7 :4 34
33 32 :2 7 a :2 14 26 :2 30 3c
3f 50 53 54 :2 50 :2 26 :3 a :2 10
15 21 61 64 :2 21 71 74 :2 21
78 7b :2 21 85 88 91 99 :2 a2
:2 91 b3 :2 88 :2 21 :2 a 57 :2 7 a
:2 14 26 :2 30 3c 3f 50 53 54
:2 50 :2 26 :3 a :2 10 15 21 61 64
:2 21 :2 a 57 :3 7 :2 12 28 :2 31 41
:2 7 4a :3 4 16 :2 4 10 :2 4 17
:2 4 12 :2 4 13 :2 4 17 :2 4 12
:2 4 10 :2 4 13 :2 4 15 :2 4 f
:2 4 16 :2 4 15 :2 4 14 4 7
10 17 :2 10 29 :2 7 2e 2c :2 37
:2 2c b 14 23 :2 b 26 28 :2 26
a 2f 38 47 :2 2f 4a 4c :2 4a
2e :2 a :4 e d 10 :2 1a 2c :2 36
42 45 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 67 6a :2 27 77 7a
:2 27 7e 81 :2 27 8b 8e 97 9f
:2 a8 :2 97 b9 :2 8e :2 27 :2 10 5d :2 d
10 :2 1a 2c :2 36 42 45 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 :2 10 5d :3 d :2 18 2e :2 37
47 :2 d 22 :3 a 1b :2 a 17 :2 a
18 a 14 20 2d 3b 12 20
2d :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5a 5d 5e :2 5a :2 2f :3 13 :2 19
1e 2a 6a 6d :2 2a 7a 7d :2 2a
81 84 :2 2a 90 93 :2 2a 9b 9e
:2 2a aa ad b4 bd c0 :2 ad :2 2a
:2 13 61 :2 10 :2 d :4 19 :2 d a :3 4f
a :3 15 :2 a 1a 23 2c 37 :2 23
:2 1a :2 a :2 13 1f 2e 3c 47 52
61 27 :2 1f a e :2 17 20 22
:2 20 d 2a 33 42 :2 2a 45 47
:2 45 29 :2 d 4f 58 62 :2 4f 65
67 :2 65 4e :3 d 1b d 17 27
37 2e 16 23 34 41 :2 10 :2 19
25 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5d 60
61 :2 5d :2 32 :3 16 :2 1c 21 2d 6d
70 :2 2d 7d 80 :2 2d 84 87 :2 2d
93 96 :2 2d 9e a1 :2 2d ad b0
b7 c0 c3 :2 b0 :2 2d :2 16 64 :2 13
:2 10 :4 1c :2 10 d :3 6a 10 19 25
:2 10 28 2b :2 28 10 21 :2 10 1c
:2 10 23 10 :4 14 13 1d 2a 35
42 63 74 :2 16 :2 1f 2b 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 63 66 67 :2 63 :2 38
:3 1c :2 22 27 33 73 76 :2 33 83
86 :2 33 8a 8d :2 33 99 9c :2 33
a4 a7 :2 33 b3 b6 bd c6 c9
:2 b6 :2 33 :2 1c 6a :2 19 :2 16 :4 22 :2 16
13 :4 2c :2 10 2d :2 d 6a :2 a e
17 26 :2 e 29 2b :2 29 d 33
3e 47 52 :2 3e :2 33 32 57 5a
:2 57 :3 d 1e d 5c :2 a 4f a
15 a 14 20 29 36 43 d
18 22 2d 3b 12 20 2b 3a
49 d 1e 26 31 41 12 29
3d :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5a 5d 5e :2 5a :2 2f :3 13 :2 19
1e 2a 6a 6d :2 2a 7a 7d :2 2a
81 84 :2 2a 90 93 :2 2a 9b 9e
:2 2a aa ad b4 bd c0 :2 ad :2 2a
:2 13 61 :2 10 :2 d :4 19 :2 d a :3 7
e :2 17 22 20 :2 2b :2 20 d 40
49 59 :2 40 5f 5c 10 1f :2 5f
:2 5c 3f :3 d 1f :2 d 18 19 :2 18
d 23 :2 a :4 7 a 13 22 :2 a
25 28 :2 25 d :2 16 1f 22 :2 1f
10 :2 1a 2c :2 36 42 46 57 5a
5b :2 57 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8b 8e 97 9f :2 a8 :2 97 b3 :2 8e
:2 27 bb be :2 27 c6 c9 :2 27 ce
d1 :2 27 d9 dc :2 27 :2 10 5e :2 d
10 :2 1a 2c :2 36 42 45 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 :2 10 5d :3 d :2 18 2c :2 35
3f 48 :2 d 24 :2 a :4 e d :4 26
25 :2 d :4 3f 3e :2 d :4 14 13 :2 d
10 :2 1a 2c :2 36 42 45 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8b 8e 97 9f :2 a8 :2 97 b9 :2 8e
:2 27 :2 10 5d :2 d 10 :2 1a 2c :2 36
42 45 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 67 6a :2 27 :2 10 5d
:3 d :2 18 2e :2 37 47 :2 d 2d :3 a
1c :2 25 a d 16 1f :2 d 22
24 :2 22 d 18 d 2e :2 a 14
1d 37 46 54 61 :2 d :2 16 22
d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5a 5d 5e
:2 5a :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 90
93 :2 2a 9b 9e :2 2a aa ad b4
bd c0 :2 ad :2 2a :2 13 61 :2 10 :2 d
:4 19 :2 d a :3 2a d 16 1e :2 d
21 23 :2 21 d 1b 23 2c 34
:2 23 37 39 42 4d :2 39 :2 23 22
51 53 :2 22 21 5a 5c :2 21 :2 1b
d 10 19 22 :2 10 28 25 31
3d :2 28 :2 25 10 1a :2 10 1d 10
40 10 1b 10 :4 d 25 :3 a 18
a e 15 1e 29 :2 15 2d :2 e
d 32 34 :2 32 10 19 28 :2 10
2b 2d :2 2b 13 1c 2c :2 13 2f
31 :2 2f 13 :2 1c 28 35 3e 4a
56 67 25 32 3c 44 4c 54
25 35 40 50 25 36 :2 28 13
16 :2 1f 28 2a :2 28 20 35 3b
19 2a 36 48 55 65 1f 2c
3d 47 55 63 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 66
69 6a :2 66 :2 3b :3 1f :2 25 2a 36
76 79 :2 36 86 89 :2 36 8d 90
:2 36 9c 9f :2 36 a7 aa :2 36 b6
b9 c0 c9 cc :2 b9 :2 36 :2 1f 6d
:2 1c :2 19 :4 25 :2 19 16 :4 2c :2 13 33
13 :2 1c 28 35 3e 4a 56 67
25 32 3c 44 4c 54 25 35
40 50 25 36 :2 28 13 :4 10 2f
10 22 2b 3b :2 22 3e 40 :2 22
10 13 1c 2c :2 13 2f 31 :2 2f
13 :2 1c 28 35 3e 4a 56 67
25 32 3c 44 4c 54 25 35
40 50 25 36 :2 28 13 16 :2 1f
28 2a :2 28 20 35 3b 19 2a
36 48 55 65 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 66 69 6a :2 66 :2 3b :3 1f :2 25
2a 36 76 79 :2 36 86 89 :2 36
8d 90 :2 36 9c 9f :2 36 a7 aa
:2 36 b6 b9 c0 c9 cc :2 b9 :2 36
:2 1f 6d :2 1c :2 19 :4 25 :2 19 16 :4 2c
:2 13 33 13 :2 1c 28 35 3e 4a
56 67 25 32 3c 44 4c 54
25 35 40 50 25 36 :2 28 13
:4 10 :4 d 11 :2 1a 23 25 :2 23 10
2e 35 3e 49 :2 35 4d :2 2e 2d
51 53 :2 51 2c :2 10 14 1d 2d
:2 14 32 30 3b 46 :2 32 :2 30 13
4f 58 5e :2 4f 61 63 :2 61 4e
:2 13 6b 2c 41 :2 6b 44 46 :2 44
6a :2 13 1d 32 46 16 22 2b
3a 16 27 33 45 52 62 16
25 31 41 16 24 16 :2 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 63 66 67 :2 63 :2 38
:3 1c :2 22 27 33 73 76 :2 33 83
86 :2 33 8a 8d :2 33 99 9c :2 33
a4 a7 :2 33 b3 b6 bd c6 c9
:2 b6 :2 33 :2 1c 6a :2 19 :2 16 :4 22 :2 16
13 :3 4d 1d 32 3f 4a 1c 29
3a 4e 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 63 66 67
:2 63 :2 38 :3 1c :2 22 27 33 73 76
:2 33 83 86 :2 33 8a 8d :2 33 99
9c :2 33 a4 a7 :2 33 b3 b6 bd
c6 c9 :2 b6 :2 33 :2 1c 6a :2 19 :2 16
:4 22 :2 16 13 :3 4d 1d 32 43 1c
30 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 63 66 67 :2 63
:2 38 :3 1c :2 22 27 33 73 76 :2 33
83 86 :2 33 8a 8d :2 33 99 9c
:2 33 a4 a7 :2 33 b3 b6 bd c6
c9 :2 b6 :2 33 :2 1c 6a :2 19 :2 16 :4 22
:2 16 13 :4 4d 1d 32 38 16 27
33 45 52 62 1c 30 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 63 66 67 :2 63 :2 38 :3 1c :2 22
27 33 73 76 :2 33 83 86 :2 33
8a 8d :2 33 99 9c :2 33 a4 a7
:2 33 b3 b6 bd c6 c9 :2 b6 :2 33
:2 1c 6a :2 19 :2 16 :4 22 :2 16 13 :7 10
56 :2 d 37 d 1c 23 2c 39
:2 23 3d :2 46 :2 1c d 10 19 28
:2 10 2b 2d :2 2b 10 :2 19 25 32
3b 47 53 64 25 32 3c 44
4c 54 25 35 40 50 25 36
:2 25 10 14 :2 1d 26 28 :2 26 13
30 39 44 :2 30 47 49 :2 47 2f
:2 13 51 5a 63 :2 51 66 68 :2 66
50 :2 13 1d 32 38 16 27 33
45 52 62 1c 29 3a 44 52
60 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 63 66 67 :2 63
:2 38 :3 1c :2 22 27 33 73 76 :2 33
83 86 :2 33 8a 8d :2 33 99 9c
:2 33 a4 a7 :2 33 b3 b6 bd c6
c9 :2 b6 :2 33 :2 1c 6a :2 19 :2 16 :4 22
:2 16 13 :4 6b :2 10 2f :4 14 :2 13 20
13 1d 24 3e 45 5f 66 80
87 9c ab :2 16 :2 1f 2b 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 63 66 67 :2 63 :2 38
:3 1c :2 22 27 33 73 76 :2 33 83
86 :2 33 8a 8d :2 33 99 9c :2 33
a4 a7 :2 33 b3 b6 bd c6 c9
:2 b6 :2 33 :2 1c 6a :2 19 :2 16 :4 22 :2 16
13 :3 33 16 :2 21 29 34 3e :2 16
42 44 :2 42 16 23 :2 2c :2 16 26
16 20 30 1e 1f :2 19 :2 22 2e
19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 69 6a
:2 66 :2 3b :3 1f :2 25 2a 36 76 79
:2 36 86 89 :2 36 8d 90 :2 36 9c
9f :2 36 a7 aa :2 36 b6 b9 c0
c9 cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19
:4 25 :2 19 16 :3 46 16 29 3b 49
54 62 6d 28 :2 29 16 19 22
33 :2 19 36 38 :2 36 19 26 :2 19
27 :2 19 2b :2 19 27 :2 19 28 :2 19
1e :3 19 1f 2c 3c :3 19 1c 24
:2 1c :2 25 31 1c 2a 1c :2 25 31
1c :4 19 1c 22 :3 1c :2 25 31 1c
19 :2 21 1f :2 28 34 1f 22 :2 2c
3e :2 48 54 58 69 6c 6d :2 69
:2 3e :3 22 :2 28 2d 39 79 7c :2 39
89 8c :2 39 90 93 :2 39 9f a2
:2 39 aa ad :2 39 b9 bc c3 cc
cf :2 bc :2 39 :2 22 70 :2 1f :2 1c :4 28
:2 1c 19 :3 3a 23 32 43 22 30
:2 1c :2 25 31 1c 19 :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
69 6c 6d :2 69 :2 3e :3 22 :2 28 2d
39 79 7c :2 39 89 8c :2 39 90
93 :2 39 9f a2 :2 39 aa ad :2 39
b9 bc c3 cc cf :2 bc :2 39 :2 22
70 :2 1f :2 1c :4 28 :2 1c 19 :3 3a 19
26 :2 19 26 :2 19 26 2d 37 3a
:2 2d 47 4a :2 26 :2 19 26 2d 37
3a :2 2d 4b 4e :2 26 :2 19 26 2d
37 3a :2 2d 4a 4d :2 26 :2 19 26
2d 37 22 :2 2d 24 27 :2 26 :2 19
2c 3a 46 52 5a 62 6e 24
2f 3a 46 52 5e 24 2f 3b
:2 2c 19 1c :2 26 38 :2 42 4e 52
63 66 67 :2 63 :2 38 :3 1c :2 22 27
33 73 76 :2 33 83 86 :2 33 8a
8d :2 33 97 9a a3 ab :2 a3 af
:2 9a :2 33 b7 ba :2 33 c2 c5 :2 33
ca cd :2 33 d5 d8 :2 33 :2 1c 6a
:2 19 1c :2 26 38 :2 42 4e 51 62
65 66 :2 62 :2 38 :3 1c :2 22 27 33
73 76 :2 33 :2 1c 69 :3 19 :2 24 38
3b 44 :2 19 3a :2 16 46 :2 13 33
:3 10 22 2b 3b :2 22 3e 40 :2 22
:2 10 :2 19 25 32 3b 47 53 64
25 32 3c 44 4c 54 25 35
40 50 25 36 :2 25 10 14 :2 1d
26 28 :2 26 13 30 39 44 :2 30
47 49 :2 47 2f :2 13 51 5a 63
:2 51 66 68 :2 66 50 :2 13 1d 32
38 16 27 33 45 52 62 1c
30 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 63 66 67 :2 63
:2 38 :3 1c :2 22 27 33 73 76 :2 33
83 86 :2 33 8a 8d :2 33 99 9c
:2 33 a4 a7 :2 33 b3 b6 bd c6
c9 :2 b6 :2 33 :2 1c 6a :2 19 :2 16 :4 22
:2 16 13 :4 6b :2 10 :4 d :4 a d :2 16
1f 22 :2 1f 10 :2 1a 2c :2 36 42
46 57 5a 5b :2 57 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8b 8e 97 9f :2 a8
:2 97 b3 :2 8e :2 27 bb be :2 27 c6
c9 :2 27 ce d1 :2 27 d9 dc :2 27
:2 10 5e :2 d 10 :2 1a 2c :2 36 42
45 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 :2 10 5d :3 d
:2 18 2c :2 35 3f 48 :2 d 24 :3 a
1c a e 17 20 :2 e 23 26
:2 23 d 32 3b 4b :2 32 4e 50
:2 4e 31 :3 d 1f d 53 :2 a d
16 25 :2 d 28 2a :2 28 11 18
21 2c :2 18 30 :2 11 10 35 37
:2 35 :4 14 13 :4 17 16 20 35 49
19 25 2e 3d 19 2a 36 48
55 65 19 28 19 29 19 27
1f 33 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 69 6a
:2 66 :2 3b :3 1f :2 25 2a 36 76 79
:2 36 86 89 :2 36 8d 90 :2 36 9c
9f :2 36 a7 aa :2 36 b6 b9 c0
c9 cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19
:4 25 :2 19 16 :4 33 20 35 49 19
25 19 28 1f 33 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
66 69 6a :2 66 :2 3b :3 1f :2 25 2a
36 76 79 :2 36 86 89 :2 36 8d
90 :2 36 9c 9f :2 36 a7 aa :2 36
b6 b9 c0 c9 cc :2 b9 :2 36 :2 1f
6d :2 1c :2 19 :4 25 :2 19 16 :7 13 2f
:4 17 16 20 35 49 19 25 2e
3d 19 35 51 5e 76 19 36
52 5f 78 19 38 54 6e 19
34 50 66 19 2b 19 2c 19
2e 19 2a 19 2b 19 2c 19
2e 19 2a 19 2a 38 49 57
68 76 87 :2 19 2a 36 48 55
65 19 28 19 29 19 27 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 66 69 6a :2 66
:2 3b :3 1f :2 25 2a 36 76 79 :2 36
86 89 :2 36 8d 90 :2 36 9c 9f
:2 36 a7 aa :2 36 b6 b9 c0 c9
cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19 :4 25
:2 19 16 :4 33 20 35 49 19 25
2e 3d 19 35 51 5e 76 19
36 52 5f 78 19 38 54 6e
19 34 50 66 19 2b 19 2c
19 2e 19 2a 19 2b 19 2c
19 2e 19 2a 19 2a 38 49
57 68 76 87 19 1f 33 19
20 1c 28 :3 26 1c :2 25 31 1c
2d 1c :2 25 31 1c :4 19 16 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 66 69 6a :2 66 :2 3b :3 1f
:2 25 2a 36 76 79 :2 36 86 89
:2 36 8d 90 :2 36 9c 9f :2 36 a7
aa :2 36 b6 b9 c0 c9 cc :2 b9
:2 36 :2 1f 6d :2 1c :2 19 :4 25 :2 19 16
:7 13 :4 10 d 3a 13 1c 25 :2 13
28 2a :2 28 1a 2f 43 13 1f
13 22 19 2d 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 60
63 64 :2 60 :2 35 :3 19 :2 1f 24 30
70 73 :2 30 80 83 :2 30 87 8a
:2 30 96 99 :2 30 a1 a4 :2 30 b0
b3 ba c3 c6 :2 b3 :2 30 :2 19 67
:2 16 :2 13 :4 1f :2 13 10 :4 2c 3a :2 d
2c 11 18 21 2c :2 18 30 :2 11
10 35 37 :2 35 :4 14 13 :4 17 16
20 35 49 19 25 2e 3d 19
2a 36 48 55 65 19 28 19
29 19 27 1f 33 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
66 69 6a :2 66 :2 3b :3 1f :2 25 2a
36 76 79 :2 36 86 89 :2 36 8d
90 :2 36 9c 9f :2 36 a7 aa :2 36
b6 b9 c0 c9 cc :2 b9 :2 36 :2 1f
6d :2 1c :2 19 :4 25 :2 19 16 :4 33 20
35 49 19 25 2e 3d 19 27
1f 33 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 69 6a
:2 66 :2 3b :3 1f :2 25 2a 36 76 79
:2 36 86 89 :2 36 8d 90 :2 36 9c
9f :2 36 a7 aa :2 36 b6 b9 c0
c9 cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19
:4 25 :2 19 16 :7 13 2f :4 17 16 20
35 49 19 25 2e 3d 19 35
51 5e 76 19 36 52 5f 78
19 38 54 6e 19 34 50 66
19 2b 19 2c 19 2e 19 2a
19 2b 19 2c 19 2e 19 2a
19 2a 38 49 57 68 76 87
:2 19 2a 36 48 55 65 19 28
19 29 19 27 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 66 69 6a :2 66 :2 3b :3 1f :2 25
2a 36 76 79 :2 36 86 89 :2 36
8d 90 :2 36 9c 9f :2 36 a7 aa
:2 36 b6 b9 c0 c9 cc :2 b9 :2 36
:2 1f 6d :2 1c :2 19 :4 25 :2 19 16 :4 33
20 35 49 19 25 2e 3d 19
27 19 35 51 5e 76 19 36
52 5f 78 19 38 54 6e 19
34 50 66 19 2b 19 2c 19
2e 19 2a 19 2b 19 2c 19
2e 19 2a 19 2a 38 49 57
68 76 87 19 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 66 69 6a :2 66 :2 3b :3 1f :2 25
2a 36 76 79 :2 36 86 89 :2 36
8d 90 :2 36 9c 9f :2 36 a7 aa
:2 36 b6 b9 c0 c9 cc :2 b9 :2 36
:2 1f 6d :2 1c :2 19 :4 25 :2 19 16 :7 13
:4 10 d 3a 13 1c 25 :2 13 28
2a :2 28 :4 14 13 16 1f 25 :2 16
28 2a :2 28 20 35 49 19 25
2e 3d 19 27 19 1f 2a 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 66 6a 6b :2 66
:2 3b :3 1f :2 25 2a 36 77 7a :2 36
87 8a :2 36 8e 91 :2 36 9d a0
:2 36 a8 ab :2 36 b7 ba c1 ca
cd :2 ba :2 36 :2 1f 6e :2 1c :2 19 :4 25
:2 19 16 :4 2c 20 35 49 19 25
2e 3d 19 27 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 66 6a 6b :2 66 :2 3b :3 1f :2 25
2a 36 77 7a :2 36 87 8a :2 36
8e 91 :2 36 9d a0 :2 36 a8 ab
:2 36 b7 ba c1 ca cd :2 ba :2 36
:2 1f 6e :2 1c :2 19 :4 25 :2 19 16 :7 13
31 1d 32 46 16 22 2b 3a
16 24 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 63
67 68 :2 63 :2 38 :3 1c :2 22 27 33
74 77 :2 33 84 87 :2 33 8b 8e
:2 33 9a 9d :2 33 a5 a8 :2 33 b4
b7 be c7 ca :2 b7 :2 33 :2 1c 6b
:2 19 :2 16 :4 22 :2 16 13 :7 10 2c 3a
:2 d :4 a :4 f e 30 39 4b :2 30
4e 50 :2 4e 2f :2 e d 58 10
20 :2 58 23 25 :2 23 57 :3 d 1b
:2 d 1b :2 d 18 :2 d 18 d 10
19 28 :2 10 2b 2d :2 2b 1a 2d
39 42 4a 51 67 6f 76 8d
97 a8 b6 18 2d 37 42 48
4e 5a 6d 79 18 19 2d :2 13
:2 1c 28 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 60
64 65 :2 60 :2 35 :3 19 :2 1f 24 30
71 74 :2 30 81 84 :2 30 88 8b
:2 30 97 9a :2 30 a2 a5 :2 30 b1
b4 bb c4 c7 :2 b4 :2 30 :2 19 68
:2 16 :2 13 :4 1f :2 13 10 :4 2f 10 27
10 1a 26 2f 37 3e 54 5c
63 7a 84 95 a3 18 22 2d
33 39 45 58 64 18 19 2d
:2 13 :2 1c 28 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
60 64 65 :2 60 :2 35 :3 19 :2 1f 24
30 71 74 :2 30 81 84 :2 30 88
8b :2 30 97 9a :2 30 a2 a5 :2 30
b1 b4 bb c4 c7 :2 b4 :2 30 :2 19
68 :2 16 :2 13 :4 1f :2 13 10 :7 d 11
:2 1a 25 23 :2 2e :2 23 10 14 1d
2d :2 14 32 30 3b 46 :2 32 :2 30
13 4f 58 5e :2 4f 61 63 :2 61
4e :2 13 6b 2c 41 :2 6b 44 46
:2 44 6a :2 13 1d 32 3f 4a 1c
29 3a 4e 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 63 67
68 :2 63 :2 38 :3 1c :2 22 27 33 74
77 :2 33 84 87 :2 33 8b 8e :2 33
9a 9d :2 33 a5 a8 :2 33 b4 b7
be c7 ca :2 b7 :2 33 :2 1c 6b :2 19
:2 16 :4 22 :2 16 13 :3 4d 1d 32 40
16 2f 33 42 1c 29 3a 4e
1c 30 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 63 67 68
:2 63 :2 38 :3 1c :2 22 27 33 74 77
:2 33 84 87 :2 33 8b 8e :2 33 9a
9d :2 33 a5 a8 :2 33 b4 b7 be
c7 ca :2 b7 :2 33 :2 1c 6b :2 19 :2 16
:4 22 :2 16 13 :4 4d 13 18 :4 13 1c
25 30 3d :3 16 19 1d :2 19 :2 22
2e 19 23 19 :2 22 2e 19 :4 16
19 :2 22 2b 2e :2 2b :2 19 30 :3 16
21 2a 33 :2 21 36 38 41 4c
:2 38 :2 21 16 19 22 2b :2 19 2e
30 :2 2e 1c 25 2e :2 1c 33 31
3c 4b :2 33 :2 31 1f 28 33 :2 1f
39 36 42 51 :2 39 :2 36 1f 2c
35 44 :2 2c 1f 54 1f 2c 35
44 :2 2c 47 49 52 5b :2 49 :2 2c
5e 60 69 74 :2 60 :2 2c 1f :4 1c
4e :2 19 23 38 45 50 71 1c
23 1f 2b :3 29 1f :2 28 34 1f
30 1f :2 28 34 1f :4 1c 19 :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 69 6d 6e :2 69 :2 3e :3 22
:2 28 2d 39 7a 7d :2 39 8a 8d
:2 39 91 94 :2 39 a0 a3 :2 39 ab
ae :2 39 ba bd c4 cd d0 :2 bd
:2 39 :2 22 71 :2 1f :2 1c :4 28 :2 1c 19
:3 32 19 27 19 32 :2 16 19 22
2b :2 19 31 2e 3a 49 :2 31 :2 2e
:2 19 4c :2 16 13 17 10 16 1c
:3 16 :2 1f 2b 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
63 67 68 :2 63 :2 38 :3 1c :2 22 27
33 74 77 :2 33 84 87 :2 33 8b
8e :2 33 9a 9d :2 33 a5 a8 :2 33
b4 b7 be c7 ca :2 b7 :2 33 :2 1c
6b :2 19 :2 16 :4 22 :2 16 13 :3 10 17
20 29 :2 17 2c 2e :2 2c 16 :4 37
36 35 :2 16 20 35 46 57 6b
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 66 6a 6b :2 66 :2 3b
:3 1f :2 25 2a 36 77 7a :2 36 87
8a :2 36 8e 91 :2 36 9d a0 :2 36
a8 ab :2 36 b7 ba c1 ca cd
:2 ba :2 36 :2 1f 6e :2 1c :2 19 :4 25 :2 19
16 :4 50 :2 13 :4 10 13 1c 2b :2 13
2e 30 :2 2e 17 1e 27 32 :2 1e
36 :2 17 16 3b 3d :2 3b 16 29
3c 51 :2 29 16 40 16 29 3c
51 :2 29 16 :4 13 32 :2 10 3e :2 d
28 :2 a 2a :2 7 a :2 13 1c 1e
:2 1c a :2 13 1f a 22 :2 7 4f
:2 4 7 :2 11 23 :2 2d 39 3c 4d
51 52 :2 4d :2 23 :3 7 :2 d 12 1e
5f 62 :2 1e 6f 72 :2 1e 76 79
:2 1e 83 86 8f 97 :2 a0 :2 8f ab
:2 86 :2 1e b3 b6 :2 1e be c1 :2 1e
c6 c9 :2 1e cc cf :2 1e :2 7 55
:3 4 :2 f 21 :2 2a 34 38 :2 4 1
9 12 9 a :2 14 26 :2 30 3c
40 51 55 56 :2 51 :2 26 :3 a :2 10
15 21 62 65 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 59 :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 4e 52 53 :2 4e :2 23 :3 7 :2 d
12 1e 5f 62 :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 56
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
1cc5
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 :4 14
:4 15 :4 16 :4 17 2
:4 18 :2 1 :7 1a :7 1b
:7 1c :7 1d :7 1e :7 1f
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :7 26 :7 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:5 38 :5 39 :7 3a :7 3b
:7 3c :5 3d :5 3e :5 3f
:5 40 :5 41 :5 42 :7 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :5 4b
:5 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :2 54
0 :2 54 :7 55 56
:4 57 :2 58 55 :5 54
:2 5a 0 :2 5a :3 5b
5c :4 5d :2 5e 5b
:5 5a :7 60 :b 62 :11 63
64 :2 63 :2 64 :2 63
:2 64 :2 63 :2 65 :2 63
:9 65 :2 63 :2 66 :2 63
:2 66 :2 63 :2 66 :2 63
:2 66 :2 63 :2 67 :2 63
:2 67 :2 63 :2 67 :2 63
:2 67 :2 63 :2 68 :2 63
:2 68 :2 63 :2 68 :2 63
:2 68 :2 63 :2 69 :2 63
:9 69 :2 63 :2 6a :2 63
:2 6a :2 63 :2 6a :2 63
:2 6a :2 63 :2 6b :2 63
:9 6b :2 63 :2 6c :2 63
:9 6c :2 63 :2 6d :2 63
:9 6d :2 63 :2 6e :2 63
:9 6e :2 63 :2 6f :2 63
:9 6f :2 63 :2 70 :2 63
:9 70 :2 63 :2 71 :2 63
:2 71 :2 63 :2 71 :2 63
:2 71 :2 63 :2 72 :2 63
:2 72 :2 63 :2 72 :2 63
:2 72 :2 63 :2 73 :2 63
:9 73 :2 63 :2 74 :2 63
:9 74 :2 63 :2 75 :2 63
:2 75 :2 63 :2 75 :2 63
:2 75 :2 63 :2 76 :2 63
:2 76 :2 63 :2 76 :2 63
:2 76 :2 63 :2 77 :2 63
:9 77 :2 63 :2 78 :2 63
:2 78 :2 63 :2 78 :2 63
:2 78 :2 63 :2 78 :4 63
:3 62 :11 7b :b 7c :3 7b
:11 7f :2 80 :2 7f :4 80
:6 7f :11 81 :20 82 :3 81
:11 84 :b 85 :3 84 :9 87
80 :2 7f :16 8a :11 8b
:20 8c :3 8b :11 8e :b 8f
:3 8e :9 91 :3 8a :3 96
:3 97 :3 98 :3 99 :3 9a
:3 9b :3 9c :3 9d :3 9e
:3 9f :3 a0 :3 a1 :3 a2
:3 a3 :e a7 :16 a8 :5 aa
:11 ab :20 ac :3 ab :11 ae
:b af :3 ae :9 b1 :3 aa
:3 b4 :3 b5 :3 b6 :4 b9
:3 ba b9 :5 bb b8
:2 bd :5 bf :11 c0 :24 c1
:3 c0 :2 be :6 bd bc
:3 a8 :5 c6 :a c7 :9 c9
ca :3 c9 :20 cd :3 ce
:3 d0 d1 :4 d2 d0
:5 d3 cf :2 d5 :5 d7
:11 d8 :24 d9 :3 d8 :2 d6
:6 d5 d4 :3 cd :9 de
:3 df :3 e0 :3 e1 :5 e3
:7 e5 :5 e6 e4 :2 e8
:5 ea :11 eb :24 ec :3 eb
:2 e9 :6 e8 e7 :6 e3
:3 de :3 cd :19 f5 :3 f6
:3 f5 a8 :3 f9 :5 fc
:5 fd :5 fe :5 ff :3 100
fc :5 101 fb :2 103
:5 105 :11 106 :24 107 :3 106
:2 104 :6 103 102 :3 f8
:11 10d :2 10e :7 10d :3 10f
:6 110 10e :2 10d f8
:3 a8 :9 115 :7 116 :11 117
:30 118 :3 117 :11 11a :b 11b
:3 11a :a 11d :3 116 :13 121
:5 122 :2 121 :11 123 :20 124
:3 123 :11 126 :b 127 :3 126
:9 129 122 :2 121 :5 12c
:9 12f :3 130 :3 12f :7 137
:5 138 136 :2 13a :5 13c
:11 13d :24 13e :3 13d :2 13b
:6 13a 139 :3 115 :9 143
:1c 145 :d 147 :3 148 :3 149
147 :3 14b 14a :3 147
:3 143 :3 168 :e 16a :9 16b
:9 16c :9 16d :6 16e :4 16f
:2 170 :3 16d :7 173 :3 175
:6 176 :6 177 175 :6 178
:5 179 178 :5 17b 17a
:3 178 174 :2 17e :5 180
:11 181 :24 182 :3 181 :2 17f
:6 17e 17d :6 173 16c
:9 188 :6 189 :4 18a :2 18b
:3 188 187 :3 16c 16b
:b 18f :9 190 :9 191 :6 192
:4 193 :2 194 :3 191 :7 197
:3 199 :6 19a :2 19b 199
:6 19c :5 19d 19c :5 19f
19e :3 19c 198 :2 1a2
:5 1a4 :11 1a5 :24 1a6 :3 1a5
:2 1a3 :6 1a2 1a1 :6 197
190 :9 1ac :6 1ad :4 1ae
:2 1af :3 1ac 1ab :3 190
18e :3 16b :19 1b4 :1b 1b5
:2 1b6 :2 1b5 :4 1b6 :3 1b5
:3 1b8 :4 1b9 :6 1ba :4 1bb
:2 1bc :2 1bd :2 1be 1b8
:6 1bf :5 1c0 1bf :5 1c2
1c1 :3 1bf 1b7 :2 1c5
:5 1c7 :11 1c8 :24 1c9 :3 1c8
:2 1c6 :6 1c5 1c4 :3 1b6
:4 1cf :4 1d0 1cf :6 1d1
:5 1d2 1d1 :5 1d4 1d3
:3 1d1 1ce :2 1d7 :5 1d9
:11 1da :24 1db :3 1da :2 1d8
:6 1d7 1d6 :3 1b6 :3 1e1
:2 1e2 1e1 :6 1e3 :5 1e4
1e3 :5 1e6 1e5 :3 1e3
1e0 :2 1e9 :5 1eb :11 1ec
:24 1ed :3 1ec :2 1ea :6 1e9
1e8 :4 1b6 :3 1f3 :6 1f4
:2 1f5 1f3 :6 1f6 :5 1f7
1f6 :5 1f9 1f8 :3 1f6
1f2 :2 1fc :5 1fe :11 1ff
:24 200 :3 1ff :2 1fd :6 1fc
1fb :4 1f1 :3 1b5 :3 1b4
16a :d 207 :9 209 :9 20a
:6 20b :4 20c :2 20d :3 20a
:20 210 :3 212 :6 213 :6 214
212 :6 215 :5 216 215
:5 218 217 :3 215 211
:2 21b :5 21d :11 21e :24 21f
:3 21e :2 21c :6 21b 21a
:6 210 209 :5 225 :3 226
:b 22c :5 22d 22b :2 22f
:5 231 :11 232 :24 233 :3 232
:2 230 :6 22f 22e :3 225
:c 238 :5 239 :3 23a :2 23d
23e 23f 23d :5 240
23c :2 242 :5 244 :11 245
:24 246 :3 245 :2 243 :6 242
241 :3 238 :7 24b 24c
:3 24b :9 24e :3 24f :3 250
:3 251 :3 252 :3 253 :5 255
:6 257 :3 258 :5 259 258
:5 25b 25a :3 258 :4 25f
:5 260 25e :2 262 :5 264
:11 265 :24 266 :3 265 :2 263
:6 262 261 :3 24e :3 26c
:2 26d 26c :5 26e 26b
:2 270 :5 272 :11 273 :24 274
:3 273 :2 271 :6 270 26f
:3 24e :3 27a :3 27c :c 27d
:c 27e :c 27f :4 280 281
:2 280 :2 282 :3 280 :8 284
:6 285 :3 286 :3 284 :11 288
:2e 289 :3 288 :11 28b :b 28c
:3 28b :8 28e :3 24e :3 238
:3 225 :b 293 :9 294 :6 295
:4 296 :2 297 :3 294 :20 29b
:3 29d :6 29e :2 29f 29d
:6 2a0 :5 2a1 2a0 :5 2a3
2a2 :3 2a0 29c :2 2a6
:5 2a8 :11 2a9 :24 2aa :3 2a9
:2 2a7 :6 2a6 2a5 :6 29b
224 :3 209 206 :3 16a
:7 2b3 :11 2b4 :30 2b5 :3 2b4
:11 2b7 :b 2b8 :3 2b7 :a 2ba
:3 2b3 :3 2bd :16 2be :3 2bf
:3 2be :9 2c2 :e 2c3 :5 2c4
:5 2c6 :3 2c8 :4 2c9 :6 2ca
:2 2cb :2 2cc :2 2cd :2 2ce
2c8 :6 2cf :5 2d0 2cf
:5 2d2 2d1 :3 2cf 2c7
:2 2d5 :5 2d7 :11 2d8 :24 2d9
:3 2d8 :2 2d6 :6 2d5 2d4
:4 2c6 :3 2df :2 2e0 :2 2e1
:2 2e2 2df :6 2e3 :5 2e4
2e3 :5 2e6 2e5 :3 2e3
2de :2 2e9 :5 2eb :11 2ec
:24 2ed :3 2ec :2 2ea :6 2e9
2e8 :4 2dd :3 2c6 2c4
:5 2f4 :3 2f6 :4 2f7 :5 2f8
:5 2f9 :4 2fa :4 2fb :2 2fd
:2 2fe :2 2ff :2 300 :2 302
:2 303 :2 304 :2 305 :8 306
308 :6 309 :2 30a :2 30b
:2 30c :2 30d 2f6 :6 30e
:5 30f 30e :5 311 310
:3 30e 2f5 :2 314 :5 316
:11 317 :24 318 :3 317 :2 315
:6 314 313 :4 2f4 :3 31f
:4 320 :5 321 :5 322 :4 323
:4 324 :2 326 :2 327 :2 328
:2 329 :2 32b :2 32c :2 32d
:2 32e :8 32f 331 :2 332
31f :6 333 :5 334 333
:5 336 335 :3 333 31e
:2 339 :5 33b :11 33c :24 33d
:3 33c :2 33a :6 339 338
:4 31d :3 2f4 2f2 :3 2c4
343 2c3 :9 343 :3 345
:2 346 :2 347 :2 348 345
:6 349 :5 34a 349 :5 34c
34b :3 349 344 :2 34f
:5 351 :11 352 :24 353 :3 352
:2 350 :6 34f 34e :4 343
:3 2c3 2c2 :e 359 :5 35a
:5 35c :3 35e :4 35f :6 360
:2 361 :2 362 :2 363 :2 364
35e :6 365 :5 366 365
:5 368 367 :3 365 35d
:2 36b :5 36d :11 36e :24 36f
:3 36e :2 36c :6 36b 36a
:4 35c :3 375 :4 376 :2 377
:2 378 375 :6 379 :5 37a
379 :5 37c 37b :3 379
374 :2 37f :5 381 :11 382
:24 383 :3 382 :2 380 :6 37f
37e :4 373 :3 35c 35a
:5 38a :3 38c :4 38d :5 38e
:5 38f :4 390 :4 391 :2 393
:2 394 :2 395 :2 396 :2 398
:2 399 :2 39a :2 39b :8 39c
39e :6 39f :2 3a0 :2 3a1
:2 3a2 :2 3a3 38c :6 3a4
:5 3a5 3a4 :5 3a7 3a6
:3 3a4 38b :2 3aa :5 3ac
:11 3ad :24 3ae :3 3ad :2 3ab
:6 3aa 3a9 :4 38a :3 3b4
:4 3b5 :2 3b6 :5 3b7 :5 3b8
:4 3b9 :4 3ba :2 3bc :2 3bd
:2 3be :2 3bf :2 3c1 :2 3c2
:2 3c3 :2 3c4 :8 3c5 3c7
:2 3c8 3b4 :6 3c9 :5 3ca
3c9 :5 3cc 3cb :3 3c9
3b3 :2 3cf :5 3d1 :11 3d2
:24 3d3 :3 3d2 :2 3d0 :6 3cf
3ce :4 3b2 :3 38a 388
:3 35a 3d9 359 :9 3d9
:5 3da :9 3db :3 3dd :4 3de
:2 3df :3 3e0 :2 3e1 3dd
:6 3e2 :5 3e3 3e2 :5 3e5
3e4 :3 3e2 3dc :2 3e8
:5 3ea :11 3eb :24 3ec :3 3eb
:2 3e9 :6 3e8 3e7 :4 3db
:3 3f2 :4 3f3 :2 3f4 :2 3f5
3f2 :6 3f6 :5 3f7 3f6
:5 3f9 3f8 :3 3f6 3f1
:2 3fc :5 3fe :11 3ff :24 400
:3 3ff :2 3fd :6 3fc 3fb
:4 3f0 :3 3db 3da :3 407
:4 408 :2 409 :2 40a 407
:6 40b :5 40c 40b :5 40e
40d :3 40b 406 :2 411
:5 413 :11 414 :24 415 :3 414
:2 412 :6 411 410 :4 405
:3 3da 3d9 :3 359 358
:3 2c2 :13 41f :2 420 :2 41f
:4 420 :3 41f :3 421 :3 422
:3 423 :3 424 :9 426 :d 428
:9 429 42a :2 42b 428
:5 42c 427 :2 42e :5 430
:11 431 :24 432 :3 431 :2 42f
:6 42e 42d :4 426 :3 437
:c 439 :8 43a 43b :2 43c
439 :5 43d 438 :2 43f
:5 441 :11 442 :24 443 :3 442
:2 440 :6 43f 43e :4 436
:3 426 :a 44a :1b 44b :2 44c
:2 44b :4 44c :3 44b :4 44e
:4 44f 44e :6 450 :5 451
450 :5 453 452 :3 450
44d :2 456 :5 458 :11 459
:24 45a :3 459 :2 457 :6 456
455 :3 44c :3 460 :4 461
:4 462 :2 463 460 :6 464
:5 465 464 :5 467 466
:3 464 45f :2 46a :5 46c
:11 46d :24 46e :3 46d :2 46b
:6 46a 469 :4 44c :5 482
484 :7 485 :3 486 :5 487
486 :5 489 488 :3 486
:7 48b :2 48c :3 48b :f 490
:9 492 :d 493 :d 494 :7 495
494 :17 497 496 :3 494
:3 493 :6 49c :6 49d :5 49e
49d :5 4a0 49f :3 49d
49b :2 4a3 :5 4a5 :11 4a6
:24 4a7 :3 4a6 :2 4a4 :6 4a3
4a2 :3 492 :3 4ac :3 492
:d 4af :2 4b0 :3 4af 484
4b2 481 :4 4b5 :5 4b6
4b4 :2 4b8 :5 4ba :11 4bb
:24 4bc :3 4bb :2 4b9 :6 4b8
4b7 :3 481 :12 4c2 :6 4c4
:6 4c5 :5 4c6 4c5 :5 4c8
4c7 :3 4c5 4c3 :2 4cb
:5 4cd :11 4ce :24 4cf :3 4ce
:2 4cc :6 4cb 4ca :6 4c2
481 :3 44b :9 51c :e 51d
:7 51e 51d :7 520 51f
:3 51d :3 51c :3 44a 420
:2 41f :3 115 :7 527 :5 528
:3 527 :3 a7 :11 52e :30 52f
:3 52e :a 531 61 :3 535
:11 536 :b 537 :17 538 :3 536
:2 53a :3 53b :3 53c 53d
53b 53a 53b :3 53e
:3 535 :2 53f :5 541 :11 542
:b 543 :18 544 :3 542 :2 546
547 :3 548 549 547
546 547 :3 54a :2 540
:6 53f 534 :7 1 
6529
4
:3 0 1 :3 0 2
:a 0 1cc0 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 4 :3 0
7 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 8
:7 0 11 10 :3 0
4 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 6
:3 0 a :7 0 19
18 :3 0 4 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 6 :3 0 c
:7 0 21 20 :3 0
6 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 6
:3 0 e :7 0 29
28 :3 0 6 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 6 :3 0 10
:7 0 31 30 :3 0
6 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 4
:3 0 12 :7 0 39
38 :3 0 4 :3 0
13 :7 0 3d 3c
:3 0 25 160 0
23 6 :3 0 14
:7 0 41 40 :3 0
6 :3 0 15 :7 0
45 44 :3 0 29
186 0 27 4
:3 0 16 :7 0 49
48 :3 0 4 :3 0
17 :7 0 4d 4c
:3 0 2d :2 0 2b
6 :3 0 18 :7 0
51 50 :3 0 4
:3 0 19 :7 0 55
54 :3 0 1a :3 0
1b :3 0 1c :2 0
4 59 5a 0
57 5b 0 1cc0
2 5c :2 0 1e
:2 0 45 4 :3 0
1e :2 0 43 5f
61 :6 0 64 62
0 1cbe 0 1d
:6 0 21 :2 0 49
4 :3 0 47 66
68 :6 0 6b 69
0 1cbe 0 1f
:6 0 23 :2 0 4d
4 :3 0 4b 6d
6f :6 0 72 70
0 1cbe 0 20
:6 0 25 :2 0 51
4 :3 0 4f 74
76 :6 0 79 77
0 1cbe 0 22
:6 0 27 :2 0 55
4 :3 0 53 7b
7d :6 0 80 7e
0 1cbe 0 24
:6 0 27 :2 0 59
4 :3 0 57 82
84 :6 0 87 85
0 1cbe 0 26
:6 0 27 :2 0 5d
4 :3 0 5b 89
8b :6 0 8e 8c
0 1cbe 0 28
:6 0 27 :2 0 61
4 :3 0 5f 90
92 :6 0 95 93
0 1cbe 0 29
:6 0 27 :2 0 65
4 :3 0 63 97
99 :6 0 9c 9a
0 1cbe 0 2a
:6 0 27 :2 0 69
4 :3 0 67 9e
a0 :6 0 a3 a1
0 1cbe 0 2b
:6 0 27 :2 0 6d
4 :3 0 6b a5
a7 :6 0 aa a8
0 1cbe 0 2c
:6 0 27 :2 0 71
4 :3 0 6f ac
ae :6 0 b1 af
0 1cbe 0 2d
:6 0 27 :2 0 75
4 :3 0 73 b3
b5 :6 0 b8 b6
0 1cbe 0 2e
:6 0 31 :2 0 79
4 :3 0 77 ba
bc :6 0 bf bd
0 1cbe 0 2f
:6 0 31 :2 0 7b
6 :3 0 c1 :7 0
c5 c2 c3 1cbe
0 30 :6 0 31
:2 0 7d 6 :3 0
c7 :7 0 cb c8
c9 1cbe 0 32
:6 0 35 :2 0 7f
6 :3 0 cd :7 0
d1 ce cf 1cbe
0 33 :6 0 31
:2 0 81 6 :3 0
d3 :7 0 d7 d4
d5 1cbe 0 34
:6 0 31 :2 0 83
6 :3 0 d9 :7 0
dd da db 1cbe
0 36 :6 0 31
:2 0 85 6 :3 0
df :7 0 e3 e0
e1 1cbe 0 37
:6 0 31 :2 0 87
6 :3 0 e5 :7 0
e9 e6 e7 1cbe
0 38 :6 0 3b
:2 0 89 6 :3 0
eb :7 0 ef ec
ed 1cbe 0 39
:6 0 31 :2 0 8b
6 :3 0 f1 :7 0
f5 f2 f3 1cbe
0 3a :6 0 31
:2 0 8d 6 :3 0
f7 :7 0 fb f8
f9 1cbe 0 3c
:6 0 31 :2 0 8f
6 :3 0 fd :7 0
101 fe ff 1cbe
0 3d :6 0 31
:2 0 91 6 :3 0
103 :7 0 107 104
105 1cbe 0 3e
:6 0 31 :2 0 93
6 :3 0 109 :7 0
10d 10a 10b 1cbe
0 3f :6 0 31
:2 0 95 6 :3 0
10f :7 0 113 110
111 1cbe 0 40
:6 0 31 :2 0 97
6 :3 0 115 :7 0
119 116 117 1cbe
0 41 :6 0 9b
51c 0 99 6
:3 0 11b :7 0 11f
11c 11d 1cbe 0
42 :6 0 27 :2 0
9d 44 :3 0 121
:7 0 124 122 0
1cbe 0 43 :6 0
44 :3 0 126 :7 0
129 127 0 1cbe
0 45 :6 0 27
:2 0 a1 4 :3 0
9f 12b 12d :6 0
130 12e 0 1cbe
0 46 :6 0 49
:2 0 a5 4 :3 0
a3 132 134 :6 0
137 135 0 1cbe
0 47 :6 0 ab
5a7 0 a9 4
:3 0 a7 139 13b
:6 0 13e 13c 0
1cbe 0 48 :6 0
af 5db 0 ad
4b :3 0 140 :7 0
143 141 0 1cbe
0 4a :6 0 4b
:3 0 145 :7 0 148
146 0 1cbe 0
4c :6 0 b3 60f
0 b1 4b :3 0
14a :7 0 14d 14b
0 1cbe 0 4d
:6 0 4b :3 0 14f
:7 0 152 150 0
1cbe 0 4e :6 0
52 :2 0 b5 4b
:3 0 154 :7 0 157
155 0 1cbe 0
4f :6 0 4b :3 0
159 :7 0 15c 15a
0 1cbe 0 50
:6 0 31 :2 0 b9
4 :3 0 b7 15e
160 :6 0 163 161
0 1cbe 0 51
:6 0 31 :2 0 bb
6 :3 0 165 :7 0
169 166 167 1cbe
0 53 :6 0 31
:2 0 bd 6 :3 0
16b :7 0 16f 16c
16d 1cbe 0 54
:6 0 31 :2 0 bf
6 :3 0 171 :7 0
175 172 173 1cbe
0 55 :6 0 31
:2 0 c1 6 :3 0
177 :7 0 17b 178
179 1cbe 0 56
:6 0 31 :2 0 c3
6 :3 0 17d :7 0
181 17e 17f 1cbe
0 57 :6 0 31
:2 0 c5 6 :3 0
183 :7 0 187 184
185 1cbe 0 58
:6 0 c9 724 0
c7 6 :3 0 189
:7 0 18d 18a 18b
1cbe 0 59 :6 0
31 :2 0 cb 44
:3 0 18f :7 0 192
190 0 1cbe 0
5a :6 0 44 :3 0
194 :7 0 197 195
0 1cbe 0 5b
:6 0 31 :2 0 cd
5d :3 0 199 :7 0
19d 19a 19b 1cbe
0 5c :6 0 31
:2 0 cf 5d :3 0
19f :7 0 1a3 1a0
1a1 1cbe 0 5e
:6 0 31 :2 0 d1
6 :3 0 1a5 :7 0
1a9 1a6 1a7 1cbe
0 5f :6 0 31
:2 0 d3 6 :3 0
1ab :7 0 1af 1ac
1ad 1cbe 0 60
:6 0 31 :2 0 d5
6 :3 0 1b1 :7 0
1b5 1b2 1b3 1cbe
0 61 :9 0 d7
6 :3 0 1b7 :7 0
1bb 1b8 1b9 1cbe
0 62 :6 0 63
:3 0 64 :a 0 2
1d0 :4 0 1bd 1c0
0 1be :3 0 65
:3 0 66 :3 0 67
:3 0 68 :3 0 66
:3 0 67 :3 0 69
:3 0 6a :3 0 6b
:3 0 2d :3 0 6c
:3 0 2e :3 0 6d
:3 0 6e :4 0 6f
1 :8 0 1d1 1bd
1c0 1d2 0 1cbe
d9 1d2 1d4 1d1
1d3 :6 0 1d0 :7 0
1d2 63 :3 0 70
:a 0 3 1e5 :5 0
1d6 1d9 0 1d7
:3 0 71 :3 0 72
:3 0 73 :3 0 74
:3 0 6b :3 0 2d
:3 0 75 :3 0 46
:3 0 76 :3 0 73
:4 0 77 1 :8 0
1e6 1d6 1d9 1e7
0 1cbe db 1e7
1e9 1e6 1e8 :6 0
1e5 :7 0 1e7 1f1
1f2 0 dd 1b
:3 0 1c :2 0 4
1eb 1ec 0 1ed
:7 0 1f0 1ee 0
1cbe 0 78 :6 0
79 :3 0 7a :3 0
79 :3 0 7b :3 0
1f4 1f5 0 2
:4 0 df 1f6 1f8
1f3 1fa 1f9 :2 0
7c :3 0 7d :3 0
1fc 1fd 0 7e
:4 0 79 :3 0 7f
:3 0 200 201 0
2 :4 0 e1 202
204 80 :4 0 81
:2 0 82 :3 0 e3
207 209 :3 0 83
:4 0 81 :2 0 84
:4 0 e6 20c 20e
:3 0 81 :2 0 3
:3 0 e9 210 212
:3 0 81 :2 0 84
:4 0 ec 214 216
:3 0 81 :2 0 85
:4 0 ef 218 21a
:3 0 81 :2 0 86
:3 0 67 :3 0 5
:3 0 f2 21e 220
87 :4 0 f4 21d
223 f7 21c 225
:3 0 81 :2 0 85
:4 0 fa 227 229
:3 0 81 :2 0 84
:4 0 fd 22b 22d
:3 0 81 :2 0 7
:3 0 100 22f 231
:3 0 81 :2 0 84
:4 0 103 233 235
:3 0 81 :2 0 85
:4 0 106 237 239
:3 0 81 :2 0 84
:4 0 109 23b 23d
:3 0 81 :2 0 8
:3 0 10c 23f 241
:3 0 81 :2 0 84
:4 0 10f 243 245
:3 0 81 :2 0 85
:4 0 112 247 249
:3 0 81 :2 0 84
:4 0 115 24b 24d
:3 0 81 :2 0 9
:3 0 118 24f 251
:3 0 81 :2 0 84
:4 0 11b 253 255
:3 0 81 :2 0 85
:4 0 11e 257 259
:3 0 81 :2 0 86
:3 0 67 :3 0 a
:3 0 121 25d 25f
87 :4 0 123 25c
262 126 25b 264
:3 0 81 :2 0 85
:4 0 129 266 268
:3 0 81 :2 0 84
:4 0 12c 26a 26c
:3 0 81 :2 0 b
:3 0 12f 26e 270
:3 0 81 :2 0 84
:4 0 132 272 274
:3 0 81 :2 0 85
:4 0 135 276 278
:3 0 81 :2 0 86
:3 0 67 :3 0 c
:3 0 138 27c 27e
87 :4 0 13a 27b
281 13d 27a 283
:3 0 81 :2 0 85
:4 0 140 285 287
:3 0 81 :2 0 86
:3 0 67 :3 0 d
:3 0 143 28b 28d
87 :4 0 145 28a
290 148 289 292
:3 0 81 :2 0 85
:4 0 14b 294 296
:3 0 81 :2 0 86
:3 0 67 :3 0 e
:3 0 14e 29a 29c
87 :4 0 150 299
29f 153 298 2a1
:3 0 81 :2 0 85
:4 0 156 2a3 2a5
:3 0 81 :2 0 86
:3 0 67 :3 0 f
:3 0 159 2a9 2ab
87 :4 0 15b 2a8
2ae 15e 2a7 2b0
:3 0 81 :2 0 85
:4 0 161 2b2 2b4
:3 0 81 :2 0 86
:3 0 67 :3 0 10
:3 0 164 2b8 2ba
87 :4 0 166 2b7
2bd 169 2b6 2bf
:3 0 81 :2 0 85
:4 0 16c 2c1 2c3
:3 0 81 :2 0 86
:3 0 67 :3 0 11
:3 0 16f 2c7 2c9
87 :4 0 171 2c6
2cc 174 2c5 2ce
:3 0 81 :2 0 85
:4 0 177 2d0 2d2
:3 0 81 :2 0 84
:4 0 17a 2d4 2d6
:3 0 81 :2 0 12
:3 0 17d 2d8 2da
:3 0 81 :2 0 84
:4 0 180 2dc 2de
:3 0 81 :2 0 85
:4 0 183 2e0 2e2
:3 0 81 :2 0 84
:4 0 186 2e4 2e6
:3 0 81 :2 0 13
:3 0 189 2e8 2ea
:3 0 81 :2 0 84
:4 0 18c 2ec 2ee
:3 0 81 :2 0 85
:4 0 18f 2f0 2f2
:3 0 81 :2 0 86
:3 0 67 :3 0 14
:3 0 192 2f6 2f8
87 :4 0 194 2f5
2fb 197 2f4 2fd
:3 0 81 :2 0 85
:4 0 19a 2ff 301
:3 0 81 :2 0 86
:3 0 67 :3 0 15
:3 0 19d 305 307
87 :4 0 19f 304
30a 1a2 303 30c
:3 0 81 :2 0 85
:4 0 1a5 30e 310
:3 0 81 :2 0 84
:4 0 1a8 312 314
:3 0 81 :2 0 16
:3 0 1ab 316 318
:3 0 81 :2 0 84
:4 0 1ae 31a 31c
:3 0 81 :2 0 85
:4 0 1b1 31e 320
:3 0 81 :2 0 84
:4 0 1b4 322 324
:3 0 81 :2 0 17
:3 0 1b7 326 328
:3 0 81 :2 0 84
:4 0 1ba 32a 32c
:3 0 81 :2 0 85
:4 0 1bd 32e 330
:3 0 81 :2 0 86
:3 0 67 :3 0 18
:3 0 1c0 334 336
87 :4 0 1c2 333
339 1c5 332 33b
:3 0 81 :2 0 85
:4 0 1c8 33d 33f
:3 0 81 :2 0 84
:4 0 1cb 341 343
:3 0 81 :2 0 19
:3 0 1ce 345 347
:3 0 81 :2 0 84
:4 0 1d1 349 34b
:3 0 81 :2 0 88
:4 0 1d4 34d 34f
:3 0 1d7 1fe 351
:2 0 353 1dc 354
1fb 353 0 355
1de 0 1c1e 79
:3 0 7a :3 0 356
357 0 79 :3 0
89 :3 0 359 35a
0 49 :2 0 2
:4 0 8a :2 0 8b
:2 0 49 :2 0 1e0
35f 361 :3 0 1e3
35b 363 358 365
364 :2 0 7c :3 0
8c :3 0 367 368
0 7e :4 0 8d
:4 0 81 :2 0 82
:3 0 1e7 36c 36e
:3 0 1ea 369 370
:2 0 372 1ed 373
366 372 0 374
1ef 0 1c1e 5
:3 0 8e :2 0 1f1
376 377 :3 0 378
:2 0 379 :2 0 86
:3 0 5 :3 0 31
:2 0 1f3 37b 37e
8f :2 0 49 :2 0
1f8 380 382 :3 0
383 :2 0 86 :3 0
5 :3 0 31 :2 0
1fb 385 388 90
:2 0 91 :2 0 200
38a 38c :3 0 38d
:2 0 384 38f 38e
:2 0 390 :2 0 37a
392 391 :2 0 79
:3 0 7a :3 0 394
395 0 79 :3 0
89 :3 0 397 398
0 92 :2 0 2
:4 0 93 :2 0 8b
:2 0 49 :2 0 203
39d 39f :3 0 206
399 3a1 396 3a3
3a2 :2 0 7c :3 0
8c :3 0 3a5 3a6
0 7e :4 0 94
:4 0 81 :2 0 82
:3 0 20a 3aa 3ac
:3 0 81 :2 0 95
:4 0 20d 3ae 3b0
:3 0 81 :2 0 96
:4 0 210 3b2 3b4
:3 0 81 :2 0 86
:3 0 67 :3 0 97
:3 0 98 :3 0 3b9
3ba 0 213 3b8
3bc 87 :4 0 215
3b7 3bf 218 3b6
3c1 :3 0 21b 3a7
3c3 :2 0 3c5 21e
3c6 3a4 3c5 0
3c7 220 0 3f0
79 :3 0 7a :3 0
3c8 3c9 0 79
:3 0 89 :3 0 3cb
3cc 0 49 :2 0
2 :4 0 99 :2 0
8b :2 0 49 :2 0
222 3d1 3d3 :3 0
225 3cd 3d5 3ca
3d7 3d6 :2 0 7c
:3 0 8c :3 0 3d9
3da 0 7e :4 0
9a :4 0 81 :2 0
82 :3 0 229 3de
3e0 :3 0 22c 3db
3e2 :2 0 3e4 22f
3e5 3d8 3e4 0
3e6 231 0 3f0
9b :3 0 9c :3 0
3e7 3e8 0 97
:3 0 98 :3 0 3ea
3eb 0 9d :3 0
233 3e9 3ee :2 0
3f0 236 3f1 393
3f0 0 3f2 23a
0 1c1e 3 :3 0
8e :2 0 23c 3f4
3f5 :3 0 3f6 :2 0
3f7 :2 0 f :3 0
8e :2 0 23e 3fa
3fb :3 0 3fc :2 0
3fd :2 0 3f8 3ff
3fe :2 0 19 :3 0
8e :2 0 240 402
403 :3 0 404 :2 0
405 :2 0 400 407
406 :2 0 79 :3 0
7a :3 0 409 40a
0 79 :3 0 89
:3 0 40c 40d 0
92 :2 0 2 :4 0
9e :2 0 8b :2 0
49 :2 0 242 412
414 :3 0 245 40e
416 40b 418 417
:2 0 7c :3 0 8c
:3 0 41a 41b 0
7e :4 0 9f :4 0
81 :2 0 82 :3 0
249 41f 421 :3 0
81 :2 0 95 :4 0
24c 423 425 :3 0
81 :2 0 96 :4 0
24f 427 429 :3 0
81 :2 0 86 :3 0
67 :3 0 97 :3 0
98 :3 0 42e 42f
0 252 42d 431
87 :4 0 254 42c
434 257 42b 436
:3 0 25a 41c 438
:2 0 43a 25d 43b
419 43a 0 43c
25f 0 465 79
:3 0 7a :3 0 43d
43e 0 79 :3 0
89 :3 0 440 441
0 49 :2 0 2
:4 0 a0 :2 0 8b
:2 0 49 :2 0 261
446 448 :3 0 264
442 44a 43f 44c
44b :2 0 7c :3 0
8c :3 0 44e 44f
0 7e :4 0 a1
:4 0 81 :2 0 82
:3 0 268 453 455
:3 0 26b 450 457
:2 0 459 26e 45a
44d 459 0 45b
270 0 465 9b
:3 0 9c :3 0 45c
45d 0 97 :3 0
98 :3 0 45f 460
0 9d :3 0 272
45e 463 :2 0 465
275 466 408 465
0 467 279 0
1c1e 4d :4 0 468
469 0 1c1e 4f
:4 0 46b 46c 0
1c1e 32 :3 0 a2
:2 0 46e 46f 0
1c1e 4c :3 0 8
:3 0 471 472 0
1c1e 4e :3 0 9
:3 0 474 475 0
1c1e 51 :3 0 b
:3 0 477 478 0
1c1e 2f :3 0 19
:3 0 47a 47b 0
1c1e 3d :3 0 a
:3 0 47d 47e 0
1c1e 41 :3 0 f
:3 0 480 481 0
1c1e 58 :3 0 5
:3 0 483 484 0
1c1e 39 :3 0 10
:3 0 486 487 0
1c1e 4d :3 0 16
:3 0 489 48a 0
1c1e 42 :3 0 c
:3 0 48c 48d 0
1c1e 56 :3 0 31
:2 0 48f 490 0
1c1e 86 :3 0 a3
:3 0 51 :3 0 27b
493 495 31 :2 0
27d 492 498 97
:3 0 8f :2 0 a4
:3 0 49a 49c 0
282 49b 49e :3 0
86 :3 0 58 :3 0
31 :2 0 285 4a0
4a3 a5 :2 0 49
:2 0 28a 4a5 4a7
:3 0 4a8 :2 0 86
:3 0 58 :3 0 31
:2 0 28d 4aa 4ad
a5 :2 0 91 :2 0
292 4af 4b1 :3 0
4b2 :2 0 4a9 4b4
4b3 :2 0 7 :3 0
8e :2 0 295 4b7
4b8 :3 0 4b9 :2 0
79 :3 0 7a :3 0
4bb 4bc 0 79
:3 0 89 :3 0 4be
4bf 0 92 :2 0
2 :4 0 a6 :2 0
8b :2 0 49 :2 0
297 4c4 4c6 :3 0
29a 4c0 4c8 4bd
4ca 4c9 :2 0 7c
:3 0 8c :3 0 4cc
4cd 0 7e :4 0
a7 :4 0 81 :2 0
82 :3 0 29e 4d1
4d3 :3 0 81 :2 0
95 :4 0 2a1 4d5
4d7 :3 0 81 :2 0
96 :4 0 2a4 4d9
4db :3 0 81 :2 0
86 :3 0 67 :3 0
97 :3 0 98 :3 0
4e0 4e1 0 2a7
4df 4e3 87 :4 0
2a9 4de 4e6 2ac
4dd 4e8 :3 0 2af
4ce 4ea :2 0 4ec
2b2 4ed 4cb 4ec
0 4ee 2b4 0
517 79 :3 0 7a
:3 0 4ef 4f0 0
79 :3 0 89 :3 0
4f2 4f3 0 49
:2 0 2 :4 0 a8
:2 0 8b :2 0 49
:2 0 2b6 4f8 4fa
:3 0 2b9 4f4 4fc
4f1 4fe 4fd :2 0
7c :3 0 8c :3 0
500 501 0 7e
:4 0 a9 :4 0 81
:2 0 82 :3 0 2bd
505 507 :3 0 2c0
502 509 :2 0 50b
2c3 50c 4ff 50b
0 50d 2c5 0
517 9b :3 0 9c
:3 0 50e 50f 0
97 :3 0 98 :3 0
511 512 0 9d
:3 0 2c7 510 515
:2 0 517 2ca 518
4ba 517 0 519
2ce 0 6ac 2c
:3 0 3 :3 0 51a
51b 0 6ac 2e
:3 0 7 :3 0 51d
51e 0 6ac 2f
:3 0 19 :3 0 520
521 0 6ac 6b
:3 0 aa :3 0 2d
:3 0 30 :3 0 6a
:3 0 6c :3 0 2e
:4 0 ab 1 :8 0
530 1b :3 0 ac
:3 0 52b 52c 0
ad :3 0 52d 52e
0 530 2d0 57a
ae :3 0 1b :3 0
ac :3 0 533 534
0 ad :3 0 535
536 0 570 79
:3 0 7a :3 0 538
539 0 79 :3 0
89 :3 0 53b 53c
0 25 :2 0 2
:4 0 af :2 0 8b
:2 0 49 :2 0 2d3
541 543 :3 0 2d6
53d 545 53a 547
546 :2 0 7c :3 0
8c :3 0 549 54a
0 7e :4 0 b0
:4 0 81 :2 0 82
:3 0 2da 54e 550
:3 0 81 :2 0 95
:4 0 2dd 552 554
:3 0 81 :2 0 b1
:4 0 2e0 556 558
:3 0 81 :2 0 ad
:3 0 2e3 55a 55c
:3 0 81 :2 0 b2
:4 0 2e6 55e 560
:3 0 81 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 2e9
563 567 2ed 562
569 :3 0 2f0 54b
56b :2 0 56d 2f3
56e 548 56d 0
56f 2f5 0 570
2f7 573 :3 0 573
0 573 572 570
571 :6 0 575 4
:3 0 2fa 577 2fc
576 575 :2 0 578
2fe :2 0 57a 0
57a 579 530 578
:6 0 6ac 1 :3 0
2b :3 0 b6 :4 0
57d 57e :3 0 57c
57f 0 6ac 53
:3 0 b7 :3 0 86
:3 0 30 :3 0 31
:2 0 300 583 586
303 582 588 581
589 0 6ac 1b
:3 0 ac :3 0 58b
58c 0 b8 :3 0
53 :3 0 30 :3 0
2e :3 0 2c :3 0
2f :3 0 2b :3 0
305 58e 595 58d
596 0 6ac 1b
:3 0 ac :3 0 598
599 0 a5 :2 0
31 :2 0 30e 59b
59d :3 0 59e :2 0
86 :3 0 58 :3 0
31 :2 0 311 5a0
5a3 a5 :2 0 91
:2 0 316 5a5 5a7
:3 0 5a8 :2 0 59f
5aa 5a9 :2 0 86
:3 0 3d :3 0 31
:2 0 319 5ac 5af
a5 :2 0 31 :2 0
31e 5b1 5b3 :3 0
5b4 :2 0 5ab 5b6
5b5 :2 0 54 :3 0
31 :2 0 5b8 5b9
0 68a b9 :3 0
54 :3 0 ba :3 0
bb :3 0 6b :3 0
2d :3 0 bc :3 0
2c :4 0 bd 1
:8 0 5c9 1b :3 0
ac :3 0 5c4 5c5
0 ad :3 0 5c6
5c7 0 5c9 321
613 ae :3 0 1b
:3 0 ac :3 0 5cc
5cd 0 ad :3 0
5ce 5cf 0 609
79 :3 0 7a :3 0
5d1 5d2 0 79
:3 0 89 :3 0 5d4
5d5 0 25 :2 0
2 :4 0 be :2 0
8b :2 0 49 :2 0
324 5da 5dc :3 0
327 5d6 5de 5d3
5e0 5df :2 0 7c
:3 0 8c :3 0 5e2
5e3 0 7e :4 0
bf :4 0 81 :2 0
82 :3 0 32b 5e7
5e9 :3 0 81 :2 0
95 :4 0 32e 5eb
5ed :3 0 81 :2 0
b1 :4 0 331 5ef
5f1 :3 0 81 :2 0
ad :3 0 334 5f3
5f5 :3 0 81 :2 0
b2 :4 0 337 5f7
5f9 :3 0 81 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
33a 5fc 600 33e
5fb 602 :3 0 341
5e4 604 :2 0 606
344 607 5e1 606
0 608 346 0
609 348 60c :3 0
60c 0 60c 60b
609 60a :6 0 60e
6 :3 0 34b 610
34d 60f 60e :2 0
611 34f :2 0 613
0 613 612 5c9
611 :6 0 68a 1
:3 0 86 :3 0 54
:3 0 31 :2 0 351
615 618 c0 :2 0
31 :2 0 356 61a
61c :3 0 58 :3 0
49 :2 0 61e 61f
0 687 3d :3 0
c1 :2 0 621 622
0 687 51 :3 0
c2 :4 0 624 625
0 687 4c :3 0
c3 :2 0 359 628
629 :3 0 62a :2 0
c4 :3 0 c5 :3 0
c6 :3 0 4c :3 0
4e :3 0 ba :4 0
c7 1 :8 0 638
1b :3 0 ac :3 0
633 634 0 ad
:3 0 635 636 0
638 35b 682 ae
:3 0 1b :3 0 ac
:3 0 63b 63c 0
ad :3 0 63d 63e
0 678 79 :3 0
7a :3 0 640 641
0 79 :3 0 89
:3 0 643 644 0
25 :2 0 2 :4 0
c8 :2 0 8b :2 0
49 :2 0 35e 649
64b :3 0 361 645
64d 642 64f 64e
:2 0 7c :3 0 8c
:3 0 651 652 0
7e :4 0 c9 :4 0
81 :2 0 82 :3 0
365 656 658 :3 0
81 :2 0 95 :4 0
368 65a 65c :3 0
81 :2 0 b1 :4 0
36b 65e 660 :3 0
81 :2 0 ad :3 0
36e 662 664 :3 0
81 :2 0 b2 :4 0
371 666 668 :3 0
81 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 374 66b
66f 378 66a 671
:3 0 37b 653 673
:2 0 675 37e 676
650 675 0 677
380 0 678 382
67b :3 0 67b 0
67b 67a 678 679
:6 0 67d 8 :3 0
385 67f 387 67e
67d :2 0 680 389
:2 0 682 0 682
681 638 680 :6 0
684 1 :3 0 38b
685 62b 684 0
686 38d 0 687
38f 688 61d 687
0 689 394 0
68a 396 68b 5b7
68a 0 68c 39a
0 6ac 86 :3 0
58 :3 0 31 :2 0
39c 68d 690 a5
:2 0 49 :2 0 3a1
692 694 :3 0 695
:2 0 ca :3 0 86
:3 0 30 :3 0 31
:2 0 3a4 698 69b
3a7 697 69d 69e
:2 0 c0 :2 0 31
:2 0 3ab 6a0 6a2
:3 0 696 6a4 6a3
:2 0 58 :3 0 91
:2 0 6a6 6a7 0
6a9 3ae 6aa 6a5
6a9 0 6ab 3b0
0 6ac 3b2 740
2b :3 0 3 :3 0
6ad 6ae 0 73f
6b :3 0 cb :3 0
cc :3 0 cd :3 0
ce :3 0 cf :3 0
d0 :3 0 d1 :3 0
d2 :3 0 6d :3 0
2d :3 0 2e :3 0
2c :3 0 42 :3 0
47 :3 0 62 :3 0
36 :3 0 37 :3 0
38 :3 0 4f :3 0
d3 :3 0 75 :3 0
2b :4 0 d4 1
:8 0 6cd 1b :3 0
ac :3 0 6c8 6c9
0 ad :3 0 6ca
6cb 0 6cd 3bd
717 ae :3 0 1b
:3 0 ac :3 0 6d0
6d1 0 ad :3 0
6d2 6d3 0 70d
79 :3 0 7a :3 0
6d5 6d6 0 79
:3 0 89 :3 0 6d8
6d9 0 25 :2 0
2 :4 0 d5 :2 0
8b :2 0 49 :2 0
3c0 6de 6e0 :3 0
3c3 6da 6e2 6d7
6e4 6e3 :2 0 7c
:3 0 8c :3 0 6e6
6e7 0 7e :4 0
d6 :4 0 81 :2 0
82 :3 0 3c7 6eb
6ed :3 0 81 :2 0
95 :4 0 3ca 6ef
6f1 :3 0 81 :2 0
b1 :4 0 3cd 6f3
6f5 :3 0 81 :2 0
ad :3 0 3d0 6f7
6f9 :3 0 81 :2 0
b2 :4 0 3d3 6fb
6fd :3 0 81 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
3d6 700 704 3da
6ff 706 :3 0 3dd
6e8 708 :2 0 70a
3e0 70b 6e5 70a
0 70c 3e2 0
70d 3e4 710 :3 0
710 0 710 70f
70d 70e :6 0 712
a :3 0 3e7 714
3e9 713 712 :2 0
715 3eb :2 0 717
0 717 716 6cd
715 :6 0 73f 1
:3 0 1b :3 0 ac
:3 0 719 71a 0
1b :3 0 a5 :2 0
d7 :3 0 71c 71e
0 3ef 71d 720
:3 0 721 :2 0 86
:3 0 c :3 0 31
:2 0 3f2 723 726
86 :3 0 c0 :2 0
42 :3 0 31 :2 0
3f5 728 72c 3fa
729 72e :3 0 72f
:2 0 722 731 730
:2 0 4d :4 0 733
734 0 73c 3e
:3 0 d8 :2 0 49
:2 0 3fd 737 739
:3 0 736 73a 0
73c 3ff 73d 732
73c 0 73e 402
0 73f 404 741
4b5 6ac 0 742
0 73f 0 742
408 0 1bcd 86
:3 0 58 :3 0 31
:2 0 40b 743 746
c0 :2 0 91 :2 0
410 748 74a :3 0
1b :3 0 ac :3 0
74c 74d 0 c0
:2 0 31 :2 0 415
74f 751 :3 0 79
:3 0 7a :3 0 753
754 0 79 :3 0
89 :3 0 756 757
0 27 :2 0 2
:4 0 d9 :2 0 8b
:2 0 49 :2 0 418
75c 75e :3 0 41b
758 760 755 762
761 :2 0 7c :3 0
8c :3 0 764 765
0 7e :4 0 da
:4 0 81 :2 0 82
:3 0 41f 769 76b
:3 0 81 :2 0 95
:4 0 422 76d 76f
:3 0 81 :2 0 96
:4 0 425 771 773
:3 0 81 :2 0 86
:3 0 67 :3 0 1b
:3 0 ac :3 0 778
779 0 428 777
77b 87 :4 0 42a
776 77e 42d 775
780 :3 0 81 :2 0
db :4 0 430 782
784 :3 0 81 :2 0
84 :4 0 433 786
788 :3 0 81 :2 0
2b :3 0 436 78a
78c :3 0 81 :2 0
84 :4 0 439 78e
790 :3 0 43c 766
792 :2 0 794 43f
795 763 794 0
796 441 0 7c0
79 :3 0 7a :3 0
797 798 0 79
:3 0 89 :3 0 79a
79b 0 49 :2 0
2 :4 0 dc :2 0
8b :2 0 49 :2 0
443 7a0 7a2 :3 0
446 79c 7a4 799
7a6 7a5 :2 0 7c
:3 0 8c :3 0 7a8
7a9 0 7e :4 0
dd :4 0 81 :2 0
82 :3 0 44a 7ad
7af :3 0 44d 7aa
7b1 :2 0 7b3 450
7b4 7a7 7b3 0
7b5 452 0 7c0
9b :3 0 de :3 0
7b6 7b7 0 1b
:3 0 ac :3 0 7b9
7ba 0 2b :3 0
9d :3 0 454 7b8
7be :2 0 7c0 458
7c1 752 7c0 0
7c2 45c 0 1bbb
4c :3 0 8e :2 0
45e 7c4 7c5 :3 0
7c6 :2 0 4e :3 0
8e :2 0 460 7c9
7ca :3 0 7cb :2 0
7c7 7cd 7cc :2 0
3d :3 0 8e :2 0
462 7d0 7d1 :3 0
7d2 :2 0 7ce 7d4
7d3 :2 0 51 :3 0
8e :2 0 464 7d7
7d8 :3 0 7d9 :2 0
7d5 7db 7da :2 0
79 :3 0 7a :3 0
7dd 7de 0 79
:3 0 89 :3 0 7e0
7e1 0 92 :2 0
2 :4 0 df :2 0
8b :2 0 49 :2 0
466 7e6 7e8 :3 0
469 7e2 7ea 7df
7ec 7eb :2 0 7c
:3 0 8c :3 0 7ee
7ef 0 7e :4 0
e0 :4 0 81 :2 0
82 :3 0 46d 7f3
7f5 :3 0 81 :2 0
95 :4 0 470 7f7
7f9 :3 0 81 :2 0
96 :4 0 473 7fb
7fd :3 0 81 :2 0
86 :3 0 67 :3 0
97 :3 0 98 :3 0
802 803 0 476
801 805 87 :4 0
478 800 808 47b
7ff 80a :3 0 47e
7f0 80c :2 0 80e
481 80f 7ed 80e
0 810 483 0
839 79 :3 0 7a
:3 0 811 812 0
79 :3 0 89 :3 0
814 815 0 49
:2 0 2 :4 0 e1
:2 0 8b :2 0 49
:2 0 485 81a 81c
:3 0 488 816 81e
813 820 81f :2 0
7c :3 0 8c :3 0
822 823 0 7e
:4 0 e2 :4 0 81
:2 0 82 :3 0 48c
827 829 :3 0 48f
824 82b :2 0 82d
492 82e 821 82d
0 82f 494 0
839 9b :3 0 9c
:3 0 830 831 0
97 :3 0 98 :3 0
833 834 0 9d
:3 0 496 832 837
:2 0 839 499 83a
7dc 839 0 83b
49d 0 1bbb 3c
:3 0 97 :3 0 e3
:3 0 83d 83e 0
83c 83f 0 1bbb
86 :3 0 39 :3 0
31 :2 0 49f 841
844 90 :2 0 e4
:2 0 4a4 846 848
:3 0 39 :3 0 e4
:2 0 84a 84b 0
84d 4a7 84e 849
84d 0 84f 4a9
0 1bbb 86 :3 0
e5 :3 0 3a :3 0
6a :3 0 6c :3 0
2e :4 0 e6 1
:8 0 85c 1b :3 0
ac :3 0 857 858
0 ad :3 0 859
85a 0 85c 4ab
8a6 ae :3 0 1b
:3 0 ac :3 0 85f
860 0 ad :3 0
861 862 0 89c
79 :3 0 7a :3 0
864 865 0 79
:3 0 89 :3 0 867
868 0 25 :2 0
2 :4 0 e7 :2 0
8b :2 0 49 :2 0
4ae 86d 86f :3 0
4b1 869 871 866
873 872 :2 0 7c
:3 0 8c :3 0 875
876 0 7e :4 0
e8 :4 0 81 :2 0
82 :3 0 4b5 87a
87c :3 0 81 :2 0
95 :4 0 4b8 87e
880 :3 0 81 :2 0
b1 :4 0 4bb 882
884 :3 0 81 :2 0
ad :3 0 4be 886
888 :3 0 81 :2 0
b2 :4 0 4c1 88a
88c :3 0 81 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
4c4 88f 893 4c8
88e 895 :3 0 4cb
877 897 :2 0 899
4ce 89a 874 899
0 89b 4d0 0
89c 4d2 89f :3 0
89f 0 89f 89e
89c 89d :6 0 8a1
c :3 0 4d5 8a3
4d7 8a2 8a1 :2 0
8a4 4d9 :2 0 8a6
0 8a6 8a5 85c
8a4 :6 0 1bbb 1
:3 0 86 :3 0 36
:3 0 31 :2 0 4db
8a8 8ab 90 :2 0
31 :2 0 4e0 8ad
8af :3 0 54 :3 0
e9 :3 0 86 :3 0
36 :3 0 31 :2 0
4e3 8b3 8b6 ea
:2 0 86 :3 0 3a
:3 0 31 :2 0 4e6
8b9 8bc 4e9 8b8
8be :3 0 8bf :2 0
eb :2 0 ec :2 0
4ec 8c1 8c3 :3 0
8c4 :2 0 8b :2 0
ed :2 0 4ef 8c6
8c8 :3 0 4f2 8b2
8ca 8b1 8cb 0
8e8 86 :3 0 39
:3 0 31 :2 0 4f4
8cd 8d0 86 :3 0
c0 :2 0 54 :3 0
31 :2 0 4f7 8d2
8d6 4fc 8d3 8d8
:3 0 36 :3 0 31
:2 0 8da 8db 0
8e0 37 :3 0 31
:2 0 8dd 8de 0
8e0 4ff 8e5 39
:3 0 31 :2 0 8e1
8e2 0 8e4 502
8e6 8d9 8e0 0
8e7 0 8e4 0
8e7 504 0 8e8
507 8e9 8b0 8e8
0 8ea 50a 0
1bbb 48 :4 0 8eb
8ec 0 1bbb ee
:3 0 86 :3 0 f
:3 0 31 :2 0 50c
8ef 8f2 25 :2 0
50f 8ee 8f5 8f6
:2 0 a5 :2 0 25
:2 0 514 8f8 8fa
:3 0 86 :3 0 58
:3 0 31 :2 0 517
8fc 8ff a5 :2 0
49 :2 0 51c 901
903 :3 0 86 :3 0
c :3 0 31 :2 0
51f 905 908 90
:2 0 31 :2 0 524
90a 90c :3 0 1b
:3 0 ac :3 0 90e
90f 0 ef :3 0
2b :3 0 48 :3 0
48 :3 0 32 :3 0
4c :3 0 4e :3 0
3d :3 0 36 :3 0
33 :3 0 33 :3 0
34 :3 0 3c :3 0
37 :3 0 38 :3 0
56 :3 0 51 :3 0
2f :3 0 527 911
923 910 924 0
9a1 1b :3 0 ac
:3 0 926 927 0
a5 :2 0 31 :2 0
53b 929 92b :3 0
d3 :3 0 f0 :3 0
e :3 0 f1 :3 0
f2 :3 0 f3 :3 0
f4 :3 0 f5 :3 0
f6 :3 0 6b :3 0
2d :3 0 cb :3 0
2e :3 0 cc :3 0
2c :4 0 f7 1
:8 0 952 f8 :4 0
93d :3 0 9d :3 0
a5 :2 0 540 940
941 :3 0 1b :3 0
ac :3 0 943 944
0 31 :2 0 945
946 0 948 543
94f 1b :3 0 ac
:3 0 949 94a 0
f9 :2 0 94b 94c
0 94e 545 950
942 948 0 951
0 94e 0 951
547 0 952 54a
99c ae :3 0 1b
:3 0 ac :3 0 955
956 0 ad :3 0
957 958 0 992
79 :3 0 7a :3 0
95a 95b 0 79
:3 0 89 :3 0 95d
95e 0 25 :2 0
2 :4 0 fa :2 0
8b :2 0 49 :2 0
54d 963 965 :3 0
550 95f 967 95c
969 968 :2 0 7c
:3 0 8c :3 0 96b
96c 0 7e :4 0
fb :4 0 81 :2 0
82 :3 0 554 970
972 :3 0 81 :2 0
95 :4 0 557 974
976 :3 0 81 :2 0
b1 :4 0 55a 978
97a :3 0 81 :2 0
ad :3 0 55d 97c
97e :3 0 81 :2 0
b2 :4 0 560 980
982 :3 0 81 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
563 985 989 567
984 98b :3 0 56a
96d 98d :2 0 98f
56d 990 96a 98f
0 991 56f 0
992 571 995 :3 0
995 0 995 994
992 993 :6 0 997
e :3 0 574 999
576 998 997 :2 0
99a 578 :2 0 99c
0 99c 99b 952
99a :6 0 99e 1
:3 0 57a 99f 92c
99e 0 9a0 57c
0 9a1 57e 9bb
1b :3 0 ac :3 0
9a2 9a3 0 ef
:3 0 2b :3 0 48
:3 0 48 :3 0 32
:3 0 4c :3 0 4e
:3 0 3d :3 0 36
:3 0 33 :3 0 33
:3 0 33 :3 0 3c
:3 0 37 :3 0 38
:3 0 56 :3 0 51
:3 0 2f :3 0 581
9a5 9b7 9a4 9b8
0 9ba 593 9bc
90d 9a1 0 9bd
0 9ba 0 9bd
595 0 9be 598
a80 3c :3 0 86
:3 0 3c :3 0 31
:2 0 59a 9c0 9c3
8b :2 0 49 :2 0
59d 9c5 9c7 :3 0
9bf 9c8 0 a7f
86 :3 0 c :3 0
31 :2 0 5a0 9ca
9cd 90 :2 0 31
:2 0 5a5 9cf 9d1
:3 0 1b :3 0 ac
:3 0 9d3 9d4 0
ef :3 0 2b :3 0
48 :3 0 48 :3 0
32 :3 0 4c :3 0
4e :3 0 3d :3 0
36 :3 0 33 :3 0
33 :3 0 34 :3 0
3c :3 0 37 :3 0
38 :3 0 56 :3 0
51 :3 0 2f :3 0
5a8 9d6 9e8 9d5
9e9 0 a62 1b
:3 0 ac :3 0 9eb
9ec 0 a5 :2 0
31 :2 0 5bc 9ee
9f0 :3 0 d3 :3 0
f0 :3 0 e :3 0
f1 :3 0 f2 :3 0
f3 :3 0 f4 :3 0
f5 :3 0 f6 :3 0
75 :3 0 2b :4 0
fc 1 :8 0 a13
f8 :4 0 9fe :3 0
9d :3 0 a5 :2 0
5c1 a01 a02 :3 0
1b :3 0 ac :3 0
a04 a05 0 31
:2 0 a06 a07 0
a09 5c4 a10 1b
:3 0 ac :3 0 a0a
a0b 0 f9 :2 0
a0c a0d 0 a0f
5c6 a11 a03 a09
0 a12 0 a0f
0 a12 5c8 0
a13 5cb a5d ae
:3 0 1b :3 0 ac
:3 0 a16 a17 0
ad :3 0 a18 a19
0 a53 79 :3 0
7a :3 0 a1b a1c
0 79 :3 0 89
:3 0 a1e a1f 0
25 :2 0 2 :4 0
fd :2 0 8b :2 0
49 :2 0 5ce a24
a26 :3 0 5d1 a20
a28 a1d a2a a29
:2 0 7c :3 0 8c
:3 0 a2c a2d 0
7e :4 0 fe :4 0
81 :2 0 82 :3 0
5d5 a31 a33 :3 0
81 :2 0 95 :4 0
5d8 a35 a37 :3 0
81 :2 0 b1 :4 0
5db a39 a3b :3 0
81 :2 0 ad :3 0
5de a3d a3f :3 0
81 :2 0 b2 :4 0
5e1 a41 a43 :3 0
81 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 5e4 a46
a4a 5e8 a45 a4c
:3 0 5eb a2e a4e
:2 0 a50 5ee a51
a2b a50 0 a52
5f0 0 a53 5f2
a56 :3 0 a56 0
a56 a55 a53 a54
:6 0 a58 10 :3 0
5f5 a5a 5f7 a59
a58 :2 0 a5b 5f9
:2 0 a5d 0 a5d
a5c a13 a5b :6 0
a5f 1 :3 0 5fb
a60 9f1 a5f 0
a61 5fd 0 a62
5ff a7c 1b :3 0
ac :3 0 a63 a64
0 ef :3 0 2b
:3 0 48 :3 0 48
:3 0 32 :3 0 4c
:3 0 4e :3 0 3d
:3 0 36 :3 0 33
:3 0 33 :3 0 33
:3 0 3c :3 0 37
:3 0 38 :3 0 56
:3 0 51 :3 0 2f
:3 0 602 a66 a78
a65 a79 0 a7b
614 a7d 9d2 a62
0 a7e 0 a7b
0 a7e 616 0
a7f 619 a81 904
9be 0 a82 0
a7f 0 a82 61c
0 c81 1b :3 0
ac :3 0 a83 a84
0 a5 :2 0 31
:2 0 621 a86 a88
:3 0 a89 :2 0 ee
:3 0 86 :3 0 f
:3 0 31 :2 0 624
a8c a8f 35 :2 0
627 a8b a92 a93
:2 0 a5 :2 0 35
:2 0 62c a95 a97
:3 0 a98 :2 0 a8a
a9a a99 :2 0 86
:3 0 c :3 0 31
:2 0 62f a9c a9f
86 :3 0 a5 :2 0
a :3 0 31 :2 0
632 aa1 aa5 637
aa2 aa7 :3 0 aa8
:2 0 86 :3 0 e
:3 0 31 :2 0 63a
aaa aad a5 :2 0
31 :2 0 63f aaf
ab1 :3 0 ab2 :2 0
aa9 ab4 ab3 :2 0
86 :3 0 d :3 0
31 :2 0 642 ab6
ab9 a5 :2 0 ec
:2 0 647 abb abd
:3 0 abe :2 0 ab5
ac0 abf :2 0 d3
:3 0 ff :3 0 d
:3 0 cf :3 0 39
:3 0 d2 :3 0 38
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 f4
:3 0 f5 :3 0 f6
:3 0 100 :3 0 4c
:3 0 101 :3 0 4e
:3 0 cd :3 0 c
:3 0 f0 :3 0 e
:3 0 75 :3 0 2b
:4 0 102 1 :8 0
aef f8 :4 0 ada
:3 0 9d :3 0 a5
:2 0 64c add ade
:3 0 1b :3 0 ac
:3 0 ae0 ae1 0
31 :2 0 ae2 ae3
0 ae5 64f aec
1b :3 0 ac :3 0
ae6 ae7 0 f9
:2 0 ae8 ae9 0
aeb 651 aed adf
ae5 0 aee 0
aeb 0 aee 653
0 aef 656 b39
ae :3 0 1b :3 0
ac :3 0 af2 af3
0 ad :3 0 af4
af5 0 b2f 79
:3 0 7a :3 0 af7
af8 0 79 :3 0
89 :3 0 afa afb
0 25 :2 0 2
:4 0 103 :2 0 8b
:2 0 49 :2 0 659
b00 b02 :3 0 65c
afc b04 af9 b06
b05 :2 0 7c :3 0
8c :3 0 b08 b09
0 7e :4 0 104
:4 0 81 :2 0 82
:3 0 660 b0d b0f
:3 0 81 :2 0 95
:4 0 663 b11 b13
:3 0 81 :2 0 b1
:4 0 666 b15 b17
:3 0 81 :2 0 ad
:3 0 669 b19 b1b
:3 0 81 :2 0 b2
:4 0 66c b1d b1f
:3 0 81 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 66f
b22 b26 673 b21
b28 :3 0 676 b0a
b2a :2 0 b2c 679
b2d b07 b2c 0
b2e 67b 0 b2f
67d b32 :3 0 b32
0 b32 b31 b2f
b30 :6 0 b34 12
:3 0 680 b36 682
b35 b34 :2 0 b37
684 :2 0 b39 0
b39 b38 aef b37
:6 0 c0c 1 :3 0
74 :3 0 76 :3 0
71 :3 0 73 :3 0
6b :3 0 2d :3 0
75 :3 0 2b :4 0
105 1 :8 0 b59
f8 :4 0 b44 :3 0
9d :3 0 a5 :2 0
688 b47 b48 :3 0
1b :3 0 ac :3 0
b4a b4b 0 31
:2 0 b4c b4d 0
b4f 68b b56 1b
:3 0 ac :3 0 b50
b51 0 f9 :2 0
b52 b53 0 b55
68d b57 b49 b4f
0 b58 0 b55
0 b58 68f 0
b59 692 ba3 ae
:3 0 1b :3 0 ac
:3 0 b5c b5d 0
ad :3 0 b5e b5f
0 b99 79 :3 0
7a :3 0 b61 b62
0 79 :3 0 89
:3 0 b64 b65 0
25 :2 0 2 :4 0
106 :2 0 8b :2 0
49 :2 0 695 b6a
b6c :3 0 698 b66
b6e b63 b70 b6f
:2 0 7c :3 0 8c
:3 0 b72 b73 0
7e :4 0 107 :4 0
81 :2 0 82 :3 0
69c b77 b79 :3 0
81 :2 0 95 :4 0
69f b7b b7d :3 0
81 :2 0 b1 :4 0
6a2 b7f b81 :3 0
81 :2 0 ad :3 0
6a5 b83 b85 :3 0
81 :2 0 b2 :4 0
6a8 b87 b89 :3 0
81 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 6ab b8c
b90 6af b8b b92
:3 0 6b2 b74 b94
:2 0 b96 6b5 b97
b71 b96 0 b98
6b7 0 b99 6b9
b9c :3 0 b9c 0
b9c b9b b99 b9a
:6 0 b9e 14 :3 0
6bc ba0 6be b9f
b9e :2 0 ba1 6c0
:2 0 ba3 0 ba3
ba2 b59 ba1 :6 0
c0c 1 :3 0 d3
:3 0 108 :3 0 4e
:3 0 75 :3 0 2b
:4 0 109 1 :8 0
bc0 f8 :4 0 bab
:3 0 9d :3 0 a5
:2 0 6c4 bae baf
:3 0 1b :3 0 ac
:3 0 bb1 bb2 0
31 :2 0 bb3 bb4
0 bb6 6c7 bbd
1b :3 0 ac :3 0
bb7 bb8 0 f9
:2 0 bb9 bba 0
bbc 6c9 bbe bb0
bb6 0 bbf 0
bbc 0 bbf 6cb
0 bc0 6ce c0a
ae :3 0 1b :3 0
ac :3 0 bc3 bc4
0 ad :3 0 bc5
bc6 0 c00 79
:3 0 7a :3 0 bc8
bc9 0 79 :3 0
89 :3 0 bcb bcc
0 25 :2 0 2
:4 0 10a :2 0 8b
:2 0 49 :2 0 6d1
bd1 bd3 :3 0 6d4
bcd bd5 bca bd7
bd6 :2 0 7c :3 0
8c :3 0 bd9 bda
0 7e :4 0 10b
:4 0 81 :2 0 82
:3 0 6d8 bde be0
:3 0 81 :2 0 95
:4 0 6db be2 be4
:3 0 81 :2 0 b1
:4 0 6de be6 be8
:3 0 81 :2 0 ad
:3 0 6e1 bea bec
:3 0 81 :2 0 b2
:4 0 6e4 bee bf0
:3 0 81 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 6e7
bf3 bf7 6eb bf2
bf9 :3 0 6ee bdb
bfb :2 0 bfd 6f1
bfe bd8 bfd 0
bff 6f3 0 c00
6f5 c03 :3 0 c03
0 c03 c02 c00
c01 :6 0 c05 16
:3 0 6f8 c07 6fa
c06 c05 :2 0 c08
6fc :2 0 c0a 0
c0a c09 bc0 c08
:6 0 c0c 1 :3 0
6fe c7b d3 :3 0
f0 :3 0 e :3 0
f1 :3 0 f2 :3 0
f3 :3 0 f4 :3 0
f5 :3 0 f6 :3 0
75 :3 0 2b :4 0
10c 1 :8 0 c2e
f8 :4 0 c19 :3 0
9d :3 0 a5 :2 0
704 c1c c1d :3 0
1b :3 0 ac :3 0
c1f c20 0 31
:2 0 c21 c22 0
c24 707 c2b 1b
:3 0 ac :3 0 c25
c26 0 f9 :2 0
c27 c28 0 c2a
709 c2c c1e c24
0 c2d 0 c2a
0 c2d 70b 0
c2e 70e c78 ae
:3 0 1b :3 0 ac
:3 0 c31 c32 0
ad :3 0 c33 c34
0 c6e 79 :3 0
7a :3 0 c36 c37
0 79 :3 0 89
:3 0 c39 c3a 0
25 :2 0 2 :4 0
10d :2 0 8b :2 0
49 :2 0 711 c3f
c41 :3 0 714 c3b
c43 c38 c45 c44
:2 0 7c :3 0 8c
:3 0 c47 c48 0
7e :4 0 10e :4 0
81 :2 0 82 :3 0
718 c4c c4e :3 0
81 :2 0 95 :4 0
71b c50 c52 :3 0
81 :2 0 b1 :4 0
71e c54 c56 :3 0
81 :2 0 ad :3 0
721 c58 c5a :3 0
81 :2 0 b2 :4 0
724 c5c c5e :3 0
81 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 727 c61
c65 72b c60 c67
:3 0 72e c49 c69
:2 0 c6b 731 c6c
c46 c6b 0 c6d
733 0 c6e 735
c71 :3 0 c71 0
c71 c70 c6e c6f
:6 0 c73 18 :3 0
738 c75 73a c74
c73 :2 0 c76 73c
:2 0 c78 0 c78
c77 c2e c76 :6 0
c7a 1 :3 0 73e
c7c ac1 c0c 0
c7d 0 c7a 0
c7d 740 0 c7e
743 c7f a9b c7e
0 c80 745 0
c81 747 1073 41
:3 0 ee :3 0 86
:3 0 41 :3 0 31
:2 0 74a c84 c87
97 :3 0 10f :3 0
c89 c8a 0 74d
c83 c8c c82 c8d
0 1072 86 :3 0
58 :3 0 31 :2 0
750 c8f c92 a5
:2 0 49 :2 0 755
c94 c96 :3 0 1b
:3 0 ac :3 0 c98
c99 0 ef :3 0
2b :3 0 48 :3 0
48 :3 0 32 :3 0
4c :3 0 4e :3 0
3d :3 0 36 :3 0
33 :3 0 33 :3 0
41 :3 0 3c :3 0
37 :3 0 38 :3 0
56 :3 0 51 :3 0
2f :3 0 758 c9b
cad c9a cae 0
d44 1b :3 0 ac
:3 0 cb0 cb1 0
a5 :2 0 31 :2 0
76c cb3 cb5 :3 0
cb6 :2 0 86 :3 0
f :3 0 31 :2 0
76f cb8 cbb a5
:2 0 35 :2 0 774
cbd cbf :3 0 cc0
:2 0 cb7 cc2 cc1
:2 0 86 :3 0 3e
:3 0 31 :2 0 777
cc4 cc7 a5 :2 0
31 :2 0 77c cc9
ccb :3 0 ccc :2 0
cc3 cce ccd :2 0
d3 :3 0 f0 :3 0
e :3 0 f1 :3 0
f2 :3 0 f3 :3 0
f4 :3 0 f5 :3 0
f6 :3 0 6b :3 0
2d :3 0 cb :3 0
2e :3 0 cc :3 0
2c :4 0 110 1
:8 0 cf5 f8 :4 0
ce0 :3 0 9d :3 0
a5 :2 0 781 ce3
ce4 :3 0 1b :3 0
ac :3 0 ce6 ce7
0 31 :2 0 ce8
ce9 0 ceb 784
cf2 1b :3 0 ac
:3 0 cec ced 0
f9 :2 0 cee cef
0 cf1 786 cf3
ce5 ceb 0 cf4
0 cf1 0 cf4
788 0 cf5 78b
d3f ae :3 0 1b
:3 0 ac :3 0 cf8
cf9 0 ad :3 0
cfa cfb 0 d35
79 :3 0 7a :3 0
cfd cfe 0 79
:3 0 89 :3 0 d00
d01 0 25 :2 0
2 :4 0 111 :2 0
8b :2 0 49 :2 0
78e d06 d08 :3 0
791 d02 d0a cff
d0c d0b :2 0 7c
:3 0 8c :3 0 d0e
d0f 0 7e :4 0
112 :4 0 81 :2 0
82 :3 0 795 d13
d15 :3 0 81 :2 0
95 :4 0 798 d17
d19 :3 0 81 :2 0
b1 :4 0 79b d1b
d1d :3 0 81 :2 0
ad :3 0 79e d1f
d21 :3 0 81 :2 0
b2 :4 0 7a1 d23
d25 :3 0 81 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
7a4 d28 d2c 7a8
d27 d2e :3 0 7ab
d10 d30 :2 0 d32
7ae d33 d0d d32
0 d34 7b0 0
d35 7b2 d38 :3 0
d38 0 d38 d37
d35 d36 :6 0 d3a
1a :3 0 7b5 d3c
7b7 d3b d3a :2 0
d3d 7b9 :2 0 d3f
0 d3f d3e cf5
d3d :6 0 d41 1
:3 0 7bb d42 ccf
d41 0 d43 7bd
0 d44 7bf 106f
12 :3 0 c3 :2 0
7c2 d46 d47 :3 0
d48 :2 0 50 :3 0
12 :3 0 d4a d4b
0 fb8 b3 :3 0
50 :3 0 b3 :3 0
50 :3 0 b3 :3 0
50 :3 0 b3 :3 0
50 :3 0 50 :3 0
ba :4 0 113 1
:8 0 d5d 1b :3 0
ac :3 0 d58 d59
0 ad :3 0 d5a
d5b 0 d5d 7c4
da7 ae :3 0 1b
:3 0 ac :3 0 d60
d61 0 ad :3 0
d62 d63 0 d9d
79 :3 0 7a :3 0
d65 d66 0 79
:3 0 89 :3 0 d68
d69 0 25 :2 0
2 :4 0 114 :2 0
8b :2 0 49 :2 0
7c7 d6e d70 :3 0
7ca d6a d72 d67
d74 d73 :2 0 7c
:3 0 8c :3 0 d76
d77 0 7e :4 0
115 :4 0 81 :2 0
82 :3 0 7ce d7b
d7d :3 0 81 :2 0
95 :4 0 7d1 d7f
d81 :3 0 81 :2 0
b1 :4 0 7d4 d83
d85 :3 0 81 :2 0
ad :3 0 7d7 d87
d89 :3 0 81 :2 0
b2 :4 0 7da d8b
d8d :3 0 81 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
7dd d90 d94 7e1
d8f d96 :3 0 7e4
d78 d98 :2 0 d9a
7e7 d9b d75 d9a
0 d9c 7e9 0
d9d 7eb da0 :3 0
da0 0 da0 d9f
d9d d9e :6 0 da2
1c :3 0 7ee da4
7f0 da3 da2 :2 0
da5 7f2 :2 0 da7
0 da7 da6 d5d
da5 :6 0 fb8 1
:3 0 c5 :3 0 116
:3 0 da9 daa 0
50 :3 0 4f :3 0
117 :2 0 7f4 dab
daf 8f :2 0 31
:2 0 7fa db1 db3
:3 0 30 :3 0 97
:3 0 118 :3 0 db6
db7 0 db5 db8
0 fb5 53 :3 0
49 :2 0 dba dbb
0 fb5 6c :3 0
29 :3 0 119 :3 0
11a :4 0 11b 1
:8 0 dc7 1b :3 0
ac :3 0 dc2 dc3
0 ad :3 0 dc4
dc5 0 dc7 7fd
e11 ae :3 0 1b
:3 0 ac :3 0 dca
dcb 0 ad :3 0
dcc dcd 0 e07
79 :3 0 7a :3 0
dcf dd0 0 79
:3 0 89 :3 0 dd2
dd3 0 25 :2 0
2 :4 0 11c :2 0
8b :2 0 49 :2 0
800 dd8 dda :3 0
803 dd4 ddc dd1
dde ddd :2 0 7c
:3 0 8c :3 0 de0
de1 0 7e :4 0
11d :4 0 81 :2 0
82 :3 0 807 de5
de7 :3 0 81 :2 0
95 :4 0 80a de9
deb :3 0 81 :2 0
b1 :4 0 80d ded
def :3 0 81 :2 0
ad :3 0 810 df1
df3 :3 0 81 :2 0
b2 :4 0 813 df5
df7 :3 0 81 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
816 dfa dfe 81a
df9 e00 :3 0 81d
de2 e02 :2 0 e04
820 e05 ddf e04
0 e06 822 0
e07 824 e0a :3 0
e0a 0 e0a e09
e07 e08 :6 0 e0c
1e :3 0 827 e0e
829 e0d e0c :2 0
e0f 82b :2 0 e11
0 e11 e10 dc7
e0f :6 0 fb5 1
:3 0 55 :3 0 11e
:3 0 53 :3 0 2e
:3 0 29 :3 0 30
:3 0 2f :3 0 2a
:3 0 82d e14 e1b
e13 e1c 0 fb5
86 :3 0 55 :3 0
31 :2 0 834 e1e
e21 a5 :2 0 31
:2 0 839 e23 e25
:3 0 26 :4 0 e27
e28 0 fb2 28
:4 0 e2a e2b 0
fb2 1d :4 0 e2d
e2e 0 fb2 24
:4 0 e30 e31 0
fb2 1f :4 0 e33
e34 0 fb2 11f
:3 0 64 :4 0 e39
:2 0 fb2 e37 e3a
:3 0 64 :3 0 1d
:3 0 24 :4 0 e3f
:2 0 fb2 e3b e40
:3 0 83c :3 0 64
:3 0 f8 :3 0 e41
e42 :3 0 1b :3 0
ac :3 0 e44 e45
0 31 :2 0 e46
e47 0 e49 83f
e50 1b :3 0 ac
:3 0 e4a e4b 0
f9 :2 0 e4c e4d
0 e4f 841 e51
e43 e49 0 e52
0 e4f 0 e52
843 0 fb2 120
:3 0 64 :4 0 e56
:2 0 e5c e54 0
1b :3 0 ac :3 0
e57 e58 0 ad
:3 0 e59 e5a 0
e5c 846 ea6 ae
:3 0 1b :3 0 ac
:3 0 e5f e60 0
ad :3 0 e61 e62
0 e9c 79 :3 0
7a :3 0 e64 e65
0 79 :3 0 89
:3 0 e67 e68 0
25 :2 0 2 :4 0
121 :2 0 8b :2 0
49 :2 0 849 e6d
e6f :3 0 84c e69
e71 e66 e73 e72
:2 0 7c :3 0 8c
:3 0 e75 e76 0
7e :4 0 122 :4 0
81 :2 0 82 :3 0
850 e7a e7c :3 0
81 :2 0 95 :4 0
853 e7e e80 :3 0
81 :2 0 b1 :4 0
856 e82 e84 :3 0
81 :2 0 ad :3 0
859 e86 e88 :3 0
81 :2 0 b2 :4 0
85c e8a e8c :3 0
81 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 85f e8f
e93 863 e8e e95
:3 0 866 e77 e97
:2 0 e99 869 e9a
e74 e99 0 e9b
86b 0 e9c 86d
e9f :3 0 e9f 0
e9f e9e e9c e9d
:6 0 ea1 20 :3 0
870 ea3 872 ea2
ea1 :2 0 ea4 874
:2 0 ea6 0 ea6
ea5 e5c ea4 :6 0
fb2 1 :3 0 123
:3 0 1f :3 0 124
:3 0 cc :3 0 2c
:4 0 125 1 :8 0
eb3 1b :3 0 ac
:3 0 eae eaf 0
ad :3 0 eb0 eb1
0 eb3 876 efd
ae :3 0 1b :3 0
ac :3 0 eb6 eb7
0 ad :3 0 eb8
eb9 0 ef3 79
:3 0 7a :3 0 ebb
ebc 0 79 :3 0
89 :3 0 ebe ebf
0 25 :2 0 2
:4 0 126 :2 0 8b
:2 0 49 :2 0 879
ec4 ec6 :3 0 87c
ec0 ec8 ebd eca
ec9 :2 0 7c :3 0
8c :3 0 ecc ecd
0 7e :4 0 127
:4 0 81 :2 0 82
:3 0 880 ed1 ed3
:3 0 81 :2 0 95
:4 0 883 ed5 ed7
:3 0 81 :2 0 b1
:4 0 886 ed9 edb
:3 0 81 :2 0 ad
:3 0 889 edd edf
:3 0 81 :2 0 b2
:4 0 88c ee1 ee3
:3 0 81 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 88f
ee6 eea 893 ee5
eec :3 0 896 ece
eee :2 0 ef0 899
ef1 ecb ef0 0
ef2 89b 0 ef3
89d ef6 :3 0 ef6
0 ef6 ef5 ef3
ef4 :6 0 ef8 22
:3 0 8a0 efa 8a2
ef9 ef8 :2 0 efb
8a4 :2 0 efd 0
efd efc eb3 efb
:6 0 fb2 1 :3 0
22 :3 0 128 :4 0
eff f00 0 fb2
20 :3 0 129 :4 0
f02 f03 0 fb2
20 :3 0 b3 :3 0
20 :3 0 81 :2 0
1f :3 0 8a6 f08
f0a :3 0 49 :2 0
21 :2 0 8a9 f06
f0e f05 f0f 0
fb2 20 :3 0 b3
:3 0 20 :3 0 81
:2 0 12a :4 0 8ad
f14 f16 :3 0 49
:2 0 21 :2 0 8b0
f12 f1a f11 f1b
0 fb2 20 :3 0
b3 :3 0 20 :3 0
81 :2 0 1d :3 0
8b4 f20 f22 :3 0
49 :2 0 21 :2 0
8b7 f1e f26 f1d
f27 0 fb2 20
:3 0 b3 :3 0 20
:3 0 81 :2 0 12b
:4 0 8bb f2c f2e
:3 0 49 :2 0 21
:2 0 8be f2a f32
f29 f33 0 fb2
55 :3 0 12c :3 0
2a :3 0 24 :3 0
33 :3 0 33 :3 0
48 :3 0 33 :3 0
22 :3 0 20 :3 0
2f :3 0 48 :3 0
48 :3 0 33 :3 0
26 :3 0 28 :3 0
2f :3 0 8c2 f36
f46 f35 f47 0
fb2 79 :3 0 7a
:3 0 f49 f4a 0
79 :3 0 89 :3 0
f4c f4d 0 27
:2 0 2 :4 0 12d
:2 0 8b :2 0 49
:2 0 8d2 f52 f54
:3 0 8d5 f4e f56
f4b f58 f57 :2 0
7c :3 0 8c :3 0
f5a f5b 0 7e
:4 0 12e :4 0 81
:2 0 82 :3 0 8d9
f5f f61 :3 0 81
:2 0 95 :4 0 8dc
f63 f65 :3 0 81
:2 0 96 :4 0 8df
f67 f69 :3 0 81
:2 0 86 :3 0 67
:3 0 31 :2 0 8e2
f6d f6f 87 :4 0
8e4 f6c f72 8e7
f6b f74 :3 0 81
:2 0 db :4 0 8ea
f76 f78 :3 0 81
:2 0 84 :4 0 8ed
f7a f7c :3 0 81
:2 0 2b :3 0 8f0
f7e f80 :3 0 81
:2 0 84 :4 0 8f3
f82 f84 :3 0 8f6
f5c f86 :2 0 f88
8f9 f89 f59 f88
0 f8a 8fb 0
fb2 79 :3 0 7a
:3 0 f8b f8c 0
79 :3 0 89 :3 0
f8e f8f 0 49
:2 0 2 :4 0 12f
:2 0 8b :2 0 49
:2 0 8fd f94 f96
:3 0 900 f90 f98
f8d f9a f99 :2 0
7c :3 0 8c :3 0
f9c f9d 0 7e
:4 0 130 :4 0 81
:2 0 82 :3 0 904
fa1 fa3 :3 0 907
f9e fa5 :2 0 fa7
90a fa8 f9b fa7
0 fa9 90c 0
fb2 9b :3 0 de
:3 0 faa fab 0
31 :2 0 2b :3 0
9d :3 0 90e fac
fb0 :2 0 fb2 912
fb3 e26 fb2 0
fb4 927 0 fb5
929 fb6 db4 fb5
0 fb7 92f 0
fb8 931 fb9 d49
fb8 0 fba 935
0 106e 3c :3 0
86 :3 0 3c :3 0
31 :2 0 937 fbc
fbf 8b :2 0 49
:2 0 93a fc1 fc3
:3 0 fbb fc4 0
106e 1b :3 0 ac
:3 0 fc6 fc7 0
ef :3 0 2b :3 0
48 :3 0 48 :3 0
32 :3 0 4c :3 0
4e :3 0 3d :3 0
36 :3 0 33 :3 0
33 :3 0 41 :3 0
3c :3 0 37 :3 0
38 :3 0 56 :3 0
51 :3 0 2f :3 0
93d fc9 fdb fc8
fdc 0 106e 1b
:3 0 ac :3 0 fde
fdf 0 a5 :2 0
31 :2 0 951 fe1
fe3 :3 0 fe4 :2 0
86 :3 0 f :3 0
31 :2 0 954 fe6
fe9 a5 :2 0 35
:2 0 959 feb fed
:3 0 fee :2 0 fe5
ff0 fef :2 0 86
:3 0 3e :3 0 31
:2 0 95c ff2 ff5
a5 :2 0 31 :2 0
961 ff7 ff9 :3 0
ffa :2 0 ff1 ffc
ffb :2 0 d3 :3 0
f0 :3 0 e :3 0
f1 :3 0 f2 :3 0
f3 :3 0 f4 :3 0
f5 :3 0 f6 :3 0
75 :3 0 2b :4 0
10c 1 :8 0 101f
f8 :4 0 100a :3 0
9d :3 0 a5 :2 0
966 100d 100e :3 0
1b :3 0 ac :3 0
1010 1011 0 31
:2 0 1012 1013 0
1015 969 101c 1b
:3 0 ac :3 0 1016
1017 0 f9 :2 0
1018 1019 0 101b
96b 101d 100f 1015
0 101e 0 101b
0 101e 96d 0
101f 970 1069 ae
:3 0 1b :3 0 ac
:3 0 1022 1023 0
ad :3 0 1024 1025
0 105f 79 :3 0
7a :3 0 1027 1028
0 79 :3 0 89
:3 0 102a 102b 0
25 :2 0 2 :4 0
131 :2 0 8b :2 0
49 :2 0 973 1030
1032 :3 0 976 102c
1034 1029 1036 1035
:2 0 7c :3 0 8c
:3 0 1038 1039 0
7e :4 0 132 :4 0
81 :2 0 82 :3 0
97a 103d 103f :3 0
81 :2 0 95 :4 0
97d 1041 1043 :3 0
81 :2 0 b1 :4 0
980 1045 1047 :3 0
81 :2 0 ad :3 0
983 1049 104b :3 0
81 :2 0 b2 :4 0
986 104d 104f :3 0
81 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 989 1052
1056 98d 1051 1058
:3 0 990 103a 105a
:2 0 105c 993 105d
1037 105c 0 105e
995 0 105f 997
1062 :3 0 1062 0
1062 1061 105f 1060
:6 0 1064 24 :3 0
99a 1066 99c 1065
1064 :2 0 1067 99e
:2 0 1069 0 1069
1068 101f 1067 :6 0
106b 1 :3 0 9a0
106c ffd 106b 0
106d 9a2 0 106e
9a4 1070 c97 d44
0 1071 0 106e
0 1071 9a9 0
1072 9ac 1074 8fb
c81 0 1075 0
1072 0 1075 9af
0 1bbb 1b :3 0
ac :3 0 1076 1077
0 c0 :2 0 31
:2 0 9b4 1079 107b
:3 0 79 :3 0 7a
:3 0 107d 107e 0
79 :3 0 89 :3 0
1080 1081 0 27
:2 0 2 :4 0 133
:2 0 8b :2 0 49
:2 0 9b7 1086 1088
:3 0 9ba 1082 108a
107f 108c 108b :2 0
7c :3 0 8c :3 0
108e 108f 0 7e
:4 0 134 :4 0 81
:2 0 82 :3 0 9be
1093 1095 :3 0 81
:2 0 95 :4 0 9c1
1097 1099 :3 0 81
:2 0 96 :4 0 9c4
109b 109d :3 0 81
:2 0 86 :3 0 67
:3 0 1b :3 0 ac
:3 0 10a2 10a3 0
9c7 10a1 10a5 87
:4 0 9c9 10a0 10a8
9cc 109f 10aa :3 0
81 :2 0 db :4 0
9cf 10ac 10ae :3 0
81 :2 0 84 :4 0
9d2 10b0 10b2 :3 0
81 :2 0 2b :3 0
9d5 10b4 10b6 :3 0
81 :2 0 84 :4 0
9d8 10b8 10ba :3 0
9db 1090 10bc :2 0
10be 9de 10bf 108d
10be 0 10c0 9e0
0 10ea 79 :3 0
7a :3 0 10c1 10c2
0 79 :3 0 89
:3 0 10c4 10c5 0
49 :2 0 2 :4 0
135 :2 0 8b :2 0
49 :2 0 9e2 10ca
10cc :3 0 9e5 10c6
10ce 10c3 10d0 10cf
:2 0 7c :3 0 8c
:3 0 10d2 10d3 0
7e :4 0 136 :4 0
81 :2 0 82 :3 0
9e9 10d7 10d9 :3 0
9ec 10d4 10db :2 0
10dd 9ef 10de 10d1
10dd 0 10df 9f1
0 10ea 9b :3 0
de :3 0 10e0 10e1
0 1b :3 0 ac
:3 0 10e3 10e4 0
2b :3 0 9d :3 0
9f3 10e2 10e8 :2 0
10ea 9f7 10eb 107c
10ea 0 10ec 9fb
0 1bbb 38 :3 0
11 :3 0 10ed 10ee
0 1bbb 86 :3 0
39 :3 0 31 :2 0
9fd 10f0 10f3 c0
:2 0 ec :2 0 a02
10f5 10f7 :3 0 10f8
:2 0 86 :3 0 38
:3 0 31 :2 0 a05
10fa 10fd a5 :2 0
31 :2 0 a0a 10ff
1101 :3 0 1102 :2 0
10f9 1104 1103 :2 0
38 :3 0 49 :2 0
1106 1107 0 1109
a0d 110a 1105 1109
0 110b a0f 0
1bbb 86 :3 0 58
:3 0 31 :2 0 a11
110c 110f a5 :2 0
49 :2 0 a16 1111
1113 :3 0 ee :3 0
86 :3 0 f :3 0
31 :2 0 a19 1116
1119 25 :2 0 a1c
1115 111c 111d :2 0
a5 :2 0 25 :2 0
a21 111f 1121 :3 0
12 :3 0 8e :2 0
a24 1124 1125 :3 0
1126 :2 0 4d :3 0
c3 :2 0 a26 1129
112a :3 0 112b :2 0
d3 :3 0 ff :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 f1 :3 0
f2 :3 0 f3 :3 0
f4 :3 0 f5 :3 0
f6 :3 0 100 :3 0
16 :3 0 101 :3 0
17 :3 0 cd :3 0
18 :3 0 137 :3 0
2b :4 0 138 1
:8 0 1158 f8 :4 0
1143 :3 0 9d :3 0
a5 :2 0 a2a 1146
1147 :3 0 1b :3 0
ac :3 0 1149 114a
0 31 :2 0 114b
114c 0 114e a2d
1155 1b :3 0 ac
:3 0 114f 1150 0
f9 :2 0 1151 1152
0 1154 a2f 1156
1148 114e 0 1157
0 1154 0 1157
a31 0 1158 a34
11a2 ae :3 0 1b
:3 0 ac :3 0 115b
115c 0 ad :3 0
115d 115e 0 1198
79 :3 0 7a :3 0
1160 1161 0 79
:3 0 89 :3 0 1163
1164 0 25 :2 0
2 :4 0 139 :2 0
8b :2 0 49 :2 0
a37 1169 116b :3 0
a3a 1165 116d 1162
116f 116e :2 0 7c
:3 0 8c :3 0 1171
1172 0 7e :4 0
13a :4 0 81 :2 0
82 :3 0 a3e 1176
1178 :3 0 81 :2 0
95 :4 0 a41 117a
117c :3 0 81 :2 0
b1 :4 0 a44 117e
1180 :3 0 81 :2 0
ad :3 0 a47 1182
1184 :3 0 81 :2 0
b2 :4 0 a4a 1186
1188 :3 0 81 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
a4d 118b 118f a51
118a 1191 :3 0 a54
1173 1193 :2 0 1195
a57 1196 1170 1195
0 1197 a59 0
1198 a5b 119b :3 0
119b 0 119b 119a
1198 1199 :6 0 119d
26 :3 0 a5e 119f
a60 119e 119d :2 0
11a0 a62 :2 0 11a2
0 11a2 11a1 1158
11a0 :6 0 11a4 1
:3 0 a64 1211 d3
:3 0 ff :3 0 d
:3 0 cf :3 0 39
:3 0 d2 :3 0 38
:3 0 137 :3 0 2b
:4 0 13b 1 :8 0
11c4 f8 :4 0 11af
:3 0 9d :3 0 a5
:2 0 a68 11b2 11b3
:3 0 1b :3 0 ac
:3 0 11b5 11b6 0
31 :2 0 11b7 11b8
0 11ba a6b 11c1
1b :3 0 ac :3 0
11bb 11bc 0 f9
:2 0 11bd 11be 0
11c0 a6d 11c2 11b4
11ba 0 11c3 0
11c0 0 11c3 a6f
0 11c4 a72 120e
ae :3 0 1b :3 0
ac :3 0 11c7 11c8
0 ad :3 0 11c9
11ca 0 1204 79
:3 0 7a :3 0 11cc
11cd 0 79 :3 0
89 :3 0 11cf 11d0
0 25 :2 0 2
:4 0 13c :2 0 8b
:2 0 49 :2 0 a75
11d5 11d7 :3 0 a78
11d1 11d9 11ce 11db
11da :2 0 7c :3 0
8c :3 0 11dd 11de
0 7e :4 0 13d
:4 0 81 :2 0 82
:3 0 a7c 11e2 11e4
:3 0 81 :2 0 95
:4 0 a7f 11e6 11e8
:3 0 81 :2 0 b1
:4 0 a82 11ea 11ec
:3 0 81 :2 0 ad
:3 0 a85 11ee 11f0
:3 0 81 :2 0 b2
:4 0 a88 11f2 11f4
:3 0 81 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 a8b
11f7 11fb a8f 11f6
11fd :3 0 a92 11df
11ff :2 0 1201 a95
1202 11dc 1201 0
1203 a97 0 1204
a99 1207 :3 0 1207
0 1207 1206 1204
1205 :6 0 1209 28
:3 0 a9c 120b a9e
120a 1209 :2 0 120c
aa0 :2 0 120e 0
120e 120d 11c4 120c
:6 0 1210 1 :3 0
aa2 1212 112c 11a4
0 1213 0 1210
0 1213 aa4 0
1214 aa7 1358 4d
:3 0 c3 :2 0 aa9
1216 1217 :3 0 1218
:2 0 d3 :3 0 ff
:3 0 d :3 0 cf
:3 0 39 :3 0 d2
:3 0 38 :3 0 13e
:3 0 13f :3 0 c4
:3 0 12 :3 0 13e
:3 0 140 :3 0 13f
:3 0 c4 :3 0 13
:3 0 140 :3 0 141
:3 0 13f :3 0 14
:3 0 141 :3 0 142
:3 0 13f :3 0 15
:3 0 142 :3 0 143
:3 0 144 :3 0 145
:3 0 146 :3 0 147
:3 0 148 :3 0 149
:3 0 14a :3 0 144
:3 0 12 :3 0 146
:3 0 13 :3 0 148
:3 0 14 :3 0 14a
:3 0 15 :3 0 14b
:3 0 14c :3 0 14d
:3 0 14e :3 0 14f
:3 0 150 :3 0 151
:3 0 152 :3 0 13f
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 f4
:3 0 f5 :3 0 f6
:3 0 100 :3 0 16
:3 0 101 :3 0 17
:3 0 cd :3 0 18
:3 0 137 :3 0 2b
:4 0 153 1 :8 0
1270 f8 :4 0 125b
:3 0 9d :3 0 a5
:2 0 aad 125e 125f
:3 0 1b :3 0 ac
:3 0 1261 1262 0
31 :2 0 1263 1264
0 1266 ab0 126d
1b :3 0 ac :3 0
1267 1268 0 f9
:2 0 1269 126a 0
126c ab2 126e 1260
1266 0 126f 0
126c 0 126f ab4
0 1270 ab7 12ba
ae :3 0 1b :3 0
ac :3 0 1273 1274
0 ad :3 0 1275
1276 0 12b0 79
:3 0 7a :3 0 1278
1279 0 79 :3 0
89 :3 0 127b 127c
0 25 :2 0 2
:4 0 154 :2 0 8b
:2 0 49 :2 0 aba
1281 1283 :3 0 abd
127d 1285 127a 1287
1286 :2 0 7c :3 0
8c :3 0 1289 128a
0 7e :4 0 155
:4 0 81 :2 0 82
:3 0 ac1 128e 1290
:3 0 81 :2 0 95
:4 0 ac4 1292 1294
:3 0 81 :2 0 b1
:4 0 ac7 1296 1298
:3 0 81 :2 0 ad
:3 0 aca 129a 129c
:3 0 81 :2 0 b2
:4 0 acd 129e 12a0
:3 0 81 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 ad0
12a3 12a7 ad4 12a2
12a9 :3 0 ad7 128b
12ab :2 0 12ad ada
12ae 1288 12ad 0
12af adc 0 12b0
ade 12b3 :3 0 12b3
0 12b3 12b2 12b0
12b1 :6 0 12b5 2a
:3 0 ae1 12b7 ae3
12b6 12b5 :2 0 12b8
ae5 :2 0 12ba 0
12ba 12b9 1270 12b8
:6 0 12bc 1 :3 0
ae7 1354 d3 :3 0
ff :3 0 d :3 0
cf :3 0 39 :3 0
d2 :3 0 38 :3 0
13e :3 0 13f :3 0
c4 :3 0 12 :3 0
13e :3 0 140 :3 0
13f :3 0 c4 :3 0
13 :3 0 140 :3 0
141 :3 0 13f :3 0
14 :3 0 141 :3 0
142 :3 0 13f :3 0
15 :3 0 142 :3 0
143 :3 0 144 :3 0
145 :3 0 146 :3 0
147 :3 0 148 :3 0
149 :3 0 14a :3 0
144 :3 0 12 :3 0
146 :3 0 13 :3 0
148 :3 0 14 :3 0
14a :3 0 15 :3 0
14b :3 0 14c :3 0
14d :3 0 14e :3 0
14f :3 0 150 :3 0
151 :3 0 152 :3 0
13f :3 0 137 :3 0
2b :4 0 156 1
:8 0 1307 f8 :4 0
12f2 :3 0 9d :3 0
a5 :2 0 aeb 12f5
12f6 :3 0 1b :3 0
ac :3 0 12f8 12f9
0 31 :2 0 12fa
12fb 0 12fd aee
1304 1b :3 0 ac
:3 0 12fe 12ff 0
f9 :2 0 1300 1301
0 1303 af0 1305
12f7 12fd 0 1306
0 1303 0 1306
af2 0 1307 af5
1351 ae :3 0 1b
:3 0 ac :3 0 130a
130b 0 ad :3 0
130c 130d 0 1347
79 :3 0 7a :3 0
130f 1310 0 79
:3 0 89 :3 0 1312
1313 0 25 :2 0
2 :4 0 157 :2 0
8b :2 0 49 :2 0
af8 1318 131a :3 0
afb 1314 131c 1311
131e 131d :2 0 7c
:3 0 8c :3 0 1320
1321 0 7e :4 0
158 :4 0 81 :2 0
82 :3 0 aff 1325
1327 :3 0 81 :2 0
95 :4 0 b02 1329
132b :3 0 81 :2 0
b1 :4 0 b05 132d
132f :3 0 81 :2 0
ad :3 0 b08 1331
1333 :3 0 81 :2 0
b2 :4 0 b0b 1335
1337 :3 0 81 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
b0e 133a 133e b12
1339 1340 :3 0 b15
1322 1342 :2 0 1344
b18 1345 131f 1344
0 1346 b1a 0
1347 b1c 134a :3 0
134a 0 134a 1349
1347 1348 :6 0 134c
2c :3 0 b1f 134e
b21 134d 134c :2 0
134f b23 :2 0 1351
0 1351 1350 1307
134f :6 0 1353 1
:3 0 b25 1355 1219
12bc 0 1356 0
1353 0 1356 b27
0 1357 b2a 1359
1127 1214 0 135a
0 1357 0 135a
b2c 0 135c 159
:3 0 b2f 13d3 86
:3 0 3e :3 0 31
:2 0 b31 135d 1360
a5 :2 0 31 :2 0
b36 1362 1364 :3 0
d3 :3 0 ff :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 137 :3 0
2b :4 0 15a 1
:8 0 1385 f8 :4 0
1370 :3 0 9d :3 0
a5 :2 0 b3b 1373
1374 :3 0 1b :3 0
ac :3 0 1376 1377
0 31 :2 0 1378
1379 0 137b b3e
1382 1b :3 0 ac
:3 0 137c 137d 0
f9 :2 0 137e 137f
0 1381 b40 1383
1375 137b 0 1384
0 1381 0 1384
b42 0 1385 b45
13cf ae :3 0 1b
:3 0 ac :3 0 1388
1389 0 ad :3 0
138a 138b 0 13c5
79 :3 0 7a :3 0
138d 138e 0 79
:3 0 89 :3 0 1390
1391 0 25 :2 0
2 :4 0 15b :2 0
8b :2 0 49 :2 0
b48 1396 1398 :3 0
b4b 1392 139a 138f
139c 139b :2 0 7c
:3 0 8c :3 0 139e
139f 0 7e :4 0
15c :4 0 81 :2 0
82 :3 0 b4f 13a3
13a5 :3 0 81 :2 0
95 :4 0 b52 13a7
13a9 :3 0 81 :2 0
b1 :4 0 b55 13ab
13ad :3 0 81 :2 0
ad :3 0 b58 13af
13b1 :3 0 81 :2 0
b2 :4 0 b5b 13b3
13b5 :3 0 81 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
b5e 13b8 13bc b62
13b7 13be :3 0 b65
13a0 13c0 :2 0 13c2
b68 13c3 139d 13c2
0 13c4 b6a 0
13c5 b6c 13c8 :3 0
13c8 0 13c8 13c7
13c5 13c6 :6 0 13ca
2e :3 0 b6f 13cc
b71 13cb 13ca :2 0
13cd b73 :2 0 13cf
0 13cf 13ce 1385
13cd :6 0 13d1 1
:3 0 b75 13d2 1365
13d1 0 13d4 1122
135c 0 13d4 b77
0 13d5 b7a 1792
ee :3 0 86 :3 0
f :3 0 31 :2 0
b7c 13d7 13da 25
:2 0 b7f 13d6 13dd
13de :2 0 a5 :2 0
25 :2 0 b84 13e0
13e2 :3 0 12 :3 0
8e :2 0 b87 13e5
13e6 :3 0 13e7 :2 0
4d :3 0 c3 :2 0
b89 13ea 13eb :3 0
13ec :2 0 d3 :3 0
ff :3 0 d :3 0
cf :3 0 39 :3 0
d2 :3 0 38 :3 0
f1 :3 0 f2 :3 0
f3 :3 0 f4 :3 0
f5 :3 0 f6 :3 0
100 :3 0 16 :3 0
101 :3 0 17 :3 0
cd :3 0 18 :3 0
75 :3 0 2b :4 0
15d 1 :8 0 1419
f8 :4 0 1404 :3 0
9d :3 0 a5 :2 0
b8d 1407 1408 :3 0
1b :3 0 ac :3 0
140a 140b 0 31
:2 0 140c 140d 0
140f b90 1416 1b
:3 0 ac :3 0 1410
1411 0 f9 :2 0
1412 1413 0 1415
b92 1417 1409 140f
0 1418 0 1415
0 1418 b94 0
1419 b97 1463 ae
:3 0 1b :3 0 ac
:3 0 141c 141d 0
ad :3 0 141e 141f
0 1459 79 :3 0
7a :3 0 1421 1422
0 79 :3 0 89
:3 0 1424 1425 0
25 :2 0 2 :4 0
15e :2 0 8b :2 0
49 :2 0 b9a 142a
142c :3 0 b9d 1426
142e 1423 1430 142f
:2 0 7c :3 0 8c
:3 0 1432 1433 0
7e :4 0 15f :4 0
81 :2 0 82 :3 0
ba1 1437 1439 :3 0
81 :2 0 95 :4 0
ba4 143b 143d :3 0
81 :2 0 b1 :4 0
ba7 143f 1441 :3 0
81 :2 0 ad :3 0
baa 1443 1445 :3 0
81 :2 0 b2 :4 0
bad 1447 1449 :3 0
81 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 bb0 144c
1450 bb4 144b 1452
:3 0 bb7 1434 1454
:2 0 1456 bba 1457
1431 1456 0 1458
bbc 0 1459 bbe
145c :3 0 145c 0
145c 145b 1459 145a
:6 0 145e 30 :3 0
bc1 1460 bc3 145f
145e :2 0 1461 bc5
:2 0 1463 0 1463
1462 1419 1461 :6 0
1465 1 :3 0 bc7
14d4 d3 :3 0 ff
:3 0 d :3 0 cf
:3 0 39 :3 0 d2
:3 0 38 :3 0 cd
:3 0 c :3 0 75
:3 0 2b :4 0 160
1 :8 0 1487 f8
:4 0 1472 :3 0 9d
:3 0 a5 :2 0 bcb
1475 1476 :3 0 1b
:3 0 ac :3 0 1478
1479 0 31 :2 0
147a 147b 0 147d
bce 1484 1b :3 0
ac :3 0 147e 147f
0 f9 :2 0 1480
1481 0 1483 bd0
1485 1477 147d 0
1486 0 1483 0
1486 bd2 0 1487
bd5 14d1 ae :3 0
1b :3 0 ac :3 0
148a 148b 0 ad
:3 0 148c 148d 0
14c7 79 :3 0 7a
:3 0 148f 1490 0
79 :3 0 89 :3 0
1492 1493 0 25
:2 0 2 :4 0 161
:2 0 8b :2 0 49
:2 0 bd8 1498 149a
:3 0 bdb 1494 149c
1491 149e 149d :2 0
7c :3 0 8c :3 0
14a0 14a1 0 7e
:4 0 162 :4 0 81
:2 0 82 :3 0 bdf
14a5 14a7 :3 0 81
:2 0 95 :4 0 be2
14a9 14ab :3 0 81
:2 0 b1 :4 0 be5
14ad 14af :3 0 81
:2 0 ad :3 0 be8
14b1 14b3 :3 0 81
:2 0 b2 :4 0 beb
14b5 14b7 :3 0 81
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 bee 14ba 14be
bf2 14b9 14c0 :3 0
bf5 14a2 14c2 :2 0
14c4 bf8 14c5 149f
14c4 0 14c6 bfa
0 14c7 bfc 14ca
:3 0 14ca 0 14ca
14c9 14c7 14c8 :6 0
14cc 32 :3 0 bff
14ce c01 14cd 14cc
:2 0 14cf c03 :2 0
14d1 0 14d1 14d0
1487 14cf :6 0 14d3
1 :3 0 c05 14d5
13ed 1465 0 14d6
0 14d3 0 14d6
c07 0 14d7 c0a
161d 4d :3 0 c3
:2 0 c0c 14d9 14da
:3 0 14db :2 0 d3
:3 0 ff :3 0 d
:3 0 cf :3 0 39
:3 0 d2 :3 0 38
:3 0 13e :3 0 13f
:3 0 c4 :3 0 12
:3 0 13e :3 0 140
:3 0 13f :3 0 c4
:3 0 13 :3 0 140
:3 0 141 :3 0 13f
:3 0 14 :3 0 141
:3 0 142 :3 0 13f
:3 0 15 :3 0 142
:3 0 143 :3 0 144
:3 0 145 :3 0 146
:3 0 147 :3 0 148
:3 0 149 :3 0 14a
:3 0 144 :3 0 12
:3 0 146 :3 0 13
:3 0 148 :3 0 14
:3 0 14a :3 0 15
:3 0 14b :3 0 14c
:3 0 14d :3 0 14e
:3 0 14f :3 0 150
:3 0 151 :3 0 152
:3 0 13f :3 0 f1
:3 0 f2 :3 0 f3
:3 0 f4 :3 0 f5
:3 0 f6 :3 0 100
:3 0 16 :3 0 101
:3 0 17 :3 0 cd
:3 0 18 :3 0 75
:3 0 2b :4 0 163
1 :8 0 1533 f8
:4 0 151e :3 0 9d
:3 0 a5 :2 0 c10
1521 1522 :3 0 1b
:3 0 ac :3 0 1524
1525 0 31 :2 0
1526 1527 0 1529
c13 1530 1b :3 0
ac :3 0 152a 152b
0 f9 :2 0 152c
152d 0 152f c15
1531 1523 1529 0
1532 0 152f 0
1532 c17 0 1533
c1a 157d ae :3 0
1b :3 0 ac :3 0
1536 1537 0 ad
:3 0 1538 1539 0
1573 79 :3 0 7a
:3 0 153b 153c 0
79 :3 0 89 :3 0
153e 153f 0 25
:2 0 2 :4 0 164
:2 0 8b :2 0 49
:2 0 c1d 1544 1546
:3 0 c20 1540 1548
153d 154a 1549 :2 0
7c :3 0 8c :3 0
154c 154d 0 7e
:4 0 165 :4 0 81
:2 0 82 :3 0 c24
1551 1553 :3 0 81
:2 0 95 :4 0 c27
1555 1557 :3 0 81
:2 0 b1 :4 0 c2a
1559 155b :3 0 81
:2 0 ad :3 0 c2d
155d 155f :3 0 81
:2 0 b2 :4 0 c30
1561 1563 :3 0 81
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 c33 1566 156a
c37 1565 156c :3 0
c3a 154e 156e :2 0
1570 c3d 1571 154b
1570 0 1572 c3f
0 1573 c41 1576
:3 0 1576 0 1576
1575 1573 1574 :6 0
1578 34 :3 0 c44
157a c46 1579 1578
:2 0 157b c48 :2 0
157d 0 157d 157c
1533 157b :6 0 157f
1 :3 0 c4a 1619
d3 :3 0 ff :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 cd :3 0
c :3 0 13e :3 0
13f :3 0 c4 :3 0
12 :3 0 13e :3 0
140 :3 0 13f :3 0
c4 :3 0 13 :3 0
140 :3 0 141 :3 0
13f :3 0 14 :3 0
141 :3 0 142 :3 0
13f :3 0 15 :3 0
142 :3 0 143 :3 0
144 :3 0 145 :3 0
146 :3 0 147 :3 0
148 :3 0 149 :3 0
14a :3 0 144 :3 0
12 :3 0 146 :3 0
13 :3 0 148 :3 0
14 :3 0 14a :3 0
15 :3 0 14b :3 0
14c :3 0 14d :3 0
14e :3 0 14f :3 0
150 :3 0 151 :3 0
152 :3 0 13f :3 0
75 :3 0 2b :4 0
166 1 :8 0 15cc
f8 :4 0 15b7 :3 0
9d :3 0 a5 :2 0
c4e 15ba 15bb :3 0
1b :3 0 ac :3 0
15bd 15be 0 31
:2 0 15bf 15c0 0
15c2 c51 15c9 1b
:3 0 ac :3 0 15c3
15c4 0 f9 :2 0
15c5 15c6 0 15c8
c53 15ca 15bc 15c2
0 15cb 0 15c8
0 15cb c55 0
15cc c58 1616 ae
:3 0 1b :3 0 ac
:3 0 15cf 15d0 0
ad :3 0 15d1 15d2
0 160c 79 :3 0
7a :3 0 15d4 15d5
0 79 :3 0 89
:3 0 15d7 15d8 0
25 :2 0 2 :4 0
167 :2 0 8b :2 0
49 :2 0 c5b 15dd
15df :3 0 c5e 15d9
15e1 15d6 15e3 15e2
:2 0 7c :3 0 8c
:3 0 15e5 15e6 0
7e :4 0 168 :4 0
81 :2 0 82 :3 0
c62 15ea 15ec :3 0
81 :2 0 95 :4 0
c65 15ee 15f0 :3 0
81 :2 0 b1 :4 0
c68 15f2 15f4 :3 0
81 :2 0 ad :3 0
c6b 15f6 15f8 :3 0
81 :2 0 b2 :4 0
c6e 15fa 15fc :3 0
81 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 c71 15ff
1603 c75 15fe 1605
:3 0 c78 15e7 1607
:2 0 1609 c7b 160a
15e4 1609 0 160b
c7d 0 160c c7f
160f :3 0 160f 0
160f 160e 160c 160d
:6 0 1611 36 :3 0
c82 1613 c84 1612
1611 :2 0 1614 c86
:2 0 1616 0 1616
1615 15cc 1614 :6 0
1618 1 :3 0 c88
161a 14dc 157f 0
161b 0 1618 0
161b c8a 0 161c
c8d 161e 13e8 14d7
0 161f 0 161c
0 161f c8f 0
1621 159 :3 0 c92
178f 86 :3 0 3e
:3 0 31 :2 0 c94
1622 1625 a5 :2 0
31 :2 0 c99 1627
1629 :3 0 47 :3 0
8e :2 0 c9c 162c
162d :3 0 162e :2 0
86 :3 0 e :3 0
31 :2 0 c9e 1630
1633 a5 :2 0 31
:2 0 ca3 1635 1637
:3 0 d3 :3 0 ff
:3 0 d :3 0 cf
:3 0 39 :3 0 d2
:3 0 38 :3 0 cd
:3 0 c :3 0 f0
:3 0 3d :3 0 c
:3 0 75 :3 0 2b
:4 0 169 1 :8 0
165d f8 :4 0 1648
:3 0 9d :3 0 a5
:2 0 ca8 164b 164c
:3 0 1b :3 0 ac
:3 0 164e 164f 0
31 :2 0 1650 1651
0 1653 cab 165a
1b :3 0 ac :3 0
1654 1655 0 f9
:2 0 1656 1657 0
1659 cad 165b 164d
1653 0 165c 0
1659 0 165c caf
0 165d cb2 16a7
ae :3 0 1b :3 0
ac :3 0 1660 1661
0 ad :3 0 1662
1663 0 169d 79
:3 0 7a :3 0 1665
1666 0 79 :3 0
89 :3 0 1668 1669
0 25 :2 0 2
:4 0 16a :2 0 8b
:2 0 49 :2 0 cb5
166e 1670 :3 0 cb8
166a 1672 1667 1674
1673 :2 0 7c :3 0
8c :3 0 1676 1677
0 7e :4 0 16b
:4 0 81 :2 0 82
:3 0 cbc 167b 167d
:3 0 81 :2 0 95
:4 0 cbf 167f 1681
:3 0 81 :2 0 b1
:4 0 cc2 1683 1685
:3 0 81 :2 0 ad
:3 0 cc5 1687 1689
:3 0 81 :2 0 b2
:4 0 cc8 168b 168d
:3 0 81 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 ccb
1690 1694 ccf 168f
1696 :3 0 cd2 1678
1698 :2 0 169a cd5
169b 1675 169a 0
169c cd7 0 169d
cd9 16a0 :3 0 16a0
0 16a0 169f 169d
169e :6 0 16a2 38
:3 0 cdc 16a4 cde
16a3 16a2 :2 0 16a5
ce0 :2 0 16a7 0
16a7 16a6 165d 16a5
:6 0 16a9 1 :3 0
ce2 1718 d3 :3 0
ff :3 0 d :3 0
cf :3 0 39 :3 0
d2 :3 0 38 :3 0
cd :3 0 c :3 0
75 :3 0 2b :4 0
160 1 :8 0 16cb
f8 :4 0 16b6 :3 0
9d :3 0 a5 :2 0
ce6 16b9 16ba :3 0
1b :3 0 ac :3 0
16bc 16bd 0 31
:2 0 16be 16bf 0
16c1 ce9 16c8 1b
:3 0 ac :3 0 16c2
16c3 0 f9 :2 0
16c4 16c5 0 16c7
ceb 16c9 16bb 16c1
0 16ca 0 16c7
0 16ca ced 0
16cb cf0 1715 ae
:3 0 1b :3 0 ac
:3 0 16ce 16cf 0
ad :3 0 16d0 16d1
0 170b 79 :3 0
7a :3 0 16d3 16d4
0 79 :3 0 89
:3 0 16d6 16d7 0
25 :2 0 2 :4 0
16c :2 0 8b :2 0
49 :2 0 cf3 16dc
16de :3 0 cf6 16d8
16e0 16d5 16e2 16e1
:2 0 7c :3 0 8c
:3 0 16e4 16e5 0
7e :4 0 16d :4 0
81 :2 0 82 :3 0
cfa 16e9 16eb :3 0
81 :2 0 95 :4 0
cfd 16ed 16ef :3 0
81 :2 0 b1 :4 0
d00 16f1 16f3 :3 0
81 :2 0 ad :3 0
d03 16f5 16f7 :3 0
81 :2 0 b2 :4 0
d06 16f9 16fb :3 0
81 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 d09 16fe
1702 d0d 16fd 1704
:3 0 d10 16e6 1706
:2 0 1708 d13 1709
16e3 1708 0 170a
d15 0 170b d17
170e :3 0 170e 0
170e 170d 170b 170c
:6 0 1710 3a :3 0
d1a 1712 d1c 1711
1710 :2 0 1713 d1e
:2 0 1715 0 1715
1714 16cb 1713 :6 0
1717 1 :3 0 d20
1719 1638 16a9 0
171a 0 1717 0
171a d22 0 171b
d25 178a d3 :3 0
ff :3 0 d :3 0
cf :3 0 39 :3 0
d2 :3 0 38 :3 0
cd :3 0 c :3 0
75 :3 0 2b :4 0
16e 1 :8 0 173d
f8 :4 0 1728 :3 0
9d :3 0 a5 :2 0
d29 172b 172c :3 0
1b :3 0 ac :3 0
172e 172f 0 31
:2 0 1730 1731 0
1733 d2c 173a 1b
:3 0 ac :3 0 1734
1735 0 f9 :2 0
1736 1737 0 1739
d2e 173b 172d 1733
0 173c 0 1739
0 173c d30 0
173d d33 1787 ae
:3 0 1b :3 0 ac
:3 0 1740 1741 0
ad :3 0 1742 1743
0 177d 79 :3 0
7a :3 0 1745 1746
0 79 :3 0 89
:3 0 1748 1749 0
25 :2 0 2 :4 0
16f :2 0 8b :2 0
49 :2 0 d36 174e
1750 :3 0 d39 174a
1752 1747 1754 1753
:2 0 7c :3 0 8c
:3 0 1756 1757 0
7e :4 0 170 :4 0
81 :2 0 82 :3 0
d3d 175b 175d :3 0
81 :2 0 95 :4 0
d40 175f 1761 :3 0
81 :2 0 b1 :4 0
d43 1763 1765 :3 0
81 :2 0 ad :3 0
d46 1767 1769 :3 0
81 :2 0 b2 :4 0
d49 176b 176d :3 0
81 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 d4c 1770
1774 d50 176f 1776
:3 0 d53 1758 1778
:2 0 177a d56 177b
1755 177a 0 177c
d58 0 177d d5a
1780 :3 0 1780 0
1780 177f 177d 177e
:6 0 1782 3c :3 0
d5d 1784 d5f 1783
1782 :2 0 1785 d61
:2 0 1787 0 1787
1786 173d 1785 :6 0
1789 1 :3 0 d63
178b 162f 171b 0
178c 0 1789 0
178c d65 0 178d
d68 178e 162a 178d
0 1790 13e3 1621
0 1790 d6a 0
1791 d6d 1793 1114
13d5 0 1794 0
1791 0 1794 d6f
0 1bbb 4d :3 0
c3 :2 0 d72 1796
1797 :3 0 1798 :2 0
86 :3 0 18 :3 0
31 :2 0 d74 179a
179d 90 :2 0 31
:2 0 d79 179f 17a1
:3 0 17a2 :2 0 1799
17a4 17a3 :2 0 17a5
:2 0 86 :3 0 c
:3 0 31 :2 0 d7c
17a7 17aa 90 :2 0
31 :2 0 d81 17ac
17ae :3 0 17af :2 0
17a6 17b1 17b0 :2 0
45 :3 0 171 :4 0
17b3 17b4 0 1bb8
45 :4 0 17b6 17b7
0 1bb8 3f :3 0
31 :2 0 17b9 17ba
0 1bb8 3e :3 0
31 :2 0 17bc 17bd
0 1bb8 86 :3 0
58 :3 0 31 :2 0
d84 17bf 17c2 a5
:2 0 49 :2 0 d89
17c4 17c6 :3 0 75
:3 0 f6 :3 0 cb
:3 0 172 :3 0 b3
:3 0 f2 :3 0 172
:3 0 b3 :3 0 f4
:3 0 173 :3 0 174
:3 0 14c :3 0 14e
:3 0 46 :3 0 3d
:3 0 2e :3 0 5a
:3 0 5b :3 0 5f
:3 0 60 :3 0 5c
:3 0 5e :3 0 d3
:3 0 137 :3 0 2b
:4 0 175 1 :8 0
17e7 1b :3 0 ac
:3 0 17e2 17e3 0
ad :3 0 17e4 17e5
0 17e7 d8c 1831
ae :3 0 1b :3 0
ac :3 0 17ea 17eb
0 ad :3 0 17ec
17ed 0 1827 79
:3 0 7a :3 0 17ef
17f0 0 79 :3 0
89 :3 0 17f2 17f3
0 25 :2 0 2
:4 0 176 :2 0 8b
:2 0 49 :2 0 d8f
17f8 17fa :3 0 d92
17f4 17fc 17f1 17fe
17fd :2 0 7c :3 0
8c :3 0 1800 1801
0 7e :4 0 177
:4 0 81 :2 0 82
:3 0 d96 1805 1807
:3 0 81 :2 0 95
:4 0 d99 1809 180b
:3 0 81 :2 0 b1
:4 0 d9c 180d 180f
:3 0 81 :2 0 ad
:3 0 d9f 1811 1813
:3 0 81 :2 0 b2
:4 0 da2 1815 1817
:3 0 81 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 da5
181a 181e da9 1819
1820 :3 0 dac 1802
1822 :2 0 1824 daf
1825 17ff 1824 0
1826 db1 0 1827
db3 182a :3 0 182a
0 182a 1829 1827
1828 :6 0 182c 3e
:3 0 db6 182e db8
182d 182c :2 0 182f
dba :2 0 1831 0
1831 1830 17e7 182f
:6 0 1833 1 :3 0
dbc 18a1 46 :3 0
2b :3 0 1834 1835
0 18a0 f6 :3 0
cb :3 0 172 :3 0
b3 :3 0 f2 :3 0
172 :3 0 b3 :3 0
f4 :3 0 173 :3 0
174 :3 0 14c :3 0
14e :3 0 3d :3 0
2e :3 0 5a :3 0
5b :3 0 5f :3 0
60 :3 0 5c :3 0
5e :3 0 d3 :3 0
75 :3 0 46 :4 0
178 1 :8 0 1854
1b :3 0 ac :3 0
184f 1850 0 ad
:3 0 1851 1852 0
1854 dbe 189e ae
:3 0 1b :3 0 ac
:3 0 1857 1858 0
ad :3 0 1859 185a
0 1894 79 :3 0
7a :3 0 185c 185d
0 79 :3 0 89
:3 0 185f 1860 0
25 :2 0 2 :4 0
179 :2 0 8b :2 0
49 :2 0 dc1 1865
1867 :3 0 dc4 1861
1869 185e 186b 186a
:2 0 7c :3 0 8c
:3 0 186d 186e 0
7e :4 0 17a :4 0
81 :2 0 82 :3 0
dc8 1872 1874 :3 0
81 :2 0 95 :4 0
dcb 1876 1878 :3 0
81 :2 0 b1 :4 0
dce 187a 187c :3 0
81 :2 0 ad :3 0
dd1 187e 1880 :3 0
81 :2 0 b2 :4 0
dd4 1882 1884 :3 0
81 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 dd7 1887
188b ddb 1886 188d
:3 0 dde 186f 188f
:2 0 1891 de1 1892
186c 1891 0 1893
de3 0 1894 de5
1897 :3 0 1897 0
1897 1896 1894 1895
:6 0 1899 40 :3 0
de8 189b dea 189a
1899 :2 0 189c dec
:2 0 189e 0 189e
189d 1854 189c :6 0
18a0 1 :3 0 dee
18a2 17c7 1833 0
18a3 0 18a0 0
18a3 df1 0 1bb8
1b :3 0 ac :3 0
18a4 18a5 0 1b
:3 0 a5 :2 0 d7
:3 0 18a7 18a9 0
df6 18a8 18ab :3 0
18ac :2 0 86 :3 0
c :3 0 31 :2 0
df9 18ae 18b1 86
:3 0 a5 :2 0 a
:3 0 31 :2 0 dfc
18b3 18b7 e01 18b4
18b9 :3 0 18ba :2 0
86 :3 0 e :3 0
31 :2 0 e04 18bc
18bf a5 :2 0 31
:2 0 e09 18c1 18c3
:3 0 18c4 :2 0 18bb
18c6 18c5 :2 0 86
:3 0 d :3 0 31
:2 0 e0c 18c8 18cb
a5 :2 0 ec :2 0
e11 18cd 18cf :3 0
18d0 :2 0 18c7 18d2
18d1 :2 0 74 :3 0
76 :3 0 71 :3 0
73 :3 0 6b :3 0
2d :3 0 75 :3 0
46 :4 0 17b 1
:8 0 18f2 f8 :4 0
18dd :3 0 9d :3 0
a5 :2 0 e16 18e0
18e1 :3 0 1b :3 0
ac :3 0 18e3 18e4
0 31 :2 0 18e5
18e6 0 18e8 e19
18ef 1b :3 0 ac
:3 0 18e9 18ea 0
f9 :2 0 18eb 18ec
0 18ee e1b 18f0
18e2 18e8 0 18f1
0 18ee 0 18f1
e1d 0 18f2 e20
193c ae :3 0 1b
:3 0 ac :3 0 18f5
18f6 0 ad :3 0
18f7 18f8 0 1932
79 :3 0 7a :3 0
18fa 18fb 0 79
:3 0 89 :3 0 18fd
18fe 0 25 :2 0
2 :4 0 17c :2 0
8b :2 0 49 :2 0
e23 1903 1905 :3 0
e26 18ff 1907 18fc
1909 1908 :2 0 7c
:3 0 8c :3 0 190b
190c 0 7e :4 0
17d :4 0 81 :2 0
82 :3 0 e2a 1910
1912 :3 0 81 :2 0
95 :4 0 e2d 1914
1916 :3 0 81 :2 0
b1 :4 0 e30 1918
191a :3 0 81 :2 0
ad :3 0 e33 191c
191e :3 0 81 :2 0
b2 :4 0 e36 1920
1922 :3 0 81 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
e39 1925 1929 e3d
1924 192b :3 0 e40
190d 192d :2 0 192f
e43 1930 190a 192f
0 1931 e45 0
1932 e47 1935 :3 0
1935 0 1935 1934
1932 1933 :6 0 1937
42 :3 0 e4a 1939
e4c 1938 1937 :2 0
193a e4e :2 0 193c
0 193c 193b 18f2
193a :6 0 19ad 1
:3 0 d3 :3 0 cd
:3 0 f6 :3 0 108
:3 0 17e :3 0 72
:3 0 74 :3 0 6b
:3 0 2d :3 0 75
:3 0 46 :3 0 75
:3 0 46 :4 0 17f
1 :8 0 1961 f8
:4 0 194c :3 0 9d
:3 0 a5 :2 0 e52
194f 1950 :3 0 1b
:3 0 ac :3 0 1952
1953 0 31 :2 0
1954 1955 0 1957
e55 195e 1b :3 0
ac :3 0 1958 1959
0 f9 :2 0 195a
195b 0 195d e57
195f 1951 1957 0
1960 0 195d 0
1960 e59 0 1961
e5c 19ab ae :3 0
1b :3 0 ac :3 0
1964 1965 0 ad
:3 0 1966 1967 0
19a1 79 :3 0 7a
:3 0 1969 196a 0
79 :3 0 89 :3 0
196c 196d 0 25
:2 0 2 :4 0 180
:2 0 8b :2 0 49
:2 0 e5f 1972 1974
:3 0 e62 196e 1976
196b 1978 1977 :2 0
7c :3 0 8c :3 0
197a 197b 0 7e
:4 0 181 :4 0 81
:2 0 82 :3 0 e66
197f 1981 :3 0 81
:2 0 95 :4 0 e69
1983 1985 :3 0 81
:2 0 b1 :4 0 e6c
1987 1989 :3 0 81
:2 0 ad :3 0 e6f
198b 198d :3 0 81
:2 0 b2 :4 0 e72
198f 1991 :3 0 81
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 e75 1994 1998
e79 1993 199a :3 0
e7c 197c 199c :2 0
199e e7f 199f 1979
199e 0 19a0 e81
0 19a1 e83 19a4
:3 0 19a4 0 19a4
19a3 19a1 19a2 :6 0
19a6 44 :3 0 e86
19a8 e88 19a7 19a6
:2 0 19a9 e8a :2 0
19ab 0 19ab 19aa
1961 19a9 :6 0 19ad
1 :3 0 e8c 1b85
11f :3 0 70 :4 0
19b1 :2 0 1b84 19af
19b2 :3 0 182 :3 0
70 :3 0 40 :3 0
43 :3 0 3e :4 0
19b9 :2 0 1ab0 19b4
19ba :3 0 e8f :3 0
70 :3 0 f8 :3 0
19bb 19bc :3 0 1b
:3 0 ac :3 0 19be
19bf 0 31 :2 0
19c0 19c1 0 19c3
e93 19ca 1b :3 0
ac :3 0 19c4 19c5
0 f9 :2 0 19c6
19c7 0 19c9 e95
19cb 19bd 19c3 0
19cc 0 19c9 0
19cc e97 0 1ab0
1b :3 0 ac :3 0
19cd 19ce 0 c0
:2 0 31 :2 0 e9c
19d0 19d2 :3 0 183
:8 0 19d6 e9f 19d7
19d3 19d6 0 19d8
ea1 0 1ab0 3f
:3 0 86 :3 0 3f
:3 0 31 :2 0 ea3
19da 19dd 8b :2 0
86 :3 0 40 :3 0
31 :2 0 ea6 19e0
19e3 ea9 19df 19e5
:3 0 19d9 19e6 0
1ab0 86 :3 0 3e
:3 0 31 :2 0 eac
19e8 19eb a5 :2 0
31 :2 0 eb1 19ed
19ef :3 0 86 :3 0
3f :3 0 31 :2 0
eb4 19f1 19f4 86
:3 0 90 :2 0 42
:3 0 31 :2 0 eb7
19f6 19fa ebc 19f7
19fc :3 0 86 :3 0
40 :3 0 31 :2 0
ebf 19fe 1a01 86
:3 0 184 :2 0 42
:3 0 31 :2 0 ec2
1a03 1a07 ec7 1a04
1a09 :3 0 40 :3 0
86 :3 0 42 :3 0
31 :2 0 eca 1a0c
1a0f 1a0b 1a10 0
1a12 ecd 1a2b 40
:3 0 86 :3 0 42
:3 0 31 :2 0 ecf
1a14 1a17 d8 :2 0
86 :3 0 3f :3 0
31 :2 0 ed2 1a1a
1a1d ed5 1a19 1a1f
:3 0 8b :2 0 86
:3 0 40 :3 0 31
:2 0 ed8 1a22 1a25
edb 1a21 1a27 :3 0
1a13 1a28 0 1a2a
ede 1a2c 1a0a 1a12
0 1a2d 0 1a2a
0 1a2d ee0 0
1a2e ee3 1a2f 19fd
1a2e 0 1a30 ee5
0 1a9b 74 :3 0
76 :3 0 40 :3 0
73 :3 0 70 :4 0
185 1 :8 0 1a4c
f8 :4 0 1a37 :3 0
9d :3 0 a5 :2 0
ee9 1a3a 1a3b :3 0
1b :3 0 ac :3 0
1a3d 1a3e 0 31
:2 0 1a3f 1a40 0
1a42 eec 1a49 1b
:3 0 ac :3 0 1a43
1a44 0 f9 :2 0
1a45 1a46 0 1a48
eee 1a4a 1a3c 1a42
0 1a4b 0 1a48
0 1a4b ef0 0
1a4c ef3 1a96 ae
:3 0 1b :3 0 ac
:3 0 1a4f 1a50 0
ad :3 0 1a51 1a52
0 1a8c 79 :3 0
7a :3 0 1a54 1a55
0 79 :3 0 89
:3 0 1a57 1a58 0
25 :2 0 2 :4 0
186 :2 0 8b :2 0
49 :2 0 ef6 1a5d
1a5f :3 0 ef9 1a59
1a61 1a56 1a63 1a62
:2 0 7c :3 0 8c
:3 0 1a65 1a66 0
7e :4 0 187 :4 0
81 :2 0 82 :3 0
efd 1a6a 1a6c :3 0
81 :2 0 95 :4 0
f00 1a6e 1a70 :3 0
81 :2 0 b1 :4 0
f03 1a72 1a74 :3 0
81 :2 0 ad :3 0
f06 1a76 1a78 :3 0
81 :2 0 b2 :4 0
f09 1a7a 1a7c :3 0
81 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 f0c 1a7f
1a83 f10 1a7e 1a85
:3 0 f13 1a67 1a87
:2 0 1a89 f16 1a8a
1a64 1a89 0 1a8b
f18 0 1a8c f1a
1a8f :3 0 1a8f 0
1a8f 1a8e 1a8c 1a8d
:6 0 1a91 47 :3 0
f1d 1a93 f1f 1a92
1a91 :2 0 1a94 f21
:2 0 1a96 0 1a96
1a95 1a4c 1a94 :6 0
1a9b 46 :3 0 45
:3 0 43 :3 0 1a98
1a99 0 1a9b f23
1a9c 19f0 1a9b 0
1a9d f27 0 1ab0
86 :3 0 3f :3 0
31 :2 0 f29 1a9e
1aa1 86 :3 0 184
:2 0 42 :3 0 31
:2 0 f2c 1aa3 1aa7
f31 1aa4 1aa9 :3 0
183 :8 0 1aad f34
1aae 1aaa 1aad 0
1aaf f36 0 1ab0
f38 1ab2 182 :4 0
1ab0 :4 0 1b84 120
:3 0 70 :4 0 1ab6
:2 0 1abc 1ab4 0
1b :3 0 ac :3 0
1ab7 1ab8 0 ad
:3 0 1ab9 1aba 0
1abc f3f 1b06 ae
:3 0 1b :3 0 ac
:3 0 1abf 1ac0 0
ad :3 0 1ac1 1ac2
0 1afc 79 :3 0
7a :3 0 1ac4 1ac5
0 79 :3 0 89
:3 0 1ac7 1ac8 0
25 :2 0 2 :4 0
188 :2 0 8b :2 0
49 :2 0 f42 1acd
1acf :3 0 f45 1ac9
1ad1 1ac6 1ad3 1ad2
:2 0 7c :3 0 8c
:3 0 1ad5 1ad6 0
7e :4 0 189 :4 0
81 :2 0 82 :3 0
f49 1ada 1adc :3 0
81 :2 0 95 :4 0
f4c 1ade 1ae0 :3 0
81 :2 0 b1 :4 0
f4f 1ae2 1ae4 :3 0
81 :2 0 ad :3 0
f52 1ae6 1ae8 :3 0
81 :2 0 b2 :4 0
f55 1aea 1aec :3 0
81 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 f58 1aef
1af3 f5c 1aee 1af5
:3 0 f5f 1ad7 1af7
:2 0 1af9 f62 1afa
1ad4 1af9 0 1afb
f64 0 1afc f66
1aff :3 0 1aff 0
1aff 1afe 1afc 1afd
:6 0 1b01 49 :3 0
f69 1b03 f6b 1b02
1b01 :2 0 1b04 f6d
:2 0 1b06 0 1b06
1b05 1abc 1b04 :6 0
1b84 1 :3 0 86
:3 0 3f :3 0 31
:2 0 f6f 1b08 1b0b
90 :2 0 31 :2 0
f74 1b0d 1b0f :3 0
1b10 :2 0 45 :3 0
c3 :2 0 f77 1b13
1b14 :3 0 1b15 :2 0
1b16 :2 0 1b11 1b18
1b17 :2 0 d3 :3 0
108 :3 0 45 :3 0
75 :3 0 46 :4 0
18a 1 :8 0 1b35
f8 :4 0 1b20 :3 0
9d :3 0 a5 :2 0
f7b 1b23 1b24 :3 0
1b :3 0 ac :3 0
1b26 1b27 0 31
:2 0 1b28 1b29 0
1b2b f7e 1b32 1b
:3 0 ac :3 0 1b2c
1b2d 0 f9 :2 0
1b2e 1b2f 0 1b31
f80 1b33 1b25 1b2b
0 1b34 0 1b31
0 1b34 f82 0
1b35 f85 1b7f ae
:3 0 1b :3 0 ac
:3 0 1b38 1b39 0
ad :3 0 1b3a 1b3b
0 1b75 79 :3 0
7a :3 0 1b3d 1b3e
0 79 :3 0 89
:3 0 1b40 1b41 0
25 :2 0 2 :4 0
18b :2 0 8b :2 0
49 :2 0 f88 1b46
1b48 :3 0 f8b 1b42
1b4a 1b3f 1b4c 1b4b
:2 0 7c :3 0 8c
:3 0 1b4e 1b4f 0
7e :4 0 18c :4 0
81 :2 0 82 :3 0
f8f 1b53 1b55 :3 0
81 :2 0 95 :4 0
f92 1b57 1b59 :3 0
81 :2 0 b1 :4 0
f95 1b5b 1b5d :3 0
81 :2 0 ad :3 0
f98 1b5f 1b61 :3 0
81 :2 0 b2 :4 0
f9b 1b63 1b65 :3 0
81 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 f9e 1b68
1b6c fa2 1b67 1b6e
:3 0 fa5 1b50 1b70
:2 0 1b72 fa8 1b73
1b4d 1b72 0 1b74
faa 0 1b75 fac
1b78 :3 0 1b78 0
1b78 1b77 1b75 1b76
:6 0 1b7a 4b :3 0
faf 1b7c fb1 1b7b
1b7a :2 0 1b7d fb3
:2 0 1b7f 0 1b7f
1b7e 1b35 1b7d :6 0
1b81 1 :3 0 fb5
1b82 1b19 1b81 0
1b83 fb7 0 1b84
fb9 1b86 18d3 19ad
0 1b87 0 1b84
0 1b87 fbe 0
1bb5 86 :3 0 58
:3 0 31 :2 0 fc1
1b88 1b8b a5 :2 0
49 :2 0 fc6 1b8d
1b8f :3 0 ee :3 0
86 :3 0 f :3 0
31 :2 0 fc9 1b92
1b95 27 :2 0 fcc
1b91 1b98 1b99 :2 0
a5 :2 0 27 :2 0
fd1 1b9b 1b9d :3 0
55 :3 0 18d :3 0
46 :3 0 2f :3 0
fd4 1ba0 1ba3 1b9f
1ba4 0 1ba6 fd7
1baf 55 :3 0 18e
:3 0 46 :3 0 2f
:3 0 fd9 1ba8 1bab
1ba7 1bac 0 1bae
fdc 1bb0 1b9e 1ba6
0 1bb1 0 1bae
0 1bb1 fde 0
1bb2 fe1 1bb3 1b90
1bb2 0 1bb4 fe3
0 1bb5 fe5 1bb6
18ad 1bb5 0 1bb7
fe8 0 1bb8 fea
1bb9 17b2 1bb8 0
1bba ff1 0 1bbb
ff3 1bbc 74b 1bbb
0 1bbd 1001 0
1bcd 1b :3 0 ac
:3 0 1bbe 1bbf 0
a5 :2 0 f9 :2 0
1005 1bc1 1bc3 :3 0
1b :3 0 ac :3 0
1bc5 1bc6 0 31
:2 0 1bc7 1bc8 0
1bca 1008 1bcb 1bc4
1bca 0 1bcc 100a
0 1bcd 100c 1bce
49f 1bcd 0 1bcf
1010 0 1c1e 79
:3 0 7a :3 0 1bd0
1bd1 0 79 :3 0
89 :3 0 1bd3 1bd4
0 18f :2 0 2
:4 0 190 :2 0 8b
:2 0 49 :2 0 1012
1bd9 1bdb :3 0 1015
1bd5 1bdd 1bd2 1bdf
1bde :2 0 7c :3 0
8c :3 0 1be1 1be2
0 7e :4 0 191
:4 0 81 :2 0 82
:3 0 1019 1be6 1be8
:3 0 81 :2 0 95
:4 0 101c 1bea 1bec
:3 0 81 :2 0 96
:4 0 101f 1bee 1bf0
:3 0 81 :2 0 86
:3 0 67 :3 0 1b
:3 0 ac :3 0 1bf5
1bf6 0 1022 1bf4
1bf8 87 :4 0 1024
1bf3 1bfb 1027 1bf2
1bfd :3 0 81 :2 0
db :4 0 102a 1bff
1c01 :3 0 81 :2 0
84 :4 0 102d 1c03
1c05 :3 0 81 :2 0
3 :3 0 1030 1c07
1c09 :3 0 81 :2 0
84 :4 0 1033 1c0b
1c0d :3 0 1036 1be3
1c0f :2 0 1c11 1039
1c12 1be0 1c11 0
1c13 103b 0 1c1e
9b :3 0 192 :3 0
1c14 1c15 0 1b
:3 0 ac :3 0 1c17
1c18 0 3 :3 0
9d :3 0 103d 1c16
1c1c :2 0 1c1e 1041
1cbf 1b :3 0 193
:2 0 4 1c1f 1c20
0 79 :3 0 7a
:3 0 1c22 1c23 0
79 :3 0 89 :3 0
1c25 1c26 0 25
:2 0 2 :4 0 194
:2 0 8b :2 0 49
:2 0 1057 1c2b 1c2d
:3 0 105a 1c27 1c2f
1c24 1c31 1c30 :2 0
7c :3 0 8c :3 0
1c33 1c34 0 7e
:4 0 195 :4 0 81
:2 0 82 :3 0 105e
1c38 1c3a :3 0 1061
1c35 1c3c :2 0 1c55
7c :3 0 8c :3 0
1c3e 1c3f 0 7e
:4 0 196 :4 0 81
:2 0 1b :3 0 197
:3 0 1c44 1c45 0
1064 1c43 1c47 :3 0
81 :2 0 db :4 0
1067 1c49 1c4b :3 0
81 :2 0 1b :3 0
198 :3 0 1c4e 1c4f
0 106a 1c4d 1c51
:3 0 106d 1c40 1c53
:2 0 1c55 1070 1c56
1c32 1c55 0 1c57
1073 0 1c67 11f
:3 0 78 :3 0 1b
:3 0 197 :3 0 199
:3 0 1b :3 0 198
:3 0 3 :3 0 ba
:4 0 19a 1 :a 0
1c63 :2 0 1c67 1c59
1c61 :2 0 1a :3 0
78 :3 0 1c65 :2 0
1c67 1075 1c69 1079
1c68 1c67 :2 0 1cbd
ae :3 0 1b :3 0
ac :3 0 1c6c 1c6d
0 ad :3 0 1c6e
1c6f 0 1cb5 79
:3 0 7a :3 0 1c71
1c72 0 79 :3 0
89 :3 0 1c74 1c75
0 25 :2 0 2
:4 0 19b :2 0 8b
:2 0 49 :2 0 107b
1c7a 1c7c :3 0 107e
1c76 1c7e 1c73 1c80
1c7f :2 0 7c :3 0
8c :3 0 1c82 1c83
0 7e :4 0 19c
:4 0 81 :2 0 82
:3 0 1082 1c87 1c89
:3 0 1085 1c84 1c8b
:2 0 1ca5 7c :3 0
8c :3 0 1c8d 1c8e
0 7e :4 0 b1
:4 0 81 :2 0 ad
:3 0 1088 1c92 1c94
:3 0 81 :2 0 b2
:4 0 108b 1c96 1c98
:3 0 81 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 108e
1c9b 1c9f 1092 1c9a
1ca1 :3 0 1095 1c8f
1ca3 :2 0 1ca5 1098
1ca6 1c81 1ca5 0
1ca7 109b 0 1cb5
11f :3 0 78 :3 0
199 :3 0 1b :3 0
198 :3 0 3 :3 0
ba :4 0 19d 1
:a 0 1cb1 :2 0 1cb5
1ca9 1caf :2 0 1a
:3 0 78 :3 0 1cb3
:2 0 1cb5 109d 1cb8
:3 0 1cb8 0 1cb8
1cb7 1cb5 1cb6 :6 0
1cba 1 :3 0 10a2
1cbc 10a4 1cbb 1cba
:2 0 1cbd 10a6 :2 0
1cbf 10a9 1cbf 1cbe
1c1e 1cbd :6 0 1cc0
:2 0 2 5c 1cbf
1cc3 :3 0 1cc2 1cc0
1cc4 :8 0 
10e6
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 1
47 1 4b 1
4f 1 53 15
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 4a 4e 52
56 1 60 1
5e 1 67 1
65 1 6e 1
6c 1 75 1
73 1 7c 1
7a 1 83 1
81 1 8a 1
88 1 91 1
8f 1 98 1
96 1 9f 1
9d 1 a6 1
a4 1 ad 1
ab 1 b4 1
b2 1 bb 1
b9 1 c0 1
c6 1 cc 1
d2 1 d8 1
de 1 e4 1
ea 1 f0 1
f6 1 fc 1
102 1 108 1
10e 1 114 1
11a 1 120 1
125 1 12c 1
12a 1 133 1
131 1 13a 1
138 1 13f 1
144 1 149 1
14e 1 153 1
158 1 15f 1
15d 1 164 1
16a 1 170 1
176 1 17c 1
182 1 188 1
18e 1 193 1
198 1 19e 1
1a4 1 1aa 1
1b0 1 1b6 1
1cf 1 1e4 1
1ea 1 1f7 1
203 2 206 208
2 20b 20d 2
20f 211 2 213
215 2 217 219
1 21f 2 221
222 2 21b 224
2 226 228 2
22a 22c 2 22e
230 2 232 234
2 236 238 2
23a 23c 2 23e
240 2 242 244
2 246 248 2
24a 24c 2 24e
250 2 252 254
2 256 258 1
25e 2 260 261
2 25a 263 2
265 267 2 269
26b 2 26d 26f
2 271 273 2
275 277 1 27d
2 27f 280 2
279 282 2 284
286 1 28c 2
28e 28f 2 288
291 2 293 295
1 29b 2 29d
29e 2 297 2a0
2 2a2 2a4 1
2aa 2 2ac 2ad
2 2a6 2af 2
2b1 2b3 1 2b9
2 2bb 2bc 2
2b5 2be 2 2c0
2c2 1 2c8 2
2ca 2cb 2 2c4
2cd 2 2cf 2d1
2 2d3 2d5 2
2d7 2d9 2 2db
2dd 2 2df 2e1
2 2e3 2e5 2
2e7 2e9 2 2eb
2ed 2 2ef 2f1
1 2f7 2 2f9
2fa 2 2f3 2fc
2 2fe 300 1
306 2 308 309
2 302 30b 2
30d 30f 2 311
313 2 315 317
2 319 31b 2
31d 31f 2 321
323 2 325 327
2 329 32b 2
32d 32f 1 335
2 337 338 2
331 33a 2 33c
33e 2 340 342
2 344 346 2
348 34a 2 34c
34e 4 1ff 205
20a 350 1 352
1 354 2 35e
360 3 35c 35d
362 2 36b 36d
2 36a 36f 1
371 1 373 1
375 2 37c 37d
1 381 2 37f
381 2 386 387
1 38b 2 389
38b 2 39c 39e
3 39a 39b 3a0
2 3a9 3ab 2
3ad 3af 2 3b1
3b3 1 3bb 2
3bd 3be 2 3b5
3c0 2 3a8 3c2
1 3c4 1 3c6
2 3d0 3d2 3
3ce 3cf 3d4 2
3dd 3df 2 3dc
3e1 1 3e3 1
3e5 2 3ec 3ed
3 3c7 3e6 3ef
1 3f1 1 3f3
1 3f9 1 401
2 411 413 3
40f 410 415 2
41e 420 2 422
424 2 426 428
1 430 2 432
433 2 42a 435
2 41d 437 1
439 1 43b 2
445 447 3 443
444 449 2 452
454 2 451 456
1 458 1 45a
2 461 462 3
43c 45b 464 1
466 1 494 2
496 497 1 49d
2 499 49d 2
4a1 4a2 1 4a6
2 4a4 4a6 2
4ab 4ac 1 4b0
2 4ae 4b0 1
4b6 2 4c3 4c5
3 4c1 4c2 4c7
2 4d0 4d2 2
4d4 4d6 2 4d8
4da 1 4e2 2
4e4 4e5 2 4dc
4e7 2 4cf 4e9
1 4eb 1 4ed
2 4f7 4f9 3
4f5 4f6 4fb 2
504 506 2 503
508 1 50a 1
50c 2 513 514
3 4ee 50d 516
1 518 2 52a
52f 2 540 542
3 53e 53f 544
2 54d 54f 2
551 553 2 555
557 2 559 55b
2 55d 55f 3
564 565 566 2
561 568 2 54c
56a 1 56c 1
56e 2 537 56f
1 573 1 532
1 577 2 584
585 1 587 6
58f 590 591 592
593 594 1 59c
2 59a 59c 2
5a1 5a2 1 5a6
2 5a4 5a6 2
5ad 5ae 1 5b2
2 5b0 5b2 2
5c3 5c8 2 5d9
5db 3 5d7 5d8
5dd 2 5e6 5e8
2 5ea 5ec 2
5ee 5f0 2 5f2
5f4 2 5f6 5f8
3 5fd 5fe 5ff
2 5fa 601 2
5e5 603 1 605
1 607 2 5d0
608 1 60c 1
5cb 1 610 2
616 617 1 61b
2 619 61b 1
627 2 632 637
2 648 64a 3
646 647 64c 2
655 657 2 659
65b 2 65d 65f
2 661 663 2
665 667 3 66c
66d 66e 2 669
670 2 654 672
1 674 1 676
2 63f 677 1
67b 1 63a 1
67f 1 682 1
685 4 620 623
626 686 1 688
3 5ba 613 689
1 68b 2 68e
68f 1 693 2
691 693 2 699
69a 1 69c 1
6a1 2 69f 6a1
1 6a8 1 6aa
a 519 51c 51f
522 57a 580 58a
597 68c 6ab 2
6c7 6cc 2 6dd
6df 3 6db 6dc
6e1 2 6ea 6ec
2 6ee 6f0 2
6f2 6f4 2 6f6
6f8 2 6fa 6fc
3 701 702 703
2 6fe 705 2
6e9 707 1 709
1 70b 2 6d4
70c 1 710 1
6cf 1 714 1
71f 2 71b 71f
2 724 725 2
72a 72b 1 72d
2 727 72d 1
738 2 735 73b
1 73d 3 6af
717 73e 2 740
741 2 744 745
1 749 2 747
749 1 750 2
74e 750 2 75b
75d 3 759 75a
75f 2 768 76a
2 76c 76e 2
770 772 1 77a
2 77c 77d 2
774 77f 2 781
783 2 785 787
2 789 78b 2
78d 78f 2 767
791 1 793 1
795 2 79f 7a1
3 79d 79e 7a3
2 7ac 7ae 2
7ab 7b0 1 7b2
1 7b4 3 7bb
7bc 7bd 3 796
7b5 7bf 1 7c1
1 7c3 1 7c8
1 7cf 1 7d6
2 7e5 7e7 3
7e3 7e4 7e9 2
7f2 7f4 2 7f6
7f8 2 7fa 7fc
1 804 2 806
807 2 7fe 809
2 7f1 80b 1
80d 1 80f 2
819 81b 3 817
818 81d 2 826
828 2 825 82a
1 82c 1 82e
2 835 836 3
810 82f 838 1
83a 2 842 843
1 847 2 845
847 1 84c 1
84e 2 856 85b
2 86c 86e 3
86a 86b 870 2
879 87b 2 87d
87f 2 881 883
2 885 887 2
889 88b 3 890
891 892 2 88d
894 2 878 896
1 898 1 89a
2 863 89b 1
89f 1 85e 1
8a3 2 8a9 8aa
1 8ae 2 8ac
8ae 2 8b4 8b5
2 8ba 8bb 2
8b7 8bd 2 8c0
8c2 2 8c5 8c7
1 8c9 2 8ce
8cf 2 8d4 8d5
1 8d7 2 8d1
8d7 2 8dc 8df
1 8e3 2 8e5
8e6 2 8cc 8e7
1 8e9 2 8f0
8f1 2 8f3 8f4
1 8f9 2 8f7
8f9 2 8fd 8fe
1 902 2 900
902 2 906 907
1 90b 2 909
90b 11 912 913
914 915 916 917
918 919 91a 91b
91c 91d 91e 91f
920 921 922 1
92a 2 928 92a
1 93f 2 93e
93f 1 947 1
94d 2 94f 950
2 93c 951 2
962 964 3 960
961 966 2 96f
971 2 973 975
2 977 979 2
97b 97d 2 97f
981 3 986 987
988 2 983 98a
2 96e 98c 1
98e 1 990 2
959 991 1 995
1 954 1 999
1 99c 1 99f
2 925 9a0 11
9a6 9a7 9a8 9a9
9aa 9ab 9ac 9ad
9ae 9af 9b0 9b1
9b2 9b3 9b4 9b5
9b6 1 9b9 2
9bb 9bc 1 9bd
2 9c1 9c2 2
9c4 9c6 2 9cb
9cc 1 9d0 2
9ce 9d0 11 9d7
9d8 9d9 9da 9db
9dc 9dd 9de 9df
9e0 9e1 9e2 9e3
9e4 9e5 9e6 9e7
1 9ef 2 9ed
9ef 1 a00 2
9ff a00 1 a08
1 a0e 2 a10
a11 2 9fd a12
2 a23 a25 3
a21 a22 a27 2
a30 a32 2 a34
a36 2 a38 a3a
2 a3c a3e 2
a40 a42 3 a47
a48 a49 2 a44
a4b 2 a2f a4d
1 a4f 1 a51
2 a1a a52 1
a56 1 a15 1
a5a 1 a5d 1
a60 2 9ea a61
11 a67 a68 a69
a6a a6b a6c a6d
a6e a6f a70 a71
a72 a73 a74 a75
a76 a77 1 a7a
2 a7c a7d 2
9c9 a7e 2 a80
a81 1 a87 2
a85 a87 2 a8d
a8e 2 a90 a91
1 a96 2 a94
a96 2 a9d a9e
2 aa3 aa4 1
aa6 2 aa0 aa6
2 aab aac 1
ab0 2 aae ab0
2 ab7 ab8 1
abc 2 aba abc
1 adc 2 adb
adc 1 ae4 1
aea 2 aec aed
2 ad9 aee 2
aff b01 3 afd
afe b03 2 b0c
b0e 2 b10 b12
2 b14 b16 2
b18 b1a 2 b1c
b1e 3 b23 b24
b25 2 b20 b27
2 b0b b29 1
b2b 1 b2d 2
af6 b2e 1 b32
1 af1 1 b36
1 b46 2 b45
b46 1 b4e 1
b54 2 b56 b57
2 b43 b58 2
b69 b6b 3 b67
b68 b6d 2 b76
b78 2 b7a b7c
2 b7e b80 2
b82 b84 2 b86
b88 3 b8d b8e
b8f 2 b8a b91
2 b75 b93 1
b95 1 b97 2
b60 b98 1 b9c
1 b5b 1 ba0
1 bad 2 bac
bad 1 bb5 1
bbb 2 bbd bbe
2 baa bbf 2
bd0 bd2 3 bce
bcf bd4 2 bdd
bdf 2 be1 be3
2 be5 be7 2
be9 beb 2 bed
bef 3 bf4 bf5
bf6 2 bf1 bf8
2 bdc bfa 1
bfc 1 bfe 2
bc7 bff 1 c03
1 bc2 1 c07
3 b39 ba3 c0a
1 c1b 2 c1a
c1b 1 c23 1
c29 2 c2b c2c
2 c18 c2d 2
c3e c40 3 c3c
c3d c42 2 c4b
c4d 2 c4f c51
2 c53 c55 2
c57 c59 2 c5b
c5d 3 c62 c63
c64 2 c5f c66
2 c4a c68 1
c6a 1 c6c 2
c35 c6d 1 c71
1 c30 1 c75
1 c78 2 c7b
c7c 1 c7d 1
c7f 2 a82 c80
2 c85 c86 2
c88 c8b 2 c90
c91 1 c95 2
c93 c95 11 c9c
c9d c9e c9f ca0
ca1 ca2 ca3 ca4
ca5 ca6 ca7 ca8
ca9 caa cab cac
1 cb4 2 cb2
cb4 2 cb9 cba
1 cbe 2 cbc
cbe 2 cc5 cc6
1 cca 2 cc8
cca 1 ce2 2
ce1 ce2 1 cea
1 cf0 2 cf2
cf3 2 cdf cf4
2 d05 d07 3
d03 d04 d09 2
d12 d14 2 d16
d18 2 d1a d1c
2 d1e d20 2
d22 d24 3 d29
d2a d2b 2 d26
d2d 2 d11 d2f
1 d31 1 d33
2 cfc d34 1
d38 1 cf7 1
d3c 1 d3f 1
d42 2 caf d43
1 d45 2 d57
d5c 2 d6d d6f
3 d6b d6c d71
2 d7a d7c 2
d7e d80 2 d82
d84 2 d86 d88
2 d8a d8c 3
d91 d92 d93 2
d8e d95 2 d79
d97 1 d99 1
d9b 2 d64 d9c
1 da0 1 d5f
1 da4 3 dac
dad dae 1 db2
2 db0 db2 2
dc1 dc6 2 dd7
dd9 3 dd5 dd6
ddb 2 de4 de6
2 de8 dea 2
dec dee 2 df0
df2 2 df4 df6
3 dfb dfc dfd
2 df8 dff 2
de3 e01 1 e03
1 e05 2 dce
e06 1 e0a 1
dc9 1 e0e 6
e15 e16 e17 e18
e19 e1a 2 e1f
e20 1 e24 2
e22 e24 2 e3c
e3d 1 e48 1
e4e 2 e50 e51
2 e55 e5b 2
e6c e6e 3 e6a
e6b e70 2 e79
e7b 2 e7d e7f
2 e81 e83 2
e85 e87 2 e89
e8b 3 e90 e91
e92 2 e8d e94
2 e78 e96 1
e98 1 e9a 2
e63 e9b 1 e9f
1 e5e 1 ea3
2 ead eb2 2
ec3 ec5 3 ec1
ec2 ec7 2 ed0
ed2 2 ed4 ed6
2 ed8 eda 2
edc ede 2 ee0
ee2 3 ee7 ee8
ee9 2 ee4 eeb
2 ecf eed 1
eef 1 ef1 2
eba ef2 1 ef6
1 eb5 1 efa
2 f07 f09 3
f0b f0c f0d 2
f13 f15 3 f17
f18 f19 2 f1f
f21 3 f23 f24
f25 2 f2b f2d
3 f2f f30 f31
f f37 f38 f39
f3a f3b f3c f3d
f3e f3f f40 f41
f42 f43 f44 f45
2 f51 f53 3
f4f f50 f55 2
f5e f60 2 f62
f64 2 f66 f68
1 f6e 2 f70
f71 2 f6a f73
2 f75 f77 2
f79 f7b 2 f7d
f7f 2 f81 f83
2 f5d f85 1
f87 1 f89 2
f93 f95 3 f91
f92 f97 2 fa0
fa2 2 f9f fa4
1 fa6 1 fa8
3 fad fae faf
14 e29 e2c e2f
e32 e35 e38 e3e
e52 ea6 efd f01
f04 f10 f1c f28
f34 f48 f8a fa9
fb1 1 fb3 5
db9 dbc e11 e1d
fb4 1 fb6 3
d4c da7 fb7 1
fb9 2 fbd fbe
2 fc0 fc2 11
fca fcb fcc fcd
fce fcf fd0 fd1
fd2 fd3 fd4 fd5
fd6 fd7 fd8 fd9
fda 1 fe2 2
fe0 fe2 2 fe7
fe8 1 fec 2
fea fec 2 ff3
ff4 1 ff8 2
ff6 ff8 1 100c
2 100b 100c 1
1014 1 101a 2
101c 101d 2 1009
101e 2 102f 1031
3 102d 102e 1033
2 103c 103e 2
1040 1042 2 1044
1046 2 1048 104a
2 104c 104e 3
1053 1054 1055 2
1050 1057 2 103b
1059 1 105b 1
105d 2 1026 105e
1 1062 1 1021
1 1066 1 1069
1 106c 4 fba
fc5 fdd 106d 2
106f 1070 2 c8e
1071 2 1073 1074
1 107a 2 1078
107a 2 1085 1087
3 1083 1084 1089
2 1092 1094 2
1096 1098 2 109a
109c 1 10a4 2
10a6 10a7 2 109e
10a9 2 10ab 10ad
2 10af 10b1 2
10b3 10b5 2 10b7
10b9 2 1091 10bb
1 10bd 1 10bf
2 10c9 10cb 3
10c7 10c8 10cd 2
10d6 10d8 2 10d5
10da 1 10dc 1
10de 3 10e5 10e6
10e7 3 10c0 10df
10e9 1 10eb 2
10f1 10f2 1 10f6
2 10f4 10f6 2
10fb 10fc 1 1100
2 10fe 1100 1
1108 1 110a 2
110d 110e 1 1112
2 1110 1112 2
1117 1118 2 111a
111b 1 1120 2
111e 1120 1 1123
1 1128 1 1145
2 1144 1145 1
114d 1 1153 2
1155 1156 2 1142
1157 2 1168 116a
3 1166 1167 116c
2 1175 1177 2
1179 117b 2 117d
117f 2 1181 1183
2 1185 1187 3
118c 118d 118e 2
1189 1190 2 1174
1192 1 1194 1
1196 2 115f 1197
1 119b 1 115a
1 119f 1 11a2
1 11b1 2 11b0
11b1 1 11b9 1
11bf 2 11c1 11c2
2 11ae 11c3 2
11d4 11d6 3 11d2
11d3 11d8 2 11e1
11e3 2 11e5 11e7
2 11e9 11eb 2
11ed 11ef 2 11f1
11f3 3 11f8 11f9
11fa 2 11f5 11fc
2 11e0 11fe 1
1200 1 1202 2
11cb 1203 1 1207
1 11c6 1 120b
1 120e 2 1211
1212 1 1213 1
1215 1 125d 2
125c 125d 1 1265
1 126b 2 126d
126e 2 125a 126f
2 1280 1282 3
127e 127f 1284 2
128d 128f 2 1291
1293 2 1295 1297
2 1299 129b 2
129d 129f 3 12a4
12a5 12a6 2 12a1
12a8 2 128c 12aa
1 12ac 1 12ae
2 1277 12af 1
12b3 1 1272 1
12b7 1 12ba 1
12f4 2 12f3 12f4
1 12fc 1 1302
2 1304 1305 2
12f1 1306 2 1317
1319 3 1315 1316
131b 2 1324 1326
2 1328 132a 2
132c 132e 2 1330
1332 2 1334 1336
3 133b 133c 133d
2 1338 133f 2
1323 1341 1 1343
1 1345 2 130e
1346 1 134a 1
1309 1 134e 1
1351 2 1354 1355
1 1356 2 1358
1359 1 135a 2
135e 135f 1 1363
2 1361 1363 1
1372 2 1371 1372
1 137a 1 1380
2 1382 1383 2
136f 1384 2 1395
1397 3 1393 1394
1399 2 13a2 13a4
2 13a6 13a8 2
13aa 13ac 2 13ae
13b0 2 13b2 13b4
3 13b9 13ba 13bb
2 13b6 13bd 2
13a1 13bf 1 13c1
1 13c3 2 138c
13c4 1 13c8 1
1387 1 13cc 1
13cf 2 13d3 13d2
1 13d4 2 13d8
13d9 2 13db 13dc
1 13e1 2 13df
13e1 1 13e4 1
13e9 1 1406 2
1405 1406 1 140e
1 1414 2 1416
1417 2 1403 1418
2 1429 142b 3
1427 1428 142d 2
1436 1438 2 143a
143c 2 143e 1440
2 1442 1444 2
1446 1448 3 144d
144e 144f 2 144a
1451 2 1435 1453
1 1455 1 1457
2 1420 1458 1
145c 1 141b 1
1460 1 1463 1
1474 2 1473 1474
1 147c 1 1482
2 1484 1485 2
1471 1486 2 1497
1499 3 1495 1496
149b 2 14a4 14a6
2 14a8 14aa 2
14ac 14ae 2 14b0
14b2 2 14b4 14b6
3 14bb 14bc 14bd
2 14b8 14bf 2
14a3 14c1 1 14c3
1 14c5 2 148e
14c6 1 14ca 1
1489 1 14ce 1
14d1 2 14d4 14d5
1 14d6 1 14d8
1 1520 2 151f
1520 1 1528 1
152e 2 1530 1531
2 151d 1532 2
1543 1545 3 1541
1542 1547 2 1550
1552 2 1554 1556
2 1558 155a 2
155c 155e 2 1560
1562 3 1567 1568
1569 2 1564 156b
2 154f 156d 1
156f 1 1571 2
153a 1572 1 1576
1 1535 1 157a
1 157d 1 15b9
2 15b8 15b9 1
15c1 1 15c7 2
15c9 15ca 2 15b6
15cb 2 15dc 15de
3 15da 15db 15e0
2 15e9 15eb 2
15ed 15ef 2 15f1
15f3 2 15f5 15f7
2 15f9 15fb 3
1600 1601 1602 2
15fd 1604 2 15e8
1606 1 1608 1
160a 2 15d3 160b
1 160f 1 15ce
1 1613 1 1616
2 1619 161a 1
161b 2 161d 161e
1 161f 2 1623
1624 1 1628 2
1626 1628 1 162b
2 1631 1632 1
1636 2 1634 1636
1 164a 2 1649
164a 1 1652 1
1658 2 165a 165b
2 1647 165c 2
166d 166f 3 166b
166c 1671 2 167a
167c 2 167e 1680
2 1682 1684 2
1686 1688 2 168a
168c 3 1691 1692
1693 2 168e 1695
2 1679 1697 1
1699 1 169b 2
1664 169c 1 16a0
1 165f 1 16a4
1 16a7 1 16b8
2 16b7 16b8 1
16c0 1 16c6 2
16c8 16c9 2 16b5
16ca 2 16db 16dd
3 16d9 16da 16df
2 16e8 16ea 2
16ec 16ee 2 16f0
16f2 2 16f4 16f6
2 16f8 16fa 3
16ff 1700 1701 2
16fc 1703 2 16e7
1705 1 1707 1
1709 2 16d2 170a
1 170e 1 16cd
1 1712 1 1715
2 1718 1719 1
171a 1 172a 2
1729 172a 1 1732
1 1738 2 173a
173b 2 1727 173c
2 174d 174f 3
174b 174c 1751 2
175a 175c 2 175e
1760 2 1762 1764
2 1766 1768 2
176a 176c 3 1771
1772 1773 2 176e
1775 2 1759 1777
1 1779 1 177b
2 1744 177c 1
1780 1 173f 1
1784 1 1787 2
178a 178b 1 178c
2 178f 178e 1
1790 2 1792 1793
1 1795 2 179b
179c 1 17a0 2
179e 17a0 2 17a8
17a9 1 17ad 2
17ab 17ad 2 17c0
17c1 1 17c5 2
17c3 17c5 2 17e1
17e6 2 17f7 17f9
3 17f5 17f6 17fb
2 1804 1806 2
1808 180a 2 180c
180e 2 1810 1812
2 1814 1816 3
181b 181c 181d 2
1818 181f 2 1803
1821 1 1823 1
1825 2 17ee 1826
1 182a 1 17e9
1 182e 1 1831
2 184e 1853 2
1864 1866 3 1862
1863 1868 2 1871
1873 2 1875 1877
2 1879 187b 2
187d 187f 2 1881
1883 3 1888 1889
188a 2 1885 188c
2 1870 188e 1
1890 1 1892 2
185b 1893 1 1897
1 1856 1 189b
2 1836 189e 2
18a1 18a2 1 18aa
2 18a6 18aa 2
18af 18b0 2 18b5
18b6 1 18b8 2
18b2 18b8 2 18bd
18be 1 18c2 2
18c0 18c2 2 18c9
18ca 1 18ce 2
18cc 18ce 1 18df
2 18de 18df 1
18e7 1 18ed 2
18ef 18f0 2 18dc
18f1 2 1902 1904
3 1900 1901 1906
2 190f 1911 2
1913 1915 2 1917
1919 2 191b 191d
2 191f 1921 3
1926 1927 1928 2
1923 192a 2 190e
192c 1 192e 1
1930 2 18f9 1931
1 1935 1 18f4
1 1939 1 194e
2 194d 194e 1
1956 1 195c 2
195e 195f 2 194b
1960 2 1971 1973
3 196f 1970 1975
2 197e 1980 2
1982 1984 2 1986
1988 2 198a 198c
2 198e 1990 3
1995 1996 1997 2
1992 1999 2 197d
199b 1 199d 1
199f 2 1968 19a0
1 19a4 1 1963
1 19a8 2 193c
19ab 3 19b5 19b6
19b7 1 19c2 1
19c8 2 19ca 19cb
1 19d1 2 19cf
19d1 1 19d5 1
19d7 2 19db 19dc
2 19e1 19e2 2
19de 19e4 2 19e9
19ea 1 19ee 2
19ec 19ee 2 19f2
19f3 2 19f8 19f9
1 19fb 2 19f5
19fb 2 19ff 1a00
2 1a05 1a06 1
1a08 2 1a02 1a08
2 1a0d 1a0e 1
1a11 2 1a15 1a16
2 1a1b 1a1c 2
1a18 1a1e 2 1a23
1a24 2 1a20 1a26
1 1a29 2 1a2b
1a2c 1 1a2d 1
1a2f 1 1a39 2
1a38 1a39 1 1a41
1 1a47 2 1a49
1a4a 2 1a36 1a4b
2 1a5c 1a5e 3
1a5a 1a5b 1a60 2
1a69 1a6b 2 1a6d
1a6f 2 1a71 1a73
2 1a75 1a77 2
1a79 1a7b 3 1a80
1a81 1a82 2 1a7d
1a84 2 1a68 1a86
1 1a88 1 1a8a
2 1a53 1a8b 1
1a8f 1 1a4e 1
1a93 3 1a30 1a96
1a9a 1 1a9c 2
1a9f 1aa0 2 1aa5
1aa6 1 1aa8 2
1aa2 1aa8 1 1aac
1 1aae 6 19b8
19cc 19d8 19e7 1a9d
1aaf 2 1ab5 1abb
2 1acc 1ace 3
1aca 1acb 1ad0 2
1ad9 1adb 2 1add
1adf 2 1ae1 1ae3
2 1ae5 1ae7 2
1ae9 1aeb 3 1af0
1af1 1af2 2 1aed
1af4 2 1ad8 1af6
1 1af8 1 1afa
2 1ac3 1afb 1
1aff 1 1abe 1
1b03 2 1b09 1b0a
1 1b0e 2 1b0c
1b0e 1 1b12 1
1b22 2 1b21 1b22
1 1b2a 1 1b30
2 1b32 1b33 2
1b1f 1b34 2 1b45
1b47 3 1b43 1b44
1b49 2 1b52 1b54
2 1b56 1b58 2
1b5a 1b5c 2 1b5e
1b60 2 1b62 1b64
3 1b69 1b6a 1b6b
2 1b66 1b6d 2
1b51 1b6f 1 1b71
1 1b73 2 1b3c
1b74 1 1b78 1
1b37 1 1b7c 1
1b7f 1 1b82 4
19b0 1ab2 1b06 1b83
2 1b85 1b86 2
1b89 1b8a 1 1b8e
2 1b8c 1b8e 2
1b93 1b94 2 1b96
1b97 1 1b9c 2
1b9a 1b9c 2 1ba1
1ba2 1 1ba5 2
1ba9 1baa 1 1bad
2 1baf 1bb0 1
1bb1 1 1bb3 2
1b87 1bb4 1 1bb6
6 17b5 17b8 17bb
17be 18a3 1bb7 1
1bb9 d 7c2 83b
840 84f 8a6 8ea
8ed 1075 10ec 10ef
110b 1794 1bba 1
1bbc 1 1bc2 2
1bc0 1bc2 1 1bc9
1 1bcb 3 742
1bbd 1bcc 1 1bce
2 1bd8 1bda 3
1bd6 1bd7 1bdc 2
1be5 1be7 2 1be9
1beb 2 1bed 1bef
1 1bf7 2 1bf9
1bfa 2 1bf1 1bfc
2 1bfe 1c00 2
1c02 1c04 2 1c06
1c08 2 1c0a 1c0c
2 1be4 1c0e 1
1c10 1 1c12 3
1c19 1c1a 1c1b 15
355 374 3f2 467
46a 46d 470 473
476 479 47c 47f
482 485 488 48b
48e 491 1bcf 1c13
1c1d 2 1c2a 1c2c
3 1c28 1c29 1c2e
2 1c37 1c39 2
1c36 1c3b 2 1c42
1c46 2 1c48 1c4a
2 1c4c 1c50 2
1c41 1c52 2 1c3d
1c54 1 1c56 3
1c57 1c62 1c66 1
1c21 2 1c79 1c7b
3 1c77 1c78 1c7d
2 1c86 1c88 2
1c85 1c8a 2 1c91
1c93 2 1c95 1c97
3 1c9c 1c9d 1c9e
2 1c99 1ca0 2
1c90 1ca2 2 1c8c
1ca4 1 1ca6 4
1c70 1ca7 1cb0 1cb4
1 1cb8 1 1c6b
2 1c69 1cbc 3c
63 6a 71 78
7f 86 8d 94
9b a2 a9 b0
b7 be c4 ca
d0 d6 dc e2
e8 ee f4 fa
100 106 10c 112
118 11e 123 128
12f 136 13d 142
147 14c 151 156
15b 162 168 16e
174 17a 180 186
18c 191 196 19c
1a2 1a8 1ae 1b4
1ba 1d0 1e5 1ef

1
4
0 
1cc3
0
1
50
4d
52
0 1 1 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 1 36 1
38 1 3a 1 3c 1 3e 1
40 1 42 1 44 1 46 47
1 49 1 4b 1 0 0 0

d2 1 0
53 1 0
1bd 1 2
3b 1 0
23 1 0
13 1 0
7a 1 0
a4 1 0
16a 1 0
182 1 0
43 1 0
f6 1 0
3 1 0
12a 1 0
1b0 1 0
131 1 0
188 1 0
2f 1 0
102 1 0
19e 1 0
88 1 0
114 1 0
37 1 0
120 1 0
170 1 0
10e 1 0
7 1 0
c0 1 0
81 1 0
1b6 1 0
17c 1 0
1f 1 0
2 0 1
144 1 0
fc 1 0
e4 1 0
f 1 0
13f 1 0
4b 1 0
17 1 0
8f 1 0
176 1 0
158 1 0
1a4 1 0
96 1 0
5e 1 0
153 1 0
47 1 0
b 1 0
cc 1 0
27 1 0
193 1 0
14e 1 0
108 1 0
73 1 0
1aa 1 0
1d6 1 3
2b 1 0
b2 1 0
149 1 0
11a 1 0
4f 1 0
9d 1 0
ea 1 0
d8 1 0
33 1 0
164 1 0
ab 1 0
f0 1 0
c6 1 0
3f 1 0
198 1 0
18e 1 0
125 1 0
6c 1 0
65 1 0
b9 1 0
1b 1 0
15d 1 0
de 1 0
1ea 1 0
138 1 0
0

/
SHOW ERRORS FUNCTION SP_ASSIGN_MSP;
ALTER FUNCTION SP_ASSIGN_MSP COMPILE DEBUG;
/*
#Stored Procedure  :SP_A_RESTOPROF
#Short Description :Replace a profile with a resource
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_RESTOPROF ==
CREATE OR REPLACE FUNCTION SP_A_RESTOPROF wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
33e
2 :e:
1FUNCTION:
1SP_A_RESTOPROF:
1PRJ_ID:
1VARCHAR2:
1PROFILE_ID001:
1RES_ID001:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_SECURITY_ID:
1H_REC_USER:
1H_ASSIGN_ID:
1H_PRJ_ASSIGN_ID:
1H_TSK_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_CUR_PRJ_ASSIGN_ID:
1H_TASK_ID:
1H_RES_ID:
1H_PROJECT_ID:
1H_PROFILE_ID:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_NULL_STR:
11:
1H_START_D:
1DATE:
1H_FINISH_D:
1H_RES_TYPE:
1H_RANK:
1200:
1H_START_DT:
1H_FINISH_DT:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_ROLE_ID:
1H_FULL_NAME:
1255:
1H_IN:
1H_PROFILE_NAME:
1H_LABOR_CODE:
150:
1H_PARTICIPANT:
10:
1H_EVERY:
1H_EFFORT:
1H_CRI:
1H_TYPE:
1H_TYPE_ID:
1H_TOTAL:
1H_WORK:
1H_OCCURRENCE:
1H_EUNIT:
1H_UNIT:
1H_CONTOUR:
1H_DURATION:
1H_WORK_TYPE:
1H_PASSED:
1H_ASSIGNED:
1H_REMAINING:
1H_BITFLAG:
1H_PER_DAY:
1H_PER_WEEK:
1H_UPDATE:
1H_CONSIDER:
1H_PRIORITY:
1H_DAYS:
1H_OWNER:
1H_COUNT:
1H_CONTOUR_CHANGED:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_RATE_ECHANGE:
1H_CURRENCY_ID:
1H_DONOT_REPLACE_BITS:
1H_DONOT_REPLACE_RATE:
1H_DONOT_REPLACE_COST:
1H_FROM_PRJ:
1H_SAME_LABOR:
1H_FS_PROJECT:
1I_RETURN:
1H_AND_ROLES:
14000:
1H_AND_SKILLS:
1H_TEMP_RES_COST:
1H_TEMP_VAR:
1H_TEMP_RES_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_PA_TIMEPHASE:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_SD:
1H_FD:
1H_OLD_COST:
1H_OLD_SALE:
1H_PA_COUNT:
1H_TA_COUNT:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_TABLE_TYPE:
1H_PLANNED_EFFORT:
1H_TASK_TYPE:
1H_PERCENT_UNITS:
1H_TIMECODE_1_ID:
1H_TIMECODE_2_ID:
1H_OLD_PRJ_ASSIGN_ID:
1I_ISTASK:
1ISWBSTASK:
1COALESCE:
1L_DATA_FLAG:
1I_MANY:
1CURSOR:
1CRCAL1:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1ELEMENT_ID:
1ROWNUM:
1SELECT * FROM (SELECT AVAILABLE_MIN FROM CALENDAR_DAY_OF_YEAR:n         WHERE+
1 ELEMENT_ID = h_res_id ) WHERE ROWNUM<=1:
1CSA1:
1BAK_WORK:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1PROJECT_ASSIGNMENT_ID:
1SELECT * FROM (SELECT BAK_WORK FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_+
1ID = h_project_id AND RESOURCE_ID = h_res_id AND RESOURCE_TYPE = '0' AND:n   +
1      PROJECT_ASSIGNMENT_ID IS NuLL ) WHERE ROWNUM<=1:
1C6A:
1R:
1RES_ASSIGNMENT_ID:
1T:
1TSK_ASSIGNMENT_ID:
1TASK_ID:
1ELEMENT_TYPE:
1PLANNED_WORK:
1UNITS_MSP:
1TO_DATE:
1SUBSTR:
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_DURATION:
1W:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1C_CONTOUR:
1CONTOUR_TYPE:
1TMT_WBS:
1RESOURCE_ASSIGNMENTS:
1PMO_CNST:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1RANK:
1SELECT r.RES_ASSIGNMENT_ID, t.TSK_ASSIGNMENT_ID, t.TASK_ID, r.ELEMENT_TYPE, t+
1.PLANNED_WORK, t.UNITS_MSP,:n         TO_DATE(SubStr(t.PLANNED_START, 1, 10))+
1, TO_DATE(SubStr(t.PLANNED_FINISH, 1, 10)),t.PLANNED_START, t.PLANNED_FINISH,+
1 CASE WHEN t.PLANNED_DURATION = 0 THEN w.PLANNED_DURATION ELSE t.PLANNED_DURA+
1TION END,:n         t.PROJECT_ASSIGNMENT_ID, t.BILLABLE, t.CAPITAL_EXPENSE, t+
1.REGULAR_COST, t.REGULAR_RATE,:n         t.C_EFFORT, t.T_UNIT, t.C_UNIT, t.C_+
1CONTOUR, t.CONTOUR_TYPE:n         FROM TMT_WBS w, RESOURCE_ASSIGNMENTS r, TAS+
1K_ASSIGNMENTS t:n         WHERE r.PROJECT_ID = h_project_id AND r.RESOURCE_ID+
1 = h_profile_id AND r.RESOURCE_TYPE = '1' :n         AND t.RES_ASSIGNMENT_ID +
1= r.RES_ASSIGNMENT_ID AND r.ELEMENT_ID = w.ELEMENT_ID :n         AND r.ELEMEN+
1T_TYPE IN (PMO_CNST.SC_TASK,PMO_CNST.SC_TASK_TYPE1,PMO_CNST.SC_TASK_TYPE2,PMO+
1_CNST.SC_TASK_TYPE3,PMO_CNST.SC_MILESTONE,PMO_CNST.SC_PERSONAL_TASK,PMO_CNST.+
1SC_ACTIVE_ADM_TASK,PMO_CNST.SC_INACTIVE_ADM_TASK,PMO_CNST.SC_WBS_CHANGE_REQUE+
1ST_TASK,PMO_CNST.SC_WBS_ACTION_ITEM_TASK,PMO_CNST.SC_WBS_RISK_TASK,PMO_CNST.S+
1C_WBS_ISSUE_TASK,PMO_CNST.SC_WBS_REQUIREMENT_TASK,PMO_CNST.SC_WBS_DEFECT_TASK+
1,PMO_CNST.SC_WBS_SERVICE_REQUEST_TASK) AND w.RANK LIKE h_rank:n         ORDER+
1 BY t.PLANNED_START:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_RESTOPROF(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1161:
1+:
1FPUT:
1               ENTER:: SP_A_RESTOPROF(162) :: cplan.sql(8862) :: :
1BITAND:
1SC_1FFFFFFF:
1=:
1SC_SRCH_PROFILE:
1SC_SRCH_FROM_PROJECT:
17:
1:
1OPEN:
1FOUND:
1SC_STATE:
1100:
1CLOSE:
1SQLCODE:
1OTHERS:
116:
1210:
1           EXCEPTION:: SP_A_RESTOPROF(211) :: cplan.sql(8911) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1217:
1        RETURN_ERROR:: SP_A_RESTOPROF(218) :: cplan.sql(8918) :: :
1STATE:: :
1RECORD_NOT_FOUND:
1 ID:: :
1220:
1                EXIT:: SP_A_RESTOPROF(221) :: cplan.sql(8921) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1TYPE_ID:
1TIMECODE_1_ID:
1TIMECODE_2_ID:
1TASK_TYPE:
1UNRESOLVED_DURATION:
1SELECT TYPE_ID, RANK, PROJECT_ID, TIMECODE_1_ID, TIMECODE_2_ID, TASK_TYPE, UN+
1RESOLVED_DURATION:n      INTO h_type_id, h_rank, h_project_id, h_timecode_1_i+
1d, h_timecode_2_id, h_task_type, h_duration:n      FROM TMT_WBS WHERE ELEMENT+
1_ID = h_task_id:
1235:
1           EXCEPTION:: SP_A_RESTOPROF(236) :: cplan.sql(8936) :: :
1SC_SQL_NO_DATA:
1243:
1        RETURN_ERROR:: SP_A_RESTOPROF(244) :: cplan.sql(8944) :: :
1246:
1                EXIT:: SP_A_RESTOPROF(247) :: cplan.sql(8947) :: :
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n      FROM PROJECT_DETAILS:n      WHERE PR+
1OJECT_ID = h_project_id:
1262:
1           EXCEPTION:: SP_A_RESTOPROF(263) :: cplan.sql(8963) :: :
1>:
1269:
1        RETURN_ERROR:: SP_A_RESTOPROF(270) :: cplan.sql(8970) :: :
1LEV_LOCKED_BY_LEVEL:
1272:
1                EXIT:: SP_A_RESTOPROF(273) :: cplan.sql(8973) :: :
1TW:
1FS_CODE:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1CURRENCY_ID:
1PMO_ORASTD:
1TODECIMAL:
1TD:
1ELEMENT_NAME:
1JOIN:
1TMT_DATAFIELDS:
1SELECT tw.TYPE_ID, CASE WHEN tw.FS_CODE IS NuLL THEN 0 ELSE 1 END, COALESCE(t+
1w.MINUTE_PER_DAY, 480), COALESCE(tw.MINUTE_PER_WEEK, 2400), tw.PRIORITY, tw.C+
1URRENCY_ID, PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4):n      INTO h_type, h_+
1fs_project, h_per_day, h_per_week, h_priority, h_currency_id, h_rate_echange+
1:n      FROM TMT_WBS tw JOIN TMT_DATAFIELDS td on tw.CURRENCY_ID = td.ELEMENT+
1_ID WHERE tw.ELEMENT_ID = h_project_id:
1287:
1           EXCEPTION:: SP_A_RESTOPROF(288) :: cplan.sql(8988) :: :
1294:
1        RETURN_ERROR:: SP_A_RESTOPROF(295) :: cplan.sql(8995) :: :
1297:
1                EXIT:: SP_A_RESTOPROF(298) :: cplan.sql(8998) :: :
1NICK_NAME:
1FS_LABOR_CODE:
1RESOURCES:
1SELECT NICK_NAME,FS_LABOR_CODE INTO h_full_name,h_labor_code FROM RESOURCES W+
1HERE RESOURCE_ID = h_res_id:
1310:
1           EXCEPTION:: SP_A_RESTOPROF(311) :: cplan.sql(9011) :: :
1317:
1        RETURN_ERROR:: SP_A_RESTOPROF(318) :: cplan.sql(9018) :: :
1320:
1                EXIT:: SP_A_RESTOPROF(321) :: cplan.sql(9021) :: :
1ROLE_ID:
1PROFILES:
1PROFILE_ID:
1SELECT ROLE_ID INTO h_role_id FROM PROFILES WHERE PROFILE_ID = h_profile_id:
1333:
1           EXCEPTION:: SP_A_RESTOPROF(334) :: cplan.sql(9034) :: :
1STRCMP:
1DEFAULTLEVEL:
1344:
1        RETURN_ERROR:: SP_A_RESTOPROF(345) :: cplan.sql(9045) :: :
1347:
1                EXIT:: SP_A_RESTOPROF(348) :: cplan.sql(9048) :: :
14:
12:
1!=:
1COUNT:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_temp_var FROM TASK_ASSIGNMENTS:n      +
1      WHERE PROJECT_ID = h_project_id AND TASK_ID = h_project_id AND:n       +
1     RESOURCE_ID = h_res_id AND RESOURCE_TYPE = '0':
1377:
1           EXCEPTION:: SP_A_RESTOPROF(378) :: cplan.sql(9078) :: :
1ELSIF:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_temp_var FROM TASK_ASSIGNMENTS:n      +
1      WHERE PROJECT_ID = h_project_id AND TASK_ID <> PROJECT_ID AND:n        +
1    RESOURCE_ID = h_res_id AND RESOURCE_TYPE = '0':
1392:
1           EXCEPTION:: SP_A_RESTOPROF(393) :: cplan.sql(9093) :: :
1400:
1        RETURN_ERROR:: SP_A_RESTOPROF(401) :: cplan.sql(9101) :: :
1CHILD_TASK_ASSIGNMENT_ALREADY_:
1403:
1                EXIT:: SP_A_RESTOPROF(404) :: cplan.sql(9104) :: :
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_ta_count FROM TASK_ASSIGNMENTS:n      +
1   WHERE PROJECT_ID = h_project_id AND PROJECT_ID <> TASK_ID AND RESOURCE_ID +
1= h_profile_id AND RESOURCE_TYPE = '1':
1418:
1           EXCEPTION:: SP_A_RESTOPROF(419) :: cplan.sql(9119) :: :
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_pa_count FROM TASK_ASSIGNMENTS:n      +
1   WHERE PROJECT_ID = h_project_id AND PROJECT_ID = TASK_ID AND RESOURCE_ID =+
1 h_profile_id AND RESOURCE_TYPE = '1':
1432:
1           EXCEPTION:: SP_A_RESTOPROF(433) :: cplan.sql(9133) :: :
1ISPROJECTTYPE:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_temp_var FROM TASK_ASSIGNMENTS:n      +
1      WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h_res_id AND RESOURCE+
1_TYPE = '0':n            AND PROJECT_ASSIGNMENT_ID IS NuLL:
1449:
1           EXCEPTION:: SP_A_RESTOPROF(450) :: cplan.sql(9150) :: :
1456:
1        RETURN_ERROR:: SP_A_RESTOPROF(457) :: cplan.sql(9157) :: :
1459:
1                EXIT:: SP_A_RESTOPROF(460) :: cplan.sql(9160) :: :
1SC_SQL_SUCCESS:
1516:
1           EXCEPTION:: SP_A_RESTOPROF(517) :: cplan.sql(9217) :: :
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_count FROM TASK_ASSIGNMENTS WHERE PROJ+
1ECT_ID = h_project_id AND:n         RESOURCE_ID = h_res_id AND RESOURCE_TYPE +
1= '0' AND TASK_ID = h_project_id:
1532:
1           EXCEPTION:: SP_A_RESTOPROF(533) :: cplan.sql(9233) :: :
1BIT_FLAG:
1SELECT PLANNED_START, PLANNED_FINISH INTO h_sched_start, h_sched_finish:n    +
1        FROM TASK_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND BIT_FLAG = +
1'0' AND:n            RESOURCE_ID = h_res_id AND RESOURCE_TYPE = '0' AND TASK_+
1ID = h_project_id:
1549:
1           EXCEPTION:: SP_A_RESTOPROF(550) :: cplan.sql(9250) :: :
1557:
1        RETURN_ERROR:: SP_A_RESTOPROF(558) :: cplan.sql(9258) :: :
1560:
1                EXIT:: SP_A_RESTOPROF(561) :: cplan.sql(9261) :: :
1IS NOT NULL:
1STRNCMP:
110:
1<:
1568:
1        RETURN_ERROR:: SP_A_RESTOPROF(569) :: cplan.sql(9269) :: :
1571:
1                EXIT:: SP_A_RESTOPROF(572) :: cplan.sql(9272) :: :
1PARTICIPANT:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_prj_assign_id, h_owner:n        +
1    FROM RESOURCE_ASSIGNMENTS:n            WHERE ELEMENT_ID = h_project_id :n+
1            AND RESOURCE_TYPE = h_res_type :n            AND RESOURCE_ID = h_+
1res_id:
1597:
1           EXCEPTION:: SP_A_RESTOPROF(598) :: cplan.sql(9298) :: :
1SYS_GUID:
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1SC_AFFECTED:
1FC_BEFORE_I_RES_ASSIGN:
1GETTABLE:
1SECURITY_ID:
1TABLE_TYPE:
1REC_USER:
1REC_DATETIME:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE,:n               RESOURCE_TYPE, RESOURCE_ID, PROFILE_ID, PARTICIP+
1ANT, SECURITY_ID, TABLE_TYPE,:n               REC_USER, REC_DATETIME):n      +
1         VALUES (h_prj_assign_id, h_project_id, h_project_id, h_type,:n      +
1         h_res_type, h_res_id, h_profile_id, PMO_CNST.SC_AFFECTED, h_temp_sec+
1urity_id, h_table_type,:n               rec_user001, SYSTIMESTAMP):
1634:
1           EXCEPTION:: SP_A_RESTOPROF(635) :: cplan.sql(9335) :: :
1PROFILE_NAME:
1SELECT PROFILE_NAME INTO h_profile_name FROM PROFILES WHERE PROFILE_ID = h_pr+
1ofile_id:
1648:
1           EXCEPTION:: SP_A_RESTOPROF(649) :: cplan.sql(9349) :: :
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_total FROM TASK_ASSIGNMENTS:n         +
1         WHERE PROJECT_ID = h_project_id AND TASK_ID <> h_task_id AND RESOURC+
1E_TYPE = '1' AND RESOURCE_ID = h_profile_id AND BIT_FLAG = '0':
1665:
1           EXCEPTION:: SP_A_RESTOPROF(666) :: cplan.sql(9366) :: :
1ASSIGN_NAMES:
1REPLACE:
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_profile_name, h_fu+
1ll_name):n                  WHERE ELEMENT_ID = h_project_id AND PROJECT_ID = +
1h_project_id:
1687:
1           EXCEPTION:: SP_A_RESTOPROF(688) :: cplan.sql(9388) :: :
1INSTR:
1LENGTH:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n                  CASE:n                  +
1WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n        +
1          ELSE:n                  CASE:n                  WHEN LENGTH(h_full_+
1name) + LENGTH(ASSIGN_NAMES) > 2040 THEN ASSIGN_NAMES:n                  ELSE+
1 ASSIGN_NAMES || h_full_name || ';':n                  END:n                 +
1 END:n                  WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_pr+
1oject_id:
1714:
1           EXCEPTION:: SP_A_RESTOPROF(715) :: cplan.sql(9415) :: :
1741:
1           EXCEPTION:: SP_A_RESTOPROF(742) :: cplan.sql(9442) :: :
1SELECT TSK_ASSIGNMENT_ID INTO h_prj_assignment_id FROM TASK_ASSIGNMENTS:n    +
1           WHERE RES_ASSIGNMENT_ID = h_prj_assign_id AND BIT_FLAG = '0':
1756:
1           EXCEPTION:: SP_A_RESTOPROF(757) :: cplan.sql(9457) :: :
1SC_PARTICIPANT:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n                 +
1 PARTICIPANT = PMO_CNST.SC_AFFECTED, SECURITY_ID = h_temp_security_id:n      +
1            WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1779:
1           EXCEPTION:: SP_A_RESTOPROF(780) :: cplan.sql(9480) :: :
1FC_AFTER_U_RES_ASSIGN:
1PMO_STPU:
1BIT_OR:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n                 +
1 PARTICIPANT=PMO_STPU.BIT_OR(PARTICIPANT, PMO_CNST.SC_AFFECTED):n            +
1      WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1800:
1           EXCEPTION:: SP_A_RESTOPROF(801) :: cplan.sql(9501) :: :
1SC_TEAMMEMBER:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n                 +
1 PARTICIPANT=PMO_STPU.BIT_OR(PARTICIPANT, PMO_CNST.SC_TEAMMEMBER):n          +
1        WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1821:
1           EXCEPTION:: SP_A_RESTOPROF(822) :: cplan.sql(9522) :: :
1FC_DECLARE_PMO_TMP_SEARCH:
1FC_GET_RES_RATES:
1RS:
1SELECT CASE WHEN h_currency_id = rs.CURRENCY_ID THEN 1:n      ELSE h_rate_ech+
1ange / PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4) END:n      INTO h_rate_echa+
1nge:n      FROM RESOURCES rs JOIN TMT_DATAFIELDS td ON rs.CURRENCY_ID = td.EL+
1EMENT_ID AND rs.CURRENCY_ID > 0:n      WHERE RESOURCE_ID=h_res_id:
1861:
1           EXCEPTION:: SP_A_RESTOPROF(862) :: cplan.sql(9562) :: :
11.00:
1ASSIGNMENT_BILLABLE_FLAG:
1TIMEPHASE_PROJECT_ASSIGNMENT:
1SELECT ASSIGNMENT_BILLABLE_FLAG, TIMEPHASE_PROJECT_ASSIGNMENT INTO h_billable+
1, h_pa_timephase:n      FROM PROJECT_DETAILS WHERE PROJECT_ID = h_project_id:
1886:
1           EXCEPTION:: SP_A_RESTOPROF(887) :: cplan.sql(9587) :: :
1SUM:
1SCHED_MIN:
1TASK_DAY_OF_YEAR:
1SELECT SUM(SCHED_MIN) INTO h_total FROM TASK_DAY_OF_YEAR:n         WHERE PROJ+
1ECT_ID = h_project_id AND TASK_ID = h_project_id AND RESOURCE_ID = h_profile_+
1id:
1902:
1           EXCEPTION:: SP_A_RESTOPROF(903) :: cplan.sql(9603) :: :
1SELECT TSK_ASSIGNMENT_ID,RES_ASSIGNMENT_ID,PLANNED_WORK, TO_DATE(SubStr(PLANN+
1ED_START, 1, 10)), TO_DATE(SubStr(PLANNED_FINISH, 1, 10)), BILLABLE, CAPITAL_+
1EXPENSE,:n            REGULAR_COST, REGULAR_RATE, TASK_ID, UNITS_MSP, C_EFFOR+
1T, T_UNIT, C_UNIT, C_CONTOUR:n            INTO h_prj_assignment_id, h_id, h_p+
1lanned_effort, h_start_D, h_finish_D, h_billable, h_capital_expense,:n       +
1     h_old_cost, h_old_sale, h_task_id, h_percent_units, h_work, h_eunit, h_u+
1nit, h_contour:n            FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID +
1= h_project_id AND RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1':
1931:
1           EXCEPTION:: SP_A_RESTOPROF(932) :: cplan.sql(9632) :: :
1SC_0000FFFF:
1947:
1        RETURN_ERROR:: SP_A_RESTOPROF(948) :: cplan.sql(9648) :: :
1TASK_ASSIGNMENT_ERROR:
1950:
1                EXIT:: SP_A_RESTOPROF(951) :: cplan.sql(9651) :: :
1Y:
1-:
1FC_TPHASE_SCHED_ASSIGN:
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
1997:
1           EXCEPTION:: SP_A_RESTOPROF(998) :: cplan.sql(9698) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_prj_assignment_id:
11015:
1           EXCEPTION:: SP_A_RESTOPROF(1016) :: cplan.sql(9716) :: :
1MAX:
1DAY_YEAR:
1SELECT MAX(DAY_YEAR) INTO h_start_D FROM TASK_DAY_OF_YEAR:n                  +
1WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11031:
1           EXCEPTION:: SP_A_RESTOPROF(1032) :: cplan.sql(9732) :: :
1<=:
1DB2TIMESTAMP:
1TIME:
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_D, 1, 10)) + 1     , PM+
1O_ORASTD.TIME(h_start_date)):n                     INTO h_start_date:n       +
1              FROM DUAL:
11047:
1           EXCEPTION:: SP_A_RESTOPROF(1048) :: cplan.sql(9748) :: :
1*:
1SPECIAL_COST:
1SPECIAL_RATE:
1ESTIMATION_LABOR_COST:
1SCHED_WORK:
1ROLLUP_BITS:
1SC_LABOR_BIT:
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_COST = h_reg_cost,:n                        SPECIAL_COST = h_sp+
1ec_cost,:n                        REGULAR_RATE = h_reg_sale,:n               +
1         SPECIAL_RATE = h_spec_sale,:n                        UNITS_MSP = CAS+
1E WHEN h_contour_changed = 0 THEN UNITS_MSP ELSE h_percent_units END,:n      +
1                  ESTIMATION_LABOR_COST = ((PLANNED_WORK+SCHED_WORK)/60.00) *+
1 h_reg_cost,:n                        ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BI+
1TS, PMO_CNST.SC_LABOR_BIT):n                        WHERE TSK_ASSIGNMENT_ID =+
1 h_prj_assignment_id:
11081:
1           EXCEPTION:: SP_A_RESTOPROF(1082) :: cplan.sql(9782) :: :
1ESTIMATION_LABOR_REVENUE:
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_COST = h_reg_cost,:n                        SPECIAL_COST = h_sp+
1ec_cost,:n                        REGULAR_RATE = h_reg_sale,:n               +
1         SPECIAL_RATE = h_spec_sale,:n                        UNITS_MSP = CAS+
1E WHEN h_contour_changed = 0 THEN UNITS_MSP ELSE h_percent_units END,:n      +
1                  ESTIMATION_LABOR_COST = ((PLANNED_WORK+SCHED_WORK)/60.00) *+
1 h_reg_cost,:n                        ESTIMATION_LABOR_REVENUE = ((PLANNED_WO+
1RK+PLANNED_WORK)/60.00) * h_reg_sale,:n                        ROLLUP_BITS = +
1PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_LABOR_BIT):n                        +
1WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11108:
1           EXCEPTION:: SP_A_RESTOPROF(1109) :: cplan.sql(9809) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1          RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                     +
1REGULAR_COST = h_reg_cost,:n                     SPECIAL_COST = h_spec_cost,+
1:n                     UNITS_MSP = CASE WHEN h_contour_changed = 0 THEN UNITS+
1_MSP ELSE h_percent_units END,:n                     ESTIMATION_LABOR_COST = +
1((PLANNED_WORK+SCHED_WORK)/60.00) * h_reg_cost,:n                     ROLLUP_+
1BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_LABOR_BIT):n                 +
1    WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11136:
1           EXCEPTION:: SP_A_RESTOPROF(1137) :: cplan.sql(9837) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_RATE = h_reg_sale,:n                        SPECIAL_RATE = h_sp+
1ec_sale,:n                        UNITS_MSP = CASE WHEN h_contour_changed = 0+
1 THEN UNITS_MSP ELSE h_percent_units END,:n                        ROLLUP_BIT+
1S = PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_LABOR_BIT):n                    +
1    WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11163:
1           EXCEPTION:: SP_A_RESTOPROF(1164) :: cplan.sql(9864) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_RATE = h_reg_sale,:n                        SPECIAL_RATE = h_sp+
1ec_sale,:n                        UNITS_MSP = CASE WHEN h_contour_changed = 0+
1 THEN UNITS_MSP ELSE h_percent_units END,:n                        ESTIMATION+
1_LABOR_REVENUE = ((PLANNED_WORK+PLANNED_WORK)/60.00) * h_reg_sale,:n         +
1               ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_LABOR_B+
1IT):n                        WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11187:
1           EXCEPTION:: SP_A_RESTOPROF(1188) :: cplan.sql(9888) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1          UNITS_MSP = CASE WHEN h_contour_changed = 0 THEN UNITS_MSP ELSE h_p+
1ercent_units END,:n                     RESOURCE_ID = h_res_id, RESOURCE_TYPE+
1 = '0':n                     WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11208:
1           EXCEPTION:: SP_A_RESTOPROF(1209) :: cplan.sql(9909) :: :
11226:
1           EXCEPTION:: SP_A_RESTOPROF(1227) :: cplan.sql(9927) :: :
1RESOURCE_ASSIGN_SKILLS:
1SKILL_ID:
1PROFICIENCY_LEVEL_ID:
1EXPERIENCE_ID:
1PREFERENCE_LEVEL_ID:
1LAST_USED_DATETIME:
1PRIMARY_SKILL:
1INSERT INTO RESOURCE_ASSIGN_SKILLS:n                  SELECT h_prj_assignment+
1_id, SKILL_ID, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID, PREFERENCE_LEVEL_ID, LAST+
1_USED_DATETIME, PRIMARY_SKILL:n                  FROM RESOURCE_ASSIGN_SKILLS +
1WHERE RES_ASSIGNMENT_ID = h_profile_id:
11245:
1           EXCEPTION:: SP_A_RESTOPROF(1246) :: cplan.sql(9946) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_id:
11267:
1           EXCEPTION:: SP_A_RESTOPROF(1268) :: cplan.sql(9968) :: :
1PROJECT_ASSIGNMENTS:
1DELETE FROM PROJECT_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND RESOURCE_+
1ID = h_profile_id:
11285:
1           EXCEPTION:: SP_A_RESTOPROF(1286) :: cplan.sql(9986) :: :
1PMO_FUNC:
1ASSIGNLONG:
1FC_CALC_DURATION:
1INVALID_PARAMS:
18:
11310:
1      RETURN_INVALID:: SP_A_RESTOPROF(1311) :: cplan.sql(10011) :: :
11313:
1                EXIT:: SP_A_RESTOPROF(1314) :: cplan.sql(10014) :: :
1PMO_RETURN_INVALID_SP:
11318:
1        RETURN_ERROR:: SP_A_RESTOPROF(1319) :: cplan.sql(10019) :: :
11321:
1                EXIT:: SP_A_RESTOPROF(1322) :: cplan.sql(10022) :: :
1SC_BIT_27:
1FC_SEARCH_2:
1110:
11349:
1        RETURN_ERROR:: SP_A_RESTOPROF(1350) :: cplan.sql(10050) :: :
1RESOURCE_UNAVAILABLE:
11352:
1                EXIT:: SP_A_RESTOPROF(1353) :: cplan.sql(10053) :: :
11357:
1        RETURN_ERROR:: SP_A_RESTOPROF(1358) :: cplan.sql(10058) :: :
11360:
1                EXIT:: SP_A_RESTOPROF(1361) :: cplan.sql(10061) :: :
1U_ASSIGN_STRING:
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(PLANNED_START, 1, 10)), TO_DATE(SubS+
1tr(PLANNED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULAR_COST, REGULAR_+
1RATE:n            INTO h_old_prj_assign_id, h_start_D, h_finish_D, h_billable+
1, h_capital_expense, h_old_cost, h_old_sale:n            FROM TASK_ASSIGNMENT+
1S:n            WHERE PROJECT_ID = h_project_id AND TASK_ID = h_project_id :n +
1           AND RESOURCE_TYPE = '1' AND RESOURCE_ID = h_profile_id:
11385:
1           EXCEPTION:: SP_A_RESTOPROF(1386) :: cplan.sql(10086) :: :
1SELECT TSK_ASSIGNMENT_ID, BILLABLE INTO h_old_prj_assign_id, h_billable:n    +
1        FROM TASK_ASSIGNMENTS:n            WHERE PROJECT_ID = h_project_id AN+
1D TASK_ID = h_project_id :n            AND RESOURCE_ID = h_profile_id AND RES+
1OURCE_TYPE = '1':
11410:
1           EXCEPTION:: SP_A_RESTOPROF(1411) :: cplan.sql(10111) :: :
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(PLANNED_START, 1, 10)), TO_DATE(SubS+
1tr(PLANNED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULAR_COST, REGULAR_+
1RATE:n         INTO h_old_prj_assign_id, h_start_D, h_finish_D, h_billable, h+
1_capital_expense, h_old_cost, h_old_sale:n         FROM TASK_ASSIGNMENTS:n   +
1      WHERE PROJECT_ID = h_project_id AND TASK_ID = h_project_id :n         A+
1ND RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1':
11430:
1           EXCEPTION:: SP_A_RESTOPROF(1431) :: cplan.sql(10131) :: :
1SELECT TSK_ASSIGNMENT_ID, BILLABLE INTO h_old_prj_assign_id, h_billable:n    +
1     FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_ID = h_project_id AND TASK+
1_ID = h_project_id :n         AND RESOURCE_ID = h_profile_id AND RESOURCE_TYP+
1E = '1':
11455:
1           EXCEPTION:: SP_A_RESTOPROF(1456) :: cplan.sql(10156) :: :
1IS NULL:
1SD:
1FD:
1START_DT:
1FINISH_DT:
1BAK_START_DT:
1BAK_FINISH_DT:
1SC_NS:
1SC_NF:
1INSERT INTO TASK_ASSIGNMENTS(TSK_ASSIGNMENT_ID,RES_ASSIGNMENT_ID,TASK_ID,PROJ+
1ECT_ID,SD,FD,START_DT,FINISH_DT,:n               PLANNED_START, PLANNED_FINIS+
1H, BIT_FLAG, BAK_START_DT, BAK_FINISH_DT, RESOURCE_ID,RESOURCE_TYPE,PROJECT_A+
1SSIGNMENT_ID,:n               BILLABLE, CAPITAL_EXPENSE, REGULAR_COST,SPECIAL+
1_COST,REGULAR_RATE,SPECIAL_RATE, TIMECODE_1_ID, TIMECODE_2_ID, TABLE_TYPE):n +
1              VALUES(h_prj_assignment_id, h_prj_assign_id, h_project_id, h_pr+
1oject_id, PMO_CNST.SC_NS,PMO_CNST.SC_NF,h_start_DT, h_finish_DT,:n           +
1    h_start_DT, h_finish_DT, '0', h_start_DT, h_finish_DT, h_res_id,h_res_typ+
1e, h_prj_assignment_id,:n               h_billable, h_capital_expense,h_reg_c+
1ost,h_spec_cost,h_reg_sale,h_spec_sale,h_timecode_1_id, h_timecode_2_id, h_ta+
1ble_type):
11501:
1           EXCEPTION:: SP_A_RESTOPROF(1502) :: cplan.sql(10202) :: :
1INSERT INTO TASK_ASSIGNMENTS(TSK_ASSIGNMENT_ID,RES_ASSIGNMENT_ID,TASK_ID,PROJ+
1ECT_ID,SD,FD,START_DT,FINISH_DT,:n               PLANNED_START, PLANNED_FINIS+
1H, BIT_FLAG, BAK_START_DT, BAK_FINISH_DT, RESOURCE_ID,RESOURCE_TYPE,PROJECT_A+
1SSIGNMENT_ID,:n               BILLABLE, CAPITAL_EXPENSE, REGULAR_COST,SPECIAL+
1_COST,REGULAR_RATE,SPECIAL_RATE, TIMECODE_1_ID, TIMECODE_2_ID, TABLE_TYPE):n +
1              VALUES(h_prj_assignment_id, h_prj_assign_id, h_project_id, h_pr+
1oject_id, PMO_CNST.SC_NS,PMO_CNST.SC_NF,h_start_DT, h_finish_DT,:n           +
1    h_start_DT, h_finish_DT, '0', h_start_DT, h_finish_DT, h_res_id,h_res_typ+
1e, h_prj_assignment_id,:n               h_billable, h_capital_expense,h_reg_c+
1ost,h_spec_cost,h_reg_sale,h_spec_sale, h_timecode_1_id, h_timecode_2_id, h_t+
1able_type):
11526:
1           EXCEPTION:: SP_A_RESTOPROF(1527) :: cplan.sql(10227) :: :
11551:
1           EXCEPTION:: SP_A_RESTOPROF(1552) :: cplan.sql(10252) :: :
1INSERT INTO TASK_ASSIGNMENTS(TSK_ASSIGNMENT_ID,RES_ASSIGNMENT_ID,TASK_ID,PROJ+
1ECT_ID,SD,FD,START_DT,FINISH_DT,:n            PLANNED_START,PLANNED_FINISH,BI+
1T_FLAG,BAK_START_DT,BAK_FINISH_DT,RESOURCE_ID,RESOURCE_TYPE,PROJECT_ASSIGNMEN+
1T_ID,:n            BILLABLE, CAPITAL_EXPENSE, REGULAR_COST,SPECIAL_COST,REGUL+
1AR_RATE,SPECIAL_RATE, TIMECODE_1_ID, TIMECODE_2_ID, TABLE_TYPE):n            +
1VALUES(h_prj_assignment_id, h_prj_assign_id, h_project_id, h_project_id, PMO_+
1CNST.SC_NS,PMO_CNST.SC_NF,h_start_DT, h_finish_DT,:n            h_start_DT, h+
1_finish_DT, '0', h_start_DT, h_finish_DT, h_res_id,h_res_type, h_prj_assignme+
1nt_id,:n            h_billable, h_capital_expense,h_reg_cost,h_spec_cost,h_re+
1g_sale,h_spec_sale, h_timecode_1_id, h_timecode_2_id, h_table_type):
11574:
1           EXCEPTION:: SP_A_RESTOPROF(1575) :: cplan.sql(10275) :: :
1%:
11600:
1           EXCEPTION:: SP_A_RESTOPROF(1601) :: cplan.sql(10301) :: :
1MIN:
1SELECT MIN(t.PLANNED_START) INTO h_start_date:n         FROM TMT_WBS w, TASK_+
1ASSIGNMENTS t:n         WHERE t.PROJECT_ID = h_project_id AND t.RESOURCE_ID =+
1 h_profile_id AND:n         t.TASK_ID = w.ELEMENT_ID AND w.TYPE_ID IN (PMO_CN+
1ST.SC_TASK,PMO_CNST.SC_TASK_TYPE1,PMO_CNST.SC_TASK_TYPE2,PMO_CNST.SC_TASK_TYP+
1E3,PMO_CNST.SC_MILESTONE,PMO_CNST.SC_PERSONAL_TASK,PMO_CNST.SC_ACTIVE_ADM_TAS+
1K,PMO_CNST.SC_INACTIVE_ADM_TASK,PMO_CNST.SC_WBS_CHANGE_REQUEST_TASK,PMO_CNST.+
1SC_WBS_ACTION_ITEM_TASK,PMO_CNST.SC_WBS_RISK_TASK,PMO_CNST.SC_WBS_ISSUE_TASK,+
1PMO_CNST.SC_WBS_REQUIREMENT_TASK,PMO_CNST.SC_WBS_DEFECT_TASK,PMO_CNST.SC_WBS_+
1SERVICE_REQUEST_TASK) AND w.RANK LIKE h_rank:
11622:
1           EXCEPTION:: SP_A_RESTOPROF(1623) :: cplan.sql(10323) :: :
1LOOP:
1EXIT:
1FC_BEFORE_D_RES_ASSIGN:
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
11672:
1           EXCEPTION:: SP_A_RESTOPROF(1673) :: cplan.sql(10373) :: :
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11689:
1           EXCEPTION:: SP_A_RESTOPROF(1690) :: cplan.sql(10390) :: :
1EFFORT_WEEK:
1DELETE FROM EFFORT_WEEK WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11706:
1           EXCEPTION:: SP_A_RESTOPROF(1707) :: cplan.sql(10407) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_tsk_assignment_id:
11723:
1           EXCEPTION:: SP_A_RESTOPROF(1724) :: cplan.sql(10424) :: :
1RESOURCE_ASSIGN_ROLES:
1DELETE FROM RESOURCE_ASSIGN_ROLES WHERE RES_ASSIGNMENT_ID = h_tsk_assignment_+
1id:
11740:
1           EXCEPTION:: SP_A_RESTOPROF(1741) :: cplan.sql(10441) :: :
1DELETE FROM RESOURCE_ASSIGN_SKILLS WHERE RES_ASSIGNMENT_ID = h_tsk_assignment+
1_id:
11757:
1           EXCEPTION:: SP_A_RESTOPROF(1758) :: cplan.sql(10458) :: :
1SELECT TSK_ASSIGNMENT_ID INTO h_id FROM TASK_ASSIGNMENTS:n            WHERE P+
1ROJECT_ID = h_project_id AND TASK_ID = h_task_id AND RESOURCE_ID = h_res_id:n+
1            AND RESOURCE_TYPE ='0':
11772:
1           EXCEPTION:: SP_A_RESTOPROF(1773) :: cplan.sql(10473) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_id, h_participant, +
1h_security_id:n               FROM RESOURCE_ASSIGNMENTS :n               WHER+
1E ELEMENT_ID = h_task_id AND RESOURCE_ID = h_res_id AND RESOURCE_TYPE='0':
11795:
1           EXCEPTION:: SP_A_RESTOPROF(1796) :: cplan.sql(10496) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                     PROFILE_ID		= h_profil+
1e_id,:n                     RESOURCE_ID		= h_res_id, :n                     R+
1ESOURCE_TYPE	= '0':n                     WHERE RES_ASSIGNMENT_ID = h_assign_i+
1d:
11821:
1           EXCEPTION:: SP_A_RESTOPROF(1822) :: cplan.sql(10522) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                     PARTICIPANT		= PMO_CNS+
1T.SC_TEAMMEMBER, :n                     SECURITY_ID		= h_temp_security_id, :n+
1                     PROFILE_ID		= h_profile_id,:n                     RESOUR+
1CE_ID		= h_res_id, :n                     RESOURCE_TYPE	= '0':n              +
1       WHERE RES_ASSIGNMENT_ID = h_assign_id:
11847:
1           EXCEPTION:: SP_A_RESTOPROF(1848) :: cplan.sql(10548) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                     PARTICIPANT		= PMO_STP+
1U.BIT_OR(h_participant,PMO_CNST.SC_TEAMMEMBER), :n                     SECURI+
1TY_ID		= h_security_id, :n                     PROFILE_ID		= h_profile_id,:n +
1                    RESOURCE_ID		= h_res_id, :n                     RESOURCE_+
1TYPE	= '0':n                     WHERE RES_ASSIGNMENT_ID = h_assign_id:
11870:
1           EXCEPTION:: SP_A_RESTOPROF(1871) :: cplan.sql(10571) :: :
11889:
1           EXCEPTION:: SP_A_RESTOPROF(1890) :: cplan.sql(10590) :: :
1RA:
1CREATED_BY:
1TA:
1SELECT ra.RES_ASSIGNMENT_ID, SUBSTR(tw.ASSIGN_NAMES,1,InStr(tw.ASSIGN_NAMES, +
1';') - 1):n                  INTO h_id,h_in FROM TMT_WBS tw, RESOURCE_ASSIGNM+
1ENTS ra:n                  WHERE tw.ELEMENT_ID = h_task_id AND tw.ELEMENT_ID +
1= ra.ELEMENT_ID AND ra.PARTICIPANT = 32 :n                  AND ra.RESOURCE_I+
1D = tw.CREATED_BY AND NOT EXISTS(:n                  SELECT TSK_ASSIGNMENT_ID+
1 FROM TASK_ASSIGNMENTS ta WHERE ta.RES_ASSIGNMENT_ID = ra.RES_ASSIGNMENT_ID):
11907:
1           EXCEPTION:: SP_A_RESTOPROF(1908) :: cplan.sql(10608) :: :
1SC_RESPONSIBLE_GROUP:
11929:
1           EXCEPTION:: SP_A_RESTOPROF(1930) :: cplan.sql(10630) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE='0',:n +
1                    PROFILE_ID = h_profile_id, PARTICIPANT = 48, SECURITY_ID=+
1h_temp_security_id:n                     WHERE RES_ASSIGNMENT_ID = h_assign_i+
1d:
11948:
1           EXCEPTION:: SP_A_RESTOPROF(1949) :: cplan.sql(10649) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_in, h_full_name) +
1:n                     WHERE ELEMENT_ID = h_task_id:
11966:
1           EXCEPTION:: SP_A_RESTOPROF(1967) :: cplan.sql(10667) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_profile_name, h_fu+
1ll_name) WHERE ELEMENT_ID = h_task_id:
11986:
1           EXCEPTION:: SP_A_RESTOPROF(1987) :: cplan.sql(10687) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',+
1:n                     PROFILE_ID = h_profile_id, PARTICIPANT = 16, SECURITY_+
1ID=h_temp_security_id:n                     WHERE RES_ASSIGNMENT_ID = h_assig+
1n_id:
12005:
1           EXCEPTION:: SP_A_RESTOPROF(2006) :: cplan.sql(10706) :: :
1SELECT CASE WHEN FS_LABOR_CODE IS NuLL THEN 0 WHEN FS_LABOR_CODE = h_labor_co+
1de THEN 1 ELSE 2 END:n                     INTO h_same_labor FROM TMT_WBS WHE+
1RE ELEMENT_ID=h_task_id:
12025:
1           EXCEPTION:: SP_A_RESTOPROF(2026) :: cplan.sql(10726) :: :
1UPDATE TMT_WBS SET FS_LABOR_CODE = h_labor_code WHERE ELEMENT_ID=h_task_id:
12044:
1           EXCEPTION:: SP_A_RESTOPROF(2045) :: cplan.sql(10745) :: :
12057:
1           EXCEPTION:: SP_A_RESTOPROF(2058) :: cplan.sql(10758) :: :
12063:
1        RETURN_ERROR:: SP_A_RESTOPROF(2064) :: cplan.sql(10764) :: :
1CANNOT_ASSIGN_LABOR_CODE:
12066:
1                EXIT:: SP_A_RESTOPROF(2067) :: cplan.sql(10767) :: :
12143:
1           EXCEPTION:: SP_A_RESTOPROF(2144) :: cplan.sql(10844) :: :
1ETC:
1UPDATE TASK_ASSIGNMENTS SET:n                           RESOURCE_ID = h_res_i+
1d, RESOURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                           CAS+
1E WHEN h_assigned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n              +
1             REGULAR_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_cos+
1t  ELSE REGULAR_COST END,:n                           SPECIAL_COST = CASE WHE+
1N h_donot_replace_cost = 0 THEN h_spec_cost ELSE SPECIAL_COST END,:n         +
1                  REGULAR_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_re+
1g_sale  ELSE REGULAR_RATE END,:n                           SPECIAL_RATE = CAS+
1E WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE SPECIAL_RATE END,:n    +
1                       UNITS_MSP    = work001, ETC = h_effort,:n             +
1              C_CONTOUR    = contour001,:n                           ROLLUP_B+
1ITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_LABOR_BIT):n                 +
1          WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12191:
1           EXCEPTION:: SP_A_RESTOPROF(2192) :: cplan.sql(10892) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           RESOURCE_ID = h_res_i+
1d, RESOURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                           CAS+
1E WHEN h_assigned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n              +
1             REGULAR_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_cos+
1t  ELSE REGULAR_COST END,:n                           SPECIAL_COST = CASE WHE+
1N h_donot_replace_cost = 0 THEN h_spec_cost ELSE SPECIAL_COST END,:n         +
1                  REGULAR_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_re+
1g_sale  ELSE REGULAR_RATE END,:n                           SPECIAL_RATE = CAS+
1E WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE SPECIAL_RATE END,:n    +
1                       C_EFFORT     = work001, ETC = h_effort,:n             +
1              C_UNIT       = unit,:n                           C_CONTOUR    =+
1 contour001,:n                           ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLU+
1P_BITS, PMO_CNST.SC_LABOR_BIT):n                           WHERE TSK_ASSIGNME+
1NT_ID = h_tsk_assignment_id:
12219:
1           EXCEPTION:: SP_A_RESTOPROF(2220) :: cplan.sql(10920) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                        RESOURCE_ID = h_res_id, +
1RESOURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                        CASE WHEN+
1 h_assigned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n                    +
1    REGULAR_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_cost  ELSE R+
1EGULAR_COST END,:n                        SPECIAL_COST = CASE WHEN h_donot_re+
1place_cost = 0 THEN h_spec_cost ELSE SPECIAL_COST END,:n                     +
1   REGULAR_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_reg_sale  ELSE RE+
1GULAR_RATE END,:n                        SPECIAL_RATE = CASE WHEN h_donot_rep+
1lace_rate = 0 THEN h_spec_sale ELSE SPECIAL_RATE END,:n                      +
1  ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_LABOR_BIT), ETC = h+
1_effort:n                        WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_i+
1d:
12247:
1           EXCEPTION:: SP_A_RESTOPROF(2248) :: cplan.sql(10948) :: :
12273:
1           EXCEPTION:: SP_A_RESTOPROF(2274) :: cplan.sql(10974) :: :
12279:
1      RETURN_INVALID:: SP_A_RESTOPROF(2280) :: cplan.sql(10980) :: :
12282:
1                EXIT:: SP_A_RESTOPROF(2283) :: cplan.sql(10983) :: :
12294:
1           EXCEPTION:: SP_A_RESTOPROF(2295) :: cplan.sql(10995) :: :
12300:
1        RETURN_ERROR:: SP_A_RESTOPROF(2301) :: cplan.sql(11001) :: :
12303:
1                EXIT:: SP_A_RESTOPROF(2304) :: cplan.sql(11004) :: :
1TRUNC:
1/:
130:
11.5:
1UPDATE TASK_ASSIGNMENTS SET:n                     RESOURCE_ID = h_res_id, RES+
1OURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                     CASE WHEN h_ass+
1igned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n                     REGUL+
1AR_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_cost  ELSE REGULAR_CO+
1ST END,:n                     SPECIAL_COST = CASE WHEN h_donot_replace_cost =+
1 0 THEN h_spec_cost ELSE SPECIAL_COST END,:n                     REGULAR_RATE+
1 = CASE WHEN h_donot_replace_rate = 0 THEN h_reg_sale  ELSE REGULAR_RATE END,+
1:n                     SPECIAL_RATE = CASE WHEN h_donot_replace_rate = 0 THEN+
1 h_spec_sale ELSE SPECIAL_RATE END,:n                     ROLLUP_BITS  = PMO_+
1STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_LABOR_BIT):n                     WHERE T+
1SK_ASSIGNMENT_ID = h_tsk_assignment_id:
12351:
1           EXCEPTION:: SP_A_RESTOPROF(2352) :: cplan.sql(11052) :: :
12394:
1           EXCEPTION:: SP_A_RESTOPROF(2395) :: cplan.sql(11095) :: :
12400:
1        RETURN_ERROR:: SP_A_RESTOPROF(2401) :: cplan.sql(11101) :: :
12403:
1                EXIT:: SP_A_RESTOPROF(2404) :: cplan.sql(11104) :: :
12415:
1           EXCEPTION:: SP_A_RESTOPROF(2416) :: cplan.sql(11116) :: :
12421:
1        RETURN_ERROR:: SP_A_RESTOPROF(2422) :: cplan.sql(11122) :: :
12424:
1                EXIT:: SP_A_RESTOPROF(2425) :: cplan.sql(11125) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE(ASSIGN_NAMES,h_profile_name || ';',+
1'') WHERE ELEMENT_ID=h_task_id:
12448:
1           EXCEPTION:: SP_A_RESTOPROF(2449) :: cplan.sql(11149) :: :
1C:
1TMT_COMPETENCIES:
1P:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n                  SELECT h_tsk_assignment_+
1id, c.ELEMENT_ID, c.PROFICIENCY_LEVEL_ID, c.EXPERIENCE_ID, c.PREFERENCE_LEVEL+
1_ID, c.LAST_USED_DATETIME, '0':n                  FROM TMT_COMPETENCIES c JOI+
1N PROFILES p ON c.ELEMENT_ID = p.ROLE_ID WHERE p.PROFILE_ID = h_profile_id:
12468:
1           EXCEPTION:: SP_A_RESTOPROF(2469) :: cplan.sql(11169) :: :
1PRIMARY_ROLE:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n                  SELECT h_tsk_assignment_+
1id, ROLE_ID, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID, PREFERENCE_LEVEL_ID, LAST_U+
1SED_DATETIME, PRIMARY_ROLE:n                  FROM RESOURCE_ASSIGN_ROLES WHER+
1E RES_ASSIGNMENT_ID = h_profile_id:
12488:
1           EXCEPTION:: SP_A_RESTOPROF(2489) :: cplan.sql(11189) :: :
1INSERT INTO RESOURCE_ASSIGN_SKILLS:n                  SELECT h_tsk_assignment+
1_id, SKILL_ID, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID, PREFERENCE_LEVEL_ID, LAST+
1_USED_DATETIME, PRIMARY_SKILL:n                  FROM RESOURCE_ASSIGN_SKILLS +
1WHERE RES_ASSIGNMENT_ID = h_profile_id:
12507:
1           EXCEPTION:: SP_A_RESTOPROF(2508) :: cplan.sql(11208) :: :
1FC_AFTER_REPLACE_RES_ASSIGN:
1UPDATE EFFORT_WEEK SET RESOURCE_ID = h_res_id:n                  WHERE PROJEC+
1T_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12534:
1           EXCEPTION:: SP_A_RESTOPROF(2535) :: cplan.sql(11235) :: :
1SUMMARY_TIMESHEETS:
1ACTUAL_REGULAR_COST:
1ACTUAL_SPECIAL_COST:
1ACTUAL_REGULAR_RATE:
1ACTUAL_SPECIAL_RATE:
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                     A+
1CTUAL_REGULAR_COST = h_reg_cost  ,:n                     ACTUAL_SPECIAL_COST +
1= h_spec_cost ,:n                     ACTUAL_REGULAR_RATE = h_reg_sale  ,:n  +
1                   ACTUAL_SPECIAL_RATE = h_spec_sale ,:n                     +
1REC_USER = h_rec_user, REC_DATETIME = SYSTIMESTAMP:n                     WHER+
1E TSK_ASSIGNMENT_ID = h_id:
12559:
1           EXCEPTION:: SP_A_RESTOPROF(2560) :: cplan.sql(11260) :: :
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                     A+
1CTUAL_REGULAR_COST = h_reg_cost  ,:n                     ACTUAL_SPECIAL_COST +
1= h_spec_cost ,:n                     REC_USER = h_rec_user, REC_DATETIME = S+
1YSTIMESTAMP:n                     WHERE TSK_ASSIGNMENT_ID = h_id:
12580:
1           EXCEPTION:: SP_A_RESTOPROF(2581) :: cplan.sql(11281) :: :
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                     A+
1CTUAL_REGULAR_RATE = h_reg_sale  ,:n                     ACTUAL_SPECIAL_RATE +
1= h_spec_sale ,:n                     REC_USER = h_rec_user, REC_DATETIME = S+
1YSTIMESTAMP:n                     WHERE TSK_ASSIGNMENT_ID = h_id:
12603:
1           EXCEPTION:: SP_A_RESTOPROF(2604) :: cplan.sql(11304) :: :
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                     R+
1EC_USER = h_rec_user, REC_DATETIME = SYSTIMESTAMP:n                     WHERE+
1 TSK_ASSIGNMENT_ID = h_id:
12624:
1           EXCEPTION:: SP_A_RESTOPROF(2625) :: cplan.sql(11325) :: :
1FC_D_RA_AFTER_REPLACE:
12662:
1           EXCEPTION:: SP_A_RESTOPROF(2663) :: cplan.sql(11363) :: :
1>=:
12706:
1      RETURN_INVALID:: SP_A_RESTOPROF(2707) :: cplan.sql(11407) :: :
12709:
1                EXIT:: SP_A_RESTOPROF(2710) :: cplan.sql(11410) :: :
12714:
1        RETURN_ERROR:: SP_A_RESTOPROF(2715) :: cplan.sql(11415) :: :
12717:
1                EXIT:: SP_A_RESTOPROF(2718) :: cplan.sql(11418) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_PA_SUM:
1PMO_TMP_PA_SUM:
1PARENT_ID:
1INSERT INTO PMO_TMP_PA_SUM SELECT DAY_YEAR, SUM(SCHED_MIN):n               FR+
1OM TASK_DAY_OF_YEAR:n               WHERE PROJECT_ID = h_project_id AND PAREN+
1T_ID = h_prj_assignment_id:n               GROUP BY DAY_YEAR:
12741:
1           EXCEPTION:: SP_A_RESTOPROF(2742) :: cplan.sql(11442) :: :
1SC_BIT_30:
12774:
1        RETURN_ERROR:: SP_A_RESTOPROF(2775) :: cplan.sql(11475) :: :
12777:
1                EXIT:: SP_A_RESTOPROF(2778) :: cplan.sql(11478) :: :
12782:
1        RETURN_ERROR:: SP_A_RESTOPROF(2783) :: cplan.sql(11483) :: :
12785:
1                EXIT:: SP_A_RESTOPROF(2786) :: cplan.sql(11486) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1       RESOURCE_ID  = h_res_id, RESOURCE_TYPE = '0',:n                  REGUL+
1AR_COST = CASE WHEN h_donot_replace_rate = 0 THEN h_reg_cost  * h_rate_echang+
1e ELSE REGULAR_COST END,:n                  SPECIAL_COST = CASE WHEN h_donot_+
1replace_rate = 0 THEN h_spec_cost * h_rate_echange ELSE SPECIAL_COST END,:n  +
1                REGULAR_RATE = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_+
1sale  * h_rate_echange ELSE REGULAR_RATE END,:n                  SPECIAL_RATE+
1 = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_sale * h_rate_echange ELSE +
1SPECIAL_RATE END:n                  WHERE TSK_ASSIGNMENT_ID = h_prj_assignmen+
1t_id:
12808:
1           EXCEPTION:: SP_A_RESTOPROF(2809) :: cplan.sql(11509) :: :
1SELECT COUNT(*) INTO h_count FROM RESOURCE_ASSIGNMENTS:n         WHERE ELEMEN+
1T_ID = h_project_id AND RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1':
12825:
1           EXCEPTION:: SP_A_RESTOPROF(2826) :: cplan.sql(11526) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE(ASSIGN_NAMES,h_profile_name || ';',+
1''):n            WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_project_i+
1d:
12845:
1           EXCEPTION:: SP_A_RESTOPROF(2846) :: cplan.sql(11546) :: :
1SC_ASSIGNMENT_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_ASS+
1IGNMENT_BIT) WHERE ELEMENT_ID = h_project_id:
12868:
1           EXCEPTION:: SP_A_RESTOPROF(2869) :: cplan.sql(11569) :: :
1SELECT COUNT(*) INTO h_count FROM TASK_ASSIGNMENTS:n            WHERE PROJECT+
1_ID = h_project_id AND PROJECT_ASSIGNMENT_ID = h_old_prj_assign_id:
12884:
1           EXCEPTION:: SP_A_RESTOPROF(2885) :: cplan.sql(11585) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND:n       +
1        ELEMENT_ID = h_project_id AND RESOURCE_ID = h_profile_id AND RESOURCE+
1_TYPE = '1':
12904:
1           EXCEPTION:: SP_A_RESTOPROF(2905) :: cplan.sql(11605) :: :
12921:
1           EXCEPTION:: SP_A_RESTOPROF(2922) :: cplan.sql(11622) :: :
13:
1BEST:
1SELECT PLANNED_START, PLANNED_FINISH, BEST, TO_DATE(SubStr(BAK_START_DT, 1, 1+
10)), TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULA+
1R_COST, REGULAR_RATE:n            INTO h_start_DT, h_finish_DT, h_effort, h_s+
1tart_D, h_finish_D, h_billable, h_capital_expense, h_old_cost, h_old_sale:n  +
1          FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_old_prj_assign_id:
12943:
1           EXCEPTION:: SP_A_RESTOPROF(2944) :: cplan.sql(11644) :: :
1ESTIMATED_PLANNED_START:
1ESTIMATED_PLANNED_FINISH:
1ESTIMATED_PLANNED_EFFORT:
1ESTIMATED_PLANNED_COST:
1ESTIMATED_PLANNED_REVENUE:
1UPDATE PROJECT_ASSIGNMENTS SET:n                  ESTIMATED_PLANNED_START = h+
1_start_DT,:n                  ESTIMATED_PLANNED_FINISH = h_finish_DT,:n      +
1            ESTIMATED_PLANNED_EFFORT = h_effort,:n                  ESTIMATED+
1_PLANNED_COST = (h_effort/60.00) * h_old_cost,:n                  ESTIMATED_P+
1LANNED_REVENUE = 0.00:n                  WHERE PROJECT_ID = h_project_id AND +
1RESOURCE_ID = h_profile_id:
12969:
1           EXCEPTION:: SP_A_RESTOPROF(2970) :: cplan.sql(11670) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n                  ESTIMATED_PLANNED_START = h+
1_start_DT,:n                  ESTIMATED_PLANNED_FINISH = h_finish_DT,:n      +
1            ESTIMATED_PLANNED_EFFORT = h_effort,:n                  ESTIMATED+
1_PLANNED_COST = (h_effort/60.00) * h_old_cost,:n                  ESTIMATED_P+
1LANNED_REVENUE = (h_effort/60.00) * h_old_sale:n                  WHERE PROJE+
1CT_ID = h_project_id AND RESOURCE_ID = h_profile_id:
12992:
1           EXCEPTION:: SP_A_RESTOPROF(2993) :: cplan.sql(11693) :: :
1SELECT COUNT(*) INTO h_count FROM TASK_ASSIGNMENTS:n            WHERE PROJECT+
1_ID = h_project_id AND PROJECT_ASSIGNMENT_ID = h_prj_assignment_id:n         +
1   AND RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1':
13029:
1           EXCEPTION:: SP_A_RESTOPROF(3030) :: cplan.sql(11730) :: :
1UPDATE TASK_ASSIGNMENTS:n               SET PROJECT_ASSIGNMENT_ID = Null:n   +
1            WHERE PROJECT_ID = h_project_id AND PROJECT_ASSIGNMENT_ID = h_prj+
1_assignment_id:n               AND RESOURCE_ID = h_profile_id AND RESOURCE_TY+
1PE = '1':
13051:
1           EXCEPTION:: SP_A_RESTOPROF(3052) :: cplan.sql(11752) :: :
1UPDATE TASK_DAY_OF_YEAR:n               SET PARENT_ID = TSK_ASSIGNMENT_ID:n  +
1             WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_prj_assignment+
1_id:n               AND RESOURCE_ID = h_profile_id:
13071:
1           EXCEPTION:: SP_A_RESTOPROF(3072) :: cplan.sql(11772) :: :
1SELECT PLANNED_START, PLANNED_FINISH, BEST, TO_DATE(SubStr(BAK_START_DT, 1, 1+
10)), TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULA+
1R_COST, REGULAR_RATE:n         INTO h_start_DT, h_finish_DT, h_effort, h_star+
1t_D, h_finish_D, h_billable, h_capital_expense, h_reg_cost, h_reg_sale:n     +
1    FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
13092:
1           EXCEPTION:: SP_A_RESTOPROF(3093) :: cplan.sql(11793) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n               ESTIMATED_PLANNED_START  = h_s+
1tart_DT,:n               ESTIMATED_PLANNED_FINISH = h_finish_DT,:n           +
1    ESTIMATED_PLANNED_EFFORT = h_effort,:n               ESTIMATED_PLANNED_CO+
1ST   = (h_effort/60.00) * h_reg_cost,:n               ESTIMATED_PLANNED_REVEN+
1UE = 0.00:n               WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h+
1_res_id:
13118:
1           EXCEPTION:: SP_A_RESTOPROF(3119) :: cplan.sql(11819) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n               ESTIMATED_PLANNED_START  = h_s+
1tart_DT,:n               ESTIMATED_PLANNED_FINISH = h_finish_DT,:n           +
1    ESTIMATED_PLANNED_EFFORT = h_effort,:n               ESTIMATED_PLANNED_CO+
1ST   = (h_effort/60.00) * h_reg_cost,:n               ESTIMATED_PLANNED_REVEN+
1UE = (h_effort/60.00) * h_reg_sale:n               WHERE PROJECT_ID = h_proje+
1ct_id AND RESOURCE_ID = h_res_id:
13141:
1           EXCEPTION:: SP_A_RESTOPROF(3142) :: cplan.sql(11842) :: :
1FC_ROLLUP:
13167:
1       RETURN_STATUS:: SP_A_RESTOPROF(3168) :: cplan.sql(11868) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
13174:
1           EXCEPTION:: SP_A_RESTOPROF(3175) :: cplan.sql(11875) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
13186:
1           EXCEPTION:: SP_A_RESTOPROF(3187) :: cplan.sql(11887) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
4ae5
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c :3 a0
51 a5 b a5 b 5a 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a0 f4 b4 bf
c8 :5 a0 12a bd b7 11 a4 b1
a0 f4 b4 bf c8 :9 a0 12a bd
b7 11 a4 b1 a0 f4 b4 bf
c8 :6d a0 12a bd b7 11 a4 b1
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :4 a0 51
a5 b :2 a0 6b a5 b d :2 a0
51 a5 b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b a0 7e
a0 6b b4 2e 5a 52 10 a0
51 d b7 19 3c :2 a0 d a0
6e d a0 6e d a0 51 d
a0 6e d a0 4d d a0 4d
d :2 a0 e9 dd b3 :2 a0 e9 d3
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :3 a0 6b
d :2 a0 e9 c1 :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :11 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c a0 51 d
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :25 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :7 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 6e
a5 b 7e 51 b4 2e a0 6e
d b7 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :2 a0
d :4 a0 51 a5 b 51 a5 b
d :4 a0 51 a5 b 51 a5 b
d :4 a0 51 a5 b 51 a5 b
d a0 7e 51 b4 2e :2 a0 51
a5 b 7e 51 b4 2e :b a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :b a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c b7 :b a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :b a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b a5 b
5a 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 5a a 10 :a a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 19 3c b7 :2 19 3c a0
6e d a0 6e d a0 6e d
a0 4d d a0 4d d :2 a0 e9
dd b3 :2 a0 e9 d3 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 51 d b7
a0 51 d b7 :2 19 3c :2 a0 e9
c1 :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :b a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
:d a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 a0 b7 a0 7e b4
2e :2 5a a0 7e b4 2e :2 5a a
10 :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c b7 :2 19 3c b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e a0 51 d :2 a0 d b7 :b a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 6e d :2 a0 b4
2e d :2 a0 51 :2 a0 51 a5 b
:2 a0 6b a0 a5 b d :3 a0 6b
d a0 6e d a0 51 d :9 a0
a5 b d :4 a0 51 a5 b a5
b d :1a a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
:2 a0 a5 b 7e 51 b4 2e a0
51 d b7 :c a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e :a a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :11 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :11 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
a0 b7 :2 a0 6b a0 7e a0 6b
b4 2e 5a :6 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 51 :2 a0 51 a5 b :2 a0 6b
a0 a5 b d :a a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 a5 b
d a0 b7 :3 a0 51 a5 b :2 a0
6b a5 b 5a a0 7e a0 6b
b4 2e :b a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 a5 b d b7
19 :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 a5 b d b7 :2 19
3c b7 :2 19 3c b7 :2 19 3c b7
:2 a0 d b7 :2 19 3c a0 6e d
a0 6e d a0 6e d :2 a0 b4
2e d :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 :c a0 a5
b d b7 19 3c :16 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 51 d b7 19 3c a0
51 d a0 51 d a0 4d d
:7 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 a5 b
7e 51 b4 2e :a a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d b7 a0 51 d b7 :2 19 3c
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 a5 b
7e 51 b4 2e :28 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
d a0 51 d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
5a :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 5a 52 10
:2 a0 51 a5 b 7e 51 b4 2e
5a :3 a0 51 a5 b :2 a0 6b a5
b 5a 7e 51 b4 2e 5a a
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 a0 51 d :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
19 3c b7 :2 19 3c b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d b7 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a a0 7e
b4 2e :2 5a a 10 :2 a0 :2 51 a5
b 7e 6e b4 2e a0 7e 51
b4 2e d :2 a0 6b :b a0 a5 b
d b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :5 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 d
:8 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e :a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
:2 a0 51 a5 b 7e 51 b4 2e
:1e a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :22 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
:1a a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 19 :2 a0 51 a5 b
7e 51 b4 2e :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d :2 a0 51 a5 b
7e 51 b4 2e :16 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :1a a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 19 :c a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:5 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c a0 51 d
:3 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 a0 51
d a0 51 d :2 a0 6b a0 51
a5 b 7e 51 b4 2e a0 51
d b7 a0 51 d b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
a0 51 d b7 19 3c :6 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :3 a0 a5
b d :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b d b7 :3 a0 6b :2 a0 51
a5 b :2 a0 6b a5 b d b7
:2 19 3c a0 51 d :1e a0 :4 51 a5
b d :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 a0 51 d :7 a0
51 a5 b :2 a0 51 a5 b a5
b d b7 :2 19 3c b7 19 3c
b7 19 3c a0 b7 :2 a0 :2 51 a5
b 7e 6e b4 2e :1a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 7e b4 2e :2 5a a 10
a0 7e 51 b4 2e d :2 a0 6b
:b a0 a5 b d b7 19 3c b7
19 :c a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c a0
b7 :2 a0 :2 51 a5 b 7e 6e b4
2e :1a a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 7e b4
2e :2 5a a 10 a0 7e 51 b4
2e d :2 a0 6b :b a0 a5 b d
b7 19 3c b7 19 :c a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c a0 7e b4 2e :2 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 a0 6e
d :2 a0 b4 2e d :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b d b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d :34 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
:34 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 :3 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e d :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d :34 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:34 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c a0 51 d b7
19 3c :3 a0 7e 6e b4 2e :2 51
a5 b d a0 6e d :2 a0 d
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 51 d a0 51
d a0 51 d a0 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :35 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c :2 a0 d :2 a0 e9 dd
b3 :17 a0 e9 d3 5 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 2b b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e :3 a0 51 a5 b d :3 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d b7 19 3c :c a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :3 a0 51 a5 b :2 a0 6b
a5 b 5a a0 7e a0 6b b4
2e a0 51 d :8 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 b7 :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 51 :2 a0 51 a5 b :2 a0
6b a0 a5 b d :d a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
:10 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:3 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 :22 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 7e b4 2e :2 5a a 10
:2 a0 51 :2 a0 51 a5 b :2 a0 6b
a0 a5 b d :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :b a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :8 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 a0 51 :2 a0 51 a5 b :2 a0 6b
a0 a5 b d :8 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :b a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :2 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e 5a a0 7e b4
2e :2 5a a 10 :7 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :5 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 b7 :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 e9 c1 :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 19 3c
b7 19 3c a0 7e 51 b4 2e
d :2 a0 6b :b a0 a5 b d :5 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 6e d a0 7e 51 b4 2e
:2 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e 7e 51 b4 2e 5a
52 10 :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :3 a0 51 a5 b
:2 a0 6b a5 b 5a 7e 51 b4
2e 5a :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e 5a :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e 5a 52 10 5a a
10 5a :2 a0 51 a5 b 7e 51
b4 2e :25 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :27 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :21 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 a0 51 d a0 b7 :2 a0 51
a5 b 7e 51 b4 2e :3 a0 51
a5 b d b7 :2 19 3c :6 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :3 a0 a5
b d :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 e9 c1 :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :2 a0 e9 c1 :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 b7 :2 19 3c
b7 :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e 5a 52
10 :3 a0 51 a5 b d b7 :4 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e a5 b d b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e 51 b4 2e
d b7 :4 a0 51 a5 b 7e 51
b4 2e a5 b d b7 :2 19 3c
:1f a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c a0 51 d a0
51 d a0 51 d :2 a0 51 a5
b 7e 51 b4 2e :3 a0 6b d
a0 b7 :3 a0 51 a5 b a5 b
7e 51 b4 2e :3 a0 6b 51 :2 a0
6b a5 b d b7 19 :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
d b7 :2 19 3c a0 51 d a0
51 d :1e a0 :4 51 a5 b d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
e9 c1 :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 e9 c1 :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 19 3c :7 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :18 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :b a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 51
a5 b 7e 51 b4 2e d :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d a0 6e d :5 a0 a5
b d a0 6e d :5 a0 a5 b
d :7 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :11 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :d a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b d a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e :d a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 51 a5 b d
b7 19 :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 51 a5 b d
:3 a0 51 a5 b d b7 :2 19 3c
b7 19 3c b7 19 3c b7 :2 19
3c :2 a0 6b :4 a0 a5 b d b7
a0 47 :2 a0 e9 c1 :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 51
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 a0
7e b4 2e :2 5a a 10 :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 51
a5 b 7e 51 b4 2e a0 51
d b7 19 3c :6 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :3 a0 a5 b d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 51 a5 b
:2 a0 a5 57 b7 :2 19 3c :2 a0 6e
11e 11d :2 a0 6b 51 d :a a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
6e d a0 51 d a0 51 d
a0 51 d a0 51 d :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
d a0 51 d b7 a0 51 d
b7 :2 19 3c a0 51 d :1e a0 :4 51
a5 b d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 :1c a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 19 3c b7 19 3c :8 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c b7 19
3c a0 51 d a0 7e b4 2e
5a :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :7 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 3c b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
:5 a0 :2 51 a5 b d :19 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e :f a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :11 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
:2 51 a5 b 7e 6e b4 2e 5a
a0 51 d :2 a0 6b :b a0 a5 b
d b7 19 3c b7 19 3c a0
7e b4 2e :2 5a :2 a0 6b :2 a0 a5
b 7e 51 b4 2e 5a a 10
a0 51 d b7 19 3c b7 19
3c b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e 5a a0 7e b4
2e :2 5a a 10 :2 a0 51 a5 b
7e 51 b4 2e :a a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 19 3c a0
51 d :5 a0 :2 51 a5 b d :19 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e :f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :11 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 :2 51 a5 b 7e 6e b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 a0 51 d
:2 a0 6b :b a0 a5 b d b7 19
3c b7 19 3c b7 19 3c :3 a0
a5 b d :2 a0 6b 7e 51 b4
2e :2 a0 6b 51 d b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
4ae5
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 16a 155
159 15c 15d 165 154 187 175 151
179 17a 182 174 1a4 192 171 196
197 19f 191 1c1 1af 18e 1b3 1b4
1bc 1ae 1de 1cc 1ab 1d0 1d1 1d9
1cb 1fb 1e9 1c8 1ed 1ee 1f6 1e8
218 206 1e5 20a 20b 213 205 235
223 202 227 228 230 222 252 240
21f 244 245 24d 23f 26f 25d 23c
261 262 26a 25c 28c 27a 259 27e
27f 287 279 2a9 297 276 29b 29c
2a4 296 2c5 2b4 2b8 2c0 293 2dd
2cc 2d0 2d8 2b3 2f9 2e8 2ec 2f4
2b0 311 300 304 30c 2e7 32e 31c
2e4 320 321 329 31b 34a 339 33d
345 318 362 351 355 35d 338 37f
36d 335 371 372 37a 36c 39c 38a
369 38e 38f 397 389 3b8 3a7 3ab
3b3 386 3d0 3bf 3c3 3cb 3a6 3ec
3db 3df 3e7 3a3 404 3f3 3f7 3ff
3da 421 40f 3d7 413 414 41c 40e
43e 42c 40b 430 431 439 42b 45b
449 428 44d 44e 456 448 478 466
445 46a 46b 473 465 495 483 462
487 488 490 482 4b1 4a0 4a4 47f
4ac 49f 4cd 4bc 4c0 49c 4c8 4bb
4e9 4d8 4dc 4b8 4e4 4d7 505 4f4
4f8 4d4 500 4f3 521 510 514 4f0
51c 50f 53d 52c 530 50c 538 52b
559 548 54c 528 554 547 575 564
568 544 570 563 591 580 584 560
58c 57f 5ad 59c 5a0 57c 5a8 59b
5c9 5b8 5bc 598 5c4 5b7 5e5 5d4
5d8 5b4 5e0 5d3 601 5f0 5f4 5d0
5fc 5ef 61d 60c 610 5ec 618 60b
639 628 62c 608 634 627 655 644
648 624 650 643 671 660 664 640
66c 65f 68d 67c 680 65c 688 67b
6a9 698 69c 678 6a4 697 6c5 6b4
6b8 694 6c0 6b3 6e1 6d0 6d4 6b0
6dc 6cf 6fd 6ec 6f0 6cc 6f8 6eb
719 708 70c 6e8 714 707 735 724
728 704 730 723 751 740 744 720
74c 73f 76d 75c 760 73c 768 75b
789 778 77c 758 784 777 7a5 794
798 774 7a0 793 7c1 7b0 7b4 790
7bc 7af 7dd 7cc 7d0 7ac 7d8 7cb
7f9 7e8 7ec 7c8 7f4 7e7 815 804
808 7e4 810 803 831 820 824 800
82c 81f 84d 83c 840 81c 848 83b
869 858 85c 838 864 857 885 874
878 854 880 873 8a1 890 894 870
89c 88f 8bd 8ac 8b0 88c 8b8 8ab
8d9 8c8 8cc 8a8 8d4 8c7 8f5 8e4
8e8 8c4 8f0 8e3 912 900 8e0 904
905 90d 8ff 92f 91d 8fc 921 922
92a 91c 94b 93a 93e 919 946 939
967 956 95a 936 962 955 984 972
952 976 977 97f 971 9a0 98f 993
96e 99b 98e 9bd 9ab 98b 9af 9b0
9b8 9aa 9da 9c8 9a7 9cc 9cd 9d5
9c7 9f6 9e5 9e9 9c4 9f1 9e4 a12
a01 a05 9e1 a0d a00 a2e a1d a21
a29 9fd a46 a35 a39 a41 a1c a62
a51 a55 a19 a5d a50 a7e a6d a71
a4d a79 a6c a9a a89 a8d a69 a95
a88 ab6 aa5 aa9 a85 ab1 aa4 ad2
ac1 ac5 aa1 acd ac0 aee add ae1
abd ae9 adc b0a af9 afd ad9 b05
af8 b26 b15 b19 af5 b21 b14 b42
b31 b35 b11 b3d b30 b5e b4d b51
b2d b59 b4c b7a b69 b6d b49 b75
b68 b97 b85 b65 b89 b8a b92 b84
bb4 ba2 b81 ba6 ba7 baf ba1 bd1
bbf b9e bc3 bc4 bcc bbe c02 bdc
be0 be8 bec bf0 bbb bf4 bf5 bf7
bf8 bfa bfd bdb c1e c0d c11 bd8
c19 c0c c3a c29 c2d c09 c35 c28
c41 c45 c25 c56 c59 c5d c61 c65
c69 c6d c71 c7d c82 c84 c90 c94
c96 c9a cab cac caf cb3 cb7 cbb
cbf cc3 cc7 ccb ccf cd3 cd7 ce3
ce8 cea cf6 cfa cfc d00 d11 d12
d15 d19 d1d d21 d25 d29 d2d d31
d35 d39 d3d d41 d45 d49 d4d d51
d55 d59 d5d d61 d65 d69 d6d d71
d75 d79 d7d d81 d85 d89 d8d d91
d95 d99 d9d da1 da5 da9 dad db1
db5 db9 dbd dc1 dc5 dc9 dcd dd1
dd5 dd9 ddd de1 de5 de9 ded df1
df5 df9 dfd e01 e05 e09 e0d e11
e15 e19 e1d e21 e25 e29 e2d e31
e35 e39 e3d e41 e45 e49 e4d e51
e55 e59 e5d e61 e65 e69 e6d e71
e75 e79 e7d e81 e85 e89 e8d e91
e95 e99 e9d ea1 ea5 ea9 ead eb1
eb5 eb9 ebd ec1 ec5 ec9 ecd ed9
ede ee0 eec ef0 f0e ef6 efa efe
f01 f09 ef5 f15 f19 ef2 f1d f21
f25 f28 f2d f2e 1 f30 f35 f39
f3d f40 f45 f49 f4d f50 f55 f56
f58 f5d f60 f64 f65 f6a f6f f72
f77 f78 f7d f80 f84 f85 f8a f8d
f92 f93 f98 f9b fa0 fa1 fa6 fa9
fae faf fb4 fb7 fbb fbc fc1 fc4
fc9 fca fcf fd2 fd7 fd8 fdd fe0
fe5 fe6 feb fee ff2 ff3 ff8 ffb
1000 1001 1006 1009 100e 100f 1014 1017
101c 101d 1022 1025 1029 102a 102f 1032
1037 1038 103d 1040 1045 1046 104b 104e
1053 1054 1059 105c 1060 1061 1066 1069
106e 106f 1074 1077 107c 107d 1082 1085
1089 108d 1091 1092 1094 1099 109a 109c
109d 10a2 10a5 10aa 10ab 10b0 10b3 10b7
10bb 10bf 10c0 10c2 10c7 10c8 10ca 10cb
10d0 10d3 10d8 10d9 10de 10e1 10e5 10e9
10ed 10ee 10f0 10f5 10f6 10f8 10f9 10fe
1101 1106 1107 110c 110f 1113 1117 111b
111c 111e 1123 1124 1126 1127 112c 112f
1134 1135 113a 113d 1141 1145 1149 114a
114c 1151 1152 1154 1155 115a 115d 1162
1163 1168 116b 116f 1173 1177 1178 117a
117f 1180 1182 1183 1188 118b 1190 1191
1196 1199 119d 11a1 11a5 11a6 11a8 11ad
11ae 11b0 11b1 11b6 11b9 11be 11bf 11c4
11c7 11cb 11cf 11d3 11d4 11d6 11db 11dc
11de 11df 11e4 11e7 11ec 11ed 11f2 11f5
11f9 11fd 1201 1202 1204 1209 120a 120c
120d 1212 1215 121a 121b 1220 1223 1228
1229 122e 1231 1235 1236 123b 123e 1243
1244 1249 124c 1251 1252 1257 1258 125d
125f 1263 1266 126a 126e 1271 1275 1279
127c 127f 1284 1287 128a 128d 128e 1293
1294 1 1296 129b 129f 12a3 12a6 12ab
12b0 12b3 12b7 12b8 12bd 12be 12c3 12c5
12c9 12cc 12d0 12d4 12d8 12dc 12e0 12e4
12e8 12ec 12f0 12f4 12f8 12fc 1300 1304
1308 130c 1310 1314 1318 131c 1320 1324
1327 1328 132a 132e 1332 1335 1336 1338
133c 1340 1344 1347 1348 134a 134e 1351
1355 1358 1359 135e 1361 1365 1369 136c
136d 136f 1373 1376 137a 137d 137e 1383
1 1386 138b 138f 1392 1396 1398 139c
139f 13a3 13a7 13ab 13af 13b4 13b8 13bc
13c1 13c5 13c9 13cc 13d0 13d4 13d9 13dd
13e1 13e2 13e6 13ea 13eb 13ef 13f3 13f7
13fc 1400 1401 1405 1409 140e 1413 1417
141b 1420 1424 1428 142b 142e 1432 1434
1438 143c 143f 1442 1446 1448 144c 1450
1453 1457 145b 145f 1462 1466 146a 146e
1473 1475 1479 147d 1480 1484 1488 148a
1 148e 1492 1496 1499 149d 14a1 14a5
14a9 14ac 14b0 14b4 14b7 14ba 14bf 14c2
14c5 14c8 14c9 14ce 14cf 1 14d1 14d6
14da 14de 14e1 14e6 14eb 14ee 14f2 14f3
14f8 14fb 1500 1501 1506 1509 150e 150f
1514 1517 151b 151c 1521 1524 1529 152a
152f 1532 1536 153a 153d 1540 1541 1543
1544 1549 154a 154f 1551 1555 1558 155a
155e 1560 156c 156e 1570 1571 1576 157a
157c 1588 158a 158e 1592 1595 1596 1598
159b 159e 159f 15a4 15a8 15ac 15af 15b3
15b7 15ba 15bd 15c2 15c5 15c8 15cb 15cc
15d1 15d2 1 15d4 15d9 15dd 15e1 15e4
15e9 15ee 15f1 15f5 15f6 15fb 15fe 1603
1604 1609 160c 1611 1612 1617 161a 161e
1622 1626 162a 162d 162e 1630 1635 1636
1638 1639 163e 1641 1646 1647 164c 164f
1654 1655 165a 165d 1661 1662 1667 166a
166f 1670 1675 1676 167b 167d 1681 1684
1688 168c 168f 1693 1697 169a 169d 16a2
16a5 16a8 16ab 16ac 16b1 16b2 1 16b4
16b9 16bd 16c1 16c4 16c9 16ce 16d1 16d5
16d6 16db 16dc 16e1 16e3 16e7 16ea 16ee
16f2 16f5 16f9 16fd 1700 1704 1708 1709
170e 1710 1714 1717 171b 171f 1723 1727
172b 172f 1733 1737 173b 173f 1743 1747
174b 174f 1753 1757 175b 1767 176b 176f
1772 1776 177a 177c 1 1780 1784 1788
178b 178f 1793 1797 179b 179e 17a2 17a6
17a9 17ac 17b1 17b4 17b7 17ba 17bb 17c0
17c1 1 17c3 17c8 17cc 17d0 17d3 17d8
17dd 17e0 17e4 17e5 17ea 17ed 17f2 17f3
17f8 17fb 1800 1801 1806 1809 180d 180e
1813 1816 181b 181c 1821 1824 1828 182c
182f 1832 1833 1835 1836 183b 183c 1841
1843 1847 184a 184c 1850 1852 185e 1860
1862 1863 1868 186c 186e 187a 187c 1880
1884 1887 188b 188e 1892 1895 1896 189b
189e 18a2 18a6 18a9 18ad 18b1 18b4 18b7
18bc 18bf 18c2 18c5 18c6 18cb 18cc 1
18ce 18d3 18d7 18db 18de 18e3 18e8 18eb
18ef 18f0 18f5 18f8 18fd 18fe 1903 1906
190b 190c 1911 1914 1918 191c 1920 1924
1927 1928 192a 192f 1930 1932 1933 1938
193b 1940 1941 1946 1949 194e 194f 1954
1957 195b 195c 1961 1964 1969 196a 196f
1970 1975 1977 197b 197e 1982 1986 1989
198d 1991 1994 1997 199c 199f 19a2 19a5
19a6 19ab 19ac 1 19ae 19b3 19b7 19bb
19be 19c3 19c8 19cb 19cf 19d0 19d5 19d6
19db 19dd 19e1 19e4 19e8 19ec 19ef 19f3
19f7 19fa 19fe 1a02 1a03 1a08 1a0a 1a0e
1a11 1a15 1a18 1a1c 1a20 1a24 1a28 1a2c
1a30 1a3c 1a40 1a44 1a47 1a4b 1a4f 1a51
1 1a55 1a59 1a5d 1a60 1a64 1a68 1a6c
1a70 1a73 1a77 1a7b 1a7e 1a81 1a86 1a89
1a8c 1a8f 1a90 1a95 1a96 1 1a98 1a9d
1aa1 1aa5 1aa8 1aad 1ab2 1ab5 1ab9 1aba
1abf 1ac2 1ac7 1ac8 1acd 1ad0 1ad5 1ad6
1adb 1ade 1ae2 1ae3 1ae8 1aeb 1af0 1af1
1af6 1af9 1afd 1b01 1b04 1b07 1b08 1b0a
1b0b 1b10 1b11 1b16 1b18 1b1c 1b1f 1b21
1b25 1b27 1b33 1b35 1b37 1b38 1b3d 1b41
1b43 1b4f 1b51 1b55 1b59 1b5c 1b5d 1b5f
1b62 1b65 1b66 1b6b 1b6f 1b73 1b76 1b7a
1b7e 1b81 1b84 1b89 1b8c 1b8f 1b92 1b93
1b98 1b99 1 1b9b 1ba0 1ba4 1ba8 1bab
1bb0 1bb5 1bb8 1bbc 1bbd 1bc2 1bc5 1bca
1bcb 1bd0 1bd3 1bd8 1bd9 1bde 1be1 1be5
1be9 1bed 1bf1 1bf4 1bf5 1bf7 1bfc 1bfd
1bff 1c00 1c05 1c08 1c0d 1c0e 1c13 1c16
1c1b 1c1c 1c21 1c24 1c28 1c29 1c2e 1c31
1c36 1c37 1c3c 1c3d 1c42 1c44 1c48 1c4b
1c4f 1c53 1c56 1c5a 1c5e 1c61 1c64 1c69
1c6c 1c6f 1c72 1c73 1c78 1c79 1 1c7b
1c80 1c84 1c88 1c8b 1c90 1c95 1c98 1c9c
1c9d 1ca2 1ca3 1ca8 1caa 1cae 1cb1 1cb5
1cb9 1cbc 1cc0 1cc4 1cc7 1ccb 1ccf 1cd0
1cd5 1cd7 1cdb 1cde 1ce2 1ce6 1cea 1cee
1cf2 1cf6 1cfa 1cfe 1d02 1d06 1d0a 1d0e
1d12 1d16 1d1a 1d1e 1d22 1d26 1d2a 1d2e
1d32 1d36 1d3a 1d3e 1d42 1d46 1d4a 1d4e
1d52 1d56 1d5a 1d5e 1d62 1d66 1d6a 1d6e
1d72 1d7e 1d82 1d86 1d89 1d8d 1d91 1d93
1 1d97 1d9b 1d9f 1da2 1da6 1daa 1dae
1db2 1db5 1db9 1dbd 1dc0 1dc3 1dc8 1dcb
1dce 1dd1 1dd2 1dd7 1dd8 1 1dda 1ddf
1de3 1de7 1dea 1def 1df4 1df7 1dfb 1dfc
1e01 1e04 1e09 1e0a 1e0f 1e12 1e17 1e18
1e1d 1e20 1e24 1e25 1e2a 1e2d 1e32 1e33
1e38 1e3b 1e3f 1e43 1e46 1e49 1e4a 1e4c
1e4d 1e52 1e53 1e58 1e5a 1e5e 1e61 1e63
1e67 1e69 1e75 1e77 1e79 1e7a 1e7f 1e83
1e85 1e91 1e93 1e97 1e9b 1e9e 1ea2 1ea5
1ea9 1eac 1ead 1eb2 1eb5 1eb9 1ebd 1ec0
1ec4 1ec8 1ecb 1ece 1ed3 1ed6 1ed9 1edc
1edd 1ee2 1ee3 1 1ee5 1eea 1eee 1ef2
1ef5 1efa 1eff 1f02 1f06 1f07 1f0c 1f0f
1f14 1f15 1f1a 1f1d 1f22 1f23 1f28 1f2b
1f2f 1f33 1f37 1f3b 1f3e 1f3f 1f41 1f46
1f47 1f49 1f4a 1f4f 1f52 1f57 1f58 1f5d
1f60 1f65 1f66 1f6b 1f6e 1f72 1f73 1f78
1f7b 1f80 1f81 1f86 1f87 1f8c 1f8e 1f92
1f95 1f99 1f9d 1fa0 1fa4 1fa8 1fab 1fae
1fb3 1fb6 1fb9 1fbc 1fbd 1fc2 1fc3 1
1fc5 1fca 1fce 1fd2 1fd5 1fda 1fdf 1fe2
1fe6 1fe7 1fec 1fed 1ff2 1ff4 1ff8 1ffb
1fff 2003 2006 200a 200e 2011 2015 2019
201a 201f 2021 2025 2028 202c 2030 2034
2038 203c 2040 2044 2050 2054 2058 205b
205f 2063 2065 1 2069 206d 2071 2074
2078 207c 2080 2084 2087 208b 208f 2092
2095 209a 209d 20a0 20a3 20a4 20a9 20aa
1 20ac 20b1 20b5 20b9 20bc 20c1 20c6
20c9 20cd 20ce 20d3 20d6 20db 20dc 20e1
20e4 20e9 20ea 20ef 20f2 20f6 20f7 20fc
20ff 2104 2105 210a 210d 2111 2115 2118
211b 211c 211e 211f 2124 2125 212a 212c
2130 2133 2135 2139 213b 2147 2149 214b
214c 2151 2155 2157 2163 2165 2169 216d
2170 2174 2177 217b 217e 217f 2184 2187
218b 218f 2192 2196 219a 219d 21a0 21a5
21a8 21ab 21ae 21af 21b4 21b5 1 21b7
21bc 21c0 21c4 21c7 21cc 21d1 21d4 21d8
21d9 21de 21e1 21e6 21e7 21ec 21ef 21f4
21f5 21fa 21fd 2201 2205 2209 220d 2210
2211 2213 2218 2219 221b 221c 2221 2224
2229 222a 222f 2232 2237 2238 223d 2240
2244 2245 224a 224d 2252 2253 2258 2259
225e 2260 2264 2267 226b 226f 2272 2276
227a 227d 2280 2285 2288 228b 228e 228f
2294 2295 1 2297 229c 22a0 22a4 22a7
22ac 22b1 22b4 22b8 22b9 22be 22bf 22c4
22c6 22ca 22cd 22d1 22d5 22d8 22dc 22e0
22e3 22e7 22eb 22ec 22f1 22f3 22f7 22fa
22fe 2302 2306 230a 230e 231a 231e 2322
2325 2329 232d 232f 1 2333 2337 233b
233e 2342 2346 234a 234e 2351 2355 2359
235c 235f 2364 2367 236a 236d 236e 2373
2374 1 2376 237b 237f 2383 2386 238b
2390 2393 2397 2398 239d 23a0 23a5 23a6
23ab 23ae 23b3 23b4 23b9 23bc 23c0 23c1
23c6 23c9 23ce 23cf 23d4 23d7 23db 23df
23e2 23e5 23e6 23e8 23e9 23ee 23ef 23f4
23f6 23fa 23fd 23ff 2403 2405 2411 2413
2415 2416 241b 241f 2421 242d 242f 2433
2437 243a 243e 2443 2444 2446 2449 244c
244d 2452 2456 245b 245f 2461 2465 2468
246c 2470 2473 2477 247a 247e 2481 2482
2487 248a 248e 2492 2495 2499 249d 24a0
24a3 24a8 24ab 24ae 24b1 24b2 24b7 24b8
1 24ba 24bf 24c3 24c7 24ca 24cf 24d4
24d7 24db 24dc 24e1 24e4 24e9 24ea 24ef
24f2 24f7 24f8 24fd 2500 2504 2508 250c
2510 2513 2514 2516 251b 251c 251e 251f
2524 2527 252c 252d 2532 2535 253a 253b
2540 2543 2547 2548 254d 2550 2555 2556
255b 255c 2561 2563 2567 256a 256e 2572
2575 2579 257d 2580 2583 2588 258b 258e
2591 2592 2597 2598 1 259a 259f 25a3
25a7 25aa 25af 25b4 25b7 25bb 25bc 25c1
25c2 25c7 25c9 25cd 25d0 25d4 25d8 25db
25df 25e3 25e6 25ea 25ee 25ef 25f4 25f6
25fa 25fd 2601 2605 2609 260d 2611 2615
2619 261c 261d 261f 2622 2623 2625 2629
262d 2631 2635 2639 263c 263d 263f 2642
2643 2645 2649 264d 2651 2655 2659 265c
265d 265f 2662 2663 2665 2669 266d 2670
2673 2674 2679 267d 2681 2684 2685 2687
268a 268d 268e 2693 2697 269b 269f 26a3
26a7 26ab 26af 26b3 26b7 26bb 26bf 26cb
26cf 26d3 26d6 26da 26de 26e0 1 26e4
26e8 26ec 26ef 26f3 26f7 26fb 26ff 2702
2706 270a 270d 2710 2715 2718 271b 271e
271f 2724 2725 1 2727 272c 2730 2734
2737 273c 2741 2744 2748 2749 274e 2751
2756 2757 275c 275f 2764 2765 276a 276d
2771 2772 2777 277a 277f 2780 2785 2788
278c 2790 2793 2796 2797 2799 279a 279f
27a0 27a5 27a7 27ab 27ae 27b0 27b4 27b6
27c2 27c4 27c6 27c7 27cc 27d0 27d2 27de
27e0 27e4 27e6 27ea 27ee 27f1 27f2 27f4
27f7 27fa 27fb 2800 2804 2808 280c 2810
2814 2818 281c 2820 2824 2828 282c 2838
283c 2840 2843 2847 284b 284d 1 2851
2855 2859 285c 2860 2864 2868 286c 286f
2873 2877 287a 287d 2882 2885 2888 288b
288c 2891 2892 1 2894 2899 289d 28a1
28a4 28a9 28ae 28b1 28b5 28b6 28bb 28be
28c3 28c4 28c9 28cc 28d1 28d2 28d7 28da
28de 28df 28e4 28e7 28ec 28ed 28f2 28f5
28f9 28fd 2900 2903 2904 2906 2907 290c
290d 2912 2914 2918 291b 291d 2921 2923
292f 2931 2933 2934 2939 293d 293f 294b
294d 294f 2953 2957 295a 295e 2962 2965
2966 2968 296b 296e 296f 2974 2978 297c
297f 2983 2987 298a 298d 2992 2995 2998
299b 299c 29a1 29a2 1 29a4 29a9 29ad
29b1 29b4 29b9 29be 29c1 29c5 29c6 29cb
29ce 29d3 29d4 29d9 29dc 29e1 29e2 29e7
29ea 29ee 29f2 29f6 29fa 29fd 29fe 2a00
2a05 2a06 2a08 2a09 2a0e 2a11 2a16 2a17
2a1c 2a1f 2a24 2a25 2a2a 2a2d 2a31 2a32
2a37 2a3a 2a3f 2a40 2a45 2a46 2a4b 2a4d
2a51 2a54 2a58 2a5c 2a5f 2a63 2a67 2a6a
2a6d 2a72 2a75 2a78 2a7b 2a7c 2a81 2a82
1 2a84 2a89 2a8d 2a91 2a94 2a99 2a9e
2aa1 2aa5 2aa6 2aab 2aac 2ab1 2ab3 2ab7
2aba 2abe 2ac2 2ac5 2ac9 2acd 2ad0 2ad4
2ad8 2ad9 2ade 2ae0 2ae4 2ae7 2ae9 2aed
2af1 2af5 2af9 2afd 2b01 2b05 2b09 2b0d
2b11 2b15 2b21 2b25 2b29 2b2c 2b30 2b34
2b36 1 2b3a 2b3e 2b42 2b45 2b49 2b4d
2b51 2b55 2b58 2b5c 2b60 2b63 2b66 2b6b
2b6e 2b71 2b74 2b75 2b7a 2b7b 1 2b7d
2b82 2b86 2b8a 2b8d 2b92 2b97 2b9a 2b9e
2b9f 2ba4 2ba7 2bac 2bad 2bb2 2bb5 2bba
2bbb 2bc0 2bc3 2bc7 2bc8 2bcd 2bd0 2bd5
2bd6 2bdb 2bde 2be2 2be6 2be9 2bec 2bed
2bef 2bf0 2bf5 2bf6 2bfb 2bfd 2c01 2c04
2c06 2c0a 2c0c 2c18 2c1a 2c1c 2c1d 2c22
2c26 2c28 2c34 2c36 2c3a 2c3e 2c42 2c46
2c4a 2c4e 2c52 2c56 2c5a 2c5e 2c62 2c6e
2c72 2c76 2c79 2c7d 2c81 2c83 1 2c87
2c8b 2c8f 2c92 2c96 2c9a 2c9e 2ca2 2ca5
2ca9 2cad 2cb0 2cb3 2cb8 2cbb 2cbe 2cc1
2cc2 2cc7 2cc8 1 2cca 2ccf 2cd3 2cd7
2cda 2cdf 2ce4 2ce7 2ceb 2cec 2cf1 2cf4
2cf9 2cfa 2cff 2d02 2d07 2d08 2d0d 2d10
2d14 2d15 2d1a 2d1d 2d22 2d23 2d28 2d2b
2d2f 2d33 2d36 2d39 2d3a 2d3c 2d3d 2d42
2d43 2d48 2d4a 2d4e 2d51 2d53 2d57 2d59
2d65 2d67 2d69 2d6a 2d6f 2d73 2d75 2d81
2d83 2d87 2d8b 2d8f 2d92 2d93 2d95 2d96
2d98 2d9b 2d9e 2da1 2da2 2da7 2dab 2daf
2db2 2db3 2db5 2db8 2dbb 2dbc 2dc1 2dc4
2dc8 2dcc 2dcf 2dd0 2dd2 2dd5 2dd8 2dd9
2dde 1 2de1 2de6 1 2de9 2dee 2df2
2df6 2dfa 2dfe 2e02 2e06 2e0a 2e0e 2e12
2e16 2e22 2e26 2e2a 2e2d 2e31 2e35 2e37
1 2e3b 2e3f 2e43 2e46 2e4a 2e4e 2e52
2e56 2e59 2e5d 2e61 2e64 2e67 2e6c 2e6f
2e72 2e75 2e76 2e7b 2e7c 1 2e7e 2e83
2e87 2e8b 2e8e 2e93 2e98 2e9b 2e9f 2ea0
2ea5 2ea8 2ead 2eae 2eb3 2eb6 2ebb 2ebc
2ec1 2ec4 2ec8 2ec9 2ece 2ed1 2ed6 2ed7
2edc 2edf 2ee3 2ee7 2eea 2eed 2eee 2ef0
2ef1 2ef6 2ef7 2efc 2efe 2f02 2f05 2f07
2f0b 2f0d 2f19 2f1b 2f1d 2f1e 2f23 2f27
2f29 2f35 2f37 2f3b 2f3f 2f42 2f43 2f45
2f48 2f4b 2f4c 2f51 2f55 2f59 2f5c 2f60
2f64 2f67 2f6a 2f6f 2f72 2f75 2f78 2f79
2f7e 2f7f 1 2f81 2f86 2f8a 2f8e 2f91
2f96 2f9b 2f9e 2fa2 2fa3 2fa8 2fab 2fb0
2fb1 2fb6 2fb9 2fbe 2fbf 2fc4 2fc7 2fcb
2fcf 2fd3 2fd7 2fda 2fdb 2fdd 2fe2 2fe3
2fe5 2fe6 2feb 2fee 2ff3 2ff4 2ff9 2ffc
3001 3002 3007 300a 300e 300f 3014 3017
301c 301d 3022 3023 3028 302a 302e 3031
3035 3039 303c 3040 3044 3047 304a 304f
3052 3055 3058 3059 305e 305f 1 3061
3066 306a 306e 3071 3076 307b 307e 3082
3083 3088 3089 308e 3090 3094 3097 309b
309f 30a2 30a6 30aa 30ad 30b1 30b5 30b6
30bb 30bd 30c1 30c4 30c6 30ca 30cd 30cf
30d3 30d7 30da 30de 30e3 30e7 30eb 30f0
30f4 30f8 30fd 3101 3105 3106 310a 310e
310f 3113 3117 311b 3120 3124 3125 3129
312d 3132 3137 313b 313f 3144 3148 314c
314f 3152 3156 3158 315c 3160 3163 3166
316a 316c 3170 3174 3177 317b 317f 3182
3186 3189 318d 3190 3191 3196 3199 319d
31a0 31a4 31a6 31aa 31ad 31b1 31b3 31b7
31bb 31be 31c2 31c6 31cb 31cd 31d1 31d5
31d8 31dc 31e0 31e2 1 31e6 31ea 31ee
31f1 31f5 31f9 31fd 3201 3204 3208 320c
320f 3212 3217 321a 321d 3220 3221 3226
3227 1 3229 322e 3232 3236 3239 323e
3243 3246 324a 324b 3250 3253 3258 3259
325e 3261 3266 3267 326c 326f 3273 3274
3279 327c 3281 3282 3287 328a 328e 3292
3295 3298 3299 329b 329c 32a1 32a2 32a7
32a9 32ad 32b0 32b2 32b6 32b8 32c4 32c6
32c8 32c9 32ce 32d2 32d4 32e0 32e2 32e6
32ea 32ed 32ee 32f0 32f3 32f6 32f7 32fc
3300 3304 3308 330c 3310 3314 3318 331c
3320 3324 3328 3334 3338 333c 333f 3343
3347 3349 1 334d 3351 3355 3358 335c
3360 3364 3368 336b 336f 3373 3376 3379
337e 3381 3384 3387 3388 338d 338e 1
3390 3395 3399 339d 33a0 33a5 33aa 33ad
33b1 33b2 33b7 33ba 33bf 33c0 33c5 33c8
33cd 33ce 33d3 33d6 33da 33db 33e0 33e3
33e8 33e9 33ee 33f1 33f5 33f9 33fc 33ff
3400 3402 3403 3408 3409 340e 3410 3414
3417 3419 341d 341f 342b 342d 342f 3430
3435 3439 343b 3447 3449 344d 3451 3454
3455 3457 345a 345d 345e 3463 3467 346a
346e 3472 3476 347a 347e 3482 3486 348a
348e 3492 3496 349a 349e 34a2 34ae 34b2
34b6 34b9 34bd 34c1 34c3 1 34c7 34cb
34cf 34d2 34d6 34da 34de 34e2 34e5 34e9
34ed 34f0 34f3 34f8 34fb 34fe 3501 3502
3507 3508 1 350a 350f 3513 3517 351a
351f 3524 3527 352b 352c 3531 3534 3539
353a 353f 3542 3547 3548 354d 3550 3554
3555 355a 355d 3562 3563 3568 356b 356f
3573 3576 3579 357a 357c 357d 3582 3583
3588 358a 358e 3591 3593 3597 3599 35a5
35a7 35a9 35aa 35af 35b3 35b5 35c1 35c3
35c7 35cb 35ce 35d2 35d5 35d9 35dc 35dd
35e2 35e5 35e9 35ed 35f0 35f4 35f8 35fb
35fe 3603 3606 3609 360c 360d 3612 3613
1 3615 361a 361e 3622 3625 362a 362f
3632 3636 3637 363c 363f 3644 3645 364a
364d 3652 3653 3658 365b 365f 3663 3667
366b 366e 366f 3671 3676 3677 3679 367a
367f 3682 3687 3688 368d 3690 3695 3696
369b 369e 36a2 36a3 36a8 36ab 36b0 36b1
36b6 36b7 36bc 36be 36c2 36c5 36c9 36cd
36d0 36d4 36d8 36db 36de 36e3 36e6 36e9
36ec 36ed 36f2 36f3 1 36f5 36fa 36fe
3702 3705 370a 370f 3712 3716 3717 371c
371d 3722 3724 3728 372b 372f 3733 3736
373a 373e 3741 3745 3749 374a 374f 3753
3755 3759 375c 375d 3762 3765 3768 376c
376f 3770 3775 3778 1 377b 3780 3784
3788 378b 378f 3793 3796 3797 3799 379c
379f 37a0 37a5 37a8 37ac 37b0 37b3 37b7
37bb 37be 37bf 37c1 37c4 37c7 37c8 37cd
1 37d0 37d5 37d9 37dd 37e0 37e4 37e8
37eb 37ee 37f3 37f6 37f9 37fc 37fd 3802
3803 1 3805 380a 380e 3812 3815 381a
381f 3822 3826 3827 382c 382f 3834 3835
383a 383d 3842 3843 3848 384b 384f 3853
3857 385b 385e 385f 3861 3866 3867 3869
386a 386f 3872 3877 3878 387d 3880 3885
3886 388b 388e 3892 3893 3898 389b 38a0
38a1 38a6 38a7 38ac 38ae 38b2 38b5 38b9
38bd 38c0 38c4 38c8 38cb 38ce 38d3 38d6
38d9 38dc 38dd 38e2 38e3 1 38e5 38ea
38ee 38f2 38f5 38fa 38ff 3902 3906 3907
390c 390d 3912 3914 3918 391b 391f 3923
3926 392a 392e 3931 3935 3939 393a 393f
3941 3945 3948 394a 394e 3952 3955 3957
395b 395e 3962 3966 3969 396a 396c 396f
3972 3973 3978 397c 397f 3983 3987 398b
398f 3991 3995 3999 399d 39a1 39a5 39a9
39ad 39b1 39b5 39b9 39bd 39c9 39cd 39d1
39d4 39d8 39dc 39de 1 39e2 39e6 39ea
39ed 39f1 39f5 39f9 39fd 3a00 3a04 3a08
3a0b 3a0e 3a13 3a16 3a19 3a1c 3a1d 3a22
3a23 1 3a25 3a2a 3a2e 3a32 3a35 3a3a
3a3f 3a42 3a46 3a47 3a4c 3a4f 3a54 3a55
3a5a 3a5d 3a62 3a63 3a68 3a6b 3a6f 3a70
3a75 3a78 3a7d 3a7e 3a83 3a86 3a8a 3a8e
3a91 3a94 3a95 3a97 3a98 3a9d 3a9e 3aa3
3aa5 3aa9 3aac 3aae 3ab2 3ab4 3ac0 3ac2
3ac4 3ac5 3aca 3ace 3ad0 3adc 3ade 3ae2
3ae6 3ae9 3aed 3af0 3af4 3af7 3af8 3afd
3b00 3b04 3b09 3b0d 3b11 3b15 3b16 3b1b
3b1f 3b23 3b27 3b2a 3b2e 3b32 3b35 3b36
3b38 3b3c 3b40 3b43 3b47 3b48 3b4a 3b4e
3b52 3b56 3b5a 3b5d 3b61 3b65 3b6a 3b6e
3b72 3b75 3b79 3b7d 3b81 3b85 3b89 3b8d
3b91 3b95 3b99 3b9d 3b9e 3ba0 3ba4 3ba8
3bac 3bb0 3bb4 3bb7 3bb8 3bba 3bbb 3bbd
3bc1 3bc5 3bc9 3bcd 3bd1 3bd5 3bd9 3bdd
3be1 3be5 3be9 3bed 3bf1 3bf5 3bf9 3bfd
3c01 3c05 3c09 3c0d 3c11 3c15 3c19 3c1d
3c21 3c25 3c29 3c35 3c39 3c3e 3c42 3c45
3c46 3c4b 3c4f 3c53 3c56 3c59 3c5d 3c5f
3c63 3c67 3c6a 3c6d 3c71 3c73 3c77 3c7b
3c7e 3c80 1 3c84 3c88 3c8c 3c8f 3c93
3c97 3c9b 3c9f 3ca2 3ca6 3caa 3cad 3cb0
3cb5 3cb8 3cbb 3cbe 3cbf 3cc4 3cc5 1
3cc7 3ccc 3cd0 3cd4 3cd7 3cdc 3ce1 3ce4
3ce8 3ce9 3cee 3cf1 3cf6 3cf7 3cfc 3cff
3d04 3d05 3d0a 3d0d 3d11 3d12 3d17 3d1a
3d1f 3d20 3d25 3d28 3d2c 3d30 3d33 3d36
3d37 3d39 3d3a 3d3f 3d40 3d45 3d47 3d4b
3d4e 3d50 3d54 3d56 3d62 3d64 3d66 3d67
3d6c 3d70 3d72 3d7e 3d80 3d84 3d88 3d8c
3d90 3d94 3da0 3da4 3da8 3dab 3daf 3db3
3db5 1 3db9 3dbd 3dc1 3dc4 3dc8 3dcc
3dd0 3dd4 3dd7 3ddb 3ddf 3de2 3de5 3dea
3ded 3df0 3df3 3df4 3df9 3dfa 1 3dfc
3e01 3e05 3e09 3e0c 3e11 3e16 3e19 3e1d
3e1e 3e23 3e26 3e2b 3e2c 3e31 3e34 3e39
3e3a 3e3f 3e42 3e46 3e47 3e4c 3e4f 3e54
3e55 3e5a 3e5d 3e61 3e65 3e68 3e6b 3e6c
3e6e 3e6f 3e74 3e75 3e7a 3e7c 3e80 3e83
3e85 3e89 3e8b 3e97 3e99 3e9b 3e9c 3ea1
3ea5 3ea7 3eb3 3eb5 3eb9 3ebd 3ec0 3ec4
3ec8 3ec9 3ecb 3ece 3ed1 3ed2 3ed7 3edb
3ede 3ee2 3ee4 3ee8 3eec 3ef0 3ef4 3ef8
3efc 3f00 3f04 3f08 3f0c 3f10 3f14 3f20
3f24 3f28 3f2b 3f2f 3f33 3f35 1 3f39
3f3d 3f41 3f44 3f48 3f4c 3f50 3f54 3f57
3f5b 3f5f 3f62 3f65 3f6a 3f6d 3f70 3f73
3f74 3f79 3f7a 1 3f7c 3f81 3f85 3f89
3f8c 3f91 3f96 3f99 3f9d 3f9e 3fa3 3fa6
3fab 3fac 3fb1 3fb4 3fb9 3fba 3fbf 3fc2
3fc6 3fc7 3fcc 3fcf 3fd4 3fd5 3fda 3fdd
3fe1 3fe5 3fe8 3feb 3fec 3fee 3fef 3ff4
3ff5 3ffa 3ffc 4000 4003 4005 4009 400b
4017 4019 401b 401c 4021 4025 4027 4033
4035 4037 403b 403f 4042 4046 404a 404d
404e 4050 4053 4056 4057 405c 4060 4064
4068 406c 4070 4074 4078 407c 4080 4084
4090 4094 4099 409d 40a0 40a1 40a6 40aa
40ae 40b1 40b4 40b8 40ba 40be 40c2 40c5
40c8 40cc 40ce 40d2 40d6 40d9 40db 1
40df 40e3 40e7 40ea 40ee 40f2 40f6 40fa
40fd 4101 4105 4108 410b 4110 4113 4116
4119 411a 411f 4120 1 4122 4127 412b
412f 4132 4137 413c 413f 4143 4144 4149
414c 4151 4152 4157 415a 415f 4160 4165
4168 416c 416d 4172 4175 417a 417b 4180
4183 4187 418b 418e 4191 4192 4194 4195
419a 419b 41a0 41a2 41a6 41a9 41ab 41af
41b1 41bd 41bf 41c1 41c2 41c7 41cb 41cd
41d9 41db 41df 41e3 41e7 41eb 41ef 41f3
41f7 41fb 41ff 4203 4207 420b 420f 4213
4217 421b 421f 422b 422f 4234 4238 423b
423c 4241 4245 4249 424c 424f 4253 4255
4259 425d 4260 4263 4267 4269 426d 4271
4274 4276 1 427a 427e 4282 4285 4289
428d 4291 4295 4298 429c 42a0 42a3 42a6
42ab 42ae 42b1 42b4 42b5 42ba 42bb 1
42bd 42c2 42c6 42ca 42cd 42d2 42d7 42da
42de 42df 42e4 42e7 42ec 42ed 42f2 42f5
42fa 42fb 4300 4303 4307 4308 430d 4310
4315 4316 431b 431e 4322 4326 4329 432c
432d 432f 4330 4335 4336 433b 433d 4341
4344 4346 434a 434c 4358 435a 435c 435d
4362 4366 4368 4374 4376 4378 437c 4380
4384 4388 438c 4390 4394 4398 439c 43a0
43a4 43a8 43ac 43b0 43b4 43b8 43bc 43c8
43cc 43d1 43d5 43d8 43d9 43de 43e2 43e6
43e9 43ec 43f0 43f2 43f6 43fa 43fd 4400
4404 4406 440a 440e 4411 4413 1 4417
441b 441f 4422 4426 442a 442e 4432 4435
4439 443d 4440 4443 4448 444b 444e 4451
4452 4457 4458 1 445a 445f 4463 4467
446a 446f 4474 4477 447b 447c 4481 4484
4489 448a 448f 4492 4497 4498 449d 44a0
44a4 44a5 44aa 44ad 44b2 44b3 44b8 44bb
44bf 44c3 44c6 44c9 44ca 44cc 44cd 44d2
44d3 44d8 44da 44de 44e1 44e3 44e7 44e9
44f5 44f7 44f9 44fa 44ff 4503 4505 4511
4513 4515 4519 451d 4520 4524 4526 452a
452e 4531 4535 4538 453c 453f 4540 4545
4548 454c 4550 4554 4558 455c 4560 456c
4570 4574 4577 457b 457f 4581 1 4585
4589 458d 4590 4594 4598 459c 45a0 45a3
45a7 45ab 45ae 45b1 45b6 45b9 45bc 45bf
45c0 45c5 45c6 1 45c8 45cd 45d1 45d5
45d8 45dd 45e2 45e5 45e9 45ea 45ef 45f2
45f7 45f8 45fd 4600 4605 4606 460b 460e
4612 4613 4618 461b 4620 4621 4626 4629
462d 4631 4634 4637 4638 463a 463b 4640
4641 4646 4648 464c 464f 4651 4655 4657
4663 4665 4667 4668 466d 4671 4673 467f
4681 4685 4689 468c 468d 468f 4693 4696
469a 469d 469e 46a3 46a7 46ab 46ae 46b2
46b6 46b9 46ba 46bc 46c0 46c4 46c7 46cb
46cc 46ce 46d2 46d6 46da 46de 46e2 46e6
46ea 46ee 46f2 46f6 46fa 4706 470a 470f
4713 4716 4717 471c 4720 4724 4727 472a
472e 4730 4734 4738 473b 473e 4742 4744
4748 474c 474f 4751 1 4755 4759 475d
4760 4764 4768 476c 4770 4773 4777 477b
477e 4781 4786 4789 478c 478f 4790 4795
4796 1 4798 479d 47a1 47a5 47a8 47ad
47b2 47b5 47b9 47ba 47bf 47c2 47c7 47c8
47cd 47d0 47d5 47d6 47db 47de 47e2 47e3
47e8 47eb 47f0 47f1 47f6 47f9 47fd 4801
4804 4807 4808 480a 480b 4810 4811 4816
4818 481c 481f 4821 4825 4827 4833 4835
4837 4838 483d 4841 4843 484f 4851 4855
4859 485d 485e 4860 4864 4868 486a 486e
4872 4876 4879 487a 487c 4880 4884 4887
4888 488a 488d 4891 4894 4898 489b 489c
48a1 48a5 48a9 48ad 48b1 48b5 48b9 48bd
48c1 48c5 48c9 48cd 48d9 48dd 48e2 48e6
48e9 48ea 48ef 48f3 48f7 48fa 48fd 4901
4903 4907 490b 490e 4911 4915 4917 491b
491f 4922 4924 1 4928 492c 4930 4933
4937 493b 493f 4943 4946 494a 494e 4951
4954 4959 495c 495f 4962 4963 4968 4969
1 496b 4970 4974 4978 497b 4980 4985
4988 498c 498d 4992 4995 499a 499b 49a0
49a3 49a8 49a9 49ae 49b1 49b5 49b6 49bb
49be 49c3 49c4 49c9 49cc 49d0 49d4 49d7
49da 49db 49dd 49de 49e3 49e4 49e9 49eb
49ef 49f2 49f4 49f8 49fa 4a06 4a08 4a0a
4a0b 4a10 4a14 4a16 4a22 4a24 4a28 4a2c
4a30 4a31 4a33 4a37 4a39 4a3d 4a41 4a45
4a49 4a4d 4a51 4a55 4a59 4a5d 4a61 4a65
4a69 4a75 4a79 4a7e 4a82 4a85 4a86 4a8b
4a8f 4a93 4a96 4a99 4a9d 4a9f 4aa3 4aa7
4aaa 4aad 4ab1 4ab3 4ab7 4abb 4abe 4ac0
1 4ac4 4ac8 4acc 4acf 4ad3 4ad7 4adb
4adf 4ae2 4ae6 4aea 4aed 4af0 4af5 4af8
4afb 4afe 4aff 4b04 4b05 1 4b07 4b0c
4b10 4b14 4b17 4b1c 4b21 4b24 4b28 4b29
4b2e 4b31 4b36 4b37 4b3c 4b3f 4b44 4b45
4b4a 4b4d 4b51 4b52 4b57 4b5a 4b5f 4b60
4b65 4b68 4b6c 4b70 4b73 4b76 4b77 4b79
4b7a 4b7f 4b80 4b85 4b87 4b8b 4b8e 4b90
4b94 4b96 4ba2 4ba4 4ba6 4ba7 4bac 4bb0
4bb2 4bbe 4bc0 4bc4 4bc8 4bcc 4bcd 4bcf
4bd3 4bd5 4bd9 4bdd 4be0 4be2 4be6 4bea
4bed 4bef 4bf3 4bf7 4bfa 4bfc 4c00 4c04
4c08 4c0a 4c0e 4c12 4c15 4c19 4c1e 4c22
4c26 4c2b 4c2f 4c33 4c38 4c3c 4c40 4c44
4c45 4c4a 4c4e 4c52 4c56 4c59 4c5a 4c5c
4c5f 4c62 4c63 4c68 4c6b 4c6f 4c73 4c76
4c77 4c79 4c7c 4c7f 4c80 4c85 1 4c88
4c8d 4c91 4c95 4c99 4c9d 4ca1 4ca5 4ca9
4cad 4cb1 4cb5 4cb9 4cbd 4cbe 4cc0 4cc4
4cc6 4cca 4ccd 4cd1 4cd5 4cd9 4cdd 4ce1
4ce5 4ce9 4ced 4cf1 4cf5 4cf9 4cfd 4d01
4d05 4d09 4d0d 4d11 4d15 4d19 4d1d 4d21
4d25 4d31 4d35 4d39 4d3c 4d40 4d44 4d46
1 4d4a 4d4e 4d52 4d55 4d59 4d5d 4d61
4d65 4d68 4d6c 4d70 4d73 4d76 4d7b 4d7e
4d81 4d84 4d85 4d8a 4d8b 1 4d8d 4d92
4d96 4d9a 4d9d 4da2 4da7 4daa 4dae 4daf
4db4 4db7 4dbc 4dbd 4dc2 4dc5 4dca 4dcb
4dd0 4dd3 4dd7 4dd8 4ddd 4de0 4de5 4de6
4deb 4dee 4df2 4df6 4df9 4dfc 4dfd 4dff
4e00 4e05 4e06 4e0b 4e0d 4e11 4e14 4e16
4e1a 4e1c 4e28 4e2a 4e2c 4e2d 4e32 4e36
4e38 4e44 4e46 4e4a 4e4e 4e51 4e55 4e58
4e5c 4e5f 4e60 4e65 4e68 4e6c 4e6f 4e73
4e75 4e79 4e7c 4e80 4e83 4e87 4e8b 4e8e
4e92 4e96 4e97 4e9b 4e9f 4ea3 4ea7 4eab
4eaf 4eb3 4eb7 4ec3 4ec7 4ecb 4ece 4ed2
4ed6 4ed8 1 4edc 4ee0 4ee4 4ee7 4eeb
4eef 4ef3 4ef7 4efa 4efe 4f02 4f05 4f08
4f0d 4f10 4f13 4f16 4f17 4f1c 4f1d 1
4f1f 4f24 4f28 4f2c 4f2f 4f34 4f39 4f3c
4f40 4f41 4f46 4f49 4f4e 4f4f 4f54 4f57
4f5c 4f5d 4f62 4f65 4f69 4f6a 4f6f 4f72
4f77 4f78 4f7d 4f80 4f84 4f88 4f8b 4f8e
4f8f 4f91 4f92 4f97 4f98 4f9d 4f9f 4fa3
4fa6 4fa8 4fac 4fae 4fba 4fbc 4fbe 4fbf
4fc4 4fc8 4fca 4fd6 4fd8 4fdc 4fe0 4fe3
4fe7 4feb 4fec 4fee 4ff1 4ff4 4ff5 4ffa
4ffe 5002 5006 500a 500e 5012 5016 501a
501e 5022 502e 5032 5036 5039 503d 5041
5043 1 5047 504b 504f 5052 5056 505a
505e 5062 5065 5069 506d 5070 5073 5078
507b 507e 5081 5082 5087 5088 1 508a
508f 5093 5097 509a 509f 50a4 50a7 50ab
50ac 50b1 50b4 50b9 50ba 50bf 50c2 50c7
50c8 50cd 50d0 50d4 50d5 50da 50dd 50e2
50e3 50e8 50eb 50ef 50f3 50f6 50f9 50fa
50fc 50fd 5102 5103 5108 510a 510e 5111
5113 5117 5119 5125 5127 5129 512a 512f
5133 5135 5141 5143 5147 514b 514e 514f
5151 5154 5157 5158 515d 5161 5165 5169
516b 516f 5172 5176 5178 517c 5180 5183
5185 5189 518c 5190 5194 5197 5198 519a
519d 51a0 51a1 51a6 51aa 51ae 51b1 51b5
51b9 51ba 51bc 51bf 51c2 51c3 51c8 51cc
51d0 51d4 51d8 51dc 51e0 51e4 51e8 51ec
51f0 51f4 51f8 51fc 5200 5204 5208 520c
5210 5214 5218 521c 5220 5224 5228 522c
5230 5234 5238 523c 5240 5244 5248 524c
5250 5254 5258 525c 5260 5264 5268 5274
5278 527c 527f 5283 5287 5289 1 528d
5291 5295 5298 529c 52a0 52a4 52a8 52ab
52af 52b3 52b6 52b9 52be 52c1 52c4 52c7
52c8 52cd 52ce 1 52d0 52d5 52d9 52dd
52e0 52e5 52ea 52ed 52f1 52f2 52f7 52fa
52ff 5300 5305 5308 530d 530e 5313 5316
531a 531b 5320 5323 5328 5329 532e 5331
5335 5339 533c 533f 5340 5342 5343 5348
5349 534e 5350 5354 5357 5359 535d 535f
536b 536d 536f 5370 5375 5379 537b 5387
5389 538d 5391 5395 5399 539c 53a0 53a4
53a8 53ab 53ac 53ae 53b1 53b4 53b5 53ba
53be 53c2 53c5 53c6 53c8 53cc 53cf 53d3
53d6 53d7 53d9 53da 53df 53e2 53e6 53ea
53ed 53ee 53f0 53f4 53f7 53fb 53fe 53ff
5401 5402 5407 1 540a 540f 5413 5417
541a 541b 541d 5420 5423 5424 5429 542c
5430 5434 5438 543b 543c 543e 5442 5446
5449 544a 544c 544f 5452 5455 5456 545b
1 545e 5463 5467 546b 546e 5472 5476
5479 547c 5481 5484 5487 548a 548b 5490
5491 1 5493 5498 549c 54a0 54a3 54a8
54ad 54b0 54b4 54b5 54ba 54bd 54c2 54c3
54c8 54cb 54d0 54d1 54d6 54d9 54dd 54e1
54e5 54e9 54ec 54ed 54ef 54f4 54f5 54f7
54f8 54fd 5500 5505 5506 550b 550e 5513
5514 5519 551c 5520 5521 5526 5529 552e
552f 5534 5535 553a 553c 5540 5543 5547
554b 554e 5552 5556 5559 555c 5561 5564
5567 556a 556b 5570 5571 1 5573 5578
557c 5580 5583 5588 558d 5590 5594 5595
559a 559b 55a0 55a2 55a6 55a9 55ad 55b1
55b4 55b8 55bc 55bf 55c3 55c7 55c8 55cd
55cf 55d3 55d6 55da 55de 55e2 55e5 55e6
55e8 55eb 55ee 55ef 55f4 55f8 55fb 55ff
5601 5605 5608 560a 560e 5612 5615 5617
561b 561e 5622 5626 562a 562e 5632 5636
563a 563e 5642 5646 564a 564e 5652 5656
565a 565e 5662 5666 566a 566e 5672 5676
567a 567e 5682 5686 568a 568c 5690 5693
5697 569b 569e 56a2 56a5 56a9 56ac 56ad
56b2 56b5 56b9 56bc 56bd 56c2 56c5 1
56c8 56cd 56d1 56d5 56d8 56db 56dc 56de
56e1 56e6 56e7 56ec 56f0 56f3 56f6 56f7
56fc 5700 5704 5708 570b 570f 5713 5717
571b 571f 5723 5727 572b 572f 5733 5737
5738 573a 573e 5740 5744 5747 574b 574f
5752 5753 5755 5758 575b 575c 5761 5765
5769 576d 5779 577d 5782 5786 5789 578a
578f 5793 5797 579a 579d 57a1 57a3 57a7
57ab 57ae 57b1 57b5 57b7 57bb 57bf 57c2
57c4 1 57c8 57cc 57d0 57d3 57d7 57db
57df 57e3 57e6 57ea 57ee 57f1 57f4 57f9
57fc 57ff 5802 5803 5808 5809 1 580b
5810 5814 5818 581b 5820 5825 5828 582c
582d 5832 5835 583a 583b 5840 5843 5848
5849 584e 5851 5855 5856 585b 585e 5863
5864 5869 586c 5870 5874 5877 587a 587b
587d 587e 5883 5884 5889 588b 588f 5892
5894 5898 589a 58a6 58a8 58aa 58ab 58b0
58b4 58b6 58c2 58c4 58c8 58cc 58d0 58d4
58d8 58e4 58e8 58ed 58f1 58f4 58f5 58fa
58fe 5902 5905 5908 590c 590e 5912 5916
5919 591c 5920 5922 5926 592a 592d 592f
1 5933 5937 593b 593e 5942 5946 594a
594e 5951 5955 5959 595c 595f 5964 5967
596a 596d 596e 5973 5974 1 5976 597b
597f 5983 5986 598b 5990 5993 5997 5998
599d 59a0 59a5 59a6 59ab 59ae 59b3 59b4
59b9 59bc 59c0 59c1 59c6 59c9 59ce 59cf
59d4 59d7 59db 59df 59e2 59e5 59e6 59e8
59e9 59ee 59ef 59f4 59f6 59fa 59fd 59ff
5a03 5a05 5a11 5a13 5a15 5a16 5a1b 5a1f
5a21 5a2d 5a2f 5a33 5a37 5a3b 5a3f 5a43
5a47 5a4b 5a4f 5a53 5a57 5a5b 5a67 5a6b
5a6f 5a72 5a76 5a7a 5a7c 1 5a80 5a84
5a88 5a8b 5a8f 5a93 5a97 5a9b 5a9e 5aa2
5aa6 5aa9 5aac 5ab1 5ab4 5ab7 5aba 5abb
5ac0 5ac1 1 5ac3 5ac8 5acc 5ad0 5ad3
5ad8 5add 5ae0 5ae4 5ae5 5aea 5aed 5af2
5af3 5af8 5afb 5b00 5b01 5b06 5b09 5b0d
5b0e 5b13 5b16 5b1b 5b1c 5b21 5b24 5b28
5b2c 5b2f 5b32 5b33 5b35 5b36 5b3b 5b3c
5b41 5b43 5b47 5b4a 5b4c 5b50 5b52 5b5e
5b60 5b62 5b63 5b68 5b6c 5b6e 5b7a 5b7c
5b80 5b84 5b87 5b8b 5b8f 5b92 5b93 5b95
5b98 5b9b 5b9c 5ba1 5ba5 5ba9 5bad 5bb1
5bb5 5bb9 5bbd 5bc1 5bc5 5bc9 5bd5 5bd9
5bdd 5be0 5be4 5be8 5bea 1 5bee 5bf2
5bf6 5bf9 5bfd 5c01 5c05 5c09 5c0c 5c10
5c14 5c17 5c1a 5c1f 5c22 5c25 5c28 5c29
5c2e 5c2f 1 5c31 5c36 5c3a 5c3e 5c41
5c46 5c4b 5c4e 5c52 5c53 5c58 5c5b 5c60
5c61 5c66 5c69 5c6e 5c6f 5c74 5c77 5c7b
5c7c 5c81 5c84 5c89 5c8a 5c8f 5c92 5c96
5c9a 5c9d 5ca0 5ca1 5ca3 5ca4 5ca9 5caa
5caf 5cb1 5cb5 5cb8 5cba 5cbe 5cc0 5ccc
5cce 5cd0 5cd1 5cd6 5cda 5cdc 5ce8 5cea
5cec 5cf0 5cf3 5cf5 5cf9 5cfd 5d00 5d01
5d03 5d06 5d09 5d0a 5d0f 5d12 5d16 5d1a
5d1d 5d1e 5d20 5d23 5d26 5d27 5d2c 1
5d2f 5d34 5d38 5d3c 5d40 5d43 5d44 5d46
5d49 5d4d 5d51 5d54 5d55 5d57 5d58 5d5d
5d61 5d65 5d69 5d6d 5d70 5d71 5d73 5d76
5d7a 5d7e 5d81 5d82 5d84 5d85 5d8a 5d8e
5d92 5d96 5d9a 5d9d 5d9e 5da0 5da3 5da7
5dab 5dae 5daf 5db1 5db2 5db7 5dbb 5dbf
5dc3 5dc7 5dca 5dcb 5dcd 5dd0 5dd4 5dd8
5ddb 5ddc 5dde 5ddf 5de4 5de8 5dec 5df0
5df3 5df4 5df6 5df9 5dfc 5dfd 5e02 5e06
5e0a 5e0e 5e12 5e16 5e1a 5e1e 5e22 5e26
5e2a 5e2e 5e32 5e36 5e3a 5e3e 5e42 5e46
5e4a 5e4e 5e52 5e56 5e5a 5e5e 5e62 5e66
5e6a 5e6e 5e72 5e76 5e7a 5e86 5e8a 5e8f
5e93 5e96 5e97 5e9c 5ea0 5ea4 5ea7 5eaa
5eae 5eb0 5eb4 5eb8 5ebb 5ebe 5ec2 5ec4
5ec8 5ecc 5ecf 5ed1 1 5ed5 5ed9 5edd
5ee0 5ee4 5ee8 5eec 5ef0 5ef3 5ef7 5efb
5efe 5f01 5f06 5f09 5f0c 5f0f 5f10 5f15
5f16 1 5f18 5f1d 5f21 5f25 5f28 5f2d
5f32 5f35 5f39 5f3a 5f3f 5f42 5f47 5f48
5f4d 5f50 5f55 5f56 5f5b 5f5e 5f62 5f63
5f68 5f6b 5f70 5f71 5f76 5f79 5f7d 5f81
5f84 5f87 5f88 5f8a 5f8b 5f90 5f91 5f96
5f98 5f9c 5f9f 5fa1 5fa5 5fa7 5fb3 5fb5
5fb7 5fb8 5fbd 5fc1 5fc3 5fcf 5fd1 5fd3
5fd7 5fdb 5fdf 5fe3 5fe7 5feb 5fef 5ff3
5ff7 5ffb 5fff 6003 6007 600b 600f 6013
6017 601b 601f 6023 6027 602b 602f 6033
6037 603b 603f 6043 6047 604b 604f 6053
6057 605b 6067 606b 6070 6074 6077 6078
607d 6081 6085 6088 608b 608f 6091 6095
6099 609c 609f 60a3 60a5 60a9 60ad 60b0
60b2 1 60b6 60ba 60be 60c1 60c5 60c9
60cd 60d1 60d4 60d8 60dc 60df 60e2 60e7
60ea 60ed 60f0 60f1 60f6 60f7 1 60f9
60fe 6102 6106 6109 610e 6113 6116 611a
611b 6120 6123 6128 6129 612e 6131 6136
6137 613c 613f 6143 6144 6149 614c 6151
6152 6157 615a 615e 6162 6165 6168 6169
616b 616c 6171 6172 6177 6179 617d 6180
6182 6186 6188 6194 6196 6198 6199 619e
61a2 61a4 61b0 61b2 61b4 61b8 61bc 61bf
61c3 61c5 61c9 61cd 61d0 61d1 61d3 61d6
61d9 61da 61df 61e3 61e7 61eb 61ee 61ef
61f1 61f4 61f8 61fc 61ff 6200 6202 6203
6208 620c 6210 6214 6218 621b 621c 621e
6221 6225 6229 622c 622d 622f 6230 6235
6239 623d 6241 6245 6249 624d 6251 6255
6259 625d 6261 6265 6269 626d 6271 6275
6279 627d 6281 6285 6289 628d 6291 6295
6299 629d 62a1 62ad 62b1 62b6 62ba 62bd
62be 62c3 62c7 62cb 62ce 62d1 62d5 62d7
62db 62df 62e2 62e5 62e9 62eb 62ef 62f3
62f6 62f8 1 62fc 6300 6304 6307 630b
630f 6313 6317 631a 631e 6322 6325 6328
632d 6330 6333 6336 6337 633c 633d 1
633f 6344 6348 634c 634f 6354 6359 635c
6360 6361 6366 6369 636e 636f 6374 6377
637c 637d 6382 6385 6389 638a 638f 6392
6397 6398 639d 63a0 63a4 63a8 63ab 63ae
63af 63b1 63b2 63b7 63b8 63bd 63bf 63c3
63c6 63c8 63cc 63ce 63da 63dc 63de 63df
63e4 63e8 63ea 63f6 63f8 63fc 63fe 6402
6406 640a 640d 640e 6410 6413 6416 6417
641c 6420 6424 6428 642b 642c 642e 6431
6435 6439 643c 643d 643f 6440 6445 6449
644d 6451 6455 6458 6459 645b 645e 6462
6466 6469 646a 646c 646d 6472 6476 647a
647e 6481 6482 6484 6487 648a 648b 6490
6494 6498 649c 64a0 64a4 64a8 64ac 64b0
64b4 64b8 64bc 64c0 64c4 64c8 64cc 64d0
64d4 64d8 64dc 64e0 64e4 64e8 64f4 64f8
64fd 6501 6504 6505 650a 650e 6512 6515
6518 651c 651e 6522 6526 6529 652c 6530
6532 6536 653a 653d 653f 1 6543 6547
654b 654e 6552 6556 655a 655e 6561 6565
6569 656c 656f 6574 6577 657a 657d 657e
6583 6584 1 6586 658b 658f 6593 6596
659b 65a0 65a3 65a7 65a8 65ad 65b0 65b5
65b6 65bb 65be 65c3 65c4 65c9 65cc 65d0
65d1 65d6 65d9 65de 65df 65e4 65e7 65eb
65ef 65f2 65f5 65f6 65f8 65f9 65fe 65ff
6604 6606 660a 660d 660f 6613 6615 6621
6623 6625 6626 662b 662f 6631 663d 663f
6641 6645 6649 664d 6651 6655 6659 665d
6661 6665 6669 666d 6671 6675 6679 667d
6681 6685 6689 668d 6691 6695 6699 669d
66a1 66a5 66a9 66b5 66b9 66be 66c2 66c5
66c6 66cb 66cf 66d3 66d6 66d9 66dd 66df
66e3 66e7 66ea 66ed 66f1 66f3 66f7 66fb
66fe 6700 1 6704 6708 670c 670f 6713
6717 671b 671f 6722 6726 672a 672d 6730
6735 6738 673b 673e 673f 6744 6745 1
6747 674c 6750 6754 6757 675c 6761 6764
6768 6769 676e 6771 6776 6777 677c 677f
6784 6785 678a 678d 6791 6792 6797 679a
679f 67a0 67a5 67a8 67ac 67b0 67b3 67b6
67b7 67b9 67ba 67bf 67c0 67c5 67c7 67cb
67ce 67d0 67d4 67d6 67e2 67e4 67e6 67e7
67ec 67f0 67f2 67fe 6800 6802 6806 680a
680d 680f 6813 6817 681b 681f 6823 6827
682b 682f 6833 6837 683b 683f 6843 684f
6853 6858 685c 685f 6860 6865 6869 686d
6870 6873 6877 6879 687d 6881 6884 6887
688b 688d 6891 6895 6898 689a 1 689e
68a2 68a6 68a9 68ad 68b1 68b5 68b9 68bc
68c0 68c4 68c7 68ca 68cf 68d2 68d5 68d8
68d9 68de 68df 1 68e1 68e6 68ea 68ee
68f1 68f6 68fb 68fe 6902 6903 6908 690b
6910 6911 6916 6919 691e 691f 6924 6927
692b 692c 6931 6934 6939 693a 693f 6942
6946 694a 694d 6950 6951 6953 6954 6959
695a 695f 6961 6965 6968 696a 696e 6970
697c 697e 6980 6981 6986 698a 698c 6998
699a 699c 69a0 69a4 69a7 69ab 69af 69b3
69b7 69bb 69c7 69cb 69d0 69d4 69d7 69d8
69dd 69e1 69e5 69e8 69eb 69ef 69f1 69f5
69f9 69fc 69ff 6a03 6a05 6a09 6a0d 6a10
6a12 1 6a16 6a1a 6a1e 6a21 6a25 6a29
6a2d 6a31 6a34 6a38 6a3c 6a3f 6a42 6a47
6a4a 6a4d 6a50 6a51 6a56 6a57 1 6a59
6a5e 6a62 6a66 6a69 6a6e 6a73 6a76 6a7a
6a7b 6a80 6a83 6a88 6a89 6a8e 6a91 6a96
6a97 6a9c 6a9f 6aa3 6aa4 6aa9 6aac 6ab1
6ab2 6ab7 6aba 6abe 6ac2 6ac5 6ac8 6ac9
6acb 6acc 6ad1 6ad2 6ad7 6ad9 6add 6ae0
6ae2 6ae6 6ae8 6af4 6af6 6af8 6af9 6afe
6b02 6b04 6b10 6b12 6b16 6b1a 6b1e 6b22
6b26 6b2a 6b2e 6b32 6b36 6b3a 6b3e 6b4a
6b4e 6b53 6b57 6b5a 6b5b 6b60 6b64 6b68
6b6b 6b6e 6b72 6b74 6b78 6b7c 6b7f 6b82
6b86 6b88 6b8c 6b90 6b93 6b95 1 6b99
6b9d 6ba1 6ba4 6ba8 6bac 6bb0 6bb4 6bb7
6bbb 6bbf 6bc2 6bc5 6bca 6bcd 6bd0 6bd3
6bd4 6bd9 6bda 1 6bdc 6be1 6be5 6be9
6bec 6bf1 6bf6 6bf9 6bfd 6bfe 6c03 6c06
6c0b 6c0c 6c11 6c14 6c19 6c1a 6c1f 6c22
6c26 6c27 6c2c 6c2f 6c34 6c35 6c3a 6c3d
6c41 6c45 6c48 6c4b 6c4c 6c4e 6c4f 6c54
6c55 6c5a 6c5c 6c60 6c63 6c65 6c69 6c6b
6c77 6c79 6c7b 6c7c 6c81 6c85 6c87 6c93
6c95 6c97 6c9b 6c9f 6ca2 6ca6 6ca9 6cad
6cb1 6cb5 6cb9 6cc5 6cc9 6cce 6cd2 6cd5
6cd6 6cdb 6cdf 6ce3 6ce6 6ce9 6ced 6cef
6cf3 6cf7 6cfa 6cfd 6d01 6d03 6d07 6d0b
6d0e 6d10 1 6d14 6d18 6d1c 6d1f 6d23
6d27 6d2b 6d2f 6d32 6d36 6d3a 6d3d 6d40
6d45 6d48 6d4b 6d4e 6d4f 6d54 6d55 1
6d57 6d5c 6d60 6d64 6d67 6d6c 6d71 6d74
6d78 6d79 6d7e 6d81 6d86 6d87 6d8c 6d8f
6d94 6d95 6d9a 6d9d 6da1 6da2 6da7 6daa
6daf 6db0 6db5 6db8 6dbc 6dc0 6dc3 6dc6
6dc7 6dc9 6dca 6dcf 6dd0 6dd5 6dd7 6ddb
6dde 6de0 6de4 6de6 6df2 6df4 6df6 6df7
6dfc 6e00 6e02 6e0e 6e10 6e14 6e18 6e1c
6e20 6e24 6e30 6e34 6e39 6e3d 6e40 6e41
6e46 6e4a 6e4e 6e51 6e54 6e58 6e5a 6e5e
6e62 6e65 6e68 6e6c 6e6e 6e72 6e76 6e79
6e7b 1 6e7f 6e83 6e87 6e8a 6e8e 6e92
6e96 6e9a 6e9d 6ea1 6ea5 6ea8 6eab 6eb0
6eb3 6eb6 6eb9 6eba 6ebf 6ec0 1 6ec2
6ec7 6ecb 6ecf 6ed2 6ed7 6edc 6edf 6ee3
6ee4 6ee9 6eec 6ef1 6ef2 6ef7 6efa 6eff
6f00 6f05 6f08 6f0c 6f0d 6f12 6f15 6f1a
6f1b 6f20 6f23 6f27 6f2b 6f2e 6f31 6f32
6f34 6f35 6f3a 6f3b 6f40 6f42 6f46 6f49
6f4b 6f4f 6f51 6f5d 6f5f 6f61 6f62 6f67
6f6b 6f6d 6f79 6f7b 6f7f 6f83 6f86 6f87
6f89 6f8c 6f8f 6f90 6f95 6f98 6f9c 6fa0
6fa3 6fa4 6fa6 6fa9 6fac 6fad 6fb2 1
6fb5 6fba 6fbe 6fc1 6fc5 6fc9 6fcc 6fd0
6fd4 6fd8 6fdb 6fdf 6fe2 6fe3 6fe5 6fe8
6feb 6fec 6ff1 6ff5 6ff8 6ffc 6ffe 7002
7005 7009 700b 700f 7013 7016 701a 701e
7021 7022 7024 7027 702a 702b 7030 7034
7037 703b 703d 7041 7044 7048 704c 7050
7054 7058 705c 705f 7060 7062 7066 706a
706d 706e 7070 7074 7078 707b 707c 707e
7082 7086 7089 708a 708c 7090 7094 7097
7098 709a 709e 70a2 70a5 70a6 70a8 70ac
70b0 70b3 70b4 70b6 70ba 70be 70c1 70c2
70c4 70c8 70cc 70d0 70d1 70d3 70d7 70db
70df 70e2 70e3 70e5 70e9 70ec 70f0 70f3
70f4 70f9 70fd 7101 7104 7108 710c 710f
7112 7117 711a 711d 7120 7121 7126 7127
1 7129 712e 7132 7136 7139 713e 7143
7146 714a 714b 7150 7153 7158 7159 715e
7161 7166 7167 716c 716f 7173 7177 717b
717f 7182 7183 7185 718a 718b 718d 718e
7193 7194 7199 719b 719f 71a2 71a6 71aa
71ad 71b1 71b5 71b8 71bb 71c0 71c3 71c6
71c9 71ca 71cf 71d0 1 71d2 71d7 71db
71df 71e2 71e7 71ec 71ef 71f3 71f4 71f9
71fa 71ff 7201 7205 7208 720c 7210 7213
7217 721b 721e 7222 7223 7228 722c 722e
7232 7236 7239 723a 723c 723f 7242 7243
7248 724c 7250 7253 7257 725b 725e 7261
7266 7269 726c 726f 7270 7275 7276 1
7278 727d 7281 7285 7288 728d 7292 7295
7299 729a 729f 72a2 72a7 72a8 72ad 72b0
72b5 72b6 72bb 72be 72c2 72c6 72ca 72cb
72cd 72d2 72d3 72d5 72d6 72db 72de 72e3
72e4 72e9 72ec 72f1 72f2 72f7 72fa 72fe
72ff 7304 7307 730c 730d 7312 7313 7318
731a 731e 7321 7325 7329 732c 7330 7334
7337 733a 733f 7342 7345 7348 7349 734e
734f 1 7351 7356 735a 735e 7361 7366
736b 736e 7372 7373 7378 7379 737e 7380
7384 7387 738b 738f 7392 7396 739a 739d
739e 73a0 73a4 73a8 73a9 73ae 73b0 73b4
73b8 73bb 73bf 73c3 73c6 73c7 73c9 73cc
73cf 73d0 73d5 73d9 73dd 73e1 73e4 73e8
73ea 73ee 73f2 73f6 73f9 73fd 7401 7404
7405 7407 740b 740f 7412 7413 7415 7419
741b 741f 7423 7426 742a 742d 7431 7435
7439 743d 7441 7445 7449 744d 7451 7455
7459 745d 7461 7465 7469 746d 7471 7475
7479 747d 7481 7485 7489 748d 7491 7495
7499 749d 74a1 74a5 74a9 74ac 74af 74b2
74b5 74b6 74b8 74bc 74c0 74c4 74c7 74c8
74ca 74cd 74d0 74d1 74d6 74da 74de 74e1
74e5 74e9 74ec 74ef 74f4 74f7 74fa 74fd
74fe 7503 7504 1 7506 750b 750f 7513
7516 751b 7520 7523 7527 7528 752d 7530
7535 7536 753b 753e 7543 7544 7549 754c
7550 7554 7558 755c 755f 7560 7562 7567
7568 756a 756b 7570 7573 7578 7579 757e
7581 7586 7587 758c 758f 7593 7594 7599
759c 75a1 75a2 75a7 75a8 75ad 75af 75b3
75b6 75ba 75be 75c1 75c5 75c9 75cc 75cf
75d4 75d7 75da 75dd 75de 75e3 75e4 1
75e6 75eb 75ef 75f3 75f6 75fb 7600 7603
7607 7608 760d 760e 7613 7615 7619 761c
7620 7624 7627 762b 762f 7632 7636 763a
763b 7640 7644 7646 764a 764e 7651 7652
7654 7657 765a 765b 7660 7664 7668 766b
766f 7673 7676 7679 767e 7681 7684 7687
7688 768d 768e 1 7690 7695 7699 769d
76a0 76a5 76aa 76ad 76b1 76b2 76b7 76ba
76bf 76c0 76c5 76c8 76cd 76ce 76d3 76d6
76da 76de 76e2 76e6 76e9 76ea 76ec 76f1
76f2 76f4 76f5 76fa 76fd 7702 7703 7708
770b 7710 7711 7716 7719 771d 771e 7723
7726 772b 772c 7731 7732 7737 7739 773d
7740 7744 7748 774b 774f 7753 7756 7759
775e 7761 7764 7767 7768 776d 776e 1
7770 7775 7779 777d 7780 7785 778a 778d
7791 7792 7797 7798 779d 779f 77a3 77a6
77aa 77ae 77b1 77b5 77b9 77bc 77c0 77c4
77c5 77ca 77cc 77d0 77d4 77d7 77db 77df
77e3 77e7 77eb 77ef 77f3 77f7 77fa 77fb
77fd 7801 7805 7808 7809 780b 780c 780e
7812 7814 7818 781c 781f 7821 7825 7828
782a 782e 7831 7835 7837 783b 783f 7842
7845 7846 7848 784b 7850 7851 7856 785a
785e 7862 7866 786a 786e 7872 7876 787a
787e 7882 7886 788a 788e 7892 7896 789a
789e 78a2 78a6 78aa 78ae 78b2 78b6 78ba
78be 78ca 78ce 78d2 78d5 78d9 78dd 78df
1 78e3 78e7 78eb 78ee 78f2 78f6 78fa
78fe 7901 7905 7909 790c 790f 7914 7917
791a 791d 791e 7923 7924 1 7926 792b
792f 7933 7936 793b 7940 7943 7947 7948
794d 7950 7955 7956 795b 795e 7963 7964
7969 796c 7970 7971 7976 7979 797e 797f
7984 7987 798b 798f 7992 7995 7996 7998
7999 799e 799f 79a4 79a6 79aa 79ad 79af
79b3 79b5 79c1 79c3 79c5 79c6 79cb 79cf
79d1 79dd 79df 79e3 79e7 79ea 79ee 79f1
79f5 79f8 79f9 79fe 7a01 7a05 7a08 7a09
7a0e 7a11 1 7a14 7a19 7a1d 7a20 7a23
7a24 7a29 7a2d 7a31 7a35 7a38 7a3c 7a40
7a44 7a48 7a4c 7a50 7a54 7a58 7a5c 7a60
7a64 7a65 7a67 7a6b 7a6d 7a71 7a74 7a76
7a7a 7a7e 7a82 7a86 7a8a 7a8e 7a92 7a96
7a9a 7a9e 7aa2 7aa6 7aaa 7ab6 7aba 7abe
7ac1 7ac5 7ac9 7acb 1 7acf 7ad3 7ad7
7ada 7ade 7ae2 7ae6 7aea 7aed 7af1 7af5
7af8 7afb 7b00 7b03 7b06 7b09 7b0a 7b0f
7b10 1 7b12 7b17 7b1b 7b1f 7b22 7b27
7b2c 7b2f 7b33 7b34 7b39 7b3c 7b41 7b42
7b47 7b4a 7b4f 7b50 7b55 7b58 7b5c 7b5d
7b62 7b65 7b6a 7b6b 7b70 7b73 7b77 7b7b
7b7e 7b81 7b82 7b84 7b85 7b8a 7b8b 7b90
7b92 7b96 7b99 7b9b 7b9f 7ba1 7bad 7baf
7bb1 7bb2 7bb7 7bbb 7bbd 7bc9 7bcb 7bcd
7bd1 7bd5 7bd8 7bdc 7bde 7be2 7be6 7be9
7bec 7bed 7bef 7bf2 7bf7 7bf8 7bfd 7c01
7c05 7c09 7c0d 7c11 7c15 7c19 7c1d 7c21
7c25 7c29 7c2d 7c31 7c35 7c39 7c3d 7c41
7c45 7c49 7c4d 7c51 7c55 7c59 7c5d 7c61
7c65 7c71 7c75 7c79 7c7c 7c80 7c84 7c86
1 7c8a 7c8e 7c92 7c95 7c99 7c9d 7ca1
7ca5 7ca8 7cac 7cb0 7cb3 7cb6 7cbb 7cbe
7cc1 7cc4 7cc5 7cca 7ccb 1 7ccd 7cd2
7cd6 7cda 7cdd 7ce2 7ce7 7cea 7cee 7cef
7cf4 7cf7 7cfc 7cfd 7d02 7d05 7d0a 7d0b
7d10 7d13 7d17 7d18 7d1d 7d20 7d25 7d26
7d2b 7d2e 7d32 7d36 7d39 7d3c 7d3d 7d3f
7d40 7d45 7d46 7d4b 7d4d 7d51 7d54 7d56
7d5a 7d5c 7d68 7d6a 7d6c 7d6d 7d72 7d76
7d78 7d84 7d86 7d8a 7d8e 7d91 7d95 7d98
7d9c 7d9f 7da0 7da5 7da8 7dac 7daf 7db0
7db5 7db8 1 7dbb 7dc0 7dc4 7dc7 7dca
7dcb 7dd0 7dd4 7dd8 7ddc 7ddf 7de3 7de7
7deb 7def 7df3 7df7 7dfb 7dff 7e03 7e07
7e0b 7e0c 7e0e 7e12 7e14 7e18 7e1b 7e1d
7e21 7e25 7e29 7e2d 7e31 7e35 7e39 7e3d
7e41 7e45 7e49 7e4d 7e51 7e5d 7e61 7e65
7e68 7e6c 7e70 7e72 1 7e76 7e7a 7e7e
7e81 7e85 7e89 7e8d 7e91 7e94 7e98 7e9c
7e9f 7ea2 7ea7 7eaa 7ead 7eb0 7eb1 7eb6
7eb7 1 7eb9 7ebe 7ec2 7ec6 7ec9 7ece
7ed3 7ed6 7eda 7edb 7ee0 7ee3 7ee8 7ee9
7eee 7ef1 7ef6 7ef7 7efc 7eff 7f03 7f04
7f09 7f0c 7f11 7f12 7f17 7f1a 7f1e 7f22
7f25 7f28 7f29 7f2b 7f2c 7f31 7f32 7f37
7f39 7f3d 7f40 7f42 7f46 7f48 7f54 7f56
7f58 7f59 7f5e 7f62 7f64 7f70 7f72 7f74
7f78 7f7c 7f7f 7f83 7f86 7f87 7f8c 7f8f
7f92 7f96 7f9a 7f9d 7f9e 7fa0 7fa3 7fa6
7fa7 7fac 1 7faf 7fb4 7fb8 7fbc 7fbf
7fc0 7fc2 7fc5 7fc8 7fc9 7fce 1 7fd1
7fd6 7fda 7fdf 7fe3 7fe7 7feb 7fec 7ff1
7ff5 7ff9 7ffd 8000 8001 8003 8006 8009
800a 800f 8013 8017 801b 801e 801f 8021
8025 8027 802b 802e 8032 8036 8039 803a
803c 803f 8042 8043 8048 804b 804f 8053
8056 8057 8059 805c 805f 8060 8065 1
8068 806d 8071 8075 8078 8079 807b 807e
8081 8082 8087 808a 808e 8092 8095 8096
8098 809b 809e 809f 80a4 1 80a7 80ac
80b0 80b4 80b8 80bb 80bc 80be 80c1 80c5
80c9 80cc 80cd 80cf 80d0 80d5 80d9 80dd
80e1 80e5 80e8 80e9 80eb 80ee 80f2 80f6
80f9 80fa 80fc 80fd 8102 8106 810a 810e
8112 8115 8116 8118 811b 811f 8123 8126
8127 8129 812a 812f 8133 8137 813b 813f
8142 8143 8145 8148 814c 8150 8153 8154
8156 8157 815c 8160 8164 8168 816c 8170
8174 8178 817c 8180 8184 8188 818c 8190
8194 8198 819c 81a0 81a4 81a8 81ac 81b0
81b4 81b8 81bc 81c0 81c4 81c8 81cc 81d0
81d4 81d8 81dc 81e0 81e4 81e8 81ec 81f0
81f4 81f8 81fc 8200 8204 8208 820c 8210
8214 8218 821c 8220 8224 8228 822c 8230
823c 8240 8245 8249 824c 824d 8252 8256
825a 825d 8260 8264 8266 826a 826e 8271
8274 8278 827a 827e 8282 8285 8287 1
828b 828f 8293 8296 829a 829e 82a2 82a6
82a9 82ad 82b1 82b4 82b7 82bc 82bf 82c2
82c5 82c6 82cb 82cc 1 82ce 82d3 82d7
82db 82de 82e3 82e8 82eb 82ef 82f0 82f5
82f8 82fd 82fe 8303 8306 830b 830c 8311
8314 8318 8319 831e 8321 8326 8327 832c
832f 8333 8337 833a 833d 833e 8340 8341
8346 8347 834c 834e 8352 8355 8357 835b
835d 8369 836b 836d 836e 8373 8377 8379
8385 8387 838b 838d 8391 8395 8398 8399
839b 839e 83a1 83a2 83a7 83ab 83af 83b3
83b6 83b7 83b9 83bc 83c0 83c4 83c7 83c8
83ca 83cb 83d0 83d4 83d8 83dc 83e0 83e3
83e4 83e6 83e9 83ed 83f1 83f4 83f5 83f7
83f8 83fd 8401 8405 8409 840d 8411 8415
8419 841d 8421 8425 8429 842d 8431 8435
8439 843d 8441 8445 8449 844d 8451 8455
8459 845d 8461 8465 8469 846d 8471 8475
8479 847d 8481 8485 8489 848d 8491 8495
8499 849d 84a1 84a5 84a9 84ad 84b1 84b5
84b9 84bd 84c1 84c5 84c9 84cd 84d1 84dd
84e1 84e6 84ea 84ed 84ee 84f3 84f7 84fb
84fe 8501 8505 8507 850b 850f 8512 8515
8519 851b 851f 8523 8526 8528 1 852c
8530 8534 8537 853b 853f 8543 8547 854a
854e 8552 8555 8558 855d 8560 8563 8566
8567 856c 856d 1 856f 8574 8578 857c
857f 8584 8589 858c 8590 8591 8596 8599
859e 859f 85a4 85a7 85ac 85ad 85b2 85b5
85b9 85ba 85bf 85c2 85c7 85c8 85cd 85d0
85d4 85d8 85db 85de 85df 85e1 85e2 85e7
85e8 85ed 85ef 85f3 85f6 85f8 85fc 85fe
860a 860c 860e 860f 8614 8618 861a 8626
8628 862a 862e 8632 8636 863a 863d 863e
8640 8643 8647 864b 864e 864f 8651 8652
8657 865b 865f 8663 8667 866a 866b 866d
8670 8674 8678 867b 867c 867e 867f 8684
8688 868c 8690 8694 8698 869c 86a0 86a4
86a8 86ac 86b0 86b4 86b8 86bc 86c0 86c4
86c8 86cc 86d0 86d4 86d8 86dc 86e0 86e4
86e8 86ec 86f0 86f4 86f8 86fc 8700 8704
8708 870c 8710 8714 8718 871c 8720 8724
8728 872c 8730 8734 8738 873c 8740 8744
8748 874c 8750 8754 8758 8764 8768 876d
8771 8774 8775 877a 877e 8782 8785 8788
878c 878e 8792 8796 8799 879c 87a0 87a2
87a6 87aa 87ad 87af 1 87b3 87b7 87bb
87be 87c2 87c6 87ca 87ce 87d1 87d5 87d9
87dc 87df 87e4 87e7 87ea 87ed 87ee 87f3
87f4 1 87f6 87fb 87ff 8803 8806 880b
8810 8813 8817 8818 881d 8820 8825 8826
882b 882e 8833 8834 8839 883c 8840 8841
8846 8849 884e 884f 8854 8857 885b 885f
8862 8865 8866 8868 8869 886e 886f 8874
8876 887a 887d 887f 8883 8885 8891 8893
8895 8896 889b 889f 88a1 88ad 88af 88b1
88b5 88b9 88bc 88be 88c2 88c6 88ca 88ce
88d2 88d6 88da 88de 88e2 88e6 88ea 88ee
88f2 88f6 88fa 88fe 8902 8906 890a 890e
8912 8916 891a 891e 8922 8926 892a 892e
8932 8936 893a 893e 8942 8946 894a 894e
8952 8956 895a 895e 8962 8966 896a 896e
8972 8976 897a 897e 8982 8986 898a 898e
899a 899e 89a3 89a7 89aa 89ab 89b0 89b4
89b8 89bb 89be 89c2 89c4 89c8 89cc 89cf
89d2 89d6 89d8 89dc 89e0 89e3 89e5 1
89e9 89ed 89f1 89f4 89f8 89fc 8a00 8a04
8a07 8a0b 8a0f 8a12 8a15 8a1a 8a1d 8a20
8a23 8a24 8a29 8a2a 1 8a2c 8a31 8a35
8a39 8a3c 8a41 8a46 8a49 8a4d 8a4e 8a53
8a56 8a5b 8a5c 8a61 8a64 8a69 8a6a 8a6f
8a72 8a76 8a77 8a7c 8a7f 8a84 8a85 8a8a
8a8d 8a91 8a95 8a98 8a9b 8a9c 8a9e 8a9f
8aa4 8aa5 8aaa 8aac 8ab0 8ab3 8ab5 8ab9
8abb 8ac7 8ac9 8acb 8acc 8ad1 8ad5 8ad7
8ae3 8ae5 8ae7 8aeb 8aef 8af2 8af6 8af9
8afd 8aff 8b03 8b06 8b0a 8b0e 8b12 8b15
8b1a 8b1b 8b20 8b23 8b26 8b27 8b29 8b2d
8b31 8b36 8b3a 8b3e 8b42 8b46 8b4a 8b4e
8b52 8b56 8b5a 8b66 8b6a 8b6e 8b71 8b75
8b79 8b7b 1 8b7f 8b83 8b87 8b8a 8b8e
8b92 8b96 8b9a 8b9d 8ba1 8ba5 8ba8 8bab
8bb0 8bb3 8bb6 8bb9 8bba 8bbf 8bc0 1
8bc2 8bc7 8bcb 8bcf 8bd2 8bd7 8bdc 8bdf
8be3 8be4 8be9 8bec 8bf1 8bf2 8bf7 8bfa
8bff 8c00 8c05 8c08 8c0c 8c0d 8c12 8c15
8c1a 8c1b 8c20 8c23 8c27 8c2b 8c2e 8c31
8c32 8c34 8c35 8c3a 8c3b 8c40 8c42 8c46
8c49 8c4b 8c4f 8c51 8c5d 8c5f 8c61 8c62
8c67 8c6b 8c6d 8c79 8c7b 8c7f 8c82 8c86
8c8a 8c8d 8c91 8c95 8c98 8c9c 8ca0 8ca3
8ca6 8ca7 8cac 8caf 8cb3 8cb7 8cba 8cbb
8cbd 8cc0 8cc3 8cc4 8cc9 1 8ccc 8cd1
8cd5 8cd9 8cdd 8ce1 8ce5 8ce9 8ced 8cf1
8cf5 8cf9 8cfd 8d01 8d05 8d09 8d0d 8d11
8d15 8d19 8d1d 8d21 8d25 8d29 8d2d 8d31
8d35 8d39 8d3d 8d41 8d45 8d49 8d4d 8d51
8d55 8d59 8d5d 8d61 8d65 8d69 8d6d 8d71
8d75 8d79 8d7d 8d81 8d85 8d89 8d8d 8d91
8d95 8d99 8d9d 8da1 8da5 8db1 8db5 8db9
8dbc 8dc0 8dc4 8dc6 1 8dca 8dce 8dd2
8dd5 8dd9 8ddd 8de1 8de5 8de8 8dec 8df0
8df3 8df6 8dfb 8dfe 8e01 8e04 8e05 8e0a
8e0b 1 8e0d 8e12 8e16 8e1a 8e1d 8e22
8e27 8e2a 8e2e 8e2f 8e34 8e37 8e3c 8e3d
8e42 8e45 8e4a 8e4b 8e50 8e53 8e57 8e58
8e5d 8e60 8e65 8e66 8e6b 8e6e 8e72 8e76
8e79 8e7c 8e7d 8e7f 8e80 8e85 8e86 8e8b
8e8d 8e91 8e94 8e96 8e9a 8e9c 8ea8 8eaa
8eac 8ead 8eb2 8eb6 8eb8 8ec4 8ec6 8ec8
8ecc 8ecf 8ed3 8ed7 8edb 8edf 8ee3 8ee8
8eec 8eed 8ef1 8ef5 8ef9 8efd 8f01 8f05
8f09 8f0d 8f11 8f15 8f19 8f1d 8f21 8f25
8f29 8f2d 8f31 8f35 8f39 8f3d 8f41 8f45
8f49 8f4e 8f53 8f57 8f5b 8f5f 8f64 8f68
8f6c 8f6f 8f72 8f76 8f78 8f7c 8f80 8f83
8f86 8f8a 8f8c 8f90 8f94 8f97 8f9b 8f9f
8fa2 8fa6 8fa9 8fad 8fb0 8fb1 8fb6 8fb9
8fbd 8fc3 8fc5 8fc9 8fcc 8fd0 8fd4 8fd7
8fd8 8fda 8fdd 8fe0 8fe1 8fe6 8fea 8fee
8ff2 8ff5 8ff6 8ff8 8ffc 9000 9004 9008
9014 9018 901d 9021 9024 9025 902a 902e
9032 9035 9038 903c 903e 9042 9046 9049
904c 9050 9052 9056 905a 905d 905f 1
9063 9067 906b 906e 9072 9076 907a 907e
9081 9085 9089 908c 908f 9094 9097 909a
909d 909e 90a3 90a4 1 90a6 90ab 90af
90b3 90b6 90bb 90c0 90c3 90c7 90c8 90cd
90d0 90d5 90d6 90db 90de 90e3 90e4 90e9
90ec 90f0 90f1 90f6 90f9 90fe 90ff 9104
9107 910b 910f 9112 9115 9116 9118 9119
911e 911f 9124 9126 912a 912d 912f 9133
9135 9141 9143 9145 9146 914b 914f 9151
915d 915f 9163 9167 916b 9177 917b 9180
9184 9187 9188 918d 9191 9195 9198 919b
919f 91a1 91a5 91a9 91ac 91af 91b3 91b5
91b9 91bd 91c0 91c2 1 91c6 91ca 91ce
91d1 91d5 91d9 91dd 91e1 91e4 91e8 91ec
91ef 91f2 91f7 91fa 91fd 9200 9201 9206
9207 1 9209 920e 9212 9216 9219 921e
9223 9226 922a 922b 9230 9233 9238 9239
923e 9241 9246 9247 924c 924f 9253 9254
9259 925c 9261 9262 9267 926a 926e 9272
9275 9278 9279 927b 927c 9281 9282 9287
9289 928d 9290 9292 9296 9298 92a4 92a6
92a8 92a9 92ae 92b2 92b4 92c0 92c2 92c6
92ca 92ce 92da 92de 92e3 92e7 92ea 92eb
92f0 92f4 92f8 92fb 92fe 9302 9304 9308
930c 930f 9312 9316 9318 931c 9320 9323
9325 1 9329 932d 9331 9334 9338 933c
9340 9344 9347 934b 934f 9352 9355 935a
935d 9360 9363 9364 9369 936a 1 936c
9371 9375 9379 937c 9381 9386 9389 938d
938e 9393 9396 939b 939c 93a1 93a4 93a9
93aa 93af 93b2 93b6 93b7 93bc 93bf 93c4
93c5 93ca 93cd 93d1 93d5 93d8 93db 93dc
93de 93df 93e4 93e5 93ea 93ec 93f0 93f3
93f5 93f9 93fb 9407 9409 940b 940c 9411
9415 9417 9423 9425 9429 942d 9431 9435
9439 9445 9449 944e 9452 9455 9456 945b
945f 9463 9466 9469 946d 946f 9473 9477
947a 947d 9481 9483 9487 948b 948e 9490
1 9494 9498 949c 949f 94a3 94a7 94ab
94af 94b2 94b6 94ba 94bd 94c0 94c5 94c8
94cb 94ce 94cf 94d4 94d5 1 94d7 94dc
94e0 94e4 94e7 94ec 94f1 94f4 94f8 94f9
94fe 9501 9506 9507 950c 950f 9514 9515
951a 951d 9521 9522 9527 952a 952f 9530
9535 9538 953c 9540 9543 9546 9547 9549
954a 954f 9550 9555 9557 955b 955e 9560
9564 9566 9572 9574 9576 9577 957c 9580
9582 958e 9590 9594 9598 959c 95a8 95ac
95b1 95b5 95b8 95b9 95be 95c2 95c6 95c9
95cc 95d0 95d2 95d6 95da 95dd 95e0 95e4
95e6 95ea 95ee 95f1 95f3 1 95f7 95fb
95ff 9602 9606 960a 960e 9612 9615 9619
961d 9620 9623 9628 962b 962e 9631 9632
9637 9638 1 963a 963f 9643 9647 964a
964f 9654 9657 965b 965c 9661 9664 9669
966a 966f 9672 9677 9678 967d 9680 9684
9685 968a 968d 9692 9693 9698 969b 969f
96a3 96a6 96a9 96aa 96ac 96ad 96b2 96b3
96b8 96ba 96be 96c1 96c3 96c7 96c9 96d5
96d7 96d9 96da 96df 96e3 96e5 96f1 96f3
96f7 96fb 96ff 970b 970f 9714 9718 971b
971c 9721 9725 9729 972c 972f 9733 9735
9739 973d 9740 9743 9747 9749 974d 9751
9754 9756 1 975a 975e 9762 9765 9769
976d 9771 9775 9778 977c 9780 9783 9786
978b 978e 9791 9794 9795 979a 979b 1
979d 97a2 97a6 97aa 97ad 97b2 97b7 97ba
97be 97bf 97c4 97c7 97cc 97cd 97d2 97d5
97da 97db 97e0 97e3 97e7 97e8 97ed 97f0
97f5 97f6 97fb 97fe 9802 9806 9809 980c
980d 980f 9810 9815 9816 981b 981d 9821
9824 9826 982a 982c 9838 983a 983c 983d
9842 9846 9848 9854 9856 9858 985c 9860
9864 9868 986c 9870 9874 9878 987c 9880
988c 9890 9894 9897 989b 989f 98a1 1
98a5 98a9 98ad 98b0 98b4 98b8 98bc 98c0
98c3 98c7 98cb 98ce 98d1 98d6 98d9 98dc
98df 98e0 98e5 98e6 1 98e8 98ed 98f1
98f5 98f8 98fd 9902 9905 9909 990a 990f
9912 9917 9918 991d 9920 9925 9926 992b
992e 9932 9933 9938 993b 9940 9941 9946
9949 994d 9951 9954 9957 9958 995a 995b
9960 9961 9966 9968 996c 996f 9971 9975
9977 9983 9985 9987 9988 998d 9991 9993
999f 99a1 99a5 99a9 99ac 99b0 99b3 99b7
99ba 99bb 99c0 99c3 99c7 99cb 99ce 99cf
99d1 99d4 99d7 99d8 99dd 99e1 99e5 99e9
99eb 99ef 99f2 99f6 99fa 99fe 9a02 9a06
9a0a 9a0e 9a12 9a16 9a1a 9a1e 9a22 9a2e
9a32 9a36 9a39 9a3d 9a41 9a43 1 9a47
9a4b 9a4f 9a52 9a56 9a5a 9a5e 9a62 9a65
9a69 9a6d 9a70 9a73 9a78 9a7b 9a7e 9a81
9a82 9a87 9a88 1 9a8a 9a8f 9a93 9a97
9a9a 9a9f 9aa4 9aa7 9aab 9aac 9ab1 9ab4
9ab9 9aba 9abf 9ac2 9ac7 9ac8 9acd 9ad0
9ad4 9ad5 9ada 9add 9ae2 9ae3 9ae8 9aeb
9aef 9af3 9af6 9af9 9afa 9afc 9afd 9b02
9b03 9b08 9b0a 9b0e 9b11 9b13 9b17 9b19
9b25 9b27 9b29 9b2a 9b2f 9b33 9b35 9b41
9b43 9b47 9b4b 9b4e 9b52 9b55 9b59 9b5c
9b5d 9b62 9b65 9b69 9b6d 9b71 9b74 9b75
9b77 9b7b 9b7f 9b82 9b83 9b85 9b88 9b8c
9b8f 9b93 9b96 9b97 9b9c 9ba0 9ba3 9ba7
9bab 9baf 9bb3 9bb7 9bbb 9bbf 9bc3 9bc7
9bd3 9bd7 9bdc 9be0 9be3 9be4 9be9 9bed
9bf1 9bf4 9bf7 9bfb 9bfd 9c01 9c05 9c08
9c0b 9c0f 9c11 9c15 9c19 9c1c 9c1e 1
9c22 9c26 9c2a 9c2d 9c31 9c35 9c39 9c3d
9c40 9c44 9c48 9c4b 9c4e 9c53 9c56 9c59
9c5c 9c5d 9c62 9c63 1 9c65 9c6a 9c6e
9c72 9c75 9c7a 9c7f 9c82 9c86 9c87 9c8c
9c8f 9c94 9c95 9c9a 9c9d 9ca2 9ca3 9ca8
9cab 9caf 9cb0 9cb5 9cb8 9cbd 9cbe 9cc3
9cc6 9cca 9cce 9cd1 9cd4 9cd5 9cd7 9cd8
9cdd 9cde 9ce3 9ce5 9ce9 9cec 9cee 9cf2
9cf4 9d00 9d02 9d04 9d05 9d0a 9d0e 9d10
9d1c 9d1e 9d22 9d24 9d28 9d2c 9d2f 9d30
9d32 9d36 9d39 9d3d 9d40 9d41 9d46 9d4a
9d4e 9d51 9d55 9d59 9d5c 9d5d 9d5f 9d63
9d67 9d6a 9d6e 9d6f 9d71 9d75 9d79 9d7d
9d81 9d85 9d89 9d8d 9d91 9d95 9d99 9d9d
9da1 9da5 9da9 9db5 9db9 9dbe 9dc2 9dc5
9dc6 9dcb 9dcf 9dd3 9dd6 9dd9 9ddd 9ddf
9de3 9de7 9dea 9ded 9df1 9df3 9df7 9dfb
9dfe 9e00 1 9e04 9e08 9e0c 9e0f 9e13
9e17 9e1b 9e1f 9e22 9e26 9e2a 9e2d 9e30
9e35 9e38 9e3b 9e3e 9e3f 9e44 9e45 1
9e47 9e4c 9e50 9e54 9e57 9e5c 9e61 9e64
9e68 9e69 9e6e 9e71 9e76 9e77 9e7c 9e7f
9e84 9e85 9e8a 9e8d 9e91 9e92 9e97 9e9a
9e9f 9ea0 9ea5 9ea8 9eac 9eb0 9eb3 9eb6
9eb7 9eb9 9eba 9ebf 9ec0 9ec5 9ec7 9ecb
9ece 9ed0 9ed4 9ed6 9ee2 9ee4 9ee6 9ee7
9eec 9ef0 9ef2 9efe 9f00 9f02 9f06 9f0a
9f0e 9f12 9f16 9f1a 9f1e 9f22 9f26 9f2a
9f2e 9f32 9f36 9f3a 9f3e 9f42 9f46 9f52
9f56 9f5b 9f5f 9f62 9f63 9f68 9f6c 9f70
9f73 9f76 9f7a 9f7c 9f80 9f84 9f87 9f8a
9f8e 9f90 9f94 9f98 9f9b 9f9d 1 9fa1
9fa5 9fa9 9fac 9fb0 9fb4 9fb8 9fbc 9fbf
9fc3 9fc7 9fca 9fcd 9fd2 9fd5 9fd8 9fdb
9fdc 9fe1 9fe2 1 9fe4 9fe9 9fed 9ff1
9ff4 9ff9 9ffe a001 a005 a006 a00b a00e
a013 a014 a019 a01c a021 a022 a027 a02a
a02e a02f a034 a037 a03c a03d a042 a045
a049 a04d a050 a053 a054 a056 a057 a05c
a05d a062 a064 a068 a06b a06d a071 a073
a07f a081 a083 a084 a089 a08d a08f a09b
a09d a09f a0a3 a0a7 a0aa a0ae a0b2 a0b5
a0b9 a0bc a0c0 a0c3 a0c4 a0c9 a0cc a0d0
a0d4 a0d7 a0d8 a0da a0dd a0e0 a0e1 a0e6
1 a0e9 a0ee a0f2 a0f6 a0fa a106 a10a
a10f a113 a116 a117 a11c a120 a124 a127
a12a a12e a130 a134 a138 a13b a13e a142
a144 a148 a14c a14f a151 1 a155 a159
a15d a160 a164 a168 a16c a170 a173 a177
a17b a17e a181 a186 a189 a18c a18f a190
a195 a196 1 a198 a19d a1a1 a1a5 a1a8
a1ad a1b2 a1b5 a1b9 a1ba a1bf a1c2 a1c7
a1c8 a1cd a1d0 a1d5 a1d6 a1db a1de a1e2
a1e3 a1e8 a1eb a1f0 a1f1 a1f6 a1f9 a1fd
a201 a204 a207 a208 a20a a20b a210 a211
a216 a218 a21c a21f a221 a225 a227 a233
a235 a237 a238 a23d a241 a243 a24f a251
a253 a257 a25a a25c a260 a264 a268 a26c
a270 a274 a278 a27c a280 a284 a288 a28c
a290 a294 a298 a29c a2a0 a2a4 a2a8 a2ac
a2b0 a2b4 a2b8 a2bc a2c0 a2c4 a2c8 a2cc
a2d0 a2d4 a2d8 a2dc a2e0 a2e4 a2f0 a2f4
a2f8 a2fb a2ff a303 a305 1 a309 a30d
a311 a314 a318 a31c a320 a324 a327 a32b
a32f a332 a335 a33a a33d a340 a343 a344
a349 a34a 1 a34c a351 a355 a359 a35c
a361 a366 a369 a36d a36e a373 a376 a37b
a37c a381 a384 a389 a38a a38f a392 a396
a397 a39c a39f a3a4 a3a5 a3aa a3ad a3b1
a3b5 a3b8 a3bb a3bc a3be a3bf a3c4 a3c5
a3ca a3cc a3d0 a3d3 a3d5 a3d9 a3db a3e7
a3e9 a3eb a3ec a3f1 a3f5 a3f7 a403 a405
a409 a40d a410 a414 a417 a41b a41e a41f
a424 a427 a42b a42e a42f a434 a437 1
a43a a43f a443 a447 a44a a44e a452 a455
a456 a458 a45c a460 a463 a467 a468 a46a
a46e a472 a476 a47a a486 a48a a48f a493
a496 a497 a49c a4a0 a4a4 a4a7 a4aa a4ae
a4b0 a4b4 a4b8 a4bb a4be a4c2 a4c4 a4c8
a4cc a4cf a4d1 1 a4d5 a4d9 a4dd a4e0
a4e4 a4e8 a4ec a4f0 a4f3 a4f7 a4fb a4fe
a501 a506 a509 a50c a50f a510 a515 a516
1 a518 a51d a521 a525 a528 a52d a532
a535 a539 a53a a53f a542 a547 a548 a54d
a550 a555 a556 a55b a55e a562 a563 a568
a56b a570 a571 a576 a579 a57d a581 a584
a587 a588 a58a a58b a590 a591 a596 a598
a59c a59f a5a1 a5a5 a5a7 a5b3 a5b5 a5b7
a5b8 a5bd a5c1 a5c3 a5cf a5d1 a5d5 a5d9
a5dd a5e1 a5e5 a5e9 a5ed a5f1 a5f5 a5f9
a5fd a609 a60d a612 a616 a619 a61a a61f
a623 a627 a62a a62d a631 a633 a637 a63b
a63e a641 a645 a647 a64b a64f a652 a654
1 a658 a65c a660 a663 a667 a66b a66f
a673 a676 a67a a67e a681 a684 a689 a68c
a68f a692 a693 a698 a699 1 a69b a6a0
a6a4 a6a8 a6ab a6b0 a6b5 a6b8 a6bc a6bd
a6c2 a6c5 a6ca a6cb a6d0 a6d3 a6d8 a6d9
a6de a6e1 a6e5 a6e6 a6eb a6ee a6f3 a6f4
a6f9 a6fc a700 a704 a707 a70a a70b a70d
a70e a713 a714 a719 a71b a71f a722 a724
a728 a72a a736 a738 a73a a73b a740 a744
a746 a752 a754 a758 a75c a760 a764 a768
a76c a770 a774 a780 a784 a789 a78d a790
a791 a796 a79a a79e a7a1 a7a4 a7a8 a7aa
a7ae a7b2 a7b5 a7b8 a7bc a7be a7c2 a7c6
a7c9 a7cb 1 a7cf a7d3 a7d7 a7da a7de
a7e2 a7e6 a7ea a7ed a7f1 a7f5 a7f8 a7fb
a800 a803 a806 a809 a80a a80f a810 1
a812 a817 a81b a81f a822 a827 a82c a82f
a833 a834 a839 a83c a841 a842 a847 a84a
a84f a850 a855 a858 a85c a85d a862 a865
a86a a86b a870 a873 a877 a87b a87e a881
a882 a884 a885 a88a a88b a890 a892 a896
a899 a89b a89f a8a1 a8ad a8af a8b1 a8b2
a8b7 a8bb a8bd a8c9 a8cb a8cd a8d1 a8d5
a8d8 a8dc a8e0 a8e3 a8e4 a8e6 a8ea a8ee
a8f1 a8f5 a8f6 a8f8 a8fc a900 a904 a908
a90c a910 a914 a918 a91c a928 a92c a931
a935 a938 a939 a93e a942 a946 a949 a94c
a950 a952 a956 a95a a95d a960 a964 a966
a96a a96e a971 a973 1 a977 a97b a97f
a982 a986 a98a a98e a992 a995 a999 a99d
a9a0 a9a3 a9a8 a9ab a9ae a9b1 a9b2 a9b7
a9b8 1 a9ba a9bf a9c3 a9c7 a9ca a9cf
a9d4 a9d7 a9db a9dc a9e1 a9e4 a9e9 a9ea
a9ef a9f2 a9f7 a9f8 a9fd aa00 aa04 aa05
aa0a aa0d aa12 aa13 aa18 aa1b aa1f aa23
aa26 aa29 aa2a aa2c aa2d aa32 aa33 aa38
aa3a aa3e aa41 aa43 aa47 aa49 aa55 aa57
aa59 aa5a aa5f aa63 aa65 aa71 aa73 aa77
aa7b aa7f aa83 aa87 aa8b aa8f aa93 aa97
aa9b aa9f aaab aaaf aab4 aab8 aabb aabc
aac1 aac5 aac9 aacc aacf aad3 aad5 aad9
aadd aae0 aae3 aae7 aae9 aaed aaf1 aaf4
aaf6 1 aafa aafe ab02 ab05 ab09 ab0d
ab11 ab15 ab18 ab1c ab20 ab23 ab26 ab2b
ab2e ab31 ab34 ab35 ab3a ab3b 1 ab3d
ab42 ab46 ab4a ab4d ab52 ab57 ab5a ab5e
ab5f ab64 ab67 ab6c ab6d ab72 ab75 ab7a
ab7b ab80 ab83 ab87 ab88 ab8d ab90 ab95
ab96 ab9b ab9e aba2 aba6 aba9 abac abad
abaf abb0 abb5 abb6 abbb abbd abc1 abc4
abc6 abca abcc abd8 abda abdc abdd abe2
abe6 abe8 abf4 abf6 abf8 abfc ac00 ac03
ac05 ac09 ac0d ac10 ac14 ac18 ac1b ac1c
ac1e ac21 ac24 ac25 ac2a ac2e ac32 ac35
ac36 ac38 ac3b ac3e ac3f ac44 ac47 ac4b
ac4e ac4f ac54 ac57 1 ac5a ac5f ac63
ac67 ac6b ac6f ac73 ac77 ac7b ac87 ac8b
ac8f ac92 ac96 ac9a ac9c 1 aca0 aca4
aca8 acab acaf acb3 acb7 acbb acbe acc2
acc6 acc9 accc acd1 acd4 acd7 acda acdb
ace0 ace1 1 ace3 ace8 acec acf0 acf3
acf8 acfd ad00 ad04 ad05 ad0a ad0d ad12
ad13 ad18 ad1b ad20 ad21 ad26 ad29 ad2d
ad2e ad33 ad36 ad3b ad3c ad41 ad44 ad48
ad4c ad4f ad52 ad53 ad55 ad56 ad5b ad5c
ad61 ad63 ad67 ad6a ad6c ad70 ad72 ad7e
ad80 ad82 ad83 ad88 ad8c ad8e ad9a ad9c
ada0 ada4 ada7 adab adae adb2 adb5 adb6
adbb adbe adc2 adc6 adc9 adca adcc adcf
add2 add3 add8 1 addb ade0 ade4 ade8
adec adf0 adf4 ae00 ae04 ae09 ae0d ae10
ae11 ae16 ae1a ae1e ae21 ae24 ae28 ae2a
ae2e ae32 ae35 ae38 ae3c ae3e ae42 ae46
ae49 ae4b 1 ae4f ae53 ae57 ae5a ae5e
ae62 ae66 ae6a ae6d ae71 ae75 ae78 ae7b
ae80 ae83 ae86 ae89 ae8a ae8f ae90 1
ae92 ae97 ae9b ae9f aea2 aea7 aeac aeaf
aeb3 aeb4 aeb9 aebc aec1 aec2 aec7 aeca
aecf aed0 aed5 aed8 aedc aedd aee2 aee5
aeea aeeb aef0 aef3 aef7 aefb aefe af01
af02 af04 af05 af0a af0b af10 af12 af16
af19 af1b af1f af21 af2d af2f af31 af32
af37 af3b af3d af49 af4b af4f af51 af55
af59 af5c af60 af63 af67 af6a af6b af70
af73 af77 af7b af7e af7f af81 af84 af87
af88 af8d 1 af90 af95 af99 af9d afa2
afa4 afa8 afac afaf afb3 afb7 afb9 1
afbd afc1 afc5 afc8 afcc afd0 afd4 afd8
afdb afdf afe3 afe6 afe9 afee aff1 aff4
aff7 aff8 affd affe 1 b000 b005 b009
b00d b010 b015 b01a b01d b021 b022 b027
b02a b02f b030 b035 b038 b03d b03e b043
b046 b04a b04b b050 b053 b058 b059 b05e
b061 b065 b069 b06c b06f b070 b072 b073
b078 b079 b07e b080 b084 b087 b089 b08d
b08f b09b b09d b09f b0a0 b0a5 b0a9 b0ab
b0b7 b0b9 b0bd b0c1 b0c4 b0c8 b0cc b0cf
b0d2 b0d7 b0da b0dd b0e0 b0e1 b0e6 b0e7
1 b0e9 b0ee b0f2 b0f6 b0f9 b0fe b103
b106 b10a b10b b110 b113 b118 b119 b11e
b121 b126 b127 b12c b12f b133 b137 b13b
b13f b142 b143 b145 b14a b14b b14d b14e
b153 b156 b15b b15c b161 b164 b169 b16a
b16f b172 b176 b177 b17c b17f b184 b185
b18a b18b b190 b192 b196 b199 b19d b1a1
b1a4 b1a8 b1ac b1af b1b2 b1b7 b1ba b1bd
b1c0 b1c1 b1c6 b1c7 1 b1c9 b1ce b1d2
b1d6 b1d9 b1de b1e3 b1e6 b1ea b1eb b1f0
b1f1 b1f6 b1f8 b1fc b1ff b203 b207 b20a
b20e b212 b215 b219 b21d b21e b223 b225
b229 b22d b230 b232 b236 b239 b23d b240
b243 b244 b249 b24d b251 b255 b258 b25c
b260 b264 b268 b26c b270 b274 b278 b27c
b280 b284 b285 b287 b28b b28f b293 b297
b29b b29f b2ab b2af b2b4 b2b8 b2bb b2bc
b2c1 b2c5 b2c9 b2cc b2cf b2d3 b2d5 b2d9
b2dd b2e0 b2e3 b2e7 b2e9 b2ed b2f1 b2f4
b2f6 1 b2fa b2fe b302 b305 b309 b30d
b311 b315 b318 b31c b320 b323 b326 b32b
b32e b331 b334 b335 b33a b33b 1 b33d
b342 b346 b34a b34d b352 b357 b35a b35e
b35f b364 b367 b36c b36d b372 b375 b37a
b37b b380 b383 b387 b388 b38d b390 b395
b396 b39b b39e b3a2 b3a6 b3a9 b3ac b3ad
b3af b3b0 b3b5 b3b6 b3bb b3bd b3c1 b3c4
b3c6 b3ca b3cc b3d8 b3da b3dc b3dd b3e2
b3e6 b3e8 b3f4 b3f6 b3fa b3ff b403 b407
b40a b40d b40e b413 b417 b41b b41e b41f
b421 b424 b428 b42c b42f b430 b432 b433
b438 b43b b43e b43f b444 1 b447 b44c
b450 b454 b458 b45c b460 b464 b468 b46c
b470 b474 b478 b47c b480 b484 b488 b48c
b490 b494 b498 b49c b4a0 b4a4 b4a8 b4ac
b4b0 b4b4 b4b8 b4bc b4c0 b4c4 b4c7 b4c8
b4ca b4ce b4d2 b4d5 b4d6 b4d8 b4db b4de
b4e1 b4e2 b4e7 b4ea b4ee b4f2 b4f5 b4f6
b4f8 b4fc b4ff b503 b506 b507 b509 b50a
b50f b512 b516 b51a b51d b51e b520 b524
b527 b52b b52e b52f b531 b532 b537 1
b53a b53f 1 b542 b547 b54a b54e b552
b555 b556 b558 b55b b55e b55f b564 b568
b56c b570 b574 b578 b57c b580 b584 b588
b58c b590 b594 b598 b59c b5a0 b5a4 b5a8
b5ac b5b0 b5b4 b5b8 b5bc b5c0 b5c4 b5c8
b5cc b5d0 b5d4 b5d8 b5dc b5e0 b5e4 b5e8
b5ec b5f0 b5f4 b5f8 b604 b608 b60d b611
b614 b615 b61a b61e b622 b625 b628 b62c
b62e b632 b636 b639 b63c b640 b642 b646
b64a b64d b64f 1 b653 b657 b65b b65e
b662 b666 b66a b66e b671 b675 b679 b67c
b67f b684 b687 b68a b68d b68e b693 b694
1 b696 b69b b69f b6a3 b6a6 b6ab b6b0
b6b3 b6b7 b6b8 b6bd b6c0 b6c5 b6c6 b6cb
b6ce b6d3 b6d4 b6d9 b6dc b6e0 b6e1 b6e6
b6e9 b6ee b6ef b6f4 b6f7 b6fb b6ff b702
b705 b706 b708 b709 b70e b70f b714 b716
b71a b71d b71f b723 b725 b731 b733 b735
b736 b73b b73f b741 b74d b74f b751 b755
b759 b75d b761 b765 b769 b76d b771 b775
b779 b77d b781 b785 b789 b78d b791 b795
b799 b79d b7a1 b7a5 b7a9 b7ad b7b1 b7b5
b7b9 b7bd b7c1 b7c5 b7c9 b7cd b7d1 b7d5
b7d9 b7dd b7e1 b7e5 b7e9 b7ed b7f9 b7fd
b802 b806 b809 b80a b80f b813 b817 b81a
b81d b821 b823 b827 b82b b82e b831 b835
b837 b83b b83f b842 b844 1 b848 b84c
b850 b853 b857 b85b b85f b863 b866 b86a
b86e b871 b874 b879 b87c b87f b882 b883
b888 b889 1 b88b b890 b894 b898 b89b
b8a0 b8a5 b8a8 b8ac b8ad b8b2 b8b5 b8ba
b8bb b8c0 b8c3 b8c8 b8c9 b8ce b8d1 b8d5
b8d6 b8db b8de b8e3 b8e4 b8e9 b8ec b8f0
b8f4 b8f7 b8fa b8fb b8fd b8fe b903 b904
b909 b90b b90f b912 b914 b918 b91a b926
b928 b92a b92b b930 b934 b936 b942 b944
b946 b94a b94e b951 b953 b957 b95b b95f
b963 b967 b96b b96f b973 b977 b97b b97f
b983 b987 b98b b98f b993 b997 b99b b99f
b9a3 b9a7 b9ab b9af b9b3 b9b7 b9bb b9bf
b9c3 b9c7 b9cb b9cf b9d3 b9d7 b9e3 b9e7
b9ec b9f0 b9f3 b9f4 b9f9 b9fd ba01 ba04
ba07 ba0b ba0d ba11 ba15 ba18 ba1b ba1f
ba21 ba25 ba29 ba2c ba2e 1 ba32 ba36
ba3a ba3d ba41 ba45 ba49 ba4d ba50 ba54
ba58 ba5b ba5e ba63 ba66 ba69 ba6c ba6d
ba72 ba73 1 ba75 ba7a ba7e ba82 ba85
ba8a ba8f ba92 ba96 ba97 ba9c ba9f baa4
baa5 baaa baad bab2 bab3 bab8 babb babf
bac0 bac5 bac8 bacd bace bad3 bad6 bada
bade bae1 bae4 bae5 bae7 bae8 baed baee
baf3 baf5 baf9 bafc bafe bb02 bb04 bb10
bb12 bb14 bb15 bb1a bb1e bb20 bb2c bb2e
bb30 bb34 bb38 bb3b bb3f bb43 bb46 bb47
bb49 bb4c bb4f bb50 bb55 bb58 bb5c bb60
bb63 bb64 bb66 bb69 bb6c bb6d bb72 1
bb75 bb7a bb7e bb81 bb85 bb89 bb8b bb8f
bb93 bb96 bb97 bb99 bb9c bb9f bba0 bba5
bba9 bbad bbb1 bbb4 bbb5 bbb7 bbbb bbbd
bbc1 bbc5 bbc8 bbcc bbd0 bbd4 bbd8 bbdc
bbe0 bbe3 bbe4 bbe6 bbea bbee bbf1 bbf2
bbf4 bbf8 bbfc bbff bc00 bc02 bc06 bc0a
bc0d bc0e bc10 bc14 bc18 bc1b bc1c bc1e
bc22 bc26 bc29 bc2a bc2c bc30 bc34 bc37
bc38 bc3a bc3e bc42 bc45 bc46 bc48 bc4c
bc50 bc54 bc55 bc57 bc5b bc5f bc63 bc66
bc67 bc69 bc6d bc70 bc74 bc77 bc78 bc7d
bc81 bc85 bc8a bc8c bc90 bc94 bc97 bc9b
bc9f bca1 1 bca5 bca9 bcad bcb0 bcb4
bcb8 bcbc bcc0 bcc3 bcc7 bccb bcce bcd1
bcd6 bcd9 bcdc bcdf bce0 bce5 bce6 1
bce8 bced bcf1 bcf5 bcf8 bcfd bd02 bd05
bd09 bd0a bd0f bd12 bd17 bd18 bd1d bd20
bd25 bd26 bd2b bd2e bd32 bd33 bd38 bd3b
bd40 bd41 bd46 bd49 bd4d bd51 bd54 bd57
bd58 bd5a bd5b bd60 bd61 bd66 bd68 bd6c
bd6f bd71 bd75 bd77 bd83 bd85 bd87 bd88
bd8d bd91 bd93 bd9f bda1 bda5 bda9 bdac
bdb0 bdb4 bdb7 bdba bdbf bdc2 bdc5 bdc8
bdc9 bdce bdcf 1 bdd1 bdd6 bdda bdde
bde1 bde6 bdeb bdee bdf2 bdf3 bdf8 bdfb
be00 be01 be06 be09 be0e be0f be14 be17
be1b be1f be23 be27 be2a be2b be2d be32
be33 be35 be36 be3b be3c be41 be43 be47
be4a be4e be52 be55 be59 be5d be60 be63
be68 be6b be6e be71 be72 be77 be78 1
be7a be7f be83 be87 be8a be8f be94 be97
be9b be9c bea1 bea2 bea7 bea9 bead beb0
beb4 beb8 bebb bebf bec3 bec6 beca becb
bed0 bed4 bed6 beda bede bee1 bee2 bee4
bee7 beea beeb bef0 bef4 bef8 befd beff
bf03 bf07 bf0a bf0e bf12 bf14 1 bf18
bf1c bf20 bf23 bf27 bf2b bf2f bf33 bf36
bf3a bf3e bf41 bf44 bf49 bf4c bf4f bf52
bf53 bf58 bf59 1 bf5b bf60 bf64 bf68
bf6b bf70 bf75 bf78 bf7c bf7d bf82 bf85
bf8a bf8b bf90 bf93 bf98 bf99 bf9e bfa1
bfa5 bfa6 bfab bfae bfb3 bfb4 bfb9 bfbc
bfc0 bfc4 bfc7 bfca bfcb bfcd bfce bfd3
bfd4 bfd9 bfdb bfdf bfe2 bfe4 bfe8 bfea
bff6 bff8 bffa bffb c000 c004 c006 c012
c014 c018 c01c c01f c023 c027 c02a c02d
c032 c035 c038 c03b c03c c041 c042 1
c044 c049 c04d c051 c054 c059 c05e c061
c065 c066 c06b c06e c073 c074 c079 c07c
c081 c082 c087 c08a c08e c092 c096 c097
c099 c09e c09f c0a1 c0a2 c0a7 c0aa c0af
c0b0 c0b5 c0b8 c0bd c0be c0c3 c0c6 c0ca
c0cb c0d0 c0d3 c0d8 c0d9 c0de c0df c0e4
c0e6 c0ea c0ed c0f1 c0f5 c0f8 c0fc c100
c103 c106 c10b c10e c111 c114 c115 c11a
c11b 1 c11d c122 c126 c12a c12d c132
c137 c13a c13e c13f c144 c145 c14a c14c
c150 c153 c157 c15b c15e c162 c166 c169
c16a c16c c170 c174 c175 c17a c17c c180
c184 c187 c189 c18d c191 c194 c195 c197
c19a c19d c19e c1a3 c1a6 c1aa c1ae c1b1
c1b2 c1b4 c1b8 c1bb c1bf c1c2 c1c3 c1c5
c1c6 c1cb 1 c1ce c1d3 c1d7 c1db c1df
c1e2 c1e3 c1e5 c1e9 c1eb c1ef c1f3 c1f7
c1fb c1fe c1ff c201 c204 c208 c20c c20f
c210 c212 c213 c218 c219 c21b c21f c221
c225 c229 c22c c230 c234 c237 c238 c23a
c23d c240 c241 c246 c24a c24e c252 c255
c256 c258 c25b c25e c25f c264 c268 c26a
c26e c272 c276 c27a c27d c27e c280 c283
c286 c287 c28c c28d c28f c293 c295 c299
c29d c2a0 c2a4 c2a8 c2ac c2b0 c2b4 c2b8
c2bc c2c0 c2c4 c2c8 c2cc c2d0 c2d4 c2d8
c2dc c2e0 c2e4 c2e8 c2ec c2f0 c2f4 c2f8
c2fc c300 c304 c308 c30c c310 c314 c318
c31c c328 c32c c331 c335 c338 c339 c33e
c342 c346 c349 c34c c350 c352 c356 c35a
c35d c360 c364 c366 c36a c36e c371 c373
1 c377 c37b c37f c382 c386 c38a c38e
c392 c395 c399 c39d c3a0 c3a3 c3a8 c3ab
c3ae c3b1 c3b2 c3b7 c3b8 1 c3ba c3bf
c3c3 c3c7 c3ca c3cf c3d4 c3d7 c3db c3dc
c3e1 c3e4 c3e9 c3ea c3ef c3f2 c3f7 c3f8
c3fd c400 c404 c405 c40a c40d c412 c413
c418 c41b c41f c423 c426 c429 c42a c42c
c42d c432 c433 c438 c43a c43e c441 c443
c447 c449 c455 c457 c459 c45a c45f c463
c465 c471 c473 c475 c479 c47d c480 c484
c487 c48b c48f c492 c496 c49a c49d c4a1
c4a5 c4a9 c4ac c4ad c4af c4b2 c4b5 c4b6
c4bb c4bf c4c3 c4c7 c4ca c4ce c4d2 c4d4
c4d8 c4dc c4e0 c4e3 c4e4 c4e6 c4e7 c4e9
c4ec c4ef c4f0 c4f5 c4f9 c4fd c501 c504
c507 c50b c50f c512 c513 c515 c519 c51b
c51f c523 c527 c52b c52e c532 c536 c539
c53a c53c c540 c544 c547 c548 c54a c54e
c550 c554 c558 c55b c55f c562 c566 c56a
c56d c571 c575 c579 c57d c581 c585 c589
c58d c591 c595 c599 c59d c5a1 c5a5 c5a9
c5ad c5b1 c5b5 c5b9 c5bd c5c1 c5c5 c5c9
c5cd c5d1 c5d5 c5d9 c5dd c5e1 c5e5 c5e9
c5ec c5ef c5f2 c5f5 c5f6 c5f8 c5fc c600
c604 c607 c608 c60a c60d c610 c611 c616
c61a c61e c623 c625 c629 c62d c630 c634
c638 c63a 1 c63e c642 c646 c649 c64d
c651 c655 c659 c65c c660 c664 c667 c66a
c66f c672 c675 c678 c679 c67e c67f 1
c681 c686 c68a c68e c691 c696 c69b c69e
c6a2 c6a3 c6a8 c6ab c6b0 c6b1 c6b6 c6b9
c6be c6bf c6c4 c6c7 c6cb c6cc c6d1 c6d4
c6d9 c6da c6df c6e2 c6e6 c6ea c6ed c6f0
c6f1 c6f3 c6f4 c6f9 c6fa c6ff c701 c705
c708 c70a c70e c710 c71c c71e c720 c721
c726 c72a c72c c738 c73a c73e c742 c745
c749 c74d c750 c753 c758 c75b c75e c761
c762 c767 c768 1 c76a c76f c773 c777
c77a c77f c784 c787 c78b c78c c791 c794
c799 c79a c79f c7a2 c7a7 c7a8 c7ad c7b0
c7b4 c7b8 c7bc c7c0 c7c3 c7c4 c7c6 c7cb
c7cc c7ce c7cf c7d4 c7d7 c7dc c7dd c7e2
c7e5 c7ea c7eb c7f0 c7f3 c7f7 c7f8 c7fd
c800 c805 c806 c80b c80c c811 c813 c817
c81a c81e c822 c825 c829 c82d c830 c833
c838 c83b c83e c841 c842 c847 c848 1
c84a c84f c853 c857 c85a c85f c864 c867
c86b c86c c871 c872 c877 c879 c87d c880
c884 c888 c88b c88f c893 c896 c89a c89e
c89f c8a4 c8a8 c8aa c8ae c8b2 c8b5 c8b6
c8b8 c8bb c8be c8bf c8c4 c8c8 c8cc c8d1
c8d3 c8d7 c8db c8de c8e2 c8e6 c8e8 1
c8ec c8f0 c8f4 c8f7 c8fb c8ff c903 c907
c90a c90e c912 c915 c918 c91d c920 c923
c926 c927 c92c c92d 1 c92f c934 c938
c93c c93f c944 c949 c94c c950 c951 c956
c959 c95e c95f c964 c967 c96c c96d c972
c975 c979 c97a c97f c982 c987 c988 c98d
c990 c994 c998 c99b c99e c99f c9a1 c9a2
c9a7 c9a8 c9ad c9af c9b3 c9b6 c9b8 c9bc
c9be c9ca c9cc c9ce c9cf c9d4 c9d8 c9da
c9e6 c9e8 c9ec c9f0 c9f3 c9f7 c9fb c9fe
ca01 ca06 ca09 ca0c ca0f ca10 ca15 ca16
1 ca18 ca1d ca21 ca25 ca28 ca2d ca32
ca35 ca39 ca3a ca3f ca42 ca47 ca48 ca4d
ca50 ca55 ca56 ca5b ca5e ca62 ca66 ca6a
ca6e ca71 ca72 ca74 ca79 ca7a ca7c ca7d
ca82 ca85 ca8a ca8b ca90 ca93 ca98 ca99
ca9e caa1 caa5 caa6 caab caae cab3 cab4
cab9 caba cabf cac1 cac5 cac8 cacc cad0
cad3 cad7 cadb cade cae1 cae6 cae9 caec
caef caf0 caf5 caf6 1 caf8 cafd cb01
cb05 cb08 cb0d cb12 cb15 cb19 cb1a cb1f
cb20 cb25 cb27 cb2b cb2e cb32 cb36 cb39
cb3d cb41 cb44 cb48 cb4c cb4d cb52 cb54
cb58 cb5c cb5f cb63 cb67 cb6b cb6f cb73
cb77 cb7b cb87 cb8b cb90 cb94 cb97 cb98
cb9d cba1 cba5 cba8 cbab cbaf cbb1 cbb5
cbb9 cbbc cbbf cbc3 cbc5 cbc9 cbcd cbd0
cbd2 1 cbd6 cbda cbde cbe1 cbe5 cbe9
cbed cbf1 cbf4 cbf8 cbfc cbff cc02 cc07
cc0a cc0d cc10 cc11 cc16 cc17 1 cc19
cc1e cc22 cc26 cc29 cc2e cc33 cc36 cc3a
cc3b cc40 cc43 cc48 cc49 cc4e cc51 cc56
cc57 cc5c cc5f cc63 cc64 cc69 cc6c cc71
cc72 cc77 cc7a cc7e cc82 cc85 cc88 cc89
cc8b cc8c cc91 cc92 cc97 cc99 cc9d cca0
cca2 cca6 cca8 ccb4 ccb6 ccb8 ccb9 ccbe
ccc2 ccc4 ccd0 ccd2 ccd6 ccda ccde cce2
cce6 ccea ccee ccf2 ccf6 ccfa ccfe cd02
cd06 cd0a cd0e cd12 cd16 cd1a cd1e cd22
cd26 cd2a cd2e cd32 cd3e cd42 cd47 cd4b
cd4e cd4f cd54 cd58 cd5c cd5f cd62 cd66
cd68 cd6c cd70 cd73 cd76 cd7a cd7c cd80
cd84 cd87 cd89 1 cd8d cd91 cd95 cd98
cd9c cda0 cda4 cda8 cdab cdaf cdb3 cdb6
cdb9 cdbe cdc1 cdc4 cdc7 cdc8 cdcd cdce
1 cdd0 cdd5 cdd9 cddd cde0 cde5 cdea
cded cdf1 cdf2 cdf7 cdfa cdff ce00 ce05
ce08 ce0d ce0e ce13 ce16 ce1a ce1b ce20
ce23 ce28 ce29 ce2e ce31 ce35 ce39 ce3c
ce3f ce40 ce42 ce43 ce48 ce49 ce4e ce50
ce54 ce57 ce59 ce5d ce5f ce6b ce6d ce6f
ce70 ce75 ce79 ce7b ce87 ce89 ce8d ce91
ce95 ce99 ce9d cea1 cea5 cea9 cead ceb1
ceb5 cec1 cec5 ceca cece ced1 ced2 ced7
cedb cedf cee2 cee5 cee9 ceeb ceef cef3
cef6 cef9 cefd ceff cf03 cf07 cf0a cf0c
1 cf10 cf14 cf18 cf1b cf1f cf23 cf27
cf2b cf2e cf32 cf36 cf39 cf3c cf41 cf44
cf47 cf4a cf4b cf50 cf51 1 cf53 cf58
cf5c cf60 cf63 cf68 cf6d cf70 cf74 cf75
cf7a cf7d cf82 cf83 cf88 cf8b cf90 cf91
cf96 cf99 cf9d cf9e cfa3 cfa6 cfab cfac
cfb1 cfb4 cfb8 cfbc cfbf cfc2 cfc3 cfc5
cfc6 cfcb cfcc cfd1 cfd3 cfd7 cfda cfdc
cfe0 cfe2 cfee cff0 cff2 cff3 cff8 cffc
cffe d00a d00c d010 d014 d018 d01c d020
d024 d028 d02c d030 d034 d038 d044 d048
d04d d051 d054 d055 d05a d05e d062 d065
d068 d06c d06e d072 d076 d079 d07c d080
d082 d086 d08a d08d d08f 1 d093 d097
d09b d09e d0a2 d0a6 d0aa d0ae d0b1 d0b5
d0b9 d0bc d0bf d0c4 d0c7 d0ca d0cd d0ce
d0d3 d0d4 1 d0d6 d0db d0df d0e3 d0e6
d0eb d0f0 d0f3 d0f7 d0f8 d0fd d100 d105
d106 d10b d10e d113 d114 d119 d11c d120
d121 d126 d129 d12e d12f d134 d137 d13b
d13f d142 d145 d146 d148 d149 d14e d14f
d154 d156 d15a d15d d15f d163 d165 d171
d173 d175 d176 d17b d17f d181 d18d d18f
d193 d197 d19b d19e d19f d1a1 d1a4 d1a7
d1a8 d1ad d1b1 d1b5 d1b9 d1bd d1c0 d1c1
d1c3 d1c6 d1ca d1ce d1d1 d1d2 d1d4 d1d5
d1da d1de d1e2 d1e7 d1eb d1ef d1f3 d1f7
d1fb d1ff d200 d202 d206 d20a d20f d213
d217 d21b d21f d223 d227 d228 d22a d22e
d232 d236 d23a d23e d242 d246 d24a d256
d25a d25f d263 d266 d267 d26c d270 d274
d277 d27a d27e d280 d284 d288 d28b d28e
d292 d294 d298 d29c d29f d2a1 1 d2a5
d2a9 d2ad d2b0 d2b4 d2b8 d2bc d2c0 d2c3
d2c7 d2cb d2ce d2d1 d2d6 d2d9 d2dc d2df
d2e0 d2e5 d2e6 1 d2e8 d2ed d2f1 d2f5
d2f8 d2fd d302 d305 d309 d30a d30f d312
d317 d318 d31d d320 d325 d326 d32b d32e
d332 d333 d338 d33b d340 d341 d346 d349
d34d d351 d354 d357 d358 d35a d35b d360
d361 d366 d368 d36c d36f d371 d375 d377
d383 d385 d387 d388 d38d d391 d393 d39f
d3a1 d3a5 d3a9 d3ac d3ad d3af d3b2 d3b5
d3b6 d3bb d3be d3c2 d3c6 d3c9 d3ca d3cc
d3cf d3d2 d3d3 d3d8 1 d3db d3e0 d3e4
d3e8 d3ec d3f0 d3f4 d3f8 d3fc d400 d404
d408 d40c d410 d414 d418 d41c d420 d424
d430 d434 d439 d43d d440 d441 d446 d44a
d44e d451 d454 d458 d45a d45e d462 d465
d468 d46c d46e d472 d476 d479 d47b 1
d47f d483 d487 d48a d48e d492 d496 d49a
d49d d4a1 d4a5 d4a8 d4ab d4b0 d4b3 d4b6
d4b9 d4ba d4bf d4c0 1 d4c2 d4c7 d4cb
d4cf d4d2 d4d7 d4dc d4df d4e3 d4e4 d4e9
d4ec d4f1 d4f2 d4f7 d4fa d4ff d500 d505
d508 d50c d50d d512 d515 d51a d51b d520
d523 d527 d52b d52e d531 d532 d534 d535
d53a d53b d540 d542 d546 d549 d54b d54f
d551 d55d d55f d561 d562 d567 d56b d56d
d579 d57b d57f d581 d585 d589 d58c d58d
d58f d592 d595 d596 d59b d59f d5a3 d5a7
d5ab d5af d5b3 d5b7 d5bb d5bf d5c3 d5c7
d5cb d5cf d5db d5df d5e4 d5e8 d5eb d5ec
d5f1 d5f5 d5f9 d5fc d5ff d603 d605 d609
d60d d610 d613 d617 d619 d61d d621 d624
d626 1 d62a d62e d632 d635 d639 d63d
d641 d645 d648 d64c d650 d653 d656 d65b
d65e d661 d664 d665 d66a d66b 1 d66d
d672 d676 d67a d67d d682 d687 d68a d68e
d68f d694 d697 d69c d69d d6a2 d6a5 d6aa
d6ab d6b0 d6b3 d6b7 d6b8 d6bd d6c0 d6c5
d6c6 d6cb d6ce d6d2 d6d6 d6d9 d6dc d6dd
d6df d6e0 d6e5 d6e6 d6eb d6ed d6f1 d6f4
d6f6 d6fa d6fc d708 d70a d70c d70d d712
d716 d718 d724 d726 d72a d72e d732 d735
d736 d738 d73c d740 d742 d746 d74a d74e
d751 d752 d754 d757 d75a d75b d760 d764
d768 d76c d770 d774 d778 d77c d780 d784
d788 d78c d790 d794 d7a0 d7a4 d7a9 d7ad
d7b0 d7b1 d7b6 d7ba d7be d7c1 d7c4 d7c8
d7ca d7ce d7d2 d7d5 d7d8 d7dc d7de d7e2
d7e6 d7e9 d7eb 1 d7ef d7f3 d7f7 d7fa
d7fe d802 d806 d80a d80d d811 d815 d818
d81b d820 d823 d826 d829 d82a d82f d830
1 d832 d837 d83b d83f d842 d847 d84c
d84f d853 d854 d859 d85c d861 d862 d867
d86a d86f d870 d875 d878 d87c d87d d882
d885 d88a d88b d890 d893 d897 d89b d89e
d8a1 d8a2 d8a4 d8a5 d8aa d8ab d8b0 d8b2
d8b6 d8b9 d8bb d8bf d8c1 d8cd d8cf d8d1
d8d2 d8d7 d8db d8dd d8e9 d8eb d8ef d8f3
d8f7 d8fa d8fb d8fd d901 d903 d907 d90b
d90f d913 d917 d91b d91f d923 d927 d92b
d937 d93b d940 d944 d947 d948 d94d d951
d955 d958 d95b d95f d961 d965 d969 d96c
d96f d973 d975 d979 d97d d980 d982 1
d986 d98a d98e d991 d995 d999 d99d d9a1
d9a4 d9a8 d9ac d9af d9b2 d9b7 d9ba d9bd
d9c0 d9c1 d9c6 d9c7 1 d9c9 d9ce d9d2
d9d6 d9d9 d9de d9e3 d9e6 d9ea d9eb d9f0
d9f3 d9f8 d9f9 d9fe da01 da06 da07 da0c
da0f da13 da14 da19 da1c da21 da22 da27
da2a da2e da32 da35 da38 da39 da3b da3c
da41 da42 da47 da49 da4d da50 da52 da56
da58 da64 da66 da68 da69 da6e da72 da74
da80 da82 da86 da8a da8e da91 da92 da94
da98 da9c daa0 daa4 daa7 daa8 daaa daae
dab0 dab4 dab8 dabb dabd dac1 dac4 dac6
daca dacd dacf dad3 dad7 dada dade dae2
dae5 dae9 daed daf1 daf5 daf6 daf8 dafc
dafe db02 db09 db0d db11 db16 db18 db1c
db20 db23 db27 db2b db2d 1 db31 db35
db39 db3c db40 db44 db48 db4c db4f db53
db57 db5a db5d db62 db65 db68 db6b db6c
db71 db72 1 db74 db79 db7d db81 db84
db89 db8e db91 db95 db96 db9b db9e dba3
dba4 dba9 dbac dbb1 dbb2 dbb7 dbba dbbe
dbbf dbc4 dbc7 dbcc dbcd dbd2 dbd5 dbd9
dbdd dbe0 dbe3 dbe4 dbe6 dbe7 dbec dbed
dbf2 dbf4 dbf8 dbfb dbfd dc01 dc03 dc0f
dc11 dc13 dc14 dc19 dc1d dc1f dc2b dc2d
dc31 dc34 dc38 dc3c dc40 dc43 dc44 dc46
dc49 dc4c dc4d dc52 dc56 dc5a dc5e dc62
dc66 dc69 dc6a dc6c dc70 dc73 dc77 dc7a
dc7b dc7d dc7e dc83 dc87 dc8b dc8f dc92
dc93 dc95 dc98 dc9c dca0 dca3 dca4 dca6
dca7 dcac dcb0 dcb4 dcb8 dcbb dcbc dcbe
dcc1 dcc4 dcc5 dcca dccd dcd1 dcd5 dcd8
dcd9 dcdb dcde dce1 dce2 dce7 1 dcea
dcef dcf3 dcf6 dcf7 dcfc dcff 1 dd02
dd07 dd0b dd0f dd13 dd17 dd1b dd1f dd23
dd27 dd2b dd2f dd33 dd37 dd3b dd3f dd43
dd47 dd4b dd4f dd53 dd57 dd5b dd5f dd63
dd67 dd6b dd6f dd72 dd73 dd75 dd78 dd7b
dd7c dd81 dd85 dd88 dd8c dd8e dd92 dd95
dd99 dd9d dda1 dda5 dda9 ddad ddb0 ddb1
ddb3 ddb7 ddbb ddbe ddbf ddc1 ddc5 ddc9
ddcc ddcd ddcf ddd3 ddd7 ddda dddb dddd
dde1 dde5 dde8 dde9 ddeb ddef ddf3 ddf6
ddf7 ddf9 ddfd de01 de04 de05 de07 de0b
de0f de12 de13 de15 de19 de1d de21 de22
de24 de28 de2c de30 de33 de34 de36 de3a
de3d de41 de44 de45 de4a de4e de52 de55
de59 de5d de60 de63 de68 de6b de6e de71
de72 de77 de78 1 de7a de7f de83 de87
de8a de8f de94 de97 de9b de9c dea1 dea4
dea9 deaa deaf deb2 deb7 deb8 debd dec0
dec4 dec8 decc ded0 ded3 ded4 ded6 dedb
dedc dede dedf dee4 dee5 deea deec def0
def3 def7 defb defe df02 df06 df09 df0c
df11 df14 df17 df1a df1b df20 df21 1
df23 df28 df2c df30 df33 df38 df3d df40
df44 df45 df4a df4b df50 df52 df56 df59
df5d df61 df64 df68 df6c df6f df73 df74
df79 df7d df7f df83 df87 df8a df8b df8d
df90 df93 df94 df99 df9d dfa1 dfa4 dfa8
dfac dfaf dfb2 dfb7 dfba dfbd dfc0 dfc1
dfc6 dfc7 1 dfc9 dfce dfd2 dfd6 dfd9
dfde dfe3 dfe6 dfea dfeb dff0 dff3 dff8
dff9 dffe e001 e006 e007 e00c e00f e013
e017 e01b e01c e01e e023 e024 e026 e027
e02c e02f e034 e035 e03a e03d e042 e043
e048 e04b e04f e050 e055 e058 e05d e05e
e063 e064 e069 e06b e06f e072 e076 e07a
e07d e081 e085 e088 e08b e090 e093 e096
e099 e09a e09f e0a0 1 e0a2 e0a7 e0ab
e0af e0b2 e0b7 e0bc e0bf e0c3 e0c4 e0c9
e0ca e0cf e0d1 e0d5 e0d8 e0dc e0e0 e0e3
e0e7 e0eb e0ee e0ef e0f1 e0f5 e0f9 e0fa
e0ff e101 e105 e109 e10c e110 e114 e119
e11e e122 e126 e12a e12d e130 e134 e138
e13c e140 e144 e148 e14c e150 e154 e158
e15c e168 e16c e171 e175 e178 e179 e17e
e182 e186 e189 e18c e190 e192 e196 e19a
e19d e1a0 e1a4 e1a6 e1aa e1ae e1b1 e1b3
1 e1b7 e1bb e1bf e1c2 e1c6 e1ca e1ce
e1d2 e1d5 e1d9 e1dd e1e0 e1e3 e1e8 e1eb
e1ee e1f1 e1f2 e1f7 e1f8 1 e1fa e1ff
e203 e207 e20a e20f e214 e217 e21b e21c
e221 e224 e229 e22a e22f e232 e237 e238
e23d e240 e244 e245 e24a e24d e252 e253
e258 e25b e25f e263 e266 e269 e26a e26c
e26d e272 e273 e278 e27a e27e e281 e283
e287 e289 e295 e297 e299 e29a e29f e2a3
e2a5 e2b1 e2b3 e2b7 e2bc e2c0 e2c4 e2c7
e2cb e2cf e2d2 e2d6 e2da e2dd e2e1 e2e5
e2e8 e2ec e2f0 e2f4 e2f7 e2f8 e2fa e2fd
e300 e301 e306 e30a e30e e312 e315 e319
e31d e320 e321 e323 e327 e32b e32e e32f
e331 e335 e339 e33c e340 e342 e346 e349
e34d e34f e353 e357 e35a e35e e361 e365
e369 e36d e371 e375 e379 e37d e381 e385
e389 e38d e391 e395 e399 e39d e3a1 e3a5
e3a9 e3ad e3b1 e3b5 e3b9 e3bd e3c1 e3c5
e3c9 e3cd e3d1 e3d5 e3d9 e3dd e3e0 e3e3
e3e6 e3e9 e3ea e3ec e3f0 e3f4 e3f8 e3fb
e3fc e3fe e401 e404 e405 e40a e40e e412
e415 e419 e41d e420 e423 e428 e42b e42e
e431 e432 e437 e438 1 e43a e43f e443
e447 e44a e44f e454 e457 e45b e45c e461
e464 e469 e46a e46f e472 e477 e478 e47d
e480 e484 e488 e48c e490 e493 e494 e496
e49b e49c e49e e49f e4a4 e4a7 e4ac e4ad
e4b2 e4b5 e4ba e4bb e4c0 e4c3 e4c7 e4c8
e4cd e4d0 e4d5 e4d6 e4db e4dc e4e1 e4e3
e4e7 e4ea e4ee e4f2 e4f5 e4f9 e4fd e500
e503 e508 e50b e50e e511 e512 e517 e518
1 e51a e51f e523 e527 e52a e52f e534
e537 e53b e53c e541 e542 e547 e549 e54d
e550 e554 e558 e55b e55f e563 e566 e56a
e56e e56f e574 e578 e57a e57e e582 e585
e586 e588 e58b e58e e58f e594 e598 e59c
e59f e5a3 e5a7 e5aa e5ad e5b2 e5b5 e5b8
e5bb e5bc e5c1 e5c2 1 e5c4 e5c9 e5cd
e5d1 e5d4 e5d9 e5de e5e1 e5e5 e5e6 e5eb
e5ee e5f3 e5f4 e5f9 e5fc e601 e602 e607
e60a e60e e612 e616 e61a e61d e61e e620
e625 e626 e628 e629 e62e e631 e636 e637
e63c e63f e644 e645 e64a e64d e651 e652
e657 e65a e65f e660 e665 e666 e66b e66d
e671 e674 e678 e67c e67f e683 e687 e68a
e68d e692 e695 e698 e69b e69c e6a1 e6a2
1 e6a4 e6a9 e6ad e6b1 e6b4 e6b9 e6be
e6c1 e6c5 e6c6 e6cb e6cc e6d1 e6d3 e6d7
e6da e6de e6e2 e6e5 e6e9 e6ed e6f0 e6f4
e6f8 e6f9 e6fe e700 e704 e708 e70c e710
e714 e718 e71c e720 e724 e728 e72c e730
e734 e738 e73c e740 e744 e748 e74c e750
e754 e758 e75c e760 e764 e768 e76c e770
e774 e780 e784 e789 e78d e790 e791 e796
e79a e79e e7a1 e7a4 e7a8 e7aa e7ae e7b2
e7b5 e7b8 e7bc e7be e7c2 e7c6 e7c9 e7cb
1 e7cf e7d3 e7d7 e7da e7de e7e2 e7e6
e7ea e7ed e7f1 e7f5 e7f8 e7fb e800 e803
e806 e809 e80a e80f e810 1 e812 e817
e81b e81f e822 e827 e82c e82f e833 e834
e839 e83c e841 e842 e847 e84a e84f e850
e855 e858 e85c e85d e862 e865 e86a e86b
e870 e873 e877 e87b e87e e881 e882 e884
e885 e88a e88b e890 e892 e896 e899 e89b
e89f e8a1 e8ad e8af e8b1 e8b2 e8b7 e8bb
e8bd e8c9 e8cb e8cd e8d1 e8d5 e8d8 e8da
e8de e8e1 e8e3 e8e7 e8ea e8ee e8f2 e8f6
e8fa e8fe e902 e906 e90a e916 e91a e91e
e921 e925 e929 e92b 1 e92f e933 e937
e93a e93e e942 e946 e94a e94d e951 e955
e958 e95b e960 e963 e966 e969 e96a e96f
e970 1 e972 e977 e97b e97f e982 e987
e98c e98f e993 e994 e999 e99c e9a1 e9a2
e9a7 e9aa e9af e9b0 e9b5 e9b8 e9bc e9bd
e9c2 e9c5 e9ca e9cb e9d0 e9d3 e9d7 e9db
e9de e9e1 e9e2 e9e4 e9e5 e9ea e9eb e9f0
e9f2 e9f6 e9f9 e9fb e9ff ea01 ea0d ea0f
ea11 ea12 ea17 ea1b ea1d ea29 ea2b ea2f
ea33 ea36 ea37 ea39 ea3c ea3f ea40 ea45
ea49 ea4d ea51 ea55 ea59 ea5d ea61 ea65
ea69 ea75 ea79 ea7e ea82 ea85 ea86 ea8b
ea8f ea93 ea96 ea99 ea9d ea9f eaa3 eaa7
eaaa eaad eab1 eab3 eab7 eabb eabe eac0
1 eac4 eac8 eacc eacf ead3 ead7 eadb
eadf eae2 eae6 eaea eaed eaf0 eaf5 eaf8
eafb eafe eaff eb04 eb05 1 eb07 eb0c
eb10 eb14 eb17 eb1c eb21 eb24 eb28 eb29
eb2e eb31 eb36 eb37 eb3c eb3f eb44 eb45
eb4a eb4d eb51 eb52 eb57 eb5a eb5f eb60
eb65 eb68 eb6c eb70 eb73 eb76 eb77 eb79
eb7a eb7f eb80 eb85 eb87 eb8b eb8e eb90
eb94 eb96 eba2 eba4 eba6 eba7 ebac ebb0
ebb2 ebbe ebc0 ebc2 ebc6 ebc9 ebcb ebcf
ebd2 ebd6 ebd9 ebdd ebe1 ebe4 ebe5 ebea
ebed ebf1 ebf5 ebf9 ebfd ec01 ec05 ec09
ec0d ec11 ec1d ec21 ec26 ec2a ec2d ec2e
ec33 ec37 ec3b ec3e ec41 ec45 ec47 ec4b
ec4f ec52 ec55 ec59 ec5b ec5f ec63 ec66
ec68 1 ec6c ec70 ec74 ec77 ec7b ec7f
ec83 ec87 ec8a ec8e ec92 ec95 ec98 ec9d
eca0 eca3 eca6 eca7 ecac ecad 1 ecaf
ecb4 ecb8 ecbc ecbf ecc4 ecc9 eccc ecd0
ecd1 ecd6 ecd9 ecde ecdf ece4 ece7 ecec
eced ecf2 ecf5 ecf9 ecfa ecff ed02 ed07
ed08 ed0d ed10 ed14 ed18 ed1b ed1e ed1f
ed21 ed22 ed27 ed28 ed2d ed2f ed33 ed36
ed38 ed3c ed3e ed4a ed4c ed4e ed4f ed54
ed58 ed5a ed66 ed68 ed6c ed70 ed73 ed74
ed76 ed79 ed7c ed7d ed82 ed86 ed8a ed8e
ed92 ed96 ed9a ed9e edaa edae edb2 edb5
edb9 edbd edbf 1 edc3 edc7 edcb edce
edd2 edd6 edda edde ede1 ede5 ede9 edec
edef edf4 edf7 edfa edfd edfe ee03 ee04
1 ee06 ee0b ee0f ee13 ee16 ee1b ee20
ee23 ee27 ee28 ee2d ee30 ee35 ee36 ee3b
ee3e ee43 ee44 ee49 ee4c ee50 ee51 ee56
ee59 ee5e ee5f ee64 ee67 ee6b ee6f ee72
ee75 ee76 ee78 ee79 ee7e ee7f ee84 ee86
ee8a ee8d ee8f ee93 ee95 eea1 eea3 eea5
eea6 eeab eeaf eeb1 eebd eebf eec3 eec7
eeca eecb eecd eed0 eed3 eed4 eed9 eedd
eee1 eee5 eee9 eeed eef1 eef5 eef9 ef05
ef09 ef0e ef12 ef15 ef16 ef1b ef1f ef23
ef26 ef29 ef2d ef2f ef33 ef37 ef3a ef3d
ef41 ef43 ef47 ef4b ef4e ef50 1 ef54
ef58 ef5c ef5f ef63 ef67 ef6b ef6f ef72
ef76 ef7a ef7d ef80 ef85 ef88 ef8b ef8e
ef8f ef94 ef95 1 ef97 ef9c efa0 efa4
efa7 efac efb1 efb4 efb8 efb9 efbe efc1
efc6 efc7 efcc efcf efd4 efd5 efda efdd
efe1 efe2 efe7 efea efef eff0 eff5 eff8
effc f000 f003 f006 f007 f009 f00a f00f
f010 f015 f017 f01b f01e f020 f024 f026
f032 f034 f036 f037 f03c f040 f042 f04e
f050 f054 f058 f05c f060 f064 f070 f074
f079 f07d f080 f081 f086 f08a f08e f091
f094 f098 f09a f09e f0a2 f0a5 f0a8 f0ac
f0ae f0b2 f0b6 f0b9 f0bb 1 f0bf f0c3
f0c7 f0ca f0ce f0d2 f0d6 f0da f0dd f0e1
f0e5 f0e8 f0eb f0f0 f0f3 f0f6 f0f9 f0fa
f0ff f100 1 f102 f107 f10b f10f f112
f117 f11c f11f f123 f124 f129 f12c f131
f132 f137 f13a f13f f140 f145 f148 f14c
f14d f152 f155 f15a f15b f160 f163 f167
f16b f16e f171 f172 f174 f175 f17a f17b
f180 f182 f186 f189 f18b f18f f191 f19d
f19f f1a1 f1a2 f1a7 f1ab f1ad f1b9 f1bb
f1bd f1c1 f1c4 f1c6 f1ca f1cd f1d1 f1d5
f1d8 f1d9 f1db f1de f1e1 f1e2 f1e7 f1eb
f1ee f1f2 f1f6 f1fa f1fe f202 f206 f209
f20c f20d f20f f213 f217 f21b f21f f223
f227 f22b f22f f233 f237 f23b f23f f243
f247 f24b f24f f253 f257 f25b f25f f263
f267 f26b f26f f273 f277 f283 f287 f28b
f28e f292 f296 f298 1 f29c f2a0 f2a4
f2a7 f2ab f2af f2b3 f2b7 f2ba f2be f2c2
f2c5 f2c8 f2cd f2d0 f2d3 f2d6 f2d7 f2dc
f2dd 1 f2df f2e4 f2e8 f2ec f2ef f2f4
f2f9 f2fc f300 f301 f306 f309 f30e f30f
f314 f317 f31c f31d f322 f325 f329 f32a
f32f f332 f337 f338 f33d f340 f344 f348
f34b f34e f34f f351 f352 f357 f358 f35d
f35f f363 f366 f368 f36c f36e f37a f37c
f37e f37f f384 f388 f38a f396 f398 f39c
f3a0 f3a3 f3a7 f3aa f3ae f3b1 f3b2 f3b7
f3ba f3be f3c2 f3c5 f3c6 f3c8 f3cb f3ce
f3cf f3d4 f3d8 f3dc f3e0 f3e4 f3e8 f3ec
f3f0 f3f4 f3f8 f3fc f400 f404 f408 f40c
f410 f41c f420 f425 f429 f42c f42d f432
f436 f43a f43d f440 f444 f446 f44a f44e
f451 f454 f458 f45a f45e f462 f465 f467
1 f46b f46f f473 f476 f47a f47e f482
f486 f489 f48d f491 f494 f497 f49c f49f
f4a2 f4a5 f4a6 f4ab f4ac 1 f4ae f4b3
f4b7 f4bb f4be f4c3 f4c8 f4cb f4cf f4d0
f4d5 f4d8 f4dd f4de f4e3 f4e6 f4eb f4ec
f4f1 f4f4 f4f8 f4f9 f4fe f501 f506 f507
f50c f50f f513 f517 f51a f51d f51e f520
f521 f526 f527 f52c f52e f532 f535 f537
f53b f53d f549 f54b f54d f54e f553 f557
f559 f565 f567 f569 f56d f571 f575 f579
f57d f581 f585 f589 f58d f591 f595 f599
f59d f5a1 f5a5 f5a9 f5ad f5b9 f5bd f5c2
f5c6 f5c9 f5ca f5cf f5d3 f5d7 f5da f5dd
f5e1 f5e3 f5e7 f5eb f5ee f5f1 f5f5 f5f7
f5fb f5ff f602 f604 1 f608 f60c f610
f613 f617 f61b f61f f623 f626 f62a f62e
f631 f634 f639 f63c f63f f642 f643 f648
f649 1 f64b f650 f654 f658 f65b f660
f665 f668 f66c f66d f672 f675 f67a f67b
f680 f683 f688 f689 f68e f691 f695 f696
f69b f69e f6a3 f6a4 f6a9 f6ac f6b0 f6b4
f6b7 f6ba f6bb f6bd f6be f6c3 f6c4 f6c9
f6cb f6cf f6d2 f6d4 f6d8 f6da f6e6 f6e8
f6ea f6eb f6f0 f6f4 f6f6 f702 f704 f706
f70a f70e f711 f715 f719 f71c f71f f720
f722 f725 f72a f72b f730 f733 f737 f73a
f73e f742 f746 f749 f74d f751 f755 f759
f75d f761 f765 f769 f76d f771 f775 f776
f778 f77c f77e f782 f785 f787 f78b f78e
f792 f795 f796 f79b f79e f7a1 f7a5 f7a9
f7ac f7b0 f7b4 f7b5 f7b7 f7ba f7bd f7be
f7c3 1 f7c6 f7cb f7cf f7d2 f7d6 f7d8
f7dc f7df f7e1 f7e5 f7e8 f7ea f7ee f7f1
f7f5 f7f9 f7fc f7fd f7ff f802 f805 f806
f80b f80e f812 f815 f816 f81b f81e 1
f821 f826 f82a f82e f831 f832 f834 f837
f83a f83b f840 f844 f848 f84c f850 f854
f858 f85c f860 f864 f868 f874 f878 f87c
f87f f883 f887 f889 1 f88d f891 f895
f898 f89c f8a0 f8a4 f8a8 f8ab f8af f8b3
f8b6 f8b9 f8be f8c1 f8c4 f8c7 f8c8 f8cd
f8ce 1 f8d0 f8d5 f8d9 f8dd f8e0 f8e5
f8ea f8ed f8f1 f8f2 f8f7 f8fa f8ff f900
f905 f908 f90d f90e f913 f916 f91a f91b
f920 f923 f928 f929 f92e f931 f935 f939
f93c f93f f940 f942 f943 f948 f949 f94e
f950 f954 f957 f959 f95d f95f f96b f96d
f96f f970 f975 f979 f97b f987 f989 f98d
f991 f994 f995 f997 f99a f99d f99e f9a3
f9a7 f9ab f9af f9b3 f9b7 f9bb f9bf f9c3
f9c7 f9d3 f9d7 f9dc f9e0 f9e3 f9e4 f9e9
f9ed f9f1 f9f4 f9f7 f9fb f9fd fa01 fa05
fa08 fa0b fa0f fa11 fa15 fa19 fa1c fa1e
1 fa22 fa26 fa2a fa2d fa31 fa35 fa39
fa3d fa40 fa44 fa48 fa4b fa4e fa53 fa56
fa59 fa5c fa5d fa62 fa63 1 fa65 fa6a
fa6e fa72 fa75 fa7a fa7f fa82 fa86 fa87
fa8c fa8f fa94 fa95 fa9a fa9d faa2 faa3
faa8 faab faaf fab0 fab5 fab8 fabd fabe
fac3 fac6 faca face fad1 fad4 fad5 fad7
fad8 fadd fade fae3 fae5 fae9 faec faee
faf2 faf4 fb00 fb02 fb04 fb05 fb0a fb0e
fb10 fb1c fb1e fb22 fb26 fb2a fb2e fb32
fb36 fb3a fb3e fb42 fb4e fb52 fb57 fb5b
fb5e fb5f fb64 fb68 fb6c fb6f fb72 fb76
fb78 fb7c fb80 fb83 fb86 fb8a fb8c fb90
fb94 fb97 fb99 1 fb9d fba1 fba5 fba8
fbac fbb0 fbb4 fbb8 fbbb fbbf fbc3 fbc6
fbc9 fbce fbd1 fbd4 fbd7 fbd8 fbdd fbde
1 fbe0 fbe5 fbe9 fbed fbf0 fbf5 fbfa
fbfd fc01 fc02 fc07 fc0a fc0f fc10 fc15
fc18 fc1d fc1e fc23 fc26 fc2a fc2b fc30
fc33 fc38 fc39 fc3e fc41 fc45 fc49 fc4c
fc4f fc50 fc52 fc53 fc58 fc59 fc5e fc60
fc64 fc67 fc69 fc6d fc6f fc7b fc7d fc7f
fc80 fc85 fc89 fc8b fc97 fc99 fc9b fc9f
fca2 fca4 fca8 fcab fcaf fcb2 fcb6 fcba
fcbe fcc2 fcc6 fcca fccd fcd0 fcd1 fcd3
fcd7 fcdb fcdf fce3 fce7 fceb fcef fcf3
fcf7 fcfb fcff fd03 fd07 fd0b fd0f fd13
fd17 fd1b fd1f fd23 fd27 fd2b fd2f fd33
fd37 fd3b fd47 fd4b fd4f fd52 fd56 fd5a
fd5c 1 fd60 fd64 fd68 fd6b fd6f fd73
fd77 fd7b fd7e fd82 fd86 fd89 fd8c fd91
fd94 fd97 fd9a fd9b fda0 fda1 1 fda3
fda8 fdac fdb0 fdb3 fdb8 fdbd fdc0 fdc4
fdc5 fdca fdcd fdd2 fdd3 fdd8 fddb fde0
fde1 fde6 fde9 fded fdee fdf3 fdf6 fdfb
fdfc fe01 fe04 fe08 fe0c fe0f fe12 fe13
fe15 fe16 fe1b fe1c fe21 fe23 fe27 fe2a
fe2c fe30 fe32 fe3e fe40 fe42 fe43 fe48
fe4c fe4e fe5a fe5c fe60 fe64 fe67 fe6b
fe6e fe72 fe75 fe76 fe7b fe7e fe82 fe86
fe89 fe8a fe8c fe8f fe92 fe93 fe98 fe9c
fea0 fea4 fea8 feac feb0 feb4 feb8 febc
fec0 fec4 fec8 fecc fed0 fed4 fee0 fee4
fee9 feed fef0 fef1 fef6 fefa fefe ff01
ff04 ff08 ff0a ff0e ff12 ff15 ff18 ff1c
ff1e ff22 ff26 ff29 ff2b 1 ff2f ff33
ff37 ff3a ff3e ff42 ff46 ff4a ff4d ff51
ff55 ff58 ff5b ff60 ff63 ff66 ff69 ff6a
ff6f ff70 1 ff72 ff77 ff7b ff7f ff82
ff87 ff8c ff8f ff93 ff94 ff99 ff9c ffa1
ffa2 ffa7 ffaa ffaf ffb0 ffb5 ffb8 ffbc
ffbd ffc2 ffc5 ffca ffcb ffd0 ffd3 ffd7
ffdb ffde ffe1 ffe2 ffe4 ffe5 ffea ffeb
fff0 fff2 fff6 fff9 fffb ffff 10001 1000d
1000f 10011 10012 10017 1001b 1001d 10029 1002b
1002d 10031 10035 10039 1003d 10041 10045 10049
1004d 10051 10055 10059 1005d 10061 10065 10069
1006d 10071 1007d 10081 10086 1008a 1008d 1008e
10093 10097 1009b 1009e 100a1 100a5 100a7 100ab
100af 100b2 100b5 100b9 100bb 100bf 100c3 100c6
100c8 1 100cc 100d0 100d4 100d7 100db 100df
100e3 100e7 100ea 100ee 100f2 100f5 100f8 100fd
10100 10103 10106 10107 1010c 1010d 1 1010f
10114 10118 1011c 1011f 10124 10129 1012c 10130
10131 10136 10139 1013e 1013f 10144 10147 1014c
1014d 10152 10155 10159 1015a 1015f 10162 10167
10168 1016d 10170 10174 10178 1017b 1017e 1017f
10181 10182 10187 10188 1018d 1018f 10193 10196
10198 1019c 1019e 101aa 101ac 101ae 101af 101b4
101b8 101ba 101c6 101c8 101ca 101ce 101d2 101d5
101d9 101dd 101e0 101e3 101e4 101e6 101e9 101ee
101ef 101f4 101f7 101fb 101ff 10202 10203 10205
10208 1020b 1020c 10211 1 10214 10219 1021d
10220 10224 10228 1022c 1022f 10233 10237 1023b
1023f 10243 10247 1024b 1024f 10253 10257 1025b
1025c 1025e 10262 10264 10268 1026b 1026d 10271
10274 10276 1027a 1027d 10281 10285 10289 1028a
1028c 10290 10294 10298 1029b 1029e 102a1 102a2
102a7 102ab 102af 102b2 102b5 102b9 102bb 102bf
102c2 102c6 102ca 102cd 102d1 102d5 102d8 102db
102e0 102e3 102e6 102e9 102ea 102ef 102f0 1
102f2 102f7 102fb 102ff 10302 10307 1030c 1030f
10313 10314 10319 1031c 10321 10322 10327 1032a
1032f 10330 10335 10338 1033c 10340 10344 10348
1034b 1034c 1034e 10353 10354 10356 10357 1035c
1035f 10364 10365 1036a 1036d 10372 10373 10378
1037b 1037f 10380 10385 10388 1038d 1038e 10393
10394 10399 1039b 1039f 103a2 103a6 103aa 103ad
103b1 103b5 103b8 103bc 103c0 103c1 103c6 103c8
103cc 103d0 103d3 103d7 103db 103de 103e2 103e6
103e9 103ec 103f1 103f4 103f7 103fa 103fb 10400
10401 1 10403 10408 1040c 10410 10413 10418
1041d 10420 10424 10425 1042a 1042b 10430 10434
10438 1043b 10440 10445 10448 1044c 10450 10453
10454 10459 1045c 10461 10462 10467 1046a 1046e
10472 10475 10476 1047b 1047c 10481 10483 10487
1048a 1048e 10492 10496 1049a 1049e 104a2 104a6
104aa 104ae 104ba 104bf 104c3 104c7 104cb 104cf
104d1 104d2 104d7 1 104db 104df 104e3 104e6
104ea 104ee 104f2 104f6 104f9 104fd 10501 10504
10507 1050c 1050f 10512 10515 10516 1051b 1051c
1 1051e 10523 10527 1052b 1052e 10533 10538
1053b 1053f 10540 10545 10546 1054b 1054f 10553
10556 1055b 10560 10563 10567 10568 1056d 10570
10575 10576 1057b 1057e 10582 10586 10589 1058c
1058d 1058f 10590 10595 10596 1059b 1059d 105a1
105a4 105a8 105ac 105b0 105b4 105b8 105bc 105c0
105cc 105d1 105d5 105d9 105dd 105e1 105e3 105e7
105e9 105f5 105f7 105f9 105fa 105ff 10603 10605
10611 10615 10617 10618 10621 
4ae5
2
0 1 a 6 d :3 6 14 :3 6
10 :3 6 14 :3 6 15 :3 6 10 :3 6
e :3 6 11 :3 6 c :3 6 b :3 6
11 :3 6 11 :3 6 1d :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 9 12 11 :2 9 :2 4 12 1b
1a :2 12 :2 4 f 18 17 :2 f :2 4
10 19 18 :2 10 :2 4 14 1d 1c
:2 14 :2 4 18 21 20 :2 18 :2 4 18
21 20 :2 18 :2 4 18 21 20 :2 18
:2 4 e 17 16 :2 e :2 4 d 16
15 :2 d :2 4 11 1a 19 :2 11 :2 4
11 1a 19 :2 11 :2 4 :3 11 :2 4 :3 12
:2 4 :3 14 :2 4 :3 15 :2 4 f 18 17
:2 f :2 4 :3 e :2 4 :3 f :2 4 f 18
17 :2 f :2 4 b 14 13 :2 b :2 4
:3 f :2 4 :3 10 :2 4 :3 12 :2 4 :3 13 :2 4
e 17 16 :2 e :2 4 10 19 18
:2 10 :2 4 9 12 11 :2 9 :2 4 13
1c 1b :2 13 :2 4 11 1a 19 :2 11
:2 4 :2 12 21 12 :2 4 :2 c 1b c
:2 4 :2 d 1c d :2 4 :2 a 19 a
:2 4 :2 b 1a b :2 4 :2 e 1d e
:2 4 :2 c 1b c :2 4 :2 b 1a b
:2 4 :2 11 20 11 :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 e 1d e
:2 4 :2 f 1e f :2 4 :2 10 1f 10
:2 4 :2 d 1c d :2 4 :2 f 1e f
:2 4 :2 10 1f 10 :2 4 :2 e 1d e
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 f 1e f
:2 4 :2 f 1e f :2 4 :2 b 1a b
:2 4 :2 c 1b c :2 4 :2 c 1b c
:2 4 :2 16 25 16 :2 4 :2 f 19 f
:2 4 :2 f 19 f :2 4 :2 10 1a 10
:2 4 :2 10 1a 10 :2 4 :2 13 1d 13
:2 4 :2 12 21 12 :2 4 :2 19 28 19
:2 4 :2 19 28 19 :2 4 :2 19 28 19
:2 4 :2 f 1e f :2 4 :2 11 20 11
:2 4 :2 11 20 11 :2 4 :2 d 1c d
:2 4 10 19 18 :2 10 :2 4 11 1a
19 :2 11 :2 4 :2 14 1e 14 :2 4 :2 f
1e f :2 4 14 1d 1c :2 14 :2 4
:2 17 26 17 :2 4 17 20 1f :2 17
:2 4 13 1c 1b :2 13 :2 4 :2 13 22
13 :2 4 :2 14 23 14 :2 4 :3 9 :2 4
:3 9 :2 4 :2 f 19 f :2 4 :2 f 19
f :2 4 :2 f 1e f :2 4 :2 f 1e
f :2 4 :2 f 1e f :2 4 :2 16 25
16 :2 4 :2 11 20 11 :2 4 :2 11 20
11 :2 4 :2 15 24 15 :2 4 :2 10 1f
10 :2 4 :2 14 23 14 :2 4 14 1d
1c :2 14 :2 4 14 1d 1c :2 14 :2 4
18 21 20 :2 18 :2 4 :2 d 26 30
39 44 :2 30 :2 26 25 d :2 4 :2 10
28 10 :2 4 :2 b 23 b 4 7
e 0 :2 7 20 33 10 1d 2e
a :6 7 e 0 :2 7 20 2e 10
1d 2e 3c 49 a 30 a :6 7
e 0 :2 7 11 13 26 28 3b
3d 46 48 56 58 66 68 a
12 19 1b 33 3b 42 44 5c
5e 6d 6f 89 8b a5 a7 bd
bf a c 23 25 2f 31 42
44 52 54 a c 16 18 20
22 2a 2c 37 39 f 17 1a
2f 32 43 10 12 1f 30 32
40 51 53 e 10 24 26 3c
3e 4b 4d e 10 21 2a 32
3b 49 52 60 69 77 80 8d
96 a7 b0 c3 cc e1 ea 105
10e 126 12f 140 149 15b 164 17c
185 198 1a1 1c2 1c4 1ce 13 15
a :5 7 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 56 5c 5f :2 56
6d 85 8 :2 6d d 10 :2 6d 17
1a :2 6d b e :2 6d 13 16 :2 6d
1b 1e :2 6d 2c 2f :2 6d b e
:2 6d 13 16 :2 6d 1b 1e :2 6d 28
2b :2 6d b e :2 6d 13 16 :2 6d
1b 1e :2 6d 2c 2f :2 6d b e
:2 6d 13 16 :2 6d 1b 1e :2 6d 2d
30 :2 6d b e :2 6d 13 16 1f
27 :2 1f 33 :2 16 :2 6d b e :2 6d
13 16 1f 27 :2 1f 31 :2 16 :2 6d
b e :2 6d 13 16 1f 27 :2 1f
34 :2 16 :2 6d b e :2 6d 13 16
1f 27 :2 1f 2f :2 16 :2 6d b e
:2 6d 13 16 1f 27 :2 1f 2e :2 16
:2 6d b e :2 6d 13 16 1f 27
:2 1f 34 :2 16 :2 6d b e :2 6d 13
16 1f 27 :2 1f 34 :2 16 :2 6d b
e :2 6d 13 16 1f 27 :2 1f 40
:2 16 :2 6d b e :2 6d 13 16 1f
27 :2 1f 33 :2 16 :2 6d b e :2 6d
13 16 :2 6d 1b 1e :2 6d 2a 2d
:2 6d 32 35 :2 6d :2 7 4c :2 4 7
:2 11 23 :2 2d 39 3c 4e 51 52
:2 4e :2 23 :3 7 :2 d 12 1e 5f 62
:2 1e :2 7 55 :3 4 11 :2 4 14 :2 4
10 :2 4 12 :2 4 12 :2 4 12 :2 4
12 19 22 2e :2 19 32 :2 3b :2 12
4 8 11 1d :2 8 22 20 :2 2b
:2 20 7 40 e 1a :2 40 1f 1d
:2 28 :2 1d 3f :3 7 15 7 3e :3 4
13 :2 4 14 :2 4 12 :2 4 14 :2 4
15 :2 4 15 :2 4 16 :2 4 9 :3 4
a 16 :2 4 7 e :2 7 :2 10 1c
7 14 7 :2 10 1c 7 :5 4 f
:2 18 4 7 d :3 7 :2 10 1c 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 7 10 19 :2 7 1c
1e :2 1c a :2 14 26 :2 30 3c 40
52 55 56 :2 52 :2 26 :3 a :2 10 15
21 62 65 :2 21 72 75 :2 21 79
7c :2 21 86 89 92 9a :2 a3 :2 92
b6 :2 89 :2 21 be c1 :2 21 c9 cc
:2 21 d1 d4 :2 21 dd e0 :2 21 :2 a
59 :2 7 a :2 14 26 :2 30 3c 3f
51 54 55 :2 51 :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 58 :3 7 :2 12
26 :2 2f 41 4b :2 7 22 :2 4 e
17 1d 29 38 47 52 c 17
1f 2d 3e 4f 5c c 1a 27
:2 7 :2 10 1c 7 4 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
55 58 59 :2 55 :2 29 :3 d :2 13 18
24 65 68 :2 24 75 78 :2 24 7c
7f :2 24 8b 8e :2 24 96 99 :2 24
a5 a8 af b8 bb :2 a8 :2 24 :2 d
5c :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a 7 a :2 14
26 :2 30 3c 40 52 55 56 :2 52
:2 26 :3 a :2 10 15 21 62 65 :2 21
72 75 :2 21 79 7c :2 21 86 89
92 9a :2 a3 :2 92 b6 :2 89 :2 21 be
c1 :2 21 c9 cc :2 21 d1 d4 :2 21
de e1 :2 21 :2 a 59 :2 7 a :2 14
26 :2 30 3c 3f 51 54 55 :2 51
:2 26 :3 a :2 10 15 21 62 65 :2 21
:2 a 58 :3 7 :2 12 26 :2 2f 41 4c
:2 7 35 :3 4 12 4 e 1e c
d 1a :2 7 :2 10 1c 7 4 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 55 58 59 :2 55 :2 29 :3 d
:2 13 18 24 65 68 :2 24 75 78
:2 24 7c 7f :2 24 8b 8e :2 24 96
99 :2 24 a5 a8 af b8 bb :2 a8
:2 24 :2 d 5c :2 a :2 7 :4 13 :2 7 4
:3 1 7 10 1c :2 7 1f 21 :2 1f
a :2 14 26 :2 30 3c 40 52 55
56 :2 52 :2 26 :3 a :2 10 15 21 62
65 :2 21 72 75 :2 21 79 7c :2 21
86 89 92 9a :2 a3 :2 92 b9 :2 89
:2 21 c1 c4 :2 21 cc cf :2 21 d4
d7 :2 21 e4 e7 :2 21 :2 a 59 :2 7
a :2 14 26 :2 30 3c 3f 51 54
55 :2 51 :2 26 :3 a :2 10 15 21 62
65 :2 21 :2 a 58 :3 7 :2 12 26 :2 2f
44 52 :2 7 23 :2 4 e 11 24
27 4a 53 56 6c 75 78 90
93 9d a0 ad b8 c2 c5 c
14 22 2d 39 45 54 c 14
17 1c 2b 31 34 42 45 56
59 66 :2 7 :2 10 1c 7 4 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 55 58 59 :2 55 :2 29 :3 d
:2 13 18 24 65 68 :2 24 75 78
:2 24 7c 7f :2 24 8b 8e :2 24 96
99 :2 24 a5 a8 af b8 bb :2 a8
:2 24 :2 d 5c :2 a :2 7 :4 13 :2 7 4
:3 1 8 :2 11 1c 1a :2 25 :2 1a 7
a :2 14 26 :2 30 3c 40 52 55
56 :2 52 :2 26 :3 a :2 10 15 21 62
65 :2 21 72 75 :2 21 79 7c :2 21
86 89 92 9a :2 a3 :2 92 b6 :2 89
:2 21 be c1 :2 21 c9 cc :2 21 d1
d4 :2 21 de e1 :2 21 :2 a 59 :2 7
a :2 14 26 :2 30 3c 3f 51 54
55 :2 51 :2 26 :3 a :2 10 15 21 62
65 :2 21 :2 a 58 :3 7 :2 12 26 :2 2f
41 4c :2 7 35 :2 4 e 18 2b
37 49 59 67 :2 7 :2 10 1c 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 8 :2 11 1c 1a :2 25
:2 1a 7 a :2 14 26 :2 30 3c 40
52 55 56 :2 52 :2 26 :3 a :2 10 15
21 62 65 :2 21 72 75 :2 21 79
7c :2 21 86 89 92 9a :2 a3 :2 92
b6 :2 89 :2 21 be c1 :2 21 c9 cc
:2 21 d1 d4 :2 21 dd e0 :2 21 :2 a
59 :2 7 a :2 14 26 :2 30 3c 3f
51 54 55 :2 51 :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 58 :3 7 :2 12
26 :2 2f 41 4b :2 7 35 :2 4 e
1b 2a 39 46 :2 7 :2 10 1c 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 7 :2 12 19 24 :2 7
34 36 :2 34 7 14 7 38 :2 4
8 :2 11 1c 1a :2 25 :2 1a 7 a
:2 14 26 :2 30 3c 40 52 55 56
:2 52 :2 26 :3 a :2 10 15 21 62 65
:2 21 72 75 :2 21 79 7c :2 21 86
89 92 9a :2 a3 :2 92 b6 :2 89 :2 21
be c1 :2 21 c9 cc :2 21 d1 d4
:2 21 e1 e4 :2 21 :2 a 59 :2 7 a
:2 14 26 :2 30 3c 3f 51 54 55
:2 51 :2 26 :3 a :2 10 15 21 62 65
:2 21 :2 a 58 :3 7 :2 12 26 :2 2f 41
4f :2 7 35 :3 4 1c :2 4 1c 23
2c 42 :2 23 46 :2 1c :2 4 12 19
22 38 :2 19 3c :2 12 :2 4 1c 23
2c 42 :2 23 46 :2 1c 4 7 10
13 :2 10 a 13 1f :2 a 22 24
:2 22 14 1a 32 42 13 20 31
3b d 1b 28 :2 d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5e 5f :2 5b
:2 2f :3 13 :2 19 1e 2a 6b 6e :2 2a
7b 7e :2 2a 82 85 :2 2a 91 94
:2 2a 9c 9f :2 2a ab ae b5 be
c1 :2 ae :2 2a :2 13 62 :2 10 :2 d :4 19
:2 d a :3 26 7 26 d 16 22
:2 d 25 27 :2 25 14 1a 32 42
13 20 31 3c d 1b 28 :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5b
5e 5f :2 5b :2 2f :3 13 :2 19 1e 2a
6b 6e :2 2a 7b 7e :2 2a 82 85
:2 2a 91 94 :2 2a 9c 9f :2 2a ab
ae b5 be c1 :2 ae :2 2a :2 13 62
:2 10 :2 d :4 19 :2 d a :4 29 26 :2 7
a 13 1f :2 a 22 24 :2 22 d
:2 17 29 :2 33 3f 43 55 58 59
:2 55 :2 29 :3 d :2 13 18 24 65 68
:2 24 75 78 :2 24 7c 7f :2 24 89
8c 95 9d :2 a6 :2 95 c7 :2 8c :2 24
cf d2 :2 24 da dd :2 24 e2 e5
:2 24 ee f1 :2 24 :2 d 5c :2 a d
:2 17 29 :2 33 3f 42 54 57 58
:2 54 :2 29 :3 d :2 13 18 24 65 68
:2 24 :2 d 5b :3 a :2 15 29 :2 32 52
12 :2 a 26 :2 7 15 11 17 2f
3f 10 1d 2e 3c 48 56 67
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
58 5b 5c :2 58 :2 2c :3 10 :2 16 1b
27 68 6b :2 27 78 7b :2 27 7f
82 :2 27 8e 91 :2 27 99 9c :2 27
a8 ab b2 bb be :2 ab :2 27 :2 10
5f :2 d :2 a :4 16 :2 a 7 :3 4 11
17 2f 3f 10 1d 2e 3b 47
55 66 :2 a :2 13 1f a 7 :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 58 5b 5c :2 58 :2 2c :3 10
:2 16 1b 27 68 6b :2 27 78 7b
:2 27 7f 82 :2 27 8e 91 :2 27 99
9c :2 27 a8 ab b2 bb be :2 ab
:2 27 :2 10 5f :2 d :2 a :4 16 :2 a 7
:3 4 b 19 22 2d :2 19 :2 b a
32 35 :2 32 3d 46 52 :2 3d 55
57 :2 55 3c 5e d 19 :2 5e 1c
1e :2 1c 5d :2 3c 3b :2 a 14 1a
32 42 13 20 31 3f 4c 11
:2 d :2 16 22 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5e 5f :2 5b :2 2f :3 13 :2 19 1e
2a 6b 6e :2 2a 7b 7e :2 2a 82
85 :2 2a 91 94 :2 2a 9c 9f :2 2a
ab ae b5 be c1 :2 ae :2 2a :2 13
62 :2 10 :2 d :4 19 :2 d a :3 22 d
16 22 :2 d 25 27 :2 25 10 :2 1a
2c :2 36 42 46 58 5b 5c :2 58
:2 2c :3 10 :2 16 1b 27 68 6b :2 27
78 7b :2 27 7f 82 :2 27 8c 8f
98 a0 :2 a9 :2 98 ca :2 8f :2 27 d2
d5 :2 27 dd e0 :2 27 e5 e8 :2 27
f1 f4 :2 27 :2 10 5f :2 d 10 :2 1a
2c :2 36 42 45 57 5a 5b :2 57
:2 2c :3 10 :2 16 1b 27 68 6b :2 27
:2 10 5e :3 d :2 18 2c :2 35 55 15
:2 d 29 :2 a 22 :2 7 :5 4 12 :2 4
13 :2 4 17 :2 4 1b :2 4 14 :2 4
9 :3 4 a 14 :2 4 7 c :2 7
:2 10 1c 7 12 7 :2 10 1c 7
:4 4 8 :2 11 1c 1a :2 25 :2 1a :2 7
15 7 35 7 15 7 :4 4 7
d :3 7 :2 10 1c 7 4 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 55 58 59 :2 55 :2 29 :3 d :2 13
18 24 65 68 :2 24 75 78 :2 24
7c 7f :2 24 8b 8e :2 24 96 99
:2 24 a5 a8 af b8 bb :2 a8 :2 24
:2 d 5c :2 a :2 7 :4 13 :2 7 4 :3 1
7 10 1c :2 7 1f 21 :2 1f 11
17 2f 3c 53 60 a 18 25
3d 47 :2 a :2 13 1f a 7 :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 58 5b 5c :2 58 :2 2c :3 10
:2 16 1b 27 68 6b :2 27 78 7b
:2 27 7f 82 :2 27 8e 91 :2 27 99
9c :2 27 a8 ab b2 bb be :2 ab
:2 27 :2 10 5f :2 d :2 a :4 16 :2 a 7
:3 23 a 13 1c :2 a 1f 21 :2 1f
a 18 a 14 23 37 46 12
29 36 47 d 1b 28 40 4a
:2 d :2 16 22 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5e 5f :2 5b :2 2f :3 13 :2 19 1e
2a 6b 6e :2 2a 7b 7e :2 2a 82
85 :2 2a 91 94 :2 2a 9c 9f :2 2a
ab ae b5 be c1 :2 ae :2 2a :2 13
62 :2 10 :2 d :4 19 :2 d a :3 23 e
:2 17 22 20 :2 2b :2 20 d 10 :2 1a
2c :2 36 42 46 58 5b 5c :2 58
:2 2c :3 10 :2 16 1b 27 68 6b :2 27
78 7b :2 27 7f 82 :2 27 8c 8f
98 a0 :2 a9 :2 98 ca :2 8f :2 27 d2
d5 :2 27 dd e0 :2 27 e5 e8 :2 27
f1 f4 :2 27 :2 10 5f :2 d 10 :2 1a
2c :2 36 42 45 57 5a 5b :2 57
:2 2c :3 10 :2 16 1b 27 68 6b :2 27
:2 10 5e :3 d :2 18 2c :2 35 55 15
:2 d a 3b :4 12 11 10 :4 34 33
32 :2 10 11 :2 1c 24 33 41 :2 11
45 47 :2 45 10 4e :2 59 61 15
23 :2 4e 27 29 :2 27 4d :2 10 13
:2 1d 2f :2 39 45 49 5b 5e 5f
:2 5b :2 2f :3 13 :2 19 1e 2a 6b 6e
:2 2a 7b 7e :2 2a 82 85 :2 2a 8f
92 9b a3 :2 ac :2 9b cd :2 92 :2 2a
d5 d8 :2 2a e0 e3 :2 2a e8 eb
:2 2a f4 f7 :2 2a :2 13 62 :2 10 13
:2 1d 2f :2 39 45 48 5a 5d 5e
:2 5a :2 2f :3 13 :2 19 1e 2a 6b 6e
:2 2a :2 13 61 :3 10 :2 1b 2f :2 38 58
18 :2 10 2c :2 d 51 3b :2 a 23
:2 7 a 13 1f :2 a 22 24 :2 22
a 18 :2 a 21 a 26 14 27
38 49 12 13 20 11 21 11
1f :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5e 5f :2 5b :2 2f :3 13 :2 19
1e 2a 6b 6e :2 2a 7b 7e :2 2a
82 85 :2 2a 91 94 :2 2a 9c 9f
:2 2a ab ae b5 be c1 :2 ae :2 2a
:2 13 62 :2 10 :2 d :4 19 :2 d a :3 7
e :2 17 22 20 :2 2b :2 20 :2 d 20
:2 d :3 20 :2 d 20 2e 31 3a 42
:2 31 46 :2 4f 24 :2 20 :2 d 23 :2 2c
:2 d 20 :2 d 1f :2 d 20 37 45
4f 57 2d 41 52 :2 20 :2 d 1d
26 2f 37 :2 26 :2 1d d 1c 31
44 50 5c 10 1f 2c 38 45
52 10 1a 18 29 37 45 10
1c 26 34 3d 4a 5e 10 1d
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5e 61 62 :2 5e :2 32
:3 16 :2 1c 21 2d 6e 71 :2 2d 7e
81 :2 2d 85 88 :2 2d 94 97 :2 2d
9f a2 :2 2d ae b1 b8 c1 c4
:2 b1 :2 2d :2 16 65 :2 13 :2 10 :4 1c :2 10
d :3 3b 17 29 3d 4c 59 :2 10
:2 19 25 10 d :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5e
61 62 :2 5e :2 32 :3 16 :2 1c 21 2d
6e 71 :2 2d 7e 81 :2 2d 85 88
:2 2d 94 97 :2 2d 9f a2 :2 2d ae
b1 b8 c1 c4 :2 b1 :2 2d :2 16 65
:2 13 :2 10 :4 1c :2 10 d :3 3b 10 :2 1b
22 30 :2 10 3b 3d :2 3b 10 1b
10 3f 1a 20 38 45 19 26
37 42 50 68 76 87 :2 13 :2 1c
28 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 64
65 :2 61 :2 35 :3 19 :2 1f 24 30 71
74 :2 30 81 84 :2 30 88 8b :2 30
97 9a :2 30 a2 a5 :2 30 b1 b4
bb c4 c7 :2 b4 :2 30 :2 19 68 :2 16
:2 13 :4 1f :2 13 10 :7 d 10 19 22
:2 10 25 27 :2 25 1a 26 35 3e
4c 5c 19 26 37 44 13 1a
16 22 :3 20 16 :2 1f 2b 16 27
16 :2 1f 2b 16 :4 13 10 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 61 64 65 :2 61 :2 35 :3 19 :2 1f
24 30 71 74 :2 30 81 84 :2 30
88 8b :2 30 97 9a :2 30 a2 a5
:2 30 b1 b4 bb c4 c7 :2 b4 :2 30
:2 19 68 :2 16 :2 13 :4 1f :2 13 10 :3 29
1a 26 18 1f 2d 4a 18 1f
2e 35 4f 18 28 19 26 37
44 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 64 65 :2 61
:2 35 :3 19 :2 1f 24 30 71 74 :2 30
81 84 :2 30 88 8b :2 30 97 9a
:2 30 a2 a5 :2 30 b1 b4 bb c4
c7 :2 b4 :2 30 :2 19 68 :2 16 :2 13 :4 1f
:2 13 10 :4 29 1a 26 18 1f 2d
4a 18 1f 2e 35 4f 18 28
19 26 37 44 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 61
64 65 :2 61 :2 35 :3 19 :2 1f 24 30
71 74 :2 30 81 84 :2 30 88 8b
:2 30 97 9a :2 30 a2 a5 :2 30 b1
b4 bb c4 c7 :2 b4 :2 30 :2 19 68
:2 16 :2 13 :4 1f :2 13 10 :7 d a 3b
11 :2 1a 25 23 :2 2e :2 23 10 17
2e 47 16 2a 3e :2 10 :2 19 25
10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 61 62
:2 5e :2 32 :3 16 :2 1c 21 2d 6e 71
:2 2d 7e 81 :2 2d 85 88 :2 2d 94
97 :2 2d 9f a2 :2 2d ae b1 b8
c1 c4 :2 b1 :2 2d :2 16 65 :2 13 :2 10
:4 1c :2 10 d :3 3e 10 19 22 :2 10
27 25 :2 30 :2 25 10 23 31 34
3d 45 :2 34 49 :2 52 24 :2 23 10
1a 33 40 13 21 2a 37 45
19 2d 13 1a 16 22 :3 20 16
:2 1f 2b 16 27 16 :2 1f 2b 16
:4 13 10 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 64 65
:2 61 :2 35 :3 19 :2 1f 24 30 71 74
:2 30 81 84 :2 30 88 8b :2 30 97
9a :2 30 a2 a5 :2 30 b1 b4 bb
c4 c7 :2 b4 :2 30 :2 19 68 :2 16 :2 13
:4 1f :2 13 10 :3 3f 10 23 39 :2 23
10 d 3f 14 1b 24 2d :2 1b
31 :2 3a :2 14 13 4b 48 :2 54 :2 48
1a 33 40 13 1f 28 2f 3c
45 19 2d 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 64
65 :2 61 :2 35 :3 19 :2 1f 24 30 71
74 :2 30 81 84 :2 30 88 8b :2 30
97 9a :2 30 a2 a5 :2 30 b1 b4
bb c4 c7 :2 b4 :2 30 :2 19 68 :2 16
:2 13 :4 1f :2 13 10 :3 60 10 23 39
:2 23 10 60 3f 1a 33 40 13
1f 28 2f 3c 45 19 2d 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 64 65 :2 61 :2 35 :3 19
:2 1f 24 30 71 74 :2 30 81 84
:2 30 88 8b :2 30 97 9a :2 30 a2
a5 :2 30 b1 b4 bb c4 c7 :2 b4
:2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13 10
:3 d 10 23 39 :2 23 10 :4 d 3e
3b :2 a :4 7 23 7 1e 7 :5 4
13 :2 4 14 :2 4 15 :2 4 :3 17 4
8 11 27 :2 8 2a 2c :2 2a 7
33 3c 52 :2 33 55 57 :2 55 32
:3 7 1a 2b 39 43 4f 5c 27
34 40 4d 59 :2 1a 7 5a :2 4
18 28 2b c 1d 28 32 35
:2 c 16 19 1e 2d 33 36 44
47 56 59 d 19 :2 7 :2 10 1c
7 4 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 55 58 59
:2 55 :2 29 :3 d :2 13 18 24 65 68
:2 24 75 78 :2 24 7c 7f :2 24 8b
8e :2 24 96 99 :2 24 a5 a8 af
b8 bb :2 a8 :2 24 :2 d 5c :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1d 1a
:2 26 :2 1a :2 7 19 7 36 :3 4 10
:2 4 f :2 4 1b 4 e 28 4a
56 c 22 2f :2 7 :2 10 1c 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 7 :2 12 19 27 :2 7
32 35 :2 32 11 15 25 32 10
1d 2e 38 49 57 :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5b 5c
:2 58 :2 2c :3 10 :2 16 1b 27 68 6b
:2 27 78 7b :2 27 7f 82 :2 27 8e
91 :2 27 99 9c :2 27 a8 ab b2
bb be :2 ab :2 27 :2 10 5f :2 d :2 a
:4 16 :2 a 7 :3 37 a 13 1c :2 a
1f 21 :2 1f a 17 a 23 a
15 a :4 7 37 :2 4 7 10 1c
:2 7 1f 21 :2 1f a :2 15 1c 2a
:2 a 35 37 :2 35 14 26 38 46
4e 55 6d 75 7c 95 9f d
1b 29 32 3d 47 4f 57 12
27 2d 3f 4a 56 62 d 19
25 30 41 49 52 5a 12 13
1d 2e 3c 4d :2 d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5e 5f :2 5b
:2 2f :3 13 :2 19 1e 2a 6b 6e :2 2a
7b 7e :2 2a 82 85 :2 2a 91 94
:2 2a 9c 9f :2 2a ab ae b5 be
c1 :2 ae :2 2a :2 13 62 :2 10 :2 d :4 19
:2 d a :3 39 a 21 :2 a 1f a
d 16 22 :2 d 25 27 :2 25 11
1a 25 :2 11 2b 28 34 40 :2 2b
:2 28 10 48 51 59 :2 48 5f 5c
28 31 :2 5f :2 5c 47 :2 10 14 1d
29 :2 14 2c 2e :2 2c 13 37 3e
16 22 :2 3e 26 :2 2f :2 37 36 3d
40 :2 3d 35 :2 13 16 :2 20 32 :2 3c
48 4c 5e 61 62 :2 5e :2 32 :3 16
:2 1c 21 2d 6e 71 :2 2d 7e 81
:2 2d 85 88 :2 2d 92 95 9e a6
:2 af :2 9e c7 :2 95 :2 2d cf d2 :2 2d
da dd :2 2d e2 e5 :2 2d ee f1
:2 2d :2 16 65 :2 13 16 :2 20 32 :2 3c
48 4b 5d 60 61 :2 5d :2 32 :3 16
:2 1c 21 2d 6e 71 :2 2d :2 16 64
:3 13 :2 1e 32 :2 3b 52 5c :2 13 43
13 28 13 16 1f 2b :2 16 2e
30 :2 2e 16 29 16 32 :2 13 :4 10
35 :3 d 19 :2 d 1d :2 d 1e :2 d
17 :2 d 1d :2 d 18 :2 d 17 :2 d
1a :2 d 1a d 29 :2 a e :2 17
22 20 :2 2b :2 20 d :4 41 40 3f
:2 d 10 17 27 2a :2 10 2d 2f
:2 2d 10 20 21 :2 20 :2 10 :2 19 25
3c 4a 58 2f 3a 46 52 2f
3d 50 :2 25 10 33 :2 d 10 19
25 :2 10 28 2a :2 28 1f 36 4a
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 64 65 :2 61 :2 35
:3 19 :2 1f 24 30 71 74 :2 30 81
84 :2 30 88 8b :2 30 97 9a :2 30
a2 a5 :2 30 b1 b4 bb c4 c7
:2 b4 :2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13
10 :3 2c 1f 36 43 54 68 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 65 66 :2 61 :2 35 :3 19
:2 1f 24 30 72 75 :2 30 82 85
:2 30 89 8c :2 30 98 9b :2 30 a3
a6 :2 30 b2 b5 bc c5 c8 :2 b5
:2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13 10
:3 2c 10 27 10 1a 1e 2d 3c
19 26 37 4b :2 13 :2 1c 28 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 65 66 :2 61
:2 35 :3 19 :2 1f 24 30 72 75 :2 30
82 85 :2 30 89 8c :2 30 98 9b
:2 30 a3 a6 :2 30 b2 b5 bc c5
c8 :2 b5 :2 30 :2 19 69 :2 16 :2 13 :4 1f
:2 13 10 :3 2c 13 :2 1e 26 34 3f
:2 13 43 46 :2 43 1d 28 35 3d
44 61 6c 71 :2 1b :2 16 :2 1f 2b
16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 64 68 69
:2 64 :2 38 :3 1c :2 22 27 33 75 78
:2 33 85 88 :2 33 8c 8f :2 33 9b
9e :2 33 a6 a9 :2 33 b5 b8 bf
c8 cb :2 b8 :2 33 :2 1c 6c :2 19 :2 16
:4 22 :2 16 13 :4 48 :2 10 2c 14 1d
33 :2 14 36 38 :2 36 13 40 49
5f :2 40 62 64 :2 62 3f :3 13 21
2a 36 :2 21 39 3b 44 54 :2 3b
:2 21 :2 13 22 2b 38 :2 22 3b 3d
46 56 :2 3d :2 22 :2 13 21 2a 36
:2 21 39 3b 44 54 :2 3b :2 21 :2 13
22 2b 38 :2 22 3b 3d 46 56
:2 3d :2 22 13 16 1f 2b :2 16 2e
30 :2 2e 20 35 49 19 27 31
19 28 19 28 19 28 19 28
19 2f 4a 59 19 33 40 55
19 27 30 37 44 4d 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 78 7b :2 36 88
8b :2 36 8f 92 :2 36 9e a1 :2 36
a9 ac :2 36 b8 bb c2 cb ce
:2 bb :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :4 32 20 35 49 19 27 31
19 28 19 28 19 28 19 28
19 2f 4a 59 19 33 40 55
19 36 43 5a 19 27 30 37
44 4d 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 67
6b 6c :2 67 :2 3b :3 1f :2 25 2a 36
78 7b :2 36 88 8b :2 36 8f 92
:2 36 9e a1 :2 36 a9 ac :2 36 b8
bb c2 cb ce :2 bb :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :7 13 10 67
16 1f 35 :2 16 38 3a :2 38 13
21 2a 36 :2 21 39 3b 44 54
:2 3b :2 21 :2 13 22 2b 38 :2 22 3b
3d 46 56 :2 3d :2 22 13 1d 32
46 16 24 2e 16 25 16 25
16 2c 47 56 16 30 3d 52
16 24 2d 34 41 4a 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 68 69 :2 64 :2 38
:3 1c :2 22 27 33 75 78 :2 33 85
88 :2 33 8c 8f :2 33 9b 9e :2 33
a6 a9 :2 33 b5 b8 bf c8 cb
:2 b8 :2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16
13 :3 3c 10 3c 67 16 1f 35
:2 16 38 3a :2 38 13 21 2a 36
:2 21 39 3b 44 54 :2 3b :2 21 :2 13
22 2b 38 :2 22 3b 3d 46 56
:2 3d :2 22 13 16 1f 2b :2 16 2e
30 :2 2e 20 35 49 19 27 31
19 28 19 28 19 2f 4a 59
19 27 30 37 44 4d 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 78 7b :2 36 88
8b :2 36 8f 92 :2 36 9e a1 :2 36
a9 ac :2 36 b8 bb c2 cb ce
:2 bb :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :4 32 20 35 49 19 27 31
19 28 19 28 19 2f 4a 59
19 36 43 5a 19 27 30 37
44 4d 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 67
6b 6c :2 67 :2 3b :3 1f :2 25 2a 36
78 7b :2 36 88 8b :2 36 8f 92
:2 36 9e a1 :2 36 a9 ac :2 36 b8
bb c2 cb ce :2 bb :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :7 13 3c 67
1d 32 46 16 2c 47 56 16
24 2e 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 64
68 69 :2 64 :2 38 :3 1c :2 22 27 33
75 78 :2 33 85 88 :2 33 8c 8f
:2 33 9b 9e :2 33 a6 a9 :2 33 b5
b8 bf c8 cb :2 b8 :2 33 :2 1c 6c
:2 19 :2 16 :4 22 :2 16 13 :7 10 1f 36
43 54 68 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 65
66 :2 61 :2 35 :3 19 :2 1f 24 30 72
75 :2 30 82 85 :2 30 89 8c :2 30
98 9b :2 30 a3 a6 :2 30 b2 b5
bc c5 c8 :2 b5 :2 30 :2 19 69 :2 16
:2 13 :4 1f :2 13 10 :3 d 1f 1a 2f
39 4f 5e 73 87 18 35 49
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 72 75 :2 30 82
85 :2 30 89 8c :2 30 98 9b :2 30
a3 a6 :2 30 b2 b5 bc c5 c8
:2 b5 :2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13
10 :8 d 18 d 1c 37 4b 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 6f 72 :2 2d 7f 82
:2 2d 86 89 :2 2d 95 98 :2 2d a0
a3 :2 2d af b2 b9 c2 c5 :2 b2
:2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10 d
:3 63 1c 36 43 54 62 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 6f 72 :2 2d 7f 82 :2 2d
86 89 :2 2d 95 98 :2 2d a0 a3
:2 2d af b2 b9 c2 c5 :2 b2 :2 2d
:2 16 66 :2 13 :2 10 :4 1c :2 10 d :3 63
11 1a 26 :2 11 29 2b :2 29 10
33 3c 48 :2 33 4b 4d :2 4b 32
:3 10 1f :2 10 19 10 13 :2 1c 27
3a :2 13 3d 40 :2 3d 13 1f 13
42 13 1f 13 :4 10 13 1c 28
:2 13 2b 2d :2 2b 13 1d 13 2f
:3 10 1e 2f 3b 48 51 5a :2 48
5e 67 6f :2 5e 22 2b 37 :2 22
3b 44 4f :2 3b 53 20 2b :2 53
2f 38 46 :2 2f 4a 53 5e :2 4a
22 2b 37 :2 22 3b 43 4d :2 1e
10 13 1c 28 :2 13 2d 2b :2 36
:2 2b 16 :2 20 32 :2 3c 48 4b 5d
61 62 :2 5d :2 32 :3 16 :2 1c 21 2d
70 73 :2 2d 80 83 :2 2d 87 8a
:2 2d 94 97 a0 a8 :2 b1 :2 a0 c2
:2 97 :2 2d :2 16 65 :2 13 16 :2 20 32
:2 3c 48 4b 5d 61 62 :2 5d :2 32
:3 16 :2 1c 21 2d 70 73 :2 2d :2 16
65 :3 13 :2 1e 34 :2 3d 4d :2 13 10
45 16 1f 2b :2 16 2e 31 :2 2e
16 :2 20 32 :2 3c 48 4c 5e 62
63 :2 5e :2 32 :3 16 :2 1c 21 2d 70
73 :2 2d 80 83 :2 2d 87 8a :2 2d
94 97 a0 a8 :2 a0 b5 :2 97 :2 2d
bd c0 :2 2d c8 cb :2 2d d0 d3
:2 2d e0 e3 :2 2d :2 16 66 :2 13 16
:2 20 32 :2 3c 48 4b 5d 61 62
:2 5d :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d :2 16 65 :3 13 :2 1e 32 3b 47
:2 32 4b 59 :2 13 33 45 :2 10 13
1c 24 :2 13 27 29 :2 27 13 20
:2 29 13 2b 13 20 :2 29 30 39
44 :2 30 48 :2 51 :2 20 13 :5 10 23
:2 10 1c 28 3d 4b 59 63 1b
23 2f 3b 47 53 1b 2a 36
40 48 51 59 1b 27 33 40
4b 56 1b 25 30 3c 48 4b
4e 54 :2 1c 10 13 1c 26 :2 13
29 2b :2 29 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 94 97 a0 a8 :2 b1
:2 a0 c8 :2 97 :2 2d d0 d3 :2 2d db
de :2 2d e3 e6 :2 2d ef f2 :2 2d
:2 16 66 :2 13 16 :2 20 32 :2 3c 48
4b 5d 61 62 :2 5d :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d :2 16 65 :3 13
:2 1e 32 :2 3b 51 5b :2 13 10 2f
16 1f 29 :2 16 2c 2f :2 2c 16
:2 20 32 :2 3c 48 4c 5e 62 63
:2 5e :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 94
97 a0 a8 :2 b1 :2 a0 c9 :2 97 :2 2d
d1 d4 :2 2d dc df :2 2d e4 e7
:2 2d f7 fa :2 2d :2 16 66 :2 13 16
:2 20 32 :2 3c 48 4b 5d 61 62
:2 5d :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d :2 16 65 :3 13 :2 1e 32 :2 3b 52
1b :2 13 31 2f 13 21 :2 13 21
31 3f 54 60 69 74 :2 60 21
2a 34 :4 21 13 :4 10 50 :2 d 63
:2 a 7 39 d 14 24 27 :2 d
2a 2c :2 2a 14 27 2f 36 4e
56 5d 76 80 91 9f 12 27
32 3e 4a 5d 69 12 13 20
31 3b 11 29 37 :2 d :2 16 22
d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5f 60
:2 5b :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a 7d 80 :2 2a 84 87 :2 2a 93
96 :2 2a 9e a1 :2 2a ad b0 b7
c0 c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d
:4 19 :2 d a :3 30 e :2 17 22 20
:2 2b :2 20 d :4 41 40 3f :3 d 1d
1e :2 1d :2 d :2 16 22 39 47 55
2f 3a 46 52 2f 3d 50 :2 22
d 63 :2 a 30 39 14 27 35
4a 12 13 20 31 3b 11 1f
30 :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5f 60 :2 5b :2 2f :3 13 :2 19
1e 2a 6d 70 :2 2a 7d 80 :2 2a
84 87 :2 2a 93 96 :2 2a 9e a1
:2 2a ad b0 b7 c0 c3 :2 b0 :2 2a
:2 13 63 :2 10 :2 d :4 19 :2 d a :7 7
4 23 a 11 21 24 :2 a 27
29 :2 27 11 24 2c 33 4b 53
5a 73 7d 8e 9c f 24 2f
3b 47 5a 66 f 10 1d 2e
38 e 1c 2d :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 58 5c 5d :2 58
:2 2c :3 10 :2 16 1b 27 6a 6d :2 27
7a 7d :2 27 81 84 :2 27 90 93
:2 27 9b 9e :2 27 aa ad b4 bd
c0 :2 ad :2 27 :2 10 60 :2 d :2 a :4 16
:2 a 7 :3 2d b :2 14 1f 1d :2 28
:2 1d a :4 3e 3d 3c :3 a 1a 1b
:2 1a :2 a :2 13 1f 36 44 52 2f
3a 46 52 2f 3d 50 :2 1f a
60 :2 7 2d 23 11 24 32 47
f 10 1d 2e 38 e 1c 2d
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
58 5c 5d :2 58 :2 2c :3 10 :2 16 1b
27 6a 6d :2 27 7a 7d :2 27 81
84 :2 27 90 93 :2 27 9b 9e :2 27
aa ad b4 bd c0 :2 ad :2 27 :2 10
60 :2 d :2 a :4 16 :2 a 7 :7 4 :4 9
8 7 2c 35 41 :2 2c 44 46
:2 44 2b :2 7 4e a 16 :2 4e 19
1b :2 19 4d :3 7 1e :2 7 :3 1e 7
a 13 19 :2 a 1c 1e :2 1c a
1d 26 2e :2 1d a 22 :2 7 b
14 2a :2 b 2d 2f :2 2d a 36
3f 55 :2 36 58 5a :2 58 35 :2 a
e 17 2d :2 e 30 32 :2 30 d
3a 43 59 :2 3a 5c 5e :2 5c 39
:3 d 1b 24 30 :2 1b 33 35 3e
4e :2 35 :2 1b :2 d 1c 25 32 :2 1c
35 37 40 50 :2 37 :2 1c :2 d 1b
24 30 :2 1b 33 35 3e 4e :2 35
:2 1b :2 d 1c 25 32 :2 1c 35 37
40 50 :2 37 :2 1c d 1c 2d 3f
51 59 64 67 6a 73 10 1f
2f 39 47 56 62 70 10 1a
2b 38 45 52 60 6f 7e 17
2c 3d 4b 59 62 68 71 77
83 10 1c 2e 3a 47 50 5c
10 1c 2e 39 45 50 5c 6d
7e 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 62 63 :2 5e
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
80 83 :2 2d 87 8a :2 2d 96 99
:2 2d a1 a4 :2 2d b0 b3 ba c3
c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c
:2 10 d :3 61 a 61 10 19 2f
:2 10 32 34 :2 32 d 1b 24 30
:2 1b 33 35 3e 4e :2 35 :2 1b :2 d
1c 25 32 :2 1c 35 37 40 50
:2 37 :2 1c d 1c 2d 3f 51 59
64 67 6a 73 10 1f 2f 39
47 56 62 70 10 1a 2b 38
45 52 60 6f 7e 17 2c 3d
4b 59 62 68 71 77 83 10
1c 2e 3a 47 50 5c 10 1c
2e 39 45 50 5d 6e 7f 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 96 99 :2 2d a1
a4 :2 2d b0 b3 ba c3 c6 :2 b3
:2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10 d
:4 36 61 d 1b 24 30 :2 1b 33
35 3e 4e :2 35 :2 1b :2 d 1c 25
32 :2 1c 35 37 40 50 :2 37 :2 1c
d 1c 2d 3f 51 59 64 67
6a 73 10 1f 2f 39 47 56
62 70 10 1a 2b 38 45 52
60 6f 7e 17 2c 3d 4b 59
62 68 71 77 83 10 1c 2e
3a 47 50 5c 10 1c 2e 39
45 50 5d 6e 7f 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 62 63 :2 5e :2 32 :3 16 :2 1c 21
2d 70 73 :2 2d 80 83 :2 2d 87
8a :2 2d 96 99 :2 2d a1 a4 :2 2d
b0 b3 ba c3 c6 :2 b3 :2 2d :2 16
66 :2 13 :2 10 :4 1c :2 10 d :7 a 5d
19 2a 3c 4e 56 61 64 67
70 d 1b 2a 33 40 4e 5a
68 d 17 28 35 42 4f 5d
6c 7b 14 29 3a 48 56 5f
65 6e 74 80 d 19 2b 37
44 4d 59 d 19 2b 36 42
4d 5a 6b 7c d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5b
5f 60 :2 5b :2 2f :3 13 :2 19 1e 2a
6d 70 :2 2a 7d 80 :2 2a 84 87
:2 2a 93 96 :2 2a 9e a1 :2 2a ad
b0 b7 c0 c3 :2 b0 :2 2a :2 13 63
:2 10 :2 d :4 19 :2 d a :8 7 12 7
1e :3 4 e 15 1c 1f :2 15 24
27 :2 e :2 4 1b :2 4 10 4 e
20 34 43 50 :2 7 :2 10 1c 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 59 5a :2 55
:2 29 :3 d :2 13 18 24 67 6a :2 24
77 7a :2 24 7e 81 :2 24 8d 90
:2 24 98 9b :2 24 a7 aa b1 ba
bd :2 aa :2 24 :2 d 5d :2 a :2 7 :4 13
:2 7 4 :3 1 4 12 :2 4 12 :2 4
f 4 8 11 13 :2 11 7 1b
24 30 :2 1b 33 35 :2 33 1a :2 7
11 15 17 2b f 17 1a 2b
10 12 1f 30 32 40 a c
16 18 27 29 35 3e 46 4f
5d 66 74 7d 8b 94 a1 aa
bb c4 d7 e0 f5 fe 119 122
13a 143 154 15d 16f 178 190 199
1ac 1b5 1d6 1d8 1e2 :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5c 5d
:2 58 :2 2c :3 10 :2 16 1b 27 6a 6d
:2 27 7a 7d :2 27 81 84 :2 27 90
93 :2 27 9b 9e :2 27 aa ad b4
bd c0 :2 ad :2 27 :2 10 60 :2 d :2 a
:4 16 :2 a 7 :4 38 :3 4 14 :2 4 9
:4 4 d 16 23 38 43 4b 55
7 c 11 21 32 7 1c 27
39 44 7 f 18 20 2b :3 7
a e :2 a :2 13 1f a 14 a
:2 13 1f a :4 7 b :2 14 20 1d
:2 29 :2 1d :3 a 39 :2 7 a 13 1d
:2 a 20 22 :2 20 a 1d 34 41
:2 1d a 19 34 48 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5f 60 :2 5b :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a 7d 80 :2 2a 84
87 :2 2a 93 96 :2 2a 9e a1 :2 2a
ad b0 b7 c0 c3 :2 b0 :2 2a :2 13
63 :2 10 :2 d :4 19 :2 d a :3 24 19
30 44 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5f 60
:2 5b :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a 7d 80 :2 2a 84 87 :2 2a 93
96 :2 2a 9e a1 :2 2a ad b0 b7
c0 c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d
:4 19 :2 d a :3 24 19 2b 3f d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5b 5f 60 :2 5b :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a 7d 80
:2 2a 84 87 :2 2a 93 96 :2 2a 9e
a1 :2 2a ad b0 b7 c0 c3 :2 b0
:2 2a :2 13 63 :2 10 :2 d :4 19 :2 d a
:3 24 19 30 3d 4e 62 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5f 60 :2 5b :2 2f :3 13 :2 19
1e 2a 6d 70 :2 2a 7d 80 :2 2a
84 87 :2 2a 93 96 :2 2a 9e a1
:2 2a ad b0 b7 c0 c3 :2 b0 :2 2a
:2 13 63 :2 10 :2 d :4 19 :2 d a :3 24
19 35 49 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5f
60 :2 5b :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
93 96 :2 2a 9e a1 :2 2a ad b0
b7 c0 c3 :2 b0 :2 2a :2 13 63 :2 10
:2 d :4 19 :2 d a :3 24 19 36 4a
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5b 5f 60 :2 5b :2 2f
:3 13 :2 19 1e 2a 6d 70 :2 2a 7d
80 :2 2a 84 87 :2 2a 93 96 :2 2a
9e a1 :2 2a ad b0 b7 c0 c3
:2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19 :2 d
a :4 24 14 2b 35 13 20 31
3b 49 57 11 :2 d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5f 60 :2 5b
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 93 96
:2 2a 9e a1 :2 2a ad b0 b7 c0
c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19
:2 d a :3 7 e :2 17 22 20 :2 2b
:2 20 d 10 19 25 :2 10 28 2a
:2 28 10 27 10 2c :2 d 17 2a
37 48 4e 5d 15 16 23 31
3f 4c :2 10 :2 19 25 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 96 99 :2 2d a1
a4 :2 2d b0 b3 ba c3 c6 :2 b3
:2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10 d
:3 3b 11 :2 1a 25 23 :2 2e :2 23 10
14 1b 24 33 :2 1b 37 :2 40 :2 14
13 52 50 :2 5b :2 50 13 1f 13
1d 16 24 16 25 16 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 68 69 :2 64 :2 38
:3 1c :2 22 27 33 76 79 :2 33 86
89 :2 33 8d 90 :2 33 9c 9f :2 33
a7 aa :2 33 b6 b9 c0 c9 cc
:2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16
13 :3 69 10 69 16 1f 2e :2 16
33 31 :2 3c :2 31 13 26 34 37
40 48 :2 37 4c :2 55 24 :2 26 13
1d 16 25 2e 16 25 16 24
16 25 16 1c 30 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9c 9f :2 33 a7 aa :2 33
b6 b9 c0 c9 cc :2 b9 :2 33 :2 1c
6c :2 19 :2 16 :4 22 :2 16 13 :4 4b 69
1d 16 25 2e 35 43 4c 16
25 16 24 16 25 16 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 68 69 :2 64 :2 38
:3 1c :2 22 27 33 76 79 :2 33 86
89 :2 33 8d 90 :2 33 9c 9f :2 33
a7 aa :2 33 b6 b9 c0 c9 cc
:2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16
13 :7 10 14 :2 1d 28 26 :2 31 :2 26
13 46 4f 59 :2 46 5c 5e :2 5c
45 :2 13 22 3d 51 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9c 9f :2 33 a7 aa :2 33
b6 b9 c0 c9 cc :2 b9 :2 33 :2 1c
6c :2 19 :2 16 :4 22 :2 16 13 :4 61 :2 10
3e 1a 1d 30 37 3a 49 4f
52 18 1d 27 2f 33 48 19
1c 29 37 3a 47 4a 59 5c
17 1a 28 2b 1a 31 42 4b
4e 62 65 :2 13 :2 1c 28 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 83
86 :2 30 8a 8d :2 30 99 9c :2 30
a4 a7 :2 30 b3 b6 bd c6 c9
:2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13
10 :3 d 14 :2 1d 28 26 :2 31 :2 26
13 :4 47 46 45 :3 13 26 34 37
40 48 :2 37 4c :2 55 24 :2 26 13
22 3d 51 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :3 5a 1d 36 44
4e 16 23 31 43 4f 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 68 69 :2 64 :2 38
:3 1c :2 22 27 33 76 79 :2 33 86
89 :2 33 8d 90 :2 33 9c 9f :2 33
a7 aa :2 33 b6 b9 c0 c9 cc
:2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16
13 :3 5a 1d 29 38 41 4f 55
1c 29 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 64 68 69
:2 64 :2 38 :3 1c :2 22 27 33 76 79
:2 33 86 89 :2 33 8d 90 :2 33 9c
9f :2 33 a7 aa :2 33 b6 b9 c0
c9 cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16
:4 22 :2 16 13 :4 5a 13 26 34 37
40 48 :2 37 4c :2 55 24 :2 26 13
1d 29 38 41 4f 5f 72 7f
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 68 69 :2 64 :2 38
:3 1c :2 22 27 33 76 79 :2 33 86
89 :2 33 8d 90 :2 33 9c 9f :2 33
a7 aa :2 33 b6 b9 c0 c9 cc
:2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16
13 :3 10 1d 36 44 4e 16 23
31 43 4f 1c 30 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9c 9f :2 33 a7 aa :2 33
b6 b9 c0 c9 cc :2 b9 :2 33 :2 1c
6c :2 19 :2 16 :4 22 :2 16 13 :7 10 :4 d
10 19 23 :2 10 26 28 :2 26 14
1d 2b :2 14 2e 30 :2 2e 13 :4 39
38 37 :2 13 27 49 59 1b 2d
3b 46 :2 16 :2 1f 2b 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 68 69 :2 64 :2 38 :3 1c
:2 22 27 33 76 79 :2 33 86 89
:2 33 8d 90 :2 33 9c 9f :2 33 a7
aa :2 33 b6 b9 c0 c9 cc :2 b9
:2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16 13
:3 54 17 :2 20 2b 29 :2 34 :2 29 16
49 52 60 :2 49 63 65 :2 63 48
:2 16 20 2c 3c 4f 5a 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 67 6b 6c :2 67 :2 3b :3 1f :2 25
2a 36 79 7c :2 36 89 8c :2 36
90 93 :2 36 9f a2 :2 36 aa ad
:2 36 b9 bc c3 cc cf :2 bc :2 36
:2 1f 6f :2 1c :2 19 :4 25 :2 19 16 :3 68
13 68 1a :2 23 2e 2c :2 37 :2 2c
19 4c 55 63 :2 4c 66 68 :2 66
4b :3 19 1f :3 19 :2 22 2e 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :3 6b 19 :2 23 35 :2 3f 4b 4f
61 65 66 :2 61 :2 35 :3 19 :2 1f 24
30 73 76 :2 30 83 86 :2 30 8a
8d :2 30 97 9a a3 ab :2 b4 :2 a3
cf :2 9a :2 30 d7 da :2 30 e2 e5
:2 30 ea ed :2 30 f7 fa :2 30 :2 19
69 :2 16 19 :2 23 35 :2 3f 4b 4e
60 64 65 :2 60 :2 35 :3 19 :2 1f 24
30 73 76 :2 30 :2 19 68 :3 16 :2 21
35 :2 3e 58 1e :2 16 6b 68 :2 13
54 :3 10 20 21 :2 20 :2 10 :2 19 25
3c 4a 55 6a 70 2f 3b 47
2f 42 :2 25 10 1f 36 43 54
68 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 65 66 :2 61
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
83 86 :2 30 8a 8d :2 30 99 9c
:2 30 a4 a7 :2 30 b3 b6 bd c6
c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f
:2 13 10 :3 2a 10 21 10 13 1c
1f :2 1c 25 2e 3a :2 25 3d 3f
48 54 :2 3f :2 25 57 59 :2 57 24
:3 13 1f :2 13 23 :2 13 24 :2 13 1d
:2 13 23 :2 13 1e :2 13 1d :2 13 20
:2 13 20 13 19 20 29 35 :2 20
39 :2 42 :2 19 18 50 53 :2 50 17
5c 19 24 :2 5c 2a 27 33 3f
:2 2a :2 27 5b 47 19 21 :2 47 27
24 30 39 :2 27 :2 24 46 :2 5b 5a
:2 17 16 19 22 28 :2 19 2b 2d
:2 2b 23 1c 2a 34 47 26 44
1c 35 53 64 1c 35 53 64
1c 35 53 64 1c 35 53 64
1c 2b 34 3a 1c 2b 1c 2b
34 3b 48 51 22 36 1c 23
1f 2b :3 29 1f :2 28 34 1f 30
1f :2 28 34 1f :4 1c 19 :2 21 1f
:2 28 34 1f 22 :2 2c 3e :2 48 54
58 6a 6e 6f :2 6a :2 3e :3 22 :2 28
2d 39 7c 7f :2 39 8c 8f :2 39
93 96 :2 39 a2 a5 :2 39 ad b0
:2 39 bc bf c6 cf d2 :2 bf :2 39
:2 22 72 :2 1f :2 1c :4 28 :2 1c 19 :4 31
23 1c 2a 34 47 26 44 1c
35 53 64 1c 35 53 64 1c
35 53 64 1c 35 53 64 1c
2b 34 3a 1c 2b 1c 2b 1c
2b 34 3b 48 51 22 36 1c
23 1f 2b :3 29 1f :2 28 34 1f
30 1f :2 28 34 1f :4 1c 19 :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6a 6e 6f :2 6a :2 3e :3 22
:2 28 2d 39 7c 7f :2 39 8c 8f
:2 39 93 96 :2 39 a2 a5 :2 39 ad
b0 :2 39 bc bf c6 cf d2 :2 bf
:2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c 19
:7 16 3f 20 19 27 31 44 23
41 19 32 50 61 19 32 50
61 19 32 50 61 19 32 50
61 19 28 31 38 45 4e 5d
63 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 67 6b
6c :2 67 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :7 13 17 20 2b
:2 17 2e 30 :2 2e 16 38 41 49
:2 38 4c 4f :2 4c 37 :3 16 20 16
13 54 19 22 2a :2 19 2d 2f
:2 2d 16 29 32 3a :2 29 16 33
54 :3 13 21 32 3e 4b 54 5d
:2 4b 61 6a 72 :2 61 22 2b 37
:2 22 3b 44 4f :2 3b 53 20 2b
:2 53 2f 38 46 :2 2f 4a 53 5e
:2 4a 22 2b 37 :2 22 3b 43 4d
:2 21 13 16 1f 2b :2 16 30 2e
:2 39 :2 2e 19 1f :3 19 :2 22 2e 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 67 6b 6c :2 67
:2 3b :3 1f :2 25 2a 36 79 7c :2 36
89 8c :2 36 90 93 :2 36 9f a2
:2 36 aa ad :2 36 b9 bc c3 cc
cf :2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25
:2 19 16 :3 48 19 :2 23 35 :2 3f 4b
4e 60 64 65 :2 60 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 83 86 :2 30
8a 8d :2 30 97 9a a3 ab :2 b4
:2 a3 c5 :2 9a :2 30 :2 19 68 :2 16 19
:2 23 35 :2 3f 4b 4e 60 64 65
:2 60 :2 35 :3 19 :2 1f 24 30 73 76
:2 30 :2 19 68 :3 16 :2 21 37 :2 40 50
:2 16 13 48 19 22 2e :2 19 31
34 :2 31 19 1f :3 19 :2 22 2e 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 67 6b 6c :2 67
:2 3b :3 1f :2 25 2a 36 79 7c :2 36
89 8c :2 36 90 93 :2 36 9f a2
:2 36 aa ad :2 36 b9 bc c3 cc
cf :2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25
:2 19 16 :3 36 19 :2 23 35 :2 3f 4b
4f 61 65 66 :2 61 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 83 86 :2 30
8a 8d :2 30 97 9a a3 ab :2 a3
b8 :2 9a :2 30 c0 c3 :2 30 cb ce
:2 30 d3 d6 :2 30 e3 e6 :2 30 :2 19
69 :2 16 19 :2 23 35 :2 3f 4b 4e
60 64 65 :2 60 :2 35 :3 19 :2 1f 24
30 73 76 :2 30 :2 19 68 :3 16 :2 21
35 3e 4a :2 35 4e 5c :2 16 36
48 :2 13 5c 17 20 2c :2 17 2f
31 :2 2f 16 38 41 4d :2 38 52
50 5b 66 :2 52 :2 50 37 :3 16 24
2d 38 :2 24 16 6a 16 24 2a
33 3f :2 2a 42 44 4d 58 :2 44
:2 2a :2 24 16 :4 13 16 1f 2b :2 16
2e 30 :2 2e 16 24 2d 39 :2 24
3c 3e :2 24 16 33 16 24 2a
33 3f :2 2a 42 44 :2 2a :2 24 16
:4 13 1d 16 24 2e 41 20 3e
16 2f 4d 5e 16 2f 4d 5e
16 2f 4d 5e 16 2f 4d 5e
16 25 2e 35 42 4b 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 68 69 :2 64 :2 38
:3 1c :2 22 27 33 76 79 :2 33 86
89 :2 33 8d 90 :2 33 9c 9f :2 33
a7 aa :2 33 b6 b9 c0 c9 cc
:2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16
13 :8 10 1f :2 10 1c :2 10 19 10
13 1c 24 :2 13 27 29 :2 27 13
20 :2 29 13 10 2b 16 24 2d
38 :2 24 :2 16 3c 3f :2 3c 13 20
:2 29 30 33 :2 3c :2 20 13 41 2b
13 20 :2 29 30 39 44 :2 30 48
:2 51 :2 20 13 :5 10 20 :2 10 23 :2 10
1c 28 3d 4b 56 60 1b 23
2f 3b 47 53 1b 2a 36 40
48 51 59 1b 27 33 40 4b
56 1b 25 30 3c 48 4b 4e
54 :2 1c 10 13 1c 26 :2 13 29
2b :2 29 16 1c :3 16 :2 1f 2b 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :3 2f 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 94 97 a0 a8 :2 b1
:2 a0 c8 :2 97 :2 2d d0 d3 :2 2d db
de :2 2d e3 e6 :2 2d ef f2 :2 2d
:2 16 66 :2 13 16 :2 20 32 :2 3c 48
4b 5d 61 62 :2 5d :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d :2 16 65 :3 13
:2 1e 32 :2 3b 51 5b :2 13 10 2f
16 1f 29 :2 16 2c 2f :2 2c 16
1c :3 16 :2 1f 2b 16 13 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 64 68 69 :2 64 :2 38 :3 1c :2 22
27 33 76 79 :2 33 86 89 :2 33
8d 90 :2 33 9c 9f :2 33 a7 aa
:2 33 b6 b9 c0 c9 cc :2 b9 :2 33
:2 1c 6c :2 19 :2 16 :4 22 :2 16 13 :3 31
16 :2 20 32 :2 3c 48 4c 5e 62
63 :2 5e :2 32 :3 16 :2 1c 21 2d 70
73 :2 2d 80 83 :2 2d 87 8a :2 2d
94 97 a0 a8 :2 b1 :2 a0 c9 :2 97
:2 2d d1 d4 :2 2d dc df :2 2d e4
e7 :2 2d f7 fa :2 2d :2 16 66 :2 13
16 :2 20 32 :2 3c 48 4b 5d 61
62 :2 5d :2 32 :3 16 :2 1c 21 2d 70
73 :2 2d :2 16 65 :3 13 :2 1e 32 :2 3b
52 1b :2 13 31 2f :2 10 1a 26
35 3d 4a 6a 75 13 1a 16
22 :3 20 16 :2 1f 2b 16 27 16
:2 1f 2b 16 :4 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
61 65 66 :2 61 :2 35 :3 19 :2 1f 24
30 73 76 :2 30 83 86 :2 30 8a
8d :2 30 99 9c :2 30 a4 a7 :2 30
b3 b6 bd c6 c9 :2 b6 :2 30 :2 19
69 :2 16 :2 13 :4 1f :2 13 10 :3 2a 1f
1a 2f 31 3d 3f 55 57 66
68 7d 7f 18 29 2b 30 39
3e 40 4d 4f 5d 5f 6c 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 65 66 :2 61 :2 35 :3 19
:2 1f 24 30 73 76 :2 30 83 86
:2 30 8a 8d :2 30 99 9c :2 30 a4
a7 :2 30 b3 b6 bd c6 c9 :2 b6
:2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13 10
:3 2a 1f 1a 2f 38 4e 5d 72
86 18 34 48 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 61
65 66 :2 61 :2 35 :3 19 :2 1f 24 30
73 76 :2 30 83 86 :2 30 8a 8d
:2 30 99 9c :2 30 a4 a7 :2 30 b3
b6 bd c6 c9 :2 b6 :2 30 :2 19 69
:2 16 :2 13 :4 1f :2 13 10 :3 2a 1f 1a
2f 39 4f 5e 73 87 18 35
49 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 65 66 :2 61
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
83 86 :2 30 8a 8d :2 30 99 9c
:2 30 a4 a7 :2 30 b3 b6 bd c6
c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f
:2 13 10 :3 2a 10 1c 25 2f :2 1c
32 34 :2 1c :2 10 1b 24 2d :2 1b
30 32 3b 45 :2 32 :2 1b :2 10 23
:2 10 23 3f 4d 5b :2 23 :2 10 23
:2 10 23 3f 4d 57 :2 23 10 1a
2a 38 19 26 37 4b 13 1a
16 22 :3 20 16 :2 1f 2b 16 27
16 :2 1f 2b 16 :4 13 10 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 61 65 66 :2 61 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 83 86 :2 30
8a 8d :2 30 99 9c :2 30 a4 a7
:2 30 b3 b6 bd c6 c9 :2 b6 :2 30
:2 19 69 :2 16 :2 13 :4 1f :2 13 10 :3 2a
14 1d 33 :2 14 36 38 :2 36 13
40 49 5f :2 40 62 64 :2 62 3f
:2 13 1d 34 42 16 2c 16 2c
16 2c 16 2c 16 21 2d 3c
1c 30 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 64 68 69
:2 64 :2 38 :3 1c :2 22 27 33 76 79
:2 33 86 89 :2 33 8d 90 :2 33 9c
9f :2 33 a7 aa :2 33 b6 b9 c0
c9 cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16
:4 22 :2 16 13 :3 67 10 67 16 1f
35 :2 16 38 3a :2 38 1d 34 42
16 2c 16 2c 16 21 2d 3c
1c 30 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 64 68 69
:2 64 :2 38 :3 1c :2 22 27 33 76 79
:2 33 86 89 :2 33 8d 90 :2 33 9c
9f :2 33 a7 aa :2 33 b6 b9 c0
c9 cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16
:4 22 :2 16 13 :3 3c 13 21 2a 36
:2 21 13 10 3c 67 16 1f 35
:2 16 38 3a :2 38 1d 34 42 16
2c 16 2c 16 21 2d 3c 1c
30 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :3 3c 13 21 2a 36 :2 21
13 3c 67 1d 34 42 16 21
2d 3c 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 64
68 69 :2 64 :2 38 :3 1c :2 22 27 33
76 79 :2 33 86 89 :2 33 8d 90
:2 33 9c 9f :2 33 a7 aa :2 33 b6
b9 c0 c9 cc :2 b9 :2 33 :2 1c 6c
:2 19 :2 16 :4 22 :2 16 13 :3 10 13 21
2a 36 :2 21 :2 13 21 2a 36 :2 21
13 :4 10 2a :2 d 3b :2 a :5 7 :2 10
1c 32 40 4e :2 1c 7 4 8
1 7 d :3 7 :2 10 1c 7 4
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 55 59 5a :2 55 :2 29
:3 d :2 13 18 24 67 6a :2 24 77
7a :2 24 7e 81 :2 24 8d 90 :2 24
98 9b :2 24 a7 aa b1 ba bd
:2 aa :2 24 :2 d 5d :2 a :2 7 :4 13 :2 7
4 :3 1 4 f 4 7 10 1a
:2 7 1d 1f :2 1d 7 13 7 a
13 1d :2 a 23 20 2c 35 :2 23
:2 20 a 16 1f 29 :2 16 2c 2e
37 40 :2 2e :2 16 a e 17 21
:2 e 24 26 :2 24 d 2e 37 43
:2 2e 46 48 :2 46 2d :2 d :4 16 15
14 :3 d 1d :2 d 1e :2 d 17 :2 d
1d :2 d 18 :2 d 17 :2 d 1a :2 d
1a d 10 19 25 :2 10 28 2a
:2 28 10 1a 10 2c :3 d 1b 2c
38 45 4e 57 :2 45 5b 64 6c
:2 5b 22 2b 37 :2 22 3b 44 4f
:2 3b 53 20 2b :2 53 2f 38 46
:2 2f 4a 53 5e :2 4a 22 2b 37
:2 22 3b 43 4d :2 1b d 10 19
25 :2 10 2a 28 :2 33 :2 28 13 :2 1d
2f :2 39 45 48 5a 5e 5f :2 5a
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 91 94
9d a5 :2 ae :2 9d bf :2 94 :2 2a :2 13
62 :2 10 13 :2 1d 2f :2 39 45 48
5a 5e 5f :2 5a :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a :2 13 62 :3 10 :2 1b
31 :2 3a 4a :2 10 d 42 13 1c
28 :2 13 2b 2e :2 2b 13 :2 1d 2f
:2 39 45 49 5b 5f 60 :2 5b :2 2f
:3 13 :2 19 1e 2a 6d 70 :2 2a 7d
80 :2 2a 84 87 :2 2a 91 94 9d
a5 :2 9d b2 :2 94 :2 2a ba bd :2 2a
c5 c8 :2 2a cd d0 :2 2a dd e0
:2 2a :2 13 63 :2 10 13 :2 1d 2f :2 39
45 48 5a 5e 5f :2 5a :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a :2 13 62
:3 10 :2 1b 2f 38 44 :2 2f 48 56
:2 10 30 42 :3 d 15 1f :3 d :2 16
22 d 1c 32 3c 40 15 16
23 34 40 19 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5e
62 63 :2 5e :2 32 :3 16 :2 1c 21 2d
70 73 :2 2d 80 83 :2 2d 87 8a
:2 2d 96 99 :2 2d a1 a4 :2 2d b0
b3 ba c3 c6 :2 b3 :2 2d :2 16 66
:2 13 :2 10 :4 1c :2 10 d :3 38 d 1e
:2 d 1c :2 d 19 :2 d 16 :2 d 17
d 10 19 21 :2 10 24 26 :2 24
10 1a :2 23 2a 33 3b :2 2a 3f
:2 48 :2 1a :2 10 1d 10 28 10 1d
10 :5 d 20 :2 d 19 25 36 44
52 5c 1b 23 2f 3b 47 53
1b 2a 36 40 48 51 59 1b
27 33 40 4b 56 1b 25 30
3c 48 4b 4e 54 :2 19 d 10
19 23 :2 10 26 28 :2 26 13 :2 1d
2f :2 39 45 49 5b 5f 60 :2 5b
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 91 94
9d a5 :2 ae :2 9d c5 :2 94 :2 2a cd
d0 :2 2a d8 db :2 2a e0 e3 :2 2a
ec ef :2 2a :2 13 63 :2 10 13 :2 1d
2f :2 39 45 48 5a 5e 5f :2 5a
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
:2 13 62 :3 10 :2 1b 2f :2 38 4e 58
:2 10 d 2c 13 1c 26 :2 13 29
2c :2 29 13 :2 1d 2f :2 39 45 49
5b 5f 60 :2 5b :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a 7d 80 :2 2a 84
87 :2 2a 91 94 9d a5 :2 ae :2 9d
c6 :2 94 :2 2a ce d1 :2 2a d9 dc
:2 2a e1 e4 :2 2a f4 f7 :2 2a :2 13
63 :2 10 13 :2 1d 2f :2 39 45 48
5a 5e 5f :2 5a :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a :2 13 62 :3 10 :2 1b
2f :2 38 4f 18 :2 10 2e 2c 1a
2f 43 13 22 2c 13 2c 4a
58 6c 13 2c 4a 58 6c 13
2c 4a 58 6c 13 2c 4a 58
6c 19 2d 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 65
66 :2 61 :2 35 :3 19 :2 1f 24 30 73
76 :2 30 83 86 :2 30 8a 8d :2 30
99 9c :2 30 a4 a7 :2 30 b3 b6
bd c6 c9 :2 b6 :2 30 :2 19 69 :2 16
:2 13 :4 1f :2 13 10 :7 d 38 :2 a 38
:2 7 11 1f 2c 10 1d 2e 3c
4d :2 a :2 13 1f a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 58 5c 5d :2 58 :2 2c :3 10 :2 16
1b 27 6a 6d :2 27 7a 7d :2 27
81 84 :2 27 90 93 :2 27 9b 9e
:2 27 aa ad b4 bd c0 :2 ad :2 27
:2 10 60 :2 d :2 a :4 16 :2 a 7 :3 21
a 13 1c :2 a 1f 21 :2 1f 14
20 2f 37 44 13 20 31 3e
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5b 5f 60 :2 5b :2 2f
:3 13 :2 19 1e 2a 6d 70 :2 2a 7d
80 :2 2a 84 87 :2 2a 93 96 :2 2a
9e a1 :2 2a ad b0 b7 c0 c3
:2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19 :2 d
a :4 23 :2 7 21 :3 4 12 4 :4 8
7 11 1d 2b 34 3b 48 51
6a 77 a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5c 5d
:2 58 :2 2c :3 10 :2 16 1b 27 6a 6d
:2 27 7a 7d :2 27 81 84 :2 27 90
93 :2 27 9b 9e :2 27 aa ad b4
bd c0 :2 ad :2 27 :2 10 60 :2 d :2 a
:4 16 :2 a 7 :3 29 a 13 1f :2 a
22 24 :2 22 14 22 2f 13 20
31 49 :2 d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5b 5f 60 :2 5b :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a 7d 80
:2 2a 84 87 :2 2a 93 96 :2 2a 9e
a1 :2 2a ad b0 b7 c0 c3 :2 b0
:2 2a :2 13 63 :2 10 :2 d :4 19 :2 d a
:3 26 d 16 1f :2 d 22 24 :2 22
1c 37 44 10 1d 2e 3c 4d
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5e 62 63 :2 5e :2 32
:3 16 :2 1c 21 2d 70 73 :2 2d 80
83 :2 2d 87 8a :2 2d 96 99 :2 2d
a1 a4 :2 2d b0 b3 ba c3 c6
:2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10
d :3 26 1c 36 43 54 62 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 96 99 :2 2d a1
a4 :2 2d b0 b3 ba c3 c6 :2 b3
:2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10 d
:4 26 :2 a 26 :2 7 a 13 1c :2 a
1f 21 :2 1f a 18 :2 a 1d 2d
3b 50 5c 5f :2 1d a 14 23
33 39 41 48 5f 67 6e 86
90 a1 af 12 1e 2b 35 40
4c 58 6b 77 12 29 3d :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5b
5f 60 :2 5b :2 2f :3 13 :2 19 1e 2a
6d 70 :2 2a 7d 80 :2 2a 84 87
:2 2a 93 96 :2 2a 9e a1 :2 2a ad
b0 b7 c0 c3 :2 b0 :2 2a :2 13 63
:2 10 :2 d :4 19 :2 d a :3 23 e :2 17
22 20 :2 2b :2 20 d 10 19 25
:2 10 28 2a :2 28 1a 13 2d 13
2e 13 2e 13 2d 3f 13 19
26 37 45 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 65
66 :2 61 :2 35 :3 19 :2 1f 24 30 73
76 :2 30 83 86 :2 30 8a 8d :2 30
99 9c :2 30 a4 a7 :2 30 b3 b6
bd c6 c9 :2 b6 :2 30 :2 19 69 :2 16
:2 13 :4 1f :2 13 10 :4 2c 1a 13 2d
13 2e 13 2e 13 2d 3f 13
30 42 19 26 37 45 13 1a
16 22 :3 20 16 :2 1f 2b 16 27
16 :2 1f 2b 16 :4 13 10 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 61 65 66 :2 61 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 83 86 :2 30
8a 8d :2 30 99 9c :2 30 a4 a7
:2 30 b3 b6 bd c6 c9 :2 b6 :2 30
:2 19 69 :2 16 :2 13 :4 1f :2 13 10 :7 d
11 18 28 2b :2 11 2e 30 :2 2e
:2 10 20 :2 10 :2 19 25 3c 4a 58
2f 3a 46 52 2f 3d 50 :2 25
10 35 :2 d 3b :2 a :4 f e d
36 :2 41 48 12 :2 36 27 29 :2 27
35 :3 d 1b d 2c :2 a 23 :2 7
29 :2 4 8 11 1d :2 8 20 22
:2 20 7 :4 2b 2a 29 :2 7 a 13
29 :2 a 2c 2e :2 2c 14 22 2f
13 20 31 49 11 1f 30 :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5b
5f 60 :2 5b :2 2f :3 13 :2 19 1e 2a
6d 70 :2 2a 7d 80 :2 2a 84 87
:2 2a 93 96 :2 2a 9e a1 :2 2a ad
b0 b7 c0 c3 :2 b0 :2 2a :2 13 63
:2 10 :2 d :4 19 :2 d a :3 30 d 16
1f :2 d 22 24 :2 22 17 14 16
23 34 4c 14 22 33 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 96 99 :2 2d a1 a4
:2 2d b0 b3 ba c3 c6 :2 b3 :2 2d
:2 16 66 :2 13 :2 10 :4 1c :2 10 d :3 26
17 14 20 16 23 34 40 14
22 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 62 63 :2 5e
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
80 83 :2 2d 87 8a :2 2d 96 99
:2 2d a1 a4 :2 2d b0 b3 ba c3
c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c
:2 10 d :4 26 :2 a 30 :3 7 15 :2 7
1a 2a 38 4d 59 5c :2 1a 7
11 20 30 36 3e 45 5c 64
6b 83 8d 9e ac f 1b 28
32 3d 49 55 68 74 f 26
3a :2 a :2 13 1f a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 58 5c 5d :2 58 :2 2c :3 10 :2 16
1b 27 6a 6d :2 27 7a 7d :2 27
81 84 :2 27 90 93 :2 27 9b 9e
:2 27 aa ad b4 bd c0 :2 ad :2 27
:2 10 60 :2 d :2 a :4 16 :2 a 7 :3 4d
b :2 14 1f 1d :2 28 :2 1d a d
16 22 :2 d 25 27 :2 25 17 10
2b 10 2b 10 2b 10 2c 3e
10 16 23 34 42 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 62 63 :2 5e :2 32 :3 16 :2 1c 21
2d 70 73 :2 2d 80 83 :2 2d 87
8a :2 2d 96 99 :2 2d a1 a4 :2 2d
b0 b3 ba c3 c6 :2 b3 :2 2d :2 16
66 :2 13 :2 10 :4 1c :2 10 d :4 29 17
10 2b 10 2b 10 2b 10 2c
3e 10 2d 3f 16 23 34 42
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5e 62 63 :2 5e :2 32
:3 16 :2 1c 21 2d 70 73 :2 2d 80
83 :2 2d 87 8a :2 2d 96 99 :2 2d
a1 a4 :2 2d b0 b3 ba c3 c6
:2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10
d :7 a e 15 25 28 :2 e 2b
2d :2 2b d 37 40 4c :2 37 4f
51 :2 4f 36 :3 d 1d :2 d :2 16 22
39 47 55 2f 3a 46 52 2f
3d 50 :2 22 d 54 :2 a 38 :2 7
4d :3 4 17 21 :2 17 4 7 :2 10
19 1b :2 19 7 :2 10 1c 7 1f
:2 4 7 :2 11 23 :2 2d 39 3c 4e
52 53 :2 4e :2 23 :3 7 :2 d 12 1e
61 64 :2 1e 71 74 :2 1e 78 7b
:2 1e 85 88 91 99 :2 a2 :2 91 ad
:2 88 :2 1e b5 b8 :2 1e c0 c3 :2 1e
c8 cb :2 1e df e2 :2 1e :2 7 56
:3 4 :2 f 21 :2 2a 34 49 :2 4 1
9 12 9 a :2 14 26 :2 30 3c
40 52 56 57 :2 52 :2 26 :3 a :2 10
15 21 64 67 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 5a :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 4f 53 54 :2 4f :2 23 :3 7 :2 d
12 1e 61 64 :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 57
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
4ae5
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :7 1b
:7 1c :7 1d :7 1e :7 1f
:5 20 :5 21 :5 22 :5 23
:7 24 :5 25 :5 26 :7 27
:7 28 :5 29 :5 2a :5 2b
:5 2c :7 2d :7 2e :7 2f
:7 30 :7 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :7 5a :7 5b
:6 5c :6 5d :7 5e :6 5f
:7 60 :7 61 :6 62 :6 63
:5 64 :5 65 :6 66 :6 67
:6 68 :6 69 :6 6a :6 6b
:6 6c :6 6d :6 6e :6 6f
:6 70 :7 71 :7 72 :7 73
:e 74 :6 75 :6 76 :2 78
0 :2 78 :2 79 :3 7a
79 :5 78 :2 7c 0
:2 7c :2 7d :5 7e :2 7f
7d :5 7c :2 81 0
:2 81 :c 82 :12 83 :a 84
:a 85 :6 86 :8 87 :8 88
:23 89 :2 8a 82 :5 81
:7 8c :b 8e :11 8f 90
:2 8f :2 90 :2 8f :2 90
:2 8f :2 91 :2 8f :2 91
:2 8f :2 91 :2 8f :2 91
:2 8f :2 92 :2 8f :2 92
:2 8f :2 92 :2 8f :2 92
:2 8f :2 93 :2 8f :2 93
:2 8f :2 93 :2 8f :2 93
:2 8f :2 94 :2 8f :2 94
:2 8f :2 94 :2 8f :2 94
:2 8f :2 95 :2 8f :9 95
:2 8f :2 96 :2 8f :9 96
:2 8f :2 97 :2 8f :9 97
:2 8f :2 98 :2 8f :9 98
:2 8f :2 99 :2 8f :9 99
:2 8f :2 9a :2 8f :9 9a
:2 8f :2 9b :2 8f :9 9b
:2 8f :2 9c :2 8f :9 9c
:2 8f :2 9d :2 8f :9 9d
:2 8f :2 9e :2 8f :2 9e
:2 8f :2 9e :2 8f :2 9e
:2 8f :2 9e :4 8f :3 8e
:11 a1 :b a2 :3 a1 :3 a9
:3 aa :3 ab :3 ac :3 ad
:3 ae :d af :d b0 :2 b1
:2 b0 :6 b1 :3 b0 :3 b2
b1 :2 b0 :3 b5 :3 b6
:3 b8 :3 b9 :3 bb :3 bd
:3 be :5 c0 :4 c2 :3 c3
:5 c4 c3 :5 c6 c5
:3 c3 :5 c9 :4 cc :5 cd
cb :2 cf :5 d1 :11 d2
:24 d3 :3 d2 :2 d0 :6 cf
ce :3 8d :9 d8 :11 d9
:30 da :3 d9 :11 dc :b dd
:3 dc :a df :3 d8 :7 e3
:7 e4 :3 e5 e3 :5 e6
e2 :2 e8 :5 ea :11 eb
:24 ec :3 eb :2 e9 :6 e8
e7 :3 8d :a f2 :11 f3
:30 f4 :3 f3 :11 f6 :b f7
:3 f6 :a f9 :3 f2 :3 fc
:2 fe ff :2 100 fe
:5 101 fd :2 103 :5 105
:11 106 :24 107 :3 106 :2 104
:6 103 102 :3 8d :9 10c
:11 10d :30 10e :3 10d :11 110
:b 111 :3 110 :a 113 :3 10c
:12 117 :7 118 :c 119 117
:5 11a 116 :2 11c :5 11e
:11 11f :24 120 :3 11f :2 11d
:6 11c 11b :3 8d :a 125
:11 126 :30 127 :3 126 :11 129
:b 12a :3 129 :a 12c :3 125
:8 130 :5 131 12f :2 133
:5 135 :11 136 :24 137 :3 136
:2 134 :6 133 132 :3 8d
:a 13c :11 13d :30 13e :3 13d
:11 140 :b 141 :3 140 :a 143
:3 13c :6 147 :5 148 146
:2 14a :5 14c :11 14d :24 14e
:3 14d :2 14b :6 14a 149
:3 8d :b 153 :3 154 :3 153
:a 157 :11 158 :30 159 :3 158
:11 15b :b 15c :3 15b :a 15e
:3 157 :3 161 :b 163 :b 164
:b 165 :5 16e :9 16f :4 171
:4 172 :3 173 171 :5 174
170 :2 176 :5 178 :11 179
:24 17a :3 179 :2 177 :6 176
175 :3 16f 17e 16f
:9 17e :4 180 :4 181 :3 182
180 :5 183 17f :2 185
:5 187 :11 188 :24 189 :3 188
:2 186 :6 185 184 :4 17e
:3 16f :9 18f :11 190 :30 191
:3 190 :11 193 :b 194 :3 193
:7 196 197 :2 196 :3 18f
16e :4 19b :7 19c 19b
:5 19d 19a :2 19f :5 1a1
:11 1a2 :24 1a3 :3 1a2 :2 1a0
:6 19f 19e :3 199 :4 1a9
:7 1aa 1a9 :5 1ab 1a8
:2 1ad :5 1af :11 1b0 :24 1b1
:3 1b0 :2 1ae :6 1ad 1ac
:3 199 :18 1b6 :2 1b7 :2 1b6
:4 1b7 :6 1b6 :4 1b9 :5 1ba
1bb 1b9 :5 1bc 1b8
:2 1be :5 1c0 :11 1c1 :24 1c2
:3 1c1 :2 1bf :6 1be 1bd
:3 1b7 :9 1c7 :11 1c8 :30 1c9
:3 1c8 :11 1cb :b 1cc :3 1cb
:7 1ce 1cf :2 1ce :3 1c7
1b7 :2 1b6 199 :3 16e
:3 1e1 :3 1e2 :3 1e3 :3 1e4
:3 1e5 :5 1ee :4 1f0 :3 1f1
:5 1f2 1f1 :5 1f4 1f3
:3 1f1 :a 1f7 :3 1f8 1f7
:3 1fa 1f9 :3 1f7 :4 1fe
:5 1ff 1fd :2 201 :5 203
:11 204 :24 205 :3 204 :2 202
:6 201 200 :3 8d :9 20b
:6 20d :5 20e 20d :5 20f
20c :2 211 :5 213 :11 214
:24 215 :3 214 :2 212 :6 211
210 :3 20b :9 21a :3 21b
:4 21d :4 21e :5 21f 21d
:5 220 21c :2 222 :5 224
:11 225 :24 226 :3 225 :2 223
:6 222 221 :3 21a :a 22c
:11 22d :30 22e :3 22d :11 230
:b 231 :3 230 :7 233 234
:2 233 235 22c :e 235
:11 236 :2 237 :2 236 :4 237
:3 236 :11 238 :30 239 :3 238
:11 23b :b 23c :3 23b :7 23e
23f :2 23e 237 :2 236
235 :3 22c :3 21a :9 245
:3 246 :3 247 245 :4 24b
24c :2 24d :2 24e :2 24f
24b :5 250 24a :2 252
:5 254 :11 255 :24 256 :3 255
:2 253 :6 252 251 :3 249
:a 25c :3 25d :5 25e :b 260
261 :3 260 :5 262 :3 263
:3 264 :6 266 :3 267 :3 266
:a 269 :5 26b :6 26c :2 26d
:4 26e :7 26f :2 270 26b
:6 271 :5 272 271 :5 274
273 :3 271 26a :2 277
:5 279 :11 27a :24 27b :3 27a
:2 278 :6 277 276 :3 25c
:6 282 :5 283 281 :2 285
:5 287 :11 288 :24 289 :3 288
:2 286 :6 285 284 :3 25c
:b 28e :3 28f 28e :4 292
:8 293 292 :5 294 291
:2 296 :5 298 :11 299 :24 29a
:3 299 :2 297 :6 296 295
:4 290 :3 28e :9 2a1 :6 2a4
:4 2a5 2a4 :6 2a6 :5 2a7
2a6 :5 2a9 2a8 :3 2a6
2a3 :2 2ac :5 2ae :11 2af
:24 2b0 :3 2af :2 2ad :6 2ac
2ab :3 2a1 :2 2b7 :4 2b9
:5 2bc :2 2bd :4 2c0 2b7
:6 2c1 :5 2c2 2c1 :5 2c4
2c3 :3 2c1 2b6 :2 2c7
:5 2c9 :11 2ca :24 2cb :3 2ca
:2 2c8 :6 2c7 2c6 :4 2a1
:2 2d2 :4 2d4 :5 2d7 :2 2d8
:4 2db 2d2 :6 2dc :5 2dd
2dc :5 2df 2de :3 2dc
2d1 :2 2e2 :5 2e4 :11 2e5
:24 2e6 :3 2e5 :2 2e3 :6 2e2
2e1 :4 2cf :3 2a1 2eb
25c :a 2eb :3 2ed :3 2ee
2ed :5 2ef 2ec :2 2f1
:5 2f3 :11 2f4 :24 2f5 :3 2f4
:2 2f2 :6 2f1 2f0 :3 2eb
:b 2fb :b 2fc 2fd :3 2fc
:3 2ff :5 300 :2 301 2ff
:6 302 :5 303 302 :5 305
304 :3 302 2fe :2 308
:5 30a :11 30b :24 30c :3 30b
:2 309 :6 308 307 :3 2fb
:6 311 312 2fb :12 312
:3 314 :6 315 :2 316 314
:6 317 :5 318 317 :5 31a
319 :3 317 313 :2 31d
:5 31f :11 320 :24 321 :3 320
:2 31e :6 31d 31c :3 312
:6 326 312 2fb :3 329
:6 32a :2 32b 329 :6 32c
:5 32d 32c :5 32f 32e
:3 32c 328 :2 332 :5 334
:11 335 :24 336 :3 335 :2 333
:6 332 331 :3 327 :6 33b
327 :3 2fb 2eb :3 25c
249 :3 245 20b :3 341
340 :3 20b :3 347 :3 348
:3 349 :5 34b :16 34d :7 34e
:5 34f :3 34e :3 34d :3 353
:5 354 355 :b 356 :2 357
353 :5 358 352 :2 35a
:5 35c :11 35d :24 35e :3 35d
:2 35b :6 35a 359 :3 8d
:a 363 :3 364 :3 363 :3 369
:3 36a :3 36b :4 36f :3 370
36f :5 371 36e :2 373
:5 375 :11 376 :24 377 :3 376
:2 374 :6 373 372 :3 8d
:b 37d :4 37f :6 380 37f
:5 381 37e :2 383 :5 385
:11 386 :24 387 :3 386 :2 384
:6 383 382 :3 37d :9 38d
:3 38f 38d :3 391 390
:3 38d :3 37d :9 395 :b 396
:b 398 :8 399 :7 39a :8 39b
39c :5 39d 398 :5 39e
397 :2 3a0 :5 3a2 :11 3a3
:24 3a4 :3 3a3 :2 3a1 :6 3a0
39f :3 396 :3 3aa :3 3ad
:9 3ae :15 3af :2 3b0 :7 3af
:c 3b1 :2 3b2 :2 3b1 :3 3b2
:3 3b1 :4 3b2 :3 3b1 :11 3b3
:30 3b4 :3 3b3 :11 3b6 :b 3b7
:3 3b6 :a 3b9 3b2 :3 3bb
:9 3bd :3 3be :3 3bd 3ba
:3 3b1 3b0 :2 3af :3 3c3
:3 3c4 :3 3c5 :3 3c6 :3 3c8
:3 3ca :3 3cb :3 3cc :3 3cd
:3 3ae :12 3d1 :a 3d2 :6 3d3
:7 3d4 :4 3d5 :3 3d6 :3 3d4
:3 3d2 :9 3d9 :4 3db :6 3dc
:5 3dd 3dc :5 3df 3de
:3 3dc 3da :2 3e2 :5 3e4
:11 3e5 :24 3e6 :3 3e5 :2 3e3
:6 3e2 3e1 :3 3d9 :6 3ed
:6 3ee :5 3ef 3ee :5 3f1
3f0 :3 3ee 3ec :2 3f4
:5 3f6 :11 3f7 :24 3f8 :3 3f7
:2 3f5 :6 3f4 3f3 :3 3d9
:3 3fe :4 400 :4 401 400
:5 402 3ff :2 404 :5 406
:11 407 :24 408 :3 407 :2 405
:6 404 403 :3 3d9 :c 40d
:8 40f 410 411 40f
:5 412 40e :2 414 :5 416
:11 417 :24 418 :3 417 :2 415
:6 414 413 :6 40d 3d9
:16 41e :f 41f :f 420 :f 421
:f 422 :9 424 :3 426 :3 427
:2 428 :2 429 :2 42a :2 42b
:4 42c :4 42d :6 42e :2 42f
426 :6 430 :5 431 430
:5 433 432 :3 430 425
:2 436 :5 438 :11 439 :24 43a
:3 439 :2 437 :6 436 435
:4 424 :3 440 :3 441 :2 442
:2 443 :2 444 :2 445 :4 446
:4 447 :4 448 :6 449 :2 44a
440 :6 44b :5 44c 44b
:5 44e 44d :3 44b 43f
:2 451 :5 453 :11 454 :24 455
:3 454 :2 452 :6 451 450
:4 43e :3 424 45a 41e
:9 45a :f 45b :f 45c :3 45f
:3 460 :2 461 :2 462 :4 463
:4 464 :6 465 :2 466 45f
:6 467 :5 468 467 :5 46a
469 :3 467 45e :2 46d
:5 46f :11 470 :24 471 :3 470
:2 46e :6 46d 46c :3 45a
475 45a 41e :9 475
:f 476 :f 477 :9 479 :3 47b
:3 47c :2 47d :2 47e :4 47f
:6 480 :2 481 47b :6 482
:5 483 482 :5 485 484
:3 482 47a :2 488 :5 48a
:11 48b :24 48c :3 48b :2 489
:6 488 487 :4 479 :3 492
:3 493 :2 494 :2 495 :4 496
:4 497 :6 498 :2 499 492
:6 49a :5 49b 49a :5 49d
49c :3 49a 491 :2 4a0
:5 4a2 :11 4a3 :24 4a4 :3 4a3
:2 4a1 :6 4a0 49f :4 490
:3 479 475 41e :3 4ab
:4 4ac :3 4ad :2 4ae 4ab
:6 4af :5 4b0 4af :5 4b2
4b1 :3 4af 4aa :2 4b5
:5 4b7 :11 4b8 :24 4b9 :3 4b8
:2 4b6 :6 4b5 4b4 :4 4a9
:3 41e :6 4c0 :6 4c1 :5 4c2
4c1 :5 4c4 4c3 :3 4c1
4bf :2 4c7 :5 4c9 :11 4ca
:24 4cb :3 4ca :2 4c8 :6 4c7
4c6 :3 41d 4d1 :7 4d2
:3 4d3 4d1 :6 4d4 :5 4d5
4d4 :5 4d7 4d6 :3 4d4
4d0 :2 4da :5 4dc :11 4dd
:24 4de :3 4dd :2 4db :6 4da
4d9 :4 41d :3 3d9 :3 4e5
:4 4e9 :6 4ea :5 4eb 4ea
:5 4ed 4ec :3 4ea 4e8
:2 4f0 :5 4f2 :11 4f3 :24 4f4
:3 4f3 :2 4f1 :6 4f0 4ef
:3 3d1 :6 4fb :6 4fc :5 4fd
4fc :5 4ff 4fe :3 4fc
4fa :2 502 :5 504 :11 505
:24 506 :3 505 :2 503 :6 502
501 :3 3d1 :16 50b :3 50c
:3 50d :b 50e :3 50f 50e
:3 511 510 :3 50e :9 514
:3 515 :3 514 :e 518 :b 519
:2 51a :2 519 :a 51a :8 51b
:3 518 :b 51d :11 51e :20 51f
:3 51e :11 521 :b 522 :3 521
:9 524 525 51d :9 525
:11 526 :2e 527 :3 526 :11 529
:b 52a :3 529 :c 52c 525
:3 51d :9 531 :5 532 531
:f 534 533 :3 531 :3 53b
:7 53c :6 53d :7 53e :6 53f
:8 540 :3 53c :9 544 :11 545
:30 546 :3 545 :11 548 :b 549
:3 548 :a 54b 54c 544
:9 54c :11 54d :30 54e :3 54d
:11 550 :b 551 :3 550 :7 553
554 :2 553 54c 544
:3 556 :a 557 :5 558 :3 557
555 :3 544 :3 50b :3 3d1
55c 396 :a 55c :b 55f
:7 560 561 :4 562 :3 563
55f :5 564 55e :2 566
:5 568 :11 569 :24 56a :3 569
:2 567 :6 566 565 :3 55c
:12 570 :6 571 :7 572 :4 573
:3 574 :3 572 :3 570 55c
396 :4 579 57a :4 57b
:3 57c 579 :5 57d 578
:2 57f :5 581 :11 582 :24 583
:3 582 :2 580 :6 57f 57e
:4 576 :3 396 589 395
:a 589 :b 58c :7 58d 58e
:4 58f :3 590 58c :5 591
58b :2 593 :5 595 :11 596
:24 597 :3 596 :2 594 :6 593
592 :3 589 :12 59d :6 59e
:7 59f :4 5a0 :3 5a1 :3 59f
:3 59d 589 395 :4 5a6
5a7 :4 5a8 :3 5a9 5a6
:5 5aa 5a5 :2 5ac :5 5ae
:11 5af :24 5b0 :3 5af :2 5ad
:6 5ac 5ab :4 5a3 :3 395
:13 5bb :2 5bc :2 5bb :4 5bc
:3 5bb :3 5bd :5 5be :9 5c2
:7 5c3 :3 5c2 :16 5c6 :16 5c7
:f 5c8 :f 5c9 :f 5ca :f 5cb
:9 5ce :8 5cf :9 5d0 :a 5d1
:7 5d2 :9 5d3 5ce :6 5d4
:5 5d5 5d4 :5 5d7 5d6
:3 5d4 5cd :2 5da :5 5dc
:11 5dd :24 5de :3 5dd :2 5db
:6 5da 5d9 :3 5c7 5e2
5c7 :9 5e2 :f 5e3 :f 5e4
:9 5e7 :8 5e8 :9 5e9 :a 5ea
:7 5eb :9 5ec 5e7 :6 5ed
:5 5ee 5ed :5 5f0 5ef
:3 5ed 5e6 :2 5f3 :5 5f5
:11 5f6 :24 5f7 :3 5f6 :2 5f4
:6 5f3 5f2 :4 5e2 5c7
:f 5fc :f 5fd :9 600 :8 601
:9 602 :a 603 :7 604 :9 605
600 :6 606 :5 607 606
:5 609 608 :3 606 5ff
:2 60c :5 60e :11 60f :24 610
:3 60f :2 60d :6 60c 60b
:4 5fb :3 5c7 5c6 :9 617
:8 618 :9 619 :a 61a :7 61b
:9 61c 617 :6 61d :5 61e
61d :5 620 61f :3 61d
616 :2 623 :5 625 :11 626
:24 627 :3 626 :2 624 :6 623
622 :4 615 :3 5c6 :3 62f
5bc :2 5bb :c 631 :3 632
:3 633 :6 63a :5 63b 639
:2 63d :5 63f :11 640 :24 641
:3 640 :2 63e :6 63d 63c
:3 8d :3 646 :3 647 :3 648
:12 64b :4 64d :4 64e :6 64f
:27 650 64d :5 651 64c
:2 653 :5 655 :11 656 :24 657
:3 656 :2 654 :6 653 652
:6 64b :3 662 :5 666 668
:7 669 :5 66a :5 66b :5 66c
:3 669 :3 66d :5 66e 66d
:5 670 66f :3 66d :a 673
:2 674 :3 673 :9 67a :7 67b
:4 67e :6 67f :5 680 67f
:5 682 681 :3 67f 67d
:2 685 :5 687 :11 688 :24 689
:3 688 :2 686 :6 685 684
:3 67a :4 68f :6 690 :5 691
690 :5 693 692 :3 690
68e :2 696 :5 698 :11 699
:24 69a :3 699 :2 697 :6 696
695 :3 67a :4 6a0 :6 6a1
:5 6a2 6a1 :5 6a4 6a3
:3 6a1 69f :2 6a7 :5 6a9
:11 6aa :24 6ab :3 6aa :2 6a8
:6 6a7 6a6 :3 67a :6 6b1
:6 6b2 :5 6b3 6b2 :5 6b5
6b4 :3 6b2 6b0 :2 6b8
:5 6ba :11 6bb :24 6bc :3 6bb
:2 6b9 :6 6b8 6b7 :3 67a
:4 6c2 :6 6c3 :5 6c4 6c3
:5 6c6 6c5 :3 6c3 6c1
:2 6c9 :5 6cb :11 6cc :24 6cd
:3 6cc :2 6ca :6 6c9 6c8
:3 67a :4 6d3 :6 6d4 :5 6d5
6d4 :5 6d7 6d6 :3 6d4
6d2 :2 6da :5 6dc :11 6dd
:24 6de :3 6dd :2 6db :6 6da
6d9 :4 67a :3 6e4 :6 6e5
6e6 6e4 :5 6e7 6e3
:2 6e9 :5 6eb :11 6ec :24 6ed
:3 6ec :2 6ea :6 6e9 6e8
:3 6e2 :a 6f4 :9 6f5 :3 6f6
:3 6f5 :6 6fb 6fc :5 6fd
6fb :5 6fe 6fa :2 700
:5 702 :11 703 :24 704 :3 703
:2 701 :6 700 6ff :3 6f4
:a 70b :12 70c :3 70d 70f
:2 710 :2 711 712 :2 713
70f :6 714 :5 715 714
:5 717 716 :3 714 70e
:2 71a :5 71c :11 71d :24 71e
:3 71d :2 71b :6 71a 719
:3 70c 722 70c :b 722
:b 723 724 :3 723 727
:3 728 :2 729 :2 72a :2 72b
72c :2 72d 727 :6 72e
:5 72f 72e :5 731 730
:3 72e 726 :2 734 :5 736
:11 737 :24 738 :3 737 :2 735
:6 734 733 :4 722 70c
73e :6 73f :2 740 :2 741
:2 742 743 :2 744 73e
:6 745 :5 746 745 :5 748
747 :3 745 73d :2 74b
:5 74d :11 74e :24 74f :3 74e
:2 74c :6 74b 74a :4 73c
:3 70c :16 755 :4 757 :6 758
:5 759 758 :5 75b 75a
:3 758 756 :2 75e :5 760
:11 761 :24 762 :3 761 :2 75f
:6 75e 75d :6 755 70b
:8 769 :6 76a :9 76b :4 76c
:7 76d 769 :5 76e 768
:2 770 :5 772 :11 773 :24 774
:3 773 :2 771 :6 770 76f
:3 767 :12 77a :b 77b 77c
:3 77b :4 77f :6 780 :5 781
780 :5 783 782 :3 780
77e :2 786 :5 788 :11 789
:24 78a :3 789 :2 787 :6 786
785 :3 77a :4 790 :5 791
:2 792 790 :6 793 :5 794
793 :5 796 795 :3 793
78f :2 799 :5 79b :11 79c
:24 79d :3 79c :2 79a :6 799
798 :3 77a :6 7a3 :2 7a4
7a3 :6 7a5 :5 7a6 7a5
:5 7a8 7a7 :3 7a5 7a2
:2 7ab :5 7ad :11 7ae :24 7af
:3 7ae :2 7ac :6 7ab 7aa
:4 77a :b 7b4 7b5 :3 7b4
:9 7b8 :6 7b9 :5 7ba 7b9
:5 7bc 7bb :3 7b9 7b7
:2 7bf :5 7c1 :11 7c2 :24 7c3
:3 7c2 :2 7c0 :6 7bf 7be
:3 7b3 :4 7c9 :5 7ca :2 7cb
7c9 :6 7cc :5 7cd 7cc
:5 7cf 7ce :3 7cc 7c8
:2 7d2 :5 7d4 :11 7d5 :24 7d6
:3 7d5 :2 7d3 :6 7d2 7d1
:4 7b3 :3 77a 767 :3 70b
:9 7df :12 7e0 :3 7e2 :4 7e3
7e2 :5 7e4 7e1 :2 7e6
:5 7e8 :11 7e9 :24 7ea :3 7e9
:2 7e7 :6 7e6 7e5 :3 7e0
:16 7f0 :6 7f2 :6 7f3 :5 7f4
7f3 :5 7f6 7f5 :3 7f3
7f1 :2 7f9 :5 7fb :11 7fc
:24 7fd :3 7fc :2 7fa :6 7f9
7f8 :3 7f0 801 7f0
:16 801 :4 803 :5 804 802
:2 806 :5 808 :11 809 :24 80a
:3 809 :2 807 :6 806 805
:3 801 :11 80f :30 810 :3 80f
:11 812 :b 813 :3 812 :7 815
816 :2 815 801 :3 7f0
:3 7e0 :6 81a :9 81b :3 81c
:2 81d :3 81b :6 855 :6 856
:5 857 856 :5 859 858
:3 856 854 :2 85c :5 85e
:11 85f :24 860 :3 85f :2 85d
:6 85c 85b :3 7df :3 865
:19 868 :3 86a :3 86b :3 86c
:3 86d :3 86f :3 871 :3 872
:3 873 :3 874 :12 876 :2 877
:2 876 :8 877 876 877
:2 878 :2 877 :8 878 877
:6 876 :9 879 87b :4 87c
:2 87d :4 87e :4 87f :4 880
:4 881 :4 882 :2 883 :6 884
:2 885 87b :6 886 :5 887
886 :5 889 888 :3 886
87a :2 88c :5 88e :11 88f
:24 890 :3 88f :2 88d :6 88c
88b :4 879 896 :4 897
:2 898 :4 899 :4 89a :4 89b
:4 89c :4 89d :2 89e :2 89f
:6 8a0 :2 8a1 896 :6 8a2
:5 8a3 8a2 :5 8a5 8a4
:3 8a2 895 :2 8a8 :5 8aa
:11 8ab :24 8ac :3 8ab :2 8a9
:6 8a8 8a7 :4 894 :3 879
878 8b5 :4 8b6 :2 8b7
:4 8b8 :4 8b9 :4 8ba :4 8bb
:8 8bc :2 8bd 8b5 :6 8be
:5 8bf 8be :5 8c1 8c0
:3 8be 8b4 :2 8c4 :5 8c6
:11 8c7 :24 8c8 :3 8c7 :2 8c5
:6 8c4 8c3 :4 8b3 :3 876
:16 8ce :3 8cf 8d0 8ce
:9 8d0 :7 8d1 8d0 :3 8ce
:e 8d4 :b 8d5 :2 8d6 :2 8d5
:a 8d6 :8 8d7 :3 8d4 :b 8d9
:4 8db :5 8dc 8da :2 8de
:5 8e0 :11 8e1 :24 8e2 :3 8e1
:2 8df :6 8de 8dd :3 8d9
:11 8e7 :20 8e8 :3 8e7 :11 8ea
:b 8eb :3 8ea :9 8ed 8ee
8d9 :9 8ee :4 8f0 :5 8f1
8ef :2 8f3 :5 8f5 :11 8f6
:24 8f7 :3 8f6 :2 8f4 :6 8f3
8f2 :3 8ee :11 8fc :2e 8fd
:3 8fc :11 8ff :b 900 :3 8ff
:c 902 8ee :3 8d9 868
:1a 907 :7 908 907 :12 90a
909 :3 907 :9 90d :b 90e
90d :e 910 90f :3 90d
91d :4 91e :2 91f :4 920
:4 921 :4 922 :4 923 :6 924
:2 925 91d :6 926 :5 927
926 :5 929 928 :3 926
91c :2 92c :5 92e :11 92f
:24 930 :3 92f :2 92d :6 92c
92b :4 904 :3 868 :3 936
:3 937 :3 938 :9 93a :5 93b
93c 93a :c 93c :b 93d
93c 93a :f 93f 93e
:3 93a :3 942 :3 949 :7 94a
:6 94b :7 94c :6 94d :8 94e
:3 94a :9 952 :4 954 :5 955
953 :2 957 :5 959 :11 95a
:24 95b :3 95a :2 958 :6 957
956 :3 952 :11 960 :30 961
:3 960 :11 963 :b 964 :3 963
:a 966 967 952 :9 967
:4 969 :5 96a 968 :2 96c
:5 96e :11 96f :24 970 :3 96f
:2 96d :6 96c 96b :3 967
:11 975 :30 976 :3 975 :11 978
:b 979 :3 978 :7 97b 97c
:2 97b 967 :3 952 :8 986
:6 987 :5 988 987 :5 98a
989 :3 987 985 :2 98d
:5 98f :11 990 :24 991 :3 990
:2 98e :6 98d 98c :3 7df
998 :b 999 :c 99a 998
:6 99b :5 99c 99b :5 99e
99d :3 99b 997 :2 9a1
:5 9a3 :11 9a4 :24 9a5 :3 9a4
:2 9a2 :6 9a1 9a0 :3 7df
9ac :7 9ad :3 9ae 9ac
:6 9af :5 9b0 9af :5 9b2
9b1 :3 9af 9ab :2 9b5
:5 9b7 :11 9b8 :24 9b9 :3 9b8
:2 9b6 :6 9b5 9b4 :3 7df
9bf :7 9c0 :3 9c1 9bf
:6 9c2 :5 9c3 9c2 :5 9c5
9c4 :3 9c2 9be :2 9c8
:5 9ca :11 9cb :24 9cc :3 9cb
:2 9c9 :6 9c8 9c7 :3 7df
:b 9d1 :f 9d2 :3 9d4 :8 9d5
:3 9d7 :8 9d8 :3 9db :4 9dc
9db :6 9dd :5 9de 9dd
:5 9e0 9df :3 9dd 9da
:2 9e3 :5 9e5 :11 9e6 :24 9e7
:3 9e6 :2 9e4 :6 9e3 9e2
:3 7df :16 9ed :3 9ef :2 9f0
:2 9f1 :2 9f2 :2 9f3 :4 9f4
:2 9f5 9ef :6 9f6 :5 9f7
9f6 :5 9f9 9f8 :3 9f6
9ee :2 9fc :5 9fe :11 9ff
:24 a00 :3 9ff :2 9fd :6 9fc
9fb :3 9ed a04 9ed
:9 a04 :3 a06 :2 a07 :2 a08
:4 a09 :2 a0a a06 :6 a0b
:5 a0c a0b :5 a0e a0d
:3 a0b a05 :2 a11 :5 a13
:11 a14 :24 a15 :3 a14 :2 a12
:6 a11 a10 :3 a04 :7 a1a
a1b a04 9ed :9 a1b
:3 a1d :2 a1e :2 a1f :4 a20
:2 a21 a1d :6 a22 :5 a23
a22 :5 a25 a24 :3 a22
a1c :2 a28 :5 a2a :11 a2b
:24 a2c :3 a2b :2 a29 :6 a28
a27 :3 a1b :7 a31 a1b
9ed :3 a34 :4 a35 :2 a36
a34 :6 a37 :5 a38 a37
:5 a3a a39 :3 a37 a33
:2 a3d :5 a3f :11 a40 :24 a41
:3 a40 :2 a3e :6 a3d a3c
:3 a32 :7 a46 :7 a47 a32
:3 9ed :3 7df :3 6f4 6e2
:3 67a :a a5b 668 a5c
8d :4 a60 :5 a61 a5f
:2 a63 :5 a65 :11 a66 :24 a67
:3 a66 :2 a64 :6 a63 a62
:3 8d :3 a6d :9 a6e :3 a6f
:d a73 :f a74 :16 a7b :6 a7c
:2 a7b :3 a7d :3 a7e :3 a7f
:3 a81 :3 a83 :3 a84 :3 a85
:3 a86 :9 a88 :3 a89 :3 a88
:e a8c :b a8d :2 a8e :2 a8d
:a a8e :8 a8f :3 a8c :b a91
:11 a92 :20 a93 :3 a92 :11 a95
:b a96 :3 a95 :9 a98 a99
a91 :9 a99 :11 a9a :2e a9b
:3 a9a :11 a9d :b a9e :3 a9d
:c aa0 a99 :3 a91 :5 aa4
:5 aa5 :4 aa8 aa9 :4 aaa
aab aa8 :6 aac :5 aad
aac :5 aaf aae :3 aac
aa7 :2 ab2 :5 ab4 :11 ab5
:24 ab6 :3 ab5 :2 ab3 :6 ab2
ab1 :3 a7c :3 abc :3 abf
:3 ac0 :3 ac1 :3 ac2 :9 ac4
:f ac5 :3 ac6 ac4 :3 ac8
ac7 :3 ac4 :3 acc :7 acd
:6 ace :7 acf :6 ad0 :8 ad1
:3 acd :9 ad5 :11 ad6 :30 ad7
:3 ad6 :11 ad9 :b ada :3 ad9
:a adc add ad5 :9 add
:11 ade :30 adf :3 ade :11 ae1
:b ae2 :3 ae1 :7 ae4 ae5
:2 ae4 add ad5 :3 ae8
:3 ae9 :5 aea :5 aeb :5 aec
:5 aed :2 aee ae8 :6 aef
:5 af0 aef :5 af2 af1
:3 aef ae7 :2 af5 :5 af7
:11 af8 :24 af9 :3 af8 :2 af6
:6 af5 af4 :4 ae6 :3 ad5
a7c :2 a7b :3 a73 :3 b02
:5 b03 b02 :5 b04 b01
:2 b06 :5 b08 :11 b09 :24 b0a
:3 b09 :2 b07 :6 b06 b05
:3 a6e :9 b10 :5 b12 :4 b13
b12 :6 b14 :5 b15 b14
:5 b17 b16 :3 b14 b11
:2 b1a :5 b1c :11 b1d :24 b1e
:3 b1d :2 b1b :6 b1a b19
:6 b10 :3 a6e :3 b25 :5 b28
:a b2a :6 b2b :5 b2c b2b
:5 b2e b2d :3 b2b b29
:2 b31 :5 b33 :11 b34 :24 b35
:3 b34 :2 b32 :6 b31 b30
:3 b28 :9 b3b :3 b3d :4 b3e
b3d :5 b3f b3c :2 b41
:5 b43 :11 b44 :24 b45 :3 b44
:2 b42 :6 b41 b40 :3 b3b
:9 b4b :3 b4d :5 b4e b4d
:6 b4f :5 b50 b4f :5 b52
b51 :3 b4f b4c :2 b55
:5 b57 :11 b58 :24 b59 :3 b58
:2 b56 :6 b55 b54 :3 b4b
:6 b5f :6 b60 :5 b61 b60
:5 b63 b62 :3 b60 b5e
:2 b66 :5 b68 :11 b69 :24 b6a
:3 b69 :2 b67 :6 b66 b65
:6 b4b :3 b3b :9 b71 :3 b73
:a b74 :d b77 :9 b78 :3 b79
b77 :5 b7a b76 :2 b7c
:5 b7e :11 b7f :24 b80 :3 b7f
:2 b7d :6 b7c b7b :3 b71
:a b86 :9 b87 b89 :2 b8a
:2 b8b :2 b8c :3 b8d b8e
:4 b8f b89 :6 b90 :5 b91
b90 :5 b93 b92 :3 b90
b88 :2 b96 :5 b98 :11 b99
:24 b9a :3 b99 :2 b97 :6 b96
b95 :4 b87 ba0 :2 ba1
:2 ba2 :2 ba3 :3 ba4 :3 ba5
:4 ba6 ba0 :6 ba7 :5 ba8
ba7 :5 baa ba9 :3 ba7
b9f :2 bad :5 baf :11 bb0
:24 bb1 :3 bb0 :2 bae :6 bad
bac :4 b9e :3 b87 :b bb8
:3 bb9 :7 bba :4 bbb :3 bbc
:3 bba :3 bb8 :3 b86 :a bc1
bc2 :2 bc1 :4 bc2 :3 bc1
:3 bc3 bc2 :2 bc1 :3 b71
:3 b28 :12 bc9 :9 bcb :3 bcd
:4 bce :3 bcf bcd :5 bd0
bcc :2 bd2 :5 bd4 :11 bd5
:24 bd6 :3 bd5 :2 bd3 :6 bd2
bd1 :3 bcb :9 bdb bde
bdf :4 be0 :3 be1 bde
:6 be2 :5 be3 be2 :5 be5
be4 :3 be2 bdd :2 be8
:5 bea :11 beb :24 bec :3 beb
:2 be9 :6 be8 be7 :3 bdb
bf2 :2 bf3 :4 bf4 :2 bf5
bf2 :6 bf6 :5 bf7 bf6
:5 bf9 bf8 :3 bf6 bf1
:2 bfc :5 bfe :11 bff :24 c00
:3 bff :2 bfd :6 bfc bfb
:6 bdb :3 bcb :3 c08 :a c09
:d c0c :9 c0d :3 c0e c0c
:5 c0f c0b :2 c11 :5 c13
:11 c14 :24 c15 :3 c14 :2 c12
:6 c11 c10 :3 bc9 :a c1b
:9 c1c c1e :2 c1f :2 c20
:2 c21 :3 c22 c23 :4 c24
c1e :6 c25 :5 c26 c25
:5 c28 c27 :3 c25 c1d
:2 c2b :5 c2d :11 c2e :24 c2f
:3 c2e :2 c2c :6 c2b c2a
:4 c1c c35 :2 c36 :2 c37
:2 c38 :3 c39 :3 c3a :4 c3b
c35 :6 c3c :5 c3d c3c
:5 c3f c3e :3 c3c c34
:2 c42 :5 c44 :11 c45 :24 c46
:3 c45 :2 c43 :6 c42 c41
:4 c33 :3 c1c :17 c4d :3 c4e
:7 c4f :4 c50 :3 c51 :3 c4f
:3 c4d :3 c1b :3 bc9 :6 c57
:7 c5a :5 c5b :3 c5a :11 c5f
:30 c60 :3 c5f :a c62 8d
:3 c65 :11 c66 :b c67 :17 c68
:3 c66 :2 c6a :3 c6b :3 c6c
c6d c6b c6a c6b
:3 c6e :3 c65 :2 c6f :5 c71
:11 c72 :b c73 :18 c74 :3 c72
:2 c76 c77 :3 c78 c79
c77 c76 c77 :3 c7a
:2 c70 :6 c6f c64 :7 1

10623
4
:3 0 1 :3 0 2
:a 0 4ae0 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 7
:7 0 11 10 :3 0
4 :3 0 8 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 9 :7 0 19
18 :3 0 a :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 a :3 0 c
:7 0 21 20 :3 0
a :3 0 d :7 0
25 24 :3 0 19
ee 0 17 a
:3 0 e :7 0 29
28 :3 0 a :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b a :3 0 10
:7 0 31 30 :3 0
a :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f a :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 4ae0 2 44
:2 0 18 :2 0 33
4 :3 0 18 :2 0
31 47 49 :6 0
4c 4a 0 4ade
0 17 :6 0 18
:2 0 37 4 :3 0
35 4e 50 :6 0
53 51 0 4ade
0 19 :6 0 18
:2 0 3b 4 :3 0
39 55 57 :6 0
5a 58 0 4ade
0 1a :6 0 18
:2 0 3f 4 :3 0
3d 5c 5e :6 0
61 5f 0 4ade
0 1b :6 0 18
:2 0 43 4 :3 0
41 63 65 :6 0
68 66 0 4ade
0 1c :6 0 18
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 4ade
0 1d :6 0 18
:2 0 4b 4 :3 0
49 71 73 :6 0
76 74 0 4ade
0 1e :6 0 18
:2 0 4f 4 :3 0
4d 78 7a :6 0
7d 7b 0 4ade
0 1f :6 0 18
:2 0 53 4 :3 0
51 7f 81 :6 0
84 82 0 4ade
0 20 :6 0 18
:2 0 57 4 :3 0
55 86 88 :6 0
8b 89 0 4ade
0 21 :6 0 18
:2 0 5b 4 :3 0
59 8d 8f :6 0
92 90 0 4ade
0 22 :6 0 61
2b0 0 5f 4
:3 0 5d 94 96
:6 0 99 97 0
4ade 0 23 :6 0
65 2e4 0 63
25 :3 0 9b :7 0
9e 9c 0 4ade
0 24 :6 0 25
:3 0 a0 :7 0 a3
a1 0 4ade 0
26 :6 0 2a :2 0
67 25 :3 0 a5
:7 0 a8 a6 0
4ade 0 27 :6 0
25 :3 0 aa :7 0
ad ab 0 4ade
0 28 :6 0 6d
335 0 6b 4
:3 0 69 af b1
:6 0 b4 b2 0
4ade 0 29 :6 0
2a :2 0 6f 2c
:3 0 b6 :7 0 b9
b7 0 4ade 0
2b :6 0 2c :3 0
bb :7 0 be bc
0 4ade 0 2d
:6 0 30 :2 0 73
4 :3 0 71 c0
c2 :6 0 c5 c3
0 4ade 0 2e
:6 0 79 3a3 0
77 4 :3 0 75
c7 c9 :6 0 cc
ca 0 4ade 0
2f :6 0 7d 3d7
0 7b 25 :3 0
ce :7 0 d1 cf
0 4ade 0 31
:6 0 25 :3 0 d3
:7 0 d6 d4 0
4ade 0 32 :6 0
18 :2 0 7f 25
:3 0 d8 :7 0 db
d9 0 4ade 0
33 :6 0 25 :3 0
dd :7 0 e0 de
0 4ade 0 34
:6 0 37 :2 0 83
4 :3 0 81 e2
e4 :6 0 e7 e5
0 4ade 0 35
:6 0 37 :2 0 87
4 :3 0 85 e9
eb :6 0 ee ec
0 4ade 0 36
:6 0 37 :2 0 8b
4 :3 0 89 f0
f2 :6 0 f5 f3
0 4ade 0 38
:6 0 3b :2 0 8f
4 :3 0 8d f7
f9 :6 0 fc fa
0 4ade 0 39
:6 0 3d :2 0 93
4 :3 0 91 fe
100 :6 0 103 101
0 4ade 0 3a
:6 0 3d :2 0 95
a :3 0 105 :7 0
109 106 107 4ade
0 3c :6 0 3d
:2 0 97 a :3 0
10b :7 0 10f 10c
10d 4ade 0 3e
:6 0 3d :2 0 99
a :3 0 111 :7 0
115 112 113 4ade
0 3f :6 0 3d
:2 0 9b a :3 0
117 :7 0 11b 118
119 4ade 0 40
:6 0 3d :2 0 9d
a :3 0 11d :7 0
121 11e 11f 4ade
0 41 :6 0 3d
:2 0 9f a :3 0
123 :7 0 127 124
125 4ade 0 42
:6 0 3d :2 0 a1
a :3 0 129 :7 0
12d 12a 12b 4ade
0 43 :6 0 3d
:2 0 a3 a :3 0
12f :7 0 133 130
131 4ade 0 44
:6 0 3d :2 0 a5
a :3 0 135 :7 0
139 136 137 4ade
0 45 :6 0 3d
:2 0 a7 a :3 0
13b :7 0 13f 13c
13d 4ade 0 46
:6 0 3d :2 0 a9
a :3 0 141 :7 0
145 142 143 4ade
0 47 :6 0 3d
:2 0 ab a :3 0
147 :7 0 14b 148
149 4ade 0 48
:6 0 3d :2 0 ad
a :3 0 14d :7 0
151 14e 14f 4ade
0 49 :6 0 3d
:2 0 af a :3 0
153 :7 0 157 154
155 4ade 0 4a
:6 0 3d :2 0 b1
a :3 0 159 :7 0
15d 15a 15b 4ade
0 4b :6 0 3d
:2 0 b3 a :3 0
15f :7 0 163 160
161 4ade 0 4c
:6 0 3d :2 0 b5
a :3 0 165 :7 0
169 166 167 4ade
0 4d :6 0 3d
:2 0 b7 a :3 0
16b :7 0 16f 16c
16d 4ade 0 4e
:6 0 3d :2 0 b9
a :3 0 171 :7 0
175 172 173 4ade
0 4f :6 0 3d
:2 0 bb a :3 0
177 :7 0 17b 178
179 4ade 0 50
:6 0 3d :2 0 bd
a :3 0 17d :7 0
181 17e 17f 4ade
0 51 :6 0 3d
:2 0 bf a :3 0
183 :7 0 187 184
185 4ade 0 52
:6 0 3d :2 0 c1
a :3 0 189 :7 0
18d 18a 18b 4ade
0 53 :6 0 3d
:2 0 c3 a :3 0
18f :7 0 193 190
191 4ade 0 54
:6 0 3d :2 0 c5
a :3 0 195 :7 0
199 196 197 4ade
0 55 :6 0 3d
:2 0 c7 a :3 0
19b :7 0 19f 19c
19d 4ade 0 56
:6 0 5a :2 0 c9
a :3 0 1a1 :7 0
1a5 1a2 1a3 4ade
0 57 :6 0 5a
:2 0 cb 59 :3 0
1a7 :7 0 1ab 1a8
1a9 4ade 0 58
:6 0 5a :2 0 cd
59 :3 0 1ad :7 0
1b1 1ae 1af 4ade
0 5b :6 0 5a
:2 0 cf 59 :3 0
1b3 :7 0 1b7 1b4
1b5 4ade 0 5c
:6 0 5a :2 0 d1
59 :3 0 1b9 :7 0
1bd 1ba 1bb 4ade
0 5d :6 0 3d
:2 0 d3 59 :3 0
1bf :7 0 1c3 1c0
1c1 4ade 0 5e
:6 0 3d :2 0 d5
a :3 0 1c5 :7 0
1c9 1c6 1c7 4ade
0 5f :6 0 3d
:2 0 d7 a :3 0
1cb :7 0 1cf 1cc
1cd 4ade 0 60
:6 0 3d :2 0 d9
a :3 0 1d1 :7 0
1d5 1d2 1d3 4ade
0 61 :6 0 3d
:2 0 db a :3 0
1d7 :7 0 1db 1d8
1d9 4ade 0 62
:6 0 3d :2 0 dd
a :3 0 1dd :7 0
1e1 1de 1df 4ade
0 63 :6 0 3d
:2 0 df a :3 0
1e3 :7 0 1e7 1e4
1e5 4ade 0 64
:6 0 3d :2 0 e1
a :3 0 1e9 :7 0
1ed 1ea 1eb 4ade
0 65 :6 0 68
:2 0 e3 a :3 0
1ef :7 0 1f3 1f0
1f1 4ade 0 66
:6 0 68 :2 0 e7
4 :3 0 e5 1f5
1f7 :6 0 1fa 1f8
0 4ade 0 67
:6 0 3d :2 0 eb
4 :3 0 e9 1fc
1fe :6 0 201 1ff
0 4ade 0 69
:6 0 3d :2 0 ed
59 :3 0 203 :7 0
207 204 205 4ade
0 6a :6 0 2a
:2 0 ef a :3 0
209 :7 0 20d 20a
20b 4ade 0 6b
:6 0 3d :2 0 f3
4 :3 0 f1 20f
211 :6 0 214 212
0 4ade 0 6c
:6 0 18 :2 0 f5
a :3 0 216 :7 0
21a 217 218 4ade
0 6d :6 0 2a
:2 0 f9 4 :3 0
f7 21c 21e :6 0
221 21f 0 4ade
0 6e :6 0 3d
:2 0 fd 4 :3 0
fb 223 225 :6 0
228 226 0 4ade
0 6f :6 0 3d
:2 0 ff a :3 0
22a :7 0 22e 22b
22c 4ade 0 70
:6 0 103 a19 0
101 a :3 0 230
:7 0 234 231 232
4ade 0 71 :6 0
3d :2 0 105 2c
:3 0 236 :7 0 239
237 0 4ade 0
72 :6 0 2c :3 0
23b :7 0 23e 23c
0 4ade 0 73
:6 0 3d :2 0 107
59 :3 0 240 :7 0
244 241 242 4ade
0 74 :6 0 3d
:2 0 109 59 :3 0
246 :7 0 24a 247
248 4ade 0 75
:6 0 3d :2 0 10b
a :3 0 24c :7 0
250 24d 24e 4ade
0 76 :6 0 3d
:2 0 10d a :3 0
252 :7 0 256 253
254 4ade 0 77
:6 0 3d :2 0 10f
a :3 0 258 :7 0
25c 259 25a 4ade
0 78 :6 0 3d
:2 0 111 a :3 0
25e :7 0 262 25f
260 4ade 0 79
:6 0 3d :2 0 113
a :3 0 264 :7 0
268 265 266 4ade
0 7a :6 0 3d
:2 0 115 a :3 0
26a :7 0 26e 26b
26c 4ade 0 7b
:6 0 3d :2 0 117
a :3 0 270 :7 0
274 271 272 4ade
0 7c :6 0 3d
:2 0 119 a :3 0
276 :7 0 27a 277
278 4ade 0 7d
:6 0 18 :2 0 11b
a :3 0 27c :7 0
280 27d 27e 4ade
0 7e :6 0 18
:2 0 11f 4 :3 0
11d 282 284 :6 0
287 285 0 4ade
0 7f :6 0 18
:2 0 123 4 :3 0
121 289 28b :6 0
28e 28c 0 4ade
0 80 :6 0 3d
:2 0 127 4 :3 0
125 290 292 :6 0
295 293 0 4ade
0 81 :6 0 3d
:2 0 12e a :3 0
297 0 2 :5 0
83 :3 0 84 :3 0
42 :3 0 129 29a
29d 12c 299 29f
2a0 :2 0 2a3 298
2a1 4ade 0 82
:6 0 3d :2 0 130
a :3 0 2a5 0
2 :5 0 2a9 2a6
2a7 4ade 0 85
:9 0 132 a :3 0
2ab 0 2 :5 0
2af 2ac 2ad 4ade
0 86 :6 0 87
:3 0 88 :a 0 2
2bb :4 0 2b1 2b4
0 2b2 :3 0 89
:3 0 8a :3 0 8b
:3 0 21 :3 0 8c
:4 0 8d 1 :8 0
2bc 2b1 2b4 2bd
0 4ade 134 2bd
2bf 2bc 2be :6 0
2bb :7 0 2bd 87
:3 0 8e :a 0 3
2cf :5 0 2c1 2c4
0 2c2 :3 0 8f
:3 0 90 :3 0 91
:3 0 22 :3 0 92
:3 0 21 :3 0 93
:3 0 94 :3 0 8c
:4 0 95 1 :8 0
2d0 2c1 2c4 2d1
0 4ade 136 2d1
2d3 2d0 2d2 :6 0
2cf :7 0 2d1 87
:3 0 96 :a 0 4
347 :5 0 2d5 2d8
0 2d6 :3 0 97
:3 0 98 :3 0 99
:3 0 9a :3 0 99
:3 0 9b :3 0 97
:3 0 9c :3 0 99
:3 0 9d :3 0 99
:3 0 9e :3 0 9f
:3 0 a0 :3 0 99
:3 0 a1 :3 0 9f
:3 0 a0 :3 0 99
:3 0 a2 :3 0 99
:3 0 a1 :3 0 99
:3 0 a2 :3 0 99
:3 0 a3 :3 0 a4
:3 0 a3 :3 0 99
:3 0 a3 :3 0 99
:3 0 94 :3 0 99
:3 0 a5 :3 0 99
:3 0 a6 :3 0 99
:3 0 a7 :3 0 99
:3 0 a8 :3 0 99
:3 0 a9 :3 0 99
:3 0 aa :3 0 99
:3 0 ab :3 0 99
:3 0 ac :3 0 99
:3 0 ad :3 0 ae
:3 0 a4 :3 0 af
:3 0 97 :3 0 90
:3 0 99 :3 0 97
:3 0 91 :3 0 22
:3 0 97 :3 0 92
:3 0 23 :3 0 97
:3 0 93 :3 0 99
:3 0 98 :3 0 97
:3 0 98 :3 0 97
:3 0 8b :3 0 a4
:3 0 8b :3 0 97
:3 0 9c :3 0 b0
:3 0 b1 :3 0 b0
:3 0 b2 :3 0 b0
:3 0 b3 :3 0 b0
:3 0 b4 :3 0 b0
:3 0 b5 :3 0 b0
:3 0 b6 :3 0 b0
:3 0 b7 :3 0 b0
:3 0 b8 :3 0 b0
:3 0 b9 :3 0 b0
:3 0 ba :3 0 b0
:3 0 bb :3 0 b0
:3 0 bc :3 0 b0
:3 0 bd :3 0 b0
:3 0 be :3 0 b0
:3 0 bf :3 0 a4
:3 0 c0 :3 0 2f
:3 0 99 :3 0 a1
:4 0 c1 1 :8 0
348 2d5 2d8 349
0 4ade 138 349
34b 348 34a :6 0
347 :7 0 349 353
354 0 13a 15
:3 0 16 :2 0 4
34d 34e 0 34f
:7 0 352 350 0
4ade 0 c2 :6 0
c3 :3 0 c4 :3 0
c3 :3 0 c5 :3 0
356 357 0 2
:4 0 13c 358 35a
355 35c 35b :2 0
c6 :3 0 c7 :3 0
35e 35f 0 c8
:4 0 c3 :3 0 c9
:3 0 362 363 0
2 :4 0 13e 364
366 ca :4 0 cb
:2 0 cc :3 0 140
369 36b :3 0 cd
:4 0 cb :2 0 ce
:4 0 143 36e 370
:3 0 cb :2 0 3
:3 0 146 372 374
:3 0 cb :2 0 ce
:4 0 149 376 378
:3 0 cb :2 0 cf
:4 0 14c 37a 37c
:3 0 cb :2 0 ce
:4 0 14f 37e 380
:3 0 cb :2 0 5
:3 0 152 382 384
:3 0 cb :2 0 ce
:4 0 155 386 388
:3 0 cb :2 0 cf
:4 0 158 38a 38c
:3 0 cb :2 0 ce
:4 0 15b 38e 390
:3 0 cb :2 0 6
:3 0 15e 392 394
:3 0 cb :2 0 ce
:4 0 161 396 398
:3 0 cb :2 0 cf
:4 0 164 39a 39c
:3 0 cb :2 0 ce
:4 0 167 39e 3a0
:3 0 cb :2 0 7
:3 0 16a 3a2 3a4
:3 0 cb :2 0 ce
:4 0 16d 3a6 3a8
:3 0 cb :2 0 cf
:4 0 170 3aa 3ac
:3 0 cb :2 0 ce
:4 0 173 3ae 3b0
:3 0 cb :2 0 8
:3 0 176 3b2 3b4
:3 0 cb :2 0 ce
:4 0 179 3b6 3b8
:3 0 cb :2 0 cf
:4 0 17c 3ba 3bc
:3 0 cb :2 0 84
:3 0 d0 :3 0 9
:3 0 17f 3c0 3c2
d1 :4 0 181 3bf
3c5 184 3be 3c7
:3 0 cb :2 0 cf
:4 0 187 3c9 3cb
:3 0 cb :2 0 84
:3 0 d0 :3 0 b
:3 0 18a 3cf 3d1
d1 :4 0 18c 3ce
3d4 18f 3cd 3d6
:3 0 cb :2 0 cf
:4 0 192 3d8 3da
:3 0 cb :2 0 84
:3 0 d0 :3 0 c
:3 0 195 3de 3e0
d1 :4 0 197 3dd
3e3 19a 3dc 3e5
:3 0 cb :2 0 cf
:4 0 19d 3e7 3e9
:3 0 cb :2 0 84
:3 0 d0 :3 0 d
:3 0 1a0 3ed 3ef
d1 :4 0 1a2 3ec
3f2 1a5 3eb 3f4
:3 0 cb :2 0 cf
:4 0 1a8 3f6 3f8
:3 0 cb :2 0 84
:3 0 d0 :3 0 e
:3 0 1ab 3fc 3fe
d1 :4 0 1ad 3fb
401 1b0 3fa 403
:3 0 cb :2 0 cf
:4 0 1b3 405 407
:3 0 cb :2 0 84
:3 0 d0 :3 0 f
:3 0 1b6 40b 40d
d1 :4 0 1b8 40a
410 1bb 409 412
:3 0 cb :2 0 cf
:4 0 1be 414 416
:3 0 cb :2 0 84
:3 0 d0 :3 0 10
:3 0 1c1 41a 41c
d1 :4 0 1c3 419
41f 1c6 418 421
:3 0 cb :2 0 cf
:4 0 1c9 423 425
:3 0 cb :2 0 84
:3 0 d0 :3 0 11
:3 0 1cc 429 42b
d1 :4 0 1ce 428
42e 1d1 427 430
:3 0 cb :2 0 cf
:4 0 1d4 432 434
:3 0 cb :2 0 84
:3 0 d0 :3 0 12
:3 0 1d7 438 43a
d1 :4 0 1d9 437
43d 1dc 436 43f
:3 0 cb :2 0 cf
:4 0 1df 441 443
:3 0 cb :2 0 ce
:4 0 1e2 445 447
:3 0 cb :2 0 13
:3 0 1e5 449 44b
:3 0 cb :2 0 ce
:4 0 1e8 44d 44f
:3 0 cb :2 0 d2
:4 0 1eb 451 453
:3 0 1ee 360 455
:2 0 457 1f3 458
35d 457 0 459
1f5 0 4a3e c3
:3 0 c4 :3 0 45a
45b 0 c3 :3 0
d3 :3 0 45d 45e
0 2a :2 0 2
:4 0 d4 :2 0 d5
:2 0 2a :2 0 1f7
463 465 :3 0 1fa
45f 467 45c 469
468 :2 0 c6 :3 0
d6 :3 0 46b 46c
0 c8 :4 0 d7
:4 0 cb :2 0 cc
:3 0 1fe 470 472
:3 0 201 46d 474
:2 0 476 204 477
46a 476 0 478
206 0 4a3e 20
:3 0 3 :3 0 479
47a 0 4a3e 23
:3 0 5 :3 0 47c
47d 0 4a3e 21
:3 0 6 :3 0 47f
480 0 4a3e 1a
:3 0 13 :3 0 482
483 0 4a3e 31
:3 0 7 :3 0 485
486 0 4a3e 52
:3 0 11 :3 0 488
489 0 4a3e 52
:3 0 d8 :3 0 84
:3 0 52 :3 0 3d
:2 0 208 48d 490
b0 :3 0 d9 :3 0
492 493 0 20b
48c 495 48b 496
0 4a3e 84 :3 0
52 :3 0 3d :2 0
20e 498 49b b0
:3 0 da :2 0 db
:3 0 49d 49f 0
213 49e 4a1 :3 0
4a2 :2 0 84 :3 0
52 :3 0 3d :2 0
216 4a4 4a7 b0
:3 0 da :2 0 dc
:3 0 4a9 4ab 0
21b 4aa 4ad :3 0
4ae :2 0 4a3 4b0
4af :2 0 52 :3 0
dd :2 0 4b2 4b3
0 4b5 21e 4b6
4b1 4b5 0 4b7
220 0 4a3e 32
:3 0 31 :3 0 4b8
4b9 0 4a3e 3a
:3 0 de :4 0 4bb
4bc 0 4a3e 29
:3 0 de :4 0 4be
4bf 0 4a3e 45
:3 0 3d :2 0 4c1
4c2 0 4a3e 26
:3 0 de :4 0 4c4
4c5 0 4a3e 33
:4 0 4c7 4c8 0
4a3e 34 :4 0 4ca
4cb 0 4a3e df
:3 0 88 :4 0 4d0
:2 0 4a3e 4ce 4d1
:3 0 88 :3 0 56
:4 0 4d5 :2 0 4a3e
4d2 4d3 :3 0 88
:3 0 e0 :3 0 4d6
4d7 :3 0 15 :3 0
e1 :3 0 4d9 4da
0 3d :2 0 4db
4dc 0 4de 222
4e5 15 :3 0 e1
:3 0 4df 4e0 0
e2 :2 0 4e1 4e2
0 4e4 224 4e6
4d8 4de 0 4e7
0 4e4 0 4e7
226 0 4a3e 56
:3 0 15 :3 0 e1
:3 0 4e9 4ea 0
4e8 4eb 0 4a3e
e3 :3 0 88 :4 0
4f0 :2 0 4f6 4ee
0 15 :3 0 e1
:3 0 4f1 4f2 0
e4 :3 0 4f3 4f4
0 4f6 229 540
e5 :3 0 15 :3 0
e1 :3 0 4f9 4fa
0 e4 :3 0 4fb
4fc 0 536 c3
:3 0 c4 :3 0 4fe
4ff 0 c3 :3 0
d3 :3 0 501 502
0 e6 :2 0 2
:4 0 e7 :2 0 d5
:2 0 2a :2 0 22c
507 509 :3 0 22f
503 50b 500 50d
50c :2 0 c6 :3 0
d6 :3 0 50f 510
0 c8 :4 0 e8
:4 0 cb :2 0 cc
:3 0 233 514 516
:3 0 cb :2 0 e9
:4 0 236 518 51a
:3 0 cb :2 0 ea
:4 0 239 51c 51e
:3 0 cb :2 0 e4
:3 0 23c 520 522
:3 0 cb :2 0 eb
:4 0 23f 524 526
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 242
529 52d 246 528
52f :3 0 249 511
531 :2 0 533 24c
534 50e 533 0
535 24e 0 536
250 539 :3 0 539
0 539 538 536
537 :6 0 53b 5
:3 0 253 53d 255
53c 53b :2 0 53e
257 :2 0 540 0
540 53f 4f6 53e
:6 0 4a3e 1 :3 0
84 :3 0 56 :3 0
3d :2 0 259 542
545 da :2 0 e2
:2 0 25e 547 549
:3 0 c3 :3 0 c4
:3 0 54b 54c 0
c3 :3 0 d3 :3 0
54e 54f 0 18
:2 0 2 :4 0 ee
:2 0 d5 :2 0 2a
:2 0 261 554 556
:3 0 264 550 558
54d 55a 559 :2 0
c6 :3 0 d6 :3 0
55c 55d 0 c8
:4 0 ef :4 0 cb
:2 0 cc :3 0 268
561 563 :3 0 cb
:2 0 e9 :4 0 26b
565 567 :3 0 cb
:2 0 f0 :4 0 26e
569 56b :3 0 cb
:2 0 84 :3 0 d0
:3 0 b0 :3 0 f1
:3 0 570 571 0
271 56f 573 d1
:4 0 273 56e 576
276 56d 578 :3 0
cb :2 0 f2 :4 0
279 57a 57c :3 0
cb :2 0 ce :4 0
27c 57e 580 :3 0
cb :2 0 21 :3 0
27f 582 584 :3 0
cb :2 0 ce :4 0
282 586 588 :3 0
285 55e 58a :2 0
58c 288 58d 55b
58c 0 58e 28a
0 5b8 c3 :3 0
c4 :3 0 58f 590
0 c3 :3 0 d3
:3 0 592 593 0
2a :2 0 2 :4 0
f3 :2 0 d5 :2 0
2a :2 0 28c 598
59a :3 0 28f 594
59c 591 59e 59d
:2 0 c6 :3 0 d6
:3 0 5a0 5a1 0
c8 :4 0 f4 :4 0
cb :2 0 cc :3 0
293 5a5 5a7 :3 0
296 5a2 5a9 :2 0
5ab 299 5ac 59f
5ab 0 5ad 29b
0 5b8 f5 :3 0
f6 :3 0 5ae 5af
0 b0 :3 0 f1
:3 0 5b1 5b2 0
21 :3 0 f7 :3 0
29d 5b0 5b6 :2 0
5b8 2a1 5b9 54a
5b8 0 5ba 2a5
0 4a3e f8 :3 0
c0 :3 0 91 :3 0
f9 :3 0 fa :3 0
fb :3 0 fc :3 0
42 :3 0 2f :3 0
22 :3 0 7f :3 0
80 :3 0 7d :3 0
49 :3 0 ae :3 0
8b :3 0 20 :4 0
fd 1 :8 0 5d2
15 :3 0 e1 :3 0
5cd 5ce 0 e4
:3 0 5cf 5d0 0
5d2 2a7 61c e5
:3 0 15 :3 0 e1
:3 0 5d5 5d6 0
e4 :3 0 5d7 5d8
0 612 c3 :3 0
c4 :3 0 5da 5db
0 c3 :3 0 d3
:3 0 5dd 5de 0
e6 :2 0 2 :4 0
fe :2 0 d5 :2 0
2a :2 0 2aa 5e3
5e5 :3 0 2ad 5df
5e7 5dc 5e9 5e8
:2 0 c6 :3 0 d6
:3 0 5eb 5ec 0
c8 :4 0 ff :4 0
cb :2 0 cc :3 0
2b1 5f0 5f2 :3 0
cb :2 0 e9 :4 0
2b4 5f4 5f6 :3 0
cb :2 0 ea :4 0
2b7 5f8 5fa :3 0
cb :2 0 e4 :3 0
2ba 5fc 5fe :3 0
cb :2 0 eb :4 0
2bd 600 602 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 2c0 605
609 2c4 604 60b
:3 0 2c7 5ed 60d
:2 0 60f 2ca 610
5ea 60f 0 611
2cc 0 612 2ce
615 :3 0 615 0
615 614 612 613
:6 0 617 7 :3 0
2d1 619 2d3 618
617 :2 0 61a 2d5
:2 0 61c 0 61c
61b 5d2 61a :6 0
4a3e 1 :3 0 15
:3 0 e1 :3 0 61e
61f 0 15 :3 0
da :2 0 100 :3 0
621 623 0 2d9
622 625 :3 0 626
:2 0 c3 :3 0 c4
:3 0 628 629 0
c3 :3 0 d3 :3 0
62b 62c 0 18
:2 0 2 :4 0 101
:2 0 d5 :2 0 2a
:2 0 2dc 631 633
:3 0 2df 62d 635
62a 637 636 :2 0
c6 :3 0 d6 :3 0
639 63a 0 c8
:4 0 102 :4 0 cb
:2 0 cc :3 0 2e3
63e 640 :3 0 cb
:2 0 e9 :4 0 2e6
642 644 :3 0 cb
:2 0 f0 :4 0 2e9
646 648 :3 0 cb
:2 0 84 :3 0 d0
:3 0 b0 :3 0 f1
:3 0 64d 64e 0
2ec 64c 650 d1
:4 0 2ee 64b 653
2f1 64a 655 :3 0
cb :2 0 f2 :4 0
2f4 657 659 :3 0
cb :2 0 ce :4 0
2f7 65b 65d :3 0
cb :2 0 20 :3 0
2fa 65f 661 :3 0
cb :2 0 ce :4 0
2fd 663 665 :3 0
300 63b 667 :2 0
669 303 66a 638
669 0 66b 305
0 695 c3 :3 0
c4 :3 0 66c 66d
0 c3 :3 0 d3
:3 0 66f 670 0
2a :2 0 2 :4 0
103 :2 0 d5 :2 0
2a :2 0 307 675
677 :3 0 30a 671
679 66e 67b 67a
:2 0 c6 :3 0 d6
:3 0 67d 67e 0
c8 :4 0 104 :4 0
cb :2 0 cc :3 0
30e 682 684 :3 0
311 67f 686 :2 0
688 314 689 67c
688 0 68a 316
0 695 f5 :3 0
f6 :3 0 68b 68c
0 b0 :3 0 f1
:3 0 68e 68f 0
20 :3 0 f7 :3 0
318 68d 693 :2 0
695 31c 696 627
695 0 697 320
0 4a3e 6b :3 0
3d :2 0 698 699
0 4a3e 105 :3 0
6b :3 0 106 :3 0
91 :3 0 22 :4 0
107 1 :8 0 6a6
15 :3 0 e1 :3 0
6a1 6a2 0 e4
:3 0 6a3 6a4 0
6a6 322 6f0 e5
:3 0 15 :3 0 e1
:3 0 6a9 6aa 0
e4 :3 0 6ab 6ac
0 6e6 c3 :3 0
c4 :3 0 6ae 6af
0 c3 :3 0 d3
:3 0 6b1 6b2 0
e6 :2 0 2 :4 0
108 :2 0 d5 :2 0
2a :2 0 325 6b7
6b9 :3 0 328 6b3
6bb 6b0 6bd 6bc
:2 0 c6 :3 0 d6
:3 0 6bf 6c0 0
c8 :4 0 109 :4 0
cb :2 0 cc :3 0
32c 6c4 6c6 :3 0
cb :2 0 e9 :4 0
32f 6c8 6ca :3 0
cb :2 0 ea :4 0
332 6cc 6ce :3 0
cb :2 0 e4 :3 0
335 6d0 6d2 :3 0
cb :2 0 eb :4 0
338 6d4 6d6 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 33b 6d9
6dd 33f 6d8 6df
:3 0 342 6c1 6e1
:2 0 6e3 345 6e4
6be 6e3 0 6e5
347 0 6e6 349
6e9 :3 0 6e9 0
6e9 6e8 6e6 6e7
:6 0 6eb 9 :3 0
34c 6ed 34e 6ec
6eb :2 0 6ee 350
:2 0 6f0 0 6f0
6ef 6a6 6ee :6 0
4a3e 1 :3 0 84
:3 0 6b :3 0 3d
:2 0 352 6f2 6f5
10a :2 0 3d :2 0
357 6f7 6f9 :3 0
c3 :3 0 c4 :3 0
6fb 6fc 0 c3
:3 0 d3 :3 0 6fe
6ff 0 18 :2 0
2 :4 0 10b :2 0
d5 :2 0 2a :2 0
35a 704 706 :3 0
35d 700 708 6fd
70a 709 :2 0 c6
:3 0 d6 :3 0 70c
70d 0 c8 :4 0
10c :4 0 cb :2 0
cc :3 0 361 711
713 :3 0 cb :2 0
e9 :4 0 364 715
717 :3 0 cb :2 0
f0 :4 0 367 719
71b :3 0 cb :2 0
84 :3 0 d0 :3 0
b0 :3 0 10d :3 0
720 721 0 36a
71f 723 d1 :4 0
36c 71e 726 36f
71d 728 :3 0 cb
:2 0 f2 :4 0 372
72a 72c :3 0 cb
:2 0 ce :4 0 375
72e 730 :3 0 cb
:2 0 22 :3 0 378
732 734 :3 0 cb
:2 0 ce :4 0 37b
736 738 :3 0 37e
70e 73a :2 0 73c
381 73d 70b 73c
0 73e 383 0
768 c3 :3 0 c4
:3 0 73f 740 0
c3 :3 0 d3 :3 0
742 743 0 2a
:2 0 2 :4 0 10e
:2 0 d5 :2 0 2a
:2 0 385 748 74a
:3 0 388 744 74c
741 74e 74d :2 0
c6 :3 0 d6 :3 0
750 751 0 c8
:4 0 10f :4 0 cb
:2 0 cc :3 0 38c
755 757 :3 0 38f
752 759 :2 0 75b
392 75c 74f 75b
0 75d 394 0
768 f5 :3 0 f6
:3 0 75e 75f 0
b0 :3 0 10d :3 0
761 762 0 22
:3 0 f7 :3 0 396
760 766 :2 0 768
39a 769 6fa 768
0 76a 39e 0
4a3e 110 :3 0 f8
:3 0 110 :3 0 111
:3 0 84 :3 0 110
:3 0 112 :3 0 84
:3 0 110 :3 0 113
:3 0 110 :3 0 114
:3 0 110 :3 0 115
:3 0 116 :3 0 117
:3 0 118 :3 0 119
:3 0 41 :3 0 65
:3 0 4f :3 0 50
:3 0 53 :3 0 5f
:3 0 5e :3 0 ae
:3 0 110 :3 0 11a
:3 0 11b :3 0 118
:3 0 110 :3 0 115
:3 0 118 :3 0 8b
:3 0 110 :3 0 8b
:3 0 22 :4 0 11c
1 :8 0 796 15
:3 0 e1 :3 0 791
792 0 e4 :3 0
793 794 0 796
3a0 7e0 e5 :3 0
15 :3 0 e1 :3 0
799 79a 0 e4
:3 0 79b 79c 0
7d6 c3 :3 0 c4
:3 0 79e 79f 0
c3 :3 0 d3 :3 0
7a1 7a2 0 e6
:2 0 2 :4 0 11d
:2 0 d5 :2 0 2a
:2 0 3a3 7a7 7a9
:3 0 3a6 7a3 7ab
7a0 7ad 7ac :2 0
c6 :3 0 d6 :3 0
7af 7b0 0 c8
:4 0 11e :4 0 cb
:2 0 cc :3 0 3aa
7b4 7b6 :3 0 cb
:2 0 e9 :4 0 3ad
7b8 7ba :3 0 cb
:2 0 ea :4 0 3b0
7bc 7be :3 0 cb
:2 0 e4 :3 0 3b3
7c0 7c2 :3 0 cb
:2 0 eb :4 0 3b6
7c4 7c6 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 3b9 7c9 7cd
3bd 7c8 7cf :3 0
3c0 7b1 7d1 :2 0
7d3 3c3 7d4 7ae
7d3 0 7d5 3c5
0 7d6 3c7 7d9
:3 0 7d9 0 7d9
7d8 7d6 7d7 :6 0
7db b :3 0 3ca
7dd 3cc 7dc 7db
:2 0 7de 3ce :2 0
7e0 0 7e0 7df
796 7de :6 0 4a3e
1 :3 0 15 :3 0
e1 :3 0 7e2 7e3
0 15 :3 0 da
:2 0 100 :3 0 7e5
7e7 0 3d2 7e6
7e9 :3 0 7ea :2 0
c3 :3 0 c4 :3 0
7ec 7ed 0 c3
:3 0 d3 :3 0 7ef
7f0 0 18 :2 0
2 :4 0 11f :2 0
d5 :2 0 2a :2 0
3d5 7f5 7f7 :3 0
3d8 7f1 7f9 7ee
7fb 7fa :2 0 c6
:3 0 d6 :3 0 7fd
7fe 0 c8 :4 0
120 :4 0 cb :2 0
cc :3 0 3dc 802
804 :3 0 cb :2 0
e9 :4 0 3df 806
808 :3 0 cb :2 0
f0 :4 0 3e2 80a
80c :3 0 cb :2 0
84 :3 0 d0 :3 0
b0 :3 0 f1 :3 0
811 812 0 3e5
810 814 d1 :4 0
3e7 80f 817 3ea
80e 819 :3 0 cb
:2 0 f2 :4 0 3ed
81b 81d :3 0 cb
:2 0 ce :4 0 3f0
81f 821 :3 0 cb
:2 0 20 :3 0 3f3
823 825 :3 0 cb
:2 0 ce :4 0 3f6
827 829 :3 0 3f9
7ff 82b :2 0 82d
3fc 82e 7fc 82d
0 82f 3fe 0
859 c3 :3 0 c4
:3 0 830 831 0
c3 :3 0 d3 :3 0
833 834 0 2a
:2 0 2 :4 0 121
:2 0 d5 :2 0 2a
:2 0 400 839 83b
:3 0 403 835 83d
832 83f 83e :2 0
c6 :3 0 d6 :3 0
841 842 0 c8
:4 0 122 :4 0 cb
:2 0 cc :3 0 407
846 848 :3 0 40a
843 84a :2 0 84c
40d 84d 840 84c
0 84e 40f 0
859 f5 :3 0 f6
:3 0 84f 850 0
b0 :3 0 f1 :3 0
852 853 0 20
:3 0 f7 :3 0 411
851 857 :2 0 859
415 85a 7eb 859
0 85b 419 0
4a3e 123 :3 0 124
:3 0 36 :3 0 3a
:3 0 125 :3 0 92
:3 0 21 :4 0 126
1 :8 0 869 15
:3 0 e1 :3 0 864
865 0 e4 :3 0
866 867 0 869
41b 8b3 e5 :3 0
15 :3 0 e1 :3 0
86c 86d 0 e4
:3 0 86e 86f 0
8a9 c3 :3 0 c4
:3 0 871 872 0
c3 :3 0 d3 :3 0
874 875 0 e6
:2 0 2 :4 0 127
:2 0 d5 :2 0 2a
:2 0 41e 87a 87c
:3 0 421 876 87e
873 880 87f :2 0
c6 :3 0 d6 :3 0
882 883 0 c8
:4 0 128 :4 0 cb
:2 0 cc :3 0 425
887 889 :3 0 cb
:2 0 e9 :4 0 428
88b 88d :3 0 cb
:2 0 ea :4 0 42b
88f 891 :3 0 cb
:2 0 e4 :3 0 42e
893 895 :3 0 cb
:2 0 eb :4 0 431
897 899 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 434 89c 8a0
438 89b 8a2 :3 0
43b 884 8a4 :2 0
8a6 43e 8a7 881
8a6 0 8a8 440
0 8a9 442 8ac
:3 0 8ac 0 8ac
8ab 8a9 8aa :6 0
8ae d :3 0 445
8b0 447 8af 8ae
:2 0 8b1 449 :2 0
8b3 0 8b3 8b2
869 8b1 :6 0 4a3e
1 :3 0 15 :3 0
e1 :3 0 8b5 8b6
0 15 :3 0 da
:2 0 100 :3 0 8b8
8ba 0 44d 8b9
8bc :3 0 8bd :2 0
c3 :3 0 c4 :3 0
8bf 8c0 0 c3
:3 0 d3 :3 0 8c2
8c3 0 18 :2 0
2 :4 0 129 :2 0
d5 :2 0 2a :2 0
450 8c8 8ca :3 0
453 8c4 8cc 8c1
8ce 8cd :2 0 c6
:3 0 d6 :3 0 8d0
8d1 0 c8 :4 0
12a :4 0 cb :2 0
cc :3 0 457 8d5
8d7 :3 0 cb :2 0
e9 :4 0 45a 8d9
8db :3 0 cb :2 0
f0 :4 0 45d 8dd
8df :3 0 cb :2 0
84 :3 0 d0 :3 0
b0 :3 0 f1 :3 0
8e4 8e5 0 460
8e3 8e7 d1 :4 0
462 8e2 8ea 465
8e1 8ec :3 0 cb
:2 0 f2 :4 0 468
8ee 8f0 :3 0 cb
:2 0 ce :4 0 46b
8f2 8f4 :3 0 cb
:2 0 21 :3 0 46e
8f6 8f8 :3 0 cb
:2 0 ce :4 0 471
8fa 8fc :3 0 474
8d2 8fe :2 0 900
477 901 8cf 900
0 902 479 0
92c c3 :3 0 c4
:3 0 903 904 0
c3 :3 0 d3 :3 0
906 907 0 2a
:2 0 2 :4 0 12b
:2 0 d5 :2 0 2a
:2 0 47b 90c 90e
:3 0 47e 908 910
905 912 911 :2 0
c6 :3 0 d6 :3 0
914 915 0 c8
:4 0 12c :4 0 cb
:2 0 cc :3 0 482
919 91b :3 0 485
916 91d :2 0 91f
488 920 913 91f
0 921 48a 0
92c f5 :3 0 f6
:3 0 922 923 0
b0 :3 0 f1 :3 0
925 926 0 21
:3 0 f7 :3 0 48c
924 92a :2 0 92c
490 92d 8be 92c
0 92e 494 0
4a3e 12d :3 0 35
:3 0 12e :3 0 12f
:3 0 23 :4 0 130
1 :8 0 93a 15
:3 0 e1 :3 0 935
936 0 e4 :3 0
937 938 0 93a
496 984 e5 :3 0
15 :3 0 e1 :3 0
93d 93e 0 e4
:3 0 93f 940 0
97a c3 :3 0 c4
:3 0 942 943 0
c3 :3 0 d3 :3 0
945 946 0 e6
:2 0 2 :4 0 131
:2 0 d5 :2 0 2a
:2 0 499 94b 94d
:3 0 49c 947 94f
944 951 950 :2 0
c6 :3 0 d6 :3 0
953 954 0 c8
:4 0 132 :4 0 cb
:2 0 cc :3 0 4a0
958 95a :3 0 cb
:2 0 e9 :4 0 4a3
95c 95e :3 0 cb
:2 0 ea :4 0 4a6
960 962 :3 0 cb
:2 0 e4 :3 0 4a9
964 966 :3 0 cb
:2 0 eb :4 0 4ac
968 96a :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 4af 96d 971
4b3 96c 973 :3 0
4b6 955 975 :2 0
977 4b9 978 952
977 0 979 4bb
0 97a 4bd 97d
:3 0 97d 0 97d
97c 97a 97b :6 0
97f f :3 0 4c0
981 4c2 980 97f
:2 0 982 4c4 :2 0
984 0 984 983
93a 982 :6 0 4a3e
1 :3 0 116 :3 0
133 :3 0 986 987
0 35 :3 0 134
:4 0 4c6 988 98b
da :2 0 3d :2 0
4cb 98d 98f :3 0
35 :3 0 de :4 0
991 992 0 994
4ce 995 990 994
0 996 4d0 0
4a3e 15 :3 0 e1
:3 0 997 998 0
15 :3 0 da :2 0
100 :3 0 99a 99c
0 4d4 99b 99e
:3 0 99f :2 0 c3
:3 0 c4 :3 0 9a1
9a2 0 c3 :3 0
d3 :3 0 9a4 9a5
0 18 :2 0 2
:4 0 135 :2 0 d5
:2 0 2a :2 0 4d7
9aa 9ac :3 0 4da
9a6 9ae 9a3 9b0
9af :2 0 c6 :3 0
d6 :3 0 9b2 9b3
0 c8 :4 0 136
:4 0 cb :2 0 cc
:3 0 4de 9b7 9b9
:3 0 cb :2 0 e9
:4 0 4e1 9bb 9bd
:3 0 cb :2 0 f0
:4 0 4e4 9bf 9c1
:3 0 cb :2 0 84
:3 0 d0 :3 0 b0
:3 0 f1 :3 0 9c6
9c7 0 4e7 9c5
9c9 d1 :4 0 4e9
9c4 9cc 4ec 9c3
9ce :3 0 cb :2 0
f2 :4 0 4ef 9d0
9d2 :3 0 cb :2 0
ce :4 0 4f2 9d4
9d6 :3 0 cb :2 0
23 :3 0 4f5 9d8
9da :3 0 cb :2 0
ce :4 0 4f8 9dc
9de :3 0 4fb 9b4
9e0 :2 0 9e2 4fe
9e3 9b1 9e2 0
9e4 500 0 a0e
c3 :3 0 c4 :3 0
9e5 9e6 0 c3
:3 0 d3 :3 0 9e8
9e9 0 2a :2 0
2 :4 0 137 :2 0
d5 :2 0 2a :2 0
502 9ee 9f0 :3 0
505 9ea 9f2 9e7
9f4 9f3 :2 0 c6
:3 0 d6 :3 0 9f6
9f7 0 c8 :4 0
138 :4 0 cb :2 0
cc :3 0 509 9fb
9fd :3 0 50c 9f8
9ff :2 0 a01 50f
a02 9f5 a01 0
a03 511 0 a0e
f5 :3 0 f6 :3 0
a04 a05 0 b0
:3 0 f1 :3 0 a07
a08 0 23 :3 0
f7 :3 0 513 a06
a0c :2 0 a0e 517
a0f 9a0 a0e 0
a10 51b 0 4a3e
60 :3 0 12 :3 0
a11 a12 0 4a3e
62 :3 0 d8 :3 0
84 :3 0 60 :3 0
3d :2 0 51d a16
a19 139 :2 0 520
a15 a1c a14 a1d
0 4a3e 63 :3 0
d8 :3 0 84 :3 0
60 :3 0 3d :2 0
523 a21 a24 13a
:2 0 526 a20 a27
a1f a28 0 4a3e
61 :3 0 d8 :3 0
84 :3 0 60 :3 0
3d :2 0 529 a2c
a2f 2a :2 0 52c
a2b a32 a2a a33
0 4a3e 82 :3 0
13b :2 0 3d :2 0
531 a36 a38 :3 0
84 :3 0 63 :3 0
3d :2 0 534 a3a
a3d da :2 0 13a
:2 0 539 a3f a41
:3 0 13c :3 0 9a
:3 0 6b :3 0 90
:3 0 91 :3 0 22
:3 0 9b :3 0 22
:3 0 92 :3 0 21
:3 0 93 :4 0 13d
1 :8 0 a54 15
:3 0 e1 :3 0 a4f
a50 0 e4 :3 0
a51 a52 0 a54
53c a9e e5 :3 0
15 :3 0 e1 :3 0
a57 a58 0 e4
:3 0 a59 a5a 0
a94 c3 :3 0 c4
:3 0 a5c a5d 0
c3 :3 0 d3 :3 0
a5f a60 0 e6
:2 0 2 :4 0 13e
:2 0 d5 :2 0 2a
:2 0 53f a65 a67
:3 0 542 a61 a69
a5e a6b a6a :2 0
c6 :3 0 d6 :3 0
a6d a6e 0 c8
:4 0 13f :4 0 cb
:2 0 cc :3 0 546
a72 a74 :3 0 cb
:2 0 e9 :4 0 549
a76 a78 :3 0 cb
:2 0 ea :4 0 54c
a7a a7c :3 0 cb
:2 0 e4 :3 0 54f
a7e a80 :3 0 cb
:2 0 eb :4 0 552
a82 a84 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 555 a87 a8b
559 a86 a8d :3 0
55c a6f a8f :2 0
a91 55f a92 a6c
a91 0 a93 561
0 a94 563 a97
:3 0 a97 0 a97
a96 a94 a95 :6 0
a99 11 :3 0 566
a9b 568 a9a a99
:2 0 a9c 56a :2 0
a9e 0 a9e a9d
a54 a9c :6 0 aa1
1 :3 0 140 :3 0
56c b0a 84 :3 0
63 :3 0 3d :2 0
56e aa2 aa5 da
:2 0 3d :2 0 573
aa7 aa9 :3 0 13c
:3 0 9a :3 0 6b
:3 0 90 :3 0 91
:3 0 22 :3 0 9b
:3 0 91 :3 0 92
:3 0 21 :3 0 93
:4 0 141 1 :8 0
abc 15 :3 0 e1
:3 0 ab7 ab8 0
e4 :3 0 ab9 aba
0 abc 576 b06
e5 :3 0 15 :3 0
e1 :3 0 abf ac0
0 e4 :3 0 ac1
ac2 0 afc c3
:3 0 c4 :3 0 ac4
ac5 0 c3 :3 0
d3 :3 0 ac7 ac8
0 e6 :2 0 2
:4 0 142 :2 0 d5
:2 0 2a :2 0 579
acd acf :3 0 57c
ac9 ad1 ac6 ad3
ad2 :2 0 c6 :3 0
d6 :3 0 ad5 ad6
0 c8 :4 0 143
:4 0 cb :2 0 cc
:3 0 580 ada adc
:3 0 cb :2 0 e9
:4 0 583 ade ae0
:3 0 cb :2 0 ea
:4 0 586 ae2 ae4
:3 0 cb :2 0 e4
:3 0 589 ae6 ae8
:3 0 cb :2 0 eb
:4 0 58c aea aec
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 58f
aef af3 593 aee
af5 :3 0 596 ad7
af7 :2 0 af9 599
afa ad4 af9 0
afb 59b 0 afc
59d aff :3 0 aff
0 aff afe afc
afd :6 0 b01 13
:3 0 5a0 b03 5a2
b02 b01 :2 0 b04
5a4 :2 0 b06 0
b06 b05 abc b04
:6 0 b08 1 :3 0
5a6 b09 aaa b08
0 b0b a42 aa1
0 b0b 5a8 0
b85 84 :3 0 6b
:3 0 3d :2 0 5ab
b0c b0f 10a :2 0
3d :2 0 5b0 b11
b13 :3 0 c3 :3 0
c4 :3 0 b15 b16
0 c3 :3 0 d3
:3 0 b18 b19 0
18 :2 0 2 :4 0
144 :2 0 d5 :2 0
2a :2 0 5b3 b1e
b20 :3 0 5b6 b1a
b22 b17 b24 b23
:2 0 c6 :3 0 d6
:3 0 b26 b27 0
c8 :4 0 145 :4 0
cb :2 0 cc :3 0
5ba b2b b2d :3 0
cb :2 0 e9 :4 0
5bd b2f b31 :3 0
cb :2 0 f0 :4 0
5c0 b33 b35 :3 0
cb :2 0 84 :3 0
d0 :3 0 b0 :3 0
146 :3 0 b3a b3b
0 5c3 b39 b3d
d1 :4 0 5c5 b38
b40 5c8 b37 b42
:3 0 cb :2 0 f2
:4 0 5cb b44 b46
:3 0 cb :2 0 ce
:4 0 5ce b48 b4a
:3 0 cb :2 0 21
:3 0 5d1 b4c b4e
:3 0 cb :2 0 ce
:4 0 5d4 b50 b52
:3 0 5d7 b28 b54
:2 0 b56 5da b57
b25 b56 0 b58
5dc 0 b82 c3
:3 0 c4 :3 0 b59
b5a 0 c3 :3 0
d3 :3 0 b5c b5d
0 2a :2 0 2
:4 0 147 :2 0 d5
:2 0 2a :2 0 5de
b62 b64 :3 0 5e1
b5e b66 b5b b68
b67 :2 0 c6 :3 0
d6 :3 0 b6a b6b
0 c8 :4 0 148
:4 0 cb :2 0 cc
:3 0 5e5 b6f b71
:3 0 5e8 b6c b73
:2 0 b75 5eb b76
b69 b75 0 b77
5ed 0 b82 f5
:3 0 f6 :3 0 b78
b79 0 b0 :3 0
146 :3 0 b7b b7c
0 21 :3 0 f7
:3 0 5ef b7a b80
:2 0 b82 5f3 b83
b14 b82 0 b84
5f7 0 b85 5f9
d3f 13c :3 0 9a
:3 0 77 :3 0 90
:3 0 91 :3 0 22
:3 0 91 :3 0 9b
:3 0 92 :3 0 23
:3 0 93 :4 0 149
1 :8 0 b97 15
:3 0 e1 :3 0 b92
b93 0 e4 :3 0
b94 b95 0 b97
5fc be1 e5 :3 0
15 :3 0 e1 :3 0
b9a b9b 0 e4
:3 0 b9c b9d 0
bd7 c3 :3 0 c4
:3 0 b9f ba0 0
c3 :3 0 d3 :3 0
ba2 ba3 0 e6
:2 0 2 :4 0 14a
:2 0 d5 :2 0 2a
:2 0 5ff ba8 baa
:3 0 602 ba4 bac
ba1 bae bad :2 0
c6 :3 0 d6 :3 0
bb0 bb1 0 c8
:4 0 14b :4 0 cb
:2 0 cc :3 0 606
bb5 bb7 :3 0 cb
:2 0 e9 :4 0 609
bb9 bbb :3 0 cb
:2 0 ea :4 0 60c
bbd bbf :3 0 cb
:2 0 e4 :3 0 60f
bc1 bc3 :3 0 cb
:2 0 eb :4 0 612
bc5 bc7 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 615 bca bce
619 bc9 bd0 :3 0
61c bb2 bd2 :2 0
bd4 61f bd5 baf
bd4 0 bd6 621
0 bd7 623 bda
:3 0 bda 0 bda
bd9 bd7 bd8 :6 0
bdc 15 :3 0 626
bde 628 bdd bdc
:2 0 bdf 62a :2 0
be1 0 be1 be0
b97 bdf :6 0 d3e
1 :3 0 13c :3 0
9a :3 0 76 :3 0
90 :3 0 91 :3 0
22 :3 0 91 :3 0
9b :3 0 92 :3 0
23 :3 0 93 :4 0
14c 1 :8 0 bf4
15 :3 0 e1 :3 0
bef bf0 0 e4
:3 0 bf1 bf2 0
bf4 62c c3e e5
:3 0 15 :3 0 e1
:3 0 bf7 bf8 0
e4 :3 0 bf9 bfa
0 c34 c3 :3 0
c4 :3 0 bfc bfd
0 c3 :3 0 d3
:3 0 bff c00 0
e6 :2 0 2 :4 0
14d :2 0 d5 :2 0
2a :2 0 62f c05
c07 :3 0 632 c01
c09 bfe c0b c0a
:2 0 c6 :3 0 d6
:3 0 c0d c0e 0
c8 :4 0 14e :4 0
cb :2 0 cc :3 0
636 c12 c14 :3 0
cb :2 0 e9 :4 0
639 c16 c18 :3 0
cb :2 0 ea :4 0
63c c1a c1c :3 0
cb :2 0 e4 :3 0
63f c1e c20 :3 0
cb :2 0 eb :4 0
642 c22 c24 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 645 c27
c2b 649 c26 c2d
:3 0 64c c0f c2f
:2 0 c31 64f c32
c0c c31 0 c33
651 0 c34 653
c37 :3 0 c37 0
c37 c36 c34 c35
:6 0 c39 17 :3 0
656 c3b 658 c3a
c39 :2 0 c3c 65a
:2 0 c3e 0 c3e
c3d bf4 c3c :6 0
d3e 1 :3 0 14f
:3 0 84 :3 0 42
:3 0 3d :2 0 65c
c41 c44 65f c40
c46 c47 :2 0 13b
:2 0 3d :2 0 663
c49 c4b :3 0 84
:3 0 63 :3 0 3d
:2 0 666 c4d c50
da :2 0 3d :2 0
66b c52 c54 :3 0
c55 :2 0 84 :3 0
77 :3 0 3d :2 0
66e c57 c5a da
:2 0 3d :2 0 673
c5c c5e :3 0 c5f
:2 0 c56 c61 c60
:2 0 c62 :2 0 c4c
c64 c63 :2 0 13c
:3 0 9a :3 0 6b
:3 0 90 :3 0 91
:3 0 22 :3 0 92
:3 0 21 :3 0 93
:3 0 94 :4 0 150
1 :8 0 c76 15
:3 0 e1 :3 0 c71
c72 0 e4 :3 0
c73 c74 0 c76
676 cc0 e5 :3 0
15 :3 0 e1 :3 0
c79 c7a 0 e4
:3 0 c7b c7c 0
cb6 c3 :3 0 c4
:3 0 c7e c7f 0
c3 :3 0 d3 :3 0
c81 c82 0 e6
:2 0 2 :4 0 151
:2 0 d5 :2 0 2a
:2 0 679 c87 c89
:3 0 67c c83 c8b
c80 c8d c8c :2 0
c6 :3 0 d6 :3 0
c8f c90 0 c8
:4 0 152 :4 0 cb
:2 0 cc :3 0 680
c94 c96 :3 0 cb
:2 0 e9 :4 0 683
c98 c9a :3 0 cb
:2 0 ea :4 0 686
c9c c9e :3 0 cb
:2 0 e4 :3 0 689
ca0 ca2 :3 0 cb
:2 0 eb :4 0 68c
ca4 ca6 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 68f ca9 cad
693 ca8 caf :3 0
696 c91 cb1 :2 0
cb3 699 cb4 c8e
cb3 0 cb5 69b
0 cb6 69d cb9
:3 0 cb9 0 cb9
cb8 cb6 cb7 :6 0
cbb 19 :3 0 6a0
cbd 6a2 cbc cbb
:2 0 cbe 6a4 :2 0
cc0 0 cc0 cbf
c76 cbe :6 0 d3b
1 :3 0 84 :3 0
6b :3 0 3d :2 0
6a6 cc2 cc5 10a
:2 0 3d :2 0 6ab
cc7 cc9 :3 0 c3
:3 0 c4 :3 0 ccb
ccc 0 c3 :3 0
d3 :3 0 cce ccf
0 18 :2 0 2
:4 0 153 :2 0 d5
:2 0 2a :2 0 6ae
cd4 cd6 :3 0 6b1
cd0 cd8 ccd cda
cd9 :2 0 c6 :3 0
d6 :3 0 cdc cdd
0 c8 :4 0 154
:4 0 cb :2 0 cc
:3 0 6b5 ce1 ce3
:3 0 cb :2 0 e9
:4 0 6b8 ce5 ce7
:3 0 cb :2 0 f0
:4 0 6bb ce9 ceb
:3 0 cb :2 0 84
:3 0 d0 :3 0 b0
:3 0 146 :3 0 cf0
cf1 0 6be cef
cf3 d1 :4 0 6c0
cee cf6 6c3 ced
cf8 :3 0 cb :2 0
f2 :4 0 6c6 cfa
cfc :3 0 cb :2 0
ce :4 0 6c9 cfe
d00 :3 0 cb :2 0
21 :3 0 6cc d02
d04 :3 0 cb :2 0
ce :4 0 6cf d06
d08 :3 0 6d2 cde
d0a :2 0 d0c 6d5
d0d cdb d0c 0
d0e 6d7 0 d38
c3 :3 0 c4 :3 0
d0f d10 0 c3
:3 0 d3 :3 0 d12
d13 0 2a :2 0
2 :4 0 155 :2 0
d5 :2 0 2a :2 0
6d9 d18 d1a :3 0
6dc d14 d1c d11
d1e d1d :2 0 c6
:3 0 d6 :3 0 d20
d21 0 c8 :4 0
156 :4 0 cb :2 0
cc :3 0 6e0 d25
d27 :3 0 6e3 d22
d29 :2 0 d2b 6e6
d2c d1f d2b 0
d2d 6e8 0 d38
f5 :3 0 f6 :3 0
d2e d2f 0 b0
:3 0 146 :3 0 d31
d32 0 21 :3 0
f7 :3 0 6ea d30
d36 :2 0 d38 6ee
d39 cca d38 0
d3a 6f2 0 d3b
6f4 d3c c65 d3b
0 d3d 6f7 0
d3e 6f9 d40 a39
b85 0 d41 0
d3e 0 d41 6fd
0 4a3e 2e :3 0
3d :4 0 d42 d43
0 4a3e 1b :3 0
de :4 0 d45 d46
0 4a3e 1c :3 0
de :4 0 d48 d49
0 4a3e 1e :4 0
d4b d4c 0 4a3e
24 :4 0 d4e d4f
0 4a3e df :3 0
8e :4 0 d54 :2 0
4a3e d52 d55 :3 0
8e :3 0 56 :4 0
d59 :2 0 4a3e d56
d57 :3 0 8e :3 0
e0 :3 0 d5a d5b
:3 0 15 :3 0 e1
:3 0 d5d d5e 0
3d :2 0 d5f d60
0 d62 700 d69
15 :3 0 e1 :3 0
d63 d64 0 e2
:2 0 d65 d66 0
d68 702 d6a d5c
d62 0 d6b 0
d68 0 d6b 704
0 4a3e 15 :3 0
e1 :3 0 d6c d6d
0 15 :3 0 da
:2 0 157 :3 0 d6f
d71 0 709 d70
d73 :3 0 d74 :2 0
4c :3 0 3d :2 0
d76 d77 0 d79
70c d7e 4c :3 0
13a :2 0 d7a d7b
0 d7d 70e d7f
d75 d79 0 d80
0 d7d 0 d80
710 0 4a3e e3
:3 0 8e :4 0 d84
:2 0 d8a d82 0
15 :3 0 e1 :3 0
d85 d86 0 e4
:3 0 d87 d88 0
d8a 713 dd4 e5
:3 0 15 :3 0 e1
:3 0 d8d d8e 0
e4 :3 0 d8f d90
0 dca c3 :3 0
c4 :3 0 d92 d93
0 c3 :3 0 d3
:3 0 d95 d96 0
e6 :2 0 2 :4 0
158 :2 0 d5 :2 0
2a :2 0 716 d9b
d9d :3 0 719 d97
d9f d94 da1 da0
:2 0 c6 :3 0 d6
:3 0 da3 da4 0
c8 :4 0 159 :4 0
cb :2 0 cc :3 0
71d da8 daa :3 0
cb :2 0 e9 :4 0
720 dac dae :3 0
cb :2 0 ea :4 0
723 db0 db2 :3 0
cb :2 0 e4 :3 0
726 db4 db6 :3 0
cb :2 0 eb :4 0
729 db8 dba :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 72c dbd
dc1 730 dbc dc3
:3 0 733 da5 dc5
:2 0 dc7 736 dc8
da2 dc7 0 dc9
738 0 dca 73a
dcd :3 0 dcd 0
dcd dcc dca dcb
:6 0 dcf 1b :3 0
73d dd1 73f dd0
dcf :2 0 dd2 741
:2 0 dd4 0 dd4
dd3 d8a dd2 :6 0
4a3e 1 :3 0 84
:3 0 4c :3 0 3d
:2 0 743 dd6 dd9
da :2 0 13a :2 0
748 ddb ddd :3 0
13c :3 0 9a :3 0
56 :3 0 90 :3 0
91 :3 0 22 :3 0
92 :3 0 21 :3 0
93 :3 0 9b :3 0
22 :4 0 15a 1
:8 0 df0 15 :3 0
e1 :3 0 deb dec
0 e4 :3 0 ded
dee 0 df0 74b
e3a e5 :3 0 15
:3 0 e1 :3 0 df3
df4 0 e4 :3 0
df5 df6 0 e30
c3 :3 0 c4 :3 0
df8 df9 0 c3
:3 0 d3 :3 0 dfb
dfc 0 e6 :2 0
2 :4 0 15b :2 0
d5 :2 0 2a :2 0
74e e01 e03 :3 0
751 dfd e05 dfa
e07 e06 :2 0 c6
:3 0 d6 :3 0 e09
e0a 0 c8 :4 0
15c :4 0 cb :2 0
cc :3 0 755 e0e
e10 :3 0 cb :2 0
e9 :4 0 758 e12
e14 :3 0 cb :2 0
ea :4 0 75b e16
e18 :3 0 cb :2 0
e4 :3 0 75e e1a
e1c :3 0 cb :2 0
eb :4 0 761 e1e
e20 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
764 e23 e27 768
e22 e29 :3 0 76b
e0b e2b :2 0 e2d
76e e2e e08 e2d
0 e2f 770 0
e30 772 e33 :3 0
e33 0 e33 e32
e30 e31 :6 0 e35
1d :3 0 775 e37
777 e36 e35 :2 0
e38 779 :2 0 e3a
0 e3a e39 df0
e38 :6 0 150c 1
:3 0 84 :3 0 56
:3 0 3d :2 0 77b
e3c e3f 10a :2 0
3d :2 0 780 e41
e43 :3 0 4c :3 0
2a :2 0 e45 e46
0 fbe a1 :3 0
a2 :3 0 33 :3 0
34 :3 0 90 :3 0
91 :3 0 22 :3 0
15d :3 0 92 :3 0
21 :3 0 93 :3 0
9b :3 0 22 :4 0
15e 1 :8 0 e5b
15 :3 0 e1 :3 0
e56 e57 0 e4
:3 0 e58 e59 0
e5b 783 ea5 e5
:3 0 15 :3 0 e1
:3 0 e5e e5f 0
e4 :3 0 e60 e61
0 e9b c3 :3 0
c4 :3 0 e63 e64
0 c3 :3 0 d3
:3 0 e66 e67 0
e6 :2 0 2 :4 0
15f :2 0 d5 :2 0
2a :2 0 786 e6c
e6e :3 0 789 e68
e70 e65 e72 e71
:2 0 c6 :3 0 d6
:3 0 e74 e75 0
c8 :4 0 160 :4 0
cb :2 0 cc :3 0
78d e79 e7b :3 0
cb :2 0 e9 :4 0
790 e7d e7f :3 0
cb :2 0 ea :4 0
793 e81 e83 :3 0
cb :2 0 e4 :3 0
796 e85 e87 :3 0
cb :2 0 eb :4 0
799 e89 e8b :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 79c e8e
e92 7a0 e8d e94
:3 0 7a3 e76 e96
:2 0 e98 7a6 e99
e73 e98 0 e9a
7a8 0 e9b 7aa
e9e :3 0 e9e 0
e9e e9d e9b e9c
:6 0 ea0 1f :3 0
7ad ea2 7af ea1
ea0 :2 0 ea3 7b1
:2 0 ea5 0 ea5
ea4 e5b ea3 :6 0
fbe 1 :3 0 15
:3 0 e1 :3 0 ea7
ea8 0 15 :3 0
da :2 0 100 :3 0
eaa eac 0 7b5
eab eae :3 0 eaf
:2 0 c3 :3 0 c4
:3 0 eb1 eb2 0
c3 :3 0 d3 :3 0
eb4 eb5 0 18
:2 0 2 :4 0 161
:2 0 d5 :2 0 2a
:2 0 7b8 eba ebc
:3 0 7bb eb6 ebe
eb3 ec0 ebf :2 0
c6 :3 0 d6 :3 0
ec2 ec3 0 c8
:4 0 162 :4 0 cb
:2 0 cc :3 0 7bf
ec7 ec9 :3 0 cb
:2 0 e9 :4 0 7c2
ecb ecd :3 0 cb
:2 0 f0 :4 0 7c5
ecf ed1 :3 0 cb
:2 0 84 :3 0 d0
:3 0 b0 :3 0 146
:3 0 ed6 ed7 0
7c8 ed5 ed9 d1
:4 0 7ca ed4 edc
7cd ed3 ede :3 0
cb :2 0 f2 :4 0
7d0 ee0 ee2 :3 0
cb :2 0 ce :4 0
7d3 ee4 ee6 :3 0
cb :2 0 21 :3 0
7d6 ee8 eea :3 0
cb :2 0 ce :4 0
7d9 eec eee :3 0
7dc ec4 ef0 :2 0
ef2 7df ef3 ec1
ef2 0 ef4 7e1
0 f1f c3 :3 0
c4 :3 0 ef5 ef6
0 c3 :3 0 d3
:3 0 ef8 ef9 0
2a :2 0 2 :4 0
163 :2 0 d5 :2 0
2a :2 0 7e3 efe
f00 :3 0 7e6 efa
f02 ef7 f04 f03
:2 0 c6 :3 0 d6
:3 0 f06 f07 0
c8 :4 0 164 :4 0
cb :2 0 cc :3 0
7ea f0b f0d :3 0
7ed f08 f0f :2 0
f11 7f0 f12 f05
f11 0 f13 7f2
0 f1f f5 :3 0
f6 :3 0 f14 f15
0 b0 :3 0 146
:3 0 f17 f18 0
21 :3 0 f7 :3 0
7f4 f16 f1c :2 0
f1f 140 :3 0 7f8
fbc 33 :3 0 165
:2 0 7fc f21 f22
:3 0 f23 :2 0 f24
:2 0 34 :3 0 165
:2 0 7fe f27 f28
:3 0 f29 :2 0 f2a
:2 0 f25 f2c f2b
:2 0 116 :3 0 166
:3 0 f2e f2f 0
33 :3 0 24 :3 0
167 :2 0 800 f30
f34 10a :2 0 3d
:2 0 806 f36 f38
:3 0 f39 :2 0 116
:3 0 166 :3 0 f3b
f3c 0 34 :3 0
24 :3 0 167 :2 0
809 f3d f41 168
:2 0 3d :2 0 80f
f43 f45 :3 0 f46
:2 0 f3a f48 f47
:2 0 c3 :3 0 c4
:3 0 f4a f4b 0
c3 :3 0 d3 :3 0
f4d f4e 0 18
:2 0 2 :4 0 169
:2 0 d5 :2 0 2a
:2 0 812 f53 f55
:3 0 815 f4f f57
f4c f59 f58 :2 0
c6 :3 0 d6 :3 0
f5b f5c 0 c8
:4 0 16a :4 0 cb
:2 0 cc :3 0 819
f60 f62 :3 0 cb
:2 0 e9 :4 0 81c
f64 f66 :3 0 cb
:2 0 f0 :4 0 81f
f68 f6a :3 0 cb
:2 0 84 :3 0 d0
:3 0 b0 :3 0 146
:3 0 f6f f70 0
822 f6e f72 d1
:4 0 824 f6d f75
827 f6c f77 :3 0
cb :2 0 f2 :4 0
82a f79 f7b :3 0
cb :2 0 ce :4 0
82d f7d f7f :3 0
cb :2 0 21 :3 0
830 f81 f83 :3 0
cb :2 0 ce :4 0
833 f85 f87 :3 0
836 f5d f89 :2 0
f8b 839 f8c f5a
f8b 0 f8d 83b
0 fb7 c3 :3 0
c4 :3 0 f8e f8f
0 c3 :3 0 d3
:3 0 f91 f92 0
2a :2 0 2 :4 0
16b :2 0 d5 :2 0
2a :2 0 83d f97
f99 :3 0 840 f93
f9b f90 f9d f9c
:2 0 c6 :3 0 d6
:3 0 f9f fa0 0
c8 :4 0 16c :4 0
cb :2 0 cc :3 0
844 fa4 fa6 :3 0
847 fa1 fa8 :2 0
faa 84a fab f9e
faa 0 fac 84c
0 fb7 f5 :3 0
f6 :3 0 fad fae
0 b0 :3 0 146
:3 0 fb0 fb1 0
21 :3 0 f7 :3 0
84e faf fb5 :2 0
fb7 852 fb8 f49
fb7 0 fb9 856
0 fba 858 fbb
f2d fba 0 fbd
eb0 f1f 0 fbd
85a 0 fbe 85d
fbf e44 fbe 0
fc0 861 0 150c
84 :3 0 63 :3 0
3d :2 0 863 fc1
fc4 da :2 0 13a
:2 0 868 fc6 fc8
:3 0 4c :3 0 3d
:2 0 fca fcb 0
fd0 1e :3 0 1e
:3 0 fcd fce 0
fd0 86b 1509 98
:3 0 16d :3 0 1c
:3 0 55 :3 0 af
:3 0 8b :3 0 22
:3 0 93 :3 0 2e
:3 0 92 :3 0 21
:4 0 16e 1 :8 0
fe2 15 :3 0 e1
:3 0 fdd fde 0
e4 :3 0 fdf fe0
0 fe2 86e 102c
e5 :3 0 15 :3 0
e1 :3 0 fe5 fe6
0 e4 :3 0 fe7
fe8 0 1022 c3
:3 0 c4 :3 0 fea
feb 0 c3 :3 0
d3 :3 0 fed fee
0 e6 :2 0 2
:4 0 16f :2 0 d5
:2 0 2a :2 0 871
ff3 ff5 :3 0 874
fef ff7 fec ff9
ff8 :2 0 c6 :3 0
d6 :3 0 ffb ffc
0 c8 :4 0 170
:4 0 cb :2 0 cc
:3 0 878 1000 1002
:3 0 cb :2 0 e9
:4 0 87b 1004 1006
:3 0 cb :2 0 ea
:4 0 87e 1008 100a
:3 0 cb :2 0 e4
:3 0 881 100c 100e
:3 0 cb :2 0 eb
:4 0 884 1010 1012
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 887
1015 1019 88b 1014
101b :3 0 88e ffd
101d :2 0 101f 891
1020 ffa 101f 0
1021 893 0 1022
895 1025 :3 0 1025
0 1025 1024 1022
1023 :6 0 1027 21
:3 0 898 1029 89a
1028 1027 :2 0 102a
89c :2 0 102c 0
102c 102b fe2 102a
:6 0 1508 1 :3 0
15 :3 0 e1 :3 0
102e 102f 0 15
:3 0 da :2 0 100
:3 0 1031 1033 0
8a0 1032 1035 :3 0
1036 :2 0 1c :3 0
de :4 0 1038 1039
0 1315 1c :3 0
171 :4 0 103c 103d
:3 0 103b 103e 0
1315 71 :3 0 172
:3 0 3d :2 0 84
:3 0 41 :3 0 3d
:2 0 8a3 1043 1046
b0 :3 0 173 :3 0
1048 1049 0 6e
:3 0 8a6 1041 104c
1040 104d 0 1315
6d :3 0 b0 :3 0
174 :3 0 1050 1051
0 104f 1052 0
1315 6c :3 0 3d
:4 0 1054 1055 0
1315 70 :3 0 2a
:2 0 1057 1058 0
1315 71 :3 0 175
:3 0 22 :3 0 21
:3 0 41 :3 0 6d
:3 0 6e :3 0 6c
:3 0 70 :3 0 8ab
105b 1063 105a 1064
0 1315 7b :3 0
176 :3 0 84 :3 0
41 :3 0 3d :2 0
8b3 1068 106b 8b6
1067 106d 1066 106e
0 1315 af :3 0
98 :3 0 91 :3 0
8b :3 0 9c :3 0
93 :3 0 92 :3 0
12f :3 0 16d :3 0
177 :3 0 178 :3 0
179 :3 0 17a :3 0
1c :3 0 22 :3 0
22 :3 0 41 :3 0
2e :3 0 21 :3 0
23 :3 0 b0 :3 0
174 :3 0 6e :3 0
7b :3 0 13 :3 0
cc :4 0 17b 1
:8 0 10a0 e0 :4 0
108b :3 0 f7 :3 0
da :2 0 8ba 108e
108f :3 0 15 :3 0
e1 :3 0 1091 1092
0 3d :2 0 1093
1094 0 1096 8bd
109d 15 :3 0 e1
:3 0 1097 1098 0
e2 :2 0 1099 109a
0 109c 8bf 109e
1090 1096 0 109f
0 109c 0 109f
8c1 0 10a0 8c4
10ea e5 :3 0 15
:3 0 e1 :3 0 10a3
10a4 0 e4 :3 0
10a5 10a6 0 10e0
c3 :3 0 c4 :3 0
10a8 10a9 0 c3
:3 0 d3 :3 0 10ab
10ac 0 e6 :2 0
2 :4 0 17c :2 0
d5 :2 0 2a :2 0
8c7 10b1 10b3 :3 0
8ca 10ad 10b5 10aa
10b7 10b6 :2 0 c6
:3 0 d6 :3 0 10b9
10ba 0 c8 :4 0
17d :4 0 cb :2 0
cc :3 0 8ce 10be
10c0 :3 0 cb :2 0
e9 :4 0 8d1 10c2
10c4 :3 0 cb :2 0
ea :4 0 8d4 10c6
10c8 :3 0 cb :2 0
e4 :3 0 8d7 10ca
10cc :3 0 cb :2 0
eb :4 0 8da 10ce
10d0 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
8dd 10d3 10d7 8e1
10d2 10d9 :3 0 8e4
10bb 10db :2 0 10dd
8e7 10de 10b8 10dd
0 10df 8e9 0
10e0 8eb 10e3 :3 0
10e3 0 10e3 10e2
10e0 10e1 :6 0 10e5
23 :3 0 8ee 10e7
8f0 10e6 10e5 :2 0
10e8 8f2 :2 0 10ea
0 10ea 10e9 10a0
10e8 :6 0 1315 1
:3 0 17e :3 0 39
:3 0 12e :3 0 12f
:3 0 23 :4 0 17f
1 :8 0 10f7 15
:3 0 e1 :3 0 10f2
10f3 0 e4 :3 0
10f4 10f5 0 10f7
8f4 1141 e5 :3 0
15 :3 0 e1 :3 0
10fa 10fb 0 e4
:3 0 10fc 10fd 0
1137 c3 :3 0 c4
:3 0 10ff 1100 0
c3 :3 0 d3 :3 0
1102 1103 0 e6
:2 0 2 :4 0 180
:2 0 d5 :2 0 2a
:2 0 8f7 1108 110a
:3 0 8fa 1104 110c
1101 110e 110d :2 0
c6 :3 0 d6 :3 0
1110 1111 0 c8
:4 0 181 :4 0 cb
:2 0 cc :3 0 8fe
1115 1117 :3 0 cb
:2 0 e9 :4 0 901
1119 111b :3 0 cb
:2 0 ea :4 0 904
111d 111f :3 0 cb
:2 0 e4 :3 0 907
1121 1123 :3 0 cb
:2 0 eb :4 0 90a
1125 1127 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 90d 112a 112e
911 1129 1130 :3 0
914 1112 1132 :2 0
1134 917 1135 110f
1134 0 1136 919
0 1137 91b 113a
:3 0 113a 0 113a
1139 1137 1138 :6 0
113c 25 :3 0 91e
113e 920 113d 113c
:2 0 113f 922 :2 0
1141 0 1141 1140
10f7 113f :6 0 1315
1 :3 0 116 :3 0
133 :3 0 1143 1144
0 22 :3 0 20
:3 0 924 1145 1148
da :2 0 3d :2 0
929 114a 114c :3 0
43 :3 0 3d :2 0
114e 114f 0 1151
92c 11b1 13c :3 0
9a :3 0 43 :3 0
90 :3 0 91 :3 0
22 :3 0 9b :3 0
20 :3 0 93 :3 0
92 :3 0 23 :3 0
15d :4 0 182 1
:8 0 1164 15 :3 0
e1 :3 0 115f 1160
0 e4 :3 0 1161
1162 0 1164 92e
11ae e5 :3 0 15
:3 0 e1 :3 0 1167
1168 0 e4 :3 0
1169 116a 0 11a4
c3 :3 0 c4 :3 0
116c 116d 0 c3
:3 0 d3 :3 0 116f
1170 0 e6 :2 0
2 :4 0 183 :2 0
d5 :2 0 2a :2 0
931 1175 1177 :3 0
934 1171 1179 116e
117b 117a :2 0 c6
:3 0 d6 :3 0 117d
117e 0 c8 :4 0
184 :4 0 cb :2 0
cc :3 0 938 1182
1184 :3 0 cb :2 0
e9 :4 0 93b 1186
1188 :3 0 cb :2 0
ea :4 0 93e 118a
118c :3 0 cb :2 0
e4 :3 0 941 118e
1190 :3 0 cb :2 0
eb :4 0 944 1192
1194 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
947 1197 119b 94b
1196 119d :3 0 94e
117f 119f :2 0 11a1
951 11a2 117c 11a1
0 11a3 953 0
11a4 955 11a7 :3 0
11a7 0 11a7 11a6
11a4 11a5 :6 0 11a9
27 :3 0 958 11ab
95a 11aa 11a9 :2 0
11ac 95c :2 0 11ae
0 11ae 11ad 1164
11ac :6 0 11b0 1
:3 0 95e 11b2 114d
1151 0 11b3 0
11b0 0 11b3 960
0 1315 84 :3 0
43 :3 0 3d :2 0
963 11b4 11b7 da
:2 0 3d :2 0 968
11b9 11bb :3 0 ae
:3 0 185 :3 0 186
:3 0 185 :3 0 39
:3 0 36 :3 0 8b
:3 0 22 :3 0 91
:3 0 22 :4 0 187
1 :8 0 11dd e0
:4 0 11c8 :3 0 f7
:3 0 da :2 0 96d
11cb 11cc :3 0 15
:3 0 e1 :3 0 11ce
11cf 0 3d :2 0
11d0 11d1 0 11d3
970 11da 15 :3 0
e1 :3 0 11d4 11d5
0 e2 :2 0 11d6
11d7 0 11d9 972
11db 11cd 11d3 0
11dc 0 11d9 0
11dc 974 0 11dd
977 1227 e5 :3 0
15 :3 0 e1 :3 0
11e0 11e1 0 e4
:3 0 11e2 11e3 0
121d c3 :3 0 c4
:3 0 11e5 11e6 0
c3 :3 0 d3 :3 0
11e8 11e9 0 e6
:2 0 2 :4 0 188
:2 0 d5 :2 0 2a
:2 0 97a 11ee 11f0
:3 0 97d 11ea 11f2
11e7 11f4 11f3 :2 0
c6 :3 0 d6 :3 0
11f6 11f7 0 c8
:4 0 189 :4 0 cb
:2 0 cc :3 0 981
11fb 11fd :3 0 cb
:2 0 e9 :4 0 984
11ff 1201 :3 0 cb
:2 0 ea :4 0 987
1203 1205 :3 0 cb
:2 0 e4 :3 0 98a
1207 1209 :3 0 cb
:2 0 eb :4 0 98d
120b 120d :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 990 1210 1214
994 120f 1216 :3 0
997 11f8 1218 :2 0
121a 99a 121b 11f5
121a 0 121c 99c
0 121d 99e 1220
:3 0 1220 0 1220
121f 121d 121e :6 0
1222 29 :3 0 9a1
1224 9a3 1223 1222
:2 0 1225 9a5 :2 0
1227 0 1227 1226
11dd 1225 :6 0 129c
1 :3 0 ae :3 0
185 :3 0 18a :3 0
185 :3 0 36 :3 0
185 :3 0 18b :3 0
36 :3 0 18b :3 0
185 :3 0 185 :3 0
185 :3 0 36 :3 0
91 :3 0 22 :3 0
8b :3 0 22 :4 0
18c 1 :8 0 1250
e0 :4 0 123b :3 0
f7 :3 0 da :2 0
9a9 123e 123f :3 0
15 :3 0 e1 :3 0
1241 1242 0 3d
:2 0 1243 1244 0
1246 9ac 124d 15
:3 0 e1 :3 0 1247
1248 0 e2 :2 0
1249 124a 0 124c
9ae 124e 1240 1246
0 124f 0 124c
0 124f 9b0 0
1250 9b3 129a e5
:3 0 15 :3 0 e1
:3 0 1253 1254 0
e4 :3 0 1255 1256
0 1290 c3 :3 0
c4 :3 0 1258 1259
0 c3 :3 0 d3
:3 0 125b 125c 0
e6 :2 0 2 :4 0
18d :2 0 d5 :2 0
2a :2 0 9b6 1261
1263 :3 0 9b9 125d
1265 125a 1267 1266
:2 0 c6 :3 0 d6
:3 0 1269 126a 0
c8 :4 0 18e :4 0
cb :2 0 cc :3 0
9bd 126e 1270 :3 0
cb :2 0 e9 :4 0
9c0 1272 1274 :3 0
cb :2 0 ea :4 0
9c3 1276 1278 :3 0
cb :2 0 e4 :3 0
9c6 127a 127c :3 0
cb :2 0 eb :4 0
9c9 127e 1280 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 9cc 1283
1287 9d0 1282 1289
:3 0 9d3 126b 128b
:2 0 128d 9d6 128e
1268 128d 0 128f
9d8 0 1290 9da
1293 :3 0 1293 0
1293 1292 1290 1291
:6 0 1295 2b :3 0
9dd 1297 9df 1296
1295 :2 0 1298 9e1
:2 0 129a 0 129a
1299 1250 1298 :6 0
129c 1 :3 0 9e3
1311 ae :3 0 185
:3 0 18a :3 0 185
:3 0 36 :3 0 185
:3 0 18b :3 0 36
:3 0 18b :3 0 185
:3 0 185 :3 0 185
:3 0 36 :3 0 91
:3 0 22 :3 0 8b
:3 0 22 :4 0 18c
1 :8 0 12c4 e0
:4 0 12af :3 0 f7
:3 0 da :2 0 9e8
12b2 12b3 :3 0 15
:3 0 e1 :3 0 12b5
12b6 0 3d :2 0
12b7 12b8 0 12ba
9eb 12c1 15 :3 0
e1 :3 0 12bb 12bc
0 e2 :2 0 12bd
12be 0 12c0 9ed
12c2 12b4 12ba 0
12c3 0 12c0 0
12c3 9ef 0 12c4
9f2 130e e5 :3 0
15 :3 0 e1 :3 0
12c7 12c8 0 e4
:3 0 12c9 12ca 0
1304 c3 :3 0 c4
:3 0 12cc 12cd 0
c3 :3 0 d3 :3 0
12cf 12d0 0 e6
:2 0 2 :4 0 18f
:2 0 d5 :2 0 2a
:2 0 9f5 12d5 12d7
:3 0 9f8 12d1 12d9
12ce 12db 12da :2 0
c6 :3 0 d6 :3 0
12dd 12de 0 c8
:4 0 190 :4 0 cb
:2 0 cc :3 0 9fc
12e2 12e4 :3 0 cb
:2 0 e9 :4 0 9ff
12e6 12e8 :3 0 cb
:2 0 ea :4 0 a02
12ea 12ec :3 0 cb
:2 0 e4 :3 0 a05
12ee 12f0 :3 0 cb
:2 0 eb :4 0 a08
12f2 12f4 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 a0b 12f7 12fb
a0f 12f6 12fd :3 0
a12 12df 12ff :2 0
1301 a15 1302 12dc
1301 0 1303 a17
0 1304 a19 1307
:3 0 1307 0 1307
1306 1304 1305 :6 0
1309 2d :3 0 a1c
130b a1e 130a 1309
:2 0 130c a20 :2 0
130e 0 130e 130d
12c4 130c :6 0 1310
1 :3 0 a22 1312
11bc 129c 0 1313
0 1310 0 1313
a24 0 1315 140
:3 0 a27 1506 15
:3 0 e1 :3 0 1316
1317 0 15 :3 0
da :2 0 157 :3 0
1319 131b 0 a36
131a 131d :3 0 131e
:2 0 9a :3 0 1e
:3 0 90 :3 0 98
:3 0 1c :3 0 15d
:4 0 191 1 :8 0
132c 15 :3 0 e1
:3 0 1327 1328 0
e4 :3 0 1329 132a
0 132c a39 1376
e5 :3 0 15 :3 0
e1 :3 0 132f 1330
0 e4 :3 0 1331
1332 0 136c c3
:3 0 c4 :3 0 1334
1335 0 c3 :3 0
d3 :3 0 1337 1338
0 e6 :2 0 2
:4 0 192 :2 0 d5
:2 0 2a :2 0 a3c
133d 133f :3 0 a3f
1339 1341 1336 1343
1342 :2 0 c6 :3 0
d6 :3 0 1345 1346
0 c8 :4 0 193
:4 0 cb :2 0 cc
:3 0 a43 134a 134c
:3 0 cb :2 0 e9
:4 0 a46 134e 1350
:3 0 cb :2 0 ea
:4 0 a49 1352 1354
:3 0 cb :2 0 e4
:3 0 a4c 1356 1358
:3 0 cb :2 0 eb
:4 0 a4f 135a 135c
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 a52
135f 1363 a56 135e
1365 :3 0 a59 1347
1367 :2 0 1369 a5c
136a 1344 1369 0
136b a5e 0 136c
a60 136f :3 0 136f
0 136f 136e 136c
136d :6 0 1371 2f
:3 0 a63 1373 a65
1372 1371 :2 0 1374
a67 :2 0 1376 0
1376 1375 132c 1374
:6 0 1504 1 :3 0
84 :3 0 55 :3 0
3d :2 0 a69 1378
137b b0 :3 0 da
:2 0 194 :3 0 137d
137f 0 a6e 137e
1381 :3 0 71 :3 0
172 :3 0 3d :2 0
84 :3 0 41 :3 0
3d :2 0 a71 1386
1389 b0 :3 0 173
:3 0 138b 138c 0
6e :3 0 a74 1384
138f 1383 1390 0
1405 af :3 0 12f
:3 0 23 :3 0 16d
:3 0 b0 :3 0 174
:3 0 177 :3 0 6e
:3 0 98 :3 0 1c
:4 0 195 1 :8 0
13b2 e0 :4 0 139d
:3 0 f7 :3 0 da
:2 0 a7b 13a0 13a1
:3 0 15 :3 0 e1
:3 0 13a3 13a4 0
3d :2 0 13a5 13a6
0 13a8 a7e 13af
15 :3 0 e1 :3 0
13a9 13aa 0 e2
:2 0 13ab 13ac 0
13ae a80 13b0 13a2
13a8 0 13b1 0
13ae 0 13b1 a82
0 13b2 a85 13fc
e5 :3 0 15 :3 0
e1 :3 0 13b5 13b6
0 e4 :3 0 13b7
13b8 0 13f2 c3
:3 0 c4 :3 0 13ba
13bb 0 c3 :3 0
d3 :3 0 13bd 13be
0 e6 :2 0 2
:4 0 196 :2 0 d5
:2 0 2a :2 0 a88
13c3 13c5 :3 0 a8b
13bf 13c7 13bc 13c9
13c8 :2 0 c6 :3 0
d6 :3 0 13cb 13cc
0 c8 :4 0 197
:4 0 cb :2 0 cc
:3 0 a8f 13d0 13d2
:3 0 cb :2 0 e9
:4 0 a92 13d4 13d6
:3 0 cb :2 0 ea
:4 0 a95 13d8 13da
:3 0 cb :2 0 e4
:3 0 a98 13dc 13de
:3 0 cb :2 0 eb
:4 0 a9b 13e0 13e2
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 a9e
13e5 13e9 aa2 13e4
13eb :3 0 aa5 13cd
13ed :2 0 13ef aa8
13f0 13ca 13ef 0
13f1 aaa 0 13f2
aac 13f5 :3 0 13f5
0 13f5 13f4 13f2
13f3 :6 0 13f7 31
:3 0 aaf 13f9 ab1
13f8 13f7 :2 0 13fa
ab3 :2 0 13fc 0
13fc 13fb 13b2 13fa
:6 0 1405 1 :3 0
71 :3 0 198 :3 0
1c :3 0 ab5 13ff
1401 13fe 1402 0
1405 140 :3 0 ab7
1501 d8 :3 0 84
:3 0 55 :3 0 3d
:2 0 abb 1407 140a
b0 :3 0 174 :3 0
140c 140d 0 abe
1406 140f 1410 :2 0
b0 :3 0 13b :2 0
174 :3 0 1412 1414
0 ac3 1413 1416
:3 0 af :3 0 12f
:3 0 23 :3 0 16d
:3 0 199 :3 0 19a
:3 0 16d :3 0 b0
:3 0 174 :3 0 98
:3 0 1c :4 0 19b
1 :8 0 1439 e0
:4 0 1424 :3 0 f7
:3 0 da :2 0 ac8
1427 1428 :3 0 15
:3 0 e1 :3 0 142a
142b 0 3d :2 0
142c 142d 0 142f
acb 1436 15 :3 0
e1 :3 0 1430 1431
0 e2 :2 0 1432
1433 0 1435 acd
1437 1429 142f 0
1438 0 1435 0
1438 acf 0 1439
ad2 1483 e5 :3 0
15 :3 0 e1 :3 0
143c 143d 0 e4
:3 0 143e 143f 0
1479 c3 :3 0 c4
:3 0 1441 1442 0
c3 :3 0 d3 :3 0
1444 1445 0 e6
:2 0 2 :4 0 19c
:2 0 d5 :2 0 2a
:2 0 ad5 144a 144c
:3 0 ad8 1446 144e
1443 1450 144f :2 0
c6 :3 0 d6 :3 0
1452 1453 0 c8
:4 0 19d :4 0 cb
:2 0 cc :3 0 adc
1457 1459 :3 0 cb
:2 0 e9 :4 0 adf
145b 145d :3 0 cb
:2 0 ea :4 0 ae2
145f 1461 :3 0 cb
:2 0 e4 :3 0 ae5
1463 1465 :3 0 cb
:2 0 eb :4 0 ae8
1467 1469 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 aeb 146c 1470
aef 146b 1472 :3 0
af2 1454 1474 :2 0
1476 af5 1477 1451
1476 0 1478 af7
0 1479 af9 147c
:3 0 147c 0 147c
147b 1479 147a :6 0
147e 33 :3 0 afc
1480 afe 147f 147e
:2 0 1481 b00 :2 0
1483 0 1483 1482
1439 1481 :6 0 148b
1 :3 0 71 :3 0
198 :3 0 1c :3 0
b02 1486 1488 1485
1489 0 148b b04
148c 1417 148b 0
1503 af :3 0 12f
:3 0 23 :3 0 16d
:3 0 199 :3 0 19a
:3 0 16d :3 0 b0
:3 0 19e :3 0 98
:3 0 1c :4 0 19f
1 :8 0 14ae e0
:4 0 1499 :3 0 f7
:3 0 da :2 0 b09
149c 149d :3 0 15
:3 0 e1 :3 0 149f
14a0 0 3d :2 0
14a1 14a2 0 14a4
b0c 14ab 15 :3 0
e1 :3 0 14a5 14a6
0 e2 :2 0 14a7
14a8 0 14aa b0e
14ac 149e 14a4 0
14ad 0 14aa 0
14ad b10 0 14ae
b13 14f8 e5 :3 0
15 :3 0 e1 :3 0
14b1 14b2 0 e4
:3 0 14b3 14b4 0
14ee c3 :3 0 c4
:3 0 14b6 14b7 0
c3 :3 0 d3 :3 0
14b9 14ba 0 e6
:2 0 2 :4 0 1a0
:2 0 d5 :2 0 2a
:2 0 b16 14bf 14c1
:3 0 b19 14bb 14c3
14b8 14c5 14c4 :2 0
c6 :3 0 d6 :3 0
14c7 14c8 0 c8
:4 0 1a1 :4 0 cb
:2 0 cc :3 0 b1d
14cc 14ce :3 0 cb
:2 0 e9 :4 0 b20
14d0 14d2 :3 0 cb
:2 0 ea :4 0 b23
14d4 14d6 :3 0 cb
:2 0 e4 :3 0 b26
14d8 14da :3 0 cb
:2 0 eb :4 0 b29
14dc 14de :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 b2c 14e1 14e5
b30 14e0 14e7 :3 0
b33 14c9 14e9 :2 0
14eb b36 14ec 14c6
14eb 0 14ed b38
0 14ee b3a 14f1
:3 0 14f1 0 14f1
14f0 14ee 14ef :6 0
14f3 35 :3 0 b3d
14f5 b3f 14f4 14f3
:2 0 14f6 b41 :2 0
14f8 0 14f8 14f7
14ae 14f6 :6 0 1500
1 :3 0 71 :3 0
198 :3 0 1c :3 0
b43 14fb 14fd 14fa
14fe 0 1500 b45
1502 1382 1405 0
1503 0 1500 0
1503 b48 0 1504
b4c 1505 131f 1504
0 1507 1037 1315
0 1507 b4f 0
1508 b52 150a fc9
fd0 0 150b 0
1508 0 150b b55
0 150c b58 1511
1e :3 0 1e :3 0
150d 150e 0 1510
b5c 1512 dde 150c
0 1513 0 1510
0 1513 b5e 0
4a3e 67 :3 0 de
:4 0 1514 1515 0
4a3e 69 :3 0 de
:4 0 1517 1518 0
4a3e 26 :3 0 de
:4 0 151a 151b 0
4a3e 71 :3 0 1a2
:4 0 151e 151f :3 0
151d 1520 0 4a3e
84 :3 0 62 :3 0
3d :2 0 b61 1522
1525 da :2 0 3d
:2 0 b66 1527 1529
:3 0 152a :2 0 84
:3 0 61 :3 0 3d
:2 0 b69 152c 152f
da :2 0 3d :2 0
b6e 1531 1533 :3 0
1534 :2 0 152b 1536
1535 :2 0 71 :3 0
1a3 :3 0 22 :3 0
21 :3 0 2e :3 0
67 :3 0 69 :3 0
85 :3 0 58 :3 0
5c :3 0 5b :3 0
5d :3 0 b71 1539
1544 1538 1545 0
1547 b7c 1548 1537
1547 0 1549 b7e
0 4a3e 5f :3 0
1a4 :3 0 115 :3 0
5e :3 0 116 :3 0
117 :3 0 118 :3 0
119 :3 0 5e :3 0
125 :3 0 1a4 :3 0
11a :3 0 11b :3 0
118 :3 0 1a4 :3 0
115 :3 0 118 :3 0
8b :3 0 1a4 :3 0
115 :3 0 92 :3 0
21 :4 0 1a5 1
:8 0 1566 15 :3 0
e1 :3 0 1561 1562
0 e4 :3 0 1563
1564 0 1566 b80
15b0 e5 :3 0 15
:3 0 e1 :3 0 1569
156a 0 e4 :3 0
156b 156c 0 15a6
c3 :3 0 c4 :3 0
156e 156f 0 c3
:3 0 d3 :3 0 1571
1572 0 e6 :2 0
2 :4 0 1a6 :2 0
d5 :2 0 2a :2 0
b83 1577 1579 :3 0
b86 1573 157b 1570
157d 157c :2 0 c6
:3 0 d6 :3 0 157f
1580 0 c8 :4 0
1a7 :4 0 cb :2 0
cc :3 0 b8a 1584
1586 :3 0 cb :2 0
e9 :4 0 b8d 1588
158a :3 0 cb :2 0
ea :4 0 b90 158c
158e :3 0 cb :2 0
e4 :3 0 b93 1590
1592 :3 0 cb :2 0
eb :4 0 b96 1594
1596 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
b99 1599 159d b9d
1598 159f :3 0 ba0
1581 15a1 :2 0 15a3
ba3 15a4 157e 15a3
0 15a5 ba5 0
15a6 ba7 15a9 :3 0
15a9 0 15a9 15a8
15a6 15a7 :6 0 15ab
37 :3 0 baa 15ad
bac 15ac 15ab :2 0
15ae bae :2 0 15b0
0 15b0 15af 1566
15ae :6 0 4a3e 1
:3 0 15 :3 0 e1
:3 0 15b2 15b3 0
15 :3 0 13b :2 0
157 :3 0 15b5 15b7
0 bb2 15b6 15b9
:3 0 15ba :2 0 5e
:3 0 1a8 :2 0 15bc
15bd 0 15bf bb5
15c0 15bb 15bf 0
15c1 bb7 0 4a3e
4b :3 0 3d :2 0
15c2 15c3 0 4a3e
43 :3 0 3d :2 0
15c5 15c6 0 4a3e
81 :4 0 15c8 15c9
0 4a3e 1a9 :3 0
1aa :3 0 78 :3 0
6f :3 0 106 :3 0
91 :3 0 22 :4 0
1ab 1 :8 0 15d8
15 :3 0 e1 :3 0
15d3 15d4 0 e4
:3 0 15d5 15d6 0
15d8 bb9 1622 e5
:3 0 15 :3 0 e1
:3 0 15db 15dc 0
e4 :3 0 15dd 15de
0 1618 c3 :3 0
c4 :3 0 15e0 15e1
0 c3 :3 0 d3
:3 0 15e3 15e4 0
e6 :2 0 2 :4 0
1ac :2 0 d5 :2 0
2a :2 0 bbc 15e9
15eb :3 0 bbf 15e5
15ed 15e2 15ef 15ee
:2 0 c6 :3 0 d6
:3 0 15f1 15f2 0
c8 :4 0 1ad :4 0
cb :2 0 cc :3 0
bc3 15f6 15f8 :3 0
cb :2 0 e9 :4 0
bc6 15fa 15fc :3 0
cb :2 0 ea :4 0
bc9 15fe 1600 :3 0
cb :2 0 e4 :3 0
bcc 1602 1604 :3 0
cb :2 0 eb :4 0
bcf 1606 1608 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 bd2 160b
160f bd6 160a 1611
:3 0 bd9 15f3 1613
:2 0 1615 bdc 1616
15f0 1615 0 1617
bde 0 1618 be0
161b :3 0 161b 0
161b 161a 1618 1619
:6 0 161d 39 :3 0
be3 161f be5 161e
161d :2 0 1620 be7
:2 0 1622 0 1622
1621 15d8 1620 :6 0
4a3e 1 :3 0 116
:3 0 133 :3 0 1624
1625 0 22 :3 0
20 :3 0 be9 1626
1629 13b :2 0 3d
:2 0 bee 162b 162d
:3 0 1ae :3 0 1af
:3 0 43 :3 0 1b0
:3 0 91 :3 0 22
:3 0 9b :3 0 22
:3 0 92 :3 0 23
:4 0 1b1 1 :8 0
163f 15 :3 0 e1
:3 0 163a 163b 0
e4 :3 0 163c 163d
0 163f bf1 1689
e5 :3 0 15 :3 0
e1 :3 0 1642 1643
0 e4 :3 0 1644
1645 0 167f c3
:3 0 c4 :3 0 1647
1648 0 c3 :3 0
d3 :3 0 164a 164b
0 e6 :2 0 2
:4 0 1b2 :2 0 d5
:2 0 2a :2 0 bf4
1650 1652 :3 0 bf7
164c 1654 1649 1656
1655 :2 0 c6 :3 0
d6 :3 0 1658 1659
0 c8 :4 0 1b3
:4 0 cb :2 0 cc
:3 0 bfb 165d 165f
:3 0 cb :2 0 e9
:4 0 bfe 1661 1663
:3 0 cb :2 0 ea
:4 0 c01 1665 1667
:3 0 cb :2 0 e4
:3 0 c04 1669 166b
:3 0 cb :2 0 eb
:4 0 c07 166d 166f
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 c0a
1672 1676 c0e 1671
1678 :3 0 c11 165a
167a :2 0 167c c14
167d 1657 167c 0
167e c16 0 167f
c18 1682 :3 0 1682
0 1682 1681 167f
1680 :6 0 1684 3b
:3 0 c1b 1686 c1d
1685 1684 :2 0 1687
c1f :2 0 1689 0
1689 1688 163f 1687
:6 0 169f 1 :3 0
84 :3 0 43 :3 0
3d :2 0 c21 168b
168e da :2 0 3d
:2 0 c26 1690 1692
:3 0 20 :3 0 22
:3 0 1694 1695 0
1697 c29 169c 43
:3 0 3d :2 0 1698
1699 0 169b c2b
169d 1693 1697 0
169e 0 169b 0
169e c2d 0 169f
c30 16a0 162e 169f
0 16a1 c33 0
4a3e 84 :3 0 4c
:3 0 3d :2 0 c35
16a2 16a5 10a :2 0
3d :2 0 c3a 16a7
16a9 :3 0 116 :3 0
133 :3 0 16ab 16ac
0 22 :3 0 20
:3 0 c3d 16ad 16b0
da :2 0 3d :2 0
c42 16b2 16b4 :3 0
9a :3 0 98 :3 0
9d :3 0 9f :3 0
a0 :3 0 a1 :3 0
9f :3 0 a0 :3 0
a2 :3 0 a5 :3 0
a6 :3 0 a7 :3 0
a8 :3 0 9b :3 0
9e :3 0 a9 :3 0
aa :3 0 ab :3 0
ac :3 0 1e :3 0
17 :3 0 7c :3 0
2b :3 0 2d :3 0
78 :3 0 79 :3 0
74 :3 0 75 :3 0
20 :3 0 7e :3 0
44 :3 0 46 :3 0
47 :3 0 48 :3 0
90 :3 0 9b :3 0
22 :3 0 92 :3 0
23 :3 0 93 :4 0
1b4 1 :8 0 16e4
15 :3 0 e1 :3 0
16df 16e0 0 e4
:3 0 16e1 16e2 0
16e4 c45 172e e5
:3 0 15 :3 0 e1
:3 0 16e7 16e8 0
e4 :3 0 16e9 16ea
0 1724 c3 :3 0
c4 :3 0 16ec 16ed
0 c3 :3 0 d3
:3 0 16ef 16f0 0
e6 :2 0 2 :4 0
1b5 :2 0 d5 :2 0
2a :2 0 c48 16f5
16f7 :3 0 c4b 16f1
16f9 16ee 16fb 16fa
:2 0 c6 :3 0 d6
:3 0 16fd 16fe 0
c8 :4 0 1b6 :4 0
cb :2 0 cc :3 0
c4f 1702 1704 :3 0
cb :2 0 e9 :4 0
c52 1706 1708 :3 0
cb :2 0 ea :4 0
c55 170a 170c :3 0
cb :2 0 e4 :3 0
c58 170e 1710 :3 0
cb :2 0 eb :4 0
c5b 1712 1714 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 c5e 1717
171b c62 1716 171d
:3 0 c65 16ff 171f
:2 0 1721 c68 1722
16fc 1721 0 1723
c6a 0 1724 c6c
1727 :3 0 1727 0
1727 1726 1724 1725
:6 0 1729 3d :3 0
c6f 172b c71 172a
1729 :2 0 172c c73
:2 0 172e 0 172e
172d 16e4 172c :6 0
21f3 1 :3 0 81
:3 0 1e :3 0 1730
1731 0 21f3 57
:3 0 3d :2 0 1733
1734 0 21f3 84
:3 0 76 :3 0 3d
:2 0 c75 1736 1739
da :2 0 2a :2 0
c7a 173b 173d :3 0
84 :3 0 48 :3 0
3d :2 0 c7d 173f
1742 84 :3 0 13b
:2 0 f :3 0 3d
:2 0 c80 1744 1748
c85 1745 174a :3 0
174b :2 0 84 :3 0
44 :3 0 3d :2 0
c88 174d 1750 84
:3 0 13b :2 0 b
:3 0 3d :2 0 c8b
1752 1756 c90 1753
1758 :3 0 1759 :2 0
174c 175b 175a :2 0
84 :3 0 4c :3 0
3d :2 0 c93 175d
1760 da :2 0 2a
:2 0 c98 1762 1764
:3 0 1765 :2 0 d8
:3 0 84 :3 0 c
:3 0 3d :2 0 c9b
1768 176b b0 :3 0
1b7 :3 0 176d 176e
0 c9e 1767 1770
1771 :2 0 13b :2 0
3d :2 0 ca3 1773
1775 :3 0 1776 :2 0
1766 1778 1777 :2 0
c3 :3 0 c4 :3 0
177a 177b 0 c3
:3 0 d3 :3 0 177d
177e 0 18 :2 0
2 :4 0 1b8 :2 0
d5 :2 0 2a :2 0
ca6 1783 1785 :3 0
ca9 177f 1787 177c
1789 1788 :2 0 c6
:3 0 d6 :3 0 178b
178c 0 c8 :4 0
1b9 :4 0 cb :2 0
cc :3 0 cad 1790
1792 :3 0 cb :2 0
e9 :4 0 cb0 1794
1796 :3 0 cb :2 0
f0 :4 0 cb3 1798
179a :3 0 cb :2 0
84 :3 0 d0 :3 0
b0 :3 0 1ba :3 0
179f 17a0 0 cb6
179e 17a2 d1 :4 0
cb8 179d 17a5 cbb
179c 17a7 :3 0 cb
:2 0 f2 :4 0 cbe
17a9 17ab :3 0 cb
:2 0 ce :4 0 cc1
17ad 17af :3 0 cb
:2 0 21 :3 0 cc4
17b1 17b3 :3 0 cb
:2 0 ce :4 0 cc7
17b5 17b7 :3 0 cca
178d 17b9 :2 0 17bb
ccd 17bc 178a 17bb
0 17bd ccf 0
17e7 c3 :3 0 c4
:3 0 17be 17bf 0
c3 :3 0 d3 :3 0
17c1 17c2 0 2a
:2 0 2 :4 0 1bb
:2 0 d5 :2 0 2a
:2 0 cd1 17c7 17c9
:3 0 cd4 17c3 17cb
17c0 17cd 17cc :2 0
c6 :3 0 d6 :3 0
17cf 17d0 0 c8
:4 0 1bc :4 0 cb
:2 0 cc :3 0 cd8
17d4 17d6 :3 0 cdb
17d1 17d8 :2 0 17da
cde 17db 17ce 17da
0 17dc ce0 0
17e7 f5 :3 0 f6
:3 0 17dd 17de 0
b0 :3 0 1ba :3 0
17e0 17e1 0 21
:3 0 f7 :3 0 ce2
17df 17e5 :2 0 17e7
ce6 17fb 57 :3 0
2a :2 0 17e8 17e9
0 17fa 84 :3 0
f :3 0 3d :2 0
cea 17eb 17ee da
:2 0 3d :2 0 cef
17f0 17f2 :3 0 7e
:3 0 3d :2 0 17f4
17f5 0 17f7 cf2
17f8 17f3 17f7 0
17f9 cf4 0 17fa
cf6 17fc 1779 17e7
0 17fd 0 17fa
0 17fd cf9 0
17fe cfc 17ff 175c
17fe 0 1800 cfe
0 181c 3f :3 0
9 :3 0 1801 1802
0 181c 24 :3 0
7 :3 0 1804 1805
0 181c 26 :3 0
8 :3 0 1807 1808
0 181c 44 :3 0
b :3 0 180a 180b
0 181c 45 :3 0
10 :3 0 180d 180e
0 181c 46 :3 0
d :3 0 1810 1811
0 181c 47 :3 0
e :3 0 1813 1814
0 181c 4e :3 0
c :3 0 1816 1817
0 181c 48 :3 0
f :3 0 1819 181a
0 181c d00 181d
173e 181c 0 181e
d0b 0 21f3 15
:3 0 e1 :3 0 181f
1820 0 15 :3 0
da :2 0 157 :3 0
1822 1824 0 d0f
1823 1826 :3 0 1827
:2 0 1e :3 0 165
:2 0 d12 182a 182b
:3 0 182c :2 0 182d
:2 0 1828 182f 182e
:2 0 a0 :3 0 6f
:3 0 2a :2 0 2a
:2 0 d14 1831 1835
da :2 0 1bd :4 0
d1a 1837 1839 :3 0
7a :3 0 1be :2 0
2a :2 0 d1d 183c
183e :3 0 183b 183f
0 1852 15 :3 0
e1 :3 0 1841 1842
0 1bf :3 0 22
:3 0 22 :3 0 1e
:3 0 2b :3 0 2d
:3 0 74 :3 0 75
:3 0 7a :3 0 79
:3 0 78 :3 0 d1f
1844 184f 1843 1850
0 1852 d2a 1853
183a 1852 0 1854
d2d 0 21ef 84
:3 0 4c :3 0 3d
:2 0 d2f 1855 1858
da :2 0 2a :2 0
d34 185a 185c :3 0
90 :3 0 9a :3 0
1e :4 0 1c0 1
:8 0 1877 e0 :4 0
1862 :3 0 f7 :3 0
da :2 0 d39 1865
1866 :3 0 15 :3 0
e1 :3 0 1868 1869
0 3d :2 0 186a
186b 0 186d d3c
1874 15 :3 0 e1
:3 0 186e 186f 0
e2 :2 0 1870 1871
0 1873 d3e 1875
1867 186d 0 1876
0 1873 0 1876
d40 0 1877 d43
18c1 e5 :3 0 15
:3 0 e1 :3 0 187a
187b 0 e4 :3 0
187c 187d 0 18b7
c3 :3 0 c4 :3 0
187f 1880 0 c3
:3 0 d3 :3 0 1882
1883 0 e6 :2 0
2 :4 0 1c1 :2 0
d5 :2 0 2a :2 0
d46 1888 188a :3 0
d49 1884 188c 1881
188e 188d :2 0 c6
:3 0 d6 :3 0 1890
1891 0 c8 :4 0
1c2 :4 0 cb :2 0
cc :3 0 d4d 1895
1897 :3 0 cb :2 0
e9 :4 0 d50 1899
189b :3 0 cb :2 0
ea :4 0 d53 189d
189f :3 0 cb :2 0
e4 :3 0 d56 18a1
18a3 :3 0 cb :2 0
eb :4 0 d59 18a5
18a7 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
d5c 18aa 18ae d60
18a9 18b0 :3 0 d63
1892 18b2 :2 0 18b4
d66 18b5 188f 18b4
0 18b6 d68 0
18b7 d6a 18ba :3 0
18ba 0 18ba 18b9
18b7 18b8 :6 0 18bc
3f :3 0 d6d 18be
d6f 18bd 18bc :2 0
18bf d71 :2 0 18c1
0 18c1 18c0 1877
18bf :6 0 19f2 1
:3 0 1b0 :3 0 91
:3 0 22 :3 0 9a
:3 0 1e :4 0 1c3
1 :8 0 18de e0
:4 0 18c9 :3 0 f7
:3 0 da :2 0 d75
18cc 18cd :3 0 15
:3 0 e1 :3 0 18cf
18d0 0 3d :2 0
18d1 18d2 0 18d4
d78 18db 15 :3 0
e1 :3 0 18d5 18d6
0 e2 :2 0 18d7
18d8 0 18da d7a
18dc 18ce 18d4 0
18dd 0 18da 0
18dd d7c 0 18de
d7f 1928 e5 :3 0
15 :3 0 e1 :3 0
18e1 18e2 0 e4
:3 0 18e3 18e4 0
191e c3 :3 0 c4
:3 0 18e6 18e7 0
c3 :3 0 d3 :3 0
18e9 18ea 0 e6
:2 0 2 :4 0 1c4
:2 0 d5 :2 0 2a
:2 0 d82 18ef 18f1
:3 0 d85 18eb 18f3
18e8 18f5 18f4 :2 0
c6 :3 0 d6 :3 0
18f7 18f8 0 c8
:4 0 1c5 :4 0 cb
:2 0 cc :3 0 d89
18fc 18fe :3 0 cb
:2 0 e9 :4 0 d8c
1900 1902 :3 0 cb
:2 0 ea :4 0 d8f
1904 1906 :3 0 cb
:2 0 e4 :3 0 d92
1908 190a :3 0 cb
:2 0 eb :4 0 d95
190c 190e :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 d98 1911 1915
d9c 1910 1917 :3 0
d9f 18f9 1919 :2 0
191b da2 191c 18f6
191b 0 191d da4
0 191e da6 1921
:3 0 1921 0 1921
1920 191e 191f :6 0
1923 41 :3 0 da9
1925 dab 1924 1923
:2 0 1926 dad :2 0
1928 0 1928 1927
18de 1926 :6 0 19f2
1 :3 0 1e :3 0
81 :3 0 192a 192b
0 19f2 1c6 :3 0
1c7 :3 0 2b :3 0
1b0 :3 0 91 :3 0
22 :3 0 9a :3 0
1e :4 0 1c8 1
:8 0 193b 15 :3 0
e1 :3 0 1936 1937
0 e4 :3 0 1938
1939 0 193b daf
1985 e5 :3 0 15
:3 0 e1 :3 0 193e
193f 0 e4 :3 0
1940 1941 0 197b
c3 :3 0 c4 :3 0
1943 1944 0 c3
:3 0 d3 :3 0 1946
1947 0 e6 :2 0
2 :4 0 1c9 :2 0
d5 :2 0 2a :2 0
db2 194c 194e :3 0
db5 1948 1950 1945
1952 1951 :2 0 c6
:3 0 d6 :3 0 1954
1955 0 c8 :4 0
1ca :4 0 cb :2 0
cc :3 0 db9 1959
195b :3 0 cb :2 0
e9 :4 0 dbc 195d
195f :3 0 cb :2 0
ea :4 0 dbf 1961
1963 :3 0 cb :2 0
e4 :3 0 dc2 1965
1967 :3 0 cb :2 0
eb :4 0 dc5 1969
196b :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
dc8 196e 1972 dcc
196d 1974 :3 0 dcf
1956 1976 :2 0 1978
dd2 1979 1953 1978
0 197a dd4 0
197b dd6 197e :3 0
197e 0 197e 197d
197b 197c :6 0 1980
43 :3 0 dd9 1982
ddb 1981 1980 :2 0
1983 ddd :2 0 1985
0 1985 1984 193b
1983 :6 0 19f2 1
:3 0 116 :3 0 166
:3 0 1987 1988 0
24 :3 0 2b :3 0
167 :2 0 ddf 1989
198d 1cb :2 0 3d
:2 0 de5 198f 1991
:3 0 116 :3 0 1cc
:3 0 9f :3 0 a0
:3 0 2b :3 0 116
:3 0 1cd :3 0 24
:3 0 24 :3 0 1ce
:4 0 1cf 1 :8 0
19a3 15 :3 0 e1
:3 0 199e 199f 0
e4 :3 0 19a0 19a1
0 19a3 de8 19ed
e5 :3 0 15 :3 0
e1 :3 0 19a6 19a7
0 e4 :3 0 19a8
19a9 0 19e3 c3
:3 0 c4 :3 0 19ab
19ac 0 c3 :3 0
d3 :3 0 19ae 19af
0 e6 :2 0 2
:4 0 1d0 :2 0 d5
:2 0 2a :2 0 deb
19b4 19b6 :3 0 dee
19b0 19b8 19ad 19ba
19b9 :2 0 c6 :3 0
d6 :3 0 19bc 19bd
0 c8 :4 0 1d1
:4 0 cb :2 0 cc
:3 0 df2 19c1 19c3
:3 0 cb :2 0 e9
:4 0 df5 19c5 19c7
:3 0 cb :2 0 ea
:4 0 df8 19c9 19cb
:3 0 cb :2 0 e4
:3 0 dfb 19cd 19cf
:3 0 cb :2 0 eb
:4 0 dfe 19d1 19d3
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 e01
19d6 19da e05 19d5
19dc :3 0 e08 19be
19de :2 0 19e0 e0b
19e1 19bb 19e0 0
19e2 e0d 0 19e3
e0f 19e6 :3 0 19e6
0 19e6 19e5 19e3
19e4 :6 0 19e8 45
:3 0 e12 19ea e14
19e9 19e8 :2 0 19eb
e16 :2 0 19ed 0
19ed 19ec 19a3 19eb
:6 0 19ef 1 :3 0
e18 19f0 1992 19ef
0 19f1 e1a 0
19f2 e1c 1e71 84
:3 0 62 :3 0 3d
:2 0 e22 19f3 19f6
da :2 0 3d :2 0
e27 19f8 19fa :3 0
19fb :2 0 84 :3 0
61 :3 0 3d :2 0
e2a 19fd 1a00 da
:2 0 3d :2 0 e2f
1a02 1a04 :3 0 1a05
:2 0 19fc 1a07 1a06
:2 0 58 :3 0 84
:3 0 58 :3 0 3d
:2 0 e32 1a0a 1a0d
1d2 :2 0 84 :3 0
5e :3 0 3d :2 0
e35 1a10 1a13 e38
1a0f 1a15 :3 0 1a09
1a16 0 1b58 5c
:3 0 84 :3 0 5c
:3 0 3d :2 0 e3b
1a19 1a1c 1d2 :2 0
84 :3 0 5e :3 0
3d :2 0 e3e 1a1f
1a22 e41 1a1e 1a24
:3 0 1a18 1a25 0
1b58 5b :3 0 84
:3 0 5b :3 0 3d
:2 0 e44 1a28 1a2b
1d2 :2 0 84 :3 0
5e :3 0 3d :2 0
e47 1a2e 1a31 e4a
1a2d 1a33 :3 0 1a27
1a34 0 1b58 5d
:3 0 84 :3 0 5d
:3 0 3d :2 0 e4d
1a37 1a3a 1d2 :2 0
84 :3 0 5e :3 0
3d :2 0 e50 1a3d
1a40 e53 1a3c 1a42
:3 0 1a36 1a43 0
1b58 84 :3 0 78
:3 0 3d :2 0 e56
1a45 1a48 da :2 0
3d :2 0 e5b 1a4a
1a4c :3 0 90 :3 0
98 :3 0 1c :3 0
92 :3 0 21 :3 0
93 :3 0 a7 :3 0
58 :3 0 1d3 :3 0
5c :3 0 a8 :3 0
5b :3 0 1d4 :3 0
5d :3 0 9e :3 0
57 :3 0 9e :3 0
7e :3 0 1d5 :3 0
9d :3 0 1d6 :3 0
58 :3 0 1d7 :3 0
199 :3 0 19a :3 0
1d7 :3 0 b0 :3 0
1d8 :3 0 9a :3 0
1e :4 0 1d9 1
:8 0 1a82 e0 :4 0
1a6d :3 0 f7 :3 0
da :2 0 e60 1a70
1a71 :3 0 15 :3 0
e1 :3 0 1a73 1a74
0 3d :2 0 1a75
1a76 0 1a78 e63
1a7f 15 :3 0 e1
:3 0 1a79 1a7a 0
e2 :2 0 1a7b 1a7c
0 1a7e e65 1a80
1a72 1a78 0 1a81
0 1a7e 0 1a81
e67 0 1a82 e6a
1acc e5 :3 0 15
:3 0 e1 :3 0 1a85
1a86 0 e4 :3 0
1a87 1a88 0 1ac2
c3 :3 0 c4 :3 0
1a8a 1a8b 0 c3
:3 0 d3 :3 0 1a8d
1a8e 0 e6 :2 0
2 :4 0 1da :2 0
d5 :2 0 2a :2 0
e6d 1a93 1a95 :3 0
e70 1a8f 1a97 1a8c
1a99 1a98 :2 0 c6
:3 0 d6 :3 0 1a9b
1a9c 0 c8 :4 0
1db :4 0 cb :2 0
cc :3 0 e74 1aa0
1aa2 :3 0 cb :2 0
e9 :4 0 e77 1aa4
1aa6 :3 0 cb :2 0
ea :4 0 e7a 1aa8
1aaa :3 0 cb :2 0
e4 :3 0 e7d 1aac
1aae :3 0 cb :2 0
eb :4 0 e80 1ab0
1ab2 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
e83 1ab5 1ab9 e87
1ab4 1abb :3 0 e8a
1a9d 1abd :2 0 1abf
e8d 1ac0 1a9a 1abf
0 1ac1 e8f 0
1ac2 e91 1ac5 :3 0
1ac5 0 1ac5 1ac4
1ac2 1ac3 :6 0 1ac7
47 :3 0 e94 1ac9
e96 1ac8 1ac7 :2 0
1aca e98 :2 0 1acc
0 1acc 1acb 1a82
1aca :6 0 1ace 1
:3 0 e9a 1b54 90
:3 0 98 :3 0 1c
:3 0 92 :3 0 21
:3 0 93 :3 0 a7
:3 0 58 :3 0 1d3
:3 0 5c :3 0 a8
:3 0 5b :3 0 1d4
:3 0 5d :3 0 9e
:3 0 57 :3 0 9e
:3 0 7e :3 0 1d5
:3 0 9d :3 0 1d6
:3 0 58 :3 0 1dc
:3 0 9d :3 0 9d
:3 0 5b :3 0 1d7
:3 0 199 :3 0 19a
:3 0 1d7 :3 0 b0
:3 0 1d8 :3 0 9a
:3 0 1e :4 0 1dd
1 :8 0 1b07 e0
:4 0 1af2 :3 0 f7
:3 0 da :2 0 e9e
1af5 1af6 :3 0 15
:3 0 e1 :3 0 1af8
1af9 0 3d :2 0
1afa 1afb 0 1afd
ea1 1b04 15 :3 0
e1 :3 0 1afe 1aff
0 e2 :2 0 1b00
1b01 0 1b03 ea3
1b05 1af7 1afd 0
1b06 0 1b03 0
1b06 ea5 0 1b07
ea8 1b51 e5 :3 0
15 :3 0 e1 :3 0
1b0a 1b0b 0 e4
:3 0 1b0c 1b0d 0
1b47 c3 :3 0 c4
:3 0 1b0f 1b10 0
c3 :3 0 d3 :3 0
1b12 1b13 0 e6
:2 0 2 :4 0 1de
:2 0 d5 :2 0 2a
:2 0 eab 1b18 1b1a
:3 0 eae 1b14 1b1c
1b11 1b1e 1b1d :2 0
c6 :3 0 d6 :3 0
1b20 1b21 0 c8
:4 0 1df :4 0 cb
:2 0 cc :3 0 eb2
1b25 1b27 :3 0 cb
:2 0 e9 :4 0 eb5
1b29 1b2b :3 0 cb
:2 0 ea :4 0 eb8
1b2d 1b2f :3 0 cb
:2 0 e4 :3 0 ebb
1b31 1b33 :3 0 cb
:2 0 eb :4 0 ebe
1b35 1b37 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 ec1 1b3a 1b3e
ec5 1b39 1b40 :3 0
ec8 1b22 1b42 :2 0
1b44 ecb 1b45 1b1f
1b44 0 1b46 ecd
0 1b47 ecf 1b4a
:3 0 1b4a 0 1b4a
1b49 1b47 1b48 :6 0
1b4c 49 :3 0 ed2
1b4e ed4 1b4d 1b4c
:2 0 1b4f ed6 :2 0
1b51 0 1b51 1b50
1b07 1b4f :6 0 1b53
1 :3 0 ed8 1b55
1a4d 1ace 0 1b56
0 1b53 0 1b56
eda 0 1b58 140
:3 0 edd 1d99 84
:3 0 62 :3 0 3d
:2 0 ee3 1b59 1b5c
da :2 0 3d :2 0
ee8 1b5e 1b60 :3 0
58 :3 0 84 :3 0
58 :3 0 3d :2 0
eeb 1b63 1b66 1d2
:2 0 84 :3 0 5e
:3 0 3d :2 0 eee
1b69 1b6c ef1 1b68
1b6e :3 0 1b62 1b6f
0 1bfd 5c :3 0
84 :3 0 5c :3 0
3d :2 0 ef4 1b72
1b75 1d2 :2 0 84
:3 0 5e :3 0 3d
:2 0 ef7 1b78 1b7b
efa 1b77 1b7d :3 0
1b71 1b7e 0 1bfd
90 :3 0 98 :3 0
1c :3 0 92 :3 0
21 :3 0 93 :3 0
a7 :3 0 58 :3 0
1d3 :3 0 5c :3 0
9e :3 0 57 :3 0
9e :3 0 7e :3 0
1d5 :3 0 9d :3 0
1d6 :3 0 58 :3 0
1d7 :3 0 199 :3 0
19a :3 0 1d7 :3 0
b0 :3 0 1d8 :3 0
9a :3 0 1e :4 0
1e0 1 :8 0 1bb0
e0 :4 0 1b9b :3 0
f7 :3 0 da :2 0
eff 1b9e 1b9f :3 0
15 :3 0 e1 :3 0
1ba1 1ba2 0 3d
:2 0 1ba3 1ba4 0
1ba6 f02 1bad 15
:3 0 e1 :3 0 1ba7
1ba8 0 e2 :2 0
1ba9 1baa 0 1bac
f04 1bae 1ba0 1ba6
0 1baf 0 1bac
0 1baf f06 0
1bb0 f09 1bfa e5
:3 0 15 :3 0 e1
:3 0 1bb3 1bb4 0
e4 :3 0 1bb5 1bb6
0 1bf0 c3 :3 0
c4 :3 0 1bb8 1bb9
0 c3 :3 0 d3
:3 0 1bbb 1bbc 0
e6 :2 0 2 :4 0
1e1 :2 0 d5 :2 0
2a :2 0 f0c 1bc1
1bc3 :3 0 f0f 1bbd
1bc5 1bba 1bc7 1bc6
:2 0 c6 :3 0 d6
:3 0 1bc9 1bca 0
c8 :4 0 1e2 :4 0
cb :2 0 cc :3 0
f13 1bce 1bd0 :3 0
cb :2 0 e9 :4 0
f16 1bd2 1bd4 :3 0
cb :2 0 ea :4 0
f19 1bd6 1bd8 :3 0
cb :2 0 e4 :3 0
f1c 1bda 1bdc :3 0
cb :2 0 eb :4 0
f1f 1bde 1be0 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 f22 1be3
1be7 f26 1be2 1be9
:3 0 f29 1bcb 1beb
:2 0 1bed f2c 1bee
1bc8 1bed 0 1bef
f2e 0 1bf0 f30
1bf3 :3 0 1bf3 0
1bf3 1bf2 1bf0 1bf1
:6 0 1bf5 4b :3 0
f33 1bf7 f35 1bf6
1bf5 :2 0 1bf8 f37
:2 0 1bfa 0 1bfa
1bf9 1bb0 1bf8 :6 0
1bfd 1 :3 0 140
:3 0 f39 1bfe 1b61
1bfd 0 1d9b 84
:3 0 61 :3 0 3d
:2 0 f3d 1bff 1c02
da :2 0 3d :2 0
f42 1c04 1c06 :3 0
5b :3 0 84 :3 0
5b :3 0 3d :2 0
f45 1c09 1c0c 1d2
:2 0 84 :3 0 5e
:3 0 3d :2 0 f48
1c0f 1c12 f4b 1c0e
1c14 :3 0 1c08 1c15
0 1d28 5d :3 0
84 :3 0 5d :3 0
3d :2 0 f4e 1c18
1c1b 1d2 :2 0 84
:3 0 5e :3 0 3d
:2 0 f51 1c1e 1c21
f54 1c1d 1c23 :3 0
1c17 1c24 0 1d28
84 :3 0 78 :3 0
3d :2 0 f57 1c26
1c29 da :2 0 3d
:2 0 f5c 1c2b 1c2d
:3 0 90 :3 0 98
:3 0 1c :3 0 92
:3 0 21 :3 0 93
:3 0 a8 :3 0 5b
:3 0 1d4 :3 0 5d
:3 0 9e :3 0 57
:3 0 9e :3 0 7e
:3 0 1d7 :3 0 199
:3 0 19a :3 0 1d7
:3 0 b0 :3 0 1d8
:3 0 9a :3 0 1e
:4 0 1e3 1 :8 0
1c5b e0 :4 0 1c46
:3 0 f7 :3 0 da
:2 0 f61 1c49 1c4a
:3 0 15 :3 0 e1
:3 0 1c4c 1c4d 0
3d :2 0 1c4e 1c4f
0 1c51 f64 1c58
15 :3 0 e1 :3 0
1c52 1c53 0 e2
:2 0 1c54 1c55 0
1c57 f66 1c59 1c4b
1c51 0 1c5a 0
1c57 0 1c5a f68
0 1c5b f6b 1ca5
e5 :3 0 15 :3 0
e1 :3 0 1c5e 1c5f
0 e4 :3 0 1c60
1c61 0 1c9b c3
:3 0 c4 :3 0 1c63
1c64 0 c3 :3 0
d3 :3 0 1c66 1c67
0 e6 :2 0 2
:4 0 1e4 :2 0 d5
:2 0 2a :2 0 f6e
1c6c 1c6e :3 0 f71
1c68 1c70 1c65 1c72
1c71 :2 0 c6 :3 0
d6 :3 0 1c74 1c75
0 c8 :4 0 1e5
:4 0 cb :2 0 cc
:3 0 f75 1c79 1c7b
:3 0 cb :2 0 e9
:4 0 f78 1c7d 1c7f
:3 0 cb :2 0 ea
:4 0 f7b 1c81 1c83
:3 0 cb :2 0 e4
:3 0 f7e 1c85 1c87
:3 0 cb :2 0 eb
:4 0 f81 1c89 1c8b
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 f84
1c8e 1c92 f88 1c8d
1c94 :3 0 f8b 1c76
1c96 :2 0 1c98 f8e
1c99 1c73 1c98 0
1c9a f90 0 1c9b
f92 1c9e :3 0 1c9e
0 1c9e 1c9d 1c9b
1c9c :6 0 1ca0 4d
:3 0 f95 1ca2 f97
1ca1 1ca0 :2 0 1ca3
f99 :2 0 1ca5 0
1ca5 1ca4 1c5b 1ca3
:6 0 1ca7 1 :3 0
f9b 1d25 90 :3 0
98 :3 0 1c :3 0
92 :3 0 21 :3 0
93 :3 0 a8 :3 0
5b :3 0 1d4 :3 0
5d :3 0 9e :3 0
57 :3 0 9e :3 0
7e :3 0 1dc :3 0
9d :3 0 9d :3 0
5b :3 0 1d7 :3 0
199 :3 0 19a :3 0
1d7 :3 0 b0 :3 0
1d8 :3 0 9a :3 0
1e :4 0 1e6 1
:8 0 1cd8 e0 :4 0
1cc3 :3 0 f7 :3 0
da :2 0 f9f 1cc6
1cc7 :3 0 15 :3 0
e1 :3 0 1cc9 1cca
0 3d :2 0 1ccb
1ccc 0 1cce fa2
1cd5 15 :3 0 e1
:3 0 1ccf 1cd0 0
e2 :2 0 1cd1 1cd2
0 1cd4 fa4 1cd6
1cc8 1cce 0 1cd7
0 1cd4 0 1cd7
fa6 0 1cd8 fa9
1d22 e5 :3 0 15
:3 0 e1 :3 0 1cdb
1cdc 0 e4 :3 0
1cdd 1cde 0 1d18
c3 :3 0 c4 :3 0
1ce0 1ce1 0 c3
:3 0 d3 :3 0 1ce3
1ce4 0 e6 :2 0
2 :4 0 1e7 :2 0
d5 :2 0 2a :2 0
fac 1ce9 1ceb :3 0
faf 1ce5 1ced 1ce2
1cef 1cee :2 0 c6
:3 0 d6 :3 0 1cf1
1cf2 0 c8 :4 0
1e8 :4 0 cb :2 0
cc :3 0 fb3 1cf6
1cf8 :3 0 cb :2 0
e9 :4 0 fb6 1cfa
1cfc :3 0 cb :2 0
ea :4 0 fb9 1cfe
1d00 :3 0 cb :2 0
e4 :3 0 fbc 1d02
1d04 :3 0 cb :2 0
eb :4 0 fbf 1d06
1d08 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
fc2 1d0b 1d0f fc6
1d0a 1d11 :3 0 fc9
1cf3 1d13 :2 0 1d15
fcc 1d16 1cf0 1d15
0 1d17 fce 0
1d18 fd0 1d1b :3 0
1d1b 0 1d1b 1d1a
1d18 1d19 :6 0 1d1d
4f :3 0 fd3 1d1f
fd5 1d1e 1d1d :2 0
1d20 fd7 :2 0 1d22
0 1d22 1d21 1cd8
1d20 :6 0 1d24 1
:3 0 fd9 1d26 1c2e
1ca7 0 1d27 0
1d24 0 1d27 fdb
0 1d28 fde 1d29
1c07 1d28 0 1d9b
90 :3 0 98 :3 0
1c :3 0 9e :3 0
57 :3 0 9e :3 0
7e :3 0 92 :3 0
21 :3 0 93 :3 0
9a :3 0 1e :4 0
1e9 1 :8 0 1d4c
e0 :4 0 1d37 :3 0
f7 :3 0 da :2 0
fe4 1d3a 1d3b :3 0
15 :3 0 e1 :3 0
1d3d 1d3e 0 3d
:2 0 1d3f 1d40 0
1d42 fe7 1d49 15
:3 0 e1 :3 0 1d43
1d44 0 e2 :2 0
1d45 1d46 0 1d48
fe9 1d4a 1d3c 1d42
0 1d4b 0 1d48
0 1d4b feb 0
1d4c fee 1d96 e5
:3 0 15 :3 0 e1
:3 0 1d4f 1d50 0
e4 :3 0 1d51 1d52
0 1d8c c3 :3 0
c4 :3 0 1d54 1d55
0 c3 :3 0 d3
:3 0 1d57 1d58 0
e6 :2 0 2 :4 0
1ea :2 0 d5 :2 0
2a :2 0 ff1 1d5d
1d5f :3 0 ff4 1d59
1d61 1d56 1d63 1d62
:2 0 c6 :3 0 d6
:3 0 1d65 1d66 0
c8 :4 0 1eb :4 0
cb :2 0 cc :3 0
ff8 1d6a 1d6c :3 0
cb :2 0 e9 :4 0
ffb 1d6e 1d70 :3 0
cb :2 0 ea :4 0
ffe 1d72 1d74 :3 0
cb :2 0 e4 :3 0
1001 1d76 1d78 :3 0
cb :2 0 eb :4 0
1004 1d7a 1d7c :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1007 1d7f
1d83 100b 1d7e 1d85
:3 0 100e 1d67 1d87
:2 0 1d89 1011 1d8a
1d64 1d89 0 1d8b
1013 0 1d8c 1015
1d8f :3 0 1d8f 0
1d8f 1d8e 1d8c 1d8d
:6 0 1d91 51 :3 0
1018 1d93 101a 1d92
1d91 :2 0 1d94 101c
:2 0 1d96 0 1d96
1d95 1d4c 1d94 :6 0
1d98 1 :3 0 101e
1d9a 1a08 1b58 0
1d9b 0 1d98 0
1d9b 1020 0 1e70
1b0 :3 0 91 :3 0
22 :3 0 9a :3 0
1e :4 0 1c3 1
:8 0 1db7 e0 :4 0
1da2 :3 0 f7 :3 0
da :2 0 1027 1da5
1da6 :3 0 15 :3 0
e1 :3 0 1da8 1da9
0 3d :2 0 1daa
1dab 0 1dad 102a
1db4 15 :3 0 e1
:3 0 1dae 1daf 0
e2 :2 0 1db0 1db1
0 1db3 102c 1db5
1da7 1dad 0 1db6
0 1db3 0 1db6
102e 0 1db7 1031
1e01 e5 :3 0 15
:3 0 e1 :3 0 1dba
1dbb 0 e4 :3 0
1dbc 1dbd 0 1df7
c3 :3 0 c4 :3 0
1dbf 1dc0 0 c3
:3 0 d3 :3 0 1dc2
1dc3 0 e6 :2 0
2 :4 0 1ec :2 0
d5 :2 0 2a :2 0
1034 1dc8 1dca :3 0
1037 1dc4 1dcc 1dc1
1dce 1dcd :2 0 c6
:3 0 d6 :3 0 1dd0
1dd1 0 c8 :4 0
1ed :4 0 cb :2 0
cc :3 0 103b 1dd5
1dd7 :3 0 cb :2 0
e9 :4 0 103e 1dd9
1ddb :3 0 cb :2 0
ea :4 0 1041 1ddd
1ddf :3 0 cb :2 0
e4 :3 0 1044 1de1
1de3 :3 0 cb :2 0
eb :4 0 1047 1de5
1de7 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
104a 1dea 1dee 104e
1de9 1df0 :3 0 1051
1dd2 1df2 :2 0 1df4
1054 1df5 1dcf 1df4
0 1df6 1056 0
1df7 1058 1dfa :3 0
1dfa 0 1dfa 1df9
1df7 1df8 :6 0 1dfc
53 :3 0 105b 1dfe
105d 1dfd 1dfc :2 0
1dff 105f :2 0 1e01
0 1e01 1e00 1db7
1dff :6 0 1e70 1
:3 0 1ee :3 0 1e
:3 0 1ef :3 0 1f0
:3 0 1f1 :3 0 1f2
:3 0 1f3 :3 0 1f4
:3 0 1ee :3 0 98
:3 0 23 :4 0 1f5
1 :8 0 1e24 e0
:4 0 1e0f :3 0 f7
:3 0 da :2 0 1063
1e12 1e13 :3 0 15
:3 0 e1 :3 0 1e15
1e16 0 3d :2 0
1e17 1e18 0 1e1a
1066 1e21 15 :3 0
e1 :3 0 1e1b 1e1c
0 e2 :2 0 1e1d
1e1e 0 1e20 1068
1e22 1e14 1e1a 0
1e23 0 1e20 0
1e23 106a 0 1e24
106d 1e6e e5 :3 0
15 :3 0 e1 :3 0
1e27 1e28 0 e4
:3 0 1e29 1e2a 0
1e64 c3 :3 0 c4
:3 0 1e2c 1e2d 0
c3 :3 0 d3 :3 0
1e2f 1e30 0 e6
:2 0 2 :4 0 1f6
:2 0 d5 :2 0 2a
:2 0 1070 1e35 1e37
:3 0 1073 1e31 1e39
1e2e 1e3b 1e3a :2 0
c6 :3 0 d6 :3 0
1e3d 1e3e 0 c8
:4 0 1f7 :4 0 cb
:2 0 cc :3 0 1077
1e42 1e44 :3 0 cb
:2 0 e9 :4 0 107a
1e46 1e48 :3 0 cb
:2 0 ea :4 0 107d
1e4a 1e4c :3 0 cb
:2 0 e4 :3 0 1080
1e4e 1e50 :3 0 cb
:2 0 eb :4 0 1083
1e52 1e54 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1086 1e57 1e5b
108a 1e56 1e5d :3 0
108d 1e3f 1e5f :2 0
1e61 1090 1e62 1e3c
1e61 0 1e63 1092
0 1e64 1094 1e67
:3 0 1e67 0 1e67
1e66 1e64 1e65 :6 0
1e69 55 :3 0 1097
1e6b 1099 1e6a 1e69
:2 0 1e6c 109b :2 0
1e6e 0 1e6e 1e6d
1e24 1e6c :6 0 1e70
1 :3 0 109d 1e72
185d 19f2 0 1e73
0 1e70 0 1e73
10a1 0 21ef 56
:3 0 2a :2 0 1e74
1e75 0 21ef af
:3 0 98 :3 0 17
:4 0 1f8 1 :8 0
1e90 e0 :4 0 1e7b
:3 0 f7 :3 0 da
:2 0 10a6 1e7e 1e7f
:3 0 15 :3 0 e1
:3 0 1e81 1e82 0
3d :2 0 1e83 1e84
0 1e86 10a9 1e8d
15 :3 0 e1 :3 0
1e87 1e88 0 e2
:2 0 1e89 1e8a 0
1e8c 10ab 1e8e 1e80
1e86 0 1e8f 0
1e8c 0 1e8f 10ad
0 1e90 10b0 1eda
e5 :3 0 15 :3 0
e1 :3 0 1e93 1e94
0 e4 :3 0 1e95
1e96 0 1ed0 c3
:3 0 c4 :3 0 1e98
1e99 0 c3 :3 0
d3 :3 0 1e9b 1e9c
0 e6 :2 0 2
:4 0 1f9 :2 0 d5
:2 0 2a :2 0 10b3
1ea1 1ea3 :3 0 10b6
1e9d 1ea5 1e9a 1ea7
1ea6 :2 0 c6 :3 0
d6 :3 0 1ea9 1eaa
0 c8 :4 0 1fa
:4 0 cb :2 0 cc
:3 0 10ba 1eae 1eb0
:3 0 cb :2 0 e9
:4 0 10bd 1eb2 1eb4
:3 0 cb :2 0 ea
:4 0 10c0 1eb6 1eb8
:3 0 cb :2 0 e4
:3 0 10c3 1eba 1ebc
:3 0 cb :2 0 eb
:4 0 10c6 1ebe 1ec0
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 10c9
1ec3 1ec7 10cd 1ec2
1ec9 :3 0 10d0 1eab
1ecb :2 0 1ecd 10d3
1ece 1ea8 1ecd 0
1ecf 10d5 0 1ed0
10d7 1ed3 :3 0 1ed3
0 1ed3 1ed2 1ed0
1ed1 :6 0 1ed5 57
:3 0 10da 1ed7 10dc
1ed6 1ed5 :2 0 1ed8
10de :2 0 1eda 0
1eda 1ed9 1e90 1ed8
:6 0 21ef 1 :3 0
1fb :3 0 91 :3 0
22 :3 0 92 :3 0
23 :4 0 1fc 1
:8 0 1ef7 e0 :4 0
1ee2 :3 0 f7 :3 0
da :2 0 10e2 1ee5
1ee6 :3 0 15 :3 0
e1 :3 0 1ee8 1ee9
0 3d :2 0 1eea
1eeb 0 1eed 10e5
1ef4 15 :3 0 e1
:3 0 1eee 1eef 0
e2 :2 0 1ef0 1ef1
0 1ef3 10e7 1ef5
1ee7 1eed 0 1ef6
0 1ef3 0 1ef6
10e9 0 1ef7 10ec
1f41 e5 :3 0 15
:3 0 e1 :3 0 1efa
1efb 0 e4 :3 0
1efc 1efd 0 1f37
c3 :3 0 c4 :3 0
1eff 1f00 0 c3
:3 0 d3 :3 0 1f02
1f03 0 e6 :2 0
2 :4 0 1fd :2 0
d5 :2 0 2a :2 0
10ef 1f08 1f0a :3 0
10f2 1f04 1f0c 1f01
1f0e 1f0d :2 0 c6
:3 0 d6 :3 0 1f10
1f11 0 c8 :4 0
1fe :4 0 cb :2 0
cc :3 0 10f6 1f15
1f17 :3 0 cb :2 0
e9 :4 0 10f9 1f19
1f1b :3 0 cb :2 0
ea :4 0 10fc 1f1d
1f1f :3 0 cb :2 0
e4 :3 0 10ff 1f21
1f23 :3 0 cb :2 0
eb :4 0 1102 1f25
1f27 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
1105 1f2a 1f2e 1109
1f29 1f30 :3 0 110c
1f12 1f32 :2 0 1f34
110f 1f35 1f0f 1f34
0 1f36 1111 0
1f37 1113 1f3a :3 0
1f3a 0 1f3a 1f39
1f37 1f38 :6 0 1f3c
59 :3 0 1116 1f3e
1118 1f3d 1f3c :2 0
1f3f 111a :2 0 1f41
0 1f41 1f40 1ef7
1f3f :6 0 21ef 1
:3 0 84 :3 0 76
:3 0 3d :2 0 111c
1f43 1f46 da :2 0
2a :2 0 1121 1f48
1f4a :3 0 1f4b :2 0
84 :3 0 77 :3 0
3d :2 0 1124 1f4d
1f50 da :2 0 3d
:2 0 1129 1f52 1f54
:3 0 1f55 :2 0 1f4c
1f57 1f56 :2 0 4a
:3 0 3d :2 0 1f59
1f5a 0 21ec 40
:3 0 3d :2 0 1f5c
1f5d 0 21ec 1ff
:3 0 200 :3 0 1f5f
1f60 0 57 :3 0
2a :2 0 112c 1f61
1f64 13b :2 0 3d
:2 0 1131 1f66 1f68
:3 0 51 :3 0 13a
:2 0 1f6a 1f6b 0
1f6d 1134 1f72 51
:3 0 2a :2 0 1f6e
1f6f 0 1f71 1136
1f73 1f69 1f6d 0
1f74 0 1f71 0
1f74 1138 0 21ec
84 :3 0 f :3 0
3d :2 0 113b 1f75
1f78 da :2 0 3d
:2 0 1140 1f7a 1f7c
:3 0 44 :3 0 3d
:2 0 1f7e 1f7f 0
1f81 1143 1f82 1f7d
1f81 0 1f83 1145
0 21ec 6b :3 0
201 :3 0 31 :3 0
32 :3 0 84 :3 0
46 :3 0 3d :2 0
1147 1f88 1f8b 84
:3 0 47 :3 0 3d
:2 0 114a 1f8d 1f90
84 :3 0 52 :3 0
3d :2 0 114d 1f92
1f95 84 :3 0 4e
:3 0 3d :2 0 1150
1f97 1f9a 84 :3 0
48 :3 0 3d :2 0
1153 1f9c 1f9f 84
:3 0 45 :3 0 3d
:2 0 1156 1fa1 1fa4
84 :3 0 4f :3 0
3d :2 0 1159 1fa6
1fa9 84 :3 0 50
:3 0 3d :2 0 115c
1fab 1fae 44 :3 0
3f :3 0 49 :3 0
115f 1f85 1fb3 1f84
1fb4 0 21ec 84
:3 0 6b :3 0 3d
:2 0 116d 1fb6 1fb9
b0 :3 0 da :2 0
202 :3 0 1fbb 1fbd
0 1172 1fbc 1fbf
:3 0 c3 :3 0 c4
:3 0 1fc1 1fc2 0
c3 :3 0 d3 :3 0
1fc4 1fc5 0 203
:2 0 2 :4 0 204
:2 0 d5 :2 0 2a
:2 0 1175 1fca 1fcc
:3 0 1178 1fc6 1fce
1fc3 1fd0 1fcf :2 0
c6 :3 0 d6 :3 0
1fd2 1fd3 0 c8
:4 0 205 :4 0 cb
:2 0 cc :3 0 117c
1fd7 1fd9 :3 0 cb
:2 0 e9 :4 0 117f
1fdb 1fdd :3 0 cb
:2 0 f0 :4 0 1182
1fdf 1fe1 :3 0 cb
:2 0 84 :3 0 d0
:3 0 b0 :3 0 202
:3 0 1fe6 1fe7 0
1185 1fe5 1fe9 d1
:4 0 1187 1fe4 1fec
118a 1fe3 1fee :3 0
118d 1fd4 1ff0 :2 0
1ff2 1190 1ff3 1fd1
1ff2 0 1ff4 1192
0 201e c3 :3 0
c4 :3 0 1ff5 1ff6
0 c3 :3 0 d3
:3 0 1ff8 1ff9 0
2a :2 0 2 :4 0
206 :2 0 d5 :2 0
2a :2 0 1194 1ffe
2000 :3 0 1197 1ffa
2002 1ff7 2004 2003
:2 0 c6 :3 0 d6
:3 0 2006 2007 0
c8 :4 0 207 :4 0
cb :2 0 cc :3 0
119b 200b 200d :3 0
119e 2008 200f :2 0
2011 11a1 2012 2005
2011 0 2013 11a3
0 201e f5 :3 0
208 :3 0 2014 2015
0 b0 :3 0 202
:3 0 2017 2018 0
f7 :3 0 11a5 2016
201b :2 0 201e 140
:3 0 11a8 2097 84
:3 0 6b :3 0 3d
:2 0 11ac 201f 2022
13b :2 0 3d :2 0
11b1 2024 2026 :3 0
c3 :3 0 c4 :3 0
2028 2029 0 c3
:3 0 d3 :3 0 202b
202c 0 18 :2 0
2 :4 0 209 :2 0
d5 :2 0 2a :2 0
11b4 2031 2033 :3 0
11b7 202d 2035 202a
2037 2036 :2 0 c6
:3 0 d6 :3 0 2039
203a 0 c8 :4 0
20a :4 0 cb :2 0
cc :3 0 11bb 203e
2040 :3 0 cb :2 0
e9 :4 0 11be 2042
2044 :3 0 cb :2 0
f0 :4 0 11c1 2046
2048 :3 0 cb :2 0
84 :3 0 d0 :3 0
6b :3 0 11c4 204c
204e d1 :4 0 11c6
204b 2051 11c9 204a
2053 :3 0 cb :2 0
f2 :4 0 11cc 2055
2057 :3 0 cb :2 0
ce :4 0 11cf 2059
205b :3 0 cb :2 0
22 :3 0 11d2 205d
205f :3 0 cb :2 0
ce :4 0 11d5 2061
2063 :3 0 11d8 203b
2065 :2 0 2067 11db
2068 2038 2067 0
2069 11dd 0 2095
c3 :3 0 c4 :3 0
206a 206b 0 c3
:3 0 d3 :3 0 206d
206e 0 2a :2 0
2 :4 0 20b :2 0
d5 :2 0 2a :2 0
11df 2073 2075 :3 0
11e2 206f 2077 206c
2079 2078 :2 0 c6
:3 0 d6 :3 0 207b
207c 0 c8 :4 0
20c :4 0 cb :2 0
cc :3 0 11e6 2080
2082 :3 0 11e9 207d
2084 :2 0 2086 11ec
2087 207a 2086 0
2088 11ee 0 2095
f5 :3 0 f6 :3 0
2089 208a 0 84
:3 0 6b :3 0 3d
:2 0 11f0 208c 208f
22 :3 0 f7 :3 0
11f3 208b 2093 :2 0
2095 11f7 2096 2027
2095 0 2098 1fc0
201e 0 2098 11fb
0 21ec 84 :3 0
44 :3 0 3d :2 0
11fe 2099 209c da
:2 0 3d :2 0 1203
209e 20a0 :3 0 4e
:3 0 b0 :3 0 20d
:3 0 20a3 20a4 0
20a2 20a5 0 20a7
1206 20b8 4e :3 0
1ff :3 0 19a :3 0
20a9 20aa 0 84
:3 0 4e :3 0 3d
:2 0 1208 20ac 20af
b0 :3 0 20d :3 0
20b1 20b2 0 120b
20ab 20b4 20a8 20b5
0 20b7 120e 20b9
20a1 20a7 0 20ba
0 20b7 0 20ba
1210 0 21ec 6a
:3 0 5a :2 0 20bb
20bc 0 21ec 66
:3 0 20e :3 0 1e
:3 0 22 :3 0 22
:3 0 21 :3 0 6a
:3 0 41 :3 0 29
:3 0 29 :3 0 29
:3 0 29 :3 0 24
:3 0 26 :3 0 49
:3 0 3f :3 0 44
:3 0 46 :3 0 47
:3 0 40 :3 0 52
:3 0 2e :3 0 4a
:3 0 4e :3 0 48
:3 0 45 :3 0 51
:3 0 4f :3 0 53
:3 0 1a :3 0 3d
:2 0 3d :2 0 5a
:2 0 5a :2 0 1213
20bf 20e0 20be 20e1
0 21ec 84 :3 0
66 :3 0 3d :2 0
1234 20e3 20e6 da
:2 0 20f :2 0 1239
20e8 20ea :3 0 c3
:3 0 c4 :3 0 20ec
20ed 0 c3 :3 0
d3 :3 0 20ef 20f0
0 18 :2 0 2
:4 0 210 :2 0 d5
:2 0 2a :2 0 123c
20f5 20f7 :3 0 123f
20f1 20f9 20ee 20fb
20fa :2 0 c6 :3 0
d6 :3 0 20fd 20fe
0 c8 :4 0 211
:4 0 cb :2 0 cc
:3 0 1243 2102 2104
:3 0 cb :2 0 e9
:4 0 1246 2106 2108
:3 0 cb :2 0 f0
:4 0 1249 210a 210c
:3 0 cb :2 0 84
:3 0 d0 :3 0 b0
:3 0 212 :3 0 2111
2112 0 124c 2110
2114 d1 :4 0 124e
210f 2117 1251 210e
2119 :3 0 cb :2 0
f2 :4 0 1254 211b
211d :3 0 cb :2 0
ce :4 0 1257 211f
2121 :3 0 cb :2 0
21 :3 0 125a 2123
2125 :3 0 cb :2 0
ce :4 0 125d 2127
2129 :3 0 1260 20ff
212b :2 0 212d 1263
212e 20fc 212d 0
212f 1265 0 215a
c3 :3 0 c4 :3 0
2130 2131 0 c3
:3 0 d3 :3 0 2133
2134 0 2a :2 0
2 :4 0 213 :2 0
d5 :2 0 2a :2 0
1267 2139 213b :3 0
126a 2135 213d 2132
213f 213e :2 0 c6
:3 0 d6 :3 0 2141
2142 0 c8 :4 0
214 :4 0 cb :2 0
cc :3 0 126e 2146
2148 :3 0 1271 2143
214a :2 0 214c 1274
214d 2140 214c 0
214e 1276 0 215a
f5 :3 0 f6 :3 0
214f 2150 0 b0
:3 0 212 :3 0 2152
2153 0 21 :3 0
f7 :3 0 1278 2151
2157 :2 0 215a 140
:3 0 127c 21e9 84
:3 0 66 :3 0 3d
:2 0 1280 215b 215e
13b :2 0 3d :2 0
1285 2160 2162 :3 0
c3 :3 0 c4 :3 0
2164 2165 0 c3
:3 0 d3 :3 0 2167
2168 0 18 :2 0
2 :4 0 215 :2 0
d5 :2 0 2a :2 0
1288 216d 216f :3 0
128b 2169 2171 2166
2173 2172 :2 0 c6
:3 0 d6 :3 0 2175
2176 0 c8 :4 0
216 :4 0 cb :2 0
cc :3 0 128f 217a
217c :3 0 cb :2 0
e9 :4 0 1292 217e
2180 :3 0 cb :2 0
f0 :4 0 1295 2182
2184 :3 0 cb :2 0
84 :3 0 d0 :3 0
b0 :3 0 1ba :3 0
2189 218a 0 1298
2188 218c d1 :4 0
129a 2187 218f 129d
2186 2191 :3 0 cb
:2 0 f2 :4 0 12a0
2193 2195 :3 0 cb
:2 0 ce :4 0 12a3
2197 2199 :3 0 cb
:2 0 1c :3 0 12a6
219b 219d :3 0 cb
:2 0 ce :4 0 12a9
219f 21a1 :3 0 12ac
2177 21a3 :2 0 21a5
12af 21a6 2174 21a5
0 21a7 12b1 0
21d1 c3 :3 0 c4
:3 0 21a8 21a9 0
c3 :3 0 d3 :3 0
21ab 21ac 0 2a
:2 0 2 :4 0 217
:2 0 d5 :2 0 2a
:2 0 12b3 21b1 21b3
:3 0 12b6 21ad 21b5
21aa 21b7 21b6 :2 0
c6 :3 0 d6 :3 0
21b9 21ba 0 c8
:4 0 218 :4 0 cb
:2 0 cc :3 0 12ba
21be 21c0 :3 0 12bd
21bb 21c2 :2 0 21c4
12c0 21c5 21b8 21c4
0 21c6 12c2 0
21d1 f5 :3 0 f6
:3 0 21c7 21c8 0
b0 :3 0 1ba :3 0
21ca 21cb 0 1c
:3 0 f7 :3 0 12c4
21c9 21cf :2 0 21d1
12c8 21d2 2163 21d1
0 21eb 6b :3 0
139 :2 0 21d3 21d4
0 21e8 6b :3 0
219 :3 0 22 :3 0
1d :3 0 6b :3 0
84 :3 0 4f :3 0
3d :2 0 12cc 21db
21de 84 :3 0 3f
:3 0 3d :2 0 12cf
21e0 21e3 12d2 21d7
21e5 21d6 21e6 0
21e8 12d8 21ea 20eb
215a 0 21eb 0
21e8 0 21eb 12db
0 21ec 12df 21ed
1f58 21ec 0 21ee
12ea 0 21ef 12ec
21f0 1830 21ef 0
21f1 12f3 0 21f3
140 :3 0 12f5 22f7
a0 :3 0 6f :3 0
2a :2 0 2a :2 0
12fb 21f4 21f8 da
:2 0 1bd :4 0 1301
21fa 21fc :3 0 9a
:3 0 9f :3 0 a0
:3 0 a1 :3 0 9f
:3 0 a0 :3 0 a2
:3 0 a5 :3 0 a6
:3 0 a7 :3 0 a8
:3 0 81 :3 0 2b
:3 0 2d :3 0 78
:3 0 79 :3 0 74
:3 0 75 :3 0 90
:3 0 91 :3 0 22
:3 0 9b :3 0 22
:3 0 93 :3 0 92
:3 0 23 :4 0 21a
1 :8 0 221e 15
:3 0 e1 :3 0 2219
221a 0 e4 :3 0
221b 221c 0 221e
1304 2268 e5 :3 0
15 :3 0 e1 :3 0
2221 2222 0 e4
:3 0 2223 2224 0
225e c3 :3 0 c4
:3 0 2226 2227 0
c3 :3 0 d3 :3 0
2229 222a 0 e6
:2 0 2 :4 0 21b
:2 0 d5 :2 0 2a
:2 0 1307 222f 2231
:3 0 130a 222b 2233
2228 2235 2234 :2 0
c6 :3 0 d6 :3 0
2237 2238 0 c8
:4 0 21c :4 0 cb
:2 0 cc :3 0 130e
223c 223e :3 0 cb
:2 0 e9 :4 0 1311
2240 2242 :3 0 cb
:2 0 ea :4 0 1314
2244 2246 :3 0 cb
:2 0 e4 :3 0 1317
2248 224a :3 0 cb
:2 0 eb :4 0 131a
224c 224e :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 131d 2251 2255
1321 2250 2257 :3 0
1324 2239 2259 :2 0
225b 1327 225c 2236
225b 0 225d 1329
0 225e 132b 2261
:3 0 2261 0 2261
2260 225e 225f :6 0
2263 5b :3 0 132e
2265 1330 2264 2263
:2 0 2266 1332 :2 0
2268 0 2268 2267
221e 2266 :6 0 2296
1 :3 0 15 :3 0
e1 :3 0 226a 226b
0 15 :3 0 da
:2 0 157 :3 0 226d
226f 0 1336 226e
2271 :3 0 2272 :2 0
81 :3 0 165 :2 0
1339 2275 2276 :3 0
2277 :2 0 2278 :2 0
2273 227a 2279 :2 0
7a :3 0 1be :2 0
2a :2 0 133b 227d
227f :3 0 227c 2280
0 2293 15 :3 0
e1 :3 0 2282 2283
0 1bf :3 0 22
:3 0 22 :3 0 81
:3 0 2b :3 0 2d
:3 0 74 :3 0 75
:3 0 7a :3 0 79
:3 0 78 :3 0 133d
2285 2290 2284 2291
0 2293 1348 2294
227b 2293 0 2295
134b 0 2296 134d
2297 21fd 2296 0
22f9 9a :3 0 a5
:3 0 81 :3 0 78
:3 0 90 :3 0 91
:3 0 22 :3 0 9b
:3 0 22 :3 0 92
:3 0 23 :3 0 93
:4 0 21d 1 :8 0
22aa 15 :3 0 e1
:3 0 22a5 22a6 0
e4 :3 0 22a7 22a8
0 22aa 1350 22f4
e5 :3 0 15 :3 0
e1 :3 0 22ad 22ae
0 e4 :3 0 22af
22b0 0 22ea c3
:3 0 c4 :3 0 22b2
22b3 0 c3 :3 0
d3 :3 0 22b5 22b6
0 e6 :2 0 2
:4 0 21e :2 0 d5
:2 0 2a :2 0 1353
22bb 22bd :3 0 1356
22b7 22bf 22b4 22c1
22c0 :2 0 c6 :3 0
d6 :3 0 22c3 22c4
0 c8 :4 0 21f
:4 0 cb :2 0 cc
:3 0 135a 22c8 22ca
:3 0 cb :2 0 e9
:4 0 135d 22cc 22ce
:3 0 cb :2 0 ea
:4 0 1360 22d0 22d2
:3 0 cb :2 0 e4
:3 0 1363 22d4 22d6
:3 0 cb :2 0 eb
:4 0 1366 22d8 22da
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 1369
22dd 22e1 136d 22dc
22e3 :3 0 1370 22c5
22e5 :2 0 22e7 1373
22e8 22c2 22e7 0
22e9 1375 0 22ea
1377 22ed :3 0 22ed
0 22ed 22ec 22ea
22eb :6 0 22ef 5d
:3 0 137a 22f1 137c
22f0 22ef :2 0 22f2
137e :2 0 22f4 0
22f4 22f3 22aa 22f2
:6 0 22f6 1 :3 0
1380 22f8 16b5 21f3
0 22f9 0 22f6
0 22f9 1382 0
22fb 140 :3 0 1386
23ff a0 :3 0 6f
:3 0 2a :2 0 2a
:2 0 1388 22fc 2300
da :2 0 1bd :4 0
138e 2302 2304 :3 0
9a :3 0 9f :3 0
a0 :3 0 a1 :3 0
9f :3 0 a0 :3 0
a2 :3 0 a5 :3 0
a6 :3 0 a7 :3 0
a8 :3 0 81 :3 0
2b :3 0 2d :3 0
78 :3 0 79 :3 0
74 :3 0 75 :3 0
90 :3 0 91 :3 0
22 :3 0 9b :3 0
22 :3 0 92 :3 0
23 :3 0 93 :4 0
220 1 :8 0 2326
15 :3 0 e1 :3 0
2321 2322 0 e4
:3 0 2323 2324 0
2326 1391 2370 e5
:3 0 15 :3 0 e1
:3 0 2329 232a 0
e4 :3 0 232b 232c
0 2366 c3 :3 0
c4 :3 0 232e 232f
0 c3 :3 0 d3
:3 0 2331 2332 0
e6 :2 0 2 :4 0
221 :2 0 d5 :2 0
2a :2 0 1394 2337
2339 :3 0 1397 2333
233b 2330 233d 233c
:2 0 c6 :3 0 d6
:3 0 233f 2340 0
c8 :4 0 222 :4 0
cb :2 0 cc :3 0
139b 2344 2346 :3 0
cb :2 0 e9 :4 0
139e 2348 234a :3 0
cb :2 0 ea :4 0
13a1 234c 234e :3 0
cb :2 0 e4 :3 0
13a4 2350 2352 :3 0
cb :2 0 eb :4 0
13a7 2354 2356 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 13aa 2359
235d 13ae 2358 235f
:3 0 13b1 2341 2361
:2 0 2363 13b4 2364
233e 2363 0 2365
13b6 0 2366 13b8
2369 :3 0 2369 0
2369 2368 2366 2367
:6 0 236b 5f :3 0
13bb 236d 13bd 236c
236b :2 0 236e 13bf
:2 0 2370 0 2370
236f 2326 236e :6 0
239e 1 :3 0 15
:3 0 e1 :3 0 2372
2373 0 15 :3 0
da :2 0 157 :3 0
2375 2377 0 13c3
2376 2379 :3 0 237a
:2 0 81 :3 0 165
:2 0 13c6 237d 237e
:3 0 237f :2 0 2380
:2 0 237b 2382 2381
:2 0 7a :3 0 1be
:2 0 2a :2 0 13c8
2385 2387 :3 0 2384
2388 0 239b 15
:3 0 e1 :3 0 238a
238b 0 1bf :3 0
22 :3 0 22 :3 0
81 :3 0 2b :3 0
2d :3 0 74 :3 0
75 :3 0 7a :3 0
79 :3 0 78 :3 0
13ca 238d 2398 238c
2399 0 239b 13d5
239c 2383 239b 0
239d 13d8 0 239e
13da 239f 2305 239e
0 2401 9a :3 0
a5 :3 0 81 :3 0
78 :3 0 90 :3 0
91 :3 0 22 :3 0
9b :3 0 22 :3 0
92 :3 0 23 :3 0
93 :4 0 223 1
:8 0 23b2 15 :3 0
e1 :3 0 23ad 23ae
0 e4 :3 0 23af
23b0 0 23b2 13dd
23fc e5 :3 0 15
:3 0 e1 :3 0 23b5
23b6 0 e4 :3 0
23b7 23b8 0 23f2
c3 :3 0 c4 :3 0
23ba 23bb 0 c3
:3 0 d3 :3 0 23bd
23be 0 e6 :2 0
2 :4 0 224 :2 0
d5 :2 0 2a :2 0
13e0 23c3 23c5 :3 0
13e3 23bf 23c7 23bc
23c9 23c8 :2 0 c6
:3 0 d6 :3 0 23cb
23cc 0 c8 :4 0
225 :4 0 cb :2 0
cc :3 0 13e7 23d0
23d2 :3 0 cb :2 0
e9 :4 0 13ea 23d4
23d6 :3 0 cb :2 0
ea :4 0 13ed 23d8
23da :3 0 cb :2 0
e4 :3 0 13f0 23dc
23de :3 0 cb :2 0
eb :4 0 13f3 23e0
23e2 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
13f6 23e5 23e9 13fa
23e4 23eb :3 0 13fd
23cd 23ed :2 0 23ef
1400 23f0 23ca 23ef
0 23f1 1402 0
23f2 1404 23f5 :3 0
23f5 0 23f5 23f4
23f2 23f3 :6 0 23f7
61 :3 0 1407 23f9
1409 23f8 23f7 :2 0
23fa 140b :2 0 23fc
0 23fc 23fb 23b2
23fa :6 0 23fe 1
:3 0 140d 2400 16aa
22fb 0 2401 0
23fe 0 2401 140f
0 4a3e 1e :3 0
226 :2 0 1413 2403
2404 :3 0 2405 :2 0
2406 :2 0 84 :3 0
4c :3 0 3d :2 0
1415 2408 240b 10a
:2 0 3d :2 0 141a
240d 240f :3 0 2410
:2 0 2407 2412 2411
:2 0 84 :3 0 63
:3 0 3d :2 0 141d
2414 2417 da :2 0
3d :2 0 1422 2419
241b :3 0 241c :2 0
2413 241e 241d :2 0
1e :3 0 de :4 0
2420 2421 0 2750
1e :3 0 171 :4 0
2424 2425 :3 0 2423
2426 0 2750 84
:3 0 e :3 0 3d
:2 0 1425 2428 242b
da :2 0 e2 :2 0
142a 242d 242f :3 0
7e :3 0 84 :3 0
44 :3 0 3d :2 0
142d 2432 2435 2431
2436 0 2438 1430
2439 2430 2438 0
243a 1432 0 2750
84 :3 0 62 :3 0
3d :2 0 1434 243b
243e da :2 0 3d
:2 0 1439 2440 2442
:3 0 2443 :2 0 84
:3 0 61 :3 0 3d
:2 0 143c 2445 2448
da :2 0 3d :2 0
1441 244a 244c :3 0
244d :2 0 2444 244f
244e :2 0 84 :3 0
62 :3 0 3d :2 0
1444 2451 2454 da
:2 0 3d :2 0 1449
2456 2458 :3 0 2459
:2 0 84 :3 0 61
:3 0 3d :2 0 144c
245b 245e da :2 0
3d :2 0 1451 2460
2462 :3 0 2463 :2 0
245a 2465 2464 :2 0
58 :3 0 84 :3 0
58 :3 0 3d :2 0
1454 2468 246b 1d2
:2 0 84 :3 0 5e
:3 0 3d :2 0 1457
246e 2471 145a 246d
2473 :3 0 2467 2474
0 253a 5c :3 0
84 :3 0 5c :3 0
3d :2 0 145d 2477
247a 1d2 :2 0 84
:3 0 5e :3 0 3d
:2 0 1460 247d 2480
1463 247c 2482 :3 0
2476 2483 0 253a
5b :3 0 84 :3 0
5b :3 0 3d :2 0
1466 2486 2489 1d2
:2 0 84 :3 0 5e
:3 0 3d :2 0 1469
248c 248f 146c 248b
2491 :3 0 2485 2492
0 253a 5d :3 0
84 :3 0 5d :3 0
3d :2 0 146f 2495
2498 1d2 :2 0 84
:3 0 5e :3 0 3d
:2 0 1472 249b 249e
1475 249a 24a0 :3 0
2494 24a1 0 253a
90 :3 0 9a :3 0
98 :3 0 9b :3 0
91 :3 0 227 :3 0
228 :3 0 229 :3 0
22a :3 0 a1 :3 0
a2 :3 0 15d :3 0
22b :3 0 22c :3 0
92 :3 0 93 :3 0
94 :3 0 a5 :3 0
a6 :3 0 a7 :3 0
1d3 :3 0 a8 :3 0
1d4 :3 0 f9 :3 0
fa :3 0 178 :3 0
1e :3 0 1c :3 0
22 :3 0 22 :3 0
b0 :3 0 22d :3 0
b0 :3 0 22e :3 0
31 :3 0 32 :3 0
31 :3 0 32 :3 0
31 :3 0 32 :3 0
21 :3 0 2e :3 0
1e :3 0 78 :3 0
79 :3 0 58 :3 0
5c :3 0 5b :3 0
5d :3 0 7f :3 0
80 :3 0 7b :4 0
22f 1 :8 0 24ed
e0 :4 0 24d8 :3 0
f7 :3 0 da :2 0
147a 24db 24dc :3 0
15 :3 0 e1 :3 0
24de 24df 0 3d
:2 0 24e0 24e1 0
24e3 147d 24ea 15
:3 0 e1 :3 0 24e4
24e5 0 e2 :2 0
24e6 24e7 0 24e9
147f 24eb 24dd 24e3
0 24ec 0 24e9
0 24ec 1481 0
24ed 1484 2537 e5
:3 0 15 :3 0 e1
:3 0 24f0 24f1 0
e4 :3 0 24f2 24f3
0 252d c3 :3 0
c4 :3 0 24f5 24f6
0 c3 :3 0 d3
:3 0 24f8 24f9 0
e6 :2 0 2 :4 0
230 :2 0 d5 :2 0
2a :2 0 1487 24fe
2500 :3 0 148a 24fa
2502 24f7 2504 2503
:2 0 c6 :3 0 d6
:3 0 2506 2507 0
c8 :4 0 231 :4 0
cb :2 0 cc :3 0
148e 250b 250d :3 0
cb :2 0 e9 :4 0
1491 250f 2511 :3 0
cb :2 0 ea :4 0
1494 2513 2515 :3 0
cb :2 0 e4 :3 0
1497 2517 2519 :3 0
cb :2 0 eb :4 0
149a 251b 251d :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 149d 2520
2524 14a1 251f 2526
:3 0 14a4 2508 2528
:2 0 252a 14a7 252b
2505 252a 0 252c
14a9 0 252d 14ab
2530 :3 0 2530 0
2530 252f 252d 252e
:6 0 2532 63 :3 0
14ae 2534 14b0 2533
2532 :2 0 2535 14b2
:2 0 2537 0 2537
2536 24ed 2535 :6 0
253a 1 :3 0 140
:3 0 14b4 26af 84
:3 0 61 :3 0 3d
:2 0 14ba 253b 253e
da :2 0 3d :2 0
14bf 2540 2542 :3 0
5b :3 0 84 :3 0
5b :3 0 3d :2 0
14c2 2545 2548 1d2
:2 0 84 :3 0 5e
:3 0 3d :2 0 14c5
254b 254e 14c8 254a
2550 :3 0 2544 2551
0 25f8 5d :3 0
84 :3 0 5d :3 0
3d :2 0 14cb 2554
2557 1d2 :2 0 84
:3 0 5e :3 0 3d
:2 0 14ce 255a 255d
14d1 2559 255f :3 0
2553 2560 0 25f8
90 :3 0 9a :3 0
98 :3 0 9b :3 0
91 :3 0 227 :3 0
228 :3 0 229 :3 0
22a :3 0 a1 :3 0
a2 :3 0 15d :3 0
22b :3 0 22c :3 0
92 :3 0 93 :3 0
94 :3 0 a5 :3 0
a6 :3 0 a7 :3 0
1d3 :3 0 a8 :3 0
1d4 :3 0 f9 :3 0
fa :3 0 178 :3 0
1e :3 0 1c :3 0
22 :3 0 22 :3 0
b0 :3 0 22d :3 0
b0 :3 0 22e :3 0
31 :3 0 32 :3 0
31 :3 0 32 :3 0
31 :3 0 32 :3 0
21 :3 0 2e :3 0
1e :3 0 78 :3 0
79 :3 0 58 :3 0
5c :3 0 5b :3 0
5d :3 0 7f :3 0
80 :3 0 7b :4 0
232 1 :8 0 25ac
e0 :4 0 2597 :3 0
f7 :3 0 da :2 0
14d6 259a 259b :3 0
15 :3 0 e1 :3 0
259d 259e 0 3d
:2 0 259f 25a0 0
25a2 14d9 25a9 15
:3 0 e1 :3 0 25a3
25a4 0 e2 :2 0
25a5 25a6 0 25a8
14db 25aa 259c 25a2
0 25ab 0 25a8
0 25ab 14dd 0
25ac 14e0 25f6 e5
:3 0 15 :3 0 e1
:3 0 25af 25b0 0
e4 :3 0 25b1 25b2
0 25ec c3 :3 0
c4 :3 0 25b4 25b5
0 c3 :3 0 d3
:3 0 25b7 25b8 0
e6 :2 0 2 :4 0
233 :2 0 d5 :2 0
2a :2 0 14e3 25bd
25bf :3 0 14e6 25b9
25c1 25b6 25c3 25c2
:2 0 c6 :3 0 d6
:3 0 25c5 25c6 0
c8 :4 0 234 :4 0
cb :2 0 cc :3 0
14ea 25ca 25cc :3 0
cb :2 0 e9 :4 0
14ed 25ce 25d0 :3 0
cb :2 0 ea :4 0
14f0 25d2 25d4 :3 0
cb :2 0 e4 :3 0
14f3 25d6 25d8 :3 0
cb :2 0 eb :4 0
14f6 25da 25dc :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 14f9 25df
25e3 14fd 25de 25e5
:3 0 1500 25c7 25e7
:2 0 25e9 1503 25ea
25c4 25e9 0 25eb
1505 0 25ec 1507
25ef :3 0 25ef 0
25ef 25ee 25ec 25ed
:6 0 25f1 65 :3 0
150a 25f3 150c 25f2
25f1 :2 0 25f4 150e
:2 0 25f6 0 25f6
25f5 25ac 25f4 :6 0
25f8 1 :3 0 1510
25f9 2543 25f8 0
26b1 58 :3 0 84
:3 0 58 :3 0 3d
:2 0 1514 25fb 25fe
1d2 :2 0 84 :3 0
5e :3 0 3d :2 0
1517 2601 2604 151a
2600 2606 :3 0 25fa
2607 0 26ae 5c
:3 0 84 :3 0 5c
:3 0 3d :2 0 151d
260a 260d 1d2 :2 0
84 :3 0 5e :3 0
3d :2 0 1520 2610
2613 1523 260f 2615
:3 0 2609 2616 0
26ae 90 :3 0 9a
:3 0 98 :3 0 9b
:3 0 91 :3 0 227
:3 0 228 :3 0 229
:3 0 22a :3 0 a1
:3 0 a2 :3 0 15d
:3 0 22b :3 0 22c
:3 0 92 :3 0 93
:3 0 94 :3 0 a5
:3 0 a6 :3 0 a7
:3 0 1d3 :3 0 a8
:3 0 1d4 :3 0 f9
:3 0 fa :3 0 178
:3 0 1e :3 0 1c
:3 0 22 :3 0 22
:3 0 b0 :3 0 22d
:3 0 b0 :3 0 22e
:3 0 31 :3 0 32
:3 0 31 :3 0 32
:3 0 31 :3 0 32
:3 0 21 :3 0 2e
:3 0 1e :3 0 78
:3 0 79 :3 0 58
:3 0 5c :3 0 5b
:3 0 5d :3 0 7f
:3 0 80 :3 0 7b
:4 0 232 1 :8 0
2662 e0 :4 0 264d
:3 0 f7 :3 0 da
:2 0 1528 2650 2651
:3 0 15 :3 0 e1
:3 0 2653 2654 0
3d :2 0 2655 2656
0 2658 152b 265f
15 :3 0 e1 :3 0
2659 265a 0 e2
:2 0 265b 265c 0
265e 152d 2660 2652
2658 0 2661 0
265e 0 2661 152f
0 2662 1532 26ac
e5 :3 0 15 :3 0
e1 :3 0 2665 2666
0 e4 :3 0 2667
2668 0 26a2 c3
:3 0 c4 :3 0 266a
266b 0 c3 :3 0
d3 :3 0 266d 266e
0 e6 :2 0 2
:4 0 235 :2 0 d5
:2 0 2a :2 0 1535
2673 2675 :3 0 1538
266f 2677 266c 2679
2678 :2 0 c6 :3 0
d6 :3 0 267b 267c
0 c8 :4 0 236
:4 0 cb :2 0 cc
:3 0 153c 2680 2682
:3 0 cb :2 0 e9
:4 0 153f 2684 2686
:3 0 cb :2 0 ea
:4 0 1542 2688 268a
:3 0 cb :2 0 e4
:3 0 1545 268c 268e
:3 0 cb :2 0 eb
:4 0 1548 2690 2692
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 154b
2695 2699 154f 2694
269b :3 0 1552 267d
269d :2 0 269f 1555
26a0 267a 269f 0
26a1 1557 0 26a2
1559 26a5 :3 0 26a5
0 26a5 26a4 26a2
26a3 :6 0 26a7 67
:3 0 155c 26a9 155e
26a8 26a7 :2 0 26aa
1560 :2 0 26ac 0
26ac 26ab 2662 26aa
:6 0 26ae 1 :3 0
1562 26b0 2466 253a
0 26b1 0 26ae
0 26b1 1566 0
26b2 156a 274a 90
:3 0 9a :3 0 98
:3 0 9b :3 0 91
:3 0 227 :3 0 228
:3 0 229 :3 0 22a
:3 0 a1 :3 0 a2
:3 0 15d :3 0 22b
:3 0 22c :3 0 92
:3 0 93 :3 0 94
:3 0 a5 :3 0 a6
:3 0 a7 :3 0 1d3
:3 0 a8 :3 0 1d4
:3 0 f9 :3 0 fa
:3 0 178 :3 0 1e
:3 0 1c :3 0 22
:3 0 22 :3 0 b0
:3 0 22d :3 0 b0
:3 0 22e :3 0 31
:3 0 32 :3 0 31
:3 0 32 :3 0 31
:3 0 32 :3 0 21
:3 0 2e :3 0 1e
:3 0 78 :3 0 79
:3 0 58 :3 0 5c
:3 0 5b :3 0 5d
:3 0 7f :3 0 80
:3 0 7b :4 0 237
1 :8 0 26fd e0
:4 0 26e8 :3 0 f7
:3 0 da :2 0 156e
26eb 26ec :3 0 15
:3 0 e1 :3 0 26ee
26ef 0 3d :2 0
26f0 26f1 0 26f3
1571 26fa 15 :3 0
e1 :3 0 26f4 26f5
0 e2 :2 0 26f6
26f7 0 26f9 1573
26fb 26ed 26f3 0
26fc 0 26f9 0
26fc 1575 0 26fd
1578 2747 e5 :3 0
15 :3 0 e1 :3 0
2700 2701 0 e4
:3 0 2702 2703 0
273d c3 :3 0 c4
:3 0 2705 2706 0
c3 :3 0 d3 :3 0
2708 2709 0 e6
:2 0 2 :4 0 238
:2 0 d5 :2 0 2a
:2 0 157b 270e 2710
:3 0 157e 270a 2712
2707 2714 2713 :2 0
c6 :3 0 d6 :3 0
2716 2717 0 c8
:4 0 239 :4 0 cb
:2 0 cc :3 0 1582
271b 271d :3 0 cb
:2 0 e9 :4 0 1585
271f 2721 :3 0 cb
:2 0 ea :4 0 1588
2723 2725 :3 0 cb
:2 0 e4 :3 0 158b
2727 2729 :3 0 cb
:2 0 eb :4 0 158e
272b 272d :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1591 2730 2734
1595 272f 2736 :3 0
1598 2718 2738 :2 0
273a 159b 273b 2715
273a 0 273c 159d
0 273d 159f 2740
:3 0 2740 0 2740
273f 273d 273e :6 0
2742 69 :3 0 15a2
2744 15a4 2743 2742
:2 0 2745 15a6 :2 0
2747 0 2747 2746
26fd 2745 :6 0 2749
1 :3 0 15a8 274b
2450 26b2 0 274c
0 2749 0 274c
15aa 0 2750 56
:3 0 2a :2 0 274d
274e 0 2750 15ad
2751 241f 2750 0
2752 15b3 0 4a3e
2f :3 0 a0 :3 0
2f :3 0 cb :2 0
23a :4 0 15b5 2756
2758 :3 0 2a :2 0
30 :2 0 15b8 2754
275c 2753 275d 0
4a3e 1d :3 0 de
:4 0 275f 2760 0
4a3e 3f :3 0 9
:3 0 2762 2763 0
4a3e 17e :3 0 39
:3 0 12e :3 0 12f
:3 0 23 :4 0 17f
1 :8 0 2770 15
:3 0 e1 :3 0 276b
276c 0 e4 :3 0
276d 276e 0 2770
15bc 27ba e5 :3 0
15 :3 0 e1 :3 0
2773 2774 0 e4
:3 0 2775 2776 0
27b0 c3 :3 0 c4
:3 0 2778 2779 0
c3 :3 0 d3 :3 0
277b 277c 0 e6
:2 0 2 :4 0 23b
:2 0 d5 :2 0 2a
:2 0 15bf 2781 2783
:3 0 15c2 277d 2785
277a 2787 2786 :2 0
c6 :3 0 d6 :3 0
2789 278a 0 c8
:4 0 23c :4 0 cb
:2 0 cc :3 0 15c6
278e 2790 :3 0 cb
:2 0 e9 :4 0 15c9
2792 2794 :3 0 cb
:2 0 ea :4 0 15cc
2796 2798 :3 0 cb
:2 0 e4 :3 0 15cf
279a 279c :3 0 cb
:2 0 eb :4 0 15d2
279e 27a0 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 15d5 27a3 27a7
15d9 27a2 27a9 :3 0
15dc 278b 27ab :2 0
27ad 15df 27ae 2788
27ad 0 27af 15e1
0 27b0 15e3 27b3
:3 0 27b3 0 27b3
27b2 27b0 27b1 :6 0
27b5 6b :3 0 15e6
27b7 15e8 27b6 27b5
:2 0 27b8 15ea :2 0
27ba 0 27ba 27b9
2770 27b8 :6 0 4a3e
1 :3 0 74 :3 0
5a :2 0 27bc 27bd
0 4a3e 75 :3 0
5a :2 0 27bf 27c0
0 4a3e 43 :3 0
3d :2 0 27c2 27c3
0 4a3e 82 :3 0
da :2 0 3d :2 0
15ee 27c6 27c8 :3 0
27c9 :2 0 84 :3 0
77 :3 0 3d :2 0
15f1 27cb 27ce da
:2 0 2a :2 0 15f6
27d0 27d2 :3 0 27d3
:2 0 27ca 27d5 27d4
:2 0 23d :3 0 99
:3 0 a1 :3 0 24
:3 0 ae :3 0 a4
:3 0 90 :3 0 99
:3 0 99 :3 0 91
:3 0 22 :3 0 99
:3 0 92 :3 0 23
:3 0 99 :3 0 9b
:3 0 a4 :3 0 8b
:3 0 a4 :3 0 f8
:3 0 b0 :3 0 b1
:3 0 b0 :3 0 b2
:3 0 b0 :3 0 b3
:3 0 b0 :3 0 b4
:3 0 b0 :3 0 b5
:3 0 b0 :3 0 b6
:3 0 b0 :3 0 b7
:3 0 b0 :3 0 b8
:3 0 b0 :3 0 b9
:3 0 b0 :3 0 ba
:3 0 b0 :3 0 bb
:3 0 b0 :3 0 bc
:3 0 b0 :3 0 bd
:3 0 b0 :3 0 be
:3 0 b0 :3 0 bf
:3 0 a4 :3 0 c0
:3 0 2f :4 0 23e
1 :8 0 2812 15
:3 0 e1 :3 0 280d
280e 0 e4 :3 0
280f 2810 0 2812
15f9 285c e5 :3 0
15 :3 0 e1 :3 0
2815 2816 0 e4
:3 0 2817 2818 0
2852 c3 :3 0 c4
:3 0 281a 281b 0
c3 :3 0 d3 :3 0
281d 281e 0 e6
:2 0 2 :4 0 23f
:2 0 d5 :2 0 2a
:2 0 15fc 2823 2825
:3 0 15ff 281f 2827
281c 2829 2828 :2 0
c6 :3 0 d6 :3 0
282b 282c 0 c8
:4 0 240 :4 0 cb
:2 0 cc :3 0 1603
2830 2832 :3 0 cb
:2 0 e9 :4 0 1606
2834 2836 :3 0 cb
:2 0 ea :4 0 1609
2838 283a :3 0 cb
:2 0 e4 :3 0 160c
283c 283e :3 0 cb
:2 0 eb :4 0 160f
2840 2842 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1612 2845 2849
1616 2844 284b :3 0
1619 282d 284d :2 0
284f 161c 2850 282a
284f 0 2851 161e
0 2852 1620 2855
:3 0 2855 0 2855
2854 2852 2853 :6 0
2857 6d :3 0 1623
2859 1625 2858 2857
:2 0 285a 1627 :2 0
285c 0 285c 285b
2812 285a :6 0 285e
1 :3 0 1629 285f
27d6 285e 0 2860
162b 0 4a3e 24
:3 0 31 :3 0 2861
2862 0 4a3e df
:3 0 96 :4 0 2867
:2 0 4a3e 2865 2868
:3 0 241 :3 0 96
:3 0 1b :3 0 1d
:3 0 20 :3 0 41
:3 0 3f :3 0 7e
:3 0 72 :3 0 73
:3 0 27 :3 0 28
:3 0 49 :3 0 1f
:3 0 78 :3 0 79
:3 0 74 :3 0 75
:3 0 44 :3 0 46
:3 0 47 :3 0 48
:3 0 4e :4 0 2881
:2 0 3e67 286a 2882
:3 0 162d :3 0 96
:3 0 e0 :3 0 2883
2884 :3 0 15 :3 0
e1 :3 0 2886 2887
0 3d :2 0 2888
2889 0 288b 1643
2892 15 :3 0 e1
:3 0 288c 288d 0
e2 :2 0 288e 288f
0 2891 1645 2893
2885 288b 0 2894
0 2891 0 2894
1647 0 3e67 15
:3 0 e1 :3 0 2895
2896 0 15 :3 0
13b :2 0 157 :3 0
2898 289a 0 164c
2899 289c :3 0 289d
:2 0 242 :8 0 28a1
164f 28a2 289e 28a1
0 28a3 1651 0
3e67 84 :3 0 3f
:3 0 3d :2 0 1653
28a4 28a7 da :2 0
3d :2 0 1658 28a9
28ab :3 0 71 :3 0
243 :3 0 1b :3 0
3d :2 0 165b 28ae
28b1 28ad 28b2 0
2b14 af :3 0 98
:3 0 1b :4 0 244
1 :8 0 28cd e0
:4 0 28b8 :3 0 f7
:3 0 da :2 0 1660
28bb 28bc :3 0 15
:3 0 e1 :3 0 28be
28bf 0 3d :2 0
28c0 28c1 0 28c3
1663 28ca 15 :3 0
e1 :3 0 28c4 28c5
0 e2 :2 0 28c6
28c7 0 28c9 1665
28cb 28bd 28c3 0
28cc 0 28c9 0
28cc 1667 0 28cd
166a 2917 e5 :3 0
15 :3 0 e1 :3 0
28d0 28d1 0 e4
:3 0 28d2 28d3 0
290d c3 :3 0 c4
:3 0 28d5 28d6 0
c3 :3 0 d3 :3 0
28d8 28d9 0 e6
:2 0 2 :4 0 245
:2 0 d5 :2 0 2a
:2 0 166d 28de 28e0
:3 0 1670 28da 28e2
28d7 28e4 28e3 :2 0
c6 :3 0 d6 :3 0
28e6 28e7 0 c8
:4 0 246 :4 0 cb
:2 0 cc :3 0 1674
28eb 28ed :3 0 cb
:2 0 e9 :4 0 1677
28ef 28f1 :3 0 cb
:2 0 ea :4 0 167a
28f3 28f5 :3 0 cb
:2 0 e4 :3 0 167d
28f7 28f9 :3 0 cb
:2 0 eb :4 0 1680
28fb 28fd :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1683 2900 2904
1687 28ff 2906 :3 0
168a 28e8 2908 :2 0
290a 168d 290b 28e5
290a 0 290c 168f
0 290d 1691 2910
:3 0 2910 0 2910
290f 290d 290e :6 0
2912 70 :3 0 1694
2914 1696 2913 2912
:2 0 2915 1698 :2 0
2917 0 2917 2916
28cd 2915 :6 0 2b14
6f :3 0 90 :3 0
9a :3 0 1d :4 0
247 1 :8 0 2932
e0 :4 0 291d :3 0
f7 :3 0 da :2 0
169c 2920 2921 :3 0
15 :3 0 e1 :3 0
2923 2924 0 3d
:2 0 2925 2926 0
2928 169f 292f 15
:3 0 e1 :3 0 2929
292a 0 e2 :2 0
292b 292c 0 292e
16a1 2930 2922 2928
0 2931 0 292e
0 2931 16a3 0
2932 16a6 297c e5
:3 0 15 :3 0 e1
:3 0 2935 2936 0
e4 :3 0 2937 2938
0 2972 c3 :3 0
c4 :3 0 293a 293b
0 c3 :3 0 d3
:3 0 293d 293e 0
e6 :2 0 2 :4 0
248 :2 0 d5 :2 0
2a :2 0 16a9 2943
2945 :3 0 16ac 293f
2947 293c 2949 2948
:2 0 c6 :3 0 d6
:3 0 294b 294c 0
c8 :4 0 249 :4 0
cb :2 0 cc :3 0
16b0 2950 2952 :3 0
cb :2 0 e9 :4 0
16b3 2954 2956 :3 0
cb :2 0 ea :4 0
16b6 2958 295a :3 0
cb :2 0 e4 :3 0
16b9 295c 295e :3 0
cb :2 0 eb :4 0
16bc 2960 2962 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 16bf 2965
2969 16c3 2964 296b
:3 0 16c6 294d 296d
:2 0 296f 16c9 2970
294a 296f 0 2971
16cb 0 2972 16cd
2975 :3 0 2975 0
2975 2974 2972 2973
:6 0 2977 72 :3 0
16d0 2979 16d2 2978
2977 :2 0 297a 16d4
:2 0 297c 0 297c
297b 2932 297a :6 0
2b14 6f :3 0 24a
:3 0 9a :3 0 1d
:4 0 24b 1 :8 0
2997 e0 :4 0 2982
:3 0 f7 :3 0 da
:2 0 16d8 2985 2986
:3 0 15 :3 0 e1
:3 0 2988 2989 0
3d :2 0 298a 298b
0 298d 16db 2994
15 :3 0 e1 :3 0
298e 298f 0 e2
:2 0 2990 2991 0
2993 16dd 2995 2987
298d 0 2996 0
2993 0 2996 16df
0 2997 16e2 29e1
e5 :3 0 15 :3 0
e1 :3 0 299a 299b
0 e4 :3 0 299c
299d 0 29d7 c3
:3 0 c4 :3 0 299f
29a0 0 c3 :3 0
d3 :3 0 29a2 29a3
0 e6 :2 0 2
:4 0 24c :2 0 d5
:2 0 2a :2 0 16e5
29a8 29aa :3 0 16e8
29a4 29ac 29a1 29ae
29ad :2 0 c6 :3 0
d6 :3 0 29b0 29b1
0 c8 :4 0 24d
:4 0 cb :2 0 cc
:3 0 16ec 29b5 29b7
:3 0 cb :2 0 e9
:4 0 16ef 29b9 29bb
:3 0 cb :2 0 ea
:4 0 16f2 29bd 29bf
:3 0 cb :2 0 e4
:3 0 16f5 29c1 29c3
:3 0 cb :2 0 eb
:4 0 16f8 29c5 29c7
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 16fb
29ca 29ce 16ff 29c9
29d0 :3 0 1702 29b2
29d2 :2 0 29d4 1705
29d5 29af 29d4 0
29d6 1707 0 29d7
1709 29da :3 0 29da
0 29da 29d9 29d7
29d8 :6 0 29dc 74
:3 0 170c 29de 170e
29dd 29dc :2 0 29df
1710 :2 0 29e1 0
29e1 29e0 2997 29df
:6 0 2b14 6f :3 0
1b0 :3 0 91 :3 0
22 :3 0 9a :3 0
1d :4 0 24e 1
:8 0 29fe e0 :4 0
29e9 :3 0 f7 :3 0
da :2 0 1714 29ec
29ed :3 0 15 :3 0
e1 :3 0 29ef 29f0
0 3d :2 0 29f1
29f2 0 29f4 1717
29fb 15 :3 0 e1
:3 0 29f5 29f6 0
e2 :2 0 29f7 29f8
0 29fa 1719 29fc
29ee 29f4 0 29fd
0 29fa 0 29fd
171b 0 29fe 171e
2a48 e5 :3 0 15
:3 0 e1 :3 0 2a01
2a02 0 e4 :3 0
2a03 2a04 0 2a3e
c3 :3 0 c4 :3 0
2a06 2a07 0 c3
:3 0 d3 :3 0 2a09
2a0a 0 e6 :2 0
2 :4 0 24f :2 0
d5 :2 0 2a :2 0
1721 2a0f 2a11 :3 0
1724 2a0b 2a13 2a08
2a15 2a14 :2 0 c6
:3 0 d6 :3 0 2a17
2a18 0 c8 :4 0
250 :4 0 cb :2 0
cc :3 0 1728 2a1c
2a1e :3 0 cb :2 0
e9 :4 0 172b 2a20
2a22 :3 0 cb :2 0
ea :4 0 172e 2a24
2a26 :3 0 cb :2 0
e4 :3 0 1731 2a28
2a2a :3 0 cb :2 0
eb :4 0 1734 2a2c
2a2e :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
1737 2a31 2a35 173b
2a30 2a37 :3 0 173e
2a19 2a39 :2 0 2a3b
1741 2a3c 2a16 2a3b
0 2a3d 1743 0
2a3e 1745 2a41 :3 0
2a41 0 2a41 2a40
2a3e 2a3f :6 0 2a43
76 :3 0 1748 2a45
174a 2a44 2a43 :2 0
2a46 174c :2 0 2a48
0 2a48 2a47 29fe
2a46 :6 0 2b14 6f
:3 0 251 :3 0 98
:3 0 1d :4 0 252
1 :8 0 2a63 e0
:4 0 2a4e :3 0 f7
:3 0 da :2 0 1750
2a51 2a52 :3 0 15
:3 0 e1 :3 0 2a54
2a55 0 3d :2 0
2a56 2a57 0 2a59
1753 2a60 15 :3 0
e1 :3 0 2a5a 2a5b
0 e2 :2 0 2a5c
2a5d 0 2a5f 1755
2a61 2a53 2a59 0
2a62 0 2a5f 0
2a62 1757 0 2a63
175a 2aad e5 :3 0
15 :3 0 e1 :3 0
2a66 2a67 0 e4
:3 0 2a68 2a69 0
2aa3 c3 :3 0 c4
:3 0 2a6b 2a6c 0
c3 :3 0 d3 :3 0
2a6e 2a6f 0 e6
:2 0 2 :4 0 253
:2 0 d5 :2 0 2a
:2 0 175d 2a74 2a76
:3 0 1760 2a70 2a78
2a6d 2a7a 2a79 :2 0
c6 :3 0 d6 :3 0
2a7c 2a7d 0 c8
:4 0 254 :4 0 cb
:2 0 cc :3 0 1764
2a81 2a83 :3 0 cb
:2 0 e9 :4 0 1767
2a85 2a87 :3 0 cb
:2 0 ea :4 0 176a
2a89 2a8b :3 0 cb
:2 0 e4 :3 0 176d
2a8d 2a8f :3 0 cb
:2 0 eb :4 0 1770
2a91 2a93 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1773 2a96 2a9a
1777 2a95 2a9c :3 0
177a 2a7e 2a9e :2 0
2aa0 177d 2aa1 2a7b
2aa0 0 2aa2 177f
0 2aa3 1781 2aa6
:3 0 2aa6 0 2aa6
2aa5 2aa3 2aa4 :6 0
2aa8 78 :3 0 1784
2aaa 1786 2aa9 2aa8
:2 0 2aab 1788 :2 0
2aad 0 2aad 2aac
2a63 2aab :6 0 2b14
6f :3 0 1ee :3 0
98 :3 0 1d :4 0
255 1 :8 0 2ac8
e0 :4 0 2ab3 :3 0
f7 :3 0 da :2 0
178c 2ab6 2ab7 :3 0
15 :3 0 e1 :3 0
2ab9 2aba 0 3d
:2 0 2abb 2abc 0
2abe 178f 2ac5 15
:3 0 e1 :3 0 2abf
2ac0 0 e2 :2 0
2ac1 2ac2 0 2ac4
1791 2ac6 2ab8 2abe
0 2ac7 0 2ac4
0 2ac7 1793 0
2ac8 1796 2b12 e5
:3 0 15 :3 0 e1
:3 0 2acb 2acc 0
e4 :3 0 2acd 2ace
0 2b08 c3 :3 0
c4 :3 0 2ad0 2ad1
0 c3 :3 0 d3
:3 0 2ad3 2ad4 0
e6 :2 0 2 :4 0
256 :2 0 d5 :2 0
2a :2 0 1799 2ad9
2adb :3 0 179c 2ad5
2add 2ad2 2adf 2ade
:2 0 c6 :3 0 d6
:3 0 2ae1 2ae2 0
c8 :4 0 257 :4 0
cb :2 0 cc :3 0
17a0 2ae6 2ae8 :3 0
cb :2 0 e9 :4 0
17a3 2aea 2aec :3 0
cb :2 0 ea :4 0
17a6 2aee 2af0 :3 0
cb :2 0 e4 :3 0
17a9 2af2 2af4 :3 0
cb :2 0 eb :4 0
17ac 2af6 2af8 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 17af 2afb
2aff 17b3 2afa 2b01
:3 0 17b6 2ae3 2b03
:2 0 2b05 17b9 2b06
2ae0 2b05 0 2b07
17bb 0 2b08 17bd
2b0b :3 0 2b0b 0
2b0b 2b0a 2b08 2b09
:6 0 2b0d 7a :3 0
17c0 2b0f 17c2 2b0e
2b0d :2 0 2b10 17c4
:2 0 2b12 0 2b12
2b11 2ac8 2b10 :6 0
2b14 6f :3 0 17c6
3e5a 9a :3 0 17
:3 0 90 :3 0 91
:3 0 22 :3 0 9b
:3 0 20 :3 0 92
:3 0 21 :3 0 93
:4 0 258 1 :8 0
2b25 15 :3 0 e1
:3 0 2b20 2b21 0
e4 :3 0 2b22 2b23
0 2b25 17ce 2b6f
e5 :3 0 15 :3 0
e1 :3 0 2b28 2b29
0 e4 :3 0 2b2a
2b2b 0 2b65 c3
:3 0 c4 :3 0 2b2d
2b2e 0 c3 :3 0
d3 :3 0 2b30 2b31
0 e6 :2 0 2
:4 0 259 :2 0 d5
:2 0 2a :2 0 17d1
2b36 2b38 :3 0 17d4
2b32 2b3a 2b2f 2b3c
2b3b :2 0 c6 :3 0
d6 :3 0 2b3e 2b3f
0 c8 :4 0 25a
:4 0 cb :2 0 cc
:3 0 17d8 2b43 2b45
:3 0 cb :2 0 e9
:4 0 17db 2b47 2b49
:3 0 cb :2 0 ea
:4 0 17de 2b4b 2b4d
:3 0 cb :2 0 e4
:3 0 17e1 2b4f 2b51
:3 0 cb :2 0 eb
:4 0 17e4 2b53 2b55
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 17e7
2b58 2b5c 17eb 2b57
2b5e :3 0 17ee 2b40
2b60 :2 0 2b62 17f1
2b63 2b3d 2b62 0
2b64 17f3 0 2b65
17f5 2b68 :3 0 2b68
0 2b68 2b67 2b65
2b66 :6 0 2b6a 7c
:3 0 17f8 2b6c 17fa
2b6b 2b6a :2 0 2b6d
17fc :2 0 2b6f 0
2b6f 2b6e 2b25 2b6d
:6 0 3e59 6f :3 0
15 :3 0 e1 :3 0
2b71 2b72 0 15
:3 0 da :2 0 100
:3 0 2b74 2b76 0
1800 2b75 2b78 :3 0
2b79 :2 0 84 :3 0
4c :3 0 3d :2 0
1803 2b7b 2b7e da
:2 0 3d :2 0 1808
2b80 2b82 :3 0 1e
:3 0 1d :3 0 2b84
2b85 0 2b87 180b
2b88 2b83 2b87 0
2b89 180d 0 3e56
98 :3 0 16d :3 0
177 :3 0 17 :3 0
3c :3 0 19 :3 0
af :3 0 8b :3 0
20 :3 0 92 :3 0
21 :3 0 93 :4 0
25b 1 :8 0 2b9c
15 :3 0 e1 :3 0
2b97 2b98 0 e4
:3 0 2b99 2b9a 0
2b9c 180f 2be6 e5
:3 0 15 :3 0 e1
:3 0 2b9f 2ba0 0
e4 :3 0 2ba1 2ba2
0 2bdc c3 :3 0
c4 :3 0 2ba4 2ba5
0 c3 :3 0 d3
:3 0 2ba7 2ba8 0
e6 :2 0 2 :4 0
25c :2 0 d5 :2 0
2a :2 0 1812 2bad
2baf :3 0 1815 2ba9
2bb1 2ba6 2bb3 2bb2
:2 0 c6 :3 0 d6
:3 0 2bb5 2bb6 0
c8 :4 0 25d :4 0
cb :2 0 cc :3 0
1819 2bba 2bbc :3 0
cb :2 0 e9 :4 0
181c 2bbe 2bc0 :3 0
cb :2 0 ea :4 0
181f 2bc2 2bc4 :3 0
cb :2 0 e4 :3 0
1822 2bc6 2bc8 :3 0
cb :2 0 eb :4 0
1825 2bca 2bcc :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1828 2bcf
2bd3 182c 2bce 2bd5
:3 0 182f 2bb7 2bd7
:2 0 2bd9 1832 2bda
2bb4 2bd9 0 2bdb
1834 0 2bdc 1836
2bdf :3 0 2bdf 0
2bdf 2bde 2bdc 2bdd
:6 0 2be1 7e :3 0
1839 2be3 183b 2be2
2be1 :2 0 2be4 183d
:2 0 2be6 0 2be6
2be5 2b9c 2be4 :6 0
3e56 6f :3 0 15
:3 0 e1 :3 0 2be8
2be9 0 15 :3 0
da :2 0 157 :3 0
2beb 2bed 0 1841
2bec 2bef :3 0 2bf0
:2 0 d8 :3 0 84
:3 0 3c :3 0 3d
:2 0 1844 2bf3 2bf6
b0 :3 0 19e :3 0
2bf8 2bf9 0 1847
2bf2 2bfb 2bfc :2 0
b0 :3 0 da :2 0
19e :3 0 2bfe 2c00
0 184c 2bff 2c02
:3 0 3f :3 0 3d
:2 0 2c04 2c05 0
2c72 af :3 0 12f
:3 0 23 :3 0 92
:3 0 21 :3 0 93
:3 0 98 :3 0 1b
:4 0 25e 1 :8 0
2c25 e0 :4 0 2c10
:3 0 f7 :3 0 da
:2 0 1851 2c13 2c14
:3 0 15 :3 0 e1
:3 0 2c16 2c17 0
3d :2 0 2c18 2c19
0 2c1b 1854 2c22
15 :3 0 e1 :3 0
2c1c 2c1d 0 e2
:2 0 2c1e 2c1f 0
2c21 1856 2c23 2c15
2c1b 0 2c24 0
2c21 0 2c24 1858
0 2c25 185b 2c6f
e5 :3 0 15 :3 0
e1 :3 0 2c28 2c29
0 e4 :3 0 2c2a
2c2b 0 2c65 c3
:3 0 c4 :3 0 2c2d
2c2e 0 c3 :3 0
d3 :3 0 2c30 2c31
0 e6 :2 0 2
:4 0 25f :2 0 d5
:2 0 2a :2 0 185e
2c36 2c38 :3 0 1861
2c32 2c3a 2c2f 2c3c
2c3b :2 0 c6 :3 0
d6 :3 0 2c3e 2c3f
0 c8 :4 0 260
:4 0 cb :2 0 cc
:3 0 1865 2c43 2c45
:3 0 cb :2 0 e9
:4 0 1868 2c47 2c49
:3 0 cb :2 0 ea
:4 0 186b 2c4b 2c4d
:3 0 cb :2 0 e4
:3 0 186e 2c4f 2c51
:3 0 cb :2 0 eb
:4 0 1871 2c53 2c55
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 1874
2c58 2c5c 1878 2c57
2c5e :3 0 187b 2c40
2c60 :2 0 2c62 187e
2c63 2c3d 2c62 0
2c64 1880 0 2c65
1882 2c68 :3 0 2c68
0 2c68 2c67 2c65
2c66 :6 0 2c6a 80
:3 0 1885 2c6c 1887
2c6b 2c6a :2 0 2c6d
1889 :2 0 2c6f 0
2c6f 2c6e 2c25 2c6d
:6 0 2c72 6f :3 0
140 :3 0 188b 2d71
84 :3 0 3c :3 0
3d :2 0 188e 2c73
2c76 b0 :3 0 da
:2 0 194 :3 0 2c78
2c7a 0 1893 2c79
2c7c :3 0 71 :3 0
172 :3 0 3d :2 0
84 :3 0 41 :3 0
3d :2 0 1896 2c81
2c84 b0 :3 0 173
:3 0 2c86 2c87 0
6e :3 0 1899 2c7f
2c8a 2c7e 2c8b 0
2cfc af :3 0 16d
:3 0 b0 :3 0 19e
:3 0 177 :3 0 6e
:3 0 12f :3 0 23
:3 0 92 :3 0 21
:3 0 93 :3 0 98
:3 0 1b :4 0 261
1 :8 0 2cb0 e0
:4 0 2c9b :3 0 f7
:3 0 da :2 0 18a0
2c9e 2c9f :3 0 15
:3 0 e1 :3 0 2ca1
2ca2 0 3d :2 0
2ca3 2ca4 0 2ca6
18a3 2cad 15 :3 0
e1 :3 0 2ca7 2ca8
0 e2 :2 0 2ca9
2caa 0 2cac 18a5
2cae 2ca0 2ca6 0
2caf 0 2cac 0
2caf 18a7 0 2cb0
18aa 2cfa e5 :3 0
15 :3 0 e1 :3 0
2cb3 2cb4 0 e4
:3 0 2cb5 2cb6 0
2cf0 c3 :3 0 c4
:3 0 2cb8 2cb9 0
c3 :3 0 d3 :3 0
2cbb 2cbc 0 e6
:2 0 2 :4 0 262
:2 0 d5 :2 0 2a
:2 0 18ad 2cc1 2cc3
:3 0 18b0 2cbd 2cc5
2cba 2cc7 2cc6 :2 0
c6 :3 0 d6 :3 0
2cc9 2cca 0 c8
:4 0 263 :4 0 cb
:2 0 cc :3 0 18b4
2cce 2cd0 :3 0 cb
:2 0 e9 :4 0 18b7
2cd2 2cd4 :3 0 cb
:2 0 ea :4 0 18ba
2cd6 2cd8 :3 0 cb
:2 0 e4 :3 0 18bd
2cda 2cdc :3 0 cb
:2 0 eb :4 0 18c0
2cde 2ce0 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 18c3 2ce3 2ce7
18c7 2ce2 2ce9 :3 0
18ca 2ccb 2ceb :2 0
2ced 18cd 2cee 2cc8
2ced 0 2cef 18cf
0 2cf0 18d1 2cf3
:3 0 2cf3 0 2cf3
2cf2 2cf0 2cf1 :6 0
2cf5 82 :3 0 18d4
2cf7 18d6 2cf6 2cf5
:2 0 2cf8 18d8 :2 0
2cfa 0 2cfa 2cf9
2cb0 2cf8 :6 0 2cfc
6f :3 0 18da 2cfd
2c7d 2cfc 0 2d73
af :3 0 16d :3 0
199 :3 0 19a :3 0
3c :3 0 b0 :3 0
19e :3 0 177 :3 0
19 :3 0 12f :3 0
23 :3 0 92 :3 0
21 :3 0 93 :3 0
98 :3 0 1b :4 0
264 1 :8 0 2d24
e0 :4 0 2d0f :3 0
f7 :3 0 da :2 0
18df 2d12 2d13 :3 0
15 :3 0 e1 :3 0
2d15 2d16 0 3d
:2 0 2d17 2d18 0
2d1a 18e2 2d21 15
:3 0 e1 :3 0 2d1b
2d1c 0 e2 :2 0
2d1d 2d1e 0 2d20
18e4 2d22 2d14 2d1a
0 2d23 0 2d20
0 2d23 18e6 0
2d24 18e9 2d6e e5
:3 0 15 :3 0 e1
:3 0 2d27 2d28 0
e4 :3 0 2d29 2d2a
0 2d64 c3 :3 0
c4 :3 0 2d2c 2d2d
0 c3 :3 0 d3
:3 0 2d2f 2d30 0
e6 :2 0 2 :4 0
265 :2 0 d5 :2 0
2a :2 0 18ec 2d35
2d37 :3 0 18ef 2d31
2d39 2d2e 2d3b 2d3a
:2 0 c6 :3 0 d6
:3 0 2d3d 2d3e 0
c8 :4 0 266 :4 0
cb :2 0 cc :3 0
18f3 2d42 2d44 :3 0
cb :2 0 e9 :4 0
18f6 2d46 2d48 :3 0
cb :2 0 ea :4 0
18f9 2d4a 2d4c :3 0
cb :2 0 e4 :3 0
18fc 2d4e 2d50 :3 0
cb :2 0 eb :4 0
18ff 2d52 2d54 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1902 2d57
2d5b 1906 2d56 2d5d
:3 0 1909 2d3f 2d5f
:2 0 2d61 190c 2d62
2d3c 2d61 0 2d63
190e 0 2d64 1910
2d67 :3 0 2d67 0
2d67 2d66 2d64 2d65
:6 0 2d69 84 :3 0
1913 2d6b 1915 2d6a
2d69 :2 0 2d6c 1917
:2 0 2d6e 0 2d6e
2d6d 2d24 2d6c :6 0
2d70 6f :3 0 1919
2d72 2c03 2c72 0
2d73 0 2d70 0
2d73 191b 0 2df2
15 :3 0 e1 :3 0
2d74 2d75 0 15
:3 0 da :2 0 157
:3 0 2d77 2d79 0
1921 2d78 2d7b :3 0
2d7c :2 0 84 :3 0
3f :3 0 3d :2 0
1924 2d7e 2d81 10a
:2 0 3d :2 0 1929
2d83 2d85 :3 0 2d86
:2 0 2d7d 2d88 2d87
:2 0 af :3 0 98
:3 0 17 :4 0 1f8
1 :8 0 2da3 e0
:4 0 2d8e :3 0 f7
:3 0 da :2 0 192e
2d91 2d92 :3 0 15
:3 0 e1 :3 0 2d94
2d95 0 3d :2 0
2d96 2d97 0 2d99
1931 2da0 15 :3 0
e1 :3 0 2d9a 2d9b
0 e2 :2 0 2d9c
2d9d 0 2d9f 1933
2da1 2d93 2d99 0
2da2 0 2d9f 0
2da2 1935 0 2da3
1938 2ded e5 :3 0
15 :3 0 e1 :3 0
2da6 2da7 0 e4
:3 0 2da8 2da9 0
2de3 c3 :3 0 c4
:3 0 2dab 2dac 0
c3 :3 0 d3 :3 0
2dae 2daf 0 e6
:2 0 2 :4 0 267
:2 0 d5 :2 0 2a
:2 0 193b 2db4 2db6
:3 0 193e 2db0 2db8
2dad 2dba 2db9 :2 0
c6 :3 0 d6 :3 0
2dbc 2dbd 0 c8
:4 0 268 :4 0 cb
:2 0 cc :3 0 1942
2dc1 2dc3 :3 0 cb
:2 0 e9 :4 0 1945
2dc5 2dc7 :3 0 cb
:2 0 ea :4 0 1948
2dc9 2dcb :3 0 cb
:2 0 e4 :3 0 194b
2dcd 2dcf :3 0 cb
:2 0 eb :4 0 194e
2dd1 2dd3 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1951 2dd6 2dda
1955 2dd5 2ddc :3 0
1958 2dbe 2dde :2 0
2de0 195b 2de1 2dbb
2de0 0 2de2 195d
0 2de3 195f 2de6
:3 0 2de6 0 2de6
2de5 2de3 2de4 :6 0
2de8 86 :3 0 1962
2dea 1964 2de9 2de8
:2 0 2deb 1966 :2 0
2ded 0 2ded 2dec
2da3 2deb :6 0 2def
6f :3 0 1968 2df0
2d89 2def 0 2df1
196a 0 2df2 196c
30b0 269 :3 0 98
:3 0 a0 :3 0 110
:3 0 185 :3 0 18a
:3 0 110 :3 0 185
:3 0 17 :3 0 38
:3 0 ae :3 0 110
:3 0 af :3 0 269
:3 0 110 :3 0 8b
:3 0 20 :3 0 110
:3 0 8b :3 0 269
:3 0 8b :3 0 269
:3 0 16d :3 0 269
:3 0 92 :3 0 110
:3 0 26a :3 0 9a
:3 0 90 :3 0 26b
:3 0 26b :3 0 98
:3 0 269 :3 0 98
:4 0 26c 1 :8 0
2e1b 15 :3 0 e1
:3 0 2e16 2e17 0
e4 :3 0 2e18 2e19
0 2e1b 196f 2e65
e5 :3 0 15 :3 0
e1 :3 0 2e1e 2e1f
0 e4 :3 0 2e20
2e21 0 2e5b c3
:3 0 c4 :3 0 2e23
2e24 0 c3 :3 0
d3 :3 0 2e26 2e27
0 e6 :2 0 2
:4 0 26d :2 0 d5
:2 0 2a :2 0 1972
2e2c 2e2e :3 0 1975
2e28 2e30 2e25 2e32
2e31 :2 0 c6 :3 0
d6 :3 0 2e34 2e35
0 c8 :4 0 26e
:4 0 cb :2 0 cc
:3 0 1979 2e39 2e3b
:3 0 cb :2 0 e9
:4 0 197c 2e3d 2e3f
:3 0 cb :2 0 ea
:4 0 197f 2e41 2e43
:3 0 cb :2 0 e4
:3 0 1982 2e45 2e47
:3 0 cb :2 0 eb
:4 0 1985 2e49 2e4b
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 1988
2e4e 2e52 198c 2e4d
2e54 :3 0 198f 2e36
2e56 :2 0 2e58 1992
2e59 2e33 2e58 0
2e5a 1994 0 2e5b
1996 2e5e :3 0 2e5e
0 2e5e 2e5d 2e5b
2e5c :6 0 2e60 88
:3 0 1999 2e62 199b
2e61 2e60 :2 0 2e63
199d :2 0 2e65 0
2e65 2e64 2e1b 2e63
:6 0 30af 6f :3 0
15 :3 0 e1 :3 0
2e67 2e68 0 15
:3 0 da :2 0 157
:3 0 2e6a 2e6c 0
19a1 2e6b 2e6e :3 0
2e6f :2 0 17 :3 0
165 :2 0 19a4 2e72
2e73 :3 0 2e74 :2 0
2e75 :2 0 2e70 2e77
2e76 :2 0 71 :3 0
172 :3 0 3d :2 0
84 :3 0 41 :3 0
3d :2 0 19a6 2e7c
2e7f b0 :3 0 26f
:3 0 2e81 2e82 0
6e :3 0 19a9 2e7a
2e85 2e79 2e86 0
2fc4 af :3 0 98
:3 0 17 :4 0 1f8
1 :8 0 2ea1 e0
:4 0 2e8c :3 0 f7
:3 0 da :2 0 19b0
2e8f 2e90 :3 0 15
:3 0 e1 :3 0 2e92
2e93 0 3d :2 0
2e94 2e95 0 2e97
19b3 2e9e 15 :3 0
e1 :3 0 2e98 2e99
0 e2 :2 0 2e9a
2e9b 0 2e9d 19b5
2e9f 2e91 2e97 0
2ea0 0 2e9d 0
2ea0 19b7 0 2ea1
19ba 2eeb e5 :3 0
15 :3 0 e1 :3 0
2ea4 2ea5 0 e4
:3 0 2ea6 2ea7 0
2ee1 c3 :3 0 c4
:3 0 2ea9 2eaa 0
c3 :3 0 d3 :3 0
2eac 2ead 0 e6
:2 0 2 :4 0 270
:2 0 d5 :2 0 2a
:2 0 19bd 2eb2 2eb4
:3 0 19c0 2eae 2eb6
2eab 2eb8 2eb7 :2 0
c6 :3 0 d6 :3 0
2eba 2ebb 0 c8
:4 0 271 :4 0 cb
:2 0 cc :3 0 19c4
2ebf 2ec1 :3 0 cb
:2 0 e9 :4 0 19c7
2ec3 2ec5 :3 0 cb
:2 0 ea :4 0 19ca
2ec7 2ec9 :3 0 cb
:2 0 e4 :3 0 19cd
2ecb 2ecd :3 0 cb
:2 0 eb :4 0 19d0
2ecf 2ed1 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 19d3 2ed4 2ed8
19d7 2ed3 2eda :3 0
19da 2ebc 2edc :2 0
2ede 19dd 2edf 2eb9
2ede 0 2ee0 19df
0 2ee1 19e1 2ee4
:3 0 2ee4 0 2ee4
2ee3 2ee1 2ee2 :6 0
2ee6 8a :3 0 19e4
2ee8 19e6 2ee7 2ee6
:2 0 2ee9 19e8 :2 0
2eeb 0 2eeb 2eea
2ea1 2ee9 :6 0 2fc4
6f :3 0 af :3 0
92 :3 0 21 :3 0
93 :3 0 12f :3 0
23 :3 0 16d :3 0
177 :3 0 6e :3 0
98 :3 0 1b :4 0
272 1 :8 0 2f0e
e0 :4 0 2ef9 :3 0
f7 :3 0 da :2 0
19ec 2efc 2efd :3 0
15 :3 0 e1 :3 0
2eff 2f00 0 3d
:2 0 2f01 2f02 0
2f04 19ef 2f0b 15
:3 0 e1 :3 0 2f05
2f06 0 e2 :2 0
2f07 2f08 0 2f0a
19f1 2f0c 2efe 2f04
0 2f0d 0 2f0a
0 2f0d 19f3 0
2f0e 19f6 2f58 e5
:3 0 15 :3 0 e1
:3 0 2f11 2f12 0
e4 :3 0 2f13 2f14
0 2f4e c3 :3 0
c4 :3 0 2f16 2f17
0 c3 :3 0 d3
:3 0 2f19 2f1a 0
e6 :2 0 2 :4 0
273 :2 0 d5 :2 0
2a :2 0 19f9 2f1f
2f21 :3 0 19fc 2f1b
2f23 2f18 2f25 2f24
:2 0 c6 :3 0 d6
:3 0 2f27 2f28 0
c8 :4 0 274 :4 0
cb :2 0 cc :3 0
1a00 2f2c 2f2e :3 0
cb :2 0 e9 :4 0
1a03 2f30 2f32 :3 0
cb :2 0 ea :4 0
1a06 2f34 2f36 :3 0
cb :2 0 e4 :3 0
1a09 2f38 2f3a :3 0
cb :2 0 eb :4 0
1a0c 2f3c 2f3e :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1a0f 2f41
2f45 1a13 2f40 2f47
:3 0 1a16 2f29 2f49
:2 0 2f4b 1a19 2f4c
2f26 2f4b 0 2f4d
1a1b 0 2f4e 1a1d
2f51 :3 0 2f51 0
2f51 2f50 2f4e 2f4f
:6 0 2f53 8c :3 0
1a20 2f55 1a22 2f54
2f53 :2 0 2f56 1a24
:2 0 2f58 0 2f58
2f57 2f0e 2f56 :6 0
2fc4 6f :3 0 ae
:3 0 185 :3 0 186
:3 0 185 :3 0 38
:3 0 36 :3 0 8b
:3 0 20 :4 0 275
1 :8 0 2f78 e0
:4 0 2f63 :3 0 f7
:3 0 da :2 0 1a28
2f66 2f67 :3 0 15
:3 0 e1 :3 0 2f69
2f6a 0 3d :2 0
2f6b 2f6c 0 2f6e
1a2b 2f75 15 :3 0
e1 :3 0 2f6f 2f70
0 e2 :2 0 2f71
2f72 0 2f74 1a2d
2f76 2f68 2f6e 0
2f77 0 2f74 0
2f77 1a2f 0 2f78
1a32 2fc2 e5 :3 0
15 :3 0 e1 :3 0
2f7b 2f7c 0 e4
:3 0 2f7d 2f7e 0
2fb8 c3 :3 0 c4
:3 0 2f80 2f81 0
c3 :3 0 d3 :3 0
2f83 2f84 0 e6
:2 0 2 :4 0 276
:2 0 d5 :2 0 2a
:2 0 1a35 2f89 2f8b
:3 0 1a38 2f85 2f8d
2f82 2f8f 2f8e :2 0
c6 :3 0 d6 :3 0
2f91 2f92 0 c8
:4 0 277 :4 0 cb
:2 0 cc :3 0 1a3c
2f96 2f98 :3 0 cb
:2 0 e9 :4 0 1a3f
2f9a 2f9c :3 0 cb
:2 0 ea :4 0 1a42
2f9e 2fa0 :3 0 cb
:2 0 e4 :3 0 1a45
2fa2 2fa4 :3 0 cb
:2 0 eb :4 0 1a48
2fa6 2fa8 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1a4b 2fab 2faf
1a4f 2faa 2fb1 :3 0
1a52 2f93 2fb3 :2 0
2fb5 1a55 2fb6 2f90
2fb5 0 2fb7 1a57
0 2fb8 1a59 2fbb
:3 0 2fbb 0 2fbb
2fba 2fb8 2fb9 :6 0
2fbd 8e :3 0 1a5c
2fbf 1a5e 2fbe 2fbd
:2 0 2fc0 1a60 :2 0
2fc2 0 2fc2 2fc1
2f78 2fc0 :6 0 2fc4
6f :3 0 1a62 30ac
71 :3 0 172 :3 0
3d :2 0 84 :3 0
41 :3 0 3d :2 0
1a67 2fc8 2fcb b0
:3 0 173 :3 0 2fcd
2fce 0 6e :3 0
1a6a 2fc6 2fd1 2fc5
2fd2 0 30ab ae
:3 0 185 :3 0 186
:3 0 185 :3 0 39
:3 0 36 :3 0 8b
:3 0 20 :4 0 278
1 :8 0 2ff2 e0
:4 0 2fdd :3 0 f7
:3 0 da :2 0 1a71
2fe0 2fe1 :3 0 15
:3 0 e1 :3 0 2fe3
2fe4 0 3d :2 0
2fe5 2fe6 0 2fe8
1a74 2fef 15 :3 0
e1 :3 0 2fe9 2fea
0 e2 :2 0 2feb
2fec 0 2fee 1a76
2ff0 2fe2 2fe8 0
2ff1 0 2fee 0
2ff1 1a78 0 2ff2
1a7b 303c e5 :3 0
15 :3 0 e1 :3 0
2ff5 2ff6 0 e4
:3 0 2ff7 2ff8 0
3032 c3 :3 0 c4
:3 0 2ffa 2ffb 0
c3 :3 0 d3 :3 0
2ffd 2ffe 0 e6
:2 0 2 :4 0 279
:2 0 d5 :2 0 2a
:2 0 1a7e 3003 3005
:3 0 1a81 2fff 3007
2ffc 3009 3008 :2 0
c6 :3 0 d6 :3 0
300b 300c 0 c8
:4 0 27a :4 0 cb
:2 0 cc :3 0 1a85
3010 3012 :3 0 cb
:2 0 e9 :4 0 1a88
3014 3016 :3 0 cb
:2 0 ea :4 0 1a8b
3018 301a :3 0 cb
:2 0 e4 :3 0 1a8e
301c 301e :3 0 cb
:2 0 eb :4 0 1a91
3020 3022 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1a94 3025 3029
1a98 3024 302b :3 0
1a9b 300d 302d :2 0
302f 1a9e 3030 300a
302f 0 3031 1aa0
0 3032 1aa2 3035
:3 0 3035 0 3035
3034 3032 3033 :6 0
3037 90 :3 0 1aa5
3039 1aa7 3038 3037
:2 0 303a 1aa9 :2 0
303c 0 303c 303b
2ff2 303a :6 0 30ab
6f :3 0 af :3 0
92 :3 0 21 :3 0
93 :3 0 12f :3 0
23 :3 0 16d :3 0
177 :3 0 6e :3 0
98 :3 0 1b :4 0
27b 1 :8 0 305f
e0 :4 0 304a :3 0
f7 :3 0 da :2 0
1aad 304d 304e :3 0
15 :3 0 e1 :3 0
3050 3051 0 3d
:2 0 3052 3053 0
3055 1ab0 305c 15
:3 0 e1 :3 0 3056
3057 0 e2 :2 0
3058 3059 0 305b
1ab2 305d 304f 3055
0 305e 0 305b
0 305e 1ab4 0
305f 1ab7 30a9 e5
:3 0 15 :3 0 e1
:3 0 3062 3063 0
e4 :3 0 3064 3065
0 309f c3 :3 0
c4 :3 0 3067 3068
0 c3 :3 0 d3
:3 0 306a 306b 0
e6 :2 0 2 :4 0
27c :2 0 d5 :2 0
2a :2 0 1aba 3070
3072 :3 0 1abd 306c
3074 3069 3076 3075
:2 0 c6 :3 0 d6
:3 0 3078 3079 0
c8 :4 0 27d :4 0
cb :2 0 cc :3 0
1ac1 307d 307f :3 0
cb :2 0 e9 :4 0
1ac4 3081 3083 :3 0
cb :2 0 ea :4 0
1ac7 3085 3087 :3 0
cb :2 0 e4 :3 0
1aca 3089 308b :3 0
cb :2 0 eb :4 0
1acd 308d 308f :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1ad0 3092
3096 1ad4 3091 3098
:3 0 1ad7 307a 309a
:2 0 309c 1ada 309d
3077 309c 0 309e
1adc 0 309f 1ade
30a2 :3 0 30a2 0
30a2 30a1 309f 30a0
:6 0 30a4 92 :3 0
1ae1 30a6 1ae3 30a5
30a4 :2 0 30a7 1ae5
:2 0 30a9 0 30a9
30a8 305f 30a7 :6 0
30ab 6f :3 0 1ae7
30ad 2e78 2fc4 0
30ae 0 30ab 0
30ae 1aeb 0 30af
1aee 30b1 2bf1 2df2
0 30b2 0 30af
0 30b2 1af1 0
3e56 84 :3 0 3f
:3 0 3d :2 0 1af4
30b3 30b6 10a :2 0
3d :2 0 1af9 30b8
30ba :3 0 84 :3 0
65 :3 0 3d :2 0
1afc 30bc 30bf da
:2 0 2a :2 0 1b01
30c1 30c3 :3 0 30c4
:2 0 3a :3 0 165
:2 0 1b04 30c7 30c8
:3 0 30c9 :2 0 30ca
:2 0 30c5 30cc 30cb
:2 0 124 :3 0 124
:3 0 3a :3 0 64
:3 0 ae :3 0 8b
:3 0 20 :4 0 27e
1 :8 0 30db 15
:3 0 e1 :3 0 30d6
30d7 0 e4 :3 0
30d8 30d9 0 30db
1b06 3125 e5 :3 0
15 :3 0 e1 :3 0
30de 30df 0 e4
:3 0 30e0 30e1 0
311b c3 :3 0 c4
:3 0 30e3 30e4 0
c3 :3 0 d3 :3 0
30e6 30e7 0 e6
:2 0 2 :4 0 27f
:2 0 d5 :2 0 2a
:2 0 1b09 30ec 30ee
:3 0 1b0c 30e8 30f0
30e5 30f2 30f1 :2 0
c6 :3 0 d6 :3 0
30f4 30f5 0 c8
:4 0 280 :4 0 cb
:2 0 cc :3 0 1b10
30f9 30fb :3 0 cb
:2 0 e9 :4 0 1b13
30fd 30ff :3 0 cb
:2 0 ea :4 0 1b16
3101 3103 :3 0 cb
:2 0 e4 :3 0 1b19
3105 3107 :3 0 cb
:2 0 eb :4 0 1b1c
3109 310b :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1b1f 310e 3112
1b23 310d 3114 :3 0
1b26 30f6 3116 :2 0
3118 1b29 3119 30f3
3118 0 311a 1b2b
0 311b 1b2d 311e
:3 0 311e 0 311e
311d 311b 311c :6 0
3120 94 :3 0 1b30
3122 1b32 3121 3120
:2 0 3123 1b34 :2 0
3125 0 3125 3124
30db 3123 :6 0 3282
6f :3 0 15 :3 0
e1 :3 0 3127 3128
0 15 :3 0 da
:2 0 157 :3 0 312a
312c 0 1b38 312b
312e :3 0 312f :2 0
84 :3 0 64 :3 0
3d :2 0 1b3b 3131
3134 da :2 0 3d
:2 0 1b40 3136 3138
:3 0 3139 :2 0 3130
313b 313a :2 0 ae
:3 0 124 :3 0 3a
:3 0 8b :3 0 20
:4 0 281 1 :8 0
3158 e0 :4 0 3143
:3 0 f7 :3 0 da
:2 0 1b45 3146 3147
:3 0 15 :3 0 e1
:3 0 3149 314a 0
3d :2 0 314b 314c
0 314e 1b48 3155
15 :3 0 e1 :3 0
314f 3150 0 e2
:2 0 3151 3152 0
3154 1b4a 3156 3148
314e 0 3157 0
3154 0 3157 1b4c
0 3158 1b4f 31a2
e5 :3 0 15 :3 0
e1 :3 0 315b 315c
0 e4 :3 0 315d
315e 0 3198 c3
:3 0 c4 :3 0 3160
3161 0 c3 :3 0
d3 :3 0 3163 3164
0 e6 :2 0 2
:4 0 282 :2 0 d5
:2 0 2a :2 0 1b52
3169 316b :3 0 1b55
3165 316d 3162 316f
316e :2 0 c6 :3 0
d6 :3 0 3171 3172
0 c8 :4 0 283
:4 0 cb :2 0 cc
:3 0 1b59 3176 3178
:3 0 cb :2 0 e9
:4 0 1b5c 317a 317c
:3 0 cb :2 0 ea
:4 0 1b5f 317e 3180
:3 0 cb :2 0 e4
:3 0 1b62 3182 3184
:3 0 cb :2 0 eb
:4 0 1b65 3186 3188
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 1b68
318b 318f 1b6c 318a
3191 :3 0 1b6f 3173
3193 :2 0 3195 1b72
3196 3170 3195 0
3197 1b74 0 3198
1b76 319b :3 0 319b
0 319b 319a 3198
3199 :6 0 319d 96
:3 0 1b79 319f 1b7b
319e 319d :2 0 31a0
1b7d :2 0 31a2 0
31a2 31a1 3158 31a0
:6 0 31a5 6f :3 0
140 :3 0 1b7f 3280
15 :3 0 e1 :3 0
31a6 31a7 0 15
:3 0 da :2 0 157
:3 0 31a9 31ab 0
1b83 31aa 31ad :3 0
31ae :2 0 84 :3 0
64 :3 0 3d :2 0
1b86 31b0 31b3 da
:2 0 13a :2 0 1b8b
31b5 31b7 :3 0 31b8
:2 0 31af 31ba 31b9
:2 0 e3 :3 0 96
:4 0 31bf :2 0 31c5
31bd 0 15 :3 0
e1 :3 0 31c0 31c1
0 e4 :3 0 31c2
31c3 0 31c5 1b8e
320f e5 :3 0 15
:3 0 e1 :3 0 31c8
31c9 0 e4 :3 0
31ca 31cb 0 3205
c3 :3 0 c4 :3 0
31cd 31ce 0 c3
:3 0 d3 :3 0 31d0
31d1 0 e6 :2 0
2 :4 0 284 :2 0
d5 :2 0 2a :2 0
1b91 31d6 31d8 :3 0
1b94 31d2 31da 31cf
31dc 31db :2 0 c6
:3 0 d6 :3 0 31de
31df 0 c8 :4 0
285 :4 0 cb :2 0
cc :3 0 1b98 31e3
31e5 :3 0 cb :2 0
e9 :4 0 1b9b 31e7
31e9 :3 0 cb :2 0
ea :4 0 1b9e 31eb
31ed :3 0 cb :2 0
e4 :3 0 1ba1 31ef
31f1 :3 0 cb :2 0
eb :4 0 1ba4 31f3
31f5 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
1ba7 31f8 31fc 1bab
31f7 31fe :3 0 1bae
31e0 3200 :2 0 3202
1bb1 3203 31dd 3202
0 3204 1bb3 0
3205 1bb5 3208 :3 0
3208 0 3208 3207
3205 3206 :6 0 320a
98 :3 0 1bb8 320c
1bba 320b 320a :2 0
320d 1bbc :2 0 320f
0 320f 320e 31c5
320d :6 0 327e 6f
:3 0 c3 :3 0 c4
:3 0 3211 3212 0
c3 :3 0 d3 :3 0
3214 3215 0 18
:2 0 2 :4 0 286
:2 0 d5 :2 0 2a
:2 0 1bbe 321a 321c
:3 0 1bc1 3216 321e
3213 3220 321f :2 0
c6 :3 0 d6 :3 0
3222 3223 0 c8
:4 0 287 :4 0 cb
:2 0 cc :3 0 1bc5
3227 3229 :3 0 cb
:2 0 e9 :4 0 1bc8
322b 322d :3 0 cb
:2 0 f0 :4 0 1bcb
322f 3231 :3 0 cb
:2 0 84 :3 0 d0
:3 0 b0 :3 0 288
:3 0 3236 3237 0
1bce 3235 3239 d1
:4 0 1bd0 3234 323c
1bd3 3233 323e :3 0
cb :2 0 f2 :4 0
1bd6 3240 3242 :3 0
cb :2 0 ce :4 0
1bd9 3244 3246 :3 0
cb :2 0 20 :3 0
1bdc 3248 324a :3 0
cb :2 0 ce :4 0
1bdf 324c 324e :3 0
1be2 3224 3250 :2 0
3252 1be5 3253 3221
3252 0 3254 1be7
0 327e c3 :3 0
c4 :3 0 3255 3256
0 c3 :3 0 d3
:3 0 3258 3259 0
2a :2 0 2 :4 0
289 :2 0 d5 :2 0
2a :2 0 1be9 325e
3260 :3 0 1bec 325a
3262 3257 3264 3263
:2 0 c6 :3 0 d6
:3 0 3266 3267 0
c8 :4 0 28a :4 0
cb :2 0 cc :3 0
1bf0 326b 326d :3 0
1bf3 3268 326f :2 0
3271 1bf6 3272 3265
3271 0 3273 1bf8
0 327e f5 :3 0
f6 :3 0 3274 3275
0 b0 :3 0 288
:3 0 3277 3278 0
20 :3 0 f7 :3 0
1bfa 3276 327c :2 0
327e 1bfe 327f 31bb
327e 0 3281 313c
31a5 0 3281 1c03
0 3282 1c06 3283
30cd 3282 0 3284
1c09 0 3e53 7a
:3 0 1be :2 0 2a
:2 0 1c0b 3286 3288
:3 0 3285 3289 0
3e53 15 :3 0 e1
:3 0 328b 328c 0
1bf :3 0 22 :3 0
20 :3 0 1d :3 0
72 :3 0 73 :3 0
74 :3 0 75 :3 0
7a :3 0 79 :3 0
78 :3 0 1c0d 328e
3299 328d 329a 0
3e53 1b0 :3 0 91
:3 0 22 :3 0 9a
:3 0 1d :4 0 24e
1 :8 0 32b7 e0
:4 0 32a2 :3 0 f7
:3 0 da :2 0 1c1a
32a5 32a6 :3 0 15
:3 0 e1 :3 0 32a8
32a9 0 3d :2 0
32aa 32ab 0 32ad
1c1d 32b4 15 :3 0
e1 :3 0 32ae 32af
0 e2 :2 0 32b0
32b1 0 32b3 1c1f
32b5 32a7 32ad 0
32b6 0 32b3 0
32b6 1c21 0 32b7
1c24 3301 e5 :3 0
15 :3 0 e1 :3 0
32ba 32bb 0 e4
:3 0 32bc 32bd 0
32f7 c3 :3 0 c4
:3 0 32bf 32c0 0
c3 :3 0 d3 :3 0
32c2 32c3 0 e6
:2 0 2 :4 0 28b
:2 0 d5 :2 0 2a
:2 0 1c27 32c8 32ca
:3 0 1c2a 32c4 32cc
32c1 32ce 32cd :2 0
c6 :3 0 d6 :3 0
32d0 32d1 0 c8
:4 0 28c :4 0 cb
:2 0 cc :3 0 1c2e
32d5 32d7 :3 0 cb
:2 0 e9 :4 0 1c31
32d9 32db :3 0 cb
:2 0 ea :4 0 1c34
32dd 32df :3 0 cb
:2 0 e4 :3 0 1c37
32e1 32e3 :3 0 cb
:2 0 eb :4 0 1c3a
32e5 32e7 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1c3d 32ea 32ee
1c41 32e9 32f0 :3 0
1c44 32d2 32f2 :2 0
32f4 1c47 32f5 32cf
32f4 0 32f6 1c49
0 32f7 1c4b 32fa
:3 0 32fa 0 32fa
32f9 32f7 32f8 :6 0
32fc 9a :3 0 1c4e
32fe 1c50 32fd 32fc
:2 0 32ff 1c52 :2 0
3301 0 3301 3300
32b7 32ff :6 0 3e53
6f :3 0 26 :3 0
de :4 0 3303 3304
0 3e53 82 :3 0
13b :2 0 3d :2 0
1c56 3307 3309 :3 0
84 :3 0 76 :3 0
3d :2 0 1c59 330b
330e d5 :2 0 84
:3 0 77 :3 0 3d
:2 0 1c5c 3311 3314
1c5f 3310 3316 :3 0
da :2 0 2a :2 0
1c64 3318 331a :3 0
331b :2 0 330a 331d
331c :2 0 3f :3 0
9 :3 0 331f 3320
0 3701 24 :3 0
7 :3 0 3322 3323
0 3701 26 :3 0
8 :3 0 3325 3326
0 3701 44 :3 0
b :3 0 3328 3329
0 3701 45 :3 0
10 :3 0 332b 332c
0 3701 46 :3 0
d :3 0 332e 332f
0 3701 47 :3 0
e :3 0 3331 3332
0 3701 4e :3 0
c :3 0 3334 3335
0 3701 48 :3 0
f :3 0 3337 3338
0 3701 d8 :3 0
84 :3 0 c :3 0
3d :2 0 1c67 333b
333e b0 :3 0 1b7
:3 0 3340 3341 0
1c6a 333a 3343 3344
:2 0 13b :2 0 3d
:2 0 1c6f 3346 3348
:3 0 3349 :2 0 84
:3 0 48 :3 0 3d
:2 0 1c72 334b 334e
84 :3 0 13b :2 0
f :3 0 3d :2 0
1c75 3350 3354 1c7a
3351 3356 :3 0 3357
:2 0 84 :3 0 44
:3 0 3d :2 0 1c7d
3359 335c 84 :3 0
13b :2 0 b :3 0
3d :2 0 1c80 335e
3362 1c85 335f 3364
:3 0 3365 :2 0 3358
3367 3366 :2 0 3368
:2 0 334a 336a 3369
:2 0 336b :2 0 84
:3 0 e :3 0 3d
:2 0 1c88 336d 3370
da :2 0 e2 :2 0
1c8d 3372 3374 :3 0
90 :3 0 92 :3 0
21 :3 0 93 :3 0
94 :3 0 4c :3 0
1e :3 0 a7 :3 0
62 :3 0 58 :3 0
a7 :3 0 1d3 :3 0
62 :3 0 5c :3 0
1d3 :3 0 a8 :3 0
61 :3 0 5b :3 0
a8 :3 0 1d4 :3 0
61 :3 0 5d :3 0
1d4 :3 0 9e :3 0
b :3 0 28d :3 0
3f :3 0 ac :3 0
f :3 0 1d7 :3 0
199 :3 0 19a :3 0
1d7 :3 0 b0 :3 0
1d8 :3 0 9a :3 0
1d :4 0 28e 1
:8 0 33b1 e0 :4 0
339c :3 0 f7 :3 0
da :2 0 1c92 339f
33a0 :3 0 15 :3 0
e1 :3 0 33a2 33a3
0 3d :2 0 33a4
33a5 0 33a7 1c95
33ae 15 :3 0 e1
:3 0 33a8 33a9 0
e2 :2 0 33aa 33ab
0 33ad 1c97 33af
33a1 33a7 0 33b0
0 33ad 0 33b0
1c99 0 33b1 1c9c
33fb e5 :3 0 15
:3 0 e1 :3 0 33b4
33b5 0 e4 :3 0
33b6 33b7 0 33f1
c3 :3 0 c4 :3 0
33b9 33ba 0 c3
:3 0 d3 :3 0 33bc
33bd 0 e6 :2 0
2 :4 0 28f :2 0
d5 :2 0 2a :2 0
1c9f 33c2 33c4 :3 0
1ca2 33be 33c6 33bb
33c8 33c7 :2 0 c6
:3 0 d6 :3 0 33ca
33cb 0 c8 :4 0
290 :4 0 cb :2 0
cc :3 0 1ca6 33cf
33d1 :3 0 cb :2 0
e9 :4 0 1ca9 33d3
33d5 :3 0 cb :2 0
ea :4 0 1cac 33d7
33d9 :3 0 cb :2 0
e4 :3 0 1caf 33db
33dd :3 0 cb :2 0
eb :4 0 1cb2 33df
33e1 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
1cb5 33e4 33e8 1cb9
33e3 33ea :3 0 1cbc
33cc 33ec :2 0 33ee
1cbf 33ef 33c9 33ee
0 33f0 1cc1 0
33f1 1cc3 33f4 :3 0
33f4 0 33f4 33f3
33f1 33f2 :6 0 33f6
9c :3 0 1cc6 33f8
1cc8 33f7 33f6 :2 0
33f9 1cca :2 0 33fb
0 33fb 33fa 33b1
33f9 :6 0 33fd 6f
:3 0 1ccc 3488 90
:3 0 92 :3 0 21
:3 0 93 :3 0 94
:3 0 4c :3 0 1e
:3 0 a7 :3 0 62
:3 0 58 :3 0 a7
:3 0 1d3 :3 0 62
:3 0 5c :3 0 1d3
:3 0 a8 :3 0 61
:3 0 5b :3 0 a8
:3 0 1d4 :3 0 61
:3 0 5d :3 0 1d4
:3 0 a9 :3 0 b
:3 0 28d :3 0 3f
:3 0 ab :3 0 e
:3 0 ac :3 0 f
:3 0 1d7 :3 0 199
:3 0 19a :3 0 1d7
:3 0 b0 :3 0 1d8
:3 0 9a :3 0 1d
:4 0 291 1 :8 0
343b e0 :4 0 3426
:3 0 f7 :3 0 da
:2 0 1cd0 3429 342a
:3 0 15 :3 0 e1
:3 0 342c 342d 0
3d :2 0 342e 342f
0 3431 1cd3 3438
15 :3 0 e1 :3 0
3432 3433 0 e2
:2 0 3434 3435 0
3437 1cd5 3439 342b
3431 0 343a 0
3437 0 343a 1cd7
0 343b 1cda 3485
e5 :3 0 15 :3 0
e1 :3 0 343e 343f
0 e4 :3 0 3440
3441 0 347b c3
:3 0 c4 :3 0 3443
3444 0 c3 :3 0
d3 :3 0 3446 3447
0 e6 :2 0 2
:4 0 292 :2 0 d5
:2 0 2a :2 0 1cdd
344c 344e :3 0 1ce0
3448 3450 3445 3452
3451 :2 0 c6 :3 0
d6 :3 0 3454 3455
0 c8 :4 0 293
:4 0 cb :2 0 cc
:3 0 1ce4 3459 345b
:3 0 cb :2 0 e9
:4 0 1ce7 345d 345f
:3 0 cb :2 0 ea
:4 0 1cea 3461 3463
:3 0 cb :2 0 e4
:3 0 1ced 3465 3467
:3 0 cb :2 0 eb
:4 0 1cf0 3469 346b
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 1cf3
346e 3472 1cf7 346d
3474 :3 0 1cfa 3456
3476 :2 0 3478 1cfd
3479 3453 3478 0
347a 1cff 0 347b
1d01 347e :3 0 347e
0 347e 347d 347b
347c :6 0 3480 9e
:3 0 1d04 3482 1d06
3481 3480 :2 0 3483
1d08 :2 0 3485 0
3485 3484 343b 3483
:6 0 3487 6f :3 0
1d0a 3489 3375 33fd
0 348a 0 3487
0 348a 1d0c 0
348b 1d0f 3510 90
:3 0 92 :3 0 21
:3 0 93 :3 0 94
:3 0 4c :3 0 1e
:3 0 a7 :3 0 62
:3 0 58 :3 0 a7
:3 0 1d3 :3 0 62
:3 0 5c :3 0 1d3
:3 0 a8 :3 0 61
:3 0 5b :3 0 a8
:3 0 1d4 :3 0 61
:3 0 5d :3 0 1d4
:3 0 1d7 :3 0 199
:3 0 19a :3 0 1d7
:3 0 b0 :3 0 1d8
:3 0 28d :3 0 3f
:3 0 9a :3 0 1d
:4 0 294 1 :8 0
34c3 e0 :4 0 34ae
:3 0 f7 :3 0 da
:2 0 1d13 34b1 34b2
:3 0 15 :3 0 e1
:3 0 34b4 34b5 0
3d :2 0 34b6 34b7
0 34b9 1d16 34c0
15 :3 0 e1 :3 0
34ba 34bb 0 e2
:2 0 34bc 34bd 0
34bf 1d18 34c1 34b3
34b9 0 34c2 0
34bf 0 34c2 1d1a
0 34c3 1d1d 350d
e5 :3 0 15 :3 0
e1 :3 0 34c6 34c7
0 e4 :3 0 34c8
34c9 0 3503 c3
:3 0 c4 :3 0 34cb
34cc 0 c3 :3 0
d3 :3 0 34ce 34cf
0 e6 :2 0 2
:4 0 295 :2 0 d5
:2 0 2a :2 0 1d20
34d4 34d6 :3 0 1d23
34d0 34d8 34cd 34da
34d9 :2 0 c6 :3 0
d6 :3 0 34dc 34dd
0 c8 :4 0 296
:4 0 cb :2 0 cc
:3 0 1d27 34e1 34e3
:3 0 cb :2 0 e9
:4 0 1d2a 34e5 34e7
:3 0 cb :2 0 ea
:4 0 1d2d 34e9 34eb
:3 0 cb :2 0 e4
:3 0 1d30 34ed 34ef
:3 0 cb :2 0 eb
:4 0 1d33 34f1 34f3
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 1d36
34f6 34fa 1d3a 34f5
34fc :3 0 1d3d 34de
34fe :2 0 3500 1d40
3501 34db 3500 0
3502 1d42 0 3503
1d44 3506 :3 0 3506
0 3506 3505 3503
3504 :6 0 3508 a0
:3 0 1d47 350a 1d49
3509 3508 :2 0 350b
1d4b :2 0 350d 0
350d 350c 34c3 350b
:6 0 350f 6f :3 0
1d4d 3511 336c 348b
0 3512 0 350f
0 3512 1d4f 0
3701 84 :3 0 48
:3 0 3d :2 0 1d52
3513 3516 da :2 0
3d :2 0 1d57 3518
351a :3 0 351b :2 0
84 :3 0 47 :3 0
3d :2 0 1d5a 351d
3520 13b :2 0 e2
:2 0 1d5f 3522 3524
:3 0 3525 :2 0 351c
3527 3526 :2 0 44
:3 0 3d :2 0 3529
352a 0 352d 140
:3 0 1d62 3540 84
:3 0 47 :3 0 3d
:2 0 1d64 352e 3531
da :2 0 e2 :2 0
1d69 3533 3535 :3 0
7e :3 0 84 :3 0
44 :3 0 3d :2 0
1d6c 3538 353b 3537
353c 0 353e 1d6f
353f 3536 353e 0
3541 3528 352d 0
3541 1d71 0 3701
6b :3 0 201 :3 0
31 :3 0 32 :3 0
84 :3 0 46 :3 0
3d :2 0 1d74 3546
3549 84 :3 0 47
:3 0 3d :2 0 1d77
354b 354e 84 :3 0
52 :3 0 3d :2 0
1d7a 3550 3553 84
:3 0 4e :3 0 3d
:2 0 1d7d 3555 3558
84 :3 0 48 :3 0
3d :2 0 1d80 355a
355d 84 :3 0 45
:3 0 3d :2 0 1d83
355f 3562 84 :3 0
4f :3 0 3d :2 0
1d86 3564 3567 84
:3 0 50 :3 0 3d
:2 0 1d89 3569 356c
44 :3 0 3f :3 0
49 :3 0 1d8c 3543
3571 3542 3572 0
3701 84 :3 0 6b
:3 0 3d :2 0 1d9a
3574 3577 b0 :3 0
da :2 0 202 :3 0
3579 357b 0 1d9f
357a 357d :3 0 e3
:3 0 96 :4 0 3582
:2 0 3588 3580 0
15 :3 0 e1 :3 0
3583 3584 0 e4
:3 0 3585 3586 0
3588 1da2 35d2 e5
:3 0 15 :3 0 e1
:3 0 358b 358c 0
e4 :3 0 358d 358e
0 35c8 c3 :3 0
c4 :3 0 3590 3591
0 c3 :3 0 d3
:3 0 3593 3594 0
e6 :2 0 2 :4 0
297 :2 0 d5 :2 0
2a :2 0 1da5 3599
359b :3 0 1da8 3595
359d 3592 359f 359e
:2 0 c6 :3 0 d6
:3 0 35a1 35a2 0
c8 :4 0 298 :4 0
cb :2 0 cc :3 0
1dac 35a6 35a8 :3 0
cb :2 0 e9 :4 0
1daf 35aa 35ac :3 0
cb :2 0 ea :4 0
1db2 35ae 35b0 :3 0
cb :2 0 e4 :3 0
1db5 35b2 35b4 :3 0
cb :2 0 eb :4 0
1db8 35b6 35b8 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 1dbb 35bb
35bf 1dbf 35ba 35c1
:3 0 1dc2 35a3 35c3
:2 0 35c5 1dc5 35c6
35a0 35c5 0 35c7
1dc7 0 35c8 1dc9
35cb :3 0 35cb 0
35cb 35ca 35c8 35c9
:6 0 35cd a2 :3 0
1dcc 35cf 1dce 35ce
35cd :2 0 35d0 1dd0
:2 0 35d2 0 35d2
35d1 3588 35d0 :6 0
3631 6f :3 0 c3
:3 0 c4 :3 0 35d4
35d5 0 c3 :3 0
d3 :3 0 35d7 35d8
0 203 :2 0 2
:4 0 299 :2 0 d5
:2 0 2a :2 0 1dd2
35dd 35df :3 0 1dd5
35d9 35e1 35d6 35e3
35e2 :2 0 c6 :3 0
d6 :3 0 35e5 35e6
0 c8 :4 0 29a
:4 0 cb :2 0 cc
:3 0 1dd9 35ea 35ec
:3 0 cb :2 0 e9
:4 0 1ddc 35ee 35f0
:3 0 cb :2 0 f0
:4 0 1ddf 35f2 35f4
:3 0 cb :2 0 84
:3 0 d0 :3 0 b0
:3 0 202 :3 0 35f9
35fa 0 1de2 35f8
35fc d1 :4 0 1de4
35f7 35ff 1de7 35f6
3601 :3 0 1dea 35e7
3603 :2 0 3605 1ded
3606 35e4 3605 0
3607 1def 0 3631
c3 :3 0 c4 :3 0
3608 3609 0 c3
:3 0 d3 :3 0 360b
360c 0 2a :2 0
2 :4 0 29b :2 0
d5 :2 0 2a :2 0
1df1 3611 3613 :3 0
1df4 360d 3615 360a
3617 3616 :2 0 c6
:3 0 d6 :3 0 3619
361a 0 c8 :4 0
29c :4 0 cb :2 0
cc :3 0 1df8 361e
3620 :3 0 1dfb 361b
3622 :2 0 3624 1dfe
3625 3618 3624 0
3626 1e00 0 3631
f5 :3 0 208 :3 0
3627 3628 0 b0
:3 0 202 :3 0 362a
362b 0 f7 :3 0
1e02 3629 362e :2 0
3631 140 :3 0 1e05
36ff 84 :3 0 6b
:3 0 3d :2 0 1e0a
3632 3635 13b :2 0
3d :2 0 1e0f 3637
3639 :3 0 e3 :3 0
96 :4 0 363e :2 0
3644 363c 0 15
:3 0 e1 :3 0 363f
3640 0 e4 :3 0
3641 3642 0 3644
1e12 368e e5 :3 0
15 :3 0 e1 :3 0
3647 3648 0 e4
:3 0 3649 364a 0
3684 c3 :3 0 c4
:3 0 364c 364d 0
c3 :3 0 d3 :3 0
364f 3650 0 e6
:2 0 2 :4 0 29d
:2 0 d5 :2 0 2a
:2 0 1e15 3655 3657
:3 0 1e18 3651 3659
364e 365b 365a :2 0
c6 :3 0 d6 :3 0
365d 365e 0 c8
:4 0 29e :4 0 cb
:2 0 cc :3 0 1e1c
3662 3664 :3 0 cb
:2 0 e9 :4 0 1e1f
3666 3668 :3 0 cb
:2 0 ea :4 0 1e22
366a 366c :3 0 cb
:2 0 e4 :3 0 1e25
366e 3670 :3 0 cb
:2 0 eb :4 0 1e28
3672 3674 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 1e2b 3677 367b
1e2f 3676 367d :3 0
1e32 365f 367f :2 0
3681 1e35 3682 365c
3681 0 3683 1e37
0 3684 1e39 3687
:3 0 3687 0 3687
3686 3684 3685 :6 0
3689 a4 :3 0 1e3c
368b 1e3e 368a 3689
:2 0 368c 1e40 :2 0
368e 0 368e 368d
3644 368c :6 0 36fd
6f :3 0 c3 :3 0
c4 :3 0 3690 3691
0 c3 :3 0 d3
:3 0 3693 3694 0
18 :2 0 2 :4 0
29f :2 0 d5 :2 0
2a :2 0 1e42 3699
369b :3 0 1e45 3695
369d 3692 369f 369e
:2 0 c6 :3 0 d6
:3 0 36a1 36a2 0
c8 :4 0 2a0 :4 0
cb :2 0 cc :3 0
1e49 36a6 36a8 :3 0
cb :2 0 e9 :4 0
1e4c 36aa 36ac :3 0
cb :2 0 f0 :4 0
1e4f 36ae 36b0 :3 0
cb :2 0 84 :3 0
d0 :3 0 6b :3 0
1e52 36b4 36b6 d1
:4 0 1e54 36b3 36b9
1e57 36b2 36bb :3 0
cb :2 0 f2 :4 0
1e5a 36bd 36bf :3 0
cb :2 0 ce :4 0
1e5d 36c1 36c3 :3 0
cb :2 0 22 :3 0
1e60 36c5 36c7 :3 0
cb :2 0 ce :4 0
1e63 36c9 36cb :3 0
1e66 36a3 36cd :2 0
36cf 1e69 36d0 36a0
36cf 0 36d1 1e6b
0 36fd c3 :3 0
c4 :3 0 36d2 36d3
0 c3 :3 0 d3
:3 0 36d5 36d6 0
2a :2 0 2 :4 0
2a1 :2 0 d5 :2 0
2a :2 0 1e6d 36db
36dd :3 0 1e70 36d7
36df 36d4 36e1 36e0
:2 0 c6 :3 0 d6
:3 0 36e3 36e4 0
c8 :4 0 2a2 :4 0
cb :2 0 cc :3 0
1e74 36e8 36ea :3 0
1e77 36e5 36ec :2 0
36ee 1e7a 36ef 36e2
36ee 0 36f0 1e7c
0 36fd f5 :3 0
f6 :3 0 36f1 36f2
0 84 :3 0 6b
:3 0 3d :2 0 1e7e
36f4 36f7 22 :3 0
f7 :3 0 1e81 36f3
36fb :2 0 36fd 1e85
36fe 363a 36fd 0
3700 357e 3631 0
3700 1e8a 0 3701
1e8d 37e3 84 :3 0
49 :3 0 3d :2 0
1e9b 3702 3705 da
:2 0 3d :2 0 1ea0
3707 3709 :3 0 370a
:2 0 84 :3 0 49
:3 0 3d :2 0 1ea3
370c 370f 84 :3 0
168 :2 0 4f :3 0
3d :2 0 1ea6 3711
3715 1eab 3712 3717
:3 0 3718 :2 0 370b
371a 3719 :2 0 49
:3 0 84 :3 0 4f
:3 0 3d :2 0 1eae
371d 3720 371c 3721
0 3723 1eb1 3737
49 :3 0 2a3 :3 0
84 :3 0 49 :3 0
3d :2 0 1eb3 3726
3729 2a4 :2 0 84
:3 0 4f :3 0 3d
:2 0 1eb6 372c 372f
1eb9 372b 3731 :3 0
1ebc 3725 3733 3724
3734 0 3736 1ebe
3738 371b 3723 0
3739 0 3736 0
3739 1ec0 0 37e2
84 :3 0 49 :3 0
3d :2 0 1ec3 373a
373d 168 :2 0 2a5
:2 0 1ec8 373f 3741
:3 0 49 :3 0 84
:3 0 49 :3 0 3d
:2 0 1ecb 3744 3747
1d2 :2 0 3b :2 0
1ece 3749 374b :3 0
3743 374c 0 374e
1ed1 375e 49 :3 0
2a3 :3 0 84 :3 0
49 :3 0 3d :2 0
1ed3 3751 3754 1d2
:2 0 2a6 :2 0 1ed6
3756 3758 :3 0 1ed9
3750 375a 374f 375b
0 375d 1edb 375f
3742 374e 0 3760
0 375d 0 3760
1edd 0 37e2 90
:3 0 92 :3 0 21
:3 0 93 :3 0 94
:3 0 4c :3 0 1e
:3 0 a7 :3 0 62
:3 0 58 :3 0 a7
:3 0 1d3 :3 0 62
:3 0 5c :3 0 1d3
:3 0 a8 :3 0 61
:3 0 5b :3 0 a8
:3 0 1d4 :3 0 61
:3 0 5d :3 0 1d4
:3 0 1d7 :3 0 199
:3 0 19a :3 0 1d7
:3 0 b0 :3 0 1d8
:3 0 9a :3 0 1d
:4 0 2a7 1 :8 0
3796 e0 :4 0 3781
:3 0 f7 :3 0 da
:2 0 1ee2 3784 3785
:3 0 15 :3 0 e1
:3 0 3787 3788 0
3d :2 0 3789 378a
0 378c 1ee5 3793
15 :3 0 e1 :3 0
378d 378e 0 e2
:2 0 378f 3790 0
3792 1ee7 3794 3786
378c 0 3795 0
3792 0 3795 1ee9
0 3796 1eec 37e0
e5 :3 0 15 :3 0
e1 :3 0 3799 379a
0 e4 :3 0 379b
379c 0 37d6 c3
:3 0 c4 :3 0 379e
379f 0 c3 :3 0
d3 :3 0 37a1 37a2
0 e6 :2 0 2
:4 0 2a8 :2 0 d5
:2 0 2a :2 0 1eef
37a7 37a9 :3 0 1ef2
37a3 37ab 37a0 37ad
37ac :2 0 c6 :3 0
d6 :3 0 37af 37b0
0 c8 :4 0 2a9
:4 0 cb :2 0 cc
:3 0 1ef6 37b4 37b6
:3 0 cb :2 0 e9
:4 0 1ef9 37b8 37ba
:3 0 cb :2 0 ea
:4 0 1efc 37bc 37be
:3 0 cb :2 0 e4
:3 0 1eff 37c0 37c2
:3 0 cb :2 0 eb
:4 0 1f02 37c4 37c6
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 1f05
37c9 37cd 1f09 37c8
37cf :3 0 1f0c 37b1
37d1 :2 0 37d3 1f0f
37d4 37ae 37d3 0
37d5 1f11 0 37d6
1f13 37d9 :3 0 37d9
0 37d9 37d8 37d6
37d7 :6 0 37db a6
:3 0 1f16 37dd 1f18
37dc 37db :2 0 37de
1f1a :2 0 37e0 0
37e0 37df 3796 37de
:6 0 37e2 6f :3 0
1f1c 37e4 331e 3701
0 37e5 0 37e2
0 37e5 1f20 0
3e53 4a :3 0 3d
:2 0 37e6 37e7 0
3e53 51 :3 0 2a
:2 0 37e9 37ea 0
3e53 40 :3 0 3d
:2 0 37ec 37ed 0
3e53 84 :3 0 44
:3 0 3d :2 0 1f23
37ef 37f2 da :2 0
3d :2 0 1f28 37f4
37f6 :3 0 4e :3 0
b0 :3 0 20d :3 0
37f9 37fa 0 37f8
37fb 0 37fe 140
:3 0 1f2b 3828 14f
:3 0 84 :3 0 42
:3 0 3d :2 0 1f2d
3800 3803 1f30 37ff
3805 13b :2 0 3d
:2 0 1f34 3807 3809
:3 0 4e :3 0 1ff
:3 0 19a :3 0 380c
380d 0 2a :2 0
b0 :3 0 20d :3 0
3810 3811 0 1f37
380e 3813 380b 3814
0 3816 1f3a 3817
380a 3816 0 382a
4e :3 0 1ff :3 0
19a :3 0 3819 381a
0 84 :3 0 4e
:3 0 3d :2 0 1f3c
381c 381f b0 :3 0
20d :3 0 3821 3822
0 1f3f 381b 3824
3818 3825 0 3827
1f42 3829 37f7 37fe
0 382a 0 3827
0 382a 1f44 0
3e53 45 :3 0 3d
:2 0 382b 382c 0
3e53 6a :3 0 5a
:2 0 382e 382f 0
3e53 66 :3 0 20e
:3 0 1d :3 0 22
:3 0 20 :3 0 21
:3 0 6a :3 0 41
:3 0 29 :3 0 29
:3 0 29 :3 0 29
:3 0 24 :3 0 26
:3 0 49 :3 0 3f
:3 0 44 :3 0 46
:3 0 47 :3 0 40
:3 0 52 :3 0 2e
:3 0 4a :3 0 4e
:3 0 48 :3 0 45
:3 0 51 :3 0 4f
:3 0 53 :3 0 1a
:3 0 3d :2 0 3d
:2 0 5a :2 0 5a
:2 0 1f48 3832 3853
3831 3854 0 3e53
84 :3 0 66 :3 0
3d :2 0 1f69 3856
3859 da :2 0 20f
:2 0 1f6e 385b 385d
:3 0 e3 :3 0 96
:4 0 3862 :2 0 3868
3860 0 15 :3 0
e1 :3 0 3863 3864
0 e4 :3 0 3865
3866 0 3868 1f71
38b2 e5 :3 0 15
:3 0 e1 :3 0 386b
386c 0 e4 :3 0
386d 386e 0 38a8
c3 :3 0 c4 :3 0
3870 3871 0 c3
:3 0 d3 :3 0 3873
3874 0 e6 :2 0
2 :4 0 2aa :2 0
d5 :2 0 2a :2 0
1f74 3879 387b :3 0
1f77 3875 387d 3872
387f 387e :2 0 c6
:3 0 d6 :3 0 3881
3882 0 c8 :4 0
2ab :4 0 cb :2 0
cc :3 0 1f7b 3886
3888 :3 0 cb :2 0
e9 :4 0 1f7e 388a
388c :3 0 cb :2 0
ea :4 0 1f81 388e
3890 :3 0 cb :2 0
e4 :3 0 1f84 3892
3894 :3 0 cb :2 0
eb :4 0 1f87 3896
3898 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
1f8a 389b 389f 1f8e
389a 38a1 :3 0 1f91
3883 38a3 :2 0 38a5
1f94 38a6 3880 38a5
0 38a7 1f96 0
38a8 1f98 38ab :3 0
38ab 0 38ab 38aa
38a8 38a9 :6 0 38ad
a8 :3 0 1f9b 38af
1f9d 38ae 38ad :2 0
38b0 1f9f :2 0 38b2
0 38b2 38b1 3868
38b0 :6 0 3922 6f
:3 0 c3 :3 0 c4
:3 0 38b4 38b5 0
c3 :3 0 d3 :3 0
38b7 38b8 0 18
:2 0 2 :4 0 2ac
:2 0 d5 :2 0 2a
:2 0 1fa1 38bd 38bf
:3 0 1fa4 38b9 38c1
38b6 38c3 38c2 :2 0
c6 :3 0 d6 :3 0
38c5 38c6 0 c8
:4 0 2ad :4 0 cb
:2 0 cc :3 0 1fa8
38ca 38cc :3 0 cb
:2 0 e9 :4 0 1fab
38ce 38d0 :3 0 cb
:2 0 f0 :4 0 1fae
38d2 38d4 :3 0 cb
:2 0 84 :3 0 d0
:3 0 b0 :3 0 212
:3 0 38d9 38da 0
1fb1 38d8 38dc d1
:4 0 1fb3 38d7 38df
1fb6 38d6 38e1 :3 0
cb :2 0 f2 :4 0
1fb9 38e3 38e5 :3 0
cb :2 0 ce :4 0
1fbc 38e7 38e9 :3 0
cb :2 0 21 :3 0
1fbf 38eb 38ed :3 0
cb :2 0 ce :4 0
1fc2 38ef 38f1 :3 0
1fc5 38c7 38f3 :2 0
38f5 1fc8 38f6 38c4
38f5 0 38f7 1fca
0 3922 c3 :3 0
c4 :3 0 38f8 38f9
0 c3 :3 0 d3
:3 0 38fb 38fc 0
2a :2 0 2 :4 0
2ae :2 0 d5 :2 0
2a :2 0 1fcc 3901
3903 :3 0 1fcf 38fd
3905 38fa 3907 3906
:2 0 c6 :3 0 d6
:3 0 3909 390a 0
c8 :4 0 2af :4 0
cb :2 0 cc :3 0
1fd3 390e 3910 :3 0
1fd6 390b 3912 :2 0
3914 1fd9 3915 3908
3914 0 3916 1fdb
0 3922 f5 :3 0
f6 :3 0 3917 3918
0 b0 :3 0 212
:3 0 391a 391b 0
21 :3 0 f7 :3 0
1fdd 3919 391f :2 0
3922 140 :3 0 1fe1
39f0 84 :3 0 66
:3 0 3d :2 0 1fe6
3923 3926 13b :2 0
3d :2 0 1feb 3928
392a :3 0 e3 :3 0
96 :4 0 392f :2 0
3935 392d 0 15
:3 0 e1 :3 0 3930
3931 0 e4 :3 0
3932 3933 0 3935
1fee 397f e5 :3 0
15 :3 0 e1 :3 0
3938 3939 0 e4
:3 0 393a 393b 0
3975 c3 :3 0 c4
:3 0 393d 393e 0
c3 :3 0 d3 :3 0
3940 3941 0 e6
:2 0 2 :4 0 2b0
:2 0 d5 :2 0 2a
:2 0 1ff1 3946 3948
:3 0 1ff4 3942 394a
393f 394c 394b :2 0
c6 :3 0 d6 :3 0
394e 394f 0 c8
:4 0 2b1 :4 0 cb
:2 0 cc :3 0 1ff8
3953 3955 :3 0 cb
:2 0 e9 :4 0 1ffb
3957 3959 :3 0 cb
:2 0 ea :4 0 1ffe
395b 395d :3 0 cb
:2 0 e4 :3 0 2001
395f 3961 :3 0 cb
:2 0 eb :4 0 2004
3963 3965 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 2007 3968 396c
200b 3967 396e :3 0
200e 3950 3970 :2 0
3972 2011 3973 394d
3972 0 3974 2013
0 3975 2015 3978
:3 0 3978 0 3978
3977 3975 3976 :6 0
397a aa :3 0 2018
397c 201a 397b 397a
:2 0 397d 201c :2 0
397f 0 397f 397e
3935 397d :6 0 39ee
6f :3 0 c3 :3 0
c4 :3 0 3981 3982
0 c3 :3 0 d3
:3 0 3984 3985 0
18 :2 0 2 :4 0
2b2 :2 0 d5 :2 0
2a :2 0 201e 398a
398c :3 0 2021 3986
398e 3983 3990 398f
:2 0 c6 :3 0 d6
:3 0 3992 3993 0
c8 :4 0 2b3 :4 0
cb :2 0 cc :3 0
2025 3997 3999 :3 0
cb :2 0 e9 :4 0
2028 399b 399d :3 0
cb :2 0 f0 :4 0
202b 399f 39a1 :3 0
cb :2 0 84 :3 0
d0 :3 0 b0 :3 0
1ba :3 0 39a6 39a7
0 202e 39a5 39a9
d1 :4 0 2030 39a4
39ac 2033 39a3 39ae
:3 0 cb :2 0 f2
:4 0 2036 39b0 39b2
:3 0 cb :2 0 ce
:4 0 2039 39b4 39b6
:3 0 cb :2 0 1c
:3 0 203c 39b8 39ba
:3 0 cb :2 0 ce
:4 0 203f 39bc 39be
:3 0 2042 3994 39c0
:2 0 39c2 2045 39c3
3991 39c2 0 39c4
2047 0 39ee c3
:3 0 c4 :3 0 39c5
39c6 0 c3 :3 0
d3 :3 0 39c8 39c9
0 2a :2 0 2
:4 0 2b4 :2 0 d5
:2 0 2a :2 0 2049
39ce 39d0 :3 0 204c
39ca 39d2 39c7 39d4
39d3 :2 0 c6 :3 0
d6 :3 0 39d6 39d7
0 c8 :4 0 2b5
:4 0 cb :2 0 cc
:3 0 2050 39db 39dd
:3 0 2053 39d8 39df
:2 0 39e1 2056 39e2
39d5 39e1 0 39e3
2058 0 39ee f5
:3 0 f6 :3 0 39e4
39e5 0 b0 :3 0
1ba :3 0 39e7 39e8
0 1c :3 0 f7
:3 0 205a 39e6 39ec
:2 0 39ee 205e 39ef
392b 39ee 0 39f1
385e 3922 0 39f1
2063 0 3e53 ae
:3 0 185 :3 0 186
:3 0 185 :3 0 39
:3 0 8b :3 0 20
:4 0 2b6 1 :8 0
3a0f e0 :4 0 39fa
:3 0 f7 :3 0 da
:2 0 2068 39fd 39fe
:3 0 15 :3 0 e1
:3 0 3a00 3a01 0
3d :2 0 3a02 3a03
0 3a05 206b 3a0c
15 :3 0 e1 :3 0
3a06 3a07 0 e2
:2 0 3a08 3a09 0
3a0b 206d 3a0d 39ff
3a05 0 3a0e 0
3a0b 0 3a0e 206f
0 3a0f 2072 3a59
e5 :3 0 15 :3 0
e1 :3 0 3a12 3a13
0 e4 :3 0 3a14
3a15 0 3a4f c3
:3 0 c4 :3 0 3a17
3a18 0 c3 :3 0
d3 :3 0 3a1a 3a1b
0 e6 :2 0 2
:4 0 2b7 :2 0 d5
:2 0 2a :2 0 2075
3a20 3a22 :3 0 2078
3a1c 3a24 3a19 3a26
3a25 :2 0 c6 :3 0
d6 :3 0 3a28 3a29
0 c8 :4 0 2b8
:4 0 cb :2 0 cc
:3 0 207c 3a2d 3a2f
:3 0 cb :2 0 e9
:4 0 207f 3a31 3a33
:3 0 cb :2 0 ea
:4 0 2082 3a35 3a37
:3 0 cb :2 0 e4
:3 0 2085 3a39 3a3b
:3 0 cb :2 0 eb
:4 0 2088 3a3d 3a3f
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 208b
3a42 3a46 208f 3a41
3a48 :3 0 2092 3a2a
3a4a :2 0 3a4c 2095
3a4d 3a27 3a4c 0
3a4e 2097 0 3a4f
2099 3a52 :3 0 3a52
0 3a52 3a51 3a4f
3a50 :6 0 3a54 ac
:3 0 209c 3a56 209e
3a55 3a54 :2 0 3a57
20a0 :2 0 3a59 0
3a59 3a58 3a0f 3a57
:6 0 3e53 6f :3 0
251 :3 0 1d :3 0
2b9 :3 0 8b :3 0
2b9 :3 0 1f0 :3 0
2b9 :3 0 1f1 :3 0
2b9 :3 0 1f2 :3 0
2b9 :3 0 1f3 :3 0
2ba :3 0 2b9 :3 0
11a :3 0 12e :3 0
2bb :3 0 2b9 :3 0
8b :3 0 2bb :3 0
12d :3 0 2bb :3 0
12f :3 0 23 :4 0
2bc 1 :8 0 3a89
e0 :4 0 3a74 :3 0
f7 :3 0 da :2 0
20a4 3a77 3a78 :3 0
15 :3 0 e1 :3 0
3a7a 3a7b 0 3d
:2 0 3a7c 3a7d 0
3a7f 20a7 3a86 15
:3 0 e1 :3 0 3a80
3a81 0 e2 :2 0
3a82 3a83 0 3a85
20a9 3a87 3a79 3a7f
0 3a88 0 3a85
0 3a88 20ab 0
3a89 20ae 3ad3 e5
:3 0 15 :3 0 e1
:3 0 3a8c 3a8d 0
e4 :3 0 3a8e 3a8f
0 3ac9 c3 :3 0
c4 :3 0 3a91 3a92
0 c3 :3 0 d3
:3 0 3a94 3a95 0
e6 :2 0 2 :4 0
2bd :2 0 d5 :2 0
2a :2 0 20b1 3a9a
3a9c :3 0 20b4 3a96
3a9e 3a93 3aa0 3a9f
:2 0 c6 :3 0 d6
:3 0 3aa2 3aa3 0
c8 :4 0 2be :4 0
cb :2 0 cc :3 0
20b8 3aa7 3aa9 :3 0
cb :2 0 e9 :4 0
20bb 3aab 3aad :3 0
cb :2 0 ea :4 0
20be 3aaf 3ab1 :3 0
cb :2 0 e4 :3 0
20c1 3ab3 3ab5 :3 0
cb :2 0 eb :4 0
20c4 3ab7 3ab9 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 20c7 3abc
3ac0 20cb 3abb 3ac2
:3 0 20ce 3aa4 3ac4
:2 0 3ac6 20d1 3ac7
3aa1 3ac6 0 3ac8
20d3 0 3ac9 20d5
3acc :3 0 3acc 0
3acc 3acb 3ac9 3aca
:6 0 3ace ae :3 0
20d8 3ad0 20da 3acf
3ace :2 0 3ad1 20dc
:2 0 3ad3 0 3ad3
3ad2 3a89 3ad1 :6 0
3e53 6f :3 0 251
:3 0 1d :3 0 12d
:3 0 1f0 :3 0 1f1
:3 0 1f2 :3 0 1f3
:3 0 2bf :3 0 251
:3 0 98 :3 0 23
:4 0 2c0 1 :8 0
3af6 e0 :4 0 3ae1
:3 0 f7 :3 0 da
:2 0 20e0 3ae4 3ae5
:3 0 15 :3 0 e1
:3 0 3ae7 3ae8 0
3d :2 0 3ae9 3aea
0 3aec 20e3 3af3
15 :3 0 e1 :3 0
3aed 3aee 0 e2
:2 0 3aef 3af0 0
3af2 20e5 3af4 3ae6
3aec 0 3af5 0
3af2 0 3af5 20e7
0 3af6 20ea 3b40
e5 :3 0 15 :3 0
e1 :3 0 3af9 3afa
0 e4 :3 0 3afb
3afc 0 3b36 c3
:3 0 c4 :3 0 3afe
3aff 0 c3 :3 0
d3 :3 0 3b01 3b02
0 e6 :2 0 2
:4 0 2c1 :2 0 d5
:2 0 2a :2 0 20ed
3b07 3b09 :3 0 20f0
3b03 3b0b 3b00 3b0d
3b0c :2 0 c6 :3 0
d6 :3 0 3b0f 3b10
0 c8 :4 0 2c2
:4 0 cb :2 0 cc
:3 0 20f4 3b14 3b16
:3 0 cb :2 0 e9
:4 0 20f7 3b18 3b1a
:3 0 cb :2 0 ea
:4 0 20fa 3b1c 3b1e
:3 0 cb :2 0 e4
:3 0 20fd 3b20 3b22
:3 0 cb :2 0 eb
:4 0 2100 3b24 3b26
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 2103
3b29 3b2d 2107 3b28
3b2f :3 0 210a 3b11
3b31 :2 0 3b33 210d
3b34 3b0e 3b33 0
3b35 210f 0 3b36
2111 3b39 :3 0 3b39
0 3b39 3b38 3b36
3b37 :6 0 3b3b b0
:3 0 2114 3b3d 2116
3b3c 3b3b :2 0 3b3e
2118 :2 0 3b40 0
3b40 3b3f 3af6 3b3e
:6 0 3e53 6f :3 0
1ee :3 0 1d :3 0
1ef :3 0 1f0 :3 0
1f1 :3 0 1f2 :3 0
1f3 :3 0 1f4 :3 0
1ee :3 0 98 :3 0
23 :4 0 2c3 1
:8 0 3b63 e0 :4 0
3b4e :3 0 f7 :3 0
da :2 0 211c 3b51
3b52 :3 0 15 :3 0
e1 :3 0 3b54 3b55
0 3d :2 0 3b56
3b57 0 3b59 211f
3b60 15 :3 0 e1
:3 0 3b5a 3b5b 0
e2 :2 0 3b5c 3b5d
0 3b5f 2121 3b61
3b53 3b59 0 3b62
0 3b5f 0 3b62
2123 0 3b63 2126
3bad e5 :3 0 15
:3 0 e1 :3 0 3b66
3b67 0 e4 :3 0
3b68 3b69 0 3ba3
c3 :3 0 c4 :3 0
3b6b 3b6c 0 c3
:3 0 d3 :3 0 3b6e
3b6f 0 e6 :2 0
2 :4 0 2c4 :2 0
d5 :2 0 2a :2 0
2129 3b74 3b76 :3 0
212c 3b70 3b78 3b6d
3b7a 3b79 :2 0 c6
:3 0 d6 :3 0 3b7c
3b7d 0 c8 :4 0
2c5 :4 0 cb :2 0
cc :3 0 2130 3b81
3b83 :3 0 cb :2 0
e9 :4 0 2133 3b85
3b87 :3 0 cb :2 0
ea :4 0 2136 3b89
3b8b :3 0 cb :2 0
e4 :3 0 2139 3b8d
3b8f :3 0 cb :2 0
eb :4 0 213c 3b91
3b93 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
213f 3b96 3b9a 2143
3b95 3b9c :3 0 2146
3b7e 3b9e :2 0 3ba0
2149 3ba1 3b7b 3ba0
0 3ba2 214b 0
3ba3 214d 3ba6 :3 0
3ba6 0 3ba6 3ba5
3ba3 3ba4 :6 0 3ba8
b2 :3 0 2150 3baa
2152 3ba9 3ba8 :2 0
3bab 2154 :2 0 3bad
0 3bad 3bac 3b63
3bab :6 0 3e53 6f
:3 0 4b :3 0 84
:3 0 4b :3 0 3d
:2 0 2156 3bb0 3bb3
d5 :2 0 2a :2 0
2159 3bb5 3bb7 :3 0
3baf 3bb8 0 3e53
43 :3 0 84 :3 0
43 :3 0 3d :2 0
215c 3bbb 3bbe d5
:2 0 84 :3 0 3f
:3 0 3d :2 0 215f
3bc1 3bc4 2162 3bc0
3bc6 :3 0 3bba 3bc7
0 3e53 6c :3 0
2a :4 0 3bc9 3bca
0 3e53 71 :3 0
2c6 :3 0 22 :3 0
23 :3 0 6c :3 0
2165 3bcd 3bd1 3bcc
3bd2 0 3e53 6c
:3 0 3d :4 0 3bd4
3bd5 0 3e53 71
:3 0 2c6 :3 0 22
:3 0 21 :3 0 6c
:3 0 2169 3bd8 3bdc
3bd7 3bdd 0 3e53
24a :3 0 92 :3 0
21 :3 0 91 :3 0
22 :3 0 9a :3 0
1d :4 0 2c7 1
:8 0 3bfc e0 :4 0
3be7 :3 0 f7 :3 0
da :2 0 216f 3bea
3beb :3 0 15 :3 0
e1 :3 0 3bed 3bee
0 3d :2 0 3bef
3bf0 0 3bf2 2172
3bf9 15 :3 0 e1
:3 0 3bf3 3bf4 0
e2 :2 0 3bf5 3bf6
0 3bf8 2174 3bfa
3bec 3bf2 0 3bfb
0 3bf8 0 3bfb
2176 0 3bfc 2179
3c46 e5 :3 0 15
:3 0 e1 :3 0 3bff
3c00 0 e4 :3 0
3c01 3c02 0 3c3c
c3 :3 0 c4 :3 0
3c04 3c05 0 c3
:3 0 d3 :3 0 3c07
3c08 0 e6 :2 0
2 :4 0 2c8 :2 0
d5 :2 0 2a :2 0
217c 3c0d 3c0f :3 0
217f 3c09 3c11 3c06
3c13 3c12 :2 0 c6
:3 0 d6 :3 0 3c15
3c16 0 c8 :4 0
2c9 :4 0 cb :2 0
cc :3 0 2183 3c1a
3c1c :3 0 cb :2 0
e9 :4 0 2186 3c1e
3c20 :3 0 cb :2 0
ea :4 0 2189 3c22
3c24 :3 0 cb :2 0
e4 :3 0 218c 3c26
3c28 :3 0 cb :2 0
eb :4 0 218f 3c2a
3c2c :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
2192 3c2f 3c33 2196
3c2e 3c35 :3 0 2199
3c17 3c37 :2 0 3c39
219c 3c3a 3c14 3c39
0 3c3b 219e 0
3c3c 21a0 3c3f :3 0
3c3f 0 3c3f 3c3e
3c3c 3c3d :6 0 3c41
b4 :3 0 21a3 3c43
21a5 3c42 3c41 :2 0
3c44 21a7 :2 0 3c46
0 3c46 3c45 3bfc
3c44 :6 0 3e53 6f
:3 0 84 :3 0 62
:3 0 3d :2 0 21a9
3c48 3c4b da :2 0
3d :2 0 21ae 3c4d
3c4f :3 0 3c50 :2 0
84 :3 0 61 :3 0
3d :2 0 21b1 3c52
3c55 da :2 0 3d
:2 0 21b6 3c57 3c59
:3 0 3c5a :2 0 3c51
3c5c 3c5b :2 0 2ca
:3 0 92 :3 0 21
:3 0 2cb :3 0 58
:3 0 2cc :3 0 5c
:3 0 2cd :3 0 5b
:3 0 2ce :3 0 5d
:3 0 179 :3 0 1a
:3 0 17a :3 0 cc
:3 0 9a :3 0 17
:4 0 2cf 1 :8 0
3c85 e0 :4 0 3c70
:3 0 f7 :3 0 da
:2 0 21bb 3c73 3c74
:3 0 15 :3 0 e1
:3 0 3c76 3c77 0
3d :2 0 3c78 3c79
0 3c7b 21be 3c82
15 :3 0 e1 :3 0
3c7c 3c7d 0 e2
:2 0 3c7e 3c7f 0
3c81 21c0 3c83 3c75
3c7b 0 3c84 0
3c81 0 3c84 21c2
0 3c85 21c5 3ccf
e5 :3 0 15 :3 0
e1 :3 0 3c88 3c89
0 e4 :3 0 3c8a
3c8b 0 3cc5 c3
:3 0 c4 :3 0 3c8d
3c8e 0 c3 :3 0
d3 :3 0 3c90 3c91
0 e6 :2 0 2
:4 0 2d0 :2 0 d5
:2 0 2a :2 0 21c8
3c96 3c98 :3 0 21cb
3c92 3c9a 3c8f 3c9c
3c9b :2 0 c6 :3 0
d6 :3 0 3c9e 3c9f
0 c8 :4 0 2d1
:4 0 cb :2 0 cc
:3 0 21cf 3ca3 3ca5
:3 0 cb :2 0 e9
:4 0 21d2 3ca7 3ca9
:3 0 cb :2 0 ea
:4 0 21d5 3cab 3cad
:3 0 cb :2 0 e4
:3 0 21d8 3caf 3cb1
:3 0 cb :2 0 eb
:4 0 21db 3cb3 3cb5
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 21de
3cb8 3cbc 21e2 3cb7
3cbe :3 0 21e5 3ca0
3cc0 :2 0 3cc2 21e8
3cc3 3c9d 3cc2 0
3cc4 21ea 0 3cc5
21ec 3cc8 :3 0 3cc8
0 3cc8 3cc7 3cc5
3cc6 :6 0 3cca b6
:3 0 21ef 3ccc 21f1
3ccb 3cca :2 0 3ccd
21f3 :2 0 3ccf 0
3ccf 3cce 3c85 3ccd
:6 0 3cd2 6f :3 0
140 :3 0 21f5 3e50
84 :3 0 62 :3 0
3d :2 0 21f7 3cd3
3cd6 da :2 0 3d
:2 0 21fc 3cd8 3cda
:3 0 2ca :3 0 92
:3 0 21 :3 0 2cb
:3 0 58 :3 0 2cc
:3 0 5c :3 0 179
:3 0 1a :3 0 17a
:3 0 cc :3 0 9a
:3 0 17 :4 0 2d2
1 :8 0 3cff e0
:4 0 3cea :3 0 f7
:3 0 da :2 0 2201
3ced 3cee :3 0 15
:3 0 e1 :3 0 3cf0
3cf1 0 3d :2 0
3cf2 3cf3 0 3cf5
2204 3cfc 15 :3 0
e1 :3 0 3cf6 3cf7
0 e2 :2 0 3cf8
3cf9 0 3cfb 2206
3cfd 3cef 3cf5 0
3cfe 0 3cfb 0
3cfe 2208 0 3cff
220b 3d49 e5 :3 0
15 :3 0 e1 :3 0
3d02 3d03 0 e4
:3 0 3d04 3d05 0
3d3f c3 :3 0 c4
:3 0 3d07 3d08 0
c3 :3 0 d3 :3 0
3d0a 3d0b 0 e6
:2 0 2 :4 0 2d3
:2 0 d5 :2 0 2a
:2 0 220e 3d10 3d12
:3 0 2211 3d0c 3d14
3d09 3d16 3d15 :2 0
c6 :3 0 d6 :3 0
3d18 3d19 0 c8
:4 0 2d4 :4 0 cb
:2 0 cc :3 0 2215
3d1d 3d1f :3 0 cb
:2 0 e9 :4 0 2218
3d21 3d23 :3 0 cb
:2 0 ea :4 0 221b
3d25 3d27 :3 0 cb
:2 0 e4 :3 0 221e
3d29 3d2b :3 0 cb
:2 0 eb :4 0 2221
3d2d 3d2f :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 2224 3d32 3d36
2228 3d31 3d38 :3 0
222b 3d1a 3d3a :2 0
3d3c 222e 3d3d 3d17
3d3c 0 3d3e 2230
0 3d3f 2232 3d42
:3 0 3d42 0 3d42
3d41 3d3f 3d40 :6 0
3d44 b8 :3 0 2235
3d46 2237 3d45 3d44
:2 0 3d47 2239 :2 0
3d49 0 3d49 3d48
3cff 3d47 :6 0 3d53
6f :3 0 5b :3 0
84 :3 0 75 :3 0
3d :2 0 223b 3d4c
3d4f 3d4b 3d50 0
3d53 140 :3 0 223e
3d54 3cdb 3d53 0
3e52 84 :3 0 61
:3 0 3d :2 0 2241
3d55 3d58 da :2 0
3d :2 0 2246 3d5a
3d5c :3 0 2ca :3 0
92 :3 0 21 :3 0
2cd :3 0 5b :3 0
2ce :3 0 5d :3 0
179 :3 0 1a :3 0
17a :3 0 cc :3 0
9a :3 0 17 :4 0
2d5 1 :8 0 3d81
e0 :4 0 3d6c :3 0
f7 :3 0 da :2 0
224b 3d6f 3d70 :3 0
15 :3 0 e1 :3 0
3d72 3d73 0 3d
:2 0 3d74 3d75 0
3d77 224e 3d7e 15
:3 0 e1 :3 0 3d78
3d79 0 e2 :2 0
3d7a 3d7b 0 3d7d
2250 3d7f 3d71 3d77
0 3d80 0 3d7d
0 3d80 2252 0
3d81 2255 3dcb e5
:3 0 15 :3 0 e1
:3 0 3d84 3d85 0
e4 :3 0 3d86 3d87
0 3dc1 c3 :3 0
c4 :3 0 3d89 3d8a
0 c3 :3 0 d3
:3 0 3d8c 3d8d 0
e6 :2 0 2 :4 0
2d6 :2 0 d5 :2 0
2a :2 0 2258 3d92
3d94 :3 0 225b 3d8e
3d96 3d8b 3d98 3d97
:2 0 c6 :3 0 d6
:3 0 3d9a 3d9b 0
c8 :4 0 2d7 :4 0
cb :2 0 cc :3 0
225f 3d9f 3da1 :3 0
cb :2 0 e9 :4 0
2262 3da3 3da5 :3 0
cb :2 0 ea :4 0
2265 3da7 3da9 :3 0
cb :2 0 e4 :3 0
2268 3dab 3dad :3 0
cb :2 0 eb :4 0
226b 3daf 3db1 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 226e 3db4
3db8 2272 3db3 3dba
:3 0 2275 3d9c 3dbc
:2 0 3dbe 2278 3dbf
3d99 3dbe 0 3dc0
227a 0 3dc1 227c
3dc4 :3 0 3dc4 0
3dc4 3dc3 3dc1 3dc2
:6 0 3dc6 ba :3 0
227f 3dc8 2281 3dc7
3dc6 :2 0 3dc9 2283
:2 0 3dcb 0 3dcb
3dca 3d81 3dc9 :6 0
3dd4 6f :3 0 58
:3 0 84 :3 0 74
:3 0 3d :2 0 2285
3dce 3dd1 3dcd 3dd2
0 3dd4 2288 3dd5
3d5d 3dd4 0 3e52
2ca :3 0 92 :3 0
21 :3 0 179 :3 0
1a :3 0 17a :3 0
cc :3 0 9a :3 0
17 :4 0 2d8 1
:8 0 3df5 e0 :4 0
3de0 :3 0 f7 :3 0
da :2 0 228d 3de3
3de4 :3 0 15 :3 0
e1 :3 0 3de6 3de7
0 3d :2 0 3de8
3de9 0 3deb 2290
3df2 15 :3 0 e1
:3 0 3dec 3ded 0
e2 :2 0 3dee 3def
0 3df1 2292 3df3
3de5 3deb 0 3df4
0 3df1 0 3df4
2294 0 3df5 2297
3e3f e5 :3 0 15
:3 0 e1 :3 0 3df8
3df9 0 e4 :3 0
3dfa 3dfb 0 3e35
c3 :3 0 c4 :3 0
3dfd 3dfe 0 c3
:3 0 d3 :3 0 3e00
3e01 0 e6 :2 0
2 :4 0 2d9 :2 0
d5 :2 0 2a :2 0
229a 3e06 3e08 :3 0
229d 3e02 3e0a 3dff
3e0c 3e0b :2 0 c6
:3 0 d6 :3 0 3e0e
3e0f 0 c8 :4 0
2da :4 0 cb :2 0
cc :3 0 22a1 3e13
3e15 :3 0 cb :2 0
e9 :4 0 22a4 3e17
3e19 :3 0 cb :2 0
ea :4 0 22a7 3e1b
3e1d :3 0 cb :2 0
e4 :3 0 22aa 3e1f
3e21 :3 0 cb :2 0
eb :4 0 22ad 3e23
3e25 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
22b0 3e28 3e2c 22b4
3e27 3e2e :3 0 22b7
3e10 3e30 :2 0 3e32
22ba 3e33 3e0d 3e32
0 3e34 22bc 0
3e35 22be 3e38 :3 0
3e38 0 3e38 3e37
3e35 3e36 :6 0 3e3a
bc :3 0 22c1 3e3c
22c3 3e3b 3e3a :2 0
3e3d 22c5 :2 0 3e3f
0 3e3f 3e3e 3df5
3e3d :6 0 3e4f 6f
:3 0 58 :3 0 84
:3 0 74 :3 0 3d
:2 0 22c7 3e42 3e45
3e41 3e46 0 3e4f
5b :3 0 84 :3 0
75 :3 0 3d :2 0
22ca 3e49 3e4c 3e48
3e4d 0 3e4f 22cd
3e51 3c5d 3cd2 0
3e52 0 3e4f 0
3e52 22d1 0 3e53
22d6 3e54 30bb 3e53
0 3e55 22f1 0
3e56 22f3 3e57 2b7a
3e56 0 3e58 22f8
0 3e59 22fa 3e5b
28ac 2b14 0 3e5c
0 3e59 0 3e5c
22fd 0 3e67 15
:3 0 e1 :3 0 3e5d
3e5e 0 2db :3 0
22 :3 0 23 :3 0
1a :3 0 2300 3e60
3e64 3e5f 3e65 0
3e67 2304 3e69 241
:4 0 3e67 :4 0 4a3e
e3 :3 0 96 :4 0
3e6d :2 0 3e73 3e6b
0 15 :3 0 e1
:3 0 3e6e 3e6f 0
e4 :3 0 3e70 3e71
0 3e73 230a 3ebd
e5 :3 0 15 :3 0
e1 :3 0 3e76 3e77
0 e4 :3 0 3e78
3e79 0 3eb3 c3
:3 0 c4 :3 0 3e7b
3e7c 0 c3 :3 0
d3 :3 0 3e7e 3e7f
0 e6 :2 0 2
:4 0 2dc :2 0 d5
:2 0 2a :2 0 230d
3e84 3e86 :3 0 2310
3e80 3e88 3e7d 3e8a
3e89 :2 0 c6 :3 0
d6 :3 0 3e8c 3e8d
0 c8 :4 0 2dd
:4 0 cb :2 0 cc
:3 0 2314 3e91 3e93
:3 0 cb :2 0 e9
:4 0 2317 3e95 3e97
:3 0 cb :2 0 ea
:4 0 231a 3e99 3e9b
:3 0 cb :2 0 e4
:3 0 231d 3e9d 3e9f
:3 0 cb :2 0 eb
:4 0 2320 3ea1 3ea3
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 2323
3ea6 3eaa 2327 3ea5
3eac :3 0 232a 3e8e
3eae :2 0 3eb0 232d
3eb1 3e8b 3eb0 0
3eb2 232f 0 3eb3
2331 3eb6 :3 0 3eb6
0 3eb6 3eb5 3eb3
3eb4 :6 0 3eb8 be
:3 0 2334 3eba 2336
3eb9 3eb8 :2 0 3ebb
2338 :2 0 3ebd 0
3ebd 3ebc 3e73 3ebb
:6 0 4a3e 1 :3 0
56 :3 0 3d :2 0
3ebf 3ec0 0 4a3e
84 :3 0 4b :3 0
3d :2 0 233a 3ec2
3ec5 10a :2 0 3d
:2 0 233f 3ec7 3ec9
:3 0 3f :3 0 9
:3 0 3ecb 3ecc 0
435d 84 :3 0 3f
:3 0 3d :2 0 2342
3ece 3ed1 84 :3 0
2de :2 0 43 :3 0
3d :2 0 2345 3ed3
3ed7 234a 3ed4 3ed9
:3 0 3f :3 0 84
:3 0 3f :3 0 3d
:2 0 234d 3edc 3edf
1be :2 0 84 :3 0
43 :3 0 3d :2 0
2350 3ee2 3ee5 2353
3ee1 3ee7 :3 0 3edb
3ee8 0 4289 84
:3 0 3f :3 0 3d
:2 0 2356 3eea 3eed
10a :2 0 3d :2 0
235b 3eef 3ef1 :3 0
3ef2 :2 0 84 :3 0
4c :3 0 3d :2 0
235e 3ef4 3ef7 10a
:2 0 3d :2 0 2363
3ef9 3efb :3 0 3efc
:2 0 3ef3 3efe 3efd
:2 0 1e :3 0 165
:2 0 2366 3f01 3f02
:3 0 3f03 :2 0 3f04
:2 0 3eff 3f06 3f05
:2 0 24 :3 0 7
:3 0 3f08 3f09 0
4286 26 :3 0 8
:3 0 3f0b 3f0c 0
4286 44 :3 0 b
:3 0 3f0e 3f0f 0
4286 45 :3 0 10
:3 0 3f11 3f12 0
4286 46 :3 0 d
:3 0 3f14 3f15 0
4286 47 :3 0 e
:3 0 3f17 3f18 0
4286 4e :3 0 c
:3 0 3f1a 3f1b 0
4286 48 :3 0 f
:3 0 3f1d 3f1e 0
4286 84 :3 0 f
:3 0 3d :2 0 2368
3f20 3f23 da :2 0
3d :2 0 236d 3f25
3f27 :3 0 44 :3 0
3d :2 0 3f29 3f2a
0 3f2c 2370 3f2d
3f28 3f2c 0 3f2e
2372 0 4286 6b
:3 0 201 :3 0 31
:3 0 32 :3 0 84
:3 0 46 :3 0 3d
:2 0 2374 3f33 3f36
84 :3 0 47 :3 0
3d :2 0 2377 3f38
3f3b 84 :3 0 52
:3 0 3d :2 0 237a
3f3d 3f40 84 :3 0
4e :3 0 3d :2 0
237d 3f42 3f45 84
:3 0 48 :3 0 3d
:2 0 2380 3f47 3f4a
84 :3 0 45 :3 0
3d :2 0 2383 3f4c
3f4f 84 :3 0 4f
:3 0 3d :2 0 2386
3f51 3f54 84 :3 0
50 :3 0 3d :2 0
2389 3f56 3f59 44
:3 0 3f :3 0 49
:3 0 238c 3f30 3f5e
3f2f 3f5f 0 4286
84 :3 0 6b :3 0
3d :2 0 239a 3f61
3f64 b0 :3 0 da
:2 0 202 :3 0 3f66
3f68 0 239f 3f67
3f6a :3 0 c3 :3 0
c4 :3 0 3f6c 3f6d
0 c3 :3 0 d3
:3 0 3f6f 3f70 0
203 :2 0 2 :4 0
2df :2 0 d5 :2 0
2a :2 0 23a2 3f75
3f77 :3 0 23a5 3f71
3f79 3f6e 3f7b 3f7a
:2 0 c6 :3 0 d6
:3 0 3f7d 3f7e 0
c8 :4 0 2e0 :4 0
cb :2 0 cc :3 0
23a9 3f82 3f84 :3 0
cb :2 0 e9 :4 0
23ac 3f86 3f88 :3 0
cb :2 0 f0 :4 0
23af 3f8a 3f8c :3 0
cb :2 0 84 :3 0
d0 :3 0 b0 :3 0
202 :3 0 3f91 3f92
0 23b2 3f90 3f94
d1 :4 0 23b4 3f8f
3f97 23b7 3f8e 3f99
:3 0 23ba 3f7f 3f9b
:2 0 3f9d 23bd 3f9e
3f7c 3f9d 0 3f9f
23bf 0 3fc9 c3
:3 0 c4 :3 0 3fa0
3fa1 0 c3 :3 0
d3 :3 0 3fa3 3fa4
0 2a :2 0 2
:4 0 2e1 :2 0 d5
:2 0 2a :2 0 23c1
3fa9 3fab :3 0 23c4
3fa5 3fad 3fa2 3faf
3fae :2 0 c6 :3 0
d6 :3 0 3fb1 3fb2
0 c8 :4 0 2e2
:4 0 cb :2 0 cc
:3 0 23c8 3fb6 3fb8
:3 0 23cb 3fb3 3fba
:2 0 3fbc 23ce 3fbd
3fb0 3fbc 0 3fbe
23d0 0 3fc9 f5
:3 0 208 :3 0 3fbf
3fc0 0 b0 :3 0
202 :3 0 3fc2 3fc3
0 f7 :3 0 23d2
3fc1 3fc6 :2 0 3fc9
140 :3 0 23d5 4042
84 :3 0 6b :3 0
3d :2 0 23d9 3fca
3fcd 13b :2 0 3d
:2 0 23de 3fcf 3fd1
:3 0 c3 :3 0 c4
:3 0 3fd3 3fd4 0
c3 :3 0 d3 :3 0
3fd6 3fd7 0 18
:2 0 2 :4 0 2e3
:2 0 d5 :2 0 2a
:2 0 23e1 3fdc 3fde
:3 0 23e4 3fd8 3fe0
3fd5 3fe2 3fe1 :2 0
c6 :3 0 d6 :3 0
3fe4 3fe5 0 c8
:4 0 2e4 :4 0 cb
:2 0 cc :3 0 23e8
3fe9 3feb :3 0 cb
:2 0 e9 :4 0 23eb
3fed 3fef :3 0 cb
:2 0 f0 :4 0 23ee
3ff1 3ff3 :3 0 cb
:2 0 84 :3 0 d0
:3 0 6b :3 0 23f1
3ff7 3ff9 d1 :4 0
23f3 3ff6 3ffc 23f6
3ff5 3ffe :3 0 cb
:2 0 f2 :4 0 23f9
4000 4002 :3 0 cb
:2 0 ce :4 0 23fc
4004 4006 :3 0 cb
:2 0 22 :3 0 23ff
4008 400a :3 0 cb
:2 0 ce :4 0 2402
400c 400e :3 0 2405
3fe6 4010 :2 0 4012
2408 4013 3fe3 4012
0 4014 240a 0
4040 c3 :3 0 c4
:3 0 4015 4016 0
c3 :3 0 d3 :3 0
4018 4019 0 2a
:2 0 2 :4 0 2e5
:2 0 d5 :2 0 2a
:2 0 240c 401e 4020
:3 0 240f 401a 4022
4017 4024 4023 :2 0
c6 :3 0 d6 :3 0
4026 4027 0 c8
:4 0 2e6 :4 0 cb
:2 0 cc :3 0 2413
402b 402d :3 0 2416
4028 402f :2 0 4031
2419 4032 4025 4031
0 4033 241b 0
4040 f5 :3 0 f6
:3 0 4034 4035 0
84 :3 0 6b :3 0
3d :2 0 241d 4037
403a 22 :3 0 f7
:3 0 2420 4036 403e
:2 0 4040 2424 4041
3fd2 4040 0 4043
3f6b 3fc9 0 4043
2428 0 4286 2e7
:3 0 2e8 :3 0 2e9
:4 0 4046 :4 0 4047
:2 0 4286 15 :3 0
e1 :3 0 4049 404a
0 3d :2 0 404b
404c 0 4286 2ea
:3 0 1c7 :3 0 1ae
:3 0 1af :3 0 1b0
:3 0 91 :3 0 22
:3 0 2eb :3 0 1e
:3 0 1c7 :4 0 2ec
1 :8 0 406e e0
:4 0 4059 :3 0 f7
:3 0 da :2 0 242d
405c 405d :3 0 15
:3 0 e1 :3 0 405f
4060 0 3d :2 0
4061 4062 0 4064
2430 406b 15 :3 0
e1 :3 0 4065 4066
0 e2 :2 0 4067
4068 0 406a 2432
406c 405e 4064 0
406d 0 406a 0
406d 2434 0 406e
2437 40b8 e5 :3 0
15 :3 0 e1 :3 0
4071 4072 0 e4
:3 0 4073 4074 0
40ae c3 :3 0 c4
:3 0 4076 4077 0
c3 :3 0 d3 :3 0
4079 407a 0 e6
:2 0 2 :4 0 2ed
:2 0 d5 :2 0 2a
:2 0 243a 407f 4081
:3 0 243d 407b 4083
4078 4085 4084 :2 0
c6 :3 0 d6 :3 0
4087 4088 0 c8
:4 0 2ee :4 0 cb
:2 0 cc :3 0 2441
408c 408e :3 0 cb
:2 0 e9 :4 0 2444
4090 4092 :3 0 cb
:2 0 ea :4 0 2447
4094 4096 :3 0 cb
:2 0 e4 :3 0 244a
4098 409a :3 0 cb
:2 0 eb :4 0 244d
409c 409e :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 2450 40a1 40a5
2454 40a0 40a7 :3 0
2457 4089 40a9 :2 0
40ab 245a 40ac 4086
40ab 0 40ad 245c
0 40ae 245e 40b1
:3 0 40b1 0 40b1
40b0 40ae 40af :6 0
40b3 c0 :3 0 2461
40b5 2463 40b4 40b3
:2 0 40b6 2465 :2 0
40b8 0 40b8 40b7
406e 40b6 :6 0 4286
1 :3 0 26 :3 0
de :4 0 40ba 40bb
0 4286 4a :3 0
3d :2 0 40bd 40be
0 4286 51 :3 0
3d :2 0 40c0 40c1
0 4286 40 :3 0
3d :2 0 40c3 40c4
0 4286 41 :3 0
2a :2 0 40c6 40c7
0 4286 84 :3 0
44 :3 0 3d :2 0
2467 40c9 40cc 10a
:2 0 3d :2 0 246c
40ce 40d0 :3 0 44
:3 0 1ff :3 0 19a
:3 0 40d3 40d4 0
84 :3 0 44 :3 0
3d :2 0 246f 40d6
40d9 b0 :3 0 2ef
:3 0 40db 40dc 0
2472 40d5 40de 40d2
40df 0 40e4 4e
:3 0 2a :2 0 40e1
40e2 0 40e4 2475
40e9 4e :3 0 3d
:2 0 40e5 40e6 0
40e8 2478 40ea 40d1
40e4 0 40eb 0
40e8 0 40eb 247a
0 4286 6a :3 0
5a :2 0 40ec 40ed
0 4286 66 :3 0
20e :3 0 1c :3 0
22 :3 0 22 :3 0
21 :3 0 6a :3 0
41 :3 0 29 :3 0
29 :3 0 29 :3 0
29 :3 0 24 :3 0
26 :3 0 49 :3 0
3f :3 0 44 :3 0
46 :3 0 47 :3 0
40 :3 0 52 :3 0
2e :3 0 4a :3 0
4e :3 0 48 :3 0
45 :3 0 51 :3 0
4f :3 0 53 :3 0
1a :3 0 3d :2 0
3d :2 0 5a :2 0
5a :2 0 247d 40f0
4111 40ef 4112 0
4286 84 :3 0 66
:3 0 3d :2 0 249e
4114 4117 da :2 0
20f :2 0 24a3 4119
411b :3 0 c3 :3 0
c4 :3 0 411d 411e
0 c3 :3 0 d3
:3 0 4120 4121 0
18 :2 0 2 :4 0
2f0 :2 0 d5 :2 0
2a :2 0 24a6 4126
4128 :3 0 24a9 4122
412a 411f 412c 412b
:2 0 c6 :3 0 d6
:3 0 412e 412f 0
c8 :4 0 2f1 :4 0
cb :2 0 cc :3 0
24ad 4133 4135 :3 0
cb :2 0 e9 :4 0
24b0 4137 4139 :3 0
cb :2 0 f0 :4 0
24b3 413b 413d :3 0
cb :2 0 84 :3 0
d0 :3 0 b0 :3 0
212 :3 0 4142 4143
0 24b6 4141 4145
d1 :4 0 24b8 4140
4148 24bb 413f 414a
:3 0 cb :2 0 f2
:4 0 24be 414c 414e
:3 0 cb :2 0 ce
:4 0 24c1 4150 4152
:3 0 cb :2 0 21
:3 0 24c4 4154 4156
:3 0 cb :2 0 ce
:4 0 24c7 4158 415a
:3 0 24ca 4130 415c
:2 0 415e 24cd 415f
412d 415e 0 4160
24cf 0 418b c3
:3 0 c4 :3 0 4161
4162 0 c3 :3 0
d3 :3 0 4164 4165
0 2a :2 0 2
:4 0 2f2 :2 0 d5
:2 0 2a :2 0 24d1
416a 416c :3 0 24d4
4166 416e 4163 4170
416f :2 0 c6 :3 0
d6 :3 0 4172 4173
0 c8 :4 0 2f3
:4 0 cb :2 0 cc
:3 0 24d8 4177 4179
:3 0 24db 4174 417b
:2 0 417d 24de 417e
4171 417d 0 417f
24e0 0 418b f5
:3 0 f6 :3 0 4180
4181 0 b0 :3 0
212 :3 0 4183 4184
0 21 :3 0 f7
:3 0 24e2 4182 4188
:2 0 418b 140 :3 0
24e6 4283 84 :3 0
66 :3 0 3d :2 0
24ea 418c 418f 13b
:2 0 3d :2 0 24ef
4191 4193 :3 0 c3
:3 0 c4 :3 0 4195
4196 0 c3 :3 0
d3 :3 0 4198 4199
0 18 :2 0 2
:4 0 2f4 :2 0 d5
:2 0 2a :2 0 24f2
419e 41a0 :3 0 24f5
419a 41a2 4197 41a4
41a3 :2 0 c6 :3 0
d6 :3 0 41a6 41a7
0 c8 :4 0 2f5
:4 0 cb :2 0 cc
:3 0 24f9 41ab 41ad
:3 0 cb :2 0 e9
:4 0 24fc 41af 41b1
:3 0 cb :2 0 f0
:4 0 24ff 41b3 41b5
:3 0 cb :2 0 84
:3 0 d0 :3 0 b0
:3 0 1ba :3 0 41ba
41bb 0 2502 41b9
41bd d1 :4 0 2504
41b8 41c0 2507 41b7
41c2 :3 0 cb :2 0
f2 :4 0 250a 41c4
41c6 :3 0 cb :2 0
ce :4 0 250d 41c8
41ca :3 0 cb :2 0
1c :3 0 2510 41cc
41ce :3 0 cb :2 0
ce :4 0 2513 41d0
41d2 :3 0 2516 41a8
41d4 :2 0 41d6 2519
41d7 41a5 41d6 0
41d8 251b 0 4202
c3 :3 0 c4 :3 0
41d9 41da 0 c3
:3 0 d3 :3 0 41dc
41dd 0 2a :2 0
2 :4 0 2f6 :2 0
d5 :2 0 2a :2 0
251d 41e2 41e4 :3 0
2520 41de 41e6 41db
41e8 41e7 :2 0 c6
:3 0 d6 :3 0 41ea
41eb 0 c8 :4 0
2f7 :4 0 cb :2 0
cc :3 0 2524 41ef
41f1 :3 0 2527 41ec
41f3 :2 0 41f5 252a
41f6 41e9 41f5 0
41f7 252c 0 4202
f5 :3 0 f6 :3 0
41f8 41f9 0 b0
:3 0 1ba :3 0 41fb
41fc 0 1c :3 0
f7 :3 0 252e 41fa
4200 :2 0 4202 2532
4203 4194 4202 0
4285 90 :3 0 98
:3 0 1c :3 0 92
:3 0 21 :3 0 93
:3 0 a7 :3 0 61
:3 0 58 :3 0 5e
:3 0 a7 :3 0 1d3
:3 0 61 :3 0 5c
:3 0 5e :3 0 1d3
:3 0 a8 :3 0 62
:3 0 5b :3 0 5e
:3 0 a8 :3 0 1d4
:3 0 62 :3 0 5d
:3 0 5e :3 0 1d4
:3 0 9a :3 0 1e
:4 0 2f8 1 :8 0
4236 e0 :4 0 4221
:3 0 f7 :3 0 da
:2 0 2538 4224 4225
:3 0 15 :3 0 e1
:3 0 4227 4228 0
3d :2 0 4229 422a
0 422c 253b 4233
15 :3 0 e1 :3 0
422d 422e 0 e2
:2 0 422f 4230 0
4232 253d 4234 4226
422c 0 4235 0
4232 0 4235 253f
0 4236 2542 4280
e5 :3 0 15 :3 0
e1 :3 0 4239 423a
0 e4 :3 0 423b
423c 0 4276 c3
:3 0 c4 :3 0 423e
423f 0 c3 :3 0
d3 :3 0 4241 4242
0 e6 :2 0 2
:4 0 2f9 :2 0 d5
:2 0 2a :2 0 2545
4247 4249 :3 0 2548
4243 424b 4240 424d
424c :2 0 c6 :3 0
d6 :3 0 424f 4250
0 c8 :4 0 2fa
:4 0 cb :2 0 cc
:3 0 254c 4254 4256
:3 0 cb :2 0 e9
:4 0 254f 4258 425a
:3 0 cb :2 0 ea
:4 0 2552 425c 425e
:3 0 cb :2 0 e4
:3 0 2555 4260 4262
:3 0 cb :2 0 eb
:4 0 2558 4264 4266
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 255b
4269 426d 255f 4268
426f :3 0 2562 4251
4271 :2 0 4273 2565
4274 424e 4273 0
4275 2567 0 4276
2569 4279 :3 0 4279
0 4279 4278 4276
4277 :6 0 427b c2
:3 0 256c 427d 256e
427c 427b :2 0 427e
2570 :2 0 4280 0
4280 427f 4236 427e
:6 0 4282 1 :3 0
2572 4284 411c 418b
0 4285 0 4282
0 4285 2574 0
4286 2578 4287 3f07
4286 0 4288 2590
0 4289 2592 428a
3eda 4289 0 428b
2595 0 435d 13c
:3 0 56 :3 0 af
:3 0 8b :3 0 22
:3 0 92 :3 0 23
:3 0 93 :4 0 2fb
1 :8 0 429a 15
:3 0 e1 :3 0 4295
4296 0 e4 :3 0
4297 4298 0 429a
2597 42e4 e5 :3 0
15 :3 0 e1 :3 0
429d 429e 0 e4
:3 0 429f 42a0 0
42da c3 :3 0 c4
:3 0 42a2 42a3 0
c3 :3 0 d3 :3 0
42a5 42a6 0 e6
:2 0 2 :4 0 2fc
:2 0 d5 :2 0 2a
:2 0 259a 42ab 42ad
:3 0 259d 42a7 42af
42a4 42b1 42b0 :2 0
c6 :3 0 d6 :3 0
42b3 42b4 0 c8
:4 0 2fd :4 0 cb
:2 0 cc :3 0 25a1
42b8 42ba :3 0 cb
:2 0 e9 :4 0 25a4
42bc 42be :3 0 cb
:2 0 ea :4 0 25a7
42c0 42c2 :3 0 cb
:2 0 e4 :3 0 25aa
42c4 42c6 :3 0 cb
:2 0 eb :4 0 25ad
42c8 42ca :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 25b0 42cd 42d1
25b4 42cc 42d3 :3 0
25b7 42b5 42d5 :2 0
42d7 25ba 42d8 42b2
42d7 0 42d9 25bc
0 42da 25be 42dd
:3 0 42dd 0 42dd
42dc 42da 42db :6 0
42df c4 :3 0 25c1
42e1 25c3 42e0 42df
:2 0 42e2 25c5 :2 0
42e4 0 42e4 42e3
429a 42e2 :6 0 435d
1 :3 0 84 :3 0
56 :3 0 3d :2 0
25c7 42e6 42e9 da
:2 0 3d :2 0 25cc
42eb 42ed :3 0 ae
:3 0 185 :3 0 186
:3 0 185 :3 0 39
:3 0 91 :3 0 22
:3 0 8b :3 0 22
:4 0 2fe 1 :8 0
430e e0 :4 0 42f9
:3 0 f7 :3 0 da
:2 0 25d1 42fc 42fd
:3 0 15 :3 0 e1
:3 0 42ff 4300 0
3d :2 0 4301 4302
0 4304 25d4 430b
15 :3 0 e1 :3 0
4305 4306 0 e2
:2 0 4307 4308 0
430a 25d6 430c 42fe
4304 0 430d 0
430a 0 430d 25d8
0 430e 25db 4358
e5 :3 0 15 :3 0
e1 :3 0 4311 4312
0 e4 :3 0 4313
4314 0 434e c3
:3 0 c4 :3 0 4316
4317 0 c3 :3 0
d3 :3 0 4319 431a
0 e6 :2 0 2
:4 0 2ff :2 0 d5
:2 0 2a :2 0 25de
431f 4321 :3 0 25e1
431b 4323 4318 4325
4324 :2 0 c6 :3 0
d6 :3 0 4327 4328
0 c8 :4 0 300
:4 0 cb :2 0 cc
:3 0 25e5 432c 432e
:3 0 cb :2 0 e9
:4 0 25e8 4330 4332
:3 0 cb :2 0 ea
:4 0 25eb 4334 4336
:3 0 cb :2 0 e4
:3 0 25ee 4338 433a
:3 0 cb :2 0 eb
:4 0 25f1 433c 433e
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 25f4
4341 4345 25f8 4340
4347 :3 0 25fb 4329
4349 :2 0 434b 25fe
434c 4326 434b 0
434d 2600 0 434e
2602 4351 :3 0 4351
0 4351 4350 434e
434f :6 0 4353 c6
:3 0 2605 4355 2607
4354 4353 :2 0 4356
2609 :2 0 4358 0
4358 4357 430e 4356
:6 0 435a 1 :3 0
260b 435b 42ee 435a
0 435c 260d 0
435d 260f 435e 3eca
435d 0 435f 2614
0 4a3e 63 :3 0
3d :2 0 4360 4361
0 4a3e 81 :3 0
165 :2 0 2616 4364
4365 :3 0 4366 :2 0
ae :3 0 1d7 :3 0
199 :3 0 19a :3 0
1d7 :3 0 b0 :3 0
301 :3 0 8b :3 0
22 :4 0 302 1
:8 0 4387 e0 :4 0
4372 :3 0 f7 :3 0
da :2 0 261a 4375
4376 :3 0 15 :3 0
e1 :3 0 4378 4379
0 3d :2 0 437a
437b 0 437d 261d
4384 15 :3 0 e1
:3 0 437e 437f 0
e2 :2 0 4380 4381
0 4383 261f 4385
4377 437d 0 4386
0 4383 0 4386
2621 0 4387 2624
43d1 e5 :3 0 15
:3 0 e1 :3 0 438a
438b 0 e4 :3 0
438c 438d 0 43c7
c3 :3 0 c4 :3 0
438f 4390 0 c3
:3 0 d3 :3 0 4392
4393 0 e6 :2 0
2 :4 0 303 :2 0
d5 :2 0 2a :2 0
2627 4398 439a :3 0
262a 4394 439c 4391
439e 439d :2 0 c6
:3 0 d6 :3 0 43a0
43a1 0 c8 :4 0
304 :4 0 cb :2 0
cc :3 0 262e 43a5
43a7 :3 0 cb :2 0
e9 :4 0 2631 43a9
43ab :3 0 cb :2 0
ea :4 0 2634 43ad
43af :3 0 cb :2 0
e4 :3 0 2637 43b1
43b3 :3 0 cb :2 0
eb :4 0 263a 43b5
43b7 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
263d 43ba 43be 2641
43b9 43c0 :3 0 2644
43a2 43c2 :2 0 43c4
2647 43c5 439f 43c4
0 43c6 2649 0
43c7 264b 43ca :3 0
43ca 0 43ca 43c9
43c7 43c8 :6 0 43cc
c8 :3 0 264e 43ce
2650 43cd 43cc :2 0
43cf 2652 :2 0 43d1
0 43d1 43d0 4387
43cf :6 0 46d4 1
:3 0 84 :3 0 4c
:3 0 3d :2 0 2654
43d3 43d6 da :2 0
3d :2 0 2659 43d8
43da :3 0 13c :3 0
56 :3 0 90 :3 0
91 :3 0 22 :3 0
94 :3 0 81 :4 0
305 1 :8 0 43e9
15 :3 0 e1 :3 0
43e4 43e5 0 e4
:3 0 43e6 43e7 0
43e9 265c 4433 e5
:3 0 15 :3 0 e1
:3 0 43ec 43ed 0
e4 :3 0 43ee 43ef
0 4429 c3 :3 0
c4 :3 0 43f1 43f2
0 c3 :3 0 d3
:3 0 43f4 43f5 0
e6 :2 0 2 :4 0
306 :2 0 d5 :2 0
2a :2 0 265f 43fa
43fc :3 0 2662 43f6
43fe 43f3 4400 43ff
:2 0 c6 :3 0 d6
:3 0 4402 4403 0
c8 :4 0 307 :4 0
cb :2 0 cc :3 0
2666 4407 4409 :3 0
cb :2 0 e9 :4 0
2669 440b 440d :3 0
cb :2 0 ea :4 0
266c 440f 4411 :3 0
cb :2 0 e4 :3 0
266f 4413 4415 :3 0
cb :2 0 eb :4 0
2672 4417 4419 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 2675 441c
4420 2679 441b 4422
:3 0 267c 4404 4424
:2 0 4426 267f 4427
4401 4426 0 4428
2681 0 4429 2683
442c :3 0 442c 0
442c 442b 4429 442a
:6 0 442e ca :3 0
2686 4430 2688 442f
442e :2 0 4431 268a
:2 0 4433 0 4433
4432 43e9 4431 :6 0
4512 1 :3 0 84
:3 0 56 :3 0 3d
:2 0 268c 4435 4438
da :2 0 3d :2 0
2691 443a 443c :3 0
af :3 0 91 :3 0
22 :3 0 8b :3 0
22 :3 0 92 :3 0
23 :3 0 93 :4 0
308 1 :8 0 445c
e0 :4 0 4447 :3 0
f7 :3 0 da :2 0
2696 444a 444b :3 0
15 :3 0 e1 :3 0
444d 444e 0 3d
:2 0 444f 4450 0
4452 2699 4459 15
:3 0 e1 :3 0 4453
4454 0 e2 :2 0
4455 4456 0 4458
269b 445a 444c 4452
0 445b 0 4458
0 445b 269d 0
445c 26a0 44a6 e5
:3 0 15 :3 0 e1
:3 0 445f 4460 0
e4 :3 0 4461 4462
0 449c c3 :3 0
c4 :3 0 4464 4465
0 c3 :3 0 d3
:3 0 4467 4468 0
e6 :2 0 2 :4 0
309 :2 0 d5 :2 0
2a :2 0 26a3 446d
446f :3 0 26a6 4469
4471 4466 4473 4472
:2 0 c6 :3 0 d6
:3 0 4475 4476 0
c8 :4 0 30a :4 0
cb :2 0 cc :3 0
26aa 447a 447c :3 0
cb :2 0 e9 :4 0
26ad 447e 4480 :3 0
cb :2 0 ea :4 0
26b0 4482 4484 :3 0
cb :2 0 e4 :3 0
26b3 4486 4488 :3 0
cb :2 0 eb :4 0
26b6 448a 448c :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 26b9 448f
4493 26bd 448e 4495
:3 0 26c0 4477 4497
:2 0 4499 26c3 449a
4474 4499 0 449b
26c5 0 449c 26c7
449f :3 0 449f 0
449f 449e 449c 449d
:6 0 44a1 cc :3 0
26ca 44a3 26cc 44a2
44a1 :2 0 44a4 26ce
:2 0 44a6 0 44a6
44a5 445c 44a4 :6 0
450f 1 :3 0 1fb
:3 0 91 :3 0 22
:3 0 92 :3 0 23
:4 0 1fc 1 :8 0
44c3 e0 :4 0 44ae
:3 0 f7 :3 0 da
:2 0 26d2 44b1 44b2
:3 0 15 :3 0 e1
:3 0 44b4 44b5 0
3d :2 0 44b6 44b7
0 44b9 26d5 44c0
15 :3 0 e1 :3 0
44ba 44bb 0 e2
:2 0 44bc 44bd 0
44bf 26d7 44c1 44b3
44b9 0 44c2 0
44bf 0 44c2 26d9
0 44c3 26dc 450d
e5 :3 0 15 :3 0
e1 :3 0 44c6 44c7
0 e4 :3 0 44c8
44c9 0 4503 c3
:3 0 c4 :3 0 44cb
44cc 0 c3 :3 0
d3 :3 0 44ce 44cf
0 e6 :2 0 2
:4 0 30b :2 0 d5
:2 0 2a :2 0 26df
44d4 44d6 :3 0 26e2
44d0 44d8 44cd 44da
44d9 :2 0 c6 :3 0
d6 :3 0 44dc 44dd
0 c8 :4 0 30c
:4 0 cb :2 0 cc
:3 0 26e6 44e1 44e3
:3 0 cb :2 0 e9
:4 0 26e9 44e5 44e7
:3 0 cb :2 0 ea
:4 0 26ec 44e9 44eb
:3 0 cb :2 0 e4
:3 0 26ef 44ed 44ef
:3 0 cb :2 0 eb
:4 0 26f2 44f1 44f3
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 26f5
44f6 44fa 26f9 44f5
44fc :3 0 26fc 44de
44fe :2 0 4500 26ff
4501 44db 4500 0
4502 2701 0 4503
2703 4506 :3 0 4506
0 4506 4505 4503
4504 :6 0 4508 ce
:3 0 2706 450a 2708
4509 4508 :2 0 450b
270a :2 0 450d 0
450d 450c 44c3 450b
:6 0 450f 1 :3 0
270c 4510 443d 450f
0 4511 270f 0
4512 2711 4513 43db
4512 0 4514 2714
0 46d4 84 :3 0
56 :3 0 3d :2 0
2716 4515 4518 10a
:2 0 3d :2 0 271b
451a 451c :3 0 6b
:3 0 30d :2 0 451e
451f 0 46d1 71
:3 0 219 :3 0 22
:3 0 81 :3 0 6b
:3 0 3d :2 0 3d
:2 0 271e 4522 4528
4521 4529 0 46d1
a1 :3 0 a2 :3 0
30e :3 0 9f :3 0
a0 :3 0 22b :3 0
9f :3 0 a0 :3 0
22c :3 0 a5 :3 0
a6 :3 0 a7 :3 0
a8 :3 0 31 :3 0
32 :3 0 3f :3 0
2b :3 0 2d :3 0
78 :3 0 79 :3 0
74 :3 0 75 :3 0
90 :3 0 9a :3 0
81 :4 0 30f 1
:8 0 454a 15 :3 0
e1 :3 0 4545 4546
0 e4 :3 0 4547
4548 0 454a 2724
4594 e5 :3 0 15
:3 0 e1 :3 0 454d
454e 0 e4 :3 0
454f 4550 0 458a
c3 :3 0 c4 :3 0
4552 4553 0 c3
:3 0 d3 :3 0 4555
4556 0 e6 :2 0
2 :4 0 310 :2 0
d5 :2 0 2a :2 0
2727 455b 455d :3 0
272a 4557 455f 4554
4561 4560 :2 0 c6
:3 0 d6 :3 0 4563
4564 0 c8 :4 0
311 :4 0 cb :2 0
cc :3 0 272e 4568
456a :3 0 cb :2 0
e9 :4 0 2731 456c
456e :3 0 cb :2 0
ea :4 0 2734 4570
4572 :3 0 cb :2 0
e4 :3 0 2737 4574
4576 :3 0 cb :2 0
eb :4 0 273a 4578
457a :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
273d 457d 4581 2741
457c 4583 :3 0 2744
4565 4585 :2 0 4587
2747 4588 4562 4587
0 4589 2749 0
458a 274b 458d :3 0
458d 0 458d 458c
458a 458b :6 0 458f
d0 :3 0 274e 4591
2750 4590 458f :2 0
4592 2752 :2 0 4594
0 4594 4593 454a
4592 :6 0 46d1 1
:3 0 15 :3 0 e1
:3 0 4596 4597 0
15 :3 0 da :2 0
157 :3 0 4599 459b
0 2756 459a 459d
:3 0 459e :2 0 84
:3 0 78 :3 0 3d
:2 0 2759 45a0 45a3
da :2 0 3d :2 0
275e 45a5 45a7 :3 0
1fb :3 0 312 :3 0
31 :3 0 313 :3 0
32 :3 0 314 :3 0
3f :3 0 315 :3 0
3f :3 0 74 :3 0
316 :3 0 91 :3 0
22 :3 0 92 :3 0
23 :4 0 317 1
:8 0 45ce e0 :4 0
45b9 :3 0 f7 :3 0
da :2 0 2763 45bc
45bd :3 0 15 :3 0
e1 :3 0 45bf 45c0
0 3d :2 0 45c1
45c2 0 45c4 2766
45cb 15 :3 0 e1
:3 0 45c5 45c6 0
e2 :2 0 45c7 45c8
0 45ca 2768 45cc
45be 45c4 0 45cd
0 45ca 0 45cd
276a 0 45ce 276d
4618 e5 :3 0 15
:3 0 e1 :3 0 45d1
45d2 0 e4 :3 0
45d3 45d4 0 460e
c3 :3 0 c4 :3 0
45d6 45d7 0 c3
:3 0 d3 :3 0 45d9
45da 0 e6 :2 0
2 :4 0 318 :2 0
d5 :2 0 2a :2 0
2770 45df 45e1 :3 0
2773 45db 45e3 45d8
45e5 45e4 :2 0 c6
:3 0 d6 :3 0 45e7
45e8 0 c8 :4 0
319 :4 0 cb :2 0
cc :3 0 2777 45ec
45ee :3 0 cb :2 0
e9 :4 0 277a 45f0
45f2 :3 0 cb :2 0
ea :4 0 277d 45f4
45f6 :3 0 cb :2 0
e4 :3 0 2780 45f8
45fa :3 0 cb :2 0
eb :4 0 2783 45fc
45fe :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
2786 4601 4605 278a
4600 4607 :3 0 278d
45e9 4609 :2 0 460b
2790 460c 45e6 460b
0 460d 2792 0
460e 2794 4611 :3 0
4611 0 4611 4610
460e 460f :6 0 4613
d2 :3 0 2797 4615
2799 4614 4613 :2 0
4616 279b :2 0 4618
0 4618 4617 45ce
4616 :6 0 461a 1
:3 0 279d 468f 1fb
:3 0 312 :3 0 31
:3 0 313 :3 0 32
:3 0 314 :3 0 3f
:3 0 315 :3 0 3f
:3 0 74 :3 0 316
:3 0 3f :3 0 75
:3 0 91 :3 0 22
:3 0 92 :3 0 23
:4 0 31a 1 :8 0
4642 e0 :4 0 462d
:3 0 f7 :3 0 da
:2 0 27a1 4630 4631
:3 0 15 :3 0 e1
:3 0 4633 4634 0
3d :2 0 4635 4636
0 4638 27a4 463f
15 :3 0 e1 :3 0
4639 463a 0 e2
:2 0 463b 463c 0
463e 27a6 4640 4632
4638 0 4641 0
463e 0 4641 27a8
0 4642 27ab 468c
e5 :3 0 15 :3 0
e1 :3 0 4645 4646
0 e4 :3 0 4647
4648 0 4682 c3
:3 0 c4 :3 0 464a
464b 0 c3 :3 0
d3 :3 0 464d 464e
0 e6 :2 0 2
:4 0 31b :2 0 d5
:2 0 2a :2 0 27ae
4653 4655 :3 0 27b1
464f 4657 464c 4659
4658 :2 0 c6 :3 0
d6 :3 0 465b 465c
0 c8 :4 0 31c
:4 0 cb :2 0 cc
:3 0 27b5 4660 4662
:3 0 cb :2 0 e9
:4 0 27b8 4664 4666
:3 0 cb :2 0 ea
:4 0 27bb 4668 466a
:3 0 cb :2 0 e4
:3 0 27be 466c 466e
:3 0 cb :2 0 eb
:4 0 27c1 4670 4672
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 27c4
4675 4679 27c8 4674
467b :3 0 27cb 465d
467d :2 0 467f 27ce
4680 465a 467f 0
4681 27d0 0 4682
27d2 4685 :3 0 4685
0 4685 4684 4682
4683 :6 0 4687 d4
:3 0 27d5 4689 27d7
4688 4687 :2 0 468a
27d9 :2 0 468c 0
468c 468b 4642 468a
:6 0 468e 1 :3 0
27db 4690 45a8 461a
0 4691 0 468e
0 4691 27dd 0
46b4 a0 :3 0 6f
:3 0 2a :2 0 2a
:2 0 27e0 4692 4696
da :2 0 1bd :4 0
27e6 4698 469a :3 0
469b :2 0 7a :3 0
3d :2 0 469d 469e
0 46b1 15 :3 0
e1 :3 0 46a0 46a1
0 1bf :3 0 22
:3 0 22 :3 0 81
:3 0 2b :3 0 2d
:3 0 74 :3 0 75
:3 0 7a :3 0 79
:3 0 78 :3 0 27e9
46a3 46ae 46a2 46af
0 46b1 27f4 46b2
469c 46b1 0 46b3
27f7 0 46b4 27f9
46b5 459f 46b4 0
46b6 27fc 0 46d1
1e :3 0 165 :2 0
27fe 46b8 46b9 :3 0
46ba :2 0 46bb :2 0
116 :3 0 133 :3 0
46bd 46be 0 81
:3 0 1e :3 0 2800
46bf 46c2 da :2 0
3d :2 0 2805 46c4
46c6 :3 0 46c7 :2 0
46bc 46c9 46c8 :2 0
63 :3 0 2a :2 0
46cb 46cc 0 46ce
2808 46cf 46ca 46ce
0 46d0 280a 0
46d1 280c 46d2 451d
46d1 0 46d3 2812
0 46d4 2814 46d5
4367 46d4 0 46d6
2818 0 4a3e 84
:3 0 4c :3 0 3d
:2 0 281a 46d7 46da
10a :2 0 3d :2 0
281f 46dc 46de :3 0
46df :2 0 1e :3 0
165 :2 0 2822 46e2
46e3 :3 0 46e4 :2 0
46e5 :2 0 46e0 46e7
46e6 :2 0 84 :3 0
60 :3 0 3d :2 0
2824 46e9 46ec da
:2 0 2a :2 0 2829
46ee 46f0 :3 0 13c
:3 0 56 :3 0 90
:3 0 91 :3 0 22
:3 0 94 :3 0 1e
:3 0 92 :3 0 23
:3 0 93 :4 0 31d
1 :8 0 4702 15
:3 0 e1 :3 0 46fd
46fe 0 e4 :3 0
46ff 4700 0 4702
282c 474c e5 :3 0
15 :3 0 e1 :3 0
4705 4706 0 e4
:3 0 4707 4708 0
4742 c3 :3 0 c4
:3 0 470a 470b 0
c3 :3 0 d3 :3 0
470d 470e 0 e6
:2 0 2 :4 0 31e
:2 0 d5 :2 0 2a
:2 0 282f 4713 4715
:3 0 2832 470f 4717
470c 4719 4718 :2 0
c6 :3 0 d6 :3 0
471b 471c 0 c8
:4 0 31f :4 0 cb
:2 0 cc :3 0 2836
4720 4722 :3 0 cb
:2 0 e9 :4 0 2839
4724 4726 :3 0 cb
:2 0 ea :4 0 283c
4728 472a :3 0 cb
:2 0 e4 :3 0 283f
472c 472e :3 0 cb
:2 0 eb :4 0 2842
4730 4732 :3 0 cb
:2 0 a0 :3 0 ec
:3 0 2a :2 0 ed
:2 0 2845 4735 4739
2849 4734 473b :3 0
284c 471d 473d :2 0
473f 284f 4740 471a
473f 0 4741 2851
0 4742 2853 4745
:3 0 4745 0 4745
4744 4742 4743 :6 0
4747 d6 :3 0 2856
4749 2858 4748 4747
:2 0 474a 285a :2 0
474c 0 474c 474b
4702 474a :6 0 4830
1 :3 0 84 :3 0
56 :3 0 3d :2 0
285c 474e 4751 10a
:2 0 3d :2 0 2861
4753 4755 :3 0 90
:3 0 94 :3 0 91
:3 0 22 :3 0 94
:3 0 1e :3 0 92
:3 0 23 :3 0 93
:4 0 320 1 :8 0
4776 e0 :4 0 4761
:3 0 f7 :3 0 da
:2 0 2866 4764 4765
:3 0 15 :3 0 e1
:3 0 4767 4768 0
3d :2 0 4769 476a
0 476c 2869 4773
15 :3 0 e1 :3 0
476d 476e 0 e2
:2 0 476f 4770 0
4772 286b 4774 4766
476c 0 4775 0
4772 0 4775 286d
0 4776 2870 47c0
e5 :3 0 15 :3 0
e1 :3 0 4779 477a
0 e4 :3 0 477b
477c 0 47b6 c3
:3 0 c4 :3 0 477e
477f 0 c3 :3 0
d3 :3 0 4781 4782
0 e6 :2 0 2
:4 0 321 :2 0 d5
:2 0 2a :2 0 2873
4787 4789 :3 0 2876
4783 478b 4780 478d
478c :2 0 c6 :3 0
d6 :3 0 478f 4790
0 c8 :4 0 322
:4 0 cb :2 0 cc
:3 0 287a 4794 4796
:3 0 cb :2 0 e9
:4 0 287d 4798 479a
:3 0 cb :2 0 ea
:4 0 2880 479c 479e
:3 0 cb :2 0 e4
:3 0 2883 47a0 47a2
:3 0 cb :2 0 eb
:4 0 2886 47a4 47a6
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 2889
47a9 47ad 288d 47a8
47af :3 0 2890 4791
47b1 :2 0 47b3 2893
47b4 478e 47b3 0
47b5 2895 0 47b6
2897 47b9 :3 0 47b9
0 47b9 47b8 47b6
47b7 :6 0 47bb d8
:3 0 289a 47bd 289c
47bc 47bb :2 0 47be
289e :2 0 47c0 0
47c0 47bf 4776 47be
:6 0 482d 1 :3 0
1b0 :3 0 2eb :3 0
9a :3 0 91 :3 0
22 :3 0 2eb :3 0
1e :3 0 92 :3 0
23 :4 0 323 1
:8 0 47e1 e0 :4 0
47cc :3 0 f7 :3 0
da :2 0 28a2 47cf
47d0 :3 0 15 :3 0
e1 :3 0 47d2 47d3
0 3d :2 0 47d4
47d5 0 47d7 28a5
47de 15 :3 0 e1
:3 0 47d8 47d9 0
e2 :2 0 47da 47db
0 47dd 28a7 47df
47d1 47d7 0 47e0
0 47dd 0 47e0
28a9 0 47e1 28ac
482b e5 :3 0 15
:3 0 e1 :3 0 47e4
47e5 0 e4 :3 0
47e6 47e7 0 4821
c3 :3 0 c4 :3 0
47e9 47ea 0 c3
:3 0 d3 :3 0 47ec
47ed 0 e6 :2 0
2 :4 0 324 :2 0
d5 :2 0 2a :2 0
28af 47f2 47f4 :3 0
28b2 47ee 47f6 47eb
47f8 47f7 :2 0 c6
:3 0 d6 :3 0 47fa
47fb 0 c8 :4 0
325 :4 0 cb :2 0
cc :3 0 28b6 47ff
4801 :3 0 cb :2 0
e9 :4 0 28b9 4803
4805 :3 0 cb :2 0
ea :4 0 28bc 4807
4809 :3 0 cb :2 0
e4 :3 0 28bf 480b
480d :3 0 cb :2 0
eb :4 0 28c2 480f
4811 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
28c5 4814 4818 28c9
4813 481a :3 0 28cc
47fc 481c :2 0 481e
28cf 481f 47f9 481e
0 4820 28d1 0
4821 28d3 4824 :3 0
4824 0 4824 4823
4821 4822 :6 0 4826
da :3 0 28d6 4828
28d8 4827 4826 :2 0
4829 28da :2 0 482b
0 482b 482a 47e1
4829 :6 0 482d 1
:3 0 28dc 482e 4756
482d 0 482f 28df
0 4830 28e1 4831
46f1 4830 0 4832
28e4 0 49d8 6b
:3 0 30d :2 0 4833
4834 0 49d8 71
:3 0 219 :3 0 22
:3 0 1e :3 0 6b
:3 0 3d :2 0 3d
:2 0 28e6 4837 483d
4836 483e 0 49d8
a1 :3 0 a2 :3 0
30e :3 0 9f :3 0
a0 :3 0 22b :3 0
9f :3 0 a0 :3 0
22c :3 0 a5 :3 0
a6 :3 0 a7 :3 0
a8 :3 0 31 :3 0
32 :3 0 3f :3 0
2b :3 0 2d :3 0
78 :3 0 79 :3 0
58 :3 0 5b :3 0
90 :3 0 9a :3 0
1e :4 0 326 1
:8 0 485f 15 :3 0
e1 :3 0 485a 485b
0 e4 :3 0 485c
485d 0 485f 28ec
48a9 e5 :3 0 15
:3 0 e1 :3 0 4862
4863 0 e4 :3 0
4864 4865 0 489f
c3 :3 0 c4 :3 0
4867 4868 0 c3
:3 0 d3 :3 0 486a
486b 0 e6 :2 0
2 :4 0 327 :2 0
d5 :2 0 2a :2 0
28ef 4870 4872 :3 0
28f2 486c 4874 4869
4876 4875 :2 0 c6
:3 0 d6 :3 0 4878
4879 0 c8 :4 0
328 :4 0 cb :2 0
cc :3 0 28f6 487d
487f :3 0 cb :2 0
e9 :4 0 28f9 4881
4883 :3 0 cb :2 0
ea :4 0 28fc 4885
4887 :3 0 cb :2 0
e4 :3 0 28ff 4889
488b :3 0 cb :2 0
eb :4 0 2902 488d
488f :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
2905 4892 4896 2909
4891 4898 :3 0 290c
487a 489a :2 0 489c
290f 489d 4877 489c
0 489e 2911 0
489f 2913 48a2 :3 0
48a2 0 48a2 48a1
489f 48a0 :6 0 48a4
dc :3 0 2916 48a6
2918 48a5 48a4 :2 0
48a7 291a :2 0 48a9
0 48a9 48a8 485f
48a7 :6 0 49d8 1
:3 0 15 :3 0 e1
:3 0 48ab 48ac 0
15 :3 0 da :2 0
157 :3 0 48ae 48b0
0 291e 48af 48b2
:3 0 48b3 :2 0 84
:3 0 78 :3 0 3d
:2 0 2921 48b5 48b8
da :2 0 3d :2 0
2926 48ba 48bc :3 0
1fb :3 0 312 :3 0
31 :3 0 313 :3 0
32 :3 0 314 :3 0
3f :3 0 315 :3 0
3f :3 0 58 :3 0
316 :3 0 91 :3 0
22 :3 0 92 :3 0
21 :4 0 329 1
:8 0 48e3 e0 :4 0
48ce :3 0 f7 :3 0
da :2 0 292b 48d1
48d2 :3 0 15 :3 0
e1 :3 0 48d4 48d5
0 3d :2 0 48d6
48d7 0 48d9 292e
48e0 15 :3 0 e1
:3 0 48da 48db 0
e2 :2 0 48dc 48dd
0 48df 2930 48e1
48d3 48d9 0 48e2
0 48df 0 48e2
2932 0 48e3 2935
492d e5 :3 0 15
:3 0 e1 :3 0 48e6
48e7 0 e4 :3 0
48e8 48e9 0 4923
c3 :3 0 c4 :3 0
48eb 48ec 0 c3
:3 0 d3 :3 0 48ee
48ef 0 e6 :2 0
2 :4 0 32a :2 0
d5 :2 0 2a :2 0
2938 48f4 48f6 :3 0
293b 48f0 48f8 48ed
48fa 48f9 :2 0 c6
:3 0 d6 :3 0 48fc
48fd 0 c8 :4 0
32b :4 0 cb :2 0
cc :3 0 293f 4901
4903 :3 0 cb :2 0
e9 :4 0 2942 4905
4907 :3 0 cb :2 0
ea :4 0 2945 4909
490b :3 0 cb :2 0
e4 :3 0 2948 490d
490f :3 0 cb :2 0
eb :4 0 294b 4911
4913 :3 0 cb :2 0
a0 :3 0 ec :3 0
2a :2 0 ed :2 0
294e 4916 491a 2952
4915 491c :3 0 2955
48fe 491e :2 0 4920
2958 4921 48fb 4920
0 4922 295a 0
4923 295c 4926 :3 0
4926 0 4926 4925
4923 4924 :6 0 4928
de :3 0 295f 492a
2961 4929 4928 :2 0
492b 2963 :2 0 492d
0 492d 492c 48e3
492b :6 0 492f 1
:3 0 2965 49a4 1fb
:3 0 312 :3 0 31
:3 0 313 :3 0 32
:3 0 314 :3 0 3f
:3 0 315 :3 0 3f
:3 0 58 :3 0 316
:3 0 3f :3 0 5b
:3 0 91 :3 0 22
:3 0 92 :3 0 21
:4 0 32c 1 :8 0
4957 e0 :4 0 4942
:3 0 f7 :3 0 da
:2 0 2969 4945 4946
:3 0 15 :3 0 e1
:3 0 4948 4949 0
3d :2 0 494a 494b
0 494d 296c 4954
15 :3 0 e1 :3 0
494e 494f 0 e2
:2 0 4950 4951 0
4953 296e 4955 4947
494d 0 4956 0
4953 0 4956 2970
0 4957 2973 49a1
e5 :3 0 15 :3 0
e1 :3 0 495a 495b
0 e4 :3 0 495c
495d 0 4997 c3
:3 0 c4 :3 0 495f
4960 0 c3 :3 0
d3 :3 0 4962 4963
0 e6 :2 0 2
:4 0 32d :2 0 d5
:2 0 2a :2 0 2976
4968 496a :3 0 2979
4964 496c 4961 496e
496d :2 0 c6 :3 0
d6 :3 0 4970 4971
0 c8 :4 0 32e
:4 0 cb :2 0 cc
:3 0 297d 4975 4977
:3 0 cb :2 0 e9
:4 0 2980 4979 497b
:3 0 cb :2 0 ea
:4 0 2983 497d 497f
:3 0 cb :2 0 e4
:3 0 2986 4981 4983
:3 0 cb :2 0 eb
:4 0 2989 4985 4987
:3 0 cb :2 0 a0
:3 0 ec :3 0 2a
:2 0 ed :2 0 298c
498a 498e 2990 4989
4990 :3 0 2993 4972
4992 :2 0 4994 2996
4995 496f 4994 0
4996 2998 0 4997
299a 499a :3 0 499a
0 499a 4999 4997
4998 :6 0 499c e0
:3 0 299d 499e 299f
499d 499c :2 0 499f
29a1 :2 0 49a1 0
49a1 49a0 4957 499f
:6 0 49a3 1 :3 0
29a3 49a5 48bd 492f
0 49a6 0 49a3
0 49a6 29a5 0
49d5 a0 :3 0 6f
:3 0 2a :2 0 2a
:2 0 29a8 49a7 49ab
da :2 0 1bd :4 0
29ae 49ad 49af :3 0
49b0 :2 0 84 :3 0
63 :3 0 3d :2 0
29b1 49b2 49b5 da
:2 0 3d :2 0 29b6
49b7 49b9 :3 0 49ba
:2 0 49b1 49bc 49bb
:2 0 7a :3 0 3d
:2 0 49be 49bf 0
49d2 15 :3 0 e1
:3 0 49c1 49c2 0
1bf :3 0 22 :3 0
22 :3 0 1e :3 0
2b :3 0 2d :3 0
58 :3 0 5b :3 0
7a :3 0 79 :3 0
78 :3 0 29b9 49c4
49cf 49c3 49d0 0
49d2 29c4 49d3 49bd
49d2 0 49d4 29c7
0 49d5 29c9 49d6
48b4 49d5 0 49d7
29cc 0 49d8 29ce
49d9 46e8 49d8 0
49da 29d4 0 4a3e
71 :3 0 32f :3 0
22 :3 0 29d6 49dc
49de 49db 49df 0
4a3e 15 :3 0 e1
:3 0 49e1 49e2 0
da :2 0 e2 :2 0
29da 49e4 49e6 :3 0
15 :3 0 e1 :3 0
49e8 49e9 0 3d
:2 0 49ea 49eb 0
49ed 29dd 49ee 49e7
49ed 0 49ef 29df
0 4a3e c3 :3 0
c4 :3 0 49f0 49f1
0 c3 :3 0 d3
:3 0 49f3 49f4 0
139 :2 0 2 :4 0
330 :2 0 d5 :2 0
2a :2 0 29e1 49f9
49fb :3 0 29e4 49f5
49fd 49f2 49ff 49fe
:2 0 c6 :3 0 d6
:3 0 4a01 4a02 0
c8 :4 0 331 :4 0
cb :2 0 cc :3 0
29e8 4a06 4a08 :3 0
cb :2 0 e9 :4 0
29eb 4a0a 4a0c :3 0
cb :2 0 f0 :4 0
29ee 4a0e 4a10 :3 0
cb :2 0 84 :3 0
d0 :3 0 15 :3 0
e1 :3 0 4a15 4a16
0 29f1 4a14 4a18
d1 :4 0 29f3 4a13
4a1b 29f6 4a12 4a1d
:3 0 cb :2 0 f2
:4 0 29f9 4a1f 4a21
:3 0 cb :2 0 ce
:4 0 29fc 4a23 4a25
:3 0 cb :2 0 1e
:3 0 29ff 4a27 4a29
:3 0 cb :2 0 ce
:4 0 2a02 4a2b 4a2d
:3 0 2a05 4a03 4a2f
:2 0 4a31 2a08 4a32
4a00 4a31 0 4a33
2a0a 0 4a3e f5
:3 0 332 :3 0 4a34
4a35 0 15 :3 0
e1 :3 0 4a37 4a38
0 1e :3 0 f7
:3 0 2a0c 4a36 4a3c
:2 0 4a3e 2a10 4adf
15 :3 0 333 :2 0
4 4a3f 4a40 0
c3 :3 0 c4 :3 0
4a42 4a43 0 c3
:3 0 d3 :3 0 4a45
4a46 0 e6 :2 0
2 :4 0 334 :2 0
d5 :2 0 2a :2 0
2a67 4a4b 4a4d :3 0
2a6a 4a47 4a4f 4a44
4a51 4a50 :2 0 c6
:3 0 d6 :3 0 4a53
4a54 0 c8 :4 0
335 :4 0 cb :2 0
cc :3 0 2a6e 4a58
4a5a :3 0 2a71 4a55
4a5c :2 0 4a75 c6
:3 0 d6 :3 0 4a5e
4a5f 0 c8 :4 0
336 :4 0 cb :2 0
15 :3 0 337 :3 0
4a64 4a65 0 2a74
4a63 4a67 :3 0 cb
:2 0 f2 :4 0 2a77
4a69 4a6b :3 0 cb
:2 0 15 :3 0 338
:3 0 4a6e 4a6f 0
2a7a 4a6d 4a71 :3 0
2a7d 4a60 4a73 :2 0
4a75 2a80 4a76 4a52
4a75 0 4a77 2a83
0 4a87 df :3 0
c2 :3 0 15 :3 0
337 :3 0 339 :3 0
15 :3 0 338 :3 0
33a :3 0 1ce :4 0
33b 1 :a 0 4a83
:2 0 4a87 4a79 4a81
:2 0 14 :3 0 c2
:3 0 4a85 :2 0 4a87
2a85 4a89 2a89 4a88
4a87 :2 0 4add e5
:3 0 15 :3 0 e1
:3 0 4a8c 4a8d 0
e4 :3 0 4a8e 4a8f
0 4ad5 c3 :3 0
c4 :3 0 4a91 4a92
0 c3 :3 0 d3
:3 0 4a94 4a95 0
e6 :2 0 2 :4 0
33c :2 0 d5 :2 0
2a :2 0 2a8b 4a9a
4a9c :3 0 2a8e 4a96
4a9e 4a93 4aa0 4a9f
:2 0 c6 :3 0 d6
:3 0 4aa2 4aa3 0
c8 :4 0 33d :4 0
cb :2 0 cc :3 0
2a92 4aa7 4aa9 :3 0
2a95 4aa4 4aab :2 0
4ac5 c6 :3 0 d6
:3 0 4aad 4aae 0
c8 :4 0 ea :4 0
cb :2 0 e4 :3 0
2a98 4ab2 4ab4 :3 0
cb :2 0 eb :4 0
2a9b 4ab6 4ab8 :3 0
cb :2 0 a0 :3 0
ec :3 0 2a :2 0
ed :2 0 2a9e 4abb
4abf 2aa2 4aba 4ac1
:3 0 2aa5 4aaf 4ac3
:2 0 4ac5 2aa8 4ac6
4aa1 4ac5 0 4ac7
2aab 0 4ad5 df
:3 0 c2 :3 0 339
:3 0 15 :3 0 338
:3 0 33a :3 0 1ce
:4 0 33e 1 :a 0
4ad1 :2 0 4ad5 4ac9
4acf :2 0 14 :3 0
c2 :3 0 4ad3 :2 0
4ad5 2aad 4ad8 :3 0
4ad8 0 4ad8 4ad7
4ad5 4ad6 :6 0 4ada
1 :3 0 2ab2 4adc
2ab4 4adb 4ada :2 0
4add 2ab6 :2 0 4adf
2ab9 4adf 4ade 4a3e
4add :6 0 4ae0 :2 0
2 44 4adf 4ae3
:3 0 4ae2 4ae0 4ae4
:8 0 
2b21
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
4f 1 4d 1
56 1 54 1
5d 1 5b 1
64 1 62 1
6b 1 69 1
72 1 70 1
79 1 77 1
80 1 7e 1
87 1 85 1
8e 1 8c 1
95 1 93 1
9a 1 9f 1
a4 1 a9 1
b0 1 ae 1
b5 1 ba 1
c1 1 bf 1
c8 1 c6 1
cd 1 d2 1
d7 1 dc 1
e3 1 e1 1
ea 1 e8 1
f1 1 ef 1
f8 1 f6 1
ff 1 fd 1
104 1 10a 1
110 1 116 1
11c 1 122 1
128 1 12e 1
134 1 13a 1
140 1 146 1
14c 1 152 1
158 1 15e 1
164 1 16a 1
170 1 176 1
17c 1 182 1
188 1 18e 1
194 1 19a 1
1a0 1 1a6 1
1ac 1 1b2 1
1b8 1 1be 1
1c4 1 1ca 1
1d0 1 1d6 1
1dc 1 1e2 1
1e8 1 1ee 1
1f6 1 1f4 1
1fd 1 1fb 1
202 1 208 1
210 1 20e 1
215 1 21d 1
21b 1 224 1
222 1 229 1
22f 1 235 1
23a 1 23f 1
245 1 24b 1
251 1 257 1
25d 1 263 1
269 1 26f 1
275 1 27b 1
283 1 281 1
28a 1 288 1
291 1 28f 2
29b 29c 1 29e
1 296 1 2a4
1 2aa 1 2ba
1 2ce 1 346
1 34c 1 359
1 365 2 368
36a 2 36d 36f
2 371 373 2
375 377 2 379
37b 2 37d 37f
2 381 383 2
385 387 2 389
38b 2 38d 38f
2 391 393 2
395 397 2 399
39b 2 39d 39f
2 3a1 3a3 2
3a5 3a7 2 3a9
3ab 2 3ad 3af
2 3b1 3b3 2
3b5 3b7 2 3b9
3bb 1 3c1 2
3c3 3c4 2 3bd
3c6 2 3c8 3ca
1 3d0 2 3d2
3d3 2 3cc 3d5
2 3d7 3d9 1
3df 2 3e1 3e2
2 3db 3e4 2
3e6 3e8 1 3ee
2 3f0 3f1 2
3ea 3f3 2 3f5
3f7 1 3fd 2
3ff 400 2 3f9
402 2 404 406
1 40c 2 40e
40f 2 408 411
2 413 415 1
41b 2 41d 41e
2 417 420 2
422 424 1 42a
2 42c 42d 2
426 42f 2 431
433 1 439 2
43b 43c 2 435
43e 2 440 442
2 444 446 2
448 44a 2 44c
44e 2 450 452
4 361 367 36c
454 1 456 1
458 2 462 464
3 460 461 466
2 46f 471 2
46e 473 1 475
1 477 2 48e
48f 2 491 494
2 499 49a 1
4a0 2 49c 4a0
2 4a5 4a6 1
4ac 2 4a8 4ac
1 4b4 1 4b6
1 4dd 1 4e3
2 4e5 4e6 2
4ef 4f5 2 506
508 3 504 505
50a 2 513 515
2 517 519 2
51b 51d 2 51f
521 2 523 525
3 52a 52b 52c
2 527 52e 2
512 530 1 532
1 534 2 4fd
535 1 539 1
4f8 1 53d 2
543 544 1 548
2 546 548 2
553 555 3 551
552 557 2 560
562 2 564 566
2 568 56a 1
572 2 574 575
2 56c 577 2
579 57b 2 57d
57f 2 581 583
2 585 587 2
55f 589 1 58b
1 58d 2 597
599 3 595 596
59b 2 5a4 5a6
2 5a3 5a8 1
5aa 1 5ac 3
5b3 5b4 5b5 3
58e 5ad 5b7 1
5b9 2 5cc 5d1
2 5e2 5e4 3
5e0 5e1 5e6 2
5ef 5f1 2 5f3
5f5 2 5f7 5f9
2 5fb 5fd 2
5ff 601 3 606
607 608 2 603
60a 2 5ee 60c
1 60e 1 610
2 5d9 611 1
615 1 5d4 1
619 1 624 2
620 624 2 630
632 3 62e 62f
634 2 63d 63f
2 641 643 2
645 647 1 64f
2 651 652 2
649 654 2 656
658 2 65a 65c
2 65e 660 2
662 664 2 63c
666 1 668 1
66a 2 674 676
3 672 673 678
2 681 683 2
680 685 1 687
1 689 3 690
691 692 3 66b
68a 694 1 696
2 6a0 6a5 2
6b6 6b8 3 6b4
6b5 6ba 2 6c3
6c5 2 6c7 6c9
2 6cb 6cd 2
6cf 6d1 2 6d3
6d5 3 6da 6db
6dc 2 6d7 6de
2 6c2 6e0 1
6e2 1 6e4 2
6ad 6e5 1 6e9
1 6a8 1 6ed
2 6f3 6f4 1
6f8 2 6f6 6f8
2 703 705 3
701 702 707 2
710 712 2 714
716 2 718 71a
1 722 2 724
725 2 71c 727
2 729 72b 2
72d 72f 2 731
733 2 735 737
2 70f 739 1
73b 1 73d 2
747 749 3 745
746 74b 2 754
756 2 753 758
1 75a 1 75c
3 763 764 765
3 73e 75d 767
1 769 2 790
795 2 7a6 7a8
3 7a4 7a5 7aa
2 7b3 7b5 2
7b7 7b9 2 7bb
7bd 2 7bf 7c1
2 7c3 7c5 3
7ca 7cb 7cc 2
7c7 7ce 2 7b2
7d0 1 7d2 1
7d4 2 79d 7d5
1 7d9 1 798
1 7dd 1 7e8
2 7e4 7e8 2
7f4 7f6 3 7f2
7f3 7f8 2 801
803 2 805 807
2 809 80b 1
813 2 815 816
2 80d 818 2
81a 81c 2 81e
820 2 822 824
2 826 828 2
800 82a 1 82c
1 82e 2 838
83a 3 836 837
83c 2 845 847
2 844 849 1
84b 1 84d 3
854 855 856 3
82f 84e 858 1
85a 2 863 868
2 879 87b 3
877 878 87d 2
886 888 2 88a
88c 2 88e 890
2 892 894 2
896 898 3 89d
89e 89f 2 89a
8a1 2 885 8a3
1 8a5 1 8a7
2 870 8a8 1
8ac 1 86b 1
8b0 1 8bb 2
8b7 8bb 2 8c7
8c9 3 8c5 8c6
8cb 2 8d4 8d6
2 8d8 8da 2
8dc 8de 1 8e6
2 8e8 8e9 2
8e0 8eb 2 8ed
8ef 2 8f1 8f3
2 8f5 8f7 2
8f9 8fb 2 8d3
8fd 1 8ff 1
901 2 90b 90d
3 909 90a 90f
2 918 91a 2
917 91c 1 91e
1 920 3 927
928 929 3 902
921 92b 1 92d
2 934 939 2
94a 94c 3 948
949 94e 2 957
959 2 95b 95d
2 95f 961 2
963 965 2 967
969 3 96e 96f
970 2 96b 972
2 956 974 1
976 1 978 2
941 979 1 97d
1 93c 1 981
2 989 98a 1
98e 2 98c 98e
1 993 1 995
1 99d 2 999
99d 2 9a9 9ab
3 9a7 9a8 9ad
2 9b6 9b8 2
9ba 9bc 2 9be
9c0 1 9c8 2
9ca 9cb 2 9c2
9cd 2 9cf 9d1
2 9d3 9d5 2
9d7 9d9 2 9db
9dd 2 9b5 9df
1 9e1 1 9e3
2 9ed 9ef 3
9eb 9ec 9f1 2
9fa 9fc 2 9f9
9fe 1 a00 1
a02 3 a09 a0a
a0b 3 9e4 a03
a0d 1 a0f 2
a17 a18 2 a1a
a1b 2 a22 a23
2 a25 a26 2
a2d a2e 2 a30
a31 1 a37 2
a35 a37 2 a3b
a3c 1 a40 2
a3e a40 2 a4e
a53 2 a64 a66
3 a62 a63 a68
2 a71 a73 2
a75 a77 2 a79
a7b 2 a7d a7f
2 a81 a83 3
a88 a89 a8a 2
a85 a8c 2 a70
a8e 1 a90 1
a92 2 a5b a93
1 a97 1 a56
1 a9b 1 a9e
2 aa3 aa4 1
aa8 2 aa6 aa8
2 ab6 abb 2
acc ace 3 aca
acb ad0 2 ad9
adb 2 add adf
2 ae1 ae3 2
ae5 ae7 2 ae9
aeb 3 af0 af1
af2 2 aed af4
2 ad8 af6 1
af8 1 afa 2
ac3 afb 1 aff
1 abe 1 b03
1 b06 2 b0a
b09 2 b0d b0e
1 b12 2 b10
b12 2 b1d b1f
3 b1b b1c b21
2 b2a b2c 2
b2e b30 2 b32
b34 1 b3c 2
b3e b3f 2 b36
b41 2 b43 b45
2 b47 b49 2
b4b b4d 2 b4f
b51 2 b29 b53
1 b55 1 b57
2 b61 b63 3
b5f b60 b65 2
b6e b70 2 b6d
b72 1 b74 1
b76 3 b7d b7e
b7f 3 b58 b77
b81 1 b83 2
b0b b84 2 b91
b96 2 ba7 ba9
3 ba5 ba6 bab
2 bb4 bb6 2
bb8 bba 2 bbc
bbe 2 bc0 bc2
2 bc4 bc6 3
bcb bcc bcd 2
bc8 bcf 2 bb3
bd1 1 bd3 1
bd5 2 b9e bd6
1 bda 1 b99
1 bde 2 bee
bf3 2 c04 c06
3 c02 c03 c08
2 c11 c13 2
c15 c17 2 c19
c1b 2 c1d c1f
2 c21 c23 3
c28 c29 c2a 2
c25 c2c 2 c10
c2e 1 c30 1
c32 2 bfb c33
1 c37 1 bf6
1 c3b 2 c42
c43 1 c45 1
c4a 2 c48 c4a
2 c4e c4f 1
c53 2 c51 c53
2 c58 c59 1
c5d 2 c5b c5d
2 c70 c75 2
c86 c88 3 c84
c85 c8a 2 c93
c95 2 c97 c99
2 c9b c9d 2
c9f ca1 2 ca3
ca5 3 caa cab
cac 2 ca7 cae
2 c92 cb0 1
cb2 1 cb4 2
c7d cb5 1 cb9
1 c78 1 cbd
2 cc3 cc4 1
cc8 2 cc6 cc8
2 cd3 cd5 3
cd1 cd2 cd7 2
ce0 ce2 2 ce4
ce6 2 ce8 cea
1 cf2 2 cf4
cf5 2 cec cf7
2 cf9 cfb 2
cfd cff 2 d01
d03 2 d05 d07
2 cdf d09 1
d0b 1 d0d 2
d17 d19 3 d15
d16 d1b 2 d24
d26 2 d23 d28
1 d2a 1 d2c
3 d33 d34 d35
3 d0e d2d d37
1 d39 2 cc0
d3a 1 d3c 3
be1 c3e d3d 2
d3f d40 1 d61
1 d67 2 d69
d6a 1 d72 2
d6e d72 1 d78
1 d7c 2 d7e
d7f 2 d83 d89
2 d9a d9c 3
d98 d99 d9e 2
da7 da9 2 dab
dad 2 daf db1
2 db3 db5 2
db7 db9 3 dbe
dbf dc0 2 dbb
dc2 2 da6 dc4
1 dc6 1 dc8
2 d91 dc9 1
dcd 1 d8c 1
dd1 2 dd7 dd8
1 ddc 2 dda
ddc 2 dea def
2 e00 e02 3
dfe dff e04 2
e0d e0f 2 e11
e13 2 e15 e17
2 e19 e1b 2
e1d e1f 3 e24
e25 e26 2 e21
e28 2 e0c e2a
1 e2c 1 e2e
2 df7 e2f 1
e33 1 df2 1
e37 2 e3d e3e
1 e42 2 e40
e42 2 e55 e5a
2 e6b e6d 3
e69 e6a e6f 2
e78 e7a 2 e7c
e7e 2 e80 e82
2 e84 e86 2
e88 e8a 3 e8f
e90 e91 2 e8c
e93 2 e77 e95
1 e97 1 e99
2 e62 e9a 1
e9e 1 e5d 1
ea2 1 ead 2
ea9 ead 2 eb9
ebb 3 eb7 eb8
ebd 2 ec6 ec8
2 eca ecc 2
ece ed0 1 ed8
2 eda edb 2
ed2 edd 2 edf
ee1 2 ee3 ee5
2 ee7 ee9 2
eeb eed 2 ec5
eef 1 ef1 1
ef3 2 efd eff
3 efb efc f01
2 f0a f0c 2
f09 f0e 1 f10
1 f12 3 f19
f1a f1b 3 ef4
f13 f1d 1 f20
1 f26 3 f31
f32 f33 1 f37
2 f35 f37 3
f3e f3f f40 1
f44 2 f42 f44
2 f52 f54 3
f50 f51 f56 2
f5f f61 2 f63
f65 2 f67 f69
1 f71 2 f73
f74 2 f6b f76
2 f78 f7a 2
f7c f7e 2 f80
f82 2 f84 f86
2 f5e f88 1
f8a 1 f8c 2
f96 f98 3 f94
f95 f9a 2 fa3
fa5 2 fa2 fa7
1 fa9 1 fab
3 fb2 fb3 fb4
3 f8d fac fb6
1 fb8 1 fb9
2 fbc fbb 3
e47 ea5 fbd 1
fbf 2 fc2 fc3
1 fc7 2 fc5
fc7 2 fcc fcf
2 fdc fe1 2
ff2 ff4 3 ff0
ff1 ff6 2 fff
1001 2 1003 1005
2 1007 1009 2
100b 100d 2 100f
1011 3 1016 1017
1018 2 1013 101a
2 ffe 101c 1
101e 1 1020 2
fe9 1021 1 1025
1 fe4 1 1029
1 1034 2 1030
1034 2 1044 1045
4 1042 1047 104a
104b 7 105c 105d
105e 105f 1060 1061
1062 2 1069 106a
1 106c 1 108d
2 108c 108d 1
1095 1 109b 2
109d 109e 2 108a
109f 2 10b0 10b2
3 10ae 10af 10b4
2 10bd 10bf 2
10c1 10c3 2 10c5
10c7 2 10c9 10cb
2 10cd 10cf 3
10d4 10d5 10d6 2
10d1 10d8 2 10bc
10da 1 10dc 1
10de 2 10a7 10df
1 10e3 1 10a2
1 10e7 2 10f1
10f6 2 1107 1109
3 1105 1106 110b
2 1114 1116 2
1118 111a 2 111c
111e 2 1120 1122
2 1124 1126 3
112b 112c 112d 2
1128 112f 2 1113
1131 1 1133 1
1135 2 10fe 1136
1 113a 1 10f9
1 113e 2 1146
1147 1 114b 2
1149 114b 1 1150
2 115e 1163 2
1174 1176 3 1172
1173 1178 2 1181
1183 2 1185 1187
2 1189 118b 2
118d 118f 2 1191
1193 3 1198 1199
119a 2 1195 119c
2 1180 119e 1
11a0 1 11a2 2
116b 11a3 1 11a7
1 1166 1 11ab
1 11ae 2 11b1
11b2 2 11b5 11b6
1 11ba 2 11b8
11ba 1 11ca 2
11c9 11ca 1 11d2
1 11d8 2 11da
11db 2 11c7 11dc
2 11ed 11ef 3
11eb 11ec 11f1 2
11fa 11fc 2 11fe
1200 2 1202 1204
2 1206 1208 2
120a 120c 3 1211
1212 1213 2 120e
1215 2 11f9 1217
1 1219 1 121b
2 11e4 121c 1
1220 1 11df 1
1224 1 123d 2
123c 123d 1 1245
1 124b 2 124d
124e 2 123a 124f
2 1260 1262 3
125e 125f 1264 2
126d 126f 2 1271
1273 2 1275 1277
2 1279 127b 2
127d 127f 3 1284
1285 1286 2 1281
1288 2 126c 128a
1 128c 1 128e
2 1257 128f 1
1293 1 1252 1
1297 2 1227 129a
1 12b1 2 12b0
12b1 1 12b9 1
12bf 2 12c1 12c2
2 12ae 12c3 2
12d4 12d6 3 12d2
12d3 12d8 2 12e1
12e3 2 12e5 12e7
2 12e9 12eb 2
12ed 12ef 2 12f1
12f3 3 12f8 12f9
12fa 2 12f5 12fc
2 12e0 12fe 1
1300 1 1302 2
12cb 1303 1 1307
1 12c6 1 130b
1 130e 2 1311
1312 c 103a 103f
104e 1053 1056 1059
1065 106f 10ea 1141
11b3 1313 1 131c
2 1318 131c 2
1326 132b 2 133c
133e 3 133a 133b
1340 2 1349 134b
2 134d 134f 2
1351 1353 2 1355
1357 2 1359 135b
3 1360 1361 1362
2 135d 1364 2
1348 1366 1 1368
1 136a 2 1333
136b 1 136f 1
132e 1 1373 2
1379 137a 1 1380
2 137c 1380 2
1387 1388 4 1385
138a 138d 138e 1
139f 2 139e 139f
1 13a7 1 13ad
2 13af 13b0 2
139c 13b1 2 13c2
13c4 3 13c0 13c1
13c6 2 13cf 13d1
2 13d3 13d5 2
13d7 13d9 2 13db
13dd 2 13df 13e1
3 13e6 13e7 13e8
2 13e3 13ea 2
13ce 13ec 1 13ee
1 13f0 2 13b9
13f1 1 13f5 1
13b4 1 13f9 1
1400 3 1391 13fc
1403 2 1408 1409
2 140b 140e 1
1415 2 1411 1415
1 1426 2 1425
1426 1 142e 1
1434 2 1436 1437
2 1423 1438 2
1449 144b 3 1447
1448 144d 2 1456
1458 2 145a 145c
2 145e 1460 2
1462 1464 2 1466
1468 3 146d 146e
146f 2 146a 1471
2 1455 1473 1
1475 1 1477 2
1440 1478 1 147c
1 143b 1 1480
1 1487 2 1483
148a 1 149b 2
149a 149b 1 14a3
1 14a9 2 14ab
14ac 2 1498 14ad
2 14be 14c0 3
14bc 14bd 14c2 2
14cb 14cd 2 14cf
14d1 2 14d3 14d5
2 14d7 14d9 2
14db 14dd 3 14e2
14e3 14e4 2 14df
14e6 2 14ca 14e8
1 14ea 1 14ec
2 14b5 14ed 1
14f1 1 14b0 1
14f5 1 14fc 2
14f8 14ff 3 1501
148c 1502 2 1376
1503 2 1506 1505
2 102c 1507 2
1509 150a 3 e3a
fc0 150b 1 150f
2 1511 1512 2
1523 1524 1 1528
2 1526 1528 2
152d 152e 1 1532
2 1530 1532 a
153a 153b 153c 153d
153e 153f 1540 1541
1542 1543 1 1546
1 1548 2 1560
1565 2 1576 1578
3 1574 1575 157a
2 1583 1585 2
1587 1589 2 158b
158d 2 158f 1591
2 1593 1595 3
159a 159b 159c 2
1597 159e 2 1582
15a0 1 15a2 1
15a4 2 156d 15a5
1 15a9 1 1568
1 15ad 1 15b8
2 15b4 15b8 1
15be 1 15c0 2
15d2 15d7 2 15e8
15ea 3 15e6 15e7
15ec 2 15f5 15f7
2 15f9 15fb 2
15fd 15ff 2 1601
1603 2 1605 1607
3 160c 160d 160e
2 1609 1610 2
15f4 1612 1 1614
1 1616 2 15df
1617 1 161b 1
15da 1 161f 2
1627 1628 1 162c
2 162a 162c 2
1639 163e 2 164f
1651 3 164d 164e
1653 2 165c 165e
2 1660 1662 2
1664 1666 2 1668
166a 2 166c 166e
3 1673 1674 1675
2 1670 1677 2
165b 1679 1 167b
1 167d 2 1646
167e 1 1682 1
1641 1 1686 2
168c 168d 1 1691
2 168f 1691 1
1696 1 169a 2
169c 169d 2 1689
169e 1 16a0 2
16a3 16a4 1 16a8
2 16a6 16a8 2
16ae 16af 1 16b3
2 16b1 16b3 2
16de 16e3 2 16f4
16f6 3 16f2 16f3
16f8 2 1701 1703
2 1705 1707 2
1709 170b 2 170d
170f 2 1711 1713
3 1718 1719 171a
2 1715 171c 2
1700 171e 1 1720
1 1722 2 16eb
1723 1 1727 1
16e6 1 172b 2
1737 1738 1 173c
2 173a 173c 2
1740 1741 2 1746
1747 1 1749 2
1743 1749 2 174e
174f 2 1754 1755
1 1757 2 1751
1757 2 175e 175f
1 1763 2 1761
1763 2 1769 176a
2 176c 176f 1
1774 2 1772 1774
2 1782 1784 3
1780 1781 1786 2
178f 1791 2 1793
1795 2 1797 1799
1 17a1 2 17a3
17a4 2 179b 17a6
2 17a8 17aa 2
17ac 17ae 2 17b0
17b2 2 17b4 17b6
2 178e 17b8 1
17ba 1 17bc 2
17c6 17c8 3 17c4
17c5 17ca 2 17d3
17d5 2 17d2 17d7
1 17d9 1 17db
3 17e2 17e3 17e4
3 17bd 17dc 17e6
2 17ec 17ed 1
17f1 2 17ef 17f1
1 17f6 1 17f8
2 17ea 17f9 2
17fb 17fc 1 17fd
1 17ff a 1800
1803 1806 1809 180c
180f 1812 1815 1818
181b 1 181d 1
1825 2 1821 1825
1 1829 3 1832
1833 1834 1 1838
2 1836 1838 1
183d a 1845 1846
1847 1848 1849 184a
184b 184c 184d 184e
2 1840 1851 1
1853 2 1856 1857
1 185b 2 1859
185b 1 1864 2
1863 1864 1 186c
1 1872 2 1874
1875 2 1861 1876
2 1887 1889 3
1885 1886 188b 2
1894 1896 2 1898
189a 2 189c 189e
2 18a0 18a2 2
18a4 18a6 3 18ab
18ac 18ad 2 18a8
18af 2 1893 18b1
1 18b3 1 18b5
2 187e 18b6 1
18ba 1 1879 1
18be 1 18cb 2
18ca 18cb 1 18d3
1 18d9 2 18db
18dc 2 18c8 18dd
2 18ee 18f0 3
18ec 18ed 18f2 2
18fb 18fd 2 18ff
1901 2 1903 1905
2 1907 1909 2
190b 190d 3 1912
1913 1914 2 190f
1916 2 18fa 1918
1 191a 1 191c
2 18e5 191d 1
1921 1 18e0 1
1925 2 1935 193a
2 194b 194d 3
1949 194a 194f 2
1958 195a 2 195c
195e 2 1960 1962
2 1964 1966 2
1968 196a 3 196f
1970 1971 2 196c
1973 2 1957 1975
1 1977 1 1979
2 1942 197a 1
197e 1 193d 1
1982 3 198a 198b
198c 1 1990 2
198e 1990 2 199d
19a2 2 19b3 19b5
3 19b1 19b2 19b7
2 19c0 19c2 2
19c4 19c6 2 19c8
19ca 2 19cc 19ce
2 19d0 19d2 3
19d7 19d8 19d9 2
19d4 19db 2 19bf
19dd 1 19df 1
19e1 2 19aa 19e2
1 19e6 1 19a5
1 19ea 1 19ed
1 19f0 5 18c1
1928 192c 1985 19f1
2 19f4 19f5 1
19f9 2 19f7 19f9
2 19fe 19ff 1
1a03 2 1a01 1a03
2 1a0b 1a0c 2
1a11 1a12 2 1a0e
1a14 2 1a1a 1a1b
2 1a20 1a21 2
1a1d 1a23 2 1a29
1a2a 2 1a2f 1a30
2 1a2c 1a32 2
1a38 1a39 2 1a3e
1a3f 2 1a3b 1a41
2 1a46 1a47 1
1a4b 2 1a49 1a4b
1 1a6f 2 1a6e
1a6f 1 1a77 1
1a7d 2 1a7f 1a80
2 1a6c 1a81 2
1a92 1a94 3 1a90
1a91 1a96 2 1a9f
1aa1 2 1aa3 1aa5
2 1aa7 1aa9 2
1aab 1aad 2 1aaf
1ab1 3 1ab6 1ab7
1ab8 2 1ab3 1aba
2 1a9e 1abc 1
1abe 1 1ac0 2
1a89 1ac1 1 1ac5
1 1a84 1 1ac9
1 1acc 1 1af4
2 1af3 1af4 1
1afc 1 1b02 2
1b04 1b05 2 1af1
1b06 2 1b17 1b19
3 1b15 1b16 1b1b
2 1b24 1b26 2
1b28 1b2a 2 1b2c
1b2e 2 1b30 1b32
2 1b34 1b36 3
1b3b 1b3c 1b3d 2
1b38 1b3f 2 1b23
1b41 1 1b43 1
1b45 2 1b0e 1b46
1 1b4a 1 1b09
1 1b4e 1 1b51
2 1b54 1b55 5
1a17 1a26 1a35 1a44
1b56 2 1b5a 1b5b
1 1b5f 2 1b5d
1b5f 2 1b64 1b65
2 1b6a 1b6b 2
1b67 1b6d 2 1b73
1b74 2 1b79 1b7a
2 1b76 1b7c 1
1b9d 2 1b9c 1b9d
1 1ba5 1 1bab
2 1bad 1bae 2
1b9a 1baf 2 1bc0
1bc2 3 1bbe 1bbf
1bc4 2 1bcd 1bcf
2 1bd1 1bd3 2
1bd5 1bd7 2 1bd9
1bdb 2 1bdd 1bdf
3 1be4 1be5 1be6
2 1be1 1be8 2
1bcc 1bea 1 1bec
1 1bee 2 1bb7
1bef 1 1bf3 1
1bb2 1 1bf7 3
1b70 1b7f 1bfa 2
1c00 1c01 1 1c05
2 1c03 1c05 2
1c0a 1c0b 2 1c10
1c11 2 1c0d 1c13
2 1c19 1c1a 2
1c1f 1c20 2 1c1c
1c22 2 1c27 1c28
1 1c2c 2 1c2a
1c2c 1 1c48 2
1c47 1c48 1 1c50
1 1c56 2 1c58
1c59 2 1c45 1c5a
2 1c6b 1c6d 3
1c69 1c6a 1c6f 2
1c78 1c7a 2 1c7c
1c7e 2 1c80 1c82
2 1c84 1c86 2
1c88 1c8a 3 1c8f
1c90 1c91 2 1c8c
1c93 2 1c77 1c95
1 1c97 1 1c99
2 1c62 1c9a 1
1c9e 1 1c5d 1
1ca2 1 1ca5 1
1cc5 2 1cc4 1cc5
1 1ccd 1 1cd3
2 1cd5 1cd6 2
1cc2 1cd7 2 1ce8
1cea 3 1ce6 1ce7
1cec 2 1cf5 1cf7
2 1cf9 1cfb 2
1cfd 1cff 2 1d01
1d03 2 1d05 1d07
3 1d0c 1d0d 1d0e
2 1d09 1d10 2
1cf4 1d12 1 1d14
1 1d16 2 1cdf
1d17 1 1d1b 1
1cda 1 1d1f 1
1d22 2 1d25 1d26
3 1c16 1c25 1d27
1 1d39 2 1d38
1d39 1 1d41 1
1d47 2 1d49 1d4a
2 1d36 1d4b 2
1d5c 1d5e 3 1d5a
1d5b 1d60 2 1d69
1d6b 2 1d6d 1d6f
2 1d71 1d73 2
1d75 1d77 2 1d79
1d7b 3 1d80 1d81
1d82 2 1d7d 1d84
2 1d68 1d86 1
1d88 1 1d8a 2
1d53 1d8b 1 1d8f
1 1d4e 1 1d93
1 1d96 4 1d99
1bfe 1d29 1d9a 1
1da4 2 1da3 1da4
1 1dac 1 1db2
2 1db4 1db5 2
1da1 1db6 2 1dc7
1dc9 3 1dc5 1dc6
1dcb 2 1dd4 1dd6
2 1dd8 1dda 2
1ddc 1dde 2 1de0
1de2 2 1de4 1de6
3 1deb 1dec 1ded
2 1de8 1def 2
1dd3 1df1 1 1df3
1 1df5 2 1dbe
1df6 1 1dfa 1
1db9 1 1dfe 1
1e11 2 1e10 1e11
1 1e19 1 1e1f
2 1e21 1e22 2
1e0e 1e23 2 1e34
1e36 3 1e32 1e33
1e38 2 1e41 1e43
2 1e45 1e47 2
1e49 1e4b 2 1e4d
1e4f 2 1e51 1e53
3 1e58 1e59 1e5a
2 1e55 1e5c 2
1e40 1e5e 1 1e60
1 1e62 2 1e2b
1e63 1 1e67 1
1e26 1 1e6b 3
1d9b 1e01 1e6e 2
1e71 1e72 1 1e7d
2 1e7c 1e7d 1
1e85 1 1e8b 2
1e8d 1e8e 2 1e7a
1e8f 2 1ea0 1ea2
3 1e9e 1e9f 1ea4
2 1ead 1eaf 2
1eb1 1eb3 2 1eb5
1eb7 2 1eb9 1ebb
2 1ebd 1ebf 3
1ec4 1ec5 1ec6 2
1ec1 1ec8 2 1eac
1eca 1 1ecc 1
1ece 2 1e97 1ecf
1 1ed3 1 1e92
1 1ed7 1 1ee4
2 1ee3 1ee4 1
1eec 1 1ef2 2
1ef4 1ef5 2 1ee1
1ef6 2 1f07 1f09
3 1f05 1f06 1f0b
2 1f14 1f16 2
1f18 1f1a 2 1f1c
1f1e 2 1f20 1f22
2 1f24 1f26 3
1f2b 1f2c 1f2d 2
1f28 1f2f 2 1f13
1f31 1 1f33 1
1f35 2 1efe 1f36
1 1f3a 1 1ef9
1 1f3e 2 1f44
1f45 1 1f49 2
1f47 1f49 2 1f4e
1f4f 1 1f53 2
1f51 1f53 2 1f62
1f63 1 1f67 2
1f65 1f67 1 1f6c
1 1f70 2 1f72
1f73 2 1f76 1f77
1 1f7b 2 1f79
1f7b 1 1f80 1
1f82 2 1f89 1f8a
2 1f8e 1f8f 2
1f93 1f94 2 1f98
1f99 2 1f9d 1f9e
2 1fa2 1fa3 2
1fa7 1fa8 2 1fac
1fad d 1f86 1f87
1f8c 1f91 1f96 1f9b
1fa0 1fa5 1faa 1faf
1fb0 1fb1 1fb2 2
1fb7 1fb8 1 1fbe
2 1fba 1fbe 2
1fc9 1fcb 3 1fc7
1fc8 1fcd 2 1fd6
1fd8 2 1fda 1fdc
2 1fde 1fe0 1
1fe8 2 1fea 1feb
2 1fe2 1fed 2
1fd5 1fef 1 1ff1
1 1ff3 2 1ffd
1fff 3 1ffb 1ffc
2001 2 200a 200c
2 2009 200e 1
2010 1 2012 2
2019 201a 3 1ff4
2013 201c 2 2020
2021 1 2025 2
2023 2025 2 2030
2032 3 202e 202f
2034 2 203d 203f
2 2041 2043 2
2045 2047 1 204d
2 204f 2050 2
2049 2052 2 2054
2056 2 2058 205a
2 205c 205e 2
2060 2062 2 203c
2064 1 2066 1
2068 2 2072 2074
3 2070 2071 2076
2 207f 2081 2
207e 2083 1 2085
1 2087 2 208d
208e 3 2090 2091
2092 3 2069 2088
2094 2 2097 2096
2 209a 209b 1
209f 2 209d 209f
1 20a6 2 20ad
20ae 2 20b0 20b3
1 20b6 2 20b8
20b9 20 20c0 20c1
20c2 20c3 20c4 20c5
20c6 20c7 20c8 20c9
20ca 20cb 20cc 20cd
20ce 20cf 20d0 20d1
20d2 20d3 20d4 20d5
20d6 20d7 20d8 20d9
20da 20db 20dc 20dd
20de 20df 2 20e4
20e5 1 20e9 2
20e7 20e9 2 20f4
20f6 3 20f2 20f3
20f8 2 2101 2103
2 2105 2107 2
2109 210b 1 2113
2 2115 2116 2
210d 2118 2 211a
211c 2 211e 2120
2 2122 2124 2
2126 2128 2 2100
212a 1 212c 1
212e 2 2138 213a
3 2136 2137 213c
2 2145 2147 2
2144 2149 1 214b
1 214d 3 2154
2155 2156 3 212f
214e 2158 2 215c
215d 1 2161 2
215f 2161 2 216c
216e 3 216a 216b
2170 2 2179 217b
2 217d 217f 2
2181 2183 1 218b
2 218d 218e 2
2185 2190 2 2192
2194 2 2196 2198
2 219a 219c 2
219e 21a0 2 2178
21a2 1 21a4 1
21a6 2 21b0 21b2
3 21ae 21af 21b4
2 21bd 21bf 2
21bc 21c1 1 21c3
1 21c5 3 21cc
21cd 21ce 3 21a7
21c6 21d0 2 21dc
21dd 2 21e1 21e2
5 21d8 21d9 21da
21df 21e4 2 21d5
21e7 3 21e9 21d2
21ea a 1f5b 1f5e
1f74 1f83 1fb5 2098
20ba 20bd 20e2 21eb
1 21ed 6 1854
1e73 1e76 1eda 1f41
21ee 1 21f0 5
172e 1732 1735 181e
21f1 3 21f5 21f6
21f7 1 21fb 2
21f9 21fb 2 2218
221d 2 222e 2230
3 222c 222d 2232
2 223b 223d 2
223f 2241 2 2243
2245 2 2247 2249
2 224b 224d 3
2252 2253 2254 2
224f 2256 2 223a
2258 1 225a 1
225c 2 2225 225d
1 2261 1 2220
1 2265 1 2270
2 226c 2270 1
2274 1 227e a
2286 2287 2288 2289
228a 228b 228c 228d
228e 228f 2 2281
2292 1 2294 2
2268 2295 2 22a4
22a9 2 22ba 22bc
3 22b8 22b9 22be
2 22c7 22c9 2
22cb 22cd 2 22cf
22d1 2 22d3 22d5
2 22d7 22d9 3
22de 22df 22e0 2
22db 22e2 2 22c6
22e4 1 22e6 1
22e8 2 22b1 22e9
1 22ed 1 22ac
1 22f1 1 22f4
3 22f7 2297 22f8
1 22f9 3 22fd
22fe 22ff 1 2303
2 2301 2303 2
2320 2325 2 2336
2338 3 2334 2335
233a 2 2343 2345
2 2347 2349 2
234b 234d 2 234f
2351 2 2353 2355
3 235a 235b 235c
2 2357 235e 2
2342 2360 1 2362
1 2364 2 232d
2365 1 2369 1
2328 1 236d 1
2378 2 2374 2378
1 237c 1 2386
a 238e 238f 2390
2391 2392 2393 2394
2395 2396 2397 2
2389 239a 1 239c
2 2370 239d 2
23ac 23b1 2 23c2
23c4 3 23c0 23c1
23c6 2 23cf 23d1
2 23d3 23d5 2
23d7 23d9 2 23db
23dd 2 23df 23e1
3 23e6 23e7 23e8
2 23e3 23ea 2
23ce 23ec 1 23ee
1 23f0 2 23b9
23f1 1 23f5 1
23b4 1 23f9 1
23fc 3 23ff 239f
2400 1 2402 2
2409 240a 1 240e
2 240c 240e 2
2415 2416 1 241a
2 2418 241a 2
2429 242a 1 242e
2 242c 242e 2
2433 2434 1 2437
1 2439 2 243c
243d 1 2441 2
243f 2441 2 2446
2447 1 244b 2
2449 244b 2 2452
2453 1 2457 2
2455 2457 2 245c
245d 1 2461 2
245f 2461 2 2469
246a 2 246f 2470
2 246c 2472 2
2478 2479 2 247e
247f 2 247b 2481
2 2487 2488 2
248d 248e 2 248a
2490 2 2496 2497
2 249c 249d 2
2499 249f 1 24da
2 24d9 24da 1
24e2 1 24e8 2
24ea 24eb 2 24d7
24ec 2 24fd 24ff
3 24fb 24fc 2501
2 250a 250c 2
250e 2510 2 2512
2514 2 2516 2518
2 251a 251c 3
2521 2522 2523 2
251e 2525 2 2509
2527 1 2529 1
252b 2 24f4 252c
1 2530 1 24ef
1 2534 5 2475
2484 2493 24a2 2537
2 253c 253d 1
2541 2 253f 2541
2 2546 2547 2
254c 254d 2 2549
254f 2 2555 2556
2 255b 255c 2
2558 255e 1 2599
2 2598 2599 1
25a1 1 25a7 2
25a9 25aa 2 2596
25ab 2 25bc 25be
3 25ba 25bb 25c0
2 25c9 25cb 2
25cd 25cf 2 25d1
25d3 2 25d5 25d7
2 25d9 25db 3
25e0 25e1 25e2 2
25dd 25e4 2 25c8
25e6 1 25e8 1
25ea 2 25b3 25eb
1 25ef 1 25ae
1 25f3 3 2552
2561 25f6 2 25fc
25fd 2 2602 2603
2 25ff 2605 2
260b 260c 2 2611
2612 2 260e 2614
1 264f 2 264e
264f 1 2657 1
265d 2 265f 2660
2 264c 2661 2
2672 2674 3 2670
2671 2676 2 267f
2681 2 2683 2685
2 2687 2689 2
268b 268d 2 268f
2691 3 2696 2697
2698 2 2693 269a
2 267e 269c 1
269e 1 26a0 2
2669 26a1 1 26a5
1 2664 1 26a9
3 2608 2617 26ac
3 26af 25f9 26b0
1 26b1 1 26ea
2 26e9 26ea 1
26f2 1 26f8 2
26fa 26fb 2 26e7
26fc 2 270d 270f
3 270b 270c 2711
2 271a 271c 2
271e 2720 2 2722
2724 2 2726 2728
2 272a 272c 3
2731 2732 2733 2
272e 2735 2 2719
2737 1 2739 1
273b 2 2704 273c
1 2740 1 26ff
1 2744 1 2747
2 274a 274b 5
2422 2427 243a 274c
274f 1 2751 2
2755 2757 3 2759
275a 275b 2 276a
276f 2 2780 2782
3 277e 277f 2784
2 278d 278f 2
2791 2793 2 2795
2797 2 2799 279b
2 279d 279f 3
27a4 27a5 27a6 2
27a1 27a8 2 278c
27aa 1 27ac 1
27ae 2 2777 27af
1 27b3 1 2772
1 27b7 1 27c7
2 27c5 27c7 2
27cc 27cd 1 27d1
2 27cf 27d1 2
280c 2811 2 2822
2824 3 2820 2821
2826 2 282f 2831
2 2833 2835 2
2837 2839 2 283b
283d 2 283f 2841
3 2846 2847 2848
2 2843 284a 2
282e 284c 1 284e
1 2850 2 2819
2851 1 2855 1
2814 1 2859 1
285c 1 285f 15
286b 286c 286d 286e
286f 2870 2871 2872
2873 2874 2875 2876
2877 2878 2879 287a
287b 287c 287d 287e
287f 1 288a 1
2890 2 2892 2893
1 289b 2 2897
289b 1 28a0 1
28a2 2 28a5 28a6
1 28aa 2 28a8
28aa 2 28af 28b0
1 28ba 2 28b9
28ba 1 28c2 1
28c8 2 28ca 28cb
2 28b7 28cc 2
28dd 28df 3 28db
28dc 28e1 2 28ea
28ec 2 28ee 28f0
2 28f2 28f4 2
28f6 28f8 2 28fa
28fc 3 2901 2902
2903 2 28fe 2905
2 28e9 2907 1
2909 1 290b 2
28d4 290c 1 2910
1 28cf 1 2914
1 291f 2 291e
291f 1 2927 1
292d 2 292f 2930
2 291c 2931 2
2942 2944 3 2940
2941 2946 2 294f
2951 2 2953 2955
2 2957 2959 2
295b 295d 2 295f
2961 3 2966 2967
2968 2 2963 296a
2 294e 296c 1
296e 1 2970 2
2939 2971 1 2975
1 2934 1 2979
1 2984 2 2983
2984 1 298c 1
2992 2 2994 2995
2 2981 2996 2
29a7 29a9 3 29a5
29a6 29ab 2 29b4
29b6 2 29b8 29ba
2 29bc 29be 2
29c0 29c2 2 29c4
29c6 3 29cb 29cc
29cd 2 29c8 29cf
2 29b3 29d1 1
29d3 1 29d5 2
299e 29d6 1 29da
1 2999 1 29de
1 29eb 2 29ea
29eb 1 29f3 1
29f9 2 29fb 29fc
2 29e8 29fd 2
2a0e 2a10 3 2a0c
2a0d 2a12 2 2a1b
2a1d 2 2a1f 2a21
2 2a23 2a25 2
2a27 2a29 2 2a2b
2a2d 3 2a32 2a33
2a34 2 2a2f 2a36
2 2a1a 2a38 1
2a3a 1 2a3c 2
2a05 2a3d 1 2a41
1 2a00 1 2a45
1 2a50 2 2a4f
2a50 1 2a58 1
2a5e 2 2a60 2a61
2 2a4d 2a62 2
2a73 2a75 3 2a71
2a72 2a77 2 2a80
2a82 2 2a84 2a86
2 2a88 2a8a 2
2a8c 2a8e 2 2a90
2a92 3 2a97 2a98
2a99 2 2a94 2a9b
2 2a7f 2a9d 1
2a9f 1 2aa1 2
2a6a 2aa2 1 2aa6
1 2a65 1 2aaa
1 2ab5 2 2ab4
2ab5 1 2abd 1
2ac3 2 2ac5 2ac6
2 2ab2 2ac7 2
2ad8 2ada 3 2ad6
2ad7 2adc 2 2ae5
2ae7 2 2ae9 2aeb
2 2aed 2aef 2
2af1 2af3 2 2af5
2af7 3 2afc 2afd
2afe 2 2af9 2b00
2 2ae4 2b02 1
2b04 1 2b06 2
2acf 2b07 1 2b0b
1 2aca 1 2b0f
7 28b3 2917 297c
29e1 2a48 2aad 2b12
2 2b1f 2b24 2
2b35 2b37 3 2b33
2b34 2b39 2 2b42
2b44 2 2b46 2b48
2 2b4a 2b4c 2
2b4e 2b50 2 2b52
2b54 3 2b59 2b5a
2b5b 2 2b56 2b5d
2 2b41 2b5f 1
2b61 1 2b63 2
2b2c 2b64 1 2b68
1 2b27 1 2b6c
1 2b77 2 2b73
2b77 2 2b7c 2b7d
1 2b81 2 2b7f
2b81 1 2b86 1
2b88 2 2b96 2b9b
2 2bac 2bae 3
2baa 2bab 2bb0 2
2bb9 2bbb 2 2bbd
2bbf 2 2bc1 2bc3
2 2bc5 2bc7 2
2bc9 2bcb 3 2bd0
2bd1 2bd2 2 2bcd
2bd4 2 2bb8 2bd6
1 2bd8 1 2bda
2 2ba3 2bdb 1
2bdf 1 2b9e 1
2be3 1 2bee 2
2bea 2bee 2 2bf4
2bf5 2 2bf7 2bfa
1 2c01 2 2bfd
2c01 1 2c12 2
2c11 2c12 1 2c1a
1 2c20 2 2c22
2c23 2 2c0f 2c24
2 2c35 2c37 3
2c33 2c34 2c39 2
2c42 2c44 2 2c46
2c48 2 2c4a 2c4c
2 2c4e 2c50 2
2c52 2c54 3 2c59
2c5a 2c5b 2 2c56
2c5d 2 2c41 2c5f
1 2c61 1 2c63
2 2c2c 2c64 1
2c68 1 2c27 1
2c6c 2 2c06 2c6f
2 2c74 2c75 1
2c7b 2 2c77 2c7b
2 2c82 2c83 4
2c80 2c85 2c88 2c89
1 2c9d 2 2c9c
2c9d 1 2ca5 1
2cab 2 2cad 2cae
2 2c9a 2caf 2
2cc0 2cc2 3 2cbe
2cbf 2cc4 2 2ccd
2ccf 2 2cd1 2cd3
2 2cd5 2cd7 2
2cd9 2cdb 2 2cdd
2cdf 3 2ce4 2ce5
2ce6 2 2ce1 2ce8
2 2ccc 2cea 1
2cec 1 2cee 2
2cb7 2cef 1 2cf3
1 2cb2 1 2cf7
2 2c8c 2cfa 1
2d11 2 2d10 2d11
1 2d19 1 2d1f
2 2d21 2d22 2
2d0e 2d23 2 2d34
2d36 3 2d32 2d33
2d38 2 2d41 2d43
2 2d45 2d47 2
2d49 2d4b 2 2d4d
2d4f 2 2d51 2d53
3 2d58 2d59 2d5a
2 2d55 2d5c 2
2d40 2d5e 1 2d60
1 2d62 2 2d2b
2d63 1 2d67 1
2d26 1 2d6b 1
2d6e 3 2d71 2cfd
2d72 1 2d7a 2
2d76 2d7a 2 2d7f
2d80 1 2d84 2
2d82 2d84 1 2d90
2 2d8f 2d90 1
2d98 1 2d9e 2
2da0 2da1 2 2d8d
2da2 2 2db3 2db5
3 2db1 2db2 2db7
2 2dc0 2dc2 2
2dc4 2dc6 2 2dc8
2dca 2 2dcc 2dce
2 2dd0 2dd2 3
2dd7 2dd8 2dd9 2
2dd4 2ddb 2 2dbf
2ddd 1 2ddf 1
2de1 2 2daa 2de2
1 2de6 1 2da5
1 2dea 1 2ded
1 2df0 2 2d73
2df1 2 2e15 2e1a
2 2e2b 2e2d 3
2e29 2e2a 2e2f 2
2e38 2e3a 2 2e3c
2e3e 2 2e40 2e42
2 2e44 2e46 2
2e48 2e4a 3 2e4f
2e50 2e51 2 2e4c
2e53 2 2e37 2e55
1 2e57 1 2e59
2 2e22 2e5a 1
2e5e 1 2e1d 1
2e62 1 2e6d 2
2e69 2e6d 1 2e71
2 2e7d 2e7e 4
2e7b 2e80 2e83 2e84
1 2e8e 2 2e8d
2e8e 1 2e96 1
2e9c 2 2e9e 2e9f
2 2e8b 2ea0 2
2eb1 2eb3 3 2eaf
2eb0 2eb5 2 2ebe
2ec0 2 2ec2 2ec4
2 2ec6 2ec8 2
2eca 2ecc 2 2ece
2ed0 3 2ed5 2ed6
2ed7 2 2ed2 2ed9
2 2ebd 2edb 1
2edd 1 2edf 2
2ea8 2ee0 1 2ee4
1 2ea3 1 2ee8
1 2efb 2 2efa
2efb 1 2f03 1
2f09 2 2f0b 2f0c
2 2ef8 2f0d 2
2f1e 2f20 3 2f1c
2f1d 2f22 2 2f2b
2f2d 2 2f2f 2f31
2 2f33 2f35 2
2f37 2f39 2 2f3b
2f3d 3 2f42 2f43
2f44 2 2f3f 2f46
2 2f2a 2f48 1
2f4a 1 2f4c 2
2f15 2f4d 1 2f51
1 2f10 1 2f55
1 2f65 2 2f64
2f65 1 2f6d 1
2f73 2 2f75 2f76
2 2f62 2f77 2
2f88 2f8a 3 2f86
2f87 2f8c 2 2f95
2f97 2 2f99 2f9b
2 2f9d 2f9f 2
2fa1 2fa3 2 2fa5
2fa7 3 2fac 2fad
2fae 2 2fa9 2fb0
2 2f94 2fb2 1
2fb4 1 2fb6 2
2f7f 2fb7 1 2fbb
1 2f7a 1 2fbf
4 2e87 2eeb 2f58
2fc2 2 2fc9 2fca
4 2fc7 2fcc 2fcf
2fd0 1 2fdf 2
2fde 2fdf 1 2fe7
1 2fed 2 2fef
2ff0 2 2fdc 2ff1
2 3002 3004 3
3000 3001 3006 2
300f 3011 2 3013
3015 2 3017 3019
2 301b 301d 2
301f 3021 3 3026
3027 3028 2 3023
302a 2 300e 302c
1 302e 1 3030
2 2ff9 3031 1
3035 1 2ff4 1
3039 1 304c 2
304b 304c 1 3054
1 305a 2 305c
305d 2 3049 305e
2 306f 3071 3
306d 306e 3073 2
307c 307e 2 3080
3082 2 3084 3086
2 3088 308a 2
308c 308e 3 3093
3094 3095 2 3090
3097 2 307b 3099
1 309b 1 309d
2 3066 309e 1
30a2 1 3061 1
30a6 3 2fd3 303c
30a9 2 30ac 30ad
2 2e65 30ae 2
30b0 30b1 2 30b4
30b5 1 30b9 2
30b7 30b9 2 30bd
30be 1 30c2 2
30c0 30c2 1 30c6
2 30d5 30da 2
30eb 30ed 3 30e9
30ea 30ef 2 30f8
30fa 2 30fc 30fe
2 3100 3102 2
3104 3106 2 3108
310a 3 310f 3110
3111 2 310c 3113
2 30f7 3115 1
3117 1 3119 2
30e2 311a 1 311e
1 30dd 1 3122
1 312d 2 3129
312d 2 3132 3133
1 3137 2 3135
3137 1 3145 2
3144 3145 1 314d
1 3153 2 3155
3156 2 3142 3157
2 3168 316a 3
3166 3167 316c 2
3175 3177 2 3179
317b 2 317d 317f
2 3181 3183 2
3185 3187 3 318c
318d 318e 2 3189
3190 2 3174 3192
1 3194 1 3196
2 315f 3197 1
319b 1 315a 1
319f 1 31a2 1
31ac 2 31a8 31ac
2 31b1 31b2 1
31b6 2 31b4 31b6
2 31be 31c4 2
31d5 31d7 3 31d3
31d4 31d9 2 31e2
31e4 2 31e6 31e8
2 31ea 31ec 2
31ee 31f0 2 31f2
31f4 3 31f9 31fa
31fb 2 31f6 31fd
2 31e1 31ff 1
3201 1 3203 2
31cc 3204 1 3208
1 31c7 1 320c
2 3219 321b 3
3217 3218 321d 2
3226 3228 2 322a
322c 2 322e 3230
1 3238 2 323a
323b 2 3232 323d
2 323f 3241 2
3243 3245 2 3247
3249 2 324b 324d
2 3225 324f 1
3251 1 3253 2
325d 325f 3 325b
325c 3261 2 326a
326c 2 3269 326e
1 3270 1 3272
3 3279 327a 327b
4 320f 3254 3273
327d 2 3280 327f
2 3125 3281 1
3283 1 3287 a
328f 3290 3291 3292
3293 3294 3295 3296
3297 3298 1 32a4
2 32a3 32a4 1
32ac 1 32b2 2
32b4 32b5 2 32a1
32b6 2 32c7 32c9
3 32c5 32c6 32cb
2 32d4 32d6 2
32d8 32da 2 32dc
32de 2 32e0 32e2
2 32e4 32e6 3
32eb 32ec 32ed 2
32e8 32ef 2 32d3
32f1 1 32f3 1
32f5 2 32be 32f6
1 32fa 1 32b9
1 32fe 1 3308
2 3306 3308 2
330c 330d 2 3312
3313 2 330f 3315
1 3319 2 3317
3319 2 333c 333d
2 333f 3342 1
3347 2 3345 3347
2 334c 334d 2
3352 3353 1 3355
2 334f 3355 2
335a 335b 2 3360
3361 1 3363 2
335d 3363 2 336e
336f 1 3373 2
3371 3373 1 339e
2 339d 339e 1
33a6 1 33ac 2
33ae 33af 2 339b
33b0 2 33c1 33c3
3 33bf 33c0 33c5
2 33ce 33d0 2
33d2 33d4 2 33d6
33d8 2 33da 33dc
2 33de 33e0 3
33e5 33e6 33e7 2
33e2 33e9 2 33cd
33eb 1 33ed 1
33ef 2 33b8 33f0
1 33f4 1 33b3
1 33f8 1 33fb
1 3428 2 3427
3428 1 3430 1
3436 2 3438 3439
2 3425 343a 2
344b 344d 3 3449
344a 344f 2 3458
345a 2 345c 345e
2 3460 3462 2
3464 3466 2 3468
346a 3 346f 3470
3471 2 346c 3473
2 3457 3475 1
3477 1 3479 2
3442 347a 1 347e
1 343d 1 3482
1 3485 2 3488
3489 1 348a 1
34b0 2 34af 34b0
1 34b8 1 34be
2 34c0 34c1 2
34ad 34c2 2 34d3
34d5 3 34d1 34d2
34d7 2 34e0 34e2
2 34e4 34e6 2
34e8 34ea 2 34ec
34ee 2 34f0 34f2
3 34f7 34f8 34f9
2 34f4 34fb 2
34df 34fd 1 34ff
1 3501 2 34ca
3502 1 3506 1
34c5 1 350a 1
350d 2 3510 3511
2 3514 3515 1
3519 2 3517 3519
2 351e 351f 1
3523 2 3521 3523
1 352b 2 352f
3530 1 3534 2
3532 3534 2 3539
353a 1 353d 2
3540 353f 2 3547
3548 2 354c 354d
2 3551 3552 2
3556 3557 2 355b
355c 2 3560 3561
2 3565 3566 2
356a 356b d 3544
3545 354a 354f 3554
3559 355e 3563 3568
356d 356e 356f 3570
2 3575 3576 1
357c 2 3578 357c
2 3581 3587 2
3598 359a 3 3596
3597 359c 2 35a5
35a7 2 35a9 35ab
2 35ad 35af 2
35b1 35b3 2 35b5
35b7 3 35bc 35bd
35be 2 35b9 35c0
2 35a4 35c2 1
35c4 1 35c6 2
358f 35c7 1 35cb
1 358a 1 35cf
2 35dc 35de 3
35da 35db 35e0 2
35e9 35eb 2 35ed
35ef 2 35f1 35f3
1 35fb 2 35fd
35fe 2 35f5 3600
2 35e8 3602 1
3604 1 3606 2
3610 3612 3 360e
360f 3614 2 361d
361f 2 361c 3621
1 3623 1 3625
2 362c 362d 4
35d2 3607 3626 362f
2 3633 3634 1
3638 2 3636 3638
2 363d 3643 2
3654 3656 3 3652
3653 3658 2 3661
3663 2 3665 3667
2 3669 366b 2
366d 366f 2 3671
3673 3 3678 3679
367a 2 3675 367c
2 3660 367e 1
3680 1 3682 2
364b 3683 1 3687
1 3646 1 368b
2 3698 369a 3
3696 3697 369c 2
36a5 36a7 2 36a9
36ab 2 36ad 36af
1 36b5 2 36b7
36b8 2 36b1 36ba
2 36bc 36be 2
36c0 36c2 2 36c4
36c6 2 36c8 36ca
2 36a4 36cc 1
36ce 1 36d0 2
36da 36dc 3 36d8
36d9 36de 2 36e7
36e9 2 36e6 36eb
1 36ed 1 36ef
2 36f5 36f6 3
36f8 36f9 36fa 4
368e 36d1 36f0 36fc
2 36ff 36fe d
3321 3324 3327 332a
332d 3330 3333 3336
3339 3512 3541 3573
3700 2 3703 3704
1 3708 2 3706
3708 2 370d 370e
2 3713 3714 1
3716 2 3710 3716
2 371e 371f 1
3722 2 3727 3728
2 372d 372e 2
372a 3730 1 3732
1 3735 2 3737
3738 2 373b 373c
1 3740 2 373e
3740 2 3745 3746
2 3748 374a 1
374d 2 3752 3753
2 3755 3757 1
3759 1 375c 2
375e 375f 1 3783
2 3782 3783 1
378b 1 3791 2
3793 3794 2 3780
3795 2 37a6 37a8
3 37a4 37a5 37aa
2 37b3 37b5 2
37b7 37b9 2 37bb
37bd 2 37bf 37c1
2 37c3 37c5 3
37ca 37cb 37cc 2
37c7 37ce 2 37b2
37d0 1 37d2 1
37d4 2 379d 37d5
1 37d9 1 3798
1 37dd 3 3739
3760 37e0 2 37e3
37e4 2 37f0 37f1
1 37f5 2 37f3
37f5 1 37fc 2
3801 3802 1 3804
1 3808 2 3806
3808 2 380f 3812
1 3815 2 381d
381e 2 3820 3823
1 3826 3 3828
3817 3829 20 3833
3834 3835 3836 3837
3838 3839 383a 383b
383c 383d 383e 383f
3840 3841 3842 3843
3844 3845 3846 3847
3848 3849 384a 384b
384c 384d 384e 384f
3850 3851 3852 2
3857 3858 1 385c
2 385a 385c 2
3861 3867 2 3878
387a 3 3876 3877
387c 2 3885 3887
2 3889 388b 2
388d 388f 2 3891
3893 2 3895 3897
3 389c 389d 389e
2 3899 38a0 2
3884 38a2 1 38a4
1 38a6 2 386f
38a7 1 38ab 1
386a 1 38af 2
38bc 38be 3 38ba
38bb 38c0 2 38c9
38cb 2 38cd 38cf
2 38d1 38d3 1
38db 2 38dd 38de
2 38d5 38e0 2
38e2 38e4 2 38e6
38e8 2 38ea 38ec
2 38ee 38f0 2
38c8 38f2 1 38f4
1 38f6 2 3900
3902 3 38fe 38ff
3904 2 390d 390f
2 390c 3911 1
3913 1 3915 3
391c 391d 391e 4
38b2 38f7 3916 3920
2 3924 3925 1
3929 2 3927 3929
2 392e 3934 2
3945 3947 3 3943
3944 3949 2 3952
3954 2 3956 3958
2 395a 395c 2
395e 3960 2 3962
3964 3 3969 396a
396b 2 3966 396d
2 3951 396f 1
3971 1 3973 2
393c 3974 1 3978
1 3937 1 397c
2 3989 398b 3
3987 3988 398d 2
3996 3998 2 399a
399c 2 399e 39a0
1 39a8 2 39aa
39ab 2 39a2 39ad
2 39af 39b1 2
39b3 39b5 2 39b7
39b9 2 39bb 39bd
2 3995 39bf 1
39c1 1 39c3 2
39cd 39cf 3 39cb
39cc 39d1 2 39da
39dc 2 39d9 39de
1 39e0 1 39e2
3 39e9 39ea 39eb
4 397f 39c4 39e3
39ed 2 39f0 39ef
1 39fc 2 39fb
39fc 1 3a04 1
3a0a 2 3a0c 3a0d
2 39f9 3a0e 2
3a1f 3a21 3 3a1d
3a1e 3a23 2 3a2c
3a2e 2 3a30 3a32
2 3a34 3a36 2
3a38 3a3a 2 3a3c
3a3e 3 3a43 3a44
3a45 2 3a40 3a47
2 3a2b 3a49 1
3a4b 1 3a4d 2
3a16 3a4e 1 3a52
1 3a11 1 3a56
1 3a76 2 3a75
3a76 1 3a7e 1
3a84 2 3a86 3a87
2 3a73 3a88 2
3a99 3a9b 3 3a97
3a98 3a9d 2 3aa6
3aa8 2 3aaa 3aac
2 3aae 3ab0 2
3ab2 3ab4 2 3ab6
3ab8 3 3abd 3abe
3abf 2 3aba 3ac1
2 3aa5 3ac3 1
3ac5 1 3ac7 2
3a90 3ac8 1 3acc
1 3a8b 1 3ad0
1 3ae3 2 3ae2
3ae3 1 3aeb 1
3af1 2 3af3 3af4
2 3ae0 3af5 2
3b06 3b08 3 3b04
3b05 3b0a 2 3b13
3b15 2 3b17 3b19
2 3b1b 3b1d 2
3b1f 3b21 2 3b23
3b25 3 3b2a 3b2b
3b2c 2 3b27 3b2e
2 3b12 3b30 1
3b32 1 3b34 2
3afd 3b35 1 3b39
1 3af8 1 3b3d
1 3b50 2 3b4f
3b50 1 3b58 1
3b5e 2 3b60 3b61
2 3b4d 3b62 2
3b73 3b75 3 3b71
3b72 3b77 2 3b80
3b82 2 3b84 3b86
2 3b88 3b8a 2
3b8c 3b8e 2 3b90
3b92 3 3b97 3b98
3b99 2 3b94 3b9b
2 3b7f 3b9d 1
3b9f 1 3ba1 2
3b6a 3ba2 1 3ba6
1 3b65 1 3baa
2 3bb1 3bb2 2
3bb4 3bb6 2 3bbc
3bbd 2 3bc2 3bc3
2 3bbf 3bc5 3
3bce 3bcf 3bd0 3
3bd9 3bda 3bdb 1
3be9 2 3be8 3be9
1 3bf1 1 3bf7
2 3bf9 3bfa 2
3be6 3bfb 2 3c0c
3c0e 3 3c0a 3c0b
3c10 2 3c19 3c1b
2 3c1d 3c1f 2
3c21 3c23 2 3c25
3c27 2 3c29 3c2b
3 3c30 3c31 3c32
2 3c2d 3c34 2
3c18 3c36 1 3c38
1 3c3a 2 3c03
3c3b 1 3c3f 1
3bfe 1 3c43 2
3c49 3c4a 1 3c4e
2 3c4c 3c4e 2
3c53 3c54 1 3c58
2 3c56 3c58 1
3c72 2 3c71 3c72
1 3c7a 1 3c80
2 3c82 3c83 2
3c6f 3c84 2 3c95
3c97 3 3c93 3c94
3c99 2 3ca2 3ca4
2 3ca6 3ca8 2
3caa 3cac 2 3cae
3cb0 2 3cb2 3cb4
3 3cb9 3cba 3cbb
2 3cb6 3cbd 2
3ca1 3cbf 1 3cc1
1 3cc3 2 3c8c
3cc4 1 3cc8 1
3c87 1 3ccc 1
3ccf 2 3cd4 3cd5
1 3cd9 2 3cd7
3cd9 1 3cec 2
3ceb 3cec 1 3cf4
1 3cfa 2 3cfc
3cfd 2 3ce9 3cfe
2 3d0f 3d11 3
3d0d 3d0e 3d13 2
3d1c 3d1e 2 3d20
3d22 2 3d24 3d26
2 3d28 3d2a 2
3d2c 3d2e 3 3d33
3d34 3d35 2 3d30
3d37 2 3d1b 3d39
1 3d3b 1 3d3d
2 3d06 3d3e 1
3d42 1 3d01 1
3d46 2 3d4d 3d4e
2 3d49 3d51 2
3d56 3d57 1 3d5b
2 3d59 3d5b 1
3d6e 2 3d6d 3d6e
1 3d76 1 3d7c
2 3d7e 3d7f 2
3d6b 3d80 2 3d91
3d93 3 3d8f 3d90
3d95 2 3d9e 3da0
2 3da2 3da4 2
3da6 3da8 2 3daa
3dac 2 3dae 3db0
3 3db5 3db6 3db7
2 3db2 3db9 2
3d9d 3dbb 1 3dbd
1 3dbf 2 3d88
3dc0 1 3dc4 1
3d83 1 3dc8 2
3dcf 3dd0 2 3dcb
3dd3 1 3de2 2
3de1 3de2 1 3dea
1 3df0 2 3df2
3df3 2 3ddf 3df4
2 3e05 3e07 3
3e03 3e04 3e09 2
3e12 3e14 2 3e16
3e18 2 3e1a 3e1c
2 3e1e 3e20 2
3e22 3e24 3 3e29
3e2a 3e2b 2 3e26
3e2d 2 3e11 3e2f
1 3e31 1 3e33
2 3dfc 3e34 1
3e38 1 3df7 1
3e3c 2 3e43 3e44
2 3e4a 3e4b 3
3e3f 3e47 3e4e 4
3e50 3d54 3dd5 3e51
1a 3284 328a 329b
3301 3305 37e5 37e8
37eb 37ee 382a 382d
3830 3855 39f1 3a59
3ad3 3b40 3bad 3bb9
3bc8 3bcb 3bd3 3bd6
3bde 3c46 3e52 1
3e54 4 2b89 2be6
30b2 3e55 1 3e57
2 2b6f 3e58 2
3e5a 3e5b 3 3e61
3e62 3e63 5 2880
2894 28a3 3e5c 3e66
2 3e6c 3e72 2
3e83 3e85 3 3e81
3e82 3e87 2 3e90
3e92 2 3e94 3e96
2 3e98 3e9a 2
3e9c 3e9e 2 3ea0
3ea2 3 3ea7 3ea8
3ea9 2 3ea4 3eab
2 3e8f 3ead 1
3eaf 1 3eb1 2
3e7a 3eb2 1 3eb6
1 3e75 1 3eba
2 3ec3 3ec4 1
3ec8 2 3ec6 3ec8
2 3ecf 3ed0 2
3ed5 3ed6 1 3ed8
2 3ed2 3ed8 2
3edd 3ede 2 3ee3
3ee4 2 3ee0 3ee6
2 3eeb 3eec 1
3ef0 2 3eee 3ef0
2 3ef5 3ef6 1
3efa 2 3ef8 3efa
1 3f00 2 3f21
3f22 1 3f26 2
3f24 3f26 1 3f2b
1 3f2d 2 3f34
3f35 2 3f39 3f3a
2 3f3e 3f3f 2
3f43 3f44 2 3f48
3f49 2 3f4d 3f4e
2 3f52 3f53 2
3f57 3f58 d 3f31
3f32 3f37 3f3c 3f41
3f46 3f4b 3f50 3f55
3f5a 3f5b 3f5c 3f5d
2 3f62 3f63 1
3f69 2 3f65 3f69
2 3f74 3f76 3
3f72 3f73 3f78 2
3f81 3f83 2 3f85
3f87 2 3f89 3f8b
1 3f93 2 3f95
3f96 2 3f8d 3f98
2 3f80 3f9a 1
3f9c 1 3f9e 2
3fa8 3faa 3 3fa6
3fa7 3fac 2 3fb5
3fb7 2 3fb4 3fb9
1 3fbb 1 3fbd
2 3fc4 3fc5 3
3f9f 3fbe 3fc7 2
3fcb 3fcc 1 3fd0
2 3fce 3fd0 2
3fdb 3fdd 3 3fd9
3fda 3fdf 2 3fe8
3fea 2 3fec 3fee
2 3ff0 3ff2 1
3ff8 2 3ffa 3ffb
2 3ff4 3ffd 2
3fff 4001 2 4003
4005 2 4007 4009
2 400b 400d 2
3fe7 400f 1 4011
1 4013 2 401d
401f 3 401b 401c
4021 2 402a 402c
2 4029 402e 1
4030 1 4032 2
4038 4039 3 403b
403c 403d 3 4014
4033 403f 2 4042
4041 1 405b 2
405a 405b 1 4063
1 4069 2 406b
406c 2 4058 406d
2 407e 4080 3
407c 407d 4082 2
408b 408d 2 408f
4091 2 4093 4095
2 4097 4099 2
409b 409d 3 40a2
40a3 40a4 2 409f
40a6 2 408a 40a8
1 40aa 1 40ac
2 4075 40ad 1
40b1 1 4070 1
40b5 2 40ca 40cb
1 40cf 2 40cd
40cf 2 40d7 40d8
2 40da 40dd 2
40e0 40e3 1 40e7
2 40e9 40ea 20
40f1 40f2 40f3 40f4
40f5 40f6 40f7 40f8
40f9 40fa 40fb 40fc
40fd 40fe 40ff 4100
4101 4102 4103 4104
4105 4106 4107 4108
4109 410a 410b 410c
410d 410e 410f 4110
2 4115 4116 1
411a 2 4118 411a
2 4125 4127 3
4123 4124 4129 2
4132 4134 2 4136
4138 2 413a 413c
1 4144 2 4146
4147 2 413e 4149
2 414b 414d 2
414f 4151 2 4153
4155 2 4157 4159
2 4131 415b 1
415d 1 415f 2
4169 416b 3 4167
4168 416d 2 4176
4178 2 4175 417a
1 417c 1 417e
3 4185 4186 4187
3 4160 417f 4189
2 418d 418e 1
4192 2 4190 4192
2 419d 419f 3
419b 419c 41a1 2
41aa 41ac 2 41ae
41b0 2 41b2 41b4
1 41bc 2 41be
41bf 2 41b6 41c1
2 41c3 41c5 2
41c7 41c9 2 41cb
41cd 2 41cf 41d1
2 41a9 41d3 1
41d5 1 41d7 2
41e1 41e3 3 41df
41e0 41e5 2 41ee
41f0 2 41ed 41f2
1 41f4 1 41f6
3 41fd 41fe 41ff
3 41d8 41f7 4201
1 4223 2 4222
4223 1 422b 1
4231 2 4233 4234
2 4220 4235 2
4246 4248 3 4244
4245 424a 2 4253
4255 2 4257 4259
2 425b 425d 2
425f 4261 2 4263
4265 3 426a 426b
426c 2 4267 426e
2 4252 4270 1
4272 1 4274 2
423d 4275 1 4279
1 4238 1 427d
1 4280 3 4283
4203 4284 17 3f0a
3f0d 3f10 3f13 3f16
3f19 3f1c 3f1f 3f2e
3f60 4043 4048 404d
40b8 40bc 40bf 40c2
40c5 40c8 40eb 40ee
4113 4285 1 4287
2 3ee9 4288 1
428a 2 4294 4299
2 42aa 42ac 3
42a8 42a9 42ae 2
42b7 42b9 2 42bb
42bd 2 42bf 42c1
2 42c3 42c5 2
42c7 42c9 3 42ce
42cf 42d0 2 42cb
42d2 2 42b6 42d4
1 42d6 1 42d8
2 42a1 42d9 1
42dd 1 429c 1
42e1 2 42e7 42e8
1 42ec 2 42ea
42ec 1 42fb 2
42fa 42fb 1 4303
1 4309 2 430b
430c 2 42f8 430d
2 431e 4320 3
431c 431d 4322 2
432b 432d 2 432f
4331 2 4333 4335
2 4337 4339 2
433b 433d 3 4342
4343 4344 2 433f
4346 2 432a 4348
1 434a 1 434c
2 4315 434d 1
4351 1 4310 1
4355 1 4358 1
435b 4 3ecd 428b
42e4 435c 1 435e
1 4363 1 4374
2 4373 4374 1
437c 1 4382 2
4384 4385 2 4371
4386 2 4397 4399
3 4395 4396 439b
2 43a4 43a6 2
43a8 43aa 2 43ac
43ae 2 43b0 43b2
2 43b4 43b6 3
43bb 43bc 43bd 2
43b8 43bf 2 43a3
43c1 1 43c3 1
43c5 2 438e 43c6
1 43ca 1 4389
1 43ce 2 43d4
43d5 1 43d9 2
43d7 43d9 2 43e3
43e8 2 43f9 43fb
3 43f7 43f8 43fd
2 4406 4408 2
440a 440c 2 440e
4410 2 4412 4414
2 4416 4418 3
441d 441e 441f 2
441a 4421 2 4405
4423 1 4425 1
4427 2 43f0 4428
1 442c 1 43eb
1 4430 2 4436
4437 1 443b 2
4439 443b 1 4449
2 4448 4449 1
4451 1 4457 2
4459 445a 2 4446
445b 2 446c 446e
3 446a 446b 4470
2 4479 447b 2
447d 447f 2 4481
4483 2 4485 4487
2 4489 448b 3
4490 4491 4492 2
448d 4494 2 4478
4496 1 4498 1
449a 2 4463 449b
1 449f 1 445e
1 44a3 1 44b0
2 44af 44b0 1
44b8 1 44be 2
44c0 44c1 2 44ad
44c2 2 44d3 44d5
3 44d1 44d2 44d7
2 44e0 44e2 2
44e4 44e6 2 44e8
44ea 2 44ec 44ee
2 44f0 44f2 3
44f7 44f8 44f9 2
44f4 44fb 2 44df
44fd 1 44ff 1
4501 2 44ca 4502
1 4506 1 44c5
1 450a 2 44a6
450d 1 4510 2
4433 4511 1 4513
2 4516 4517 1
451b 2 4519 451b
5 4523 4524 4525
4526 4527 2 4544
4549 2 455a 455c
3 4558 4559 455e
2 4567 4569 2
456b 456d 2 456f
4571 2 4573 4575
2 4577 4579 3
457e 457f 4580 2
457b 4582 2 4566
4584 1 4586 1
4588 2 4551 4589
1 458d 1 454c
1 4591 1 459c
2 4598 459c 2
45a1 45a2 1 45a6
2 45a4 45a6 1
45bb 2 45ba 45bb
1 45c3 1 45c9
2 45cb 45cc 2
45b8 45cd 2 45de
45e0 3 45dc 45dd
45e2 2 45eb 45ed
2 45ef 45f1 2
45f3 45f5 2 45f7
45f9 2 45fb 45fd
3 4602 4603 4604
2 45ff 4606 2
45ea 4608 1 460a
1 460c 2 45d5
460d 1 4611 1
45d0 1 4615 1
4618 1 462f 2
462e 462f 1 4637
1 463d 2 463f
4640 2 462c 4641
2 4652 4654 3
4650 4651 4656 2
465f 4661 2 4663
4665 2 4667 4669
2 466b 466d 2
466f 4671 3 4676
4677 4678 2 4673
467a 2 465e 467c
1 467e 1 4680
2 4649 4681 1
4685 1 4644 1
4689 1 468c 2
468f 4690 3 4693
4694 4695 1 4699
2 4697 4699 a
46a4 46a5 46a6 46a7
46a8 46a9 46aa 46ab
46ac 46ad 2 469f
46b0 1 46b2 2
4691 46b3 1 46b5
1 46b7 2 46c0
46c1 1 46c5 2
46c3 46c5 1 46cd
1 46cf 5 4520
452a 4594 46b6 46d0
1 46d2 3 43d1
4514 46d3 1 46d5
2 46d8 46d9 1
46dd 2 46db 46dd
1 46e1 2 46ea
46eb 1 46ef 2
46ed 46ef 2 46fc
4701 2 4712 4714
3 4710 4711 4716
2 471f 4721 2
4723 4725 2 4727
4729 2 472b 472d
2 472f 4731 3
4736 4737 4738 2
4733 473a 2 471e
473c 1 473e 1
4740 2 4709 4741
1 4745 1 4704
1 4749 2 474f
4750 1 4754 2
4752 4754 1 4763
2 4762 4763 1
476b 1 4771 2
4773 4774 2 4760
4775 2 4786 4788
3 4784 4785 478a
2 4793 4795 2
4797 4799 2 479b
479d 2 479f 47a1
2 47a3 47a5 3
47aa 47ab 47ac 2
47a7 47ae 2 4792
47b0 1 47b2 1
47b4 2 477d 47b5
1 47b9 1 4778
1 47bd 1 47ce
2 47cd 47ce 1
47d6 1 47dc 2
47de 47df 2 47cb
47e0 2 47f1 47f3
3 47ef 47f0 47f5
2 47fe 4800 2
4802 4804 2 4806
4808 2 480a 480c
2 480e 4810 3
4815 4816 4817 2
4812 4819 2 47fd
481b 1 481d 1
481f 2 47e8 4820
1 4824 1 47e3
1 4828 2 47c0
482b 1 482e 2
474c 482f 1 4831
5 4838 4839 483a
483b 483c 2 4859
485e 2 486f 4871
3 486d 486e 4873
2 487c 487e 2
4880 4882 2 4884
4886 2 4888 488a
2 488c 488e 3
4893 4894 4895 2
4890 4897 2 487b
4899 1 489b 1
489d 2 4866 489e
1 48a2 1 4861
1 48a6 1 48b1
2 48ad 48b1 2
48b6 48b7 1 48bb
2 48b9 48bb 1
48d0 2 48cf 48d0
1 48d8 1 48de
2 48e0 48e1 2
48cd 48e2 2 48f3
48f5 3 48f1 48f2
48f7 2 4900 4902
2 4904 4906 2
4908 490a 2 490c
490e 2 4910 4912
3 4917 4918 4919
2 4914 491b 2
48ff 491d 1 491f
1 4921 2 48ea
4922 1 4926 1
48e5 1 492a 1
492d 1 4944 2
4943 4944 1 494c
1 4952 2 4954
4955 2 4941 4956
2 4967 4969 3
4965 4966 496b 2
4974 4976 2 4978
497a 2 497c 497e
2 4980 4982 2
4984 4986 3 498b
498c 498d 2 4988
498f 2 4973 4991
1 4993 1 4995
2 495e 4996 1
499a 1 4959 1
499e 1 49a1 2
49a4 49a5 3 49a8
49a9 49aa 1 49ae
2 49ac 49ae 2
49b3 49b4 1 49b8
2 49b6 49b8 a
49c5 49c6 49c7 49c8
49c9 49ca 49cb 49cc
49cd 49ce 2 49c0
49d1 1 49d3 2
49a6 49d4 1 49d6
5 4832 4835 483f
48a9 49d7 1 49d9
1 49dd 1 49e5
2 49e3 49e5 1
49ec 1 49ee 2
49f8 49fa 3 49f6
49f7 49fc 2 4a05
4a07 2 4a09 4a0b
2 4a0d 4a0f 1
4a17 2 4a19 4a1a
2 4a11 4a1c 2
4a1e 4a20 2 4a22
4a24 2 4a26 4a28
2 4a2a 4a2c 2
4a04 4a2e 1 4a30
1 4a32 3 4a39
4a3a 4a3b 56 459
478 47b 47e 481
484 487 48a 497
4b7 4ba 4bd 4c0
4c3 4c6 4c9 4cc
4cf 4d4 4e7 4ec
540 5ba 61c 697
69a 6f0 76a 7e0
85b 8b3 92e 984
996 a10 a13 a1e
a29 a34 d41 d44
d47 d4a d4d d50
d53 d58 d6b d80
dd4 1513 1516 1519
151c 1521 1549 15b0
15c1 15c4 15c7 15ca
1622 16a1 2401 2752
275e 2761 2764 27ba
27be 27c1 27c4 2860
2863 2866 3e69 3ebd
3ec1 435f 4362 46d6
49da 49e0 49ef 4a33
4a3d 2 4a4a 4a4c
3 4a48 4a49 4a4e
2 4a57 4a59 2
4a56 4a5b 2 4a62
4a66 2 4a68 4a6a
2 4a6c 4a70 2
4a61 4a72 2 4a5d
4a74 1 4a76 3
4a77 4a82 4a86 1
4a41 2 4a99 4a9b
3 4a97 4a98 4a9d
2 4aa6 4aa8 2
4aa5 4aaa 2 4ab1
4ab3 2 4ab5 4ab7
3 4abc 4abd 4abe
2 4ab9 4ac0 2
4ab0 4ac2 2 4aac
4ac4 1 4ac6 4
4a90 4ac7 4ad0 4ad4
1 4ad8 1 4a8b
2 4a89 4adc 67
4b 52 59 60
67 6e 75 7c
83 8a 91 98
9d a2 a7 ac
b3 b8 bd c4
cb d0 d5 da
df e6 ed f4
fb 102 108 10e
114 11a 120 126
12c 132 138 13e
144 14a 150 156
15c 162 168 16e
174 17a 180 186
18c 192 198 19e
1a4 1aa 1b0 1b6
1bc 1c2 1c8 1ce
1d4 1da 1e0 1e6
1ec 1f2 1f9 200
206 20c 213 219
220 227 22d 233
238 23d 243 249
24f 255 25b 261
267 26d 273 279
27f 286 28d 294
2a2 2a8 2ae 2bb
2cf 347 351 
1
4
0 
4ae3
0
1
140
e2
77
0 1 1 1 1 5 1 7
1 9 1 b 1 d 1 f
1 11 1 13 1 15 1 17
1 19 1 1b 1 1d 1 1f
1 21 1 23 1 25 1 27
1 29 1 2b 1 2d 1 2f
1 31 1 33 1 35 1 37
1 39 1 3b 1 3d 1 3f
1 41 1 43 1 45 1 47
1 49 1 4b 1 4d 1 4f
1 51 1 53 1 55 1 57
1 59 1 5b 1 5d 1 5f
1 61 1 63 1 65 1 67
1 69 1 6b 1 6d 1 6f
70 6f 72 6f 74 6f 76 6f
78 6f 7a 6f 7c 6f 7e 6f
80 6f 82 6f 84 6f 86 6f
88 6f 8a 6f 8c 6f 8e 6f
90 6f 92 6f 94 6f 96 6f
98 6f 9a 6f 9c 6f 9e 6f
a0 6f a2 6f a4 6f a6 6f
a8 6f aa 6f ac 6f ae 6f
b0 6f b2 6f b4 6f b6 6f
b8 6f ba 6f bc 1 be 1
c0 1 c2 1 c4 1 c6 1
c8 1 ca 1 cc 1 ce 1
d0 1 d2 1 d4 1 d6 1
d8 1 da 1 dc 1 de 1
e0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

245 1 0
3b 1 0
33 1 0
215 1 0
1ee 1 0
24b 1 0
37 1 0
dc 1 0
164 1 0
208 1 0
182 1 0
116 1 0
9f 1 0
69 1 0
222 1 0
2f 1 0
251 1 0
263 1 0
21b 1 0
70 1 0
27 1 0
1e2 1 0
b 1 0
15e 1 0
77 1 0
23 1 0
1be 1 0
bf 1 0
e1 1 0
19a 1 0
d7 1 0
2a4 1 0
1ac 1 0
5b 1 0
20e 1 0
17c 1 0
1b2 1 0
194 1 0
104 1 0
2d5 1 4
22f 1 0
1d0 1 0
122 1 0
27b 1 0
1b 1 0
140 1 0
2c1 1 3
1fb 1 0
110 1 0
cd 1 0
a4 1 0
2b1 1 2
1f4 1 0
9a 1 0
17 1 0
134 1 0
257 1 0
23f 1 0
4d 1 0
3 1 0
1ca 1 0
26f 1 0
2 0 1
296 1 0
16a 1 0
281 1 0
f6 1 0
23a 1 0
d2 1 0
a9 1 0
229 1 0
128 1 0
25d 1 0
176 1 0
10a 1 0
2b 1 0
28f 1 0
288 1 0
1dc 1 0
7e 1 0
46 1 0
c6 1 0
f 1 0
7 1 0
13a 1 0
12e 1 0
2aa 1 0
188 1 0
152 1 0
1e8 1 0
1c4 1 0
93 1 0
ef 1 0
275 1 0
269 1 0
1b8 1 0
11c 1 0
202 1 0
1a0 1 0
b5 1 0
8c 1 0
85 1 0
170 1 0
62 1 0
18e 1 0
1f 1 0
235 1 0
1d6 1 0
1a6 1 0
ba 1 0
e8 1 0
14c 1 0
54 1 0
fd 1 0
146 1 0
13 1 0
34c 1 0
158 1 0
ae 1 0
0

/
SHOW ERRORS FUNCTION SP_A_RESTOPROF;
ALTER FUNCTION SP_A_RESTOPROF COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_RATES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_RATES ==
CREATE OR REPLACE FUNCTION SP_U_RATES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
5b
2 :e:
1FUNCTION:
1SP_U_RATES:
1ID:
1VARCHAR2:
1REG_COST:
1NUMBER:
1SPEC_COST:
1REG_RATE:
1SPEC_RATE:
1RATE_ADJUSTMENT001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_RES_ID:
1H_REG_COST:
10:
1H_REG_RATE:
1H_SPEC_COST:
1H_SPEC_RATE:
1H_RATE_ADJUSTMENT:
1H_FLAG:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_RATES(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
134:
1+:
1FPUT:
1               ENTER:: SP_U_RATES(35) :: cplan.sql(11946) :: :
1IS NULL:
139:
1        RETURN_ERROR:: SP_U_RATES(40) :: cplan.sql(11951) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1 ID:: :
142:
1                EXIT:: SP_U_RATES(43) :: cplan.sql(11954) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1SC_STATE:
1FC_U_RATES:
1=:
1100:
14:
166:
1       RETURN_STATUS:: SP_U_RATES(67) :: cplan.sql(11978) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
116:
173:
1           EXCEPTION:: SP_U_RATES(74) :: cplan.sql(11985) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
185:
1           EXCEPTION:: SP_U_RATES(86) :: cplan.sql(11997) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2a9
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c a0 51 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 6b :9 a0 a5
b d :2 a0 6b 7e 51 b4 2e
:2 a0 6b 51 d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 a0 6b :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e :2 a0 6b b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :9 a0 12a e9 dd
:2 a0 65 b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c :7 a0 12a e9 dd :2 a0 65
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 68 4f 1d 17 b5 
2a9
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d 7c
a2 a6 aa ae b1 b5 d2 bd
c1 c4 c5 cd bc ef dd b9
e1 e2 ea dc 10b fa fe d9
106 f9 127 116 11a f6 122 115
143 132 136 112 13e 131 15f 14e
152 12e 15a 14d 17b 16a 16e 14a
176 169 197 186 18a 166 192 185
1b7 1a2 1a6 182 1aa 1b2 1a1 1be
1c2 19e 1c6 1ca 1ce 1d1 1d6 1d7
1 1d9 1de 1e2 1e6 1e9 1ee 1f2
1f6 1f9 1fe 1ff 201 206 209 20d
20e 213 218 21b 220 221 226 229
22d 22e 233 236 23b 23c 241 244
249 24a 24f 252 256 25a 25e 25f
261 266 267 269 26a 26f 272 277
278 27d 280 284 288 28c 28d 28f
294 295 297 298 29d 2a0 2a5 2a6
2ab 2ae 2b2 2b6 2ba 2bb 2bd 2c2
2c3 2c5 2c6 2cb 2ce 2d3 2d4 2d9
2dc 2e0 2e4 2e8 2e9 2eb 2f0 2f1
2f3 2f4 2f9 2fc 301 302 307 30a
30e 312 316 317 319 31e 31f 321
322 327 32a 32f 330 335 338 33d
33e 343 346 34a 34b 350 353 358
359 35e 361 366 367 36c 36d 372
374 378 37b 37f 383 386 38a 38e
391 394 399 39c 39f 3a2 3a3 3a8
3a9 1 3ab 3b0 3b4 3b8 3bb 3c0
3c5 3c8 3cc 3cd 3d2 3d3 3d8 3da
3de 3e1 3e5 3e8 3e9 3ee 3f1 3f5
3f9 3fc 400 404 407 40a 40f 412
415 418 419 41e 41f 1 421 426
42a 42e 431 436 43b 43e 442 443
448 44b 450 451 456 459 45e 45f
464 467 46b 46f 473 477 47a 47b
47d 482 483 485 486 48b 48e 493
494 499 49c 4a1 4a2 4a7 4aa 4ae
4af 4b4 4b7 4bc 4bd 4c2 4c3 4c8
4ca 4ce 4d1 4d5 4d9 4dc 4e0 4e4
4e7 4ea 4ef 4f2 4f5 4f8 4f9 4fe
4ff 1 501 506 50a 50e 511 516
51b 51e 522 523 528 529 52e 530
534 537 53b 53f 542 546 54a 54d
551 555 556 55b 55d 561 564 568
56b 56f 573 577 57b 57f 583 587
58b 58f 593 597 59b 59f 5a3 5a7
5ab 5af 5b3 5b7 5bb 5bf 5c3 5c7
5cb 5ce 5d2 5d6 5da 5de 5e2 5e6
5ea 5ee 5f2 5f3 5f5 5f9 5fd 601
604 607 60a 60b 610 614 618 61b
61e 622 624 628 62b 62f 633 636
63a 63e 641 644 649 64c 64f 652
653 658 659 1 65b 660 664 668
66b 670 675 678 67c 67d 682 685
68a 68b 690 693 698 699 69e 6a1
6a5 6a9 6ad 6b1 6b4 6b5 6b7 6bc
6bd 6bf 6c0 6c5 6c8 6cd 6ce 6d3
6d6 6db 6dc 6e1 6e4 6e8 6e9 6ee
6f1 6f6 6f7 6fc 6fd 702 704 708
70b 70f 713 716 71a 71e 721 725
729 72a 72f 731 735 739 73c 740
744 747 74b 74f 752 755 75a 75d
760 763 764 769 76a 1 76c 771
775 779 77c 781 786 789 78d 78e
793 794 799 79d 7a1 7a4 7a9 7ae
7b1 7b5 7b9 7bc 7bd 7c2 7c5 7ca
7cb 7d0 7d3 7d7 7db 7de 7df 7e4
7e5 7ea 7ec 7f0 7f3 7f7 7fb 7ff
803 807 80b 80f 813 817 823 828
82c 830 834 838 83a 83b 840 1
844 848 84c 84f 853 857 85b 85f
862 866 86a 86d 870 875 878 87b
87e 87f 884 885 1 887 88c 890
894 897 89c 8a1 8a4 8a8 8a9 8ae
8af 8b4 8b8 8bc 8bf 8c4 8c9 8cc
8d0 8d1 8d6 8d9 8de 8df 8e4 8e7
8eb 8ef 8f2 8f5 8f6 8f8 8f9 8fe
8ff 904 906 90a 90d 911 915 919
91d 921 925 929 935 93a 93e 942
946 94a 94c 950 952 95e 960 962
963 968 96c 96e 97a 97e 980 981
98a 
2a9
2
0 1 a 6 9 :3 6 f :3 6
10 :3 6 f :3 6 10 :3 6 19 :3 6
10 :2 6 1 3 a 13 a :2 1
4 9 12 11 :2 9 :2 4 d 16
15 :2 d :2 4 :2 f 19 f :2 4 :2 f
19 f :2 4 :2 10 1a 10 :2 4 :2 10
1a 10 :2 4 :2 16 25 16 :2 4 :2 b
1a b :2 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 52 58 5b :2 52
69 7d 8 :2 69 d 10 :2 69 13
16 :2 69 b e :2 69 13 16 1f
27 :2 1f 32 :2 16 :2 69 b e :2 69
13 16 1f 27 :2 1f 33 :2 16 :2 69
b e :2 69 13 16 1f 27 :2 1f
32 :2 16 :2 69 b e :2 69 13 16
1f 27 :2 1f 33 :2 16 :2 69 b e
:2 69 13 16 1f 27 :2 1f 3c :2 16
:2 69 b e :2 69 13 16 :2 69 1b
1e :2 69 28 2b :2 69 30 33 :2 69
:2 7 48 :2 4 7 :2 11 23 :2 2d 39
3c 4a 4c 4d :2 4a :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :2 7 50 :2 4
:4 8 7 a :2 14 26 :2 30 3c 40
4e 50 51 :2 4e :2 26 :3 a :2 10 15
21 5e 61 :2 21 6e 71 :2 21 75
78 :2 21 82 85 8e 96 :2 9f :2 8e
b0 :2 85 :2 21 b8 bb :2 21 c3 c6
:2 21 cb ce :2 21 d1 d4 :2 21 :2 a
54 :2 7 a :2 14 26 :2 30 3c 3f
4d 4f 50 :2 4d :2 26 :3 a :2 10 15
21 5e 61 :2 21 :2 a 53 :3 7 :2 12
26 :2 2f 3f 43 :2 7 14 :3 4 e
:2 4 c :2 4 10 :2 4 12 :2 4 13
:2 4 12 :2 4 13 :2 4 19 :2 4 :2 d
19 24 2a 36 43 4f 23 36
40 :2 19 4 7 :2 10 19 1b :2 19
7 :2 10 1c 7 1f :2 4 7 :2 11
23 :2 2d 39 3c 4a 4c 4d :2 4a
:2 23 :3 7 :2 d 12 1e 5b 5e :2 1e
6b 6e :2 1e 72 75 :2 1e 7f 82
8b 93 :2 9c :2 8b a7 :2 82 :2 1e af
b2 :2 1e ba bd :2 1e c2 c5 :2 1e
c8 cb :2 1e :2 7 50 :3 4 :2 f 21
:2 2a 34 38 :2 4 1 9 12 9
a :2 14 26 :2 30 3c 40 4e 50
51 :2 4e :2 26 :3 a :2 10 15 21 5e
61 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 54 :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 4b 4d
4e :2 4b :2 23 :3 7 :2 d 12 1e 5b
5e :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 51 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
2a9
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 2 :4 a :2 1
:7 c :7 d :6 e :6 f
:6 10 :6 11 :6 12 :6 13
:7 15 :b 17 :11 18 19
:2 18 :2 19 :2 18 :2 19
:2 18 :2 1a :2 18 :9 1a
:2 18 :2 1b :2 18 :9 1b
:2 18 :2 1c :2 18 :9 1c
:2 18 :2 1d :2 18 :9 1d
:2 18 :2 1e :2 18 :9 1e
:2 18 :2 1f :2 18 :2 1f
:2 18 :2 1f :2 18 :2 1f
:2 18 :2 1f :4 18 :3 17
:11 22 :b 23 :3 22 :5 26
:11 27 :30 28 :3 27 :11 2a
:b 2b :3 2a :a 2d :3 26
:3 30 :3 33 :3 34 :3 35
:3 36 :3 37 :3 38 :3 39
:9 3b :3 3c :3 3b :7 3e
:5 3f :3 3e :11 42 :30 43
:3 42 :a 45 16 :3 48
:11 49 :b 4a :17 4b :3 49
:2 4d :3 4e :3 4f 50
4e 4d 4e :3 51
:3 48 :2 52 :5 54 :11 55
:b 56 :18 57 :3 55 :2 59
5a :3 5b 5c 5a
59 5a :3 5d :2 53
:6 52 47 :7 1 
98c
4
:3 0 1 :3 0 2
:a 0 2a4 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d 7c 0
b 6 :3 0 8
:7 0 11 10 :3 0
6 :3 0 9 :7 0
15 14 :3 0 11
:2 0 f b :3 0
a :7 0 19 18
:3 0 4 :3 0 c
:7 0 1d 1c :3 0
d :3 0 e :3 0
f :2 0 4 21
22 0 1f 23
0 2a4 2 24
:2 0 11 :2 0 1b
4 :3 0 11 :2 0
19 27 29 :6 0
2c 2a 0 2a2
0 10 :6 0 14
:2 0 1f 4 :3 0
1d 2e 30 :6 0
33 31 0 2a2
0 12 :6 0 14
:2 0 21 6 :3 0
35 :7 0 39 36
37 2a2 0 13
:6 0 14 :2 0 23
6 :3 0 3b :7 0
3f 3c 3d 2a2
0 15 :6 0 14
:2 0 25 6 :3 0
41 :7 0 45 42
43 2a2 0 16
:6 0 14 :2 0 27
6 :3 0 47 :7 0
4b 48 49 2a2
0 17 :6 0 14
:2 0 29 b :3 0
4d :7 0 51 4e
4f 2a2 0 18
:6 0 59 5a 0
2b b :3 0 53
:7 0 57 54 55
2a2 0 19 :6 0
5f 60 0 2d
e :3 0 f :2 0
4 5b :7 0 5e
5c 0 2a2 0
1a :6 0 1b :3 0
1c :3 0 1b :3 0
1d :3 0 62 63
0 2 :4 0 2f
64 66 61 68
67 :2 0 1e :3 0
1f :3 0 6a 6b
0 20 :4 0 1b
:3 0 21 :3 0 6e
6f 0 2 :4 0
31 70 72 22
:4 0 23 :2 0 24
:3 0 33 75 77
:3 0 25 :4 0 23
:2 0 26 :4 0 36
7a 7c :3 0 23
:2 0 3 :3 0 39
7e 80 :3 0 23
:2 0 26 :4 0 3c
82 84 :3 0 23
:2 0 27 :4 0 3f
86 88 :3 0 23
:2 0 28 :3 0 29
:3 0 5 :3 0 42
8c 8e 2a :4 0
44 8b 91 47
8a 93 :3 0 23
:2 0 27 :4 0 4a
95 97 :3 0 23
:2 0 28 :3 0 29
:3 0 7 :3 0 4d
9b 9d 2a :4 0
4f 9a a0 52
99 a2 :3 0 23
:2 0 27 :4 0 55
a4 a6 :3 0 23
:2 0 28 :3 0 29
:3 0 8 :3 0 58
aa ac 2a :4 0
5a a9 af 5d
a8 b1 :3 0 23
:2 0 27 :4 0 60
b3 b5 :3 0 23
:2 0 28 :3 0 29
:3 0 9 :3 0 63
b9 bb 2a :4 0
65 b8 be 68
b7 c0 :3 0 23
:2 0 27 :4 0 6b
c2 c4 :3 0 23
:2 0 28 :3 0 29
:3 0 a :3 0 6e
c8 ca 2a :4 0
70 c7 cd 73
c6 cf :3 0 23
:2 0 27 :4 0 76
d1 d3 :3 0 23
:2 0 26 :4 0 79
d5 d7 :3 0 23
:2 0 c :3 0 7c
d9 db :3 0 23
:2 0 26 :4 0 7f
dd df :3 0 23
:2 0 2b :4 0 82
e1 e3 :3 0 85
6c e5 :2 0 e7
8a e8 69 e7
0 e9 8c 0
202 1b :3 0 1c
:3 0 ea eb 0
1b :3 0 2c :3 0
ed ee 0 2d
:2 0 2 :4 0 2e
:2 0 2f :2 0 2d
:2 0 8e f3 f5
:3 0 91 ef f7
ec f9 f8 :2 0
1e :3 0 30 :3 0
fb fc 0 20
:4 0 31 :4 0 23
:2 0 24 :3 0 95
100 102 :3 0 98
fd 104 :2 0 106
9b 107 fa 106
0 108 9d 0
202 3 :3 0 32
:2 0 9f 10a 10b
:3 0 10c :2 0 1b
:3 0 1c :3 0 10e
10f 0 1b :3 0
2c :3 0 111 112
0 11 :2 0 2
:4 0 33 :2 0 2f
:2 0 2d :2 0 a1
117 119 :3 0 a4
113 11b 110 11d
11c :2 0 1e :3 0
30 :3 0 11f 120
0 20 :4 0 34
:4 0 23 :2 0 24
:3 0 a8 124 126
:3 0 23 :2 0 35
:4 0 ab 128 12a
:3 0 23 :2 0 36
:4 0 ae 12c 12e
:3 0 23 :2 0 28
:3 0 29 :3 0 37
:3 0 38 :3 0 133
134 0 b1 132
136 2a :4 0 b3
131 139 b6 130
13b :3 0 23 :2 0
39 :4 0 b9 13d
13f :3 0 23 :2 0
26 :4 0 bc 141
143 :3 0 23 :2 0
3 :3 0 bf 145
147 :3 0 23 :2 0
26 :4 0 c2 149
14b :3 0 c5 121
14d :2 0 14f c8
150 11e 14f 0
151 ca 0 17b
1b :3 0 1c :3 0
152 153 0 1b
:3 0 2c :3 0 155
156 0 2d :2 0
2 :4 0 3a :2 0
2f :2 0 2d :2 0
cc 15b 15d :3 0
cf 157 15f 154
161 160 :2 0 1e
:3 0 30 :3 0 163
164 0 20 :4 0
3b :4 0 23 :2 0
24 :3 0 d3 168
16a :3 0 d6 165
16c :2 0 16e d9
16f 162 16e 0
170 db 0 17b
3c :3 0 3d :3 0
171 172 0 37
:3 0 38 :3 0 174
175 0 3 :3 0
3e :3 0 dd 173
179 :2 0 17b e1
17c 10d 17b 0
17d e5 0 202
19 :3 0 2d :2 0
17e 17f 0 202
10 :3 0 3 :3 0
181 182 0 202
12 :3 0 c :3 0
184 185 0 202
13 :3 0 5 :3 0
187 188 0 202
16 :3 0 7 :3 0
18a 18b 0 202
15 :3 0 8 :3 0
18d 18e 0 202
17 :3 0 9 :3 0
190 191 0 202
18 :3 0 a :3 0
193 194 0 202
e :3 0 3f :3 0
196 197 0 40
:3 0 10 :3 0 13
:3 0 16 :3 0 15
:3 0 17 :3 0 18
:3 0 12 :3 0 19
:3 0 e7 199 1a2
198 1a3 0 202
e :3 0 3f :3 0
1a5 1a6 0 41
:2 0 42 :2 0 f2
1a8 1aa :3 0 e
:3 0 3f :3 0 1ac
1ad 0 14 :2 0
1ae 1af 0 1b1
f5 1b2 1ab 1b1
0 1b3 f7 0
202 1b :3 0 1c
:3 0 1b4 1b5 0
1b :3 0 2c :3 0
1b7 1b8 0 43
:2 0 2 :4 0 44
:2 0 2f :2 0 2d
:2 0 f9 1bd 1bf
:3 0 fc 1b9 1c1
1b6 1c3 1c2 :2 0
1e :3 0 30 :3 0
1c5 1c6 0 20
:4 0 45 :4 0 23
:2 0 24 :3 0 100
1ca 1cc :3 0 23
:2 0 35 :4 0 103
1ce 1d0 :3 0 23
:2 0 36 :4 0 106
1d2 1d4 :3 0 23
:2 0 28 :3 0 29
:3 0 e :3 0 3f
:3 0 1d9 1da 0
109 1d8 1dc 2a
:4 0 10b 1d7 1df
10e 1d6 1e1 :3 0
23 :2 0 39 :4 0
111 1e3 1e5 :3 0
23 :2 0 26 :4 0
114 1e7 1e9 :3 0
23 :2 0 3 :3 0
117 1eb 1ed :3 0
23 :2 0 26 :4 0
11a 1ef 1f1 :3 0
11d 1c7 1f3 :2 0
1f5 120 1f6 1c4
1f5 0 1f7 122
0 202 3c :3 0
46 :3 0 1f8 1f9
0 e :3 0 3f
:3 0 1fb 1fc 0
3 :3 0 3e :3 0
124 1fa 200 :2 0
202 128 2a3 e
:3 0 47 :2 0 4
203 204 0 1b
:3 0 1c :3 0 206
207 0 1b :3 0
2c :3 0 209 20a
0 48 :2 0 2
:4 0 49 :2 0 2f
:2 0 2d :2 0 138
20f 211 :3 0 13b
20b 213 208 215
214 :2 0 1e :3 0
30 :3 0 217 218
0 20 :4 0 4a
:4 0 23 :2 0 24
:3 0 13f 21c 21e
:3 0 142 219 220
:2 0 239 1e :3 0
30 :3 0 222 223
0 20 :4 0 4b
:4 0 23 :2 0 e
:3 0 4c :3 0 228
229 0 145 227
22b :3 0 23 :2 0
39 :4 0 148 22d
22f :3 0 23 :2 0
e :3 0 4d :3 0
232 233 0 14b
231 235 :3 0 14e
224 237 :2 0 239
151 23a 216 239
0 23b 154 0
24b 4e :3 0 1a
:3 0 e :3 0 4c
:3 0 4f :3 0 e
:3 0 4d :3 0 3
:3 0 50 :4 0 51
1 :a 0 247 :2 0
24b 23d 245 :2 0
d :3 0 1a :3 0
249 :2 0 24b 156
24d 15a 24c 24b
:2 0 2a1 52 :3 0
e :3 0 3f :3 0
250 251 0 53
:3 0 252 253 0
299 1b :3 0 1c
:3 0 255 256 0
1b :3 0 2c :3 0
258 259 0 48
:2 0 2 :4 0 54
:2 0 2f :2 0 2d
:2 0 15c 25e 260
:3 0 15f 25a 262
257 264 263 :2 0
1e :3 0 30 :3 0
266 267 0 20
:4 0 55 :4 0 23
:2 0 24 :3 0 163
26b 26d :3 0 166
268 26f :2 0 289
1e :3 0 30 :3 0
271 272 0 20
:4 0 56 :4 0 23
:2 0 53 :3 0 169
276 278 :3 0 23
:2 0 57 :4 0 16c
27a 27c :3 0 23
:2 0 58 :3 0 59
:3 0 2d :2 0 5a
:2 0 16f 27f 283
173 27e 285 :3 0
176 273 287 :2 0
289 179 28a 265
289 0 28b 17c
0 299 4e :3 0
1a :3 0 4f :3 0
e :3 0 4d :3 0
3 :3 0 50 :4 0
5b 1 :a 0 295
:2 0 299 28d 293
:2 0 d :3 0 1a
:3 0 297 :2 0 299
17e 29c :3 0 29c
0 29c 29b 299
29a :6 0 29e 1
:3 0 183 2a0 185
29f 29e :2 0 2a1
187 :2 0 2a3 18a
2a3 2a2 202 2a1
:6 0 2a4 :2 0 2
24 2a3 2a7 :3 0
2a6 2a4 2a8 :8 0

194
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 7
6 a e 12
16 1a 1e 1
28 1 26 1
2f 1 2d 1
34 1 3a 1
40 1 46 1
4c 1 52 1
58 1 65 1
71 2 74 76
2 79 7b 2
7d 7f 2 81
83 2 85 87
1 8d 2 8f
90 2 89 92
2 94 96 1
9c 2 9e 9f
2 98 a1 2
a3 a5 1 ab
2 ad ae 2
a7 b0 2 b2
b4 1 ba 2
bc bd 2 b6
bf 2 c1 c3
1 c9 2 cb
cc 2 c5 ce
2 d0 d2 2
d4 d6 2 d8
da 2 dc de
2 e0 e2 4
6d 73 78 e4
1 e6 1 e8
2 f2 f4 3
f0 f1 f6 2
ff 101 2 fe
103 1 105 1
107 1 109 2
116 118 3 114
115 11a 2 123
125 2 127 129
2 12b 12d 1
135 2 137 138
2 12f 13a 2
13c 13e 2 140
142 2 144 146
2 148 14a 2
122 14c 1 14e
1 150 2 15a
15c 3 158 159
15e 2 167 169
2 166 16b 1
16d 1 16f 3
176 177 178 3
151 170 17a 1
17c 8 19a 19b
19c 19d 19e 19f
1a0 1a1 1 1a9
2 1a7 1a9 1
1b0 1 1b2 2
1bc 1be 3 1ba
1bb 1c0 2 1c9
1cb 2 1cd 1cf
2 1d1 1d3 1
1db 2 1dd 1de
2 1d5 1e0 2
1e2 1e4 2 1e6
1e8 2 1ea 1ec
2 1ee 1f0 2
1c8 1f2 1 1f4
1 1f6 3 1fd
1fe 1ff f e9
108 17d 180 183
186 189 18c 18f
192 195 1a4 1b3
1f7 201 2 20e
210 3 20c 20d
212 2 21b 21d
2 21a 21f 2
226 22a 2 22c
22e 2 230 234
2 225 236 2
221 238 1 23a
3 23b 246 24a
1 205 2 25d
25f 3 25b 25c
261 2 26a 26c
2 269 26e 2
275 277 2 279
27b 3 280 281
282 2 27d 284
2 274 286 2
270 288 1 28a
4 254 28b 294
298 1 29c 1
24f 2 24d 2a0
9 2b 32 38
3e 44 4a 50
56 5d 
1
4
0 
2a7
0
1
14
2
11
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
7 1 0
4c 1 0
3 1 0
13 1 0
1b 1 0
40 1 0
3a 1 0
f 1 0
26 1 0
b 1 0
2d 1 0
17 1 0
52 1 0
46 1 0
34 1 0
58 1 0
0

/
SHOW ERRORS FUNCTION SP_U_RATES;
ALTER FUNCTION SP_U_RATES COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_RATES_EDITED
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_RATES_EDITED ==
CREATE OR REPLACE FUNCTION SP_U_RATES_EDITED wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
72
2 :e:
1FUNCTION:
1SP_U_RATES_EDITED:
1ID:
1VARCHAR2:
1RATES_EDITED001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_RESOURCE_ID:
1H_REG_COST:
1NUMBER:
10:
1H_SPEC_COST:
1H_REG_RATE:
1H_SPEC_RATE:
1H_FLAG:
1H_OLD_REG_COST:
1H_OLD_REG_SALE:
1H_OLD_SPEC_COST:
1H_OLD_SPEC_RATE:
1H_RATE_ID:
1H_RATE_ADJUSTMENT:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_RATES_EDITED(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
131:
1+:
1FPUT:
1               ENTER:: SP_U_RATES_EDITED(32) :: cplan.sql(12053) :: :
1REGULAR_COST:
1REGULAR_RATE:
1SPECIAL_COST:
1SPECIAL_RATE:
1RATE_ADJUSTMENT:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT REGULAR_COST, REGULAR_RATE,:n      SPECIAL_COST, SPECIAL_RATE, RATE_AD+
1JUSTMENT:n      INTO   h_old_reg_cost, h_old_reg_sale ,:n      h_old_spec_cos+
1t,h_old_spec_rate, h_rate_adjustment:n      FROM TASK_ASSIGNMENTS:n      WHER+
1E TSK_ASSIGNMENT_ID = id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
151:
1           EXCEPTION:: SP_U_RATES_EDITED(52) :: cplan.sql(12073) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1RATE_ID:
1RESOURCES:
1RESOURCE_ID:
1SELECT RATE_ID INTO h_rate_id:n      FROM RESOURCES:n      WHERE RESOURCE_ID +
1= res_id001:
166:
1           EXCEPTION:: SP_U_RATES_EDITED(67) :: cplan.sql(12088) :: :
1REGULAR_SALE:
1SPECIAL_SALE:
1RATES:
1SELECT REGULAR_COST, REGULAR_SALE,:n      SPECIAL_COST, SPECIAL_SALE:n      I+
1NTO   h_reg_cost, h_reg_rate ,:n      h_spec_cost,h_spec_rate:n      FROM RAT+
1ES:n      WHERE RATE_ID = h_rate_id:
184:
1           EXCEPTION:: SP_U_RATES_EDITED(85) :: cplan.sql(12106) :: :
1RATES_EDITED:
1BITAND:
1UPDATE TASK_ASSIGNMENTS:n      SET RATES_EDITED = BITAND(RATES_EDITED,rates_e+
1dited001):n      WHERE TSK_ASSIGNMENT_ID = id:
1FOUND:
1TRUE:
1=:
1100:
1103:
1           EXCEPTION:: SP_U_RATES_EDITED(104) :: cplan.sql(12125) :: :
1>:
12:
1FC_U_RATES:
14:
1121:
1       RETURN_STATUS:: SP_U_RATES_EDITED(122) :: cplan.sql(12143) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1128:
1           EXCEPTION:: SP_U_RATES_EDITED(129) :: cplan.sql(12150) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1140:
1           EXCEPTION:: SP_U_RATES_EDITED(141) :: cplan.sql(12162) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
390
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d a0 51 d :d a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :5 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :b a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :7 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 51
a5 b 51 a5 b 5a 7e 51
b4 2e :2 a0 d :2 a0 d b7 19
3c :3 a0 51 a5 b 51 a5 b
5a 7e 51 b4 2e :2 a0 d :2 a0
d b7 19 3c :2 a0 6b :9 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
390
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 bf ae b2 8d
ba ad db ca ce aa d6 c9
f7 e6 ea c6 f2 e5 113 102
106 e2 10e 101 12f 11e 122 fe
12a 11d 14b 13a 13e 11a 146 139
167 156 15a 136 162 155 183 172
176 152 17e 171 19f 18e 192 16e
19a 18d 1bc 1aa 18a 1ae 1af 1b7
1a9 1d8 1c7 1cb 1a6 1d3 1c6 1f8
1e3 1e7 1c3 1eb 1f3 1e2 1ff 203
1df 207 20b 20f 212 217 218 1
21a 21f 223 227 22a 22f 233 237
23a 23f 240 242 247 24a 24e 24f
254 259 25c 261 262 267 26a 26e
26f 274 277 27c 27d 282 285 28a
28b 290 293 297 29b 29f 2a0 2a2
2a7 2a8 2aa 2ab 2b0 2b3 2b8 2b9
2be 2c1 2c6 2c7 2cc 2cf 2d3 2d4
2d9 2dc 2e1 2e2 2e7 2ea 2ef 2f0
2f5 2f6 2fb 2fd 301 304 308 30c
30f 313 317 31a 31d 322 325 328
32b 32c 331 332 1 334 339 33d
341 344 349 34e 351 355 356 35b
35c 361 363 367 36a 36e 372 376
37a 37d 381 385 389 38d 391 395
399 39d 3a1 3a5 3a9 3ad 3b1 3b5
3c1 3c5 3c9 3cc 3d0 3d4 3d6 1
3da 3de 3e2 3e5 3e9 3ed 3f1 3f5
3f8 3fc 400 403 406 40b 40e 411
414 415 41a 41b 1 41d 422 426
42a 42d 432 437 43a 43e 43f 444
447 44c 44d 452 455 45a 45b 460
463 467 468 46d 470 475 476 47b
47e 482 486 489 48c 48d 48f 490
495 496 49b 49d 4a1 4a4 4a6 4aa
4ac 4b8 4ba 4bc 4bd 4c2 4c6 4c8
4d4 4d6 4da 4de 4e2 4e6 4ea 4f6
4fa 4fe 501 505 509 50b 1 50f
513 517 51a 51e 522 526 52a 52d
531 535 538 53b 540 543 546 549
54a 54f 550 1 552 557 55b 55f
562 567 56c 56f 573 574 579 57c
581 582 587 58a 58f 590 595 598
59c 59d 5a2 5a5 5aa 5ab 5b0 5b3
5b7 5bb 5be 5c1 5c2 5c4 5c5 5ca
5cb 5d0 5d2 5d6 5d9 5db 5df 5e1
5ed 5ef 5f1 5f2 5f7 5fb 5fd 609
60b 60f 613 617 61b 61f 623 627
62b 62f 633 637 643 647 64b 64e
652 656 658 1 65c 660 664 667
66b 66f 673 677 67a 67e 682 685
688 68d 690 693 696 697 69c 69d
1 69f 6a4 6a8 6ac 6af 6b4 6b9
6bc 6c0 6c1 6c6 6c9 6ce 6cf 6d4
6d7 6dc 6dd 6e2 6e5 6e9 6ea 6ef
6f2 6f7 6f8 6fd 700 704 708 70b
70e 70f 711 712 717 718 71d 71f
723 726 728 72c 72e 73a 73c 73e
73f 744 748 74a 756 758 75c 760
764 768 76c 770 774 780 784 789
78d 790 791 796 79a 79e 7a1 7a4
7a8 7aa 7ae 7b2 7b5 7b8 7bc 7be
7c2 7c6 7c9 7cb 1 7cf 7d3 7d7
7da 7de 7e2 7e6 7ea 7ed 7f1 7f5
7f8 7fb 800 803 806 809 80a 80f
810 1 812 817 81b 81f 822 827
82c 82f 833 834 839 83c 841 842
847 84a 84f 850 855 858 85c 85d
862 865 86a 86b 870 873 877 87b
87e 881 882 884 885 88a 88b 890
892 896 899 89b 89f 8a1 8ad 8af
8b1 8b2 8b7 8bb 8bd 8c9 8cb 8cf
8d3 8d7 8da 8db 8dd 8e0 8e1 8e3
8e6 8e9 8ec 8ed 8f2 8f6 8fa 8fe
902 906 90a 90c 910 913 917 91b
91f 922 923 925 928 929 92b 92e
931 934 935 93a 93e 942 946 94a
94e 952 954 958 95b 95f 963 966
96a 96e 972 976 97a 97e 982 986
98a 98b 98d 991 995 999 99c 9a0
9a4 9a7 9aa 9af 9b2 9b5 9b8 9b9
9be 9bf 1 9c1 9c6 9ca 9ce 9d1
9d6 9db 9de 9e2 9e3 9e8 9eb 9f0
9f1 9f6 9f9 9fe 9ff a04 a07 a0b
a0f a13 a17 a1a a1b a1d a22 a23
a25 a26 a2b a2e a33 a34 a39 a3c
a41 a42 a47 a4a a4e a4f a54 a57
a5c a5d a62 a63 a68 a6a a6e a71
a75 a79 a7c a80 a84 a87 a8b a8f
a90 a95 a97 a9b a9f aa2 aa6 aaa
aad ab1 ab5 ab8 abb ac0 ac3 ac6
ac9 aca acf ad0 1 ad2 ad7 adb
adf ae2 ae7 aec aef af3 af4 af9
afa aff b03 b07 b0a b0f b14 b17
b1b b1f b22 b23 b28 b2b b30 b31
b36 b39 b3d b41 b44 b45 b4a b4b
b50 b52 b56 b59 b5d b61 b65 b69
b6d b71 b75 b79 b7d b89 b8e b92
b96 b9a b9e ba0 ba1 ba6 1 baa
bae bb2 bb5 bb9 bbd bc1 bc5 bc8
bcc bd0 bd3 bd6 bdb bde be1 be4
be5 bea beb 1 bed bf2 bf6 bfa
bfd c02 c07 c0a c0e c0f c14 c15
c1a c1e c22 c25 c2a c2f c32 c36
c37 c3c c3f c44 c45 c4a c4d c51
c55 c58 c5b c5c c5e c5f c64 c65
c6a c6c c70 c73 c77 c7b c7f c83
c87 c8b c8f c9b ca0 ca4 ca8 cac
cb0 cb2 cb6 cb8 cc4 cc6 cc8 cc9
cce cd2 cd4 ce0 ce4 ce6 ce7 cf0 
390
2
0 1 a 6 9 :3 6 16 :3 6
10 :2 6 1 3 a 13 a :2 1
4 9 12 11 :2 9 :2 4 12 1b
1a :2 12 :2 4 :2 f 19 f :2 4 :2 10
1a 10 :2 4 :2 f 19 f :2 4 :2 10
1a 10 :2 4 :2 b 1a b :2 4 :2 13
1d 13 :2 4 :2 13 1d 13 :2 4 :2 14
1e 14 :2 4 :2 14 1e 14 :2 4 e
17 16 :2 e :2 4 :2 16 25 16 :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 59 5f 62 :2 59 70 8b 8
:2 70 d 10 :2 70 13 16 :2 70 b
e :2 70 13 16 1f 27 :2 1f 39
:2 16 :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 28 2b :2 70 30 33
:2 70 :2 7 4f :2 4 7 :2 11 23 :2 2d
39 3c 51 53 54 :2 51 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 57
:3 4 15 :2 4 e 4 e 1c 7
15 23 e 1e 7 17 28 c
d 21 :2 7 :2 10 1c 7 4 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 58 5a 5b :2 58 :2 29 :3 d
:2 13 18 24 68 6b :2 24 78 7b
:2 24 7f 82 :2 24 8e 91 :2 24 99
9c :2 24 a8 ab b2 bb be :2 ab
:2 24 :2 d 5e :2 a :2 7 :4 13 :2 7 4
:3 1 e 1b c d 1b :2 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 58 5a
5b :2 58 :2 29 :3 d :2 13 18 24 68
6b :2 24 78 7b :2 24 7f 82 :2 24
8e 91 :2 24 99 9c :2 24 a8 ab
b2 bb be :2 ab :2 24 :2 d 5e :2 a
:2 7 :4 13 :2 7 4 :3 1 e 1c 7
15 e 1a 7 13 c d 17
:2 7 :2 10 1c 7 4 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
58 5a 5b :2 58 :2 29 :3 d :2 13 18
24 68 6b :2 24 78 7b :2 24 7f
82 :2 24 8e 91 :2 24 99 9c :2 24
a8 ab b2 bb be :2 ab :2 24 :2 d
5e :2 a :2 7 :4 13 :2 7 4 :3 1 e
b 1a 21 2e d 21 7 e
a 16 :3 14 a :2 13 1f a 1b
a :2 13 1f a :4 7 4 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 58 5b 5c :2 58 :2 29 :3 d :2 13
18 24 69 6c :2 24 79 7c :2 24
80 83 :2 24 8f 92 :2 24 9a 9d
:2 24 a9 ac b3 bc bf :2 ac :2 24
:2 d 5f :2 a :2 7 :4 13 :2 7 4 :3 1
8 f 18 29 :2 f 2d :2 8 7
31 33 :2 31 7 19 :2 7 1a 7
35 :2 4 8 f 18 29 :2 f 2d
:2 8 7 31 33 :2 31 7 19 :2 7
1a 7 35 :3 4 :2 d 19 24 2a
3a 4b 23 34 47 56 :2 19 4
7 :2 11 23 :2 2d 39 3c 51 54
55 :2 51 :2 23 :3 7 :2 d 12 1e 63
66 :2 1e 73 76 :2 1e 7a 7d :2 1e
87 8a 93 9b :2 a4 :2 93 af :2 8a
:2 1e b7 ba :2 1e c2 c5 :2 1e ca
cd :2 1e d0 d3 :2 1e :2 7 58 :3 4
:2 f 21 :2 2a 34 38 :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
55 58 59 :2 55 :2 26 :3 a :2 10 15
21 66 69 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 5c :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
52 55 56 :2 52 :2 23 :3 7 :2 d 12
1e 63 66 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 59 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
390
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :6 a :6 b
:6 c :6 d :6 e :6 f
:6 10 :6 11 :6 12 :7 13
:6 14 :7 16 :b 18 :11 19
1a :2 19 :2 1a :2 19
:2 1a :2 19 :2 1b :2 19
:9 1b :2 19 :2 1c :2 19
:2 1c :2 19 :2 1c :2 19
:2 1c :2 19 :2 1c :4 19
:3 18 :11 1f :b 20 :3 1f
:3 23 :3 25 :2 28 :3 29
:2 2a :3 2b 2c :2 2d
28 :5 2e 27 :2 30
:5 32 :11 33 :24 34 :3 33
:2 31 :6 30 2f :3 17
:2 3a 3b :2 3c 3a
:5 3d 39 :2 3f :5 41
:11 42 :24 43 :3 42 :2 40
:6 3f 3e :3 17 :2 49
:2 4a :2 4b :2 4c 4d
:2 4e 49 :5 4f 48
:2 51 :5 53 :11 54 :24 55
:3 54 :2 52 :6 51 50
:3 17 5b :4 5c :2 5d
5b :6 5e :5 5f 5e
:5 61 60 :3 5e 5a
:2 64 :5 66 :11 67 :24 68
:3 67 :2 65 :6 64 63
:3 17 :e 6d :3 6e :3 6f
:3 6d :e 71 :3 72 :3 73
:3 71 :8 76 :4 77 :3 76
:11 79 :30 7a :3 79 :a 7c
17 :3 7f :11 80 :b 81
:17 82 :3 80 :2 84 :3 85
:3 86 87 85 84
85 :3 88 :3 7f :2 89
:5 8b :11 8c :b 8d :18 8e
:3 8c :2 90 91 :3 92
93 91 90 91
:3 94 :2 8a :6 89 7e
:7 1 
cf2
4
:3 0 1 :3 0 2
:a 0 38b 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 38b 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 389
0 b :6 0 10
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 389
0 d :6 0 10
:2 0 15 f :3 0
25 :7 0 29 26
27 389 0 e
:6 0 10 :2 0 17
f :3 0 2b :7 0
2f 2c 2d 389
0 11 :6 0 10
:2 0 19 f :3 0
31 :7 0 35 32
33 389 0 12
:6 0 10 :2 0 1b
f :3 0 37 :7 0
3b 38 39 389
0 13 :6 0 10
:2 0 1d 6 :3 0
3d :7 0 41 3e
3f 389 0 14
:6 0 10 :2 0 1f
f :3 0 43 :7 0
47 44 45 389
0 15 :6 0 10
:2 0 21 f :3 0
49 :7 0 4d 4a
4b 389 0 16
:6 0 10 :2 0 23
f :3 0 4f :7 0
53 50 51 389
0 17 :6 0 c
:2 0 25 f :3 0
55 :7 0 59 56
57 389 0 18
:6 0 10 :2 0 29
4 :3 0 27 5b
5d :6 0 60 5e
0 389 0 19
:6 0 68 69 0
2b 6 :3 0 62
:7 0 66 63 64
389 0 1a :6 0
6e 6f 0 2d
9 :3 0 a :2 0
4 6a :7 0 6d
6b 0 389 0
1b :6 0 1c :3 0
1d :3 0 1c :3 0
1e :3 0 71 72
0 2 :4 0 2f
73 75 70 77
76 :2 0 1f :3 0
20 :3 0 79 7a
0 21 :4 0 1c
:3 0 22 :3 0 7d
7e 0 2 :4 0
31 7f 81 23
:4 0 24 :2 0 25
:3 0 33 84 86
:3 0 26 :4 0 24
:2 0 27 :4 0 36
89 8b :3 0 24
:2 0 3 :3 0 39
8d 8f :3 0 24
:2 0 27 :4 0 3c
91 93 :3 0 24
:2 0 28 :4 0 3f
95 97 :3 0 24
:2 0 29 :3 0 2a
:3 0 5 :3 0 42
9b 9d 2b :4 0
44 9a a0 47
99 a2 :3 0 24
:2 0 28 :4 0 4a
a4 a6 :3 0 24
:2 0 27 :4 0 4d
a8 aa :3 0 24
:2 0 7 :3 0 50
ac ae :3 0 24
:2 0 27 :4 0 53
b0 b2 :3 0 24
:2 0 2c :4 0 56
b4 b6 :3 0 59
7b b8 :2 0 ba
5e bb 78 ba
0 bc 60 0
2e9 1c :3 0 1d
:3 0 bd be 0
1c :3 0 2d :3 0
c0 c1 0 2e
:2 0 2 :4 0 2f
:2 0 30 :2 0 2e
:2 0 62 c6 c8
:3 0 65 c2 ca
bf cc cb :2 0
1f :3 0 31 :3 0
ce cf 0 21
:4 0 32 :4 0 24
:2 0 25 :3 0 69
d3 d5 :3 0 6c
d0 d7 :2 0 d9
6f da cd d9
0 db 71 0
2e9 d :3 0 7
:3 0 dc dd 0
2e9 14 :3 0 10
:2 0 df e0 0
2e9 33 :3 0 34
:3 0 35 :3 0 36
:3 0 37 :3 0 15
:3 0 16 :3 0 17
:3 0 18 :3 0 1a
:3 0 38 :3 0 39
:3 0 3 :4 0 3a
1 :8 0 f5 9
:3 0 3b :3 0 f0
f1 0 3c :3 0
f2 f3 0 f5
73 13f 3d :3 0
9 :3 0 3b :3 0
f8 f9 0 3c
:3 0 fa fb 0
135 1c :3 0 1d
:3 0 fd fe 0
1c :3 0 2d :3 0
100 101 0 3e
:2 0 2 :4 0 3f
:2 0 30 :2 0 2e
:2 0 76 106 108
:3 0 79 102 10a
ff 10c 10b :2 0
1f :3 0 31 :3 0
10e 10f 0 21
:4 0 40 :4 0 24
:2 0 25 :3 0 7d
113 115 :3 0 24
:2 0 41 :4 0 80
117 119 :3 0 24
:2 0 42 :4 0 83
11b 11d :3 0 24
:2 0 3c :3 0 86
11f 121 :3 0 24
:2 0 43 :4 0 89
123 125 :3 0 24
:2 0 44 :3 0 45
:3 0 2e :2 0 46
:2 0 8c 128 12c
90 127 12e :3 0
93 110 130 :2 0
132 96 133 10d
132 0 134 98
0 135 9a 138
:3 0 138 0 138
137 135 136 :6 0
13a 2 :3 0 9d
13c 9f 13b 13a
:2 0 13d a1 :2 0
13f 0 13f 13e
f5 13d :6 0 2e9
1 :3 0 47 :3 0
19 :3 0 48 :3 0
49 :3 0 7 :4 0
4a 1 :8 0 14c
9 :3 0 3b :3 0
147 148 0 3c
:3 0 149 14a 0
14c a3 196 3d
:3 0 9 :3 0 3b
:3 0 14f 150 0
3c :3 0 151 152
0 18c 1c :3 0
1d :3 0 154 155
0 1c :3 0 2d
:3 0 157 158 0
3e :2 0 2 :4 0
4b :2 0 30 :2 0
2e :2 0 a6 15d
15f :3 0 a9 159
161 156 163 162
:2 0 1f :3 0 31
:3 0 165 166 0
21 :4 0 4c :4 0
24 :2 0 25 :3 0
ad 16a 16c :3 0
24 :2 0 41 :4 0
b0 16e 170 :3 0
24 :2 0 42 :4 0
b3 172 174 :3 0
24 :2 0 3c :3 0
b6 176 178 :3 0
24 :2 0 43 :4 0
b9 17a 17c :3 0
24 :2 0 44 :3 0
45 :3 0 2e :2 0
46 :2 0 bc 17f
183 c0 17e 185
:3 0 c3 167 187
:2 0 189 c6 18a
164 189 0 18b
c8 0 18c ca
18f :3 0 18f 0
18f 18e 18c 18d
:6 0 191 4 :3 0
cd 193 cf 192
191 :2 0 194 d1
:2 0 196 0 196
195 14c 194 :6 0
2e9 1 :3 0 33
:3 0 4d :3 0 35
:3 0 4e :3 0 e
:3 0 12 :3 0 11
:3 0 13 :3 0 4f
:3 0 47 :3 0 19
:4 0 50 1 :8 0
1a9 9 :3 0 3b
:3 0 1a4 1a5 0
3c :3 0 1a6 1a7
0 1a9 d3 1f3
3d :3 0 9 :3 0
3b :3 0 1ac 1ad
0 3c :3 0 1ae
1af 0 1e9 1c
:3 0 1d :3 0 1b1
1b2 0 1c :3 0
2d :3 0 1b4 1b5
0 3e :2 0 2
:4 0 51 :2 0 30
:2 0 2e :2 0 d6
1ba 1bc :3 0 d9
1b6 1be 1b3 1c0
1bf :2 0 1f :3 0
31 :3 0 1c2 1c3
0 21 :4 0 52
:4 0 24 :2 0 25
:3 0 dd 1c7 1c9
:3 0 24 :2 0 41
:4 0 e0 1cb 1cd
:3 0 24 :2 0 42
:4 0 e3 1cf 1d1
:3 0 24 :2 0 3c
:3 0 e6 1d3 1d5
:3 0 24 :2 0 43
:4 0 e9 1d7 1d9
:3 0 24 :2 0 44
:3 0 45 :3 0 2e
:2 0 46 :2 0 ec
1dc 1e0 f0 1db
1e2 :3 0 f3 1c4
1e4 :2 0 1e6 f6
1e7 1c1 1e6 0
1e8 f8 0 1e9
fa 1ec :3 0 1ec
0 1ec 1eb 1e9
1ea :6 0 1ee 6
:3 0 fd 1f0 ff
1ef 1ee :2 0 1f1
101 :2 0 1f3 0
1f3 1f2 1a9 1f1
:6 0 2e9 1 :3 0
38 :3 0 53 :3 0
54 :3 0 53 :3 0
5 :3 0 39 :3 0
3 :4 0 55 1
:8 0 212 56 :4 0
1fd :3 0 57 :3 0
58 :2 0 105 200
201 :3 0 9 :3 0
3b :3 0 203 204
0 10 :2 0 205
206 0 208 108
20f 9 :3 0 3b
:3 0 209 20a 0
59 :2 0 20b 20c
0 20e 10a 210
202 208 0 211
0 20e 0 211
10c 0 212 10f
25c 3d :3 0 9
:3 0 3b :3 0 215
216 0 3c :3 0
217 218 0 252
1c :3 0 1d :3 0
21a 21b 0 1c
:3 0 2d :3 0 21d
21e 0 3e :2 0
2 :4 0 5a :2 0
30 :2 0 2e :2 0
112 223 225 :3 0
115 21f 227 21c
229 228 :2 0 1f
:3 0 31 :3 0 22b
22c 0 21 :4 0
5b :4 0 24 :2 0
25 :3 0 119 230
232 :3 0 24 :2 0
41 :4 0 11c 234
236 :3 0 24 :2 0
42 :4 0 11f 238
23a :3 0 24 :2 0
3c :3 0 122 23c
23e :3 0 24 :2 0
43 :4 0 125 240
242 :3 0 24 :2 0
44 :3 0 45 :3 0
2e :2 0 46 :2 0
128 245 249 12c
244 24b :3 0 12f
22d 24d :2 0 24f
132 250 22a 24f
0 251 134 0
252 136 255 :3 0
255 0 255 254
252 253 :6 0 257
8 :3 0 139 259
13b 258 257 :2 0
25a 13d :2 0 25c
0 25c 25b 212
25a :6 0 2e9 1
:3 0 54 :3 0 29
:3 0 5 :3 0 10
:2 0 13f 25f 262
2e :2 0 142 25e
265 266 :2 0 5c
:2 0 10 :2 0 147
268 26a :3 0 15
:3 0 e :3 0 26c
26d 0 272 17
:3 0 11 :3 0 26f
270 0 272 14a
273 26b 272 0
274 14d 0 2e9
54 :3 0 29 :3 0
5 :3 0 10 :2 0
14f 276 279 5d
:2 0 152 275 27c
27d :2 0 5c :2 0
10 :2 0 157 27f
281 :3 0 16 :3 0
12 :3 0 283 284
0 289 18 :3 0
13 :3 0 286 287
0 289 15a 28a
282 289 0 28b
15d 0 2e9 9
:3 0 3b :3 0 28c
28d 0 5e :3 0
b :3 0 15 :3 0
17 :3 0 16 :3 0
18 :3 0 1a :3 0
d :3 0 14 :3 0
15f 28f 298 28e
299 0 2e9 1c
:3 0 1d :3 0 29b
29c 0 1c :3 0
2d :3 0 29e 29f
0 5f :2 0 2
:4 0 60 :2 0 30
:2 0 2e :2 0 168
2a4 2a6 :3 0 16b
2a0 2a8 29d 2aa
2a9 :2 0 1f :3 0
31 :3 0 2ac 2ad
0 21 :4 0 61
:4 0 24 :2 0 25
:3 0 16f 2b1 2b3
:3 0 24 :2 0 41
:4 0 172 2b5 2b7
:3 0 24 :2 0 62
:4 0 175 2b9 2bb
:3 0 24 :2 0 29
:3 0 2a :3 0 9
:3 0 3b :3 0 2c0
2c1 0 178 2bf
2c3 2b :4 0 17a
2be 2c6 17d 2bd
2c8 :3 0 24 :2 0
63 :4 0 180 2ca
2cc :3 0 24 :2 0
27 :4 0 183 2ce
2d0 :3 0 24 :2 0
3 :3 0 186 2d2
2d4 :3 0 24 :2 0
27 :4 0 189 2d6
2d8 :3 0 18c 2ae
2da :2 0 2dc 18f
2dd 2ab 2dc 0
2de 191 0 2e9
64 :3 0 65 :3 0
2df 2e0 0 9
:3 0 3b :3 0 2e2
2e3 0 3 :3 0
57 :3 0 193 2e1
2e7 :2 0 2e9 197
38a 9 :3 0 66
:2 0 4 2ea 2eb
0 1c :3 0 1d
:3 0 2ed 2ee 0
1c :3 0 2d :3 0
2f0 2f1 0 3e
:2 0 2 :4 0 67
:2 0 30 :2 0 2e
:2 0 1a5 2f6 2f8
:3 0 1a8 2f2 2fa
2ef 2fc 2fb :2 0
1f :3 0 31 :3 0
2fe 2ff 0 21
:4 0 68 :4 0 24
:2 0 25 :3 0 1ac
303 305 :3 0 1af
300 307 :2 0 320
1f :3 0 31 :3 0
309 30a 0 21
:4 0 69 :4 0 24
:2 0 9 :3 0 6a
:3 0 30f 310 0
1b2 30e 312 :3 0
24 :2 0 63 :4 0
1b5 314 316 :3 0
24 :2 0 9 :3 0
6b :3 0 319 31a
0 1b8 318 31c
:3 0 1bb 30b 31e
:2 0 320 1be 321
2fd 320 0 322
1c1 0 332 6c
:3 0 1b :3 0 9
:3 0 6a :3 0 6d
:3 0 9 :3 0 6b
:3 0 3 :3 0 6e
:4 0 6f 1 :a 0
32e :2 0 332 324
32c :2 0 8 :3 0
1b :3 0 330 :2 0
332 1c3 334 1c7
333 332 :2 0 388
3d :3 0 9 :3 0
3b :3 0 337 338
0 3c :3 0 339
33a 0 380 1c
:3 0 1d :3 0 33c
33d 0 1c :3 0
2d :3 0 33f 340
0 3e :2 0 2
:4 0 70 :2 0 30
:2 0 2e :2 0 1c9
345 347 :3 0 1cc
341 349 33e 34b
34a :2 0 1f :3 0
31 :3 0 34d 34e
0 21 :4 0 71
:4 0 24 :2 0 25
:3 0 1d0 352 354
:3 0 1d3 34f 356
:2 0 370 1f :3 0
31 :3 0 358 359
0 21 :4 0 42
:4 0 24 :2 0 3c
:3 0 1d6 35d 35f
:3 0 24 :2 0 43
:4 0 1d9 361 363
:3 0 24 :2 0 44
:3 0 45 :3 0 2e
:2 0 46 :2 0 1dc
366 36a 1e0 365
36c :3 0 1e3 35a
36e :2 0 370 1e6
371 34c 370 0
372 1e9 0 380
6c :3 0 1b :3 0
6d :3 0 9 :3 0
6b :3 0 3 :3 0
6e :4 0 72 1
:a 0 37c :2 0 380
374 37a :2 0 8
:3 0 1b :3 0 37e
:2 0 380 1eb 383
:3 0 383 0 383
382 380 381 :6 0
385 1 :3 0 1f0
387 1f2 386 385
:2 0 388 1f4 :2 0
38a 1f7 38a 389
2e9 388 :6 0 38b
:2 0 2 14 38a
38e :3 0 38d 38b
38f :8 0 
206
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
24 1 2a 1
30 1 36 1
3c 1 42 1
48 1 4e 1
54 1 5c 1
5a 1 61 1
67 1 74 1
80 2 83 85
2 88 8a 2
8c 8e 2 90
92 2 94 96
1 9c 2 9e
9f 2 98 a1
2 a3 a5 2
a7 a9 2 ab
ad 2 af b1
2 b3 b5 4
7c 82 87 b7
1 b9 1 bb
2 c5 c7 3
c3 c4 c9 2
d2 d4 2 d1
d6 1 d8 1
da 2 ef f4
2 105 107 3
103 104 109 2
112 114 2 116
118 2 11a 11c
2 11e 120 2
122 124 3 129
12a 12b 2 126
12d 2 111 12f
1 131 1 133
2 fc 134 1
138 1 f7 1
13c 2 146 14b
2 15c 15e 3
15a 15b 160 2
169 16b 2 16d
16f 2 171 173
2 175 177 2
179 17b 3 180
181 182 2 17d
184 2 168 186
1 188 1 18a
2 153 18b 1
18f 1 14e 1
193 2 1a3 1a8
2 1b9 1bb 3
1b7 1b8 1bd 2
1c6 1c8 2 1ca
1cc 2 1ce 1d0
2 1d2 1d4 2
1d6 1d8 3 1dd
1de 1df 2 1da
1e1 2 1c5 1e3
1 1e5 1 1e7
2 1b0 1e8 1
1ec 1 1ab 1
1f0 1 1ff 2
1fe 1ff 1 207
1 20d 2 20f
210 2 1fc 211
2 222 224 3
220 221 226 2
22f 231 2 233
235 2 237 239
2 23b 23d 2
23f 241 3 246
247 248 2 243
24a 2 22e 24c
1 24e 1 250
2 219 251 1
255 1 214 1
259 2 260 261
2 263 264 1
269 2 267 269
2 26e 271 1
273 2 277 278
2 27a 27b 1
280 2 27e 280
2 285 288 1
28a 8 290 291
292 293 294 295
296 297 2 2a3
2a5 3 2a1 2a2
2a7 2 2b0 2b2
2 2b4 2b6 2
2b8 2ba 1 2c2
2 2c4 2c5 2
2bc 2c7 2 2c9
2cb 2 2cd 2cf
2 2d1 2d3 2
2d5 2d7 2 2af
2d9 1 2db 1
2dd 3 2e4 2e5
2e6 d bc db
de e1 13f 196
1f3 25c 274 28b
29a 2de 2e8 2
2f5 2f7 3 2f3
2f4 2f9 2 302
304 2 301 306
2 30d 311 2
313 315 2 317
31b 2 30c 31d
2 308 31f 1
321 3 322 32d
331 1 2ec 2
344 346 3 342
343 348 2 351
353 2 350 355
2 35c 35e 2
360 362 3 367
368 369 2 364
36b 2 35b 36d
2 357 36f 1
371 4 33b 372
37b 37f 1 383
1 336 2 334
387 e 1b 22
28 2e 34 3a
40 46 4c 52
58 5f 65 6c

1
4
0 
38e
0
1
14
a
12
0 1 2 1 4 1 6 1
8 1 0 0 0 0 0 0
0 0 0 0 
42 1 0
61 1 0
5a 1 0
1d 1 0
54 1 0
3 1 0
b 1 0
2a 1 0
30 1 0
2 0 1
48 1 0
4e 1 0
16 1 0
3c 1 0
36 1 0
7 1 0
24 1 0
67 1 0
0

/
SHOW ERRORS FUNCTION SP_U_RATES_EDITED;
ALTER FUNCTION SP_U_RATES_EDITED COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_TIMECODE2
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_TIMECODE2 ==
CREATE OR REPLACE FUNCTION SP_U_TIMECODE2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
54
2 :e:
1FUNCTION:
1SP_U_TIMECODE2:
1ASSIGN_ID:
1VARCHAR2:
1ID:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TEMP_SC_STATE:
1PLS_INTEGER:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_TIMECODE2(:
1':
1, :
1);:
1CHECK_TRACE:
11:
117:
1+:
1FPUT:
1               ENTER:: SP_U_TIMECODE2(18) :: cplan.sql(12204) :: :
1IS NULL:
18:
122:
1      RETURN_INVALID:: SP_U_TIMECODE2(23) :: cplan.sql(12209) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
125:
1                EXIT:: SP_U_TIMECODE2(26) :: cplan.sql(12212) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TASK_ASSIGNMENTS:
1TIMECODE2_ID:
1TSK_ASSIGNMENT_ID:
1UPDATE TASK_ASSIGNMENTS SET TIMECODE2_ID = id WHERE TSK_ASSIGNMENT_ID = assig+
1n_id:
1FOUND:
1=:
1SC_STATE:
1100:
1OTHERS:
1SQLCODE:
116:
143:
1           EXCEPTION:: SP_U_TIMECODE2(44) :: cplan.sql(12230) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
14:
149:
1       RETURN_STATUS:: SP_U_TIMECODE2(50) :: cplan.sql(12236) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
156:
1           EXCEPTION:: SP_U_TIMECODE2(57) :: cplan.sql(12243) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
168:
1           EXCEPTION:: SP_U_TIMECODE2(69) :: cplan.sql(12255) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
247
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c a0 7e b4 2e :2 5a
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
247
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 71 5d 61 69 6c 5c
91 7c 80 59 84 8c 7b 98
9c 78 a0 a4 a8 ab b0 b1
1 b3 b8 bc c0 c3 c8 cc
d0 d3 d8 d9 db e0 e3 e7
e8 ed f2 f5 fa fb 100 103
107 108 10d 110 115 116 11b 11e
123 124 129 12c 131 132 137 13a
13e 13f 144 147 14c 14d 152 155
15a 15b 160 161 166 168 16c 16f
173 177 17a 17e 182 185 188 18d
190 193 196 197 19c 19d 1 19f
1a4 1a8 1ac 1af 1b4 1b9 1bc 1c0
1c1 1c6 1c7 1cc 1ce 1d2 1d5 1d9
1dc 1dd 1e2 1e5 1e8 1ec 1ef 1f0
1f5 1f8 1 1fb 200 204 208 20b
20f 213 216 219 21e 221 224 227
228 22d 22e 1 230 235 239 23d
240 245 24a 24d 251 252 257 25a
25f 260 265 268 26d 26e 273 276
27a 27e 282 286 289 28a 28c 291
292 294 295 29a 29b 2a0 2a2 2a6
2a9 2ad 2b1 2b4 2b8 2bc 2bf 2c2
2c7 2ca 2cd 2d0 2d1 2d6 2d7 1
2d9 2de 2e2 2e6 2e9 2ee 2f3 2f6
2fa 2fb 300 301 306 308 30c 30f
313 317 31a 31e 322 325 329 32a
32f 331 335 338 33c 340 344 348
34c 358 35c 361 365 368 369 36e
372 376 379 37c 380 382 386 38a
38d 390 394 396 39a 39e 3a1 3a3
1 3a7 3ab 3af 3b2 3b6 3ba 3be
3c2 3c5 3c9 3cd 3d0 3d3 3d8 3db
3de 3e1 3e2 3e7 3e8 1 3ea 3ef
3f3 3f7 3fa 3ff 404 407 40b 40c
411 414 419 41a 41f 422 427 428
42d 430 434 435 43a 43d 442 443
448 44b 44f 453 456 459 45a 45c
45d 462 463 468 46a 46e 471 473
477 479 485 487 489 48a 48f 493
495 4a1 4a3 4a7 4ab 4ae 4b2 4b6
4b9 4bc 4c1 4c4 4c7 4ca 4cb 4d0
4d1 1 4d3 4d8 4dc 4e0 4e3 4e8
4ed 4f0 4f4 4f5 4fa 4fd 502 503
508 50b 510 511 516 519 51d 521
525 529 52c 52d 52f 534 535 537
538 53d 540 545 546 54b 54e 553
554 559 55c 560 561 566 569 56e
56f 574 575 57a 57c 580 583 587
58b 58e 592 596 599 59d 5a1 5a2
5a7 5a9 5ad 5b1 5b4 5b8 5bc 5bf
5c3 5c7 5ca 5cd 5d2 5d5 5d8 5db
5dc 5e1 5e2 1 5e4 5e9 5ed 5f1
5f4 5f9 5fe 601 605 606 60b 60c
611 615 619 61c 621 626 629 62d
631 634 635 63a 63d 642 643 648
64b 64f 653 656 657 65c 65d 662
664 668 66b 66f 673 677 67b 67f
683 687 68b 68f 69b 6a0 6a4 6a8
6ac 6b0 6b2 6b3 6b8 1 6bc 6c0
6c4 6c7 6cb 6cf 6d3 6d7 6da 6de
6e2 6e5 6e8 6ed 6f0 6f3 6f6 6f7
6fc 6fd 1 6ff 704 708 70c 70f
714 719 71c 720 721 726 727 72c
730 734 737 73c 741 744 748 749
74e 751 756 757 75c 75f 763 767
76a 76d 76e 770 771 776 777 77c
77e 782 785 789 78d 791 795 799
79d 7a1 7ad 7b2 7b6 7ba 7be 7c2
7c4 7c8 7ca 7d6 7d8 7da 7db 7e0
7e4 7e6 7f2 7f6 7f8 7f9 802 
247
2
0 1 a 6 10 :3 6 9 :2 6
1 3 a 13 a :2 1 4 :2 14
23 14 :2 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 56 5c 5f :2 56
6d 85 8 :2 6d d 10 :2 6d 1a
1d :2 6d b e :2 6d 13 16 :2 6d
1b 1e :2 6d 21 24 :2 6d 29 2c
:2 6d :2 7 4c :2 4 7 :2 11 23 :2 2d
39 3c 4e 50 51 :2 4e :2 23 :3 7
:2 d 12 1e 5f 62 :2 1e :2 7 54
:2 4 :4 9 8 7 :4 22 21 20 :2 7
a :2 14 26 :2 30 3c 3f 51 53
54 :2 51 :2 26 :3 a :2 10 15 21 62
65 :2 21 72 75 :2 21 79 7c :2 21
86 89 92 9a :2 a3 :2 92 b4 :2 89
:2 21 :2 a 57 :2 7 a :2 14 26 :2 30
3c 3f 51 53 54 :2 51 :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 :2 12 28 :2 31 41 :2 7 2f :2 4
e 23 32 3b 4f 7 e a
16 :3 14 a :2 13 1f a 1b a
:2 13 1f a :4 7 4 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
55 57 58 :2 55 :2 29 :3 d :2 13 18
24 65 68 :2 24 75 78 :2 24 7c
7f :2 24 8b 8e :2 24 96 99 :2 24
a5 a8 af b8 bb :2 a8 :2 24 :2 d
5b :2 a :2 7 :4 13 :2 7 4 :3 1 7
:2 11 23 :2 2d 39 3c 4e 50 51
:2 4e :2 23 :3 7 :2 d 12 1e 5f 62
:2 1e 6f 72 :2 1e 76 79 :2 1e 83
86 8f 97 :2 a0 :2 8f ab :2 86 :2 1e
b3 b6 :2 1e be c1 :2 1e c6 c9
:2 1e d3 d6 :2 1e :2 7 54 :3 4 :2 f
21 :2 2a 34 3f :2 4 1 9 12
9 a :2 14 26 :2 30 3c 40 52
54 55 :2 52 :2 26 :3 a :2 10 15 21
62 65 :2 21 :3 a :2 10 15 39 5c
5f :2 68 :2 39 76 79 :2 39 81 84
:2 8d :2 39 :2 a 58 :3 7 c 15 1e
2c a 13 1e f e 7 e
7 e 7 29 :2 4 :2 9 7 :2 10
1c :2 7 :2 11 23 :2 2d 39 3d 4f
51 52 :2 4f :2 23 :3 7 :2 d 12 1e
5f 62 :2 1e :3 7 :2 d 12 36 42
45 :2 36 4d 50 :2 36 5c 5f 66
6f 72 :2 5f :2 36 :2 7 55 :2 4 7
c 1b a 13 1e f e 7
e 7 e 7 :2 4 :4 10 :2 4 :8 1

247
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :6 7
:7 9 :b b :11 c d
:2 c :2 d :2 c :2 d
:2 c :2 e :2 c :2 e
:2 c :2 e :2 c :2 e
:2 c :2 e :4 c :3 b
:11 11 :b 12 :3 11 :e 15
:11 16 :20 17 :3 16 :11 19
:b 1a :3 19 :9 1c :3 15
:6 21 :6 22 :5 23 22
:5 25 24 :3 22 20
:2 28 :5 2a :11 2b :24 2c
:3 2b :2 29 :6 28 27
:3 a :11 31 :30 32 :3 31
:a 34 a :3 37 :11 38
:b 39 :17 3a :3 38 :2 3c
:3 3d :3 3e 3f 3d
3c 3d :3 40 :3 37
:2 41 :5 43 :11 44 :b 45
:18 46 :3 44 :2 48 49
:3 4a 4b 49 48
49 :3 4c :2 42 :6 41
36 :7 1 
804
4
:3 0 1 :3 0 2
:a 0 242 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 4
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :3 0 8 :2 0
4 b f 0
242 2 10 :2 0
19 1a 0 :2 a
:3 0 13 :7 0 b
:2 0 17 14 15
240 0 9 :6 0
1f 20 0 c
7 :3 0 8 :2 0
4 1b :7 0 1e
1c 0 240 0
c :6 0 d :3 0
e :3 0 d :3 0
f :3 0 22 23
0 2 :4 0 e
24 26 21 28
27 :2 0 10 :3 0
11 :3 0 2a 2b
0 12 :4 0 d
:3 0 13 :3 0 2e
2f 0 2 :4 0
10 30 32 14
:4 0 15 :2 0 16
:3 0 12 35 37
:3 0 17 :4 0 15
:2 0 18 :4 0 15
3a 3c :3 0 15
:2 0 3 :3 0 18
3e 40 :3 0 15
:2 0 18 :4 0 1b
42 44 :3 0 15
:2 0 19 :4 0 1e
46 48 :3 0 15
:2 0 18 :4 0 21
4a 4c :3 0 15
:2 0 5 :3 0 24
4e 50 :3 0 15
:2 0 18 :4 0 27
52 54 :3 0 15
:2 0 1a :4 0 2a
56 58 :3 0 2d
2c 5a :2 0 5c
32 5d 29 5c
0 5e 34 0
1a0 d :3 0 e
:3 0 5f 60 0
d :3 0 1b :3 0
62 63 0 1c
:2 0 2 :4 0 1d
:2 0 1e :2 0 1c
:2 0 36 68 6a
:3 0 39 64 6c
61 6e 6d :2 0
10 :3 0 1f :3 0
70 71 0 12
:4 0 20 :4 0 15
:2 0 16 :3 0 3d
75 77 :3 0 40
72 79 :2 0 7b
43 7c 6f 7b
0 7d 45 0
1a0 3 :3 0 21
:2 0 47 7f 80
:3 0 81 :2 0 82
:2 0 5 :3 0 21
:2 0 49 85 86
:3 0 87 :2 0 88
:2 0 83 8a 89
:2 0 d :3 0 e
:3 0 8c 8d 0
d :3 0 1b :3 0
8f 90 0 22
:2 0 2 :4 0 23
:2 0 1e :2 0 1c
:2 0 4b 95 97
:3 0 4e 91 99
8e 9b 9a :2 0
10 :3 0 1f :3 0
9d 9e 0 12
:4 0 24 :4 0 15
:2 0 16 :3 0 52
a2 a4 :3 0 15
:2 0 25 :4 0 55
a6 a8 :3 0 15
:2 0 26 :4 0 58
aa ac :3 0 15
:2 0 27 :3 0 28
:3 0 29 :3 0 2a
:3 0 b1 b2 0
5b b0 b4 2b
:4 0 5d af b7
60 ae b9 :3 0
63 9f bb :2 0
bd 66 be 9c
bd 0 bf 68
0 e8 d :3 0
e :3 0 c0 c1
0 d :3 0 1b
:3 0 c3 c4 0
1c :2 0 2 :4 0
2c :2 0 1e :2 0
1c :2 0 6a c9
cb :3 0 6d c5
cd c2 cf ce
:2 0 10 :3 0 1f
:3 0 d1 d2 0
12 :4 0 2d :4 0
15 :2 0 16 :3 0
71 d6 d8 :3 0
74 d3 da :2 0
dc 77 dd d0
dc 0 de 79
0 e8 2e :3 0
2f :3 0 df e0
0 29 :3 0 2a
:3 0 e2 e3 0
30 :3 0 7b e1
e6 :2 0 e8 7e
e9 8b e8 0
ea 82 0 1a0
31 :3 0 32 :3 0
5 :3 0 33 :3 0
3 :4 0 34 1
:8 0 106 35 :4 0
f1 :3 0 30 :3 0
36 :2 0 86 f4
f5 :3 0 7 :3 0
37 :3 0 f7 f8
0 b :2 0 f9
fa 0 fc 89
103 7 :3 0 37
:3 0 fd fe 0
38 :2 0 ff 100
0 102 8b 104
f6 fc 0 105
0 102 0 105
8d 0 106 90
150 39 :3 0 7
:3 0 37 :3 0 109
10a 0 3a :3 0
10b 10c 0 146
d :3 0 e :3 0
10e 10f 0 d
:3 0 1b :3 0 111
112 0 3b :2 0
2 :4 0 3c :2 0
1e :2 0 1c :2 0
93 117 119 :3 0
96 113 11b 110
11d 11c :2 0 10
:3 0 1f :3 0 11f
120 0 12 :4 0
3d :4 0 15 :2 0
16 :3 0 9a 124
126 :3 0 15 :2 0
25 :4 0 9d 128
12a :3 0 15 :2 0
3e :4 0 a0 12c
12e :3 0 15 :2 0
3a :3 0 a3 130
132 :3 0 15 :2 0
3f :4 0 a6 134
136 :3 0 15 :2 0
40 :3 0 41 :3 0
1c :2 0 42 :2 0
a9 139 13d ad
138 13f :3 0 b0
121 141 :2 0 143
b3 144 11e 143
0 145 b5 0
146 b7 149 :3 0
149 0 149 148
146 147 :6 0 14b
2 :3 0 ba 14d
bc 14c 14b :2 0
14e be :2 0 150
0 150 14f 106
14e :6 0 1a0 1
:3 0 d :3 0 e
:3 0 152 153 0
d :3 0 1b :3 0
155 156 0 43
:2 0 2 :4 0 44
:2 0 1e :2 0 1c
:2 0 c0 15b 15d
:3 0 c3 157 15f
154 161 160 :2 0
10 :3 0 1f :3 0
163 164 0 12
:4 0 45 :4 0 15
:2 0 16 :3 0 c7
168 16a :3 0 15
:2 0 25 :4 0 ca
16c 16e :3 0 15
:2 0 26 :4 0 cd
170 172 :3 0 15
:2 0 27 :3 0 28
:3 0 7 :3 0 37
:3 0 177 178 0
d0 176 17a 2b
:4 0 d2 175 17d
d5 174 17f :3 0
15 :2 0 46 :4 0
d8 181 183 :3 0
15 :2 0 18 :4 0
db 185 187 :3 0
15 :2 0 3 :3 0
de 189 18b :3 0
15 :2 0 18 :4 0
e1 18d 18f :3 0
e4 165 191 :2 0
193 e7 194 162
193 0 195 e9
0 1a0 2e :3 0
47 :3 0 196 197
0 7 :3 0 37
:3 0 199 19a 0
3 :3 0 30 :3 0
eb 198 19e :2 0
1a0 ef 241 7
:3 0 48 :2 0 4
1a1 1a2 0 d
:3 0 e :3 0 1a4
1a5 0 d :3 0
1b :3 0 1a7 1a8
0 3b :2 0 2
:4 0 49 :2 0 1e
:2 0 1c :2 0 f6
1ad 1af :3 0 f9
1a9 1b1 1a6 1b3
1b2 :2 0 10 :3 0
1f :3 0 1b5 1b6
0 12 :4 0 4a
:4 0 15 :2 0 16
:3 0 fd 1ba 1bc
:3 0 100 1b7 1be
:2 0 1d7 10 :3 0
1f :3 0 1c0 1c1
0 12 :4 0 4b
:4 0 15 :2 0 7
:3 0 4c :3 0 1c6
1c7 0 103 1c5
1c9 :3 0 15 :2 0
46 :4 0 106 1cb
1cd :3 0 15 :2 0
7 :3 0 4d :3 0
1d0 1d1 0 109
1cf 1d3 :3 0 10c
1c2 1d5 :2 0 1d7
10f 1d8 1b4 1d7
0 1d9 112 0
1e9 4e :3 0 c
:3 0 7 :3 0 4c
:3 0 4f :3 0 7
:3 0 4d :3 0 5
:3 0 50 :4 0 51
1 :a 0 1e5 :2 0
1e9 1db 1e3 :2 0
6 :3 0 c :3 0
1e7 :2 0 1e9 114
1eb 118 1ea 1e9
:2 0 23f 39 :3 0
7 :3 0 37 :3 0
1ee 1ef 0 3a
:3 0 1f0 1f1 0
237 d :3 0 e
:3 0 1f3 1f4 0
d :3 0 1b :3 0
1f6 1f7 0 3b
:2 0 2 :4 0 52
:2 0 1e :2 0 1c
:2 0 11a 1fc 1fe
:3 0 11d 1f8 200
1f5 202 201 :2 0
10 :3 0 1f :3 0
204 205 0 12
:4 0 53 :4 0 15
:2 0 16 :3 0 121
209 20b :3 0 124
206 20d :2 0 227
10 :3 0 1f :3 0
20f 210 0 12
:4 0 3e :4 0 15
:2 0 3a :3 0 127
214 216 :3 0 15
:2 0 3f :4 0 12a
218 21a :3 0 15
:2 0 40 :3 0 41
:3 0 1c :2 0 42
:2 0 12d 21d 221
131 21c 223 :3 0
134 211 225 :2 0
227 137 228 203
227 0 229 13a
0 237 4e :3 0
c :3 0 4f :3 0
7 :3 0 4d :3 0
5 :3 0 50 :4 0
54 1 :a 0 233
:2 0 237 22b 231
:2 0 6 :3 0 c
:3 0 235 :2 0 237
13c 23a :3 0 23a
0 23a 239 237
238 :6 0 23c 1
:3 0 141 23e 143
23d 23c :2 0 23f
145 :2 0 241 148
241 240 1a0 23f
:6 0 242 :2 0 2
10 241 245 :3 0
244 242 246 :8 0

14b
4
:3 0 1 3 1
7 2 6 a
1 12 1 18
1 25 1 31
2 34 36 2
39 3b 2 3d
3f 2 41 43
2 45 47 2
49 4b 2 4d
4f 2 51 53
2 55 57 4
2d 33 38 59
1 5b 1 5d
2 67 69 3
65 66 6b 2
74 76 2 73
78 1 7a 1
7c 1 7e 1
84 2 94 96
3 92 93 98
2 a1 a3 2
a5 a7 2 a9
ab 1 b3 2
b5 b6 2 ad
b8 2 a0 ba
1 bc 1 be
2 c8 ca 3
c6 c7 cc 2
d5 d7 2 d4
d9 1 db 1
dd 2 e4 e5
3 bf de e7
1 e9 1 f3
2 f2 f3 1
fb 1 101 2
103 104 2 f0
105 2 116 118
3 114 115 11a
2 123 125 2
127 129 2 12b
12d 2 12f 131
2 133 135 3
13a 13b 13c 2
137 13e 2 122
140 1 142 1
144 2 10d 145
1 149 1 108
1 14d 2 15a
15c 3 158 159
15e 2 167 169
2 16b 16d 2
16f 171 1 179
2 17b 17c 2
173 17e 2 180
182 2 184 186
2 188 18a 2
18c 18e 2 166
190 1 192 1
194 3 19b 19c
19d 6 5e 7d
ea 150 195 19f
2 1ac 1ae 3
1aa 1ab 1b0 2
1b9 1bb 2 1b8
1bd 2 1c4 1c8
2 1ca 1cc 2
1ce 1d2 2 1c3
1d4 2 1bf 1d6
1 1d8 3 1d9
1e4 1e8 1 1a3
2 1fb 1fd 3
1f9 1fa 1ff 2
208 20a 2 207
20c 2 213 215
2 217 219 3
21e 21f 220 2
21b 222 2 212
224 2 20e 226
1 228 4 1f2
229 232 236 1
23a 1 1ed 2
1eb 23e 2 16
1d 
1
4
0 
245
0
1
14
4
5
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
7 1 0
12 1 0
3 1 0
18 1 0
0

/
SHOW ERRORS FUNCTION SP_U_TIMECODE2;
ALTER FUNCTION SP_U_TIMECODE2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_S_PROFILE
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
 $$bitflag       Description
   0	-  WBS Project global view: Resources  Profile with Competencies  Skills
   1	-  WBS Project global view: Resources  Profiles
   6	-  CRI Project global view: Resources  Profiles
   2,3	-  WBS  CRI - Assignments View
   4	-  WBS  CRI - All assignments with effort (no participants, no project assignments) in the current project
   5	-  WBS  CRI - All participants (no effort) in the current project
   8	-  WBS  CRI - All assignments (effort, participants, project assignments) in the current project
   9	-  WBS  CRI - All assignments for a Resource / Profile under a element (project, deliverable, task)
   7	-  WBS Project Assignments
   11	-  DOC Assignments View (SC_TABLE_DOC, SC_TABLE_POL_DOC, SC_TABLE_RES_DOC, SC_TABLE_AST_DOC,SC_TABLE_CLN_DOC,SC_TABLE_VDR_DOC)
   12	-  WBS  CRI - display nickname for All assignments (effort, participants, project assignments) in the current project
   13	-  Returns nickname for All assignments (effort, participants, project assignments) in the current pool
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_S_PROFILE ==
CREATE OR REPLACE FUNCTION SP_S_PROFILE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1fa
2 :e:
1FUNCTION:
1SP_S_PROFILE:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_RANK:
1200:
1H_ID:
132:
1H_REC_USER:
1H_PROJECT_ID:
1H_IN:
1255:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_PER_DAY:
1H_TYPE_ID:
1H_COUNT:
1H_TEMP_SC_STATE:
1H_LEVEL_STATE:
1C7751A:
1C7751B:
1C7751C:
1C7751T:
1C7751D:
1C7751E:
1C7751F:
1C7751G:
1C7751H:
1C7751J:
1C7751L:
1C7751M:
1C7751N:
1C77513N:
1CLN_AST_RES:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_S_PROFILE(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
175:
1+:
1FPUT:
1               ENTER:: SP_S_PROFILE(76) :: cplan.sql(12370) :: :
1IS NULL:
182:
1        RETURN_ERROR:: SP_S_PROFILE(83) :: cplan.sql(12377) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1 ID:: :
185:
1                EXIT:: SP_S_PROFILE(86) :: cplan.sql(12380) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1=:
12:
13:
1B:
1PROJECT_ID:
1TYPE_ID:
1A:
1MINUTE_PER_DAY:
1LEVEL_STATE:
1TMT_WBS:
1ELEMENT_ID:
1SELECT B.PROJECT_ID, B.TYPE_ID, COALESCE(A.MINUTE_PER_DAY, 480), B.LEVEL_STAT+
1E:n         INTO h_project_id, h_type_id, h_per_day, h_level_state:n         +
1FROM TMT_WBS A, TMT_WBS B WHERE B.ELEMENT_ID = h_id AND A.ELEMENT_ID = B.PROJ+
1ECT_ID:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1108:
1           EXCEPTION:: SP_S_PROFILE(109) :: cplan.sql(12403) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT B.PROJECT_ID, B.TYPE_ID, COALESCE(A.MINUTE_PER_DAY, 480):n            +
1INTO h_project_id, h_type_id, h_per_day:n            FROM TMT_WBS A, TMT_CRI +
1B WHERE B.ELEMENT_ID = h_id AND A.ELEMENT_ID = B.PROJECT_ID:
1125:
1           EXCEPTION:: SP_S_PROFILE(126) :: cplan.sql(12420) :: :
1TMT_POOLS:
1SELECT 480 INTO h_per_day FROM TMT_POOLS WHERE ELEMENT_ID = h_id:
1140:
1           EXCEPTION:: SP_S_PROFILE(141) :: cplan.sql(12435) :: :
1147:
1        RETURN_ERROR:: SP_S_PROFILE(148) :: cplan.sql(12442) :: :
1150:
1                EXIT:: SP_S_PROFILE(151) :: cplan.sql(12445) :: :
1ELSIF:
110:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID INTO h_project_id:n         FROM TASK_ASSIGNMENTS WHERE TSK+
1_ASSIGNMENT_ID = h_id:
1166:
1           EXCEPTION:: SP_S_PROFILE(167) :: cplan.sql(12461) :: :
1173:
1        RETURN_ERROR:: SP_S_PROFILE(174) :: cplan.sql(12468) :: :
1176:
1                EXIT:: SP_S_PROFILE(177) :: cplan.sql(12471) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), LEVEL_STATE INTO h_per_day, h_level_sta+
1te:n         FROM TMT_WBS WHERE ELEMENT_ID = h_id:
1190:
1           EXCEPTION:: SP_S_PROFILE(191) :: cplan.sql(12485) :: :
113:
1RANK:
1SELECT RANK INTO h_rank FROM TMT_POOLS WHERE ELEMENT_ID = h_id:
1203:
1           EXCEPTION:: SP_S_PROFILE(204) :: cplan.sql(12498) :: :
1210:
1        RETURN_ERROR:: SP_S_PROFILE(211) :: cplan.sql(12505) :: :
1213:
1                EXIT:: SP_S_PROFILE(214) :: cplan.sql(12508) :: :
1480:
1!=:
1SC_SRCH_PARTICIPANT:
111:
1SC_ASSET_ASSIGNED_RESOURCES:
1SC_CLIENT_ASSIGNED_RESOURCES:
1SELECT COALESCE(MINUTE_PER_DAY, 480), LEVEL_STATE INTO h_per_day, h_level_sta+
1te:n         FROM TMT_WBS WHERE ELEMENT_ID = id:
1231:
1           EXCEPTION:: SP_S_PROFILE(232) :: cplan.sql(12526) :: :
1238:
1        RETURN_ERROR:: SP_S_PROFILE(239) :: cplan.sql(12533) :: :
1241:
1                EXIT:: SP_S_PROFILE(242) :: cplan.sql(12536) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_ASGNDRES_INFO:
1PMO_TMP_ASGNDRES_INFO:
1RESOURCE_ID:
1PARENT_ID:
1RATE_ID:
1PROFICIENCY_LEVEL_ID:
1PREFERENCE_LEVEL_ID:
1EXPERIENCE_ID:
1LAST_USED_DATETIME:
1R:
1RESOURCE_ASSIGNMENTS:
1JOIN:
1TMT_COMPETENCIES:
1RESOURCE_TYPE:
1INSERT INTO PMO_TMP_ASGNDRES_INFO:n         (:n         RESOURCE_ID,:n       +
1  PARENT_ID,:n         RATE_ID,:n         PROFICIENCY_LEVEL_ID,:n         PRE+
1FERENCE_LEVEL_ID,:n         EXPERIENCE_ID,:n         LAST_USED_DATETIME:n    +
1     ):n         SELECT DISTINCT:n         a.RESOURCE_ID,:n         r.PARENT_+
1ID,:n         r.RATE_ID,:n         r.PROFICIENCY_LEVEL_ID,:n         r.PREFER+
1ENCE_LEVEL_ID,:n         r.EXPERIENCE_ID,:n         r.LAST_USED_DATETIME:n   +
1      FROM RESOURCE_ASSIGNMENTS a JOIN TMT_COMPETENCIES r ON a.RESOURCE_ID=r.+
1RESOURCE_ID:n         WHERE PROJECT_ID = h_id AND RESOURCE_TYPE = '0':
1FOUND:
1100:
1285:
1           EXCEPTION:: SP_S_PROFILE(286) :: cplan.sql(12580) :: :
1DELETE FROM PMO_TMP_PROF_INFO:
1PMO_TMP_PROF_INFO:
1PROFILE_ID:
1INSERT INTO PMO_TMP_PROF_INFO (PROFILE_ID):n         SELECT DISTINCT RESOURCE+
1_ID:n         FROM RESOURCE_ASSIGNMENTS:n         WHERE PROJECT_ID = h_id AND+
1 RESOURCE_TYPE = '1':
1309:
1           EXCEPTION:: SP_S_PROFILE(310) :: cplan.sql(12604) :: :
1OPEN:
1TA:
1RES:
1RES_TYPE:
1P:
1FULL_NAME:
1ELEMENT_NAME:
1STATUS1_ID:
1E_MAIL_ADDRESS:
1D:
1ROLE_NAME:
1LAST_USED:
1RC:
1REGULAR_COST:
1REGULAR_SALE:
1SPECIAL_COST:
1SPECIAL_SALE:
1OBJECTIVES:
1RESOURCES:
1C:
1LEFT:
1OUTER:
1RATES:
1PRF:
1PROFILE_NAME:
1PROFILES:
1ROLE_ID:
1RESOURCE_ASSIGN_SKILLS:
1S:
1RES_ASSIGNMENT_ID:
1SKILL_ID:
1RESOURCE_ASSIGN_ROLES:
1SELECT CASE WHEN EXISTS(SELECT * FROM TASK_ASSIGNMENTS ta WHERE ta.PROJECT_ID+
1=h_id AND ta.RESOURCE_ID = RES.RESOURCE_ID) THEN 13 ELSE 185 END AS RES_TYPE,+
1:n      RES.RESOURCE_ID, p.FULL_NAME AS ELEMENT_NAME, p.STATUS1_ID, p.E_MAIL_+
1ADDRESS, d.TYPE_ID, d.ELEMENT_NAME AS ROLE_NAME,:n      RES.PROFICIENCY_LEVEL+
1_ID, RES.PREFERENCE_LEVEL_ID, RES.EXPERIENCE_ID, RES.LAST_USED_DATETIME AS LA+
1ST_USED,rc.REGULAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE, '' A+
1S OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_ASGNDRES_INFO RES JOIN RESOURCES +
1p ON RES.RESOURCE_ID=p.RESOURCE_ID:n      JOIN TMT_COMPETENCIES c ON c.ELEMEN+
1T_ID=RES.PARENT_ID:n      JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID+
1:n      LEFT OUTER JOIN RATES rc ON rc.RATE_ID=RES.RATE_ID:n      :n      UNI+
1ON ALL:n      :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID AS RESOURCE_ID, p.+
1PROFILE_NAME AS ELEMENT_NAME, 0 AS STATUS1_ID, '' AS E_MAIL_ADDRESS,:n      c+
1.TYPE_ID, c.ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_LEVEL_ID, r.PREFE+
1RENCE_LEVEL_ID,r.EXPERIENCE_ID,r.LAST_USED_DATETIME AS LAST_USED,:n      rc.R+
1EGULAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE,'' AS OBJECTIVES,+
1'' AS RANK:n      FROM PMO_TMP_PROF_INFO PRF  JOIN PROFILES p ON PRF.PROFILE_+
1ID=p.PROFILE_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES r ON p.ROLE_ID=r.ELEM+
1ENT_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.PARENT_ID+
1:n      LEFT OUTER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID:n      :n      UNION+
1 ALL:n      :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID AS RESOURCE_ID,p.PRO+
1FILE_NAME AS ELEMENT_NAME,0 AS STATUS1_ID,'' AS E_MAIL_ADDRESS,:n      c.TYPE+
1_ID, c.ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_LEVEL_ID, r.PREFERENCE+
1_LEVEL_ID, r.EXPERIENCE_ID, r.LAST_USED_DATETIME AS LAST_USED,:n      rc.REGU+
1LAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE, '' AS OBJECTIVES,''+
1 AS RANK:n      FROM PMO_TMP_PROF_INFO PRF JOIN PROFILES p ON PRF.PROFILE_ID=+
1p.PROFILE_ID:n      JOIN RESOURCE_ASSIGN_SKILLS s ON p.PROFILE_ID=s.RES_ASSIG+
1NMENT_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES r ON s.SKILL_ID=r.ELEMENT_ID+
1:n      LEFT OUTER JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.PARENT_ID:n     +
1 LEFT OUTER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID:n      :n      UNION ALL:n +
1     :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID AS RESOURCE_ID,p.PROFILE_NA+
1ME AS ELEMENT_NAME,0 AS STATUS1_ID,'' AS E_MAIL_ADDRESS,:n      c.TYPE_ID, c.+
1ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_LEVEL_ID, r.PREFERENCE_LEVEL_+
1ID, r.EXPERIENCE_ID, r.LAST_USED_DATETIME AS LAST_USED,:n      rc.REGULAR_COS+
1T,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE, '' AS OBJECTIVES,'' AS RAN+
1K:n      FROM PMO_TMP_PROF_INFO PRF JOIN PROFILES p ON PRF.PROFILE_ID=p.PROFI+
1LE_ID:n      JOIN RESOURCE_ASSIGN_ROLES s ON p.PROFILE_ID=s.RES_ASSIGNMENT_ID+
1:n      LEFT OUTER JOIN TMT_COMPETENCIES r ON s.ROLE_ID=r.ELEMENT_ID:n      L+
1EFT OUTER JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.PARENT_ID:n      LEFT OUT+
1ER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID:n      ORDER BY RES_TYPE, RESOURCE_I+
1D, TYPE_ID:
1358:
1                EXIT:: SP_S_PROFILE(359) :: cplan.sql(12653) :: :
16:
1DELETE FROM PMO_TMP_RES_DATA:
1PMO_TMP_RES_DATA:
1RA:
1PROJECT_ASSIGNMENT_ID:
1T:
1TASK_ID:
1INSERT INTO PMO_TMP_RES_DATA (RESOURCE_ID, TYPE_ID):n         SELECT DISTINCT+
1:n         ra.RESOURCE_ID,:n         CASE WHEN ta.TSK_ASSIGNMENT_ID IS NuLL T+
1HEN 185 ELSE 13 END AS TYPE_ID:n         FROM RESOURCE_ASSIGNMENTS ra LEFT OU+
1TER JOIN TASK_ASSIGNMENTS ta ON ta.PROJECT_ID=h_id AND ra.RESOURCE_ID = ta.RE+
1SOURCE_ID:n         WHERE ra.PROJECT_ID=h_id AND ra.RESOURCE_TYPE='0' AND ta.+
1PROJECT_ASSIGNMENT_ID IS NuLL AND:n         NOT EXISTS(SELECT * FROM TASK_ASS+
1IGNMENTS t WHERE ra.RESOURCE_ID = t.RESOURCE_ID AND t.TASK_ID=h_id):
1384:
1           EXCEPTION:: SP_S_PROFILE(385) :: cplan.sql(12679) :: :
1FC_U_CREATETMPTABLE:
1PMO_TMP_CPLN01_TEMP:
1ELEMENT_TYPE:
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME):n         SELECT DIS+
1TINCT r.PROFILE_ID ,r.PROFILE_NAME:n         FROM RESOURCE_ASSIGNMENTS a JOIN+
1 PROFILES r ON a.RESOURCE_TYPE='1' AND r.PROFILE_ID=a.RESOURCE_ID :n         +
1JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.ROLE_ID:n         JOIN TMT_COMPETEN+
1CIES d ON d.ELEMENT_ID=c.PARENT_ID :n         JOIN TASK_ASSIGNMENTS t ON t.RE+
1S_ASSIGNMENT_ID=a.RES_ASSIGNMENT_ID AND t.PROJECT_ASSIGNMENT_ID IS NuLL:n    +
1     WHERE a.PROJECT_ID=h_id AND a.ELEMENT_TYPE>1:
1409:
1           EXCEPTION:: SP_S_PROFILE(410) :: cplan.sql(12704) :: :
1TO_TIMESTAMP:
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_EFFORT:
1START_DATE:
1FINISH_DATE:
1WORK:
1REMAINING:
1T_UNIT:
1BEST_START:
1BEST_FINISH:
1CALENDAR:
1PLANNED_WORK:
1PERIOD_AVAILABILITY:
1ASSIGN_STRING:
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME,a.TYPE_ID,p.E_MAIL_ADDRESS,:n      TO_TIMESTAMP('1899-12-31 00::00+
1::00') AS PLANNED_START, TO_TIMESTAMP('1899-12-31 00::00::00') AS PLANNED_FIN+
1ISH,0 AS PLANNED_EFFORT,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS STAR+
1T_DATE, TO_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DATE, 0 AS WORK, 0 AS+
1 REMAINING,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,'' AS BEST_START,'' AS BES+
1T_FINISH,:n      0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, +
1'' AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_RES_DATA+
1 a JOIN RESOURCES p ON a.RESOURCE_ID=p.RESOURCE_ID:n      :n      UNION ALL:n+
1      :n      SELECT ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, ELEMENT_NAME,41 AS T+
1YPE_ID,'' AS E_MAIL_ADDRESS,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS +
1PLANNED_START, TO_TIMESTAMP('1899-12-31 00::00::00') AS PLANNED_FINISH,0 AS P+
1LANNED_EFFORT,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS START_DATE, TO+
1_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DATE, 0 AS WORK, 0 AS REMAINING+
1,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,''  AS BEST+
1_FINISH,0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASS+
1IGN_STRING, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_CPLN01_TEMP:n    +
1  ORDER BY TYPE_ID:
1429:
1                EXIT:: SP_S_PROFILE(430) :: cplan.sql(12724) :: :
1PARTICIPANT:
1START_DT:
1FINISH_DT:
1WORK_LOCATION:
1SECURITY_ID:
1G:
1SECURITY_NAME:
1CRI_SECURITY_ID:
1G2:
1CRI_SECURITY_NAME:
1REGULAR_RATE:
1SPECIAL_RATE:
1FS_LABOR_CODE:
1REC_STATUS:
1TIMECODE2_ID:
1TC:
1TIMECODE2:
1C_EFFORT:
1C_UNIT:
1C_CONTOUR:
1CONTOUR_TYPE:
1C_OCCURRENCE:
1BILLABLE:
1ASSIGNMENT_DELAY:
1TMT_GLOBAL_SECURITY:
1TMT_TIMECODES:
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID,:n      a.PROFILE_ID, p.PROFILE_NAME +
1AS ELEMENT_NAME,41 AS TYPE_ID,a.RES_ASSIGNMENT_ID, a.PARTICIPANT, t.PLANNED_S+
1TART,t.PLANNED_FINISH,:n      t.PLANNED_WORK,t.START_DT,t.FINISH_DT,h_per_day+
1 AS MINUTE_PER_DAY, a.WORK_LOCATION, a.SECURITY_ID, g.ELEMENT_NAME AS SECURIT+
1Y_NAME,:n      COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, +
1g2.ELEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,t.SPECIAL+
1_COST,t.SPECIAL_RATE,'' AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,:n     +
1 t.PROJECT_ASSIGNMENT_ID,t.TIMECODE2_ID,TC.ELEMENT_NAME AS TIMECODE2, t.T_UNI+
1T, t.C_EFFORT, t.C_UNIT, t.C_CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, BILLABL+
1E,:n      t.ASSIGNMENT_DELAY:n      FROM RESOURCE_ASSIGNMENTS a LEFT OUTER JO+
1IN TASK_ASSIGNMENTS t ON t.TASK_ID = h_id AND a.RES_ASSIGNMENT_ID = t.RES_ASS+
1IGNMENT_ID:n      LEFT OUTER JOIN PROFILES p ON a.RESOURCE_ID = p.PROFILE_ID +
1LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_ID=g.ELEMENT_ID:n      LE+
1FT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALESCE(a.CRI_SECURITY_ID,a.SECURITY+
1_ID)=g2.ELEMENT_ID:n      LEFT OUTER JOIN TMT_TIMECODES TC ON TC.ELEMENT_ID= +
1t.TIMECODE2_ID:n      WHERE a.ELEMENT_ID = h_id AND a.RESOURCE_TYPE='1' ORDER+
1 BY ELEMENT_NAME:
1445:
1                EXIT:: SP_S_PROFILE(446) :: cplan.sql(12740) :: :
1ISTASK:
1COUNT:
1SELECT COUNT(*) INTO h_count FROM TASK_ASSIGNMENTS WHERE PROJECT_ID = h_proje+
1ct_id AND TASK_ID = h_id:
1459:
1           EXCEPTION:: SP_S_PROFILE(460) :: cplan.sql(12754) :: :
1DUAL:
1BIT_FLAG:
1SELECT COUNT('X') INTO h_count FROM DUAL WHERE EXISTS (:n               SELEC+
1T 'X' FROM TASK_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND TASK_ID = h_i+
1d AND BIT_FLAG = '0'):
1476:
1           EXCEPTION:: SP_S_PROFILE(477) :: cplan.sql(12771) :: :
1TIMESHEET_APPROVAL_STATUS:
1APV:
1TO_DATE:
1ACTUAL_START:
1WEEK_OF:
1SELECT COUNT('X') INTO h_count FROM DUAL WHERE EXISTS (:n                  SE+
1LECT 'X' FROM TASK_ASSIGNMENTS ta JOIN TIMESHEET_APPROVAL_STATUS apv:n       +
1           ON apv.ELEMENT_ID = ta.PROJECT_ID AND apv.RESOURCE_ID = ta.RESOURC+
1E_ID:n                  WHERE ta.PROJECT_ID = h_project_id AND ta.TASK_ID = h+
1_id AND:n                  (TO_DATE(SubStr(ta.ACTUAL_START, 1, 10)) - 7     )+
1 <= apv.WEEK_OF):
1494:
1           EXCEPTION:: SP_S_PROFILE(495) :: cplan.sql(12789) :: :
1SD:
1FD:
1SCHED_EFFORT:
1WORK_TODATE:
1UNITS_PERCENT:
1MILESTONE_PERCENT:
1TRUNC:
1TO_NUMBER:
1WORK_PERCENT:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1FORECAST_START:
1FORECAST_FINISH:
1ETC:
1ACTUAL_FINISH:
1ACTUAL:
1PROPOSED_START:
1PROPOSED_FINISH:
1PROPOSED_EFFORT:
1PROPOSED_WORK:
1BASELINE1_START:
1BASELINE1_FINISH:
1BASELINE1_EFFORT:
1BASELINE1_WORK:
1TIMECODE2_NAME:
1CAPITAL_EXPENSE:
1RATE_ADJUSTMENT:
1ASSIGN_COUNT:
1UNRESOLVED_DURATION:
1DURATION:
1LEVEL_START:
1LEVEL_FINISH:
1LEVEL_DURATION:
1LEVEL_EFFORT:
1PERCENT_DISCRETE:
1TOP_ID:
1LEVEL_AFFECTED_FLAG:
1LABOR_COST_CC_ID:
1LABOR_COST_CC_NAME:
1LABOR_REVENUE_CC_ID:
1LABOR_REVENUE_CC_NAME:
1DEFAULT_LABOR_FLAG:
1CONTRACT_ID:
1CONTRACT_NAME:
1UNRESOLVED_FINISH:
1SC_UFS:
1SC_FS:
1SC_SS:
1SC_FF:
1SC_SF:
1UNRESOLVED_START:
1SCHED_WORK:
1ASSIGN_UNITS:
1UNITS_MSP:
1EC:
1CC:
1CTR:
1TMT_CHARGECODES:
1TMT_CONTRACTS:
1SELECT t.ELEMENT_ID, a.RESOURCE_ID, t.ELEMENT_NAME, t.TYPE_ID, '' AS RES_ASSI+
1GNMENT_ID, a.PARTICIPANT, t.START_DT,t.FINISH_DT,:n         t.SD, t.FD, t.STA+
1RT_DT AS PLANNED_START, t.FINISH_DT AS PLANNED_FINISH,:n         t.SCHED_EFFO+
1RT + t.PLANNED_EFFORT AS PLANNED_WORK, t.SCHED_EFFORT + t.PLANNED_EFFORT - t.+
1WORK_TODATE AS REMAINING,:n         0 UNITS_PERCENT, t.MILESTONE_PERCENT,:n  +
1       CASE WHEN t.WORK_TODATE = 0 THEN 0 ELSE Trunc((TO_NUMBER(t.WORK_TODATE+
1)/TO_NUMBER(t.SCHED_EFFORT + t.PLANNED_EFFORT))*10000) END AS WORK_PERCENT,:n+
1         TO_TIMESTAMP('1899-12-31 00::00::00') AS BAK_START_DT,TO_TIMESTAMP('+
11899-12-31 00::00::00') AS BAK_FINISH_DT,0 AS BAK_WORK,:n         t.FORECAST_+
1START,t.FORECAST_FINISH,t.ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n         t.WO+
1RK_TODATE AS ACTUAL,t.PROPOSED_START, t.PROPOSED_FINISH, t.PROPOSED_EFFORT AS+
1 PROPOSED_WORK,:n         h_per_day AS MINUTE_PER_DAY, 0 AS WORK_LOCATION, ''+
1 AS SECURITY_ID, '' AS SECURITY_NAME,:n         '' AS CRI_SECURITY_ID, '' AS +
1CRI_SECURITY_NAME, 0.00 AS REGULAR_COST,0.00 AS REGULAR_RATE,0.00 AS SPECIAL_+
1COST,0.00 AS SPECIAL_RATE,:n         '' AS FS_LABOR_CODE,t.REC_STATUS,'' AS A+
1SSIGN_STRING,t.BASELINE1_START,t.BASELINE1_FINISH,t.BASELINE1_EFFORT AS BASEL+
1INE1_WORK,:n         '' AS PROJECT_ASSIGNMENT_ID,'' AS TIMECODE2_ID, '' AS TI+
1MECODE2_NAME, 0 AS T_UNIT, 0 AS C_EFFORT, 0 AS C_UNIT, 0 AS C_CONTOUR, 0 AS C+
1ONTOUR_TYPE, 0 AS C_OCCURRENCE, 0 AS BILLABLE, 0 AS CAPITAL_EXPENSE,:n       +
1  0 AS ASSIGNMENT_DELAY, h_bit_flag AS BIT_FLAG, 0 AS RATE_ADJUSTMENT, t.ASSI+
1GN_COUNT, t.UNRESOLVED_DURATION AS DURATION,:n         CASE WHEN h_level_stat+
1e = 1 THEN t.LEVEL_START ELSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LE+
1VEL_START,:n         CASE WHEN h_level_state = 1 THEN t.LEVEL_FINISH ELSE TO_+
1TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_FINISH,:n         CASE WHEN h+
1_level_state = 1 THEN t.LEVEL_DURATION ELSE 0 END AS LEVEL_EFFORT, t.WORK_PER+
1CENT AS PERCENT_DISCRETE, 0 as TOP_ID, '0' AS LEVEL_AFFECTED_FLAG,:n         +
1'' AS LABOR_COST_CC_ID, '' AS LABOR_COST_CC_NAME, '' AS LABOR_REVENUE_CC_ID, +
1'' AS LABOR_REVENUE_CC_NAME, 'N' AS DEFAULT_LABOR_FLAG,:n         '' AS CONTR+
1ACT_ID, '' AS CONTRACT_NAME:n         FROM TMT_WBS t LEFT JOIN RESOURCE_ASSIG+
1NMENTS a ON a.ELEMENT_ID = t.ELEMENT_ID AND a.RESOURCE_ID = h_rec_user:n     +
1    LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_ID=g.ELEMENT_ID:n    +
1     WHERE t.PROJECT_ID = h_project_id AND t.ELEMENT_ID = h_id:n         UNIO+
1N ALL:n         SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_A+
1SSIGNMENT_ID ELSE a.RES_ASSIGNMENT_ID END AS ELEMENT_ID, a.RESOURCE_ID,:n    +
1     CASE WHEN a.RESOURCE_TYPE='1' THEN (SELECT p.PROFILE_NAME FROM PROFILES +
1p WHERE a.RESOURCE_ID = p.PROFILE_ID):n         ELSE (SELECT r.FULL_NAME FROM+
1 RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID) END AS ELEMENT_NAME,:n     +
1    CASE WHEN t.TSK_ASSIGNMENT_ID IS NuLL THEN 185 WHEN a.RESOURCE_TYPE='1' T+
1HEN 41 ELSE 13 END AS TYPE_ID,:n         a.RES_ASSIGNMENT_ID, a.PARTICIPANT, +
1t.START_DT, t.UNRESOLVED_FINISH AS FINISH_DT,:n         CASE WHEN t.SD = PMO_+
1CNST.SC_UFS OR t.SD = PMO_CNST.SC_FS THEN PMO_CNST.SC_SS ELSE t.SD END AS SD,+
1 CASE WHEN t.FD = PMO_CNST.SC_FF THEN PMO_CNST.SC_SF ELSE t.FD END AS FD, t.U+
1NRESOLVED_START AS PLANNED_START, t.UNRESOLVED_FINISH AS PLANNED_FINISH,:n   +
1      CASE WHEN BIT_FLAG = '2' THEN SCHED_WORK ELSE PLANNED_WORK END AS PLANN+
1ED_WORK,:n         CASE WHEN BIT_FLAG = '2' THEN SCHED_WORK - WORK_TODATE ELS+
1E PLANNED_WORK END AS REMAINING,:n         CASE WHEN t.ASSIGN_UNITS > t.UNITS+
1_MSP THEN t.ASSIGN_UNITS ELSE t.UNITS_MSP END AS UNITS_PERCENT,:n         0 A+
1S MILESTONE_PERCENT,:n         CASE WHEN t.WORK_TODATE = 0 THEN 0 ELSE Trunc(+
1(TO_NUMBER(t.WORK_TODATE)/TO_NUMBER(PLANNED_WORK+SCHED_WORK))*10000) END AS W+
1ORK_PERCENT,:n         t.BAK_START_DT,t.BAK_FINISH_DT,t.BAK_WORK,:n         t+
1.FORECAST_START,t.FORECAST_FINISH,t.ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n   +
1      t.WORK_TODATE AS ACTUAL,PROPOSED_START, PROPOSED_FINISH, PROPOSED_WORK,+
1:n         h_per_day AS MINUTE_PER_DAY, a.WORK_LOCATION, a.SECURITY_ID, g.ELE+
1MENT_NAME AS SECURITY_NAME,:n         COALESCE(a.CRI_SECURITY_ID,a.SECURITY_I+
1D) AS CRI_SECURITY_ID, g2.ELEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t+
1.REGULAR_RATE,t.SPECIAL_COST,t.SPECIAL_RATE,:n         CASE WHEN a.RESOURCE_T+
1YPE='0' THEN (SELECT r.FS_LABOR_CODE FROM RESOURCES r WHERE a.RESOURCE_ID = r+
1.RESOURCE_ID):n         ELSE '' END AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_ST+
1RING,t.BASELINE1_START,t.BASELINE1_FINISH,t.BASELINE1_WORK,:n         t.PROJE+
1CT_ASSIGNMENT_ID,t.TIMECODE2_ID, TC.ELEMENT_NAME AS TIMECODE2_NAME, t.T_UNIT,+
1 t.C_EFFORT, t.C_UNIT, t.C_CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, t.BILLABL+
1E, t.CAPITAL_EXPENSE,:n         t.ASSIGNMENT_DELAY, CASE WHEN t.BIT_FLAG IS N+
1uLL THEN '' WHEN t.BIT_FLAG = '0' THEN '1' ELSE '2' END AS BIT_FLAG, t.RATE_A+
1DJUSTMENT, 0 AS ASSIGN_COUNT, t.UNRESOLVED_DURATION AS DURATION,:n         CA+
1SE WHEN h_level_state = 1 THEN COALESCE(t.LEVEL_START,t.UNRESOLVED_START) ELS+
1E TO_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_START,:n         CASE WH+
1EN h_level_state = 1 THEN COALESCE(t.LEVEL_FINISH,t.UNRESOLVED_FINISH) ELSE T+
1O_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_FINISH,:n         CASE WHEN+
1 h_level_state = 1 THEN CASE WHEN t.LEVEL_EFFORT = 0 THEN t.ETC ELSE t.LEVEL_+
1EFFORT END ELSE 0 END AS LEVEL_EFFORT, t.MILESTONE_PERCENT AS PERCENT_DISCRET+
1E, 1 as TOP_ID, '0' AS LEVEL_AFFECTED_FLAG,:n         T.LABOR_COST_CC_ID,:n  +
1       EC.ELEMENT_NAME AS LABOR_COST_CC_NAME,:n         T.LABOR_REVENUE_CC_ID+
1,:n         CC.ELEMENT_NAME AS LABOR_REVENUE_CC_NAME, T.DEFAULT_LABOR_FLAG,:n+
1         T.CONTRACT_ID, CTR.ELEMENT_NAME AS CONTRACT_NAME:n         FROM RESO+
1URCE_ASSIGNMENTS a LEFT OUTER JOIN TASK_ASSIGNMENTS t ON a.RES_ASSIGNMENT_ID +
1= t.RES_ASSIGNMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SE+
1CURITY_ID=g.ELEMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON CO+
1ALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n         LEFT OUTER JO+
1IN TMT_TIMECODES TC ON TC.ELEMENT_ID= t.TIMECODE2_ID:n         LEFT OUTER JOI+
1N TMT_CHARGECODES EC ON EC.ELEMENT_ID = T.LABOR_COST_CC_ID:n         LEFT OUT+
1ER JOIN TMT_CHARGECODES CC ON CC.ELEMENT_ID = T.LABOR_REVENUE_CC_ID:n        +
1 LEFT OUTER JOIN TMT_CONTRACTS CTR ON CTR.ELEMENT_ID = T.CONTRACT_ID:n       +
1  WHERE a.PROJECT_ID = h_project_id AND a.ELEMENT_ID = h_id AND a.REC_STATUS +
1NOT IN ('L','D'):n         ORDER BY TOP_ID, ELEMENT_NAME:
1573:
1                EXIT:: SP_S_PROFILE(574) :: cplan.sql(12868) :: :
1BEST:
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID,a.RESOURCE_ID,:n         CASE WHEN a.+
1RESOURCE_TYPE='1' THEN (SELECT p.PROFILE_NAME FROM PROFILES p WHERE a.RESOURC+
1E_ID = p.PROFILE_ID):n         ELSE (SELECT r.FULL_NAME FROM RESOURCES r WHER+
1E a.RESOURCE_ID = r.RESOURCE_ID) END AS ELEMENT_NAME,:n         CASE WHEN t.T+
1SK_ASSIGNMENT_ID IS NuLL THEN 185 WHEN a.RESOURCE_TYPE='1' THEN 41 ELSE 13 EN+
1D AS TYPE_ID,:n         a.RES_ASSIGNMENT_ID, a.PARTICIPANT, t.START_DT,t.FINI+
1SH_DT,:n         t.SD, t.FD, t.UNRESOLVED_START AS PLANNED_START, t.UNRESOLVE+
1D_FINISH AS PLANNED_FINISH,:n         BEST AS PLANNED_WORK, CASE WHEN BIT_FLA+
1G = '2' THEN SCHED_WORK ELSE PLANNED_WORK END AS REMAINING,:n         t.UNITS+
1_MSP AS UNITS_PERCENT, t.MILESTONE_PERCENT, 0 AS WORK_PERCENT,:n         t.BA+
1K_START_DT,t.BAK_FINISH_DT,t.BAK_WORK,:n         t.FORECAST_START,t.FORECAST_+
1FINISH,t.ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n         t.WORK_TODATE AS ACTU+
1AL,PROPOSED_START, PROPOSED_FINISH, PROPOSED_WORK,:n         h_per_day AS MIN+
1UTE_PER_DAY, a.WORK_LOCATION, a.SECURITY_ID, g.ELEMENT_NAME AS SECURITY_NAME,+
1:n         COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, g2.E+
1LEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,t.SPECIAL_COS+
1T,t.SPECIAL_RATE,:n         CASE WHEN a.RESOURCE_TYPE='0' THEN (SELECT r.FS_L+
1ABOR_CODE FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n         ELS+
1E '' END AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,t.BASELINE1_START,t.BA+
1SELINE1_FINISH,t.BASELINE1_WORK,:n         t.PROJECT_ASSIGNMENT_ID,t.TIMECODE+
12_ID, TC.ELEMENT_NAME AS TIMECODE2_NAME, t.T_UNIT, t.C_EFFORT, t.C_UNIT, t.C_+
1CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, t.BILLABLE, t.CAPITAL_EXPENSE,:n    +
1     t.ASSIGNMENT_DELAY, CASE WHEN t.BIT_FLAG IS NuLL THEN '' WHEN t.BIT_FLAG+
1 = '0' THEN '1' ELSE '2' END AS BIT_FLAG, t.RATE_ADJUSTMENT, 0 AS ASSIGN_COUN+
1T, 0 AS DURATION,:n         t.LEVEL_START, t.LEVEL_FINISH, t.LEVEL_EFFORT, t.+
1MILESTONE_PERCENT AS PERCENT_DISCRETE, 0 as TOP_ID,:n         CASE WHEN t.TSK+
1_ASSIGNMENT_ID IS NOT NuLL AND t.PROJECT_ASSIGNMENT_ID = t.TSK_ASSIGNMENT_ID +
1AND (t.LEVEL_START <> t.UNRESOLVED_START OR t.LEVEL_FINISH <> t.UNRESOLVED_FI+
1NISH) THEN '1' ELSE '0' END AS LEVEL_AFFECTED_FLAG,:n         T.LABOR_COST_CC+
1_ID,:n         EC.ELEMENT_NAME AS LABOR_COST_CC_NAME,:n         T.LABOR_REVEN+
1UE_CC_ID,:n         CC.ELEMENT_NAME AS LABOR_REVENUE_CC_NAME, T.DEFAULT_LABOR+
1_FLAG,:n         T.CONTRACT_ID, CTR.ELEMENT_NAME AS CONTRACT_NAME:n         F+
1ROM RESOURCE_ASSIGNMENTS a LEFT OUTER JOIN TASK_ASSIGNMENTS t ON a.RES_ASSIGN+
1MENT_ID = t.RES_ASSIGNMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY g+
1 ON a.SECURITY_ID=g.ELEMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY +
1g2 ON COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n         LEFT +
1OUTER JOIN TMT_TIMECODES TC ON TC.ELEMENT_ID= t.TIMECODE2_ID:n         LEFT O+
1UTER JOIN TMT_CHARGECODES EC ON EC.ELEMENT_ID = T.LABOR_COST_CC_ID:n         +
1LEFT OUTER JOIN TMT_CHARGECODES CC ON CC.ELEMENT_ID = T.LABOR_REVENUE_CC_ID:n+
1         LEFT OUTER JOIN TMT_CONTRACTS CTR ON CTR.ELEMENT_ID = T.CONTRACT_ID+
1:n         WHERE a.REC_STATUS NOT IN ('L','D') AND a.ELEMENT_ID = h_id:n     +
1    ORDER BY TYPE_ID, ELEMENT_NAME:
1613:
1                EXIT:: SP_S_PROFILE(614) :: cplan.sql(12908) :: :
14:
1DELETE FROM PMO_TMP_RES_SET:
1PMO_TMP_RES_SET:
1MIN:
1MAX:
1SUM:
1SCHED_START:
1SCHED_FINISH:
1INSERT INTO PMO_TMP_RES_SET:n         (:n         RESOURCE_ID,:n         RESO+
1URCE_TYPE ,:n         PLANNED_START ,:n         PLANNED_FINISH ,:n         PL+
1ANNED_EFFORT ,:n         START_DATE ,:n         FINISH_DATE ,:n         WORK +
1,:n         REMAINING:n         ):n         SELECT:n         RESOURCE_ID,:n  +
1       RESOURCE_TYPE,:n         MIN(PLANNED_START) AS PLANNED_START,:n       +
1  MAX(PLANNED_FINISH) AS PLANNED_FINISH,:n         SUM(PLANNED_WORK) AS PLANN+
1ED_EFFORT,:n         MIN(SCHED_START) AS START_DATE,:n         MAX(SCHED_FINI+
1SH) AS FINISH_DATE,:n         SUM(SCHED_WORK) AS WORK,:n         SUM(ETC) AS +
1REMAINING:n         FROM TASK_ASSIGNMENTS WHERE PROJECT_ID=h_id AND PROJECT_A+
1SSIGNMENT_ID IS NuLL GROUP BY RESOURCE_ID, RESOURCE_TYPE:
1656:
1           EXCEPTION:: SP_S_PROFILE(657) :: cplan.sql(12951) :: :
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME, PLANNED_START, PLANN+
1ED_FINISH, PLANNED_EFFORT,START_DATE, FINISH_DATE,:n         WORK, REMAINING)+
1:n         SELECT DISTINCT r.PROFILE_ID,r.PROFILE_NAME,:n         a.PLANNED_S+
1TART, a.PLANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK,+
1 a.REMAINING:n         FROM PMO_TMP_RES_SET a JOIN PROFILES r ON a.RESOURCE_T+
1YPE='1' AND r.PROFILE_ID=a.RESOURCE_ID JOIN TMT_COMPETENCIES c ON c.ELEMENT_I+
1D=r.ROLE_ID:n         JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID:
1680:
1           EXCEPTION:: SP_S_PROFILE(681) :: cplan.sql(12975) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME,13 AS TYPE_ID,p.E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED_+
1FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 A+
1S T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,'' AS BEST_FINI+
1SH, 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_+
1STRING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_RES_S+
1ET a JOIN RESOURCES p ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_I+
1D:n      :n      UNION ALL:n      :n      SELECT ELEMENT_ID,'' AS RES_ASSIGNM+
1ENT_ID, ELEMENT_NAME,41 AS TYPE_ID,'' AS E_MAIL_ADDRESS,:n      PLANNED_START+
1, PLANNED_FINISH,PLANNED_EFFORT,   START_DATE, FINISH_DATE, WORK, REMAINING,0+
1 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,''  AS BEST_F+
1INISH,0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIG+
1N_STRING,'' AS FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP+
1_CPLN01_TEMP ORDER BY TYPE_ID:
1697:
1                EXIT:: SP_S_PROFILE(698) :: cplan.sql(12992) :: :
15:
1739:
1           EXCEPTION:: SP_S_PROFILE(740) :: cplan.sql(13034) :: :
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME, RESOURCE_TYPE, TYPE_+
1ID, E_MAIL_ADDRESS, PLANNED_START, PLANNED_FINISH, PLANNED_EFFORT,START_DATE,+
1 FINISH_DATE,:n         WORK, REMAINING, FS_LABOR_CODE):n         SELECT DIST+
1INCT r.PROFILE_ID ,r.PROFILE_NAME ,'1',41 ,'',:n         a.PLANNED_START, a.P+
1LANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAIN+
1ING,:n         '':n         FROM PMO_TMP_RES_SET a JOIN PROFILES r ON a.RESOU+
1RCE_TYPE='1' AND r.PROFILE_ID=a.RESOURCE_ID JOIN TMT_COMPETENCIES c ON c.ELEM+
1ENT_ID=r.ROLE_ID:n         JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_I+
1D:n         UNION ALL:n         SELECT DISTINCT ra.RESOURCE_ID ,p.FULL_NAME ,+
1'0',185 ,p.E_MAIL_ADDRESS,:n         TO_TIMESTAMP('1899-12-31 00::00::00') , +
1TO_TIMESTAMP('1899-12-31 00::00::00') ,0 ,:n         TO_TIMESTAMP('1899-12-31+
1 00::00::00') , TO_TIMESTAMP('1899-12-31 00::00::00') , 0 , 0 ,p.FS_LABOR_COD+
1E:n         FROM RESOURCE_ASSIGNMENTS ra, RESOURCES p:n         WHERE ra.PROJ+
1ECT_ID=h_id AND ra.RESOURCE_ID = p.RESOURCE_ID:n         AND NOT EXISTS(SELEC+
1T ta.TSK_ASSIGNMENT_ID FROM TASK_ASSIGNMENTS ta:n         WHERE ta.RES_ASSIGN+
1MENT_ID IN (SELECT a.RES_ASSIGNMENT_ID:n         FROM RESOURCE_ASSIGNMENTS a +
1WHERE a.PROJECT_ID = ra.PROJECT_ID AND a.RESOURCE_ID = ra.RESOURCE_ID)):
1773:
1           EXCEPTION:: SP_S_PROFILE(774) :: cplan.sql(13068) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME,13 AS TYPE_ID,p.E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED_+
1FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 A+
1S T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,'' AS BEST_FINI+
1SH, 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_+
1STRING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_RES_S+
1ET a JOIN RESOURCES p ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_I+
1D:n      UNION ALL:n      SELECT ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, ELEMENT_+
1NAME,TYPE_ID,E_MAIL_ADDRESS,:n      PLANNED_START, PLANNED_FINISH,PLANNED_EFF+
1ORT,   START_DATE, FINISH_DATE, WORK, REMAINING,0 AS T_UNIT,h_per_day AS MINU+
1TE_PER_DAY,:n      '' AS BEST_START,''  AS BEST_FINISH,0 AS CALENDAR, 0 AS PL+
1ANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_STRING, FS_LABOR_CODE, '' +
1AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_CPLN01_TEMP WHERE RESOURCE_TYPE=+
1'1' AND TYPE_ID = 41:n      UNION ALL:n      SELECT ELEMENT_ID,'' AS RES_ASSI+
1GNMENT_ID, ELEMENT_NAME,TYPE_ID,E_MAIL_ADDRESS,:n      PLANNED_START, PLANNED+
1_FINISH,PLANNED_EFFORT,:n      START_DATE, FINISH_DATE, WORK, REMAINING,0 AS +
1T_UNIT,h_per_day AS MINUTE_PER_DAY,'' AS BEST_START,'' AS BEST_FINISH,:n     +
1 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_STR+
1ING,FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_CPLN01_TEM+
1P:n      WHERE RESOURCE_TYPE = '0' AND TYPE_ID = 185:n      ORDER BY TYPE_ID +
1DESC, ELEMENT_NAME:
1796:
1                EXIT:: SP_S_PROFILE(797) :: cplan.sql(13091) :: :
17:
1PLANNED_REMAINING:
1PA:
1DESCRIPTION:
1LEVEL_PLANNED_START:
1LEVEL_PLANNED_FINISH:
1LEVEL_SCHED_START:
1LEVEL_SCHED_FINISH:
1ESTIMATED_BASELINE1_START:
1ESTIMATED_BASELINE1_FINISH:
1ESTIMATED_BASELINE1_EFFORT:
1ESTIMATED_BASELINE3_START:
1ESTIMATED_BASELINE3_FINISH:
1ESTIMATED_BASELINE3_EFFORT:
1PROJECT_ASSIGNMENTS:
1SELECT t.RESOURCE_ID AS ELEMENT_ID, t.RES_ASSIGNMENT_ID, p.FULL_NAME AS ELEME+
1NT_NAME, 13 AS TYPE_ID,p.E_MAIL_ADDRESS,:n      b.PLANNED_START, b.PLANNED_FI+
1NISH, b.BEST AS PLANNED_EFFORT, b.PLANNED_WORK AS PLANNED_REMAINING, a.BAK_ST+
1ART_DT AS START_DATE, a.BAK_FINISH_DT AS FINISH_DATE,:n      a.BEST AS WORK, +
1a.SCHED_WORK AS REMAINING, h_per_day AS MINUTE_PER_DAY,'' AS BEST_START, '' A+
1S BEST_FINISH,:n      0 AS CALENDAR,0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILI+
1TY, '' AS ASSIGN_STRING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      +
1pa.REGULAR_COST, pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE, pa.DESCRI+
1PTION,:n      pa.LEVEL_PLANNED_START, pa.LEVEL_PLANNED_FINISH, pa.LEVEL_SCHED+
1_START, pa.LEVEL_SCHED_FINISH,:n      pa.ESTIMATED_BASELINE1_START, pa.ESTIMA+
1TED_BASELINE1_FINISH, pa.ESTIMATED_BASELINE1_EFFORT,:n      pa.ESTIMATED_BASE+
1LINE3_START, pa.ESTIMATED_BASELINE3_FINISH, pa.ESTIMATED_BASELINE3_EFFORT:n  +
1    FROM RESOURCE_ASSIGNMENTS t JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID +
1= h_id AND pa.RESOURCE_ID = t.RESOURCE_ID:n      LEFT JOIN TASK_ASSIGNMENTS a+
1 ON a.RES_ASSIGNMENT_ID=t.RES_ASSIGNMENT_ID AND a.BIT_FLAG='2':n      LEFT JO+
1IN TASK_ASSIGNMENTS b ON b.RES_ASSIGNMENT_ID=t.RES_ASSIGNMENT_ID AND b.BIT_FL+
1AG='0':n      JOIN RESOURCES p ON t.RESOURCE_ID=p.RESOURCE_ID:n      WHERE t.+
1ELEMENT_ID=h_id AND t.RESOURCE_TYPE='0' AND (a.TSK_ASSIGNMENT_ID IS NOT NuLL +
1OR b.TSK_ASSIGNMENT_ID IS NOT NuLL):n      UNION ALL:n      SELECT t.RESOURCE+
1_ID AS ELEMENT_ID, a.RES_ASSIGNMENT_ID, p.PROFILE_NAME AS ELEMENT_NAME, 41 AS+
1 TYPE_ID,'' AS E_MAIL_ADDRESS,:n      t.PLANNED_START, t.PLANNED_FINISH,t.BES+
1T AS PLANNED_EFFORT,t.PLANNED_WORK AS PLANNED_REMAINING,TO_TIMESTAMP('1899-12+
1-31 00::00::00') AS START_DATE, TO_TIMESTAMP('1899-12-31 00::00::00') AS FINI+
1SH_DATE,:n      0 AS WORK,0 AS REMAINING,h_per_day AS MINUTE_PER_DAY,'' AS BE+
1ST_START, '' AS BEST_FINISH,:n      0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PE+
1RIOD_AVAILABILITY, t.ASSIGN_STRING,'' AS FS_LABOR_CODE, '' AS OBJECTIVES,'' A+
1S RANK,:n      pa.REGULAR_COST, pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_+
1RATE, pa.DESCRIPTION,:n      pa.LEVEL_PLANNED_START, pa.LEVEL_PLANNED_FINISH,+
1 pa.LEVEL_SCHED_START, pa.LEVEL_SCHED_FINISH,:n      pa.ESTIMATED_BASELINE1_S+
1TART, pa.ESTIMATED_BASELINE1_FINISH, pa.ESTIMATED_BASELINE1_EFFORT,:n      pa+
1.ESTIMATED_BASELINE3_START, pa.ESTIMATED_BASELINE3_FINISH, pa.ESTIMATED_BASEL+
1INE3_EFFORT:n      FROM RESOURCE_ASSIGNMENTS a JOIN PROFILES p ON a.RESOURCE_+
1ID=p.PROFILE_ID:n      JOIN TASK_ASSIGNMENTS t ON t.RES_ASSIGNMENT_ID=a.RES_A+
1SSIGNMENT_ID:n      JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID = h_id AND p+
1a.RESOURCE_ID = a.RESOURCE_ID:n      WHERE a.ELEMENT_ID=h_id AND a.RESOURCE_T+
1YPE='1':n      ORDER BY TYPE_ID DESC, ELEMENT_NAME:
1894:
1                EXIT:: SP_S_PROFILE(895) :: cplan.sql(13189) :: :
18:
1DELETE FROM PMO_TMP_PRJ_INFO:
1PMO_TMP_PRJ_INFO:
1PRJ_PLANNED_START:
1PRJ_PLANNED_FINISH:
1PRJ_SCHED_START:
1PRJ_SCHED_FINISH:
1SCHED_REMAINING:
1INSERT INTO PMO_TMP_PRJ_INFO:n         (RESOURCE_ID,:n         RESOURCE_TYPE,+
1:n         PRJ_PLANNED_START,:n         PRJ_PLANNED_FINISH,:n         PLANNED+
1_REMAINING,:n         PLANNED_EFFORT,:n         PRJ_SCHED_START ,:n         P+
1RJ_SCHED_FINISH,:n         SCHED_REMAINING,:n         WORK,:n         TYPE_ID+
1:n         ):n         SELECT:n         RESOURCE_ID,:n         RESOURCE_TYPE,+
1:n         MIN(PLANNED_START)  AS PRJ_PLANNED_START,:n         MAX(PLANNED_FI+
1NISH) AS PRJ_PLANNED_FINISH,:n         SUM(PLANNED_WORK)   AS PLANNED_REMAINI+
1NG,:n         SUM(CASE WHEN BIT_FLAG='0' THEN BEST ELSE 0 END) AS PLANNED_EFF+
1ORT,:n         MIN(SCHED_START)    AS PRJ_SCHED_START,:n         MAX(SCHED_FI+
1NISH)   AS PRJ_SCHED_FINISH,:n         SUM(SCHED_WORK)     AS SCHED_REMAINING+
1,:n         SUM(CASE WHEN BIT_FLAG='2' THEN BEST ELSE 0 END) AS WORK, 13:n   +
1      FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_ID=h_id AND TASK_ID=h_id+
1:n         GROUP BY RESOURCE_ID, RESOURCE_TYPE:
1940:
1           EXCEPTION:: SP_S_PROFILE(941) :: cplan.sql(13235) :: :
1DELETE FROM PMO_TMP_RES_INFO:
1PMO_TMP_RES_INFO:
1INSERT INTO PMO_TMP_RES_INFO:n         (:n         RESOURCE_ID,:n         RES+
1OURCE_TYPE,:n         PLANNED_START,:n         PLANNED_FINISH,:n         PLAN+
1NED_EFFORT,:n         START_DATE,:n         FINISH_DATE,:n         WORK,:n   +
1      REMAINING,:n         PRJ_PLANNED_START,:n         PRJ_PLANNED_FINISH,:n+
1         PLANNED_REMAINING,:n         PRJ_SCHED_START,:n         PRJ_SCHED_FI+
1NISH,:n         SCHED_REMAINING,:n         LEVEL_PLANNED_START,:n         LEV+
1EL_PLANNED_FINISH,:n         LEVEL_SCHED_START,:n         LEVEL_SCHED_FINISH,+
1:n         ESTIMATED_BASELINE1_START,:n         ESTIMATED_BASELINE1_FINISH,:n+
1         ESTIMATED_BASELINE1_EFFORT,:n         ESTIMATED_BASELINE3_START,:n  +
1       ESTIMATED_BASELINE3_FINISH,:n         ESTIMATED_BASELINE3_EFFORT,:n   +
1      REGULAR_COST,:n         REGULAR_RATE,:n         SPECIAL_COST,:n        +
1 SPECIAL_RATE,:n         TYPE_ID,:n         DESCRIPTION:n         ):n        +
1 SELECT:n         a.RESOURCE_ID,      a.RESOURCE_TYPE,        a.PLANNED_START+
1,        a.PLANNED_FINISH,:n         a.PLANNED_WORK,     a.SCHED_START,      +
1    a.SCHED_FINISH,         a.SCHED_WORK,:n         a.ETC,              b.PRJ+
1_PLANNED_START,    b.PRJ_PLANNED_FINISH,   b.PLANNED_REMAINING,:n         b.P+
1RJ_SCHED_START,  b.PRJ_SCHED_FINISH,     b.SCHED_REMAINING,:n         a.LEVEL+
1_PLANNED_START, a.LEVEL_PLANNED_FINISH, a.LEVEL_SCHED_START, a.LEVEL_SCHED_FI+
1NISH,:n         a.ESTIMATED_BASELINE1_START, a.ESTIMATED_BASELINE1_FINISH, a.+
1ESTIMATED_BASELINE1_EFFORT,:n         a.ESTIMATED_BASELINE3_START, a.ESTIMATE+
1D_BASELINE3_FINISH, a.ESTIMATED_BASELINE3_EFFORT,:n         a.REGULAR_COST,  +
1   a.REGULAR_RATE,         a.SPECIAL_COST,         a.SPECIAL_RATE,:n         +
1COALESCE(b.TYPE_ID,CASE WHEN (a.PLANNED_WORK+a.SCHED_WORK) = 0 THEN 185 ELSE +
113 END), a.DESCRIPTION:n         FROM PROJECT_ASSIGNMENTS a LEFT OUTER JOIN P+
1MO_TMP_PRJ_INFO b ON a.RESOURCE_ID = b.RESOURCE_ID:n         WHERE a.PROJECT_+
1ID=h_id:
11007:
1           EXCEPTION:: SP_S_PROFILE(1008) :: cplan.sql(13302) :: :
1RI:
1UPDATE PMO_TMP_RES_INFO RI SET TYPE_ID = 13 WHERE TYPE_ID = 185 AND EXISTS(:n+
1         SELECT TASK_ID FROM TASK_ASSIGNMENTS T WHERE T.PROJECT_ID=h_id AND T+
1.RESOURCE_ID = RI.RESOURCE_ID AND T.RESOURCE_TYPE = '0'):
11026:
1           EXCEPTION:: SP_S_PROFILE(1027) :: cplan.sql(13321) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME, a.TYPE_ID,p.E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED_FIN+
1ISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 AS T+
1_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,'' AS BEST_FINISH,+
1 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_STR+
1ING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      CASE WHEN a.PRJ_PLAN+
1NED_START IS NOT NuLL OR a.PRJ_SCHED_START IS NOT NuLL THEN a.RESOURCE_ID ELS+
1E '' END AS PROJECT_ASSIGNMENT_ID, a.PRJ_PLANNED_START, a.PRJ_PLANNED_FINISH,+
1 a.PLANNED_REMAINING, a.PRJ_SCHED_START, a.PRJ_SCHED_FINISH, a.SCHED_REMAININ+
1G,:n      h_id AS PROJECT_ID,:n      a.LEVEL_PLANNED_START, a.LEVEL_PLANNED_F+
1INISH, a.LEVEL_SCHED_START, a.LEVEL_SCHED_FINISH,:n      a.ESTIMATED_BASELINE+
11_START, a.ESTIMATED_BASELINE1_FINISH, a.ESTIMATED_BASELINE1_EFFORT,:n      a+
1.ESTIMATED_BASELINE3_START, a.ESTIMATED_BASELINE3_FINISH, a.ESTIMATED_BASELIN+
1E3_EFFORT,:n      a.REGULAR_COST, a.REGULAR_RATE, a.SPECIAL_COST, a.SPECIAL_R+
1ATE, a.DESCRIPTION:n      FROM PMO_TMP_RES_INFO a JOIN RESOURCES p ON a.RESOU+
1RCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_ID:n      UNION ALL:n      SELECT+
1  r.PROFILE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, r.PROFILE_NAME AS ELEME+
1NT_NAME,41 AS TYPE_ID,'' AS E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED+
1_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 +
1AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,''  AS BEST_FI+
1NISH,0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN+
1_STRING,'' AS FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      CASE WHEN a.+
1PRJ_PLANNED_START IS NOT NuLL OR a.PRJ_SCHED_START IS NOT NuLL THEN a.RESOURC+
1E_ID ELSE '' END AS PROJECT_ASSIGNMENT_ID, a.PRJ_PLANNED_START, a.PRJ_PLANNED+
1_FINISH, a.PLANNED_REMAINING, a.PRJ_SCHED_START, a.PRJ_SCHED_FINISH, a.SCHED_+
1REMAINING,:n      h_id AS PROJECT_ID,:n      a.LEVEL_PLANNED_START, a.LEVEL_P+
1LANNED_FINISH, a.LEVEL_SCHED_START, a.LEVEL_SCHED_FINISH,:n      a.ESTIMATED_+
1BASELINE1_START, a.ESTIMATED_BASELINE1_FINISH, a.ESTIMATED_BASELINE1_EFFORT,+
1:n      a.ESTIMATED_BASELINE3_START, a.ESTIMATED_BASELINE3_FINISH, a.ESTIMATE+
1D_BASELINE3_EFFORT,:n      a.REGULAR_COST, a.REGULAR_RATE, a.SPECIAL_COST, a.+
1SPECIAL_RATE, a.DESCRIPTION:n      FROM PMO_TMP_RES_INFO a JOIN PROFILES r ON+
1 a.RESOURCE_TYPE='1' AND r.PROFILE_ID=a.RESOURCE_ID:n      JOIN TMT_COMPETENC+
1IES c ON c.ELEMENT_ID=r.ROLE_ID:n      JOIN TMT_COMPETENCIES d ON d.ELEMENT_I+
1D=c.PARENT_ID:
11055:
1                EXIT:: SP_S_PROFILE(1056) :: cplan.sql(13350) :: :
1SELECT PROFILE_NAME INTO h_in FROM PROFILES WHERE PROFILE_ID = h_id:
11067:
1           EXCEPTION:: SP_S_PROFILE(1068) :: cplan.sql(13362) :: :
1SC_SQL_SUCCESS:
1ROLE_TYPE:
1ORG_ID:
1ORG:
1ORG_NAME:
1GEO_ID:
1GEO:
1GEO_NAME:
1POOL_ID:
1POOL:
1POOL_NAME:
1TMT_ORGANIZATIONS:
1TMT_GEOGRAPHIES:
1DS:
1CS:
1PMO_ORASTD:
1STRINGCONCAT:
1RTRIM:
1SELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAME,41 AS TYPE_ID,30 AS ROLE_TYPE+
1, p.ROLE_ID, h_in AS ROLE_NAME,:n         ORG_ID, org.ELEMENT_NAME AS ORG_NAM+
1E, GEO_ID, geo.ELEMENT_NAME AS GEO_NAME, POOL_ID, pool.ELEMENT_NAME AS POOL_N+
1AME:n         FROM PROFILES p:n         LEFT JOIN TMT_ORGANIZATIONS org ON or+
1g.ELEMENT_ID  = ORG_ID:n         LEFT JOIN TMT_GEOGRAPHIES geo   ON geo.ELEME+
1NT_ID  = GEO_ID:n         LEFT JOIN TMT_POOLS pool        ON pool.ELEMENT_ID +
1= POOL_ID:n         WHERE p.PROFILE_ID = h_id:n         UNION ALL:n         S+
1ELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAME,41 AS TYPE_ID,ds.TYPE_ID AS RO+
1LE_TYPE,:n         cs.ELEMENT_ID AS ROLE_ID, PMO_ORASTD.StringConcat(PMO_ORAS+
1TD.StringConcat(RTRIM(ds.ELEMENT_NAME), ', '), RTRIM(cs.ELEMENT_NAME)) AS ROL+
1E_NAME,:n         '' ORG_ID, '' AS ORG_NAME, '' GEO_ID, '' AS GEO_NAME, '' PO+
1OL_ID, '' AS POOL_NAME:n         FROM RESOURCE_ASSIGN_ROLES r LEFT OUTER JOIN+
1 TMT_COMPETENCIES cs ON r.ROLE_ID=cs.ELEMENT_ID:n         LEFT OUTER JOIN TMT+
1_COMPETENCIES ds ON ds.ELEMENT_ID=cs.PARENT_ID WHERE r.RES_ASSIGNMENT_ID=h_id+
1:n         UNION ALL:n         SELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAM+
1E,41 AS TYPE_ID,ds.TYPE_ID AS ROLE_TYPE,:n         cs.ELEMENT_ID AS ROLE_ID, +
1PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(ds.ELEMENT_NAME), ', ')+
1, RTRIM(cs.ELEMENT_NAME)) AS ROLE_NAME,:n         '' ORG_ID, '' AS ORG_NAME, +
1'' GEO_ID, '' AS GEO_NAME, '' POOL_ID, '' AS POOL_NAME:n         FROM RESOURC+
1E_ASSIGN_SKILLS s LEFT OUTER JOIN TMT_COMPETENCIES cs ON s.SKILL_ID=cs.ELEMEN+
1T_ID:n         LEFT OUTER JOIN TMT_COMPETENCIES ds ON ds.ELEMENT_ID=cs.PARENT+
1_ID WHERE s.RES_ASSIGNMENT_ID=h_id:n         ORDER BY ELEMENT_ID,TYPE_ID:
11094:
1                EXIT:: SP_S_PROFILE(1095) :: cplan.sql(13389) :: :
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID, a.RESOURCE_ID,:n      CASE WHEN a.RE+
1SOURCE_TYPE='1' THEN (SELECT p.PROFILE_NAME FROM PROFILES p WHERE a.RESOURCE_+
1ID = p.PROFILE_ID):n      ELSE (SELECT r.FULL_NAME FROM RESOURCES r WHERE a.R+
1ESOURCE_ID = r.RESOURCE_ID) END AS ELEMENT_NAME,:n      CASE WHEN t.TSK_ASSIG+
1NMENT_ID IS NuLL THEN 185 WHEN a.RESOURCE_TYPE='1' THEN 41 ELSE 13 END AS TYP+
1E_ID,:n      a.RES_ASSIGNMENT_ID, a.PARTICIPANT, t.START_DT,t.FINISH_DT,:n   +
1   t.SD, t.FD, t.UNRESOLVED_START AS PLANNED_START, t.UNRESOLVED_FINISH AS PL+
1ANNED_FINISH,:n      CASE WHEN BIT_FLAG = '2' THEN SCHED_WORK ELSE PLANNED_WO+
1RK END AS PLANNED_WORK,:n      CASE WHEN BIT_FLAG = '2' THEN SCHED_WORK - WOR+
1K_TODATE ELSE PLANNED_WORK END AS REMAINING,:n      CASE WHEN t.ASSIGN_UNITS +
1> t.UNITS_MSP THEN t.ASSIGN_UNITS ELSE t.UNITS_MSP END AS UNITS_PERCENT,:n   +
1   0 AS MILESTONE_PERCENT,:n      CASE WHEN t.WORK_TODATE = 0 THEN 0 ELSE Tru+
1nc((TO_NUMBER(t.WORK_TODATE)/TO_NUMBER(PLANNED_WORK+SCHED_WORK))*10000) END A+
1S WORK_PERCENT,:n      t.BAK_START_DT,t.BAK_FINISH_DT,t.BAK_WORK,:n      t.FO+
1RECAST_START,t.FORECAST_FINISH,t.ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n      +
1t.WORK_TODATE AS ACTUAL,PROPOSED_START, PROPOSED_FINISH, PROPOSED_WORK,:n    +
1  h_per_day AS MINUTE_PER_DAY, a.WORK_LOCATION, a.SECURITY_ID, g.ELEMENT_NAME+
1 AS SECURITY_NAME,:n      COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SE+
1CURITY_ID, g2.ELEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RAT+
1E,t.SPECIAL_COST,t.SPECIAL_RATE,:n      CASE WHEN a.RESOURCE_TYPE='0' THEN (S+
1ELECT r.FS_LABOR_CODE FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n+
1      ELSE '' END AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,t.BASELINE1_S+
1TART,t.BASELINE1_FINISH,t.BASELINE1_WORK,:n      t.PROJECT_ASSIGNMENT_ID,t.TI+
1MECODE2_ID, TC.ELEMENT_NAME AS TIMECODE2_NAME, t.T_UNIT, t.C_EFFORT, t.C_UNIT+
1, t.C_CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, t.BILLABLE, t.CAPITAL_EXPENSE,+
1:n      t.ASSIGNMENT_DELAY, CASE WHEN t.BIT_FLAG IS NuLL THEN '' WHEN t.BIT_F+
1LAG = '0' THEN '1' ELSE '2' END AS BIT_FLAG, t.RATE_ADJUSTMENT, 0 AS ASSIGN_C+
1OUNT, t.UNRESOLVED_DURATION AS DURATION,:n      CASE WHEN h_level_state = 1 T+
1HEN COALESCE(t.LEVEL_START,t.UNRESOLVED_START) ELSE TO_TIMESTAMP('1899-12-31 +
100::00::00') END AS LEVEL_START,:n      CASE WHEN h_level_state = 1 THEN COAL+
1ESCE(t.LEVEL_FINISH,t.UNRESOLVED_FINISH) ELSE TO_TIMESTAMP('1899-12-31 00::00+
1::00') END AS LEVEL_FINISH,:n      CASE WHEN h_level_state = 1 THEN CASE WHEN+
1 t.LEVEL_EFFORT = 0 THEN t.ETC ELSE t.LEVEL_EFFORT END ELSE 0 END AS LEVEL_EF+
1FORT, t.MILESTONE_PERCENT AS PERCENT_DISCRETE, 0 as TOP_ID,:n      CASE WHEN +
1t.TSK_ASSIGNMENT_ID IS NOT NuLL AND t.PROJECT_ASSIGNMENT_ID = t.TSK_ASSIGNMEN+
1T_ID AND (t.LEVEL_START <> t.UNRESOLVED_START OR t.LEVEL_FINISH <> t.UNRESOLV+
1ED_FINISH) THEN '1' ELSE '0' END AS LEVEL_AFFECTED_FLAG,:n      T.LABOR_COST_+
1CC_ID,:n      EC.ELEMENT_NAME AS LABOR_COST_CC_NAME,:n      T.LABOR_REVENUE_C+
1C_ID,:n      CC.ELEMENT_NAME AS LABOR_REVENUE_CC_NAME, T.DEFAULT_LABOR_FLAG,+
1:n      T.CONTRACT_ID, CTR.ELEMENT_NAME AS CONTRACT_NAME:n      FROM RESOURCE+
1_ASSIGNMENTS a JOIN TASK_ASSIGNMENTS t ON t.TSK_ASSIGNMENT_ID = h_id AND a.RE+
1S_ASSIGNMENT_ID = t.RES_ASSIGNMENT_ID:n      LEFT OUTER JOIN TMT_GLOBAL_SECUR+
1ITY g ON a.SECURITY_ID=g.ELEMENT_ID:n      LEFT OUTER JOIN TMT_GLOBAL_SECURIT+
1Y g2 ON COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n      LEFT O+
1UTER JOIN TMT_TIMECODES TC ON TC.ELEMENT_ID= t.TIMECODE2_ID:n      LEFT OUTER+
1 JOIN TMT_CHARGECODES EC ON EC.ELEMENT_ID = T.LABOR_COST_CC_ID:n      LEFT OU+
1TER JOIN TMT_CHARGECODES CC ON CC.ELEMENT_ID = T.LABOR_REVENUE_CC_ID:n      L+
1EFT OUTER JOIN TMT_CONTRACTS CTR ON CTR.ELEMENT_ID = T.CONTRACT_ID:n      ORD+
1ER BY TYPE_ID DESC, ELEMENT_NAME:
11137:
1                EXIT:: SP_S_PROFILE(1138) :: cplan.sql(13432) :: :
1SC_PROFILE:
1ACCEPTED_DATE:
1DELAY:
1SELECT a.RES_ASSIGNMENT_ID AS ELEMENT_ID, a.RESOURCE_ID,:n      CASE WHEN a.R+
1ESOURCE_TYPE='1' THEN (SELECT p.PROFILE_NAME FROM PROFILES p WHERE a.RESOURCE+
1_ID = p.PROFILE_ID):n      ELSE (SELECT r.FULL_NAME FROM RESOURCES r WHERE a.+
1RESOURCE_ID = r.RESOURCE_ID) END AS ELEMENT_NAME,:n      CASE WHEN a.RESOURCE+
1_TYPE='1' THEN PMO_CNST.SC_PROFILE ELSE 185 END AS TYPE_ID,  a.RES_ASSIGNMENT+
1_ID, a.PARTICIPANT, TO_TIMESTAMP('1899-12-31 00::00::00') AS PLANNED_START, T+
1O_TIMESTAMP('1899-12-31 00::00::00') AS PLANNED_FINISH,:n      0 AS PLANNED_W+
1ORK,TO_TIMESTAMP('1899-12-31 00::00::00') AS START_DT,TO_TIMESTAMP('1899-12-3+
11 00::00::00') AS FINISH_DT,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS +
1SCHED_START,TO_TIMESTAMP('1899-12-31 00::00::00') AS SCHED_FINISH, 0 AS SCHED+
1_WORK,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS BAK_START_DT,TO_TIMEST+
1AMP('1899-12-31 00::00::00') AS BAK_FINISH_DT, 0 AS BAK_WORK,:n      TO_TIMES+
1TAMP('1899-12-31 00::00::00') AS FORECAST_START,TO_TIMESTAMP('1899-12-31 00::+
100::00') AS FORECAST_FINISH,0 AS ETC,:n      TO_TIMESTAMP('1899-12-31 00::00+
1::00') AS ACTUAL_START,TO_TIMESTAMP('1899-12-31 00::00::00') AS ACTUAL_FINISH+
1,:n      0 AS ACTUAL,h_per_day AS MINUTE_PER_DAY, a.WORK_LOCATION, TO_TIMESTA+
1MP('1899-12-31 00::00::00') AS ACCEPTED_DATE,:n      a.SECURITY_ID, g.ELEMENT+
1_NAME AS SECURITY_NAME, COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECU+
1RITY_ID, g2.ELEMENT_NAME AS CRI_SECURITY_NAME,:n      0 AS REGULAR_COST,0 AS +
1REGULAR_RATE,0 AS SPECIAL_COST, 0 AS SPECIAL_RATE,:n      CASE WHEN a.RESOURC+
1E_TYPE='0' THEN (SELECT r.FS_LABOR_CODE FROM RESOURCES r WHERE a.RESOURCE_ID +
1= r.RESOURCE_ID):n      ELSE '' END AS FS_LABOR_CODE,:n      a.REC_STATUS,'' +
1AS ASSIGN_STRING,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS BASELINE1_S+
1TART,TO_TIMESTAMP('1899-12-31 00::00::00') AS BASELINE1_FINISH,0 AS BASELINE1+
1_WORK,:n      '' AS PROJECT_ASSIGNMENT_ID, '' AS TIMECODE2_ID, '' AS TIMECODE+
12_NAME, 0 AS T_UNIT,:n      0 AS C_EFFORT, 0 AS C_UNIT, 0 AS C_CONTOUR, 0 AS +
1CONTOUR_TYPE, 0 AS C_OCCURRENCE, 0 AS BILLABLE,:n      0 AS DELAY:n      FROM+
1 RESOURCE_ASSIGNMENTS a:n      LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SEC+
1URITY_ID=g.ELEMENT_ID:n      LEFT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALES+
1CE(a.CRI_SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n      WHERE a.REC_STATUS N+
1OT IN ('L','D') AND a.ELEMENT_ID = h_id:n      ORDER BY TYPE_ID DESC, ELEMENT+
1_NAME:
11166:
1                EXIT:: SP_S_PROFILE(1167) :: cplan.sql(13461) :: :
112:
1DELETE FROM PMO_TMP_RTA:
1PMO_TMP_RTA:
1PA_FLAG:
1TABLE_TYPE:
1SC_TABLE_WBS:
1INSERT INTO PMO_TMP_RTA (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n         SELEC+
1T RESOURCE_ID, RESOURCE_TYPE, 'N' AS PA_FLAG:n         FROM TASK_ASSIGNMENTS+
1:n         WHERE PROJECT_ID = h_id AND:n         PROJECT_ASSIGNMENT_ID IS NuL+
1L AND:n         TABLE_TYPE = PMO_CNST.SC_TABLE_WBS:n         GROUP BY RESOURC+
1E_ID, RESOURCE_TYPE:
11194:
1           EXCEPTION:: SP_S_PROFILE(1195) :: cplan.sql(13489) :: :
1DELETE FROM PMO_TMP_CP_PRJ:
1PMO_TMP_CP_PRJ:
1INSERT INTO PMO_TMP_CP_PRJ (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n         SE+
1LECT  RESOURCE_ID, RESOURCE_TYPE, 'Y' AS PA_FLAG:n         FROM TASK_ASSIGNME+
1NTS:n         WHERE PROJECT_ID = h_id AND:n         TASK_ID = h_id:n         +
1GROUP BY RESOURCE_ID, RESOURCE_TYPE:
11220:
1           EXCEPTION:: SP_S_PROFILE(1221) :: cplan.sql(13515) :: :
1DELETE FROM PMO_TMP_RESOURCE_DATA:
1PMO_TMP_RESOURCE_DATA:
1INSERT INTO PMO_TMP_RESOURCE_DATA (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n    +
1     SELECT a.RESOURCE_ID, a.RESOURCE_TYPE, a.PA_FLAG:n         FROM PMO_TMP_+
1RTA a LEFT OUTER JOIN PMO_TMP_CP_PRJ b ON a.RESOURCE_ID=b.RESOURCE_ID:n      +
1   UNION:n         SELECT b.RESOURCE_ID, b.RESOURCE_TYPE, b.PA_FLAG:n        +
1 FROM PMO_TMP_CP_PRJ b LEFT OUTER JOIN PMO_TMP_RTA a ON a.RESOURCE_ID=b.RESOU+
1RCE_ID:
11246:
1           EXCEPTION:: SP_S_PROFILE(1247) :: cplan.sql(13541) :: :
1NICK_NAME:
1PRJ:
1RD:
1SELECT a.RESOURCE_ID AS ELEMENT_ID, p.FULL_NAME AS ELEMENT_NAME,13 AS TYPE_ID+
1, p.NICK_NAME, a.PA_FLAG:n      FROM PMO_TMP_RESOURCE_DATA a JOIN RESOURCES p+
1 ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_ID:n      LEFT OUTER J+
1OIN PMO_TMP_CP_PRJ PRJ ON a.RESOURCE_ID=PRJ.RESOURCE_ID:n      :n      UNION +
1ALL:n      :n      SELECT DISTINCT r.PROFILE_ID AS ELEMENT_ID, r.PROFILE_NAME+
1 AS ELEMENT_NAME,41 AS TYPE_ID, ' ' AS NICK_NAME, a.PA_FLAG:n      FROM PMO_T+
1MP_RESOURCE_DATA a JOIN PROFILES r ON a.RESOURCE_TYPE = '1' AND r.PROFILE_ID +
1= a.RESOURCE_ID:n      JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.ROLE_ID:n   +
1   JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID:n      LEFT OUTER JOIN+
1 PMO_TMP_CP_PRJ PRJ ON a.RESOURCE_ID=PRJ.RESOURCE_ID:n      :n      UNION ALL+
1:n      :n      SELECT DISTINCT ra.RESOURCE_ID AS ELEMENT_ID, p.FULL_NAME AS +
1ELEMENT_NAME, 185 AS TYPE_ID, p.NICK_NAME, 'N' AS PA_FLAG:n      FROM RESOURC+
1E_ASSIGNMENTS ra, RESOURCES p:n      WHERE ra.PROJECT_ID=h_id AND:n      ra.R+
1ESOURCE_ID = p.RESOURCE_ID AND:n      NOT EXISTS(SELECT rd.RESOURCE_ID FROM P+
1MO_TMP_RESOURCE_DATA rd WHERE ra.RESOURCE_ID = rd.RESOURCE_ID):n      ORDER B+
1Y TYPE_ID DESC, ELEMENT_NAME:
11272:
1                EXIT:: SP_S_PROFILE(1273) :: cplan.sql(13567) :: :
1SELECT t.ELEMENT_ID, p.FULL_NAME AS ELEMENT_NAME,13 AS TYPE_ID, p.NICK_NAME, +
1'N' AS PA_FLAG:n      FROM TMT_POOLS t JOIN RESOURCES p:n      ON t.ELEMENT_I+
1D = p.RESOURCE_ID:n      WHERE t.TYPE_ID = 13:n      AND t.RANK LIKE h_rank |+
1| '%':n      ORDER BY ELEMENT_NAME:
11286:
1                EXIT:: SP_S_PROFILE(1287) :: cplan.sql(13581) :: :
1SC_RESOURCE:
1SELECT R.RESOURCE_ID AS ELEMENT_ID, R.FULL_NAME AS ELEMENT_NAME,PMO_CNST.SC_R+
1ESOURCE AS TYPE_ID, R.NICK_NAME, 'N' AS PA_FLAG:n      FROM PROJECT_ASSIGNMEN+
1TS RA, RESOURCES R:n      WHERE RA.PROJECT_ID = h_id:n      AND RA.RESOURCE_I+
1D = R.RESOURCE_ID:n      ORDER BY ELEMENT_NAME:
11300:
1                EXIT:: SP_S_PROFILE(1301) :: cplan.sql(13595) :: :
11305:
1       RETURN_STATUS:: SP_S_PROFILE(1306) :: cplan.sql(13600) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
11314:
1           EXCEPTION:: SP_S_PROFILE(1315) :: cplan.sql(13609) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11326:
1           EXCEPTION:: SP_S_PROFILE(1327) :: cplan.sql(13621) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
1f2b
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 d :2 a0
d :2 a0 d :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 :18 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :15 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :4 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 19 3c
b7 19 3c a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :5 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :8 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 b7
19 :2 a0 51 a5 b 7e 51 b4
2e :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c a0
51 d a0 b7 19 :2 a0 51 a5
b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 51 a5 b a0
7e a0 6b b4 2e 5a a 10
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a 10 :8 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c b7 :2 19 3c :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6e
11e 11d :2 a0 6b 51 d :22 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6e 11e 11d :2 a0 6b 51 d :7 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:12d a0 12a e9 dd :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
65 a0 b7 :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 :2 a0
6e 11e 11d :2 a0 6b 51 d :26 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 b4 2e d :2e a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :49 a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :8d a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 a0 b7 19 :2 a0
51 a5 b 7e 51 b4 2e :3 a0
51 a5 b a5 b 7e 51 b4
2e a0 51 d :7 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e a0
6e d b7 :9 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :1c a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e a0 6e d b7 a0 6e d
b7 :2 19 3c b7 a0 6e d b7
:2 19 3c b7 :2 19 3c :1f7 a0 12a e9
dd :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 65 b7 :11d a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
b7 :2 19 3c a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6e
11e 11d :2 a0 6b 51 d :27 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 b4 2e d :35 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :4c a0 12a
e9 dd :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 65 a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6e 11e 11d :2 a0 6b
51 d :27 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 b4 2e
d :62 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :6a a0 12a e9 dd :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 65 a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e :e2 a0 12a
e9 dd :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 65 a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6e 11e 11d :2 a0 6b
51 d :2f a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6e 11e 11d :2 a0
6b 51 d :71 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :10 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :d5 a0 12a e9
dd :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 65 a0 b7
19 :2 a0 51 a5 b a0 7e a0
6b b4 2e :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :9a a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
b7 19 3c a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e :13e a0 12a
e9 dd :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 65 a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e :94 a0 12a e9 dd :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 65 a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6e
11e 11d :2 a0 6b 51 d :10 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6e 11e 11d :2 a0 6b 51 d :e a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6e 11e 11d :2 a0 6b 51 d
:26 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :6c a0 12a e9 dd :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 65 a0 b7 19 :2 a0 51 a5
b 7e 51 b4 2e :1a a0 12a e9
dd :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 65 a0 b7
19 :2 a0 51 a5 b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
a0 7e a0 6b b4 2e 5a 52
10 :1a a0 12a e9 dd :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 65 b7 19 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c b7 :2 a0 6b :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e :2 a0 6b b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :9 a0 12a e9 dd
:2 a0 65 b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c :7 a0 12a e9 dd :2 a0 65
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 68 4f 1d 17 b5 
1f2b
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
133 122 126 101 12e 121 14f 13e
142 11e 14a 13d 16b 15a 15e 13a
166 159 187 176 17a 156 182 175
1a3 192 196 172 19e 191 1bf 1ae
1b2 18e 1ba 1ad 1df 1ca 1ce 1aa
1d2 1da 1c9 1ff 1ea 1ee 1c6 1f2
1fa 1e9 21f 20a 20e 1e6 212 21a
209 23f 22a 22e 206 232 23a 229
25f 24a 24e 226 252 25a 249 27f
26a 26e 246 272 27a 269 29f 28a
28e 266 292 29a 289 2bf 2aa 2ae
286 2b2 2ba 2a9 2df 2ca 2ce 2a6
2d2 2da 2c9 2ff 2ea 2ee 2c6 2f2
2fa 2e9 31f 30a 30e 2e6 312 31a
309 33f 32a 32e 306 332 33a 329
35f 34a 34e 326 352 35a 349 37f
36a 36e 346 372 37a 369 39f 38a
38e 366 392 39a 389 3bf 3aa 3ae
386 3b2 3ba 3a9 3c6 3ca 3a6 3ce
3d2 3d6 3d9 3de 3df 1 3e1 3e6
3ea 3ee 3f1 3f6 3fa 3fe 401 406
407 409 40e 411 415 416 41b 420
423 428 429 42e 431 435 436 43b
43e 443 444 449 44c 451 452 457
45a 45e 462 466 467 469 46e 46f
471 472 477 47a 47f 480 485 488
48d 48e 493 496 49a 49b 4a0 4a3
4a8 4a9 4ae 4b1 4b6 4b7 4bc 4bd
4c2 4c4 4c8 4cb 4cf 4d3 4d6 4da
4de 4e1 4e4 4e9 4ec 4ef 4f2 4f3
4f8 4f9 1 4fb 500 504 508 50b
510 515 518 51c 51d 522 523 528
52a 52e 531 535 538 539 53e 541
545 549 54c 550 554 557 55a 55f
562 565 568 569 56e 56f 1 571
576 57a 57e 581 586 58b 58e 592
593 598 59b 5a0 5a1 5a6 5a9 5ae
5af 5b4 5b7 5bb 5bf 5c3 5c7 5ca
5cb 5cd 5d2 5d3 5d5 5d6 5db 5de
5e3 5e4 5e9 5ec 5f1 5f2 5f7 5fa
5fe 5ff 604 607 60c 60d 612 613
618 61a 61e 621 625 629 62c 630
634 637 63a 63f 642 645 648 649
64e 64f 1 651 656 65a 65e 661
666 66b 66e 672 673 678 679 67e
680 684 687 68b 68f 692 696 69a
69d 6a1 6a5 6a6 6ab 6ad 6b1 6b4
6b8 6bc 6c0 6c4 6c8 6cc 6d0 6d4
6d8 6dc 6e0 6e3 6e4 6e6 6e9 6ec
6ed 6f2 6f5 6f9 6fd 700 701 703
706 709 70a 70f 1 712 717 71b
71f 723 727 72b 72f 733 737 73b
73f 743 747 74b 74f 753 757 75b
75f 763 767 76b 76f 773 777 783
787 78b 78e 792 796 798 1 79c
7a0 7a4 7a7 7ab 7af 7b3 7b7 7ba
7be 7c2 7c5 7c8 7cd 7d0 7d3 7d6
7d7 7dc 7dd 1 7df 7e4 7e8 7ec
7ef 7f4 7f9 7fc 800 801 806 809
80e 80f 814 817 81c 81d 822 825
829 82a 82f 832 837 838 83d 840
844 848 84b 84e 84f 851 852 857
858 85d 85f 863 866 868 86c 86e
87a 87c 87e 87f 884 888 88a 896
898 89c 8a0 8a3 8a7 8aa 8ae 8b1
8b2 8b7 8ba 8be 8c2 8c6 8ca 8ce
8d2 8d6 8da 8de 8e2 8e6 8ea 8ee
8f2 8f6 8fa 8fe 902 906 90a 90e
91a 91e 922 925 929 92d 92f 1
933 937 93b 93e 942 946 94a 94e
951 955 959 95c 95f 964 967 96a
96d 96e 973 974 1 976 97b 97f
983 986 98b 990 993 997 998 99d
9a0 9a5 9a6 9ab 9ae 9b3 9b4 9b9
9bc 9c0 9c1 9c6 9c9 9ce 9cf 9d4
9d7 9db 9df 9e2 9e5 9e6 9e8 9e9
9ee 9ef 9f4 9f6 9fa 9fd 9ff a03
a05 a11 a13 a15 a16 a1b a1f a21
a2d a2f a33 a37 a3a a3e a41 a45
a48 a49 a4e a51 a55 a59 a5d a61
a6d a71 a75 a78 a7c a80 a82 1
a86 a8a a8e a91 a95 a99 a9d aa1
aa4 aa8 aac aaf ab2 ab7 aba abd
ac0 ac1 ac6 ac7 1 ac9 ace ad2
ad6 ad9 ade ae3 ae6 aea aeb af0
af3 af8 af9 afe b01 b06 b07 b0c
b0f b13 b14 b19 b1c b21 b22 b27
b2a b2e b32 b35 b38 b39 b3b b3c
b41 b42 b47 b49 b4d b50 b52 b56
b58 b64 b66 b68 b69 b6e b72 b74
b80 b82 b86 b8a b8d b91 b94 b98
b9b b9c ba1 ba4 ba8 bac baf bb3
bb7 bba bbd bc2 bc5 bc8 bcb bcc
bd1 bd2 1 bd4 bd9 bdd be1 be4
be9 bee bf1 bf5 bf6 bfb bfe c03
c04 c09 c0c c11 c12 c17 c1a c1e
c22 c26 c2a c2d c2e c30 c35 c36
c38 c39 c3e c41 c46 c47 c4c c4f
c54 c55 c5a c5d c61 c62 c67 c6a
c6f c70 c75 c76 c7b c7d c81 c84
c88 c8c c8f c93 c97 c9a c9d ca2
ca5 ca8 cab cac cb1 cb2 1 cb4
cb9 cbd cc1 cc4 cc9 cce cd1 cd5
cd6 cdb cdc ce1 ce3 ce7 cea cee
cf2 cf5 cf9 cfd d00 d04 d08 d09
d0e d10 d14 d17 d19 d1d d20 d22
d26 d29 d2d d2f d33 d37 d3a d3b
d3d d40 d43 d44 d49 d4d d51 d55
d59 d5d d69 d6d d71 d74 d78 d7c
d7e 1 d82 d86 d8a d8d d91 d95
d99 d9d da0 da4 da8 dab dae db3
db6 db9 dbc dbd dc2 dc3 1 dc5
dca dce dd2 dd5 dda ddf de2 de6
de7 dec def df4 df5 dfa dfd e02
e03 e08 e0b e0f e10 e15 e18 e1d
e1e e23 e26 e2a e2e e31 e34 e35
e37 e38 e3d e3e e43 e45 e49 e4c
e4e e52 e54 e60 e62 e64 e65 e6a
e6e e70 e7c e7e e82 e86 e89 e8d
e90 e94 e97 e98 e9d ea0 ea4 ea8
eab eaf eb3 eb6 eb9 ebe ec1 ec4
ec7 ec8 ecd ece 1 ed0 ed5 ed9
edd ee0 ee5 eea eed ef1 ef2 ef7
efa eff f00 f05 f08 f0d f0e f13
f16 f1a f1e f22 f26 f29 f2a f2c
f31 f32 f34 f35 f3a f3d f42 f43
f48 f4b f50 f51 f56 f59 f5d f5e
f63 f66 f6b f6c f71 f72 f77 f79
f7d f80 f84 f88 f8b f8f f93 f96
f99 f9e fa1 fa4 fa7 fa8 fad fae
1 fb0 fb5 fb9 fbd fc0 fc5 fca
fcd fd1 fd2 fd7 fd8 fdd fdf fe3
fe6 fea fee ff1 ff5 ff9 ffc 1000
1004 1005 100a 100c 1010 1013 1017 101b
101f 1023 1027 102b 102f 1033 103f 1043
1047 104a 104e 1052 1054 1 1058 105c
1060 1063 1067 106b 106f 1073 1076 107a
107e 1081 1084 1089 108c 108f 1092 1093
1098 1099 1 109b 10a0 10a4 10a8 10ab
10b0 10b5 10b8 10bc 10bd 10c2 10c5 10ca
10cb 10d0 10d3 10d8 10d9 10de 10e1 10e5
10e6 10eb 10ee 10f3 10f4 10f9 10fc 1100
1104 1107 110a 110b 110d 110e 1113 1114
1119 111b 111f 1122 1124 1128 112a 1136
1138 113a 113b 1140 1144 1146 1152 1154
1158 115a 115e 1162 1166 1169 116a 116c
116f 1172 1173 1178 117c 1180 1184 1188
118c 1198 119c 11a0 11a3 11a7 11ab 11ad
1 11b1 11b5 11b9 11bc 11c0 11c4 11c8
11cc 11cf 11d3 11d7 11da 11dd 11e2 11e5
11e8 11eb 11ec 11f1 11f2 1 11f4 11f9
11fd 1201 1204 1209 120e 1211 1215 1216
121b 121e 1223 1224 1229 122c 1231 1232
1237 123a 123e 123f 1244 1247 124c 124d
1252 1255 1259 125d 1260 1263 1264 1266
1267 126c 126d 1272 1274 1278 127b 127d
1281 1283 128f 1291 1293 1294 1299 129d
129f 12ab 12ad 12b1 12b5 12b8 12bc 12bf
12c3 12c6 12c7 12cc 12cf 12d3 12d7 12da
12de 12e2 12e5 12e8 12ed 12f0 12f3 12f6
12f7 12fc 12fd 1 12ff 1304 1308 130c
130f 1314 1319 131c 1320 1321 1326 1329
132e 132f 1334 1337 133c 133d 1342 1345
1349 134d 1351 1355 1358 1359 135b 1360
1361 1363 1364 1369 136c 1371 1372 1377
137a 137f 1380 1385 1388 138c 138d 1392
1395 139a 139b 13a0 13a1 13a6 13a8 13ac
13af 13b3 13b7 13ba 13be 13c2 13c5 13c8
13cd 13d0 13d3 13d6 13d7 13dc 13dd 1
13df 13e4 13e8 13ec 13ef 13f4 13f9 13fc
1400 1401 1406 1407 140c 140e 1412 1415
1419 141d 1420 1424 1428 142b 142f 1433
1434 1439 143b 143f 1442 1446 1449 144d
1451 1453 1457 145b 145f 1462 1463 1465
1469 146c 1470 1473 1474 1479 147c 1480
1484 1487 1488 148a 148d 1490 1491 1496
1 1499 149e 14a2 14a6 14a9 14aa 14ac
14b0 14b3 14b7 14ba 14bb 14c0 1 14c3
14c8 14cc 14d0 14d3 14d4 14d6 14da 14dd
14e1 14e4 14e5 14ea 1 14ed 14f2 14f6
14fa 14fe 1502 1506 150a 150e 1512 151e
1522 1526 1529 152d 1531 1533 1 1537
153b 153f 1542 1546 154a 154e 1552 1555
1559 155d 1560 1563 1568 156b 156e 1571
1572 1577 1578 1 157a 157f 1583 1587
158a 158f 1594 1597 159b 159c 15a1 15a4
15a9 15aa 15af 15b2 15b7 15b8 15bd 15c0
15c4 15c5 15ca 15cd 15d2 15d3 15d8 15db
15df 15e3 15e6 15e9 15ea 15ec 15ed 15f2
15f3 15f8 15fa 15fe 1601 1603 1607 1609
1615 1617 1619 161a 161f 1623 1625 1631
1633 1637 163b 163e 1642 1645 1649 164c
164d 1652 1655 1659 165d 1660 1664 1668
166b 166e 1673 1676 1679 167c 167d 1682
1683 1 1685 168a 168e 1692 1695 169a
169f 16a2 16a6 16a7 16ac 16af 16b4 16b5
16ba 16bd 16c2 16c3 16c8 16cb 16cf 16d3
16d7 16db 16de 16df 16e1 16e6 16e7 16e9
16ea 16ef 16f2 16f7 16f8 16fd 1700 1705
1706 170b 170e 1712 1713 1718 171b 1720
1721 1726 1727 172c 172e 1732 1735 1739
173d 1740 1744 1748 174b 174e 1753 1756
1759 175c 175d 1762 1763 1 1765 176a
176e 1772 1775 177a 177f 1782 1786 1787
178c 178d 1792 1794 1798 179b 179f 17a3
17a6 17aa 17ae 17b1 17b5 17b9 17ba 17bf
17c1 17c5 17c8 17ca 17ce 17d2 17d5 17d9
17dd 17e0 17e1 17e3 17e6 17e9 17ea 17ef
17f3 17f7 17fc 1801 1805 1809 180d 1810
1813 1817 181b 181f 1823 1827 182b 182f
1833 1837 183b 183f 1843 1847 184b 184f
1853 1857 185b 185f 1863 1867 186b 186f
1873 1877 187b 187f 1883 1887 188b 188f
1893 1897 189b 189f 18ab 18af 18b4 18b8
18bb 18bc 18c1 18c5 18c9 18cc 18cf 18d3
18d5 18d9 18dd 18e0 18e3 18e7 18e9 18ed
18f1 18f4 18f6 1 18fa 18fe 1902 1905
1909 190d 1911 1915 1918 191c 1920 1923
1926 192b 192e 1931 1934 1935 193a 193b
1 193d 1942 1946 194a 194d 1952 1957
195a 195e 195f 1964 1967 196c 196d 1972
1975 197a 197b 1980 1983 1987 1988 198d
1990 1995 1996 199b 199e 19a2 19a6 19a9
19ac 19ad 19af 19b0 19b5 19b6 19bb 19bd
19c1 19c4 19c6 19ca 19cc 19d8 19da 19dc
19dd 19e2 19e6 19e8 19f4 19f6 19fa 19fe
1a03 1a08 1a0c 1a10 1a14 1a17 1a1a 1a1e
1a22 1a26 1a2a 1a2e 1a32 1a36 1a3a 1a46
1a4a 1a4f 1a53 1a56 1a57 1a5c 1a60 1a64
1a67 1a6a 1a6e 1a70 1a74 1a78 1a7b 1a7e
1a82 1a84 1a88 1a8c 1a8f 1a91 1 1a95
1a99 1a9d 1aa0 1aa4 1aa8 1aac 1ab0 1ab3
1ab7 1abb 1abe 1ac1 1ac6 1ac9 1acc 1acf
1ad0 1ad5 1ad6 1 1ad8 1add 1ae1 1ae5
1ae8 1aed 1af2 1af5 1af9 1afa 1aff 1b02
1b07 1b08 1b0d 1b10 1b15 1b16 1b1b 1b1e
1b22 1b23 1b28 1b2b 1b30 1b31 1b36 1b39
1b3d 1b41 1b44 1b47 1b48 1b4a 1b4b 1b50
1b51 1b56 1b58 1b5c 1b5f 1b61 1b65 1b67
1b73 1b75 1b77 1b78 1b7d 1b81 1b83 1b8f
1b91 1b95 1b99 1b9d 1ba1 1ba5 1ba9 1bad
1bb1 1bb5 1bb9 1bbd 1bc1 1bc5 1bc9 1bcd
1bd1 1bd5 1bd9 1bdd 1be1 1be5 1be9 1bed
1bf1 1bf5 1bf9 1bfd 1c01 1c05 1c09 1c0d
1c11 1c15 1c19 1c1d 1c21 1c25 1c29 1c2d
1c31 1c35 1c39 1c3d 1c41 1c45 1c49 1c4d
1c51 1c55 1c59 1c5d 1c61 1c65 1c69 1c6d
1c71 1c75 1c79 1c7d 1c81 1c85 1c89 1c8d
1c91 1c95 1c99 1c9d 1ca1 1ca5 1ca9 1cad
1cb1 1cb5 1cb9 1cbd 1cc1 1cc5 1cc9 1ccd
1cd1 1cd5 1cd9 1cdd 1ce1 1ce5 1ce9 1ced
1cf1 1cf5 1cf9 1cfd 1d01 1d05 1d09 1d0d
1d11 1d15 1d19 1d1d 1d21 1d25 1d29 1d2d
1d31 1d35 1d39 1d3d 1d41 1d45 1d49 1d4d
1d51 1d55 1d59 1d5d 1d61 1d65 1d69 1d6d
1d71 1d75 1d79 1d7d 1d81 1d85 1d89 1d8d
1d91 1d95 1d99 1d9d 1da1 1da5 1da9 1dad
1db1 1db5 1db9 1dbd 1dc1 1dc5 1dc9 1dcd
1dd1 1dd5 1dd9 1ddd 1de1 1de5 1de9 1ded
1df1 1df5 1df9 1dfd 1e01 1e05 1e09 1e0d
1e11 1e15 1e19 1e1d 1e21 1e25 1e29 1e2d
1e31 1e35 1e39 1e3d 1e41 1e45 1e49 1e4d
1e51 1e55 1e59 1e5d 1e61 1e65 1e69 1e6d
1e71 1e75 1e79 1e7d 1e81 1e85 1e89 1e8d
1e91 1e95 1e99 1e9d 1ea1 1ea5 1ea9 1ead
1eb1 1eb5 1eb9 1ebd 1ec1 1ec5 1ec9 1ecd
1ed1 1ed5 1ed9 1edd 1ee1 1ee5 1ee9 1eed
1ef1 1ef5 1ef9 1efd 1f01 1f05 1f09 1f0d
1f11 1f15 1f19 1f1d 1f21 1f25 1f29 1f2d
1f31 1f35 1f39 1f3d 1f41 1f45 1f49 1f4d
1f51 1f55 1f59 1f5d 1f61 1f65 1f69 1f6d
1f71 1f75 1f79 1f7d 1f81 1f85 1f89 1f8d
1f91 1f95 1f99 1f9d 1fa1 1fa5 1fa9 1fad
1fb1 1fb5 1fb9 1fbd 1fc1 1fc5 1fc9 1fcd
1fd1 1fd5 1fd9 1fdd 1fe1 1fe5 1fe9 1fed
1ff1 1ff5 1ff9 1ffd 2001 2005 2009 200d
2011 2015 2019 201d 2021 2025 2029 202d
2031 2035 2039 203d 2041 2045 2051 2056
205a 205e 2062 2065 2069 206d 2070 2073
2078 207b 207e 2081 2082 2087 2088 1
208a 208f 2093 2097 209a 209f 20a4 20a7
20ab 20ac 20b1 20b2 20b7 20b9 20bd 20c0
20c4 20c8 20cc 20d0 20d2 20d6 20da 20dd
20de 20e0 20e3 20e6 20e7 20ec 20ef 20f3
20f7 20fa 20fb 20fd 2100 2103 2104 2109
1 210c 2111 2115 2119 211e 2123 2127
212b 212f 2132 2135 2139 213d 2141 2145
2149 214d 2151 2155 2159 215d 2161 2165
2169 216d 2171 2175 2179 217d 2181 2185
2189 218d 2191 2195 2199 219d 21a1 21a5
21a9 21ad 21b1 21b5 21b9 21bd 21c1 21c5
21c9 21cd 21d1 21dd 21e1 21e6 21ea 21ed
21ee 21f3 21f7 21fb 21fe 2201 2205 2207
220b 220f 2212 2215 2219 221b 221f 2223
2226 2228 1 222c 2230 2234 2237 223b
223f 2243 2247 224a 224e 2252 2255 2258
225d 2260 2263 2266 2267 226c 226d 1
226f 2274 2278 227c 227f 2284 2289 228c
2290 2291 2296 2299 229e 229f 22a4 22a7
22ac 22ad 22b2 22b5 22b9 22ba 22bf 22c2
22c7 22c8 22cd 22d0 22d4 22d8 22db 22de
22df 22e1 22e2 22e7 22e8 22ed 22ef 22f3
22f6 22f8 22fc 22fe 230a 230c 230e 230f
2314 2318 231a 2326 2328 232c 2330 2333
2337 2338 233d 2341 2345 2349 234d 2351
2355 2359 235d 2361 2365 2369 236d 2371
2375 2379 237d 2381 2385 2389 238d 2391
2395 2399 239d 23a1 23a5 23a9 23ad 23b1
23b5 23b9 23bd 23c1 23c5 23c9 23cd 23d1
23d5 23d9 23dd 23e1 23e5 23e9 23ed 23f1
23f5 23f9 2405 2409 240e 2412 2415 2416
241b 241f 2423 2426 2429 242d 242f 2433
2437 243a 243d 2441 2443 2447 244b 244e
2450 1 2454 2458 245c 245f 2463 2467
246b 246f 2472 2476 247a 247d 2480 2485
2488 248b 248e 248f 2494 2495 1 2497
249c 24a0 24a4 24a7 24ac 24b1 24b4 24b8
24b9 24be 24c1 24c6 24c7 24cc 24cf 24d4
24d5 24da 24dd 24e1 24e2 24e7 24ea 24ef
24f0 24f5 24f8 24fc 2500 2503 2506 2507
2509 250a 250f 2510 2515 2517 251b 251e
2520 2524 2526 2532 2534 2536 2537 253c
2540 2542 254e 2550 2554 2558 255c 2560
2564 2568 256c 2570 2574 2578 257c 2580
2584 2588 258c 2590 2594 2598 259c 25a0
25a4 25a8 25ac 25b0 25b4 25b8 25bc 25c0
25c4 25c8 25cc 25d0 25d4 25d8 25dc 25e0
25e4 25e8 25ec 25f0 25f4 25f8 25fc 2600
2604 2608 260c 2610 2614 2618 261c 2620
2624 2628 262c 2630 2634 2638 263c 2640
2644 2648 264c 2650 2654 2658 265c 2660
2664 2668 266c 2670 2674 2680 2685 2689
268d 2691 2694 2698 269c 269f 26a2 26a7
26aa 26ad 26b0 26b1 26b6 26b7 1 26b9
26be 26c2 26c6 26c9 26ce 26d3 26d6 26da
26db 26e0 26e1 26e6 26e8 26ec 26ef 26f3
26f7 26fb 26ff 2701 2705 2709 270d 2710
2711 2713 2716 2719 271a 271f 2723 2727
272b 272f 2733 2737 273b 273f 2743 2747
274b 274f 2753 2757 275b 275f 2763 2767
276b 276f 2773 2777 277b 277f 2783 2787
278b 278f 2793 2797 279b 279f 27a3 27a7
27ab 27af 27b3 27b7 27bb 27bf 27c3 27c7
27cb 27cf 27d3 27d7 27db 27df 27e3 27e7
27eb 27ef 27f3 27f7 27fb 27ff 2803 2807
280b 280f 2813 2817 281b 281f 2823 2827
282b 282f 2833 2837 283b 283f 2843 2847
284b 284f 2853 2857 285b 285f 2863 2867
286b 286f 2873 2877 287b 287f 2883 2887
288b 288f 2893 2897 289b 289f 28a3 28a7
28ab 28af 28b3 28b7 28bb 28bf 28c3 28c7
28cb 28cf 28d3 28d7 28db 28df 28e3 28e7
28eb 28ef 28f3 28f7 28fb 28ff 2903 2907
290b 290f 2913 2917 291b 291f 2923 2927
292b 292f 2933 2937 293b 293f 2943 2947
294b 294f 2953 295f 2964 2968 296c 2970
2973 2977 297b 297e 2981 2986 2989 298c
298f 2990 2995 2996 1 2998 299d 29a1
29a5 29a8 29ad 29b2 29b5 29b9 29ba 29bf
29c0 29c5 29c7 29cb 29ce 29d2 29d6 29da
29de 29e0 29e4 29e8 29ec 29ef 29f0 29f2
29f5 29f8 29f9 29fe 2a02 2a06 2a0a 2a0d
2a0e 2a10 2a11 2a13 2a16 2a19 2a1a 2a1f
2a23 2a26 2a2a 2a2e 2a32 2a36 2a3a 2a3e
2a42 2a46 2a52 2a56 2a5a 2a5d 2a61 2a65
2a67 1 2a6b 2a6f 2a73 2a76 2a7a 2a7e
2a82 2a86 2a89 2a8d 2a91 2a94 2a97 2a9c
2a9f 2aa2 2aa5 2aa6 2aab 2aac 1 2aae
2ab3 2ab7 2abb 2abe 2ac3 2ac8 2acb 2acf
2ad0 2ad5 2ad8 2add 2ade 2ae3 2ae6 2aeb
2aec 2af1 2af4 2af8 2af9 2afe 2b01 2b06
2b07 2b0c 2b0f 2b13 2b17 2b1a 2b1d 2b1e
2b20 2b21 2b26 2b27 2b2c 2b2e 2b32 2b35
2b37 2b3b 2b3d 2b49 2b4b 2b4d 2b4e 2b53
2b57 2b59 2b65 2b67 2b6b 2b6f 2b72 2b73
2b75 2b78 2b7b 2b7c 2b81 2b85 2b8a 2b8e
2b90 2b94 2b98 2b9c 2ba0 2ba4 2ba8 2bac
2bb0 2bb4 2bc0 2bc4 2bc8 2bcb 2bcf 2bd3
2bd5 1 2bd9 2bdd 2be1 2be4 2be8 2bec
2bf0 2bf4 2bf7 2bfb 2bff 2c02 2c05 2c0a
2c0d 2c10 2c13 2c14 2c19 2c1a 1 2c1c
2c21 2c25 2c29 2c2c 2c31 2c36 2c39 2c3d
2c3e 2c43 2c46 2c4b 2c4c 2c51 2c54 2c59
2c5a 2c5f 2c62 2c66 2c67 2c6c 2c6f 2c74
2c75 2c7a 2c7d 2c81 2c85 2c88 2c8b 2c8c
2c8e 2c8f 2c94 2c95 2c9a 2c9c 2ca0 2ca3
2ca5 2ca9 2cab 2cb7 2cb9 2cbb 2cbc 2cc1
2cc5 2cc7 2cd3 2cd5 2cd9 2cdd 2ce0 2ce1
2ce3 2ce6 2ce9 2cea 2cef 2cf3 2cf7 2cfb
2cff 2d03 2d07 2d0b 2d0f 2d13 2d17 2d1b
2d1f 2d23 2d27 2d2b 2d2f 2d33 2d37 2d3b
2d3f 2d43 2d47 2d4b 2d4f 2d53 2d57 2d5b
2d5f 2d6b 2d6f 2d73 2d76 2d7a 2d7e 2d80
1 2d84 2d88 2d8c 2d8f 2d93 2d97 2d9b
2d9f 2da2 2da6 2daa 2dad 2db0 2db5 2db8
2dbb 2dbe 2dbf 2dc4 2dc5 1 2dc7 2dcc
2dd0 2dd4 2dd7 2ddc 2de1 2de4 2de8 2de9
2dee 2df1 2df6 2df7 2dfc 2dff 2e04 2e05
2e0a 2e0d 2e11 2e12 2e17 2e1a 2e1f 2e20
2e25 2e28 2e2c 2e30 2e33 2e36 2e37 2e39
2e3a 2e3f 2e40 2e45 2e47 2e4b 2e4e 2e50
2e54 2e56 2e62 2e64 2e66 2e67 2e6c 2e70
2e72 2e7e 2e80 2e84 2e88 2e8b 2e8c 2e8e
2e91 2e94 2e95 2e9a 2e9e 2ea3 2ea7 2ea9
2ead 2eb2 2eb6 2eb8 2ebc 2ec0 2ec3 2ec5
2ec9 2ece 2ed2 2ed4 2ed8 2edc 2edf 2ee1
2ee5 2ee9 2eec 2ef0 2ef4 2ef8 2efc 2f00
2f04 2f08 2f0c 2f10 2f14 2f18 2f1c 2f20
2f24 2f28 2f2c 2f30 2f34 2f38 2f3c 2f40
2f44 2f48 2f4c 2f50 2f54 2f58 2f5c 2f60
2f64 2f68 2f6c 2f70 2f74 2f78 2f7c 2f80
2f84 2f88 2f8c 2f90 2f94 2f98 2f9c 2fa0
2fa4 2fa8 2fac 2fb0 2fb4 2fb8 2fbc 2fc0
2fc4 2fc8 2fcc 2fd0 2fd4 2fd8 2fdc 2fe0
2fe4 2fe8 2fec 2ff0 2ff4 2ff8 2ffc 3000
3004 3008 300c 3010 3014 3018 301c 3020
3024 3028 302c 3030 3034 3038 303c 3040
3044 3048 304c 3050 3054 3058 305c 3060
3064 3068 306c 3070 3074 3078 307c 3080
3084 3088 308c 3090 3094 3098 309c 30a0
30a4 30a8 30ac 30b0 30b4 30b8 30bc 30c0
30c4 30c8 30cc 30d0 30d4 30d8 30dc 30e0
30e4 30e8 30ec 30f0 30f4 30f8 30fc 3100
3104 3108 310c 3110 3114 3118 311c 3120
3124 3128 312c 3130 3134 3138 313c 3140
3144 3148 314c 3150 3154 3158 315c 3160
3164 3168 316c 3170 3174 3178 317c 3180
3184 3188 318c 3190 3194 3198 319c 31a0
31a4 31a8 31ac 31b0 31b4 31b8 31bc 31c0
31c4 31c8 31cc 31d0 31d4 31d8 31dc 31e0
31e4 31e8 31ec 31f0 31f4 31f8 31fc 3200
3204 3208 320c 3210 3214 3218 321c 3220
3224 3228 322c 3230 3234 3238 323c 3240
3244 3248 324c 3250 3254 3258 325c 3260
3264 3268 326c 3270 3274 3278 327c 3280
3284 3288 328c 3290 3294 3298 329c 32a0
32a4 32a8 32ac 32b0 32b4 32b8 32bc 32c0
32c4 32c8 32cc 32d0 32d4 32d8 32dc 32e0
32e4 32e8 32ec 32f0 32f4 32f8 32fc 3300
3304 3308 330c 3310 3314 3318 331c 3320
3324 3328 332c 3330 3334 3338 333c 3340
3344 3348 334c 3350 3354 3358 335c 3360
3364 3368 336c 3370 3374 3378 337c 3380
3384 3388 338c 3390 3394 3398 339c 33a0
33a4 33a8 33ac 33b0 33b4 33b8 33bc 33c0
33c4 33c8 33cc 33d0 33d4 33d8 33dc 33e0
33e4 33e8 33ec 33f0 33f4 33f8 33fc 3400
3404 3408 340c 3410 3414 3418 341c 3420
3424 3428 342c 3430 3434 3438 343c 3440
3444 3448 344c 3450 3454 3458 345c 3460
3464 3468 346c 3470 3474 3478 347c 3480
3484 3488 348c 3490 3494 3498 349c 34a0
34a4 34a8 34ac 34b0 34b4 34b8 34bc 34c0
34c4 34c8 34cc 34d0 34d4 34d8 34dc 34e0
34e4 34e8 34ec 34f0 34f4 34f8 34fc 3500
3504 3508 350c 3510 3514 3518 351c 3520
3524 3528 352c 3530 3534 3538 353c 3540
3544 3548 354c 3550 3554 3558 355c 3560
3564 3568 356c 3570 3574 3578 357c 3580
3584 3588 358c 3590 3594 3598 359c 35a0
35a4 35a8 35ac 35b0 35b4 35b8 35bc 35c0
35c4 35c8 35cc 35d0 35d4 35d8 35dc 35e0
35e4 35e8 35ec 35f0 35f4 35f8 35fc 3600
3604 3608 360c 3610 3614 3618 361c 3620
3624 3628 362c 3630 3634 3638 363c 3640
3644 3648 364c 3650 3654 3658 365c 3660
3664 3668 366c 3670 3674 3678 367c 3680
3684 3688 368c 3690 3694 3698 369c 36a0
36a4 36a8 36ac 36b0 36b4 36b8 36bc 36c0
36c4 36c8 36d4 36d9 36dd 36e1 36e5 36e8
36ec 36f0 36f3 36f6 36fb 36fe 3701 3704
3705 370a 370b 1 370d 3712 3716 371a
371d 3722 3727 372a 372e 372f 3734 3735
373a 373c 3740 3743 3747 374b 374f 3751
3755 3759 375d 3761 3765 3769 376d 3771
3775 3779 377d 3781 3785 3789 378d 3791
3795 3799 379d 37a1 37a5 37a9 37ad 37b1
37b5 37b9 37bd 37c1 37c5 37c9 37cd 37d1
37d5 37d9 37dd 37e1 37e5 37e9 37ed 37f1
37f5 37f9 37fd 3801 3805 3809 380d 3811
3815 3819 381d 3821 3825 3829 382d 3831
3835 3839 383d 3841 3845 3849 384d 3851
3855 3859 385d 3861 3865 3869 386d 3871
3875 3879 387d 3881 3885 3889 388d 3891
3895 3899 389d 38a1 38a5 38a9 38ad 38b1
38b5 38b9 38bd 38c1 38c5 38c9 38cd 38d1
38d5 38d9 38dd 38e1 38e5 38e9 38ed 38f1
38f5 38f9 38fd 3901 3905 3909 390d 3911
3915 3919 391d 3921 3925 3929 392d 3931
3935 3939 393d 3941 3945 3949 394d 3951
3955 3959 395d 3961 3965 3969 396d 3971
3975 3979 397d 3981 3985 3989 398d 3991
3995 3999 399d 39a1 39a5 39a9 39ad 39b1
39b5 39b9 39bd 39c1 39c5 39c9 39cd 39d1
39d5 39d9 39dd 39e1 39e5 39e9 39ed 39f1
39f5 39f9 39fd 3a01 3a05 3a09 3a0d 3a11
3a15 3a19 3a1d 3a21 3a25 3a29 3a2d 3a31
3a35 3a39 3a3d 3a41 3a45 3a49 3a4d 3a51
3a55 3a59 3a5d 3a61 3a65 3a69 3a6d 3a71
3a75 3a79 3a7d 3a81 3a85 3a89 3a8d 3a91
3a95 3a99 3a9d 3aa1 3aa5 3aa9 3aad 3ab1
3ab5 3ab9 3abd 3ac1 3ac5 3ac9 3acd 3ad1
3ad5 3ad9 3add 3ae1 3ae5 3ae9 3aed 3af1
3af5 3af9 3afd 3b01 3b05 3b09 3b0d 3b11
3b15 3b19 3b1d 3b21 3b25 3b29 3b2d 3b31
3b35 3b39 3b3d 3b41 3b45 3b49 3b4d 3b51
3b55 3b59 3b5d 3b61 3b65 3b69 3b6d 3b71
3b75 3b79 3b7d 3b81 3b85 3b89 3b8d 3b91
3b95 3b99 3b9d 3ba1 3ba5 3ba9 3bad 3bb1
3bb5 3bb9 3bbd 3bc1 3bc5 3bd1 3bd6 3bda
3bde 3be2 3be5 3be9 3bed 3bf0 3bf3 3bf8
3bfb 3bfe 3c01 3c02 3c07 3c08 1 3c0a
3c0f 3c13 3c17 3c1a 3c1f 3c24 3c27 3c2b
3c2c 3c31 3c32 3c37 3c39 3c3d 3c40 3c44
3c48 3c4c 3c4e 3c52 3c56 3c59 3c5d 3c5f
3c63 3c67 3c6b 3c6e 3c6f 3c71 3c74 3c77
3c78 3c7d 3c81 3c85 3c8a 3c8f 3c93 3c97
3c9b 3c9e 3ca1 3ca5 3ca9 3cad 3cb1 3cb5
3cb9 3cbd 3cc1 3cc5 3cc9 3ccd 3cd1 3cd5
3cd9 3cdd 3ce1 3ce5 3ce9 3ced 3cf1 3cf5
3cf9 3cfd 3d01 3d05 3d09 3d0d 3d11 3d15
3d19 3d1d 3d21 3d25 3d29 3d2d 3d31 3d35
3d39 3d3d 3d41 3d4d 3d51 3d56 3d5a 3d5d
3d5e 3d63 3d67 3d6b 3d6e 3d71 3d75 3d77
3d7b 3d7f 3d82 3d85 3d89 3d8b 3d8f 3d93
3d96 3d98 1 3d9c 3da0 3da4 3da7 3dab
3daf 3db3 3db7 3dba 3dbe 3dc2 3dc5 3dc8
3dcd 3dd0 3dd3 3dd6 3dd7 3ddc 3ddd 1
3ddf 3de4 3de8 3dec 3def 3df4 3df9 3dfc
3e00 3e01 3e06 3e09 3e0e 3e0f 3e14 3e17
3e1c 3e1d 3e22 3e25 3e29 3e2a 3e2f 3e32
3e37 3e38 3e3d 3e40 3e44 3e48 3e4b 3e4e
3e4f 3e51 3e52 3e57 3e58 3e5d 3e5f 3e63
3e66 3e68 3e6c 3e6e 3e7a 3e7c 3e7e 3e7f
3e84 3e88 3e8a 3e96 3e98 3e9c 3ea0 3ea3
3ea7 3ea8 3ead 3eb1 3eb5 3eb9 3ebd 3ec1
3ec5 3ec9 3ecd 3ed1 3ed5 3ed9 3edd 3ee1
3ee5 3ee9 3eed 3ef1 3ef5 3ef9 3efd 3f01
3f05 3f09 3f0d 3f11 3f15 3f19 3f1d 3f21
3f25 3f29 3f2d 3f31 3f35 3f39 3f3d 3f41
3f45 3f49 3f4d 3f51 3f55 3f59 3f5d 3f61
3f65 3f69 3f6d 3f71 3f75 3f79 3f7d 3f81
3f85 3f91 3f95 3f9a 3f9e 3fa1 3fa2 3fa7
3fab 3faf 3fb2 3fb5 3fb9 3fbb 3fbf 3fc3
3fc6 3fc9 3fcd 3fcf 3fd3 3fd7 3fda 3fdc
1 3fe0 3fe4 3fe8 3feb 3fef 3ff3 3ff7
3ffb 3ffe 4002 4006 4009 400c 4011 4014
4017 401a 401b 4020 4021 1 4023 4028
402c 4030 4033 4038 403d 4040 4044 4045
404a 404d 4052 4053 4058 405b 4060 4061
4066 4069 406d 406e 4073 4076 407b 407c
4081 4084 4088 408c 408f 4092 4093 4095
4096 409b 409c 40a1 40a3 40a7 40aa 40ac
40b0 40b2 40be 40c0 40c2 40c3 40c8 40cc
40ce 40da 40dc 40e0 40e4 40e8 40ec 40f0
40f4 40f8 40fc 4100 4104 4108 410c 4110
4114 4118 411c 4120 4124 4128 412c 4130
4134 4138 413c 4140 4144 4148 414c 4150
4154 4158 415c 4160 4164 4168 416c 4170
4174 4178 417c 4180 4184 4188 418c 4190
4194 4198 419c 41a0 41a4 41a8 41ac 41b0
41b4 41b8 41bc 41c0 41c4 41c8 41cc 41d0
41d4 41d8 41dc 41e0 41e4 41e8 41ec 41f0
41f4 41f8 41fc 4200 4204 4208 420c 4218
421d 4221 4225 4229 422c 4230 4234 4237
423a 423f 4242 4245 4248 4249 424e 424f
1 4251 4256 425a 425e 4261 4266 426b
426e 4272 4273 4278 4279 427e 4280 4284
4287 428b 428f 4293 4297 4299 429d 42a1
42a5 42a8 42a9 42ab 42ae 42b1 42b2 42b7
42bb 42bf 42c4 42c9 42cd 42d1 42d5 42d8
42db 42df 42e3 42e7 42eb 42ef 42f3 42f7
42fb 42ff 4303 4307 430b 430f 4313 4317
431b 431f 4323 4327 432b 432f 4333 4337
433b 433f 4343 4347 434b 434f 4353 4357
435b 435f 4363 4367 436b 436f 4373 4377
437b 4387 438b 4390 4394 4397 4398 439d
43a1 43a5 43a8 43ab 43af 43b1 43b5 43b9
43bc 43bf 43c3 43c5 43c9 43cd 43d0 43d2
1 43d6 43da 43de 43e1 43e5 43e9 43ed
43f1 43f4 43f8 43fc 43ff 4402 4407 440a
440d 4410 4411 4416 4417 1 4419 441e
4422 4426 4429 442e 4433 4436 443a 443b
4440 4443 4448 4449 444e 4451 4456 4457
445c 445f 4463 4464 4469 446c 4471 4472
4477 447a 447e 4482 4485 4488 4489 448b
448c 4491 4492 4497 4499 449d 44a0 44a2
44a6 44a8 44b4 44b6 44b8 44b9 44be 44c2
44c4 44d0 44d2 44d6 44da 44dd 44e1 44e2
44e7 44eb 44ef 44f3 44f7 44fb 44ff 4503
4507 450b 450f 4513 4517 451b 451f 4523
4527 452b 452f 4533 4537 453b 453f 4543
4547 454b 454f 4553 4557 455b 455f 4563
4567 456b 456f 4573 4577 457b 457f 4583
4587 458b 458f 4593 4597 459b 459f 45a3
45a7 45ab 45af 45b3 45b7 45bb 45bf 45c3
45c7 45cb 45cf 45d3 45d7 45db 45df 45e3
45e7 45eb 45ef 45f3 45f7 45fb 45ff 4603
4607 460b 460f 4613 4617 461b 461f 4623
4627 462b 462f 4633 4637 463b 463f 4643
4647 464b 464f 4653 4657 465b 465f 4663
4667 466b 466f 4673 467f 4683 4688 468c
468f 4690 4695 4699 469d 46a0 46a3 46a7
46a9 46ad 46b1 46b4 46b7 46bb 46bd 46c1
46c5 46c8 46ca 1 46ce 46d2 46d6 46d9
46dd 46e1 46e5 46e9 46ec 46f0 46f4 46f7
46fa 46ff 4702 4705 4708 4709 470e 470f
1 4711 4716 471a 471e 4721 4726 472b
472e 4732 4733 4738 473b 4740 4741 4746
4749 474e 474f 4754 4757 475b 475c 4761
4764 4769 476a 476f 4772 4776 477a 477d
4780 4781 4783 4784 4789 478a 478f 4791
4795 4798 479a 479e 47a0 47ac 47ae 47b0
47b1 47b6 47ba 47bc 47c8 47ca 47ce 47d2
47d6 47da 47de 47e2 47e6 47ea 47ee 47f2
47f6 47fa 47fe 4802 4806 480a 480e 4812
4816 481a 481e 4822 4826 482a 482e 4832
4836 483a 483e 4842 4846 484a 484e 4852
4856 485a 485e 4862 4866 486a 486e 4872
4876 487a 487e 4882 4886 488a 488e 4892
4896 489a 489e 48a2 48a6 48aa 48ae 48b2
48b6 48ba 48be 48c2 48c6 48ca 48ce 48d2
48d6 48da 48de 48e2 48e6 48ea 48ee 48f2
48f6 48fa 48fe 4902 4906 490a 490e 4912
4916 491a 491e 4922 4926 492a 492e 4932
4936 493a 493e 4942 4946 494a 494e 4952
4956 495a 495e 4962 4966 496a 496e 4972
497e 4983 4987 498b 498f 4992 4996 499a
499d 49a0 49a5 49a8 49ab 49ae 49af 49b4
49b5 1 49b7 49bc 49c0 49c4 49c7 49cc
49d1 49d4 49d8 49d9 49de 49df 49e4 49e6
49ea 49ed 49f1 49f5 49f9 49fd 49ff 4a03
4a07 4a0b 4a0e 4a0f 4a11 4a14 4a17 4a18
4a1d 4a21 4a25 4a29 4a2d 4a31 4a35 4a39
4a3d 4a41 4a45 4a49 4a4d 4a51 4a55 4a59
4a5d 4a61 4a65 4a69 4a6d 4a71 4a75 4a79
4a7d 4a81 4a85 4a89 4a8d 4a91 4a95 4a99
4a9d 4aa1 4aa5 4aa9 4aad 4ab1 4ab5 4ab9
4abd 4ac1 4ac5 4ac9 4acd 4ad1 4ad5 4ad9
4add 4ae1 4ae5 4ae9 4aed 4af1 4af5 4af9
4afd 4b01 4b05 4b09 4b0d 4b11 4b15 4b19
4b1d 4b21 4b25 4b29 4b2d 4b31 4b35 4b39
4b3d 4b41 4b45 4b49 4b4d 4b51 4b55 4b59
4b5d 4b61 4b65 4b69 4b6d 4b71 4b75 4b79
4b7d 4b81 4b85 4b89 4b8d 4b91 4b95 4b99
4b9d 4ba1 4ba5 4ba9 4bad 4bb1 4bb5 4bb9
4bbd 4bc1 4bc5 4bc9 4bcd 4bd1 4bd5 4bd9
4bdd 4be1 4be5 4be9 4bed 4bf1 4bf5 4bf9
4bfd 4c01 4c05 4c09 4c0d 4c11 4c15 4c19
4c1d 4c21 4c25 4c29 4c2d 4c31 4c35 4c39
4c3d 4c41 4c45 4c49 4c4d 4c51 4c55 4c59
4c5d 4c61 4c65 4c69 4c6d 4c71 4c75 4c79
4c7d 4c81 4c85 4c89 4c8d 4c91 4c95 4c99
4c9d 4ca1 4ca5 4ca9 4cad 4cb1 4cb5 4cb9
4cbd 4cc1 4cc5 4cc9 4ccd 4cd1 4cd5 4cd9
4cdd 4ce1 4ce5 4ce9 4ced 4cf1 4cf5 4cf9
4cfd 4d01 4d05 4d09 4d0d 4d11 4d15 4d19
4d1d 4d21 4d25 4d29 4d2d 4d31 4d35 4d39
4d3d 4d41 4d45 4d49 4d4d 4d51 4d55 4d59
4d5d 4d61 4d65 4d69 4d6d 4d71 4d75 4d79
4d7d 4d81 4d85 4d89 4d8d 4d91 4d95 4d99
4d9d 4da1 4da5 4db1 4db6 4dba 4dbe 4dc2
4dc5 4dc9 4dcd 4dd0 4dd3 4dd8 4ddb 4dde
4de1 4de2 4de7 4de8 1 4dea 4def 4df3
4df7 4dfa 4dff 4e04 4e07 4e0b 4e0c 4e11
4e12 4e17 4e19 4e1d 4e20 4e24 4e28 4e2c
4e30 4e32 4e36 4e3a 4e3e 4e41 4e42 4e44
4e47 4e4a 4e4b 4e50 4e54 4e58 4e5d 4e62
4e66 4e6a 4e6e 4e71 4e74 4e78 4e7c 4e80
4e84 4e88 4e8c 4e90 4e94 4e98 4e9c 4ea0
4ea4 4ea8 4eac 4eb0 4eb4 4eb8 4ebc 4ec0
4ec4 4ec8 4ecc 4ed0 4ed4 4ed8 4edc 4ee0
4ee4 4ee8 4eec 4ef0 4ef4 4ef8 4efc 4f00
4f04 4f08 4f0c 4f10 4f14 4f18 4f1c 4f20
4f24 4f28 4f2c 4f30 4f34 4f40 4f44 4f49
4f4d 4f50 4f51 4f56 4f5a 4f5e 4f61 4f64
4f68 4f6a 4f6e 4f72 4f75 4f78 4f7c 4f7e
4f82 4f86 4f89 4f8b 1 4f8f 4f93 4f97
4f9a 4f9e 4fa2 4fa6 4faa 4fad 4fb1 4fb5
4fb8 4fbb 4fc0 4fc3 4fc6 4fc9 4fca 4fcf
4fd0 1 4fd2 4fd7 4fdb 4fdf 4fe2 4fe7
4fec 4fef 4ff3 4ff4 4ff9 4ffc 5001 5002
5007 500a 500f 5010 5015 5018 501c 501d
5022 5025 502a 502b 5030 5033 5037 503b
503e 5041 5042 5044 5045 504a 504b 5050
5052 5056 5059 505b 505f 5061 506d 506f
5071 5072 5077 507b 507d 5089 508b 508f
5093 5098 509d 50a1 50a5 50a9 50ac 50af
50b3 50b7 50bb 50bf 50c3 50c7 50cb 50cf
50d3 50d7 50db 50df 50e3 50e7 50eb 50ef
50f3 50f7 50fb 50ff 5103 5107 510b 510f
5113 5117 511b 511f 5123 5127 512b 512f
5133 5137 513b 513f 5143 5147 514b 514f
5153 5157 515b 515f 5163 5167 516b 516f
5173 5177 517b 517f 5183 5187 518b 518f
5193 5197 519b 519f 51a3 51a7 51ab 51af
51b3 51b7 51bb 51bf 51c3 51c7 51cb 51cf
51d3 51d7 51db 51df 51e3 51e7 51eb 51ef
51f3 51f7 51fb 51ff 5203 5207 520b 520f
5213 5217 521b 521f 5223 5227 522b 522f
5233 5237 523b 523f 5243 5247 524b 524f
5253 5257 525b 525f 5263 5267 526b 526f
5273 5277 5283 5287 528c 5290 5293 5294
5299 529d 52a1 52a4 52a7 52ab 52ad 52b1
52b5 52b8 52bb 52bf 52c1 52c5 52c9 52cc
52ce 1 52d2 52d6 52da 52dd 52e1 52e5
52e9 52ed 52f0 52f4 52f8 52fb 52fe 5303
5306 5309 530c 530d 5312 5313 1 5315
531a 531e 5322 5325 532a 532f 5332 5336
5337 533c 533f 5344 5345 534a 534d 5352
5353 5358 535b 535f 5360 5365 5368 536d
536e 5373 5376 537a 537e 5381 5384 5385
5387 5388 538d 538e 5393 5395 5399 539c
539e 53a2 53a4 53b0 53b2 53b4 53b5 53ba
53be 53c0 53cc 53ce 53d2 53d6 53da 53de
53e2 53e6 53ea 53ee 53f2 53f6 53fa 53fe
5402 5406 540a 540e 541a 541e 5423 5427
542a 542b 5430 5434 5438 543b 543e 5442
5444 5448 544c 544f 5452 5456 5458 545c
5460 5463 5465 1 5469 546d 5471 5474
5478 547c 5480 5484 5487 548b 548f 5492
5495 549a 549d 54a0 54a3 54a4 54a9 54aa
1 54ac 54b1 54b5 54b9 54bc 54c1 54c6
54c9 54cd 54ce 54d3 54d6 54db 54dc 54e1
54e4 54e9 54ea 54ef 54f2 54f6 54f7 54fc
54ff 5504 5505 550a 550d 5511 5515 5518
551b 551c 551e 551f 5524 5525 552a 552c
5530 5533 5535 5539 553b 5547 5549 554b
554c 5551 5555 5557 5563 5565 5569 556d
5571 5575 5579 557d 5581 5585 5589 558d
5591 5595 5599 559d 55a1 55a5 55a9 55ad
55b1 55b5 55b9 55bd 55c1 55c5 55c9 55cd
55d1 55d5 55d9 55dd 55e1 55e5 55e9 55ed
55f1 55f5 55f9 55fd 5601 5605 5609 560d
5611 5615 5619 561d 5621 5625 5629 562d
5631 5635 5639 563d 5641 5645 5649 564d
5651 5655 5659 565d 5661 5665 5669 566d
5671 5675 5679 567d 5681 5685 5689 568d
5691 5695 5699 569d 56a1 56a5 56a9 56ad
56b1 56b5 56b9 56bd 56c1 56c5 56c9 56cd
56d1 56d5 56d9 56dd 56e1 56e5 56e9 56ed
56f1 56f5 56f9 56fd 5701 5705 5709 570d
5711 5715 5719 571d 5721 5725 5729 572d
5731 5735 5739 573d 5741 5745 5749 574d
5751 5755 5759 575d 5761 5765 5769 576d
5771 5775 5779 577d 5781 5785 5789 578d
5791 5795 5799 579d 57a1 57a5 57a9 57ad
57b1 57b5 57b9 57bd 57c1 57c5 57c9 57cd
57d1 57d5 57d9 57dd 57e1 57e5 57e9 57ed
57f1 57f5 57f9 57fd 5801 5805 5809 580d
5811 5815 5819 581d 5821 5825 5829 582d
5831 5835 5839 583d 5841 5845 5849 584d
5851 5855 5859 585d 5861 5865 5869 586d
5871 5875 5879 587d 5881 5885 5889 588d
5891 5895 5899 589d 58a1 58a5 58a9 58ad
58b1 58b5 58b9 58c5 58ca 58ce 58d2 58d6
58d9 58dd 58e1 58e4 58e7 58ec 58ef 58f2
58f5 58f6 58fb 58fc 1 58fe 5903 5907
590b 590e 5913 5918 591b 591f 5920 5925
5926 592b 592d 5931 5934 5938 593c 5940
5944 5946 594a 594e 5952 5955 5956 5958
595c 595f 5963 5966 5967 596c 5970 5974
5978 597c 5980 598c 5990 5994 5997 599b
599f 59a1 1 59a5 59a9 59ad 59b0 59b4
59b8 59bc 59c0 59c3 59c7 59cb 59ce 59d1
59d6 59d9 59dc 59df 59e0 59e5 59e6 1
59e8 59ed 59f1 59f5 59f8 59fd 5a02 5a05
5a09 5a0a 5a0f 5a12 5a17 5a18 5a1d 5a20
5a25 5a26 5a2b 5a2e 5a32 5a33 5a38 5a3b
5a40 5a41 5a46 5a49 5a4d 5a51 5a54 5a57
5a58 5a5a 5a5b 5a60 5a61 5a66 5a68 5a6c
5a6f 5a71 5a75 5a77 5a83 5a85 5a87 5a88
5a8d 5a91 5a93 5a9f 5aa1 5aa5 5aa9 5aac
5ab0 5ab3 5ab7 5aba 5abb 5ac0 5ac3 5ac7
5acb 5acf 5ad3 5ad7 5adb 5adf 5ae3 5ae7
5aeb 5aef 5af3 5af7 5afb 5aff 5b03 5b07
5b0b 5b0f 5b13 5b17 5b1b 5b1f 5b23 5b27
5b2b 5b2f 5b33 5b37 5b3b 5b3f 5b43 5b47
5b4b 5b4f 5b53 5b57 5b5b 5b5f 5b63 5b67
5b6b 5b6f 5b73 5b77 5b7b 5b7f 5b83 5b87
5b8b 5b8f 5b93 5b97 5b9b 5b9f 5ba3 5ba7
5bab 5baf 5bb3 5bb7 5bbb 5bbf 5bc3 5bc7
5bcb 5bcf 5bd3 5bd7 5bdb 5bdf 5be3 5be7
5beb 5bef 5bf3 5bf7 5bfb 5bff 5c03 5c07
5c0b 5c0f 5c13 5c17 5c1b 5c1f 5c23 5c27
5c2b 5c2f 5c33 5c37 5c3b 5c3f 5c43 5c47
5c4b 5c4f 5c53 5c57 5c5b 5c5f 5c63 5c67
5c6b 5c6f 5c73 5c77 5c7b 5c7f 5c83 5c87
5c8b 5c8f 5c93 5c97 5c9b 5c9f 5ca3 5ca7
5cab 5caf 5cb3 5cb7 5cbb 5cbf 5cc3 5cc7
5ccb 5ccf 5cd3 5cd7 5cdb 5cdf 5ce3 5ce7
5ceb 5cef 5cf3 5cf7 5cfb 5cff 5d03 5d07
5d0b 5d0f 5d13 5d17 5d1b 5d1f 5d23 5d27
5d2b 5d37 5d3c 5d40 5d44 5d48 5d4b 5d4f
5d53 5d56 5d59 5d5e 5d61 5d64 5d67 5d68
5d6d 5d6e 1 5d70 5d75 5d79 5d7d 5d80
5d85 5d8a 5d8d 5d91 5d92 5d97 5d98 5d9d
5d9f 5da3 5da6 5daa 5dae 5db2 5db4 5db8
5dbb 5dbf 5dc1 5dc5 5dc9 5dcd 5dd0 5dd1
5dd3 5dd6 5dd9 5dda 5ddf 5de3 5de7 5deb
5def 5df3 5df7 5dfb 5dff 5e03 5e07 5e0b
5e0f 5e13 5e17 5e1b 5e1f 5e23 5e27 5e2b
5e2f 5e33 5e37 5e3b 5e3f 5e43 5e47 5e4b
5e4f 5e53 5e57 5e5b 5e5f 5e63 5e67 5e6b
5e6f 5e73 5e77 5e7b 5e7f 5e83 5e87 5e8b
5e8f 5e93 5e97 5e9b 5e9f 5ea3 5ea7 5eab
5eaf 5eb3 5eb7 5ebb 5ebf 5ec3 5ec7 5ecb
5ecf 5ed3 5ed7 5edb 5edf 5ee3 5ee7 5eeb
5eef 5ef3 5ef7 5efb 5eff 5f03 5f07 5f0b
5f0f 5f13 5f17 5f1b 5f1f 5f23 5f27 5f2b
5f2f 5f33 5f37 5f3b 5f3f 5f43 5f47 5f4b
5f4f 5f53 5f57 5f5b 5f5f 5f63 5f67 5f6b
5f6f 5f73 5f77 5f7b 5f7f 5f83 5f87 5f8b
5f8f 5f93 5f97 5f9b 5f9f 5fa3 5fa7 5fab
5faf 5fb3 5fb7 5fbb 5fbf 5fc3 5fc7 5fcb
5fcf 5fd3 5fd7 5fdb 5fdf 5fe3 5fe7 5feb
5fef 5ff3 5ff7 5ffb 5fff 6003 6007 600b
600f 6013 6017 601b 601f 6023 6027 602b
602f 6033 6037 603b 603f 6043 6047 604b
604f 6053 6057 605b 605f 6063 6067 606b
606f 6073 6077 607b 607f 6083 6087 608b
608f 6093 6097 609b 609f 60a3 60a7 60ab
60af 60b3 60b7 60bb 60bf 60c3 60c7 60cb
60cf 60d3 60d7 60db 60df 60e3 60e7 60eb
60ef 60f3 60f7 60fb 60ff 6103 6107 610b
610f 6113 6117 611b 611f 6123 6127 612b
612f 6133 6137 613b 613f 6143 6147 614b
614f 6153 6157 615b 615f 6163 6167 616b
616f 6173 6177 617b 617f 6183 6187 618b
618f 6193 6197 619b 619f 61a3 61a7 61ab
61af 61b3 61b7 61bb 61bf 61c3 61c7 61cb
61cf 61d3 61d7 61db 61df 61e3 61e7 61eb
61ef 61f3 61f7 61fb 61ff 6203 6207 620b
620f 6213 6217 621b 621f 6223 6227 622b
622f 6233 6237 623b 623f 6243 6247 624b
624f 6253 6257 625b 625f 6263 6267 626b
626f 6273 6277 627b 627f 6283 6287 628b
628f 6293 6297 629b 629f 62a3 62a7 62ab
62af 62b3 62b7 62bb 62bf 62c3 62c7 62cb
62cf 62d3 62d7 62e3 62e8 62ec 62f0 62f4
62f7 62fb 62ff 6302 6305 630a 630d 6310
6313 6314 6319 631a 1 631c 6321 6325
6329 632c 6331 6336 6339 633d 633e 6343
6344 6349 634b 634f 6352 6356 635a 635e
6362 6364 6368 636c 6370 6373 6374 6376
6379 637c 637d 6382 6386 638a 638e 6392
6396 639a 639e 63a2 63a6 63aa 63ae 63b2
63b6 63ba 63be 63c2 63c6 63ca 63ce 63d2
63d6 63da 63de 63e2 63e6 63ea 63ee 63f2
63f6 63fa 63fe 6402 6406 640a 640e 6412
6416 641a 641e 6422 6426 642a 642e 6432
6436 643a 643e 6442 6446 644a 644e 6452
6456 645a 645e 6462 6466 646a 646e 6472
6476 647a 647e 6482 6486 648a 648e 6492
6496 649a 649e 64a2 64a6 64aa 64ae 64b2
64b6 64ba 64be 64c2 64c6 64ca 64ce 64d2
64d6 64da 64de 64e2 64e6 64ea 64ee 64f2
64f6 64fa 64fe 6502 6506 650a 650e 6512
6516 651a 651e 6522 6526 652a 652e 6532
6536 653a 653e 6542 6546 654a 654e 6552
6556 655a 655e 6562 6566 656a 656e 6572
6576 657a 657e 6582 6586 658a 658e 6592
6596 659a 659e 65a2 65a6 65aa 65ae 65b2
65b6 65ba 65be 65c2 65c6 65ca 65ce 65d2
65de 65e3 65e7 65eb 65ef 65f2 65f6 65fa
65fd 6600 6605 6608 660b 660e 660f 6614
6615 1 6617 661c 6620 6624 6627 662c
6631 6634 6638 6639 663e 663f 6644 6646
664a 664d 6651 6655 6659 665d 665f 6663
6667 666b 666e 666f 6671 6674 6677 6678
667d 6681 6685 668a 668f 6693 6697 669b
669e 66a1 66a5 66a9 66ad 66b1 66b5 66b9
66bd 66c1 66c5 66c9 66cd 66d1 66d5 66d9
66dd 66e1 66e5 66f1 66f5 66fa 66fe 6701
6702 6707 670b 670f 6712 6715 6719 671b
671f 6723 6726 6729 672d 672f 6733 6737
673a 673c 1 6740 6744 6748 674b 674f
6753 6757 675b 675e 6762 6766 6769 676c
6771 6774 6777 677a 677b 6780 6781 1
6783 6788 678c 6790 6793 6798 679d 67a0
67a4 67a5 67aa 67ad 67b2 67b3 67b8 67bb
67c0 67c1 67c6 67c9 67cd 67ce 67d3 67d6
67db 67dc 67e1 67e4 67e8 67ec 67ef 67f2
67f3 67f5 67f6 67fb 67fc 6801 6803 6807
680a 680c 6810 6812 681e 6820 6822 6823
6828 682c 682e 683a 683c 6840 6844 6849
684e 6852 6856 685a 685d 6860 6864 6868
686c 6870 6874 6878 687c 6880 6884 6888
688c 6890 6894 6898 689c 68a8 68ac 68b1
68b5 68b8 68b9 68be 68c2 68c6 68c9 68cc
68d0 68d2 68d6 68da 68dd 68e0 68e4 68e6
68ea 68ee 68f1 68f3 1 68f7 68fb 68ff
6902 6906 690a 690e 6912 6915 6919 691d
6920 6923 6928 692b 692e 6931 6932 6937
6938 1 693a 693f 6943 6947 694a 694f
6954 6957 695b 695c 6961 6964 6969 696a
696f 6972 6977 6978 697d 6980 6984 6985
698a 698d 6992 6993 6998 699b 699f 69a3
69a6 69a9 69aa 69ac 69ad 69b2 69b3 69b8
69ba 69be 69c1 69c3 69c7 69c9 69d5 69d7
69d9 69da 69df 69e3 69e5 69f1 69f3 69f7
69fb 6a00 6a05 6a09 6a0d 6a11 6a14 6a17
6a1b 6a1f 6a23 6a27 6a2b 6a2f 6a33 6a37
6a3b 6a3f 6a43 6a47 6a4b 6a4f 6a53 6a57
6a5b 6a5f 6a63 6a67 6a6b 6a6f 6a73 6a77
6a7b 6a7f 6a83 6a87 6a8b 6a8f 6a93 6a97
6a9b 6a9f 6aa3 6aa7 6aab 6aaf 6ab3 6abf
6ac3 6ac8 6acc 6acf 6ad0 6ad5 6ad9 6add
6ae0 6ae3 6ae7 6ae9 6aed 6af1 6af4 6af7
6afb 6afd 6b01 6b05 6b08 6b0a 1 6b0e
6b12 6b16 6b19 6b1d 6b21 6b25 6b29 6b2c
6b30 6b34 6b37 6b3a 6b3f 6b42 6b45 6b48
6b49 6b4e 6b4f 1 6b51 6b56 6b5a 6b5e
6b61 6b66 6b6b 6b6e 6b72 6b73 6b78 6b7b
6b80 6b81 6b86 6b89 6b8e 6b8f 6b94 6b97
6b9b 6b9c 6ba1 6ba4 6ba9 6baa 6baf 6bb2
6bb6 6bba 6bbd 6bc0 6bc1 6bc3 6bc4 6bc9
6bca 6bcf 6bd1 6bd5 6bd8 6bda 6bde 6be0
6bec 6bee 6bf0 6bf1 6bf6 6bfa 6bfc 6c08
6c0a 6c0e 6c12 6c16 6c1a 6c1e 6c22 6c26
6c2a 6c2e 6c32 6c36 6c3a 6c3e 6c42 6c46
6c4a 6c4e 6c52 6c56 6c5a 6c5e 6c62 6c66
6c6a 6c6e 6c72 6c76 6c7a 6c7e 6c82 6c86
6c8a 6c8e 6c92 6c96 6c9a 6c9e 6ca2 6ca6
6caa 6cae 6cb2 6cb6 6cba 6cbe 6cc2 6cc6
6cca 6cce 6cd2 6cd6 6cda 6cde 6ce2 6ce6
6cea 6cee 6cf2 6cf6 6cfa 6cfe 6d02 6d06
6d0a 6d0e 6d12 6d16 6d1a 6d1e 6d22 6d26
6d2a 6d2e 6d32 6d36 6d3a 6d3e 6d42 6d46
6d4a 6d4e 6d52 6d56 6d5a 6d5e 6d62 6d66
6d6a 6d6e 6d72 6d76 6d7a 6d7e 6d82 6d86
6d8a 6d8e 6d92 6d96 6d9a 6d9e 6da2 6da6
6daa 6dae 6db2 6db6 6dba 6dc6 6dcb 6dcf
6dd3 6dd7 6dda 6dde 6de2 6de5 6de8 6ded
6df0 6df3 6df6 6df7 6dfc 6dfd 1 6dff
6e04 6e08 6e0c 6e0f 6e14 6e19 6e1c 6e20
6e21 6e26 6e27 6e2c 6e2e 6e32 6e35 6e39
6e3d 6e41 6e45 6e47 6e4b 6e4f 6e53 6e56
6e57 6e59 6e5c 6e5f 6e60 6e65 6e69 6e6d
6e71 6e75 6e79 6e7d 6e81 6e85 6e89 6e8d
6e91 6e95 6e99 6e9d 6ea1 6ea5 6ea9 6ead
6eb1 6eb5 6eb9 6ebd 6ec1 6ec5 6ec9 6ecd
6ed9 6ede 6ee2 6ee6 6eea 6eed 6ef1 6ef5
6ef8 6efb 6f00 6f03 6f06 6f09 6f0a 6f0f
6f10 1 6f12 6f17 6f1b 6f1f 6f22 6f27
6f2c 6f2f 6f33 6f34 6f39 6f3a 6f3f 6f41
6f45 6f48 6f4c 6f50 6f54 6f58 6f5a 6f5e
6f62 6f66 6f69 6f6a 6f6c 6f70 6f73 6f77
6f7a 6f7b 6f80 6f83 6f87 6f8b 6f8e 6f8f
6f91 6f95 6f98 6f9c 6f9f 6fa0 6fa5 1
6fa8 6fad 6fb1 6fb5 6fb9 6fbd 6fc1 6fc5
6fc9 6fcd 6fd1 6fd5 6fd9 6fdd 6fe1 6fe5
6fe9 6fed 6ff1 6ff5 6ff9 6ffd 7001 7005
7009 700d 7011 7015 7021 7026 702a 702e
7032 7035 7039 703d 7040 7043 7048 704b
704e 7051 7052 7057 7058 1 705a 705f
7063 7067 706a 706f 7074 7077 707b 707c
7081 7082 7087 7089 708d 7090 7094 7098
709c 709e 70a2 70a6 70aa 70ad 70b1 70b5
70b8 70bb 70c0 70c3 70c6 70c9 70ca 70cf
70d0 1 70d2 70d7 70db 70df 70e2 70e7
70ec 70ef 70f3 70f4 70f9 70fc 7101 7102
7107 710a 710f 7110 7115 7118 711c 7120
7124 7128 712b 712c 712e 7133 7134 7136
7137 713c 713f 7144 7145 714a 714d 7152
7153 7158 715b 715f 7160 7165 7168 716d
716e 7173 7174 7179 717b 717f 7182 7186
718a 718d 7191 7195 7198 719c 71a0 71a1
71a6 71a8 71ac 71b0 71b3 71b5 71b9 71bd
71c0 71c4 71c8 71cb 71cf 71d3 71d6 71d9
71de 71e1 71e4 71e7 71e8 71ed 71ee 1
71f0 71f5 71f9 71fd 7200 7205 720a 720d
7211 7212 7217 7218 721d 7221 7225 7228
722d 7232 7235 7239 723d 7240 7241 7246
7249 724e 724f 7254 7257 725b 725f 7262
7263 7268 7269 726e 7270 7274 7277 727b
727f 7283 7287 728b 728f 7293 7297 729b
72a7 72ac 72b0 72b4 72b8 72bc 72be 72bf
72c4 1 72c8 72cc 72d0 72d3 72d7 72db
72df 72e3 72e6 72ea 72ee 72f1 72f4 72f9
72fc 72ff 7302 7303 7308 7309 1 730b
7310 7314 7318 731b 7320 7325 7328 732c
732d 7332 7333 7338 733c 7340 7343 7348
734d 7350 7354 7355 735a 735d 7362 7363
7368 736b 736f 7373 7376 7379 737a 737c
737d 7382 7383 7388 738a 738e 7391 7395
7399 739d 73a1 73a5 73a9 73ad 73b9 73be
73c2 73c6 73ca 73ce 73d0 73d4 73d6 73e2
73e4 73e6 73e7 73ec 73f0 73f2 73fe 7402
7404 7405 740e 
1f2b
2
0 1 a 6 9 :3 6 11 :3 6
10 :2 6 1 3 a 13 a :2 1
4 b 14 13 :2 b :2 4 9 12
11 :2 9 :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 9 12 11
:2 9 :2 4 f 18 17 :2 f :2 4 :2 e
1d e :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 c 1b c :2 4 :2 14
23 14 :2 4 :2 12 21 12 4 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 f 18 :3 f :2 7
13 1c :3 13 7 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 54 5a
5d :2 54 6b 81 8 :2 6b d 10
:2 6b 13 16 :2 6b b e :2 6b 13
16 1f 27 :2 1f 34 :2 16 :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
28 2b :2 6b 30 33 :2 6b :2 7 4a
:2 4 7 :2 11 23 :2 2d 39 3c 4c
4e 4f :2 4c :2 23 :3 7 :2 d 12 1e
5d 60 :2 1e :2 7 52 :2 4 :4 8 7
a :2 14 26 :2 30 3c 40 50 52
53 :2 50 :2 26 :3 a :2 10 15 21 60
63 :2 21 70 73 :2 21 77 7a :2 21
84 87 90 98 :2 a1 :2 90 b2 :2 87
:2 21 ba bd :2 21 c5 c8 :2 21 cd
d0 :2 21 d3 d6 :2 21 :2 a 56 :2 7
a :2 14 26 :2 30 3c 3f 4f 51
52 :2 4f :2 26 :3 a :2 10 15 21 60
63 :2 21 :2 a 55 :3 7 :2 12 26 :2 2f
3f 43 :2 7 14 :3 4 c :2 4 11
:2 4 12 4 8 11 1c :2 8 1f
21 :2 1f 7 28 31 3c :2 28 3f
41 :2 3f 27 :2 7 11 13 1f 21
2a 33 35 4b 4d f 1d 28
33 f 17 1a 22 2a 2c 39
42 44 51 53 :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 67 6a :2 27
77 7a :2 27 7e 81 :2 27 8d 90
:2 27 98 9b :2 27 a7 aa b1 ba
bd :2 aa :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 44 b :2 14 1f 1d :2 28
:2 1d a 14 16 22 24 2d 36
38 12 20 2b 12 1a 1d 25
2d 2f 3c 45 47 54 56 :2 d
:2 16 22 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 59
5c 5d :2 59 :2 2f :3 13 :2 19 1e 2a
6a 6d :2 2a 7a 7d :2 2a 81 84
:2 2a 90 93 :2 2a 9b 9e :2 2a aa
ad b4 bd c0 :2 ad :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 38 e :2 17
22 20 :2 2b :2 20 d 20 2f 3f
4c :2 10 :2 19 25 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5c 5f 60 :2 5c :2 32 :3 16 :2 1c
21 2d 6d 70 :2 2d 7d 80 :2 2d
84 87 :2 2d 93 96 :2 2d 9e a1
:2 2d ad b0 b7 c0 c3 :2 b0 :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :3 3b
11 :2 1a 25 23 :2 2e :2 23 10 13
:2 1d 2f :2 39 45 49 59 5c 5d
:2 59 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 8e
91 9a a2 :2 ab :2 9a bc :2 91 :2 2a
c4 c7 :2 2a cf d2 :2 2a d7 da
:2 2a df e2 :2 2a :2 13 60 :2 10 13
:2 1d 2f :2 39 45 48 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a :2 13 5f :3 10 :2 1b 2f :2 38 48
4e :2 10 3e :2 d 3b :2 a 38 :2 7
4 44 a 13 1e :2 a 21 23
:2 21 11 21 f 26 3a :2 a :2 13
1f a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 26 b :2 14 1f
1d :2 28 :2 1d a d :2 17 29 :2 33
3f 43 53 56 57 :2 53 :2 29 :3 d
:2 13 18 24 64 67 :2 24 74 77
:2 24 7b 7e :2 24 88 8b 94 9c
:2 a5 :2 94 b6 :2 8b :2 24 be c1 :2 24
c9 cc :2 24 d1 d4 :2 24 d7 da
:2 24 :2 d 5a :2 a d :2 17 29 :2 33
3f 42 52 55 56 :2 52 :2 29 :3 d
:2 13 18 24 64 67 :2 24 :2 d 59
:3 a :2 15 29 :2 32 42 46 :2 a 38
:2 7 11 1a 30 41 4c f 1d
2a :2 a :2 13 1f a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8d 90 :2 27 98 9b
:2 27 a7 aa b1 ba bd :2 aa :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 26
4 26 44 a 13 1e :2 a 21
23 :2 21 11 1b 27 37 44 :2 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
67 6a :2 27 77 7a :2 27 7e 81
:2 27 8d 90 :2 27 98 9b :2 27 a7
aa b1 ba bd :2 aa :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 26 b :2 14
1f 1d :2 28 :2 1d a d :2 17 29
:2 33 3f 43 53 56 57 :2 53 :2 29
:3 d :2 13 18 24 64 67 :2 24 74
77 :2 24 7b 7e :2 24 88 8b 94
9c :2 a5 :2 94 b6 :2 8b :2 24 be c1
:2 24 c9 cc :2 24 d1 d4 :2 24 d7
da :2 24 :2 d 5a :2 a d :2 17 29
:2 33 3f 42 52 55 56 :2 52 :2 29
:3 d :2 13 18 24 64 67 :2 24 :2 d
59 :3 a :2 15 29 :2 32 42 46 :2 a
38 :3 7 14 7 4 26 44 b
14 1f :2 b 25 22 :2 2e :2 22 a
48 51 5c :2 48 5f 62 :2 5f 47
:2 a 16 1f 2a :2 16 30 2d :2 39
:2 2d 15 :2 a 5b 11 1c :2 5b 22
1f :2 2b :2 1f 5a :2 a 11 1a 30
41 4c f 1d 2a :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 67 6a
:2 27 77 7a :2 27 7e 81 :2 27 8d
90 :2 27 98 9b :2 27 a7 aa b1
ba bd :2 aa :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 49 b :2 14 1f 1d
:2 28 :2 1d a d :2 17 29 :2 33 3f
43 53 56 57 :2 53 :2 29 :3 d :2 13
18 24 64 67 :2 24 74 77 :2 24
7b 7e :2 24 88 8b 94 9c :2 a5
:2 94 b6 :2 8b :2 24 be c1 :2 24 c9
cc :2 24 d1 d4 :2 24 d7 da :2 24
:2 d 5a :2 a d :2 17 29 :2 33 3f
42 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 64 67 :2 24 :2 d 59 :3 a
:2 15 29 :2 32 42 46 :2 a 38 :2 7
49 44 :2 4 7 10 1b :2 7 1e
20 :2 1e 7 f 19 :3 7 :2 10 1c
7 16 :8 a c a c a c
a c a c a c a c
f 24 26 2b 3c 41 43 4f
51 10 1d 26 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
67 6a :2 27 77 7a :2 27 7e 81
:2 27 8d 90 :2 27 98 9b :2 27 a7
aa b1 ba bd :2 aa :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 22 7 f
19 :3 7 :2 10 1c 7 16 29 1a
f 10 1d 26 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
67 6a :2 27 77 7a :2 27 7e 81
:2 27 8d 90 :2 27 98 9b :2 27 a7
aa b1 ba bd :2 aa :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 22 7 c
3d 4e 57 5a 65 6e 71 7f
83 a8 7 b 18 1a 27 35
37 43 45 55 57 60 62 72
7 b 21 25 3a 3e 4d 51
67 71 74 81 84 91 94 a1
a4 b8 c9 c 22 26 2b 35
3a 3e 4a 4c 7 c 1d 22
24 2f 33 7 c 1d 22 24
2f 31 7 c 12 17 1d 23
26 2e 32 14 1d 21 2f 3c
3e 4e 61 73 7 9 12 14
24 7 9 1f 21 35 37 45
47 5d 7 a 17 1a 27 2a
37 3a 4d 5e c 1e 23 28
31 36 3a 45 47 7 c 12
17 28 2d 2f 37 39 7 c
12 17 28 2d 2f 3a 3c 7
c 12 17 1d 23 26 2e 30
14 1d 21 2f 3b 3d 4d 5f
70 7 9 12 14 24 7 9
1f 21 36 38 47 49 5f 7
a 17 1a 27 2a 37 3a 4e
5f c 1e 22 27 30 35 39
44 46 7 c 23 28 2a 35
37 7 c 12 17 28 2d 2f
38 3a 7 c 12 17 28 2d
2f 3a 3c 7 c 12 17 1d
23 26 2e 30 14 1d 21 2f
3b 3d 4d 5f 70 7 9 12
14 24 7 9 1f 21 36 38
47 49 5f 7 a 17 1a 27
2a 37 3a 4e 5f c 1e 22
27 30 35 39 44 46 7 c
22 27 29 34 36 7 c 12
17 28 2d 2f 37 39 7 c
12 17 28 2d 2f 3a 3c 7
c 12 17 1d 23 26 2e 30
10 1a 27 17 7 17 a :2 14
26 :2 30 3c 3f 4f 52 53 :2 4f
:2 26 :3 a :2 10 15 21 61 64 :2 21
:2 a 56 :3 7 e 7 4 22 b
14 1f :2 b 22 24 :2 22 a 2b
34 3f :2 2b 42 44 :2 42 2a :2 a
7 f 19 :3 7 :2 10 1c 7 16
28 35 a d 14 17 49 f
24 27 2c 32 37 48 4e 51
5c 65 68 76 79 10 13 1e
27 2a 40 43 23 34 3c 3f
4d 4f 5f 61 69 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 77 7a :2 27 7e
81 :2 27 8d 90 :2 27 98 9b :2 27
a7 aa b1 ba bd :2 aa :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 47 7
:2 10 :3 1c 7 16 2a 35 1a 1c
28 2a f 24 26 2b 34 39
3b 51 53 5e 60 a f 20
25 27 32 34 a f 20 25
27 32 34 a f 20 25 27
39 3b 51 53 10 12 1d 26
28 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 67 6a :2 27
77 7a :2 27 7e 81 :2 27 8d 90
:2 27 98 9b :2 27 a7 aa b1 ba
bd :2 aa :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 47 7 c 1e 20 2f
40 53 55 62 6f 71 79 7b
7 2e 3d 64 78 7 2e 3a
61 73 7e 8d 94 a1 b6 c7
c 1b 2e 49 5e 6f c 1d
1f 24 2e 33 35 41 43 e
1f 32 45 53 7 2e 3d 64
78 7 2e 3a 61 73 7e 8d
94 a1 d 1f 30 3f 52 6d
82 93 c 10 17 7 17 a
:2 14 26 :2 30 3c 3f 4f 52 53
:2 4f :2 26 :3 a :2 10 15 21 61 64
:2 21 :2 a 56 :3 7 e 7 4 47
22 a 13 1e :2 a 21 23 :2 21
7 c 28 2a 4d 4f 66 68
81 7 9 15 17 27 3a 42
44 57 59 66 68 76 78 7
9 16 18 21 23 2d 3a 4a
4c 5b 5d 6a 6c 7c 7 10
12 22 24 34 45 48 58 6b
6d 7a 7c 89 8b 98 9a ad
bb bd c8 ca 7 9 1f 21
2e 31 41 4c 4e 56 58 62
64 6c 6e 79 7b 89 8b 99
7 9 c 21 23 28 2e 33
44 49 4b 55 5e 60 74 76
7 c 12 17 20 25 27 35
37 42 47 4d 52 66 6b 6d
79 7b 7 c 12 17 2b 31
3a 3c 4c 4e 5b 5e 7 c
12 17 25 2b 2e 3a 3c d
f 1c 25 27 42 17 7 17
a :2 14 26 :2 30 3c 3f 4f 52
53 :2 4f :2 26 :3 a :2 10 15 21 61
64 :2 21 :2 a 56 :3 7 e 7 4
25 22 a 13 1e :2 a 21 23
:2 21 a 11 1a 25 :2 11 :2 a 29
2c :2 29 a 15 a 14 22 2f
46 53 64 6e :2 d :2 16 22 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 59 5c 5d :2 59
:2 2f :3 13 :2 19 1e 2a 6a 6d :2 2a
7a 7d :2 2a 81 84 :2 2a 90 93
:2 2a 9b 9e :2 2a aa ad b4 bd
c0 :2 ad :2 2a :2 13 60 :2 10 :2 d :4 19
:2 d a :3 2e d 16 1f :2 d 22
24 :2 22 d 1b d 26 17 27
34 20 37 44 55 5f 68 :2 10
:2 19 25 10 d :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5c
5f 60 :2 5c :2 32 :3 16 :2 1c 21 2d
6d 70 :2 2d 7d 80 :2 2d 84 87
:2 2d 93 96 :2 2d 9e a1 :2 2d ad
b0 b7 c0 c3 :2 b0 :2 2d :2 16 63
:2 13 :2 10 :4 1c :2 10 d :3 a 10 19
22 :2 10 25 27 :2 25 1a 2a 37
23 34 37 3c 56 16 1a 27
2a 39 3d 4b 4e 19 1c 29
3a 3d 47 14 1c 23 26 49
4d :2 13 :2 1c 28 13 10 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5f 62 63 :2 5f :2 35 :3 19 :2 1f
24 30 70 73 :2 30 80 83 :2 30
87 8a :2 30 96 99 :2 30 a1 a4
:2 30 b0 b3 ba c3 c6 :2 b3 :2 30
:2 19 66 :2 16 :2 13 :4 1f :2 13 10 :3 29
13 1c 25 :2 13 28 2a :2 28 13
21 13 2c 13 21 13 :4 10 29
10 1e 10 :4 d :5 a f 21 23
2f 31 3e 40 4e 50 5f 72
74 81 83 8c 8e a c 10
12 16 18 24 33 35 42 a
c 1b 1d 2f 3d 3f 4e 50
61 63 72 c 1b 1d 14 16
32 39 43 45 52 5c 5e 6d
6f 8e a 31 3e 65 78 a
c 1b 1d 2d 2f 34 36 43
45 a c 1b 22 24 34 36
47 49 5c a 17 2c 41 54
10 27 42 57 6c 81 10 1e
20 31 3f 41 51 53 64 66
7a 10 2c 40 55 62 71 7e
8e a1 b4 c3 f 21 2f 3e
4f 51 5f 61 78 14 2b 2d
3e 69 14 2b 2d 3f 6a 14
2b 2d 4a 58 5a 6a 81 90
10 28 42 5d 7b 10 23 f
17 19 1e 23 38 3d 3f 4c
4e 5d 5f 6d a f 15 1a
2e 33 35 41 43 10 12 1f
30 32 3f 1b 1d 40 42 59
5b 74 80 82 14 16 35 37
49 52 5a 5c 6a 6c 17 19
28 32 3a 3c 4a 4c 60 14
16 3e 40 69 a c 1f 21
2e 30 3a 3c 51 14 16 1b
24 2e 30 35 3e 49 52 5d
5f 69 77 79 7e 87 92 9b
a6 a8 b2 b6 b8 cc db dd
f2 14 28 38 4c 14 28 35
46 5a 14 16 25 27 36 38
4a 4c 5d f 14 16 32 39
43 45 52 5c 69 84 a c
19 1b 29 2b a c 1b 1d
2d 2f 34 36 43 45 a c
1b 22 32 43 a 17 27 29
38 3a 47 49 59 a 13 15
25 27 37 48 4b 5b 6e 70
7d 7f 8c 8e 9b 9d 14 16
35 37 4a 54 5c 5e 6c 6e
19 27 29 34 36 44 46 56
58 69 6b a c 22 24 32
35 45 55 57 5f 61 6b 6d
75 77 82 84 92 94 a2 a4
ae b0 a c 28 2a 48 4a
72 7c 7e 94 a2 a4 bb 14
2b 34 36 42 44 5b 86 14
2b 34 36 43 45 5d 88 14
35 37 4d 4f 58 5a 79 87
89 9e b5 c4 a c a d
1d a c a d 1d 34 36
a c 19 1d 2d f 24 26
2b 31 36 47 4c 4e 62 64
a f 15 1a 2e 33 35 41
43 a f 15 1a 2e 34 3d
3f 4f 51 5e 61 a f 15
1a 28 2e 31 3d 3f a f
15 1a 2a 30 33 40 42 a
f 15 1a 2a 30 33 40 42
a f 15 1a 28 2f 33 40
42 10 12 1f 30 32 3f 48
4a 13 1b 1a a 1a d :2 17
29 :2 33 3f 42 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 64 67 :2 24
:2 d 59 :3 a 11 a 2e a f
2b 2d 50 52 69 6b 84 8f
91 14 16 35 37 49 52 5a
5c 6a 6c 17 19 28 32 3a
3c 4a 4c 60 14 16 3e 40
69 a c 1f 21 2e 30 39
3b a c 10 12 16 18 2c
3b 3d 52 a 12 2a 3e 4e
62 a c 19 28 2a 42 a
c 19 1b 29 2b a c 1b
1d 2d 2f 34 36 43 45 a
c 1b 22 32 43 a 17 27
29 38 3a 47 49 59 a 13
15 25 27 37 48 4b 5b 6e
70 7d 7f 8c 8e 9b 9d 14
16 35 37 4a 54 5c 5e 6c
6e 19 27 29 34 36 44 46
56 58 69 6b a c 22 24
32 35 45 55 57 5f 61 6b
6d 75 77 82 84 92 94 a2
a4 ae b0 a c 28 2a 48
4a 72 7c 7e 94 a7 a c
19 1b 29 2b 39 3b 50 67
14 16 38 3a 52 54 6b 6d
7c 7e 92 94 a4 a6 d2 a
c a d 1d a c a d
1d 34 36 a c 19 1d 2d
f 24 26 2b 31 36 47 4c
4e 62 64 a f 15 1a 2e
33 35 41 43 a f 15 1a
2e 34 3d 3f 4f 51 5e 61
a f 15 1a 28 2e 31 3d
3f a f 15 1a 2a 30 33
40 42 a f 15 1a 2a 30
33 40 42 a f 15 1a 28
2f 33 40 42 10 12 32 34
41 13 1c 1a a 1a d :2 17
29 :2 33 3f 42 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 64 67 :2 24
:2 d 59 :3 a 11 a :4 7 4 25
22 a 13 1e :2 a 21 23 :2 21
7 f 19 :3 7 :2 10 1c 7 16
:c a e 20 a e 21 a e
1f a e 1e a e 1f a
e 1d a e 16 f 26 31
3a 61 6e a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 25 7 :2 10 :3 1c
7 16 2a 35 43 52 62 71
7d a 10 1a 1c 27 29 a
c 1b 1d 2c 2e 3e 40 4c
4e 5b 5d 63 65 f 1f 21
26 2f 34 36 4c 4e 59 5b
67 6c 7d 82 84 8f 91 a
f 20 25 27 32 34 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8d 90 :2 27 98 9b
:2 27 a7 aa b1 ba bd :2 aa :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 25
7 c 1e 20 2f 40 53 55
62 75 7d 7f 7 9 18 1a
29 2b 3b 3d 49 4b 58 5a
60 62 71 78 85 d 1e 30
3f 52 6d 7b 7d 92 a3 c
1c 1e 23 2d 32 34 4c 4e
5a 5c e 1f 32 45 53 7
16 25 37 43 50 56 65 6c
79 d 1f 30 3f 52 6d 81
96 a7 c 29 17 7 17 a
:2 14 26 :2 30 3c 3f 4f 52 53
:2 4f :2 26 :3 a :2 10 15 21 61 64
:2 21 :2 a 56 :3 7 e 7 4 25
22 a 13 1e :2 a 21 23 :2 21
7 f 19 :3 7 :2 10 1c 7 16
:c a e 20 a e 21 a e
1f a e 1e a e 1f a
e 1d a e 16 f 26 31
3a 61 6e a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 25 7 :2 10 :3 1c
7 16 2a 35 43 52 5b 6b
7a 8a 99 a5 a 10 1b 1a
1c 28 2a a c 1b 1d 2c
2e 3e 40 4c 4e 5b 5d 63
65 f 1f 21 26 2f 34 36
4c 4e 59 5b 67 6c 7d 82
84 8f 91 a f 20 25 27
32 34 1a 1d 2a 2c 40 42
a 30 a 30 5d 5f f 24
28 32 10 13 1e 27 2a 38
3a 20 23 3a 4b 10 13 30
32 f 24 2c 2e 3b 3e 4d
4f 5d 60 a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 25 7 c 1e
20 2f 40 53 55 62 75 7d
7f 7 9 18 1a 29 2b 3b
3d 49 4b 58 5a 60 62 71
78 85 d 1e 30 3f 52 6d
7b 7d 92 a3 c 1c 1e 23
2d 32 34 4c 4e 5a 5c e
1f 32 3f 47 7 16 25 37
43 50 56 65 6c 79 d 1f
30 3f 52 6d 7c 91 a2 c
26 3c e 1f 32 3f 47 7
16 25 7 13 20 26 35 3c
49 5e 6f c 1b 2e 49 57
6c 7d c d 25 10 1e 17
7 17 a :2 14 26 :2 30 3c 3f
4f 52 53 :2 4f :2 26 :3 a :2 10 15
21 61 64 :2 21 :2 a 56 :3 7 e
7 4 25 22 a 13 1e :2 a
21 23 :2 21 7 c 1e 20 2f
3b 3d 50 52 5f 73 7b 7d
7 9 18 1a 2a 2c 34 44
46 56 69 6b 7b 87 89 9a
7 9 11 17 19 27 32 3f
54 66 c 1a 2d 48 56 58
6d 7e 7 a 18 1b 29 2c
3a 3d 4b 4e 7 a 1f 22
38 3b 4e 51 7 a 25 28
44 47 7 a 25 28 44 47
c 21 23 28 3c 42 45 52
5b 5e 6c 6e 7 c 11 22
27 29 3b 3d 53 55 7 c
11 22 27 29 3b 3d 53 55
7 c 16 1b 1d 29 2b d
f 1a 23 25 3c 3e 5f 61
e 10 1f 2b 2d 40 42 52
66 74 7 9 18 1a 29 2b
33 42 44 54 66 8d 99 c0
c 16 20 2d 42 54 c 1b
2e 43 45 59 6e 7f 7 a
18 1b 29 2c 3a 3d 4b 4e
7 a 1f 22 38 3b 4e 51
7 a 25 28 44 47 7 a
25 28 44 47 c 21 23 28
31 36 38 44 46 7 c 1d
22 24 36 38 7 c 20 26
29 36 3f 42 50 52 d f
1a 23 25 10 1e 17 7 17
a :2 14 26 :2 30 3c 3f 4f 52
53 :2 4f :2 26 :3 a :2 10 15 21 61
64 :2 21 :2 a 56 :3 7 e 7 4
25 22 a 13 1e :2 a 21 23
:2 21 7 f 19 :3 7 :2 10 1c 7
16 b :d a e 21 a e 21
a e 21 a 18 2a 3e a
e 21 a e 21 a e 21
a 18 2a 3e f 10 1b 24
2c 13 20 a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 25 7 f 19
:3 7 :2 10 1c 7 16 :20 a c 1e
20 36 38 4e 50 a c 1e
20 36 38 4e 50 a c 1e
20 36 38 4e 50 a c 1e
20 36 38 a c 21 23 39
3b 4e 50 a c 27 29 45
47 a c 27 29 45 47 a
c 1e 20 36 38 4e 50 a
13 15 28 2a 37 39 60 62
f 23 25 2a 30 35 46 4b
4d 5b 5d 10 12 1d a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 5a 5b :2 56 :2 2c :3 10 :2 16
1b 27 68 6b :2 27 78 7b :2 27
7f 82 :2 27 8e 91 :2 27 99 9c
:2 27 a8 ab b2 bb be :2 ab :2 27
:2 10 5e :2 d :2 a :4 16 :2 a 7 :3 25
11 22 29 3c 11 1e 2f 37
39 44 4d 4f 5d 60 70 72
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 5a 5b :2 56 :2 2c
:3 10 :2 16 1b 27 68 6b :2 27 78
7b :2 27 7f 82 :2 27 8e 91 :2 27
99 9c :2 27 a8 ab b2 bb be
:2 ab :2 27 :2 10 5e :2 d :2 a :4 16 :2 a
7 :3 25 7 c 1e 20 2f 40
53 55 62 70 72 7a 7c 7
9 18 1a 29 2b 3b 3d 49
4b 58 5a 60 62 71 78 85
d 1e 30 3f 52 6d 7b 7d
92 a3 11 13 34 36 57 59
74 8b 8d a0 a2 b6 b8 cb
cd de e0 f2 f4 7 f 7
9 1e 20 36 38 4b 4d 7
9 24 26 42 44 7 9 24
26 42 44 7 9 17 19 27
29 37 39 47 49 c 1d 1f
24 2e 33 35 4d 4f 5b 5d
f 11 1f 30 43 45 55 68
76 7 9 18 1a 29 2b 3b
3d 49 4b 58 5a 60 62 71
78 85 d 1f 30 3f 52 6d
81 96 a7 11 13 34 36 57
59 74 8b 8d a0 a2 b6 b8
cb cd de e0 f2 f4 7 f
7 9 1e 20 36 38 4b 4d
7 9 24 26 42 44 7 9
24 26 42 44 7 9 17 19
27 29 37 39 47 49 c 1d
1f 24 2d 32 34 4a 4c 57
59 7 c 1d 22 24 2f 31
7 c 1d 22 24 2f 31 17
7 17 a :2 14 26 :2 30 3c 3f
4f 53 54 :2 4f :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 57 :3 7 e
7 4 25 22 a 13 1e :2 a
23 21 :2 2c :2 21 11 23 2d 3c
49 :2 a :2 13 1f a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 5a 5b :2 56 :2 2c :3 10 :2 16
1b 27 68 6b :2 27 78 7b :2 27
7f 82 :2 27 8e 91 :2 27 99 9c
:2 27 a8 ab b2 bb be :2 ab :2 27
:2 10 5e :2 d :2 a :4 16 :2 a 7 :3 40
b :2 14 1f 1d :2 28 :2 1d :2 a f
21 29 35 3d 50 5e 69 6b
74 7c a 12 16 26 30 38
3c 4c 56 5f 64 74 f 18
a f 14 26 2d 31 3f a
f 14 24 2d 31 3f a f
14 1e 2d 32 3f 10 12 1f
11 19 25 2d 40 48 4b 56
a d 1b 24 2f 3c 47 54
5a 5d 73 79 7c 8e d 1b
28 36 43 52 f 25 27 2c
32 37 48 4e 50 58 5b a
f 15 1a 2b 31 34 3f 42
52 54 66 11 19 25 2d 40
48 4b 56 a d 1b 24 2f
3c 47 54 5a 5d 73 79 7c
8e d 1b 28 36 43 52 f
26 28 2d 33 38 49 4f 51
5a 5d a f 15 1a 2b 31
34 3f 42 52 54 66 13 1e
1a a 1a d :2 17 29 :2 33 3f
42 52 56 57 :2 52 :2 29 :3 d :2 13
18 24 65 68 :2 24 :2 d 5a :3 a
11 a 38 :2 7 4 40 22 a
13 1e :2 a 21 23 :2 21 7 c
28 2a 4d 4f 66 68 81 8d
8f 11 13 32 34 46 4f 57
59 67 69 14 16 25 2f 37
39 47 49 5d 11 13 3b 3d
66 7 9 1c 1e 2b 2d 36
38 7 9 d f 13 15 29
38 3a 4f 11 25 35 49 11
25 32 43 57 11 13 22 24
33 35 47 49 5a c 11 13
2f 36 40 42 4f 59 66 81
7 9 16 18 26 28 7 9
18 1a 2a 2c 31 33 40 42
7 9 18 1f 2f 40 7 14
24 26 35 37 44 46 56 7
10 12 22 24 34 45 48 58
6b 6d 7a 7c 89 8b 98 9a
11 13 32 34 47 51 59 5b
69 6b 16 24 26 31 33 41
43 53 55 66 68 7 9 1f
21 2f 32 42 52 54 5c 5e
68 6a 72 74 7f 81 8f 91
9f a1 ab ad 7 9 25 27
45 47 6f 79 7b 91 9f a1
b8 11 28 31 33 3f 41 58
83 11 28 31 33 40 42 5a
85 11 32 34 4a 4c 55 57
76 84 86 9b b2 11 13 35
37 4f 51 68 6a 79 7b 8f
91 a1 a3 cf 7 9 7 a
1a 7 9 7 a 1a 31 33
7 9 16 1a 2a c 21 23
28 39 3e 40 54 5d 5f 73
75 7 c 12 17 2b 30 32
3e 40 7 c 12 17 2b 31
3a 3c 4c 4e 5b 5e 7 c
12 17 25 2b 2e 3a 3c 7
c 12 17 27 2d 30 3d 3f
7 c 12 17 27 2d 30 3d
3f 7 c 12 17 25 2c 30
3d 3f 10 1e 17 7 17 a
:2 14 26 :2 30 3c 3f 4f 53 54
:2 4f :2 26 :3 a :2 10 15 21 62 65
:2 21 :2 a 57 :3 7 e 7 4 26
22 a 13 1e :2 a 21 23 :2 21
7 c 1e 20 35 41 43 11
13 32 34 46 4f 57 59 67
69 14 16 25 2f 37 39 47
49 5d 11 13 2a 33 4e 58
5a 6d 6f 7c a3 b2 d9 c
19 40 49 70 7 2e 3a 61
74 7 2e 3b 62 76 7 2e
3d 64 79 7 2e 3b 62 c
13 20 30 32 41 68 7 9
16 18 28 37 40 42 52 54
64 75 78 88 c 1e 30 43
11 13 32 34 47 51 59 5b
69 6b 16 7 9 1a 7 2e
3e 65 7b d 2a 3e 53 c
1b 28 38 4b 5e :2 c 21 7
c 12 17 2b 30 32 3e 40
7 c 12 17 2b 31 3a 3c
4c 4e 5b 5e d f 2f 31
3e 10 1e 17 7 17 a :2 14
26 :2 30 3c 3f 4f 53 54 :2 4f
:2 26 :3 a :2 10 15 21 62 65 :2 21
:2 a 57 :3 7 e 7 4 26 22
a 13 1e :2 a 21 23 :2 21 7
f 19 :3 7 :2 10 1c 7 16 23
30 3f 11 1e 34 f 10 1d
:2 a 17 20 13 20 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 5a 5b :2 56 :2 2c :3 10 :2 16 1b
27 68 6b :2 27 78 7b :2 27 7f
82 :2 27 8e 91 :2 27 99 9c :2 27
a8 ab b2 bb be :2 ab :2 27 :2 10
5e :2 d :2 a :4 16 :2 a 7 :3 26 7
f 19 :3 7 :2 10 1c 7 16 26
33 42 12 1f 35 f 10 1d
a 14 13 20 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
5a 5b :2 56 :2 2c :3 10 :2 16 1b 27
68 6b :2 27 78 7b :2 27 7f 82
:2 27 8e 91 :2 27 99 9c :2 27 a8
ab b2 bb be :2 ab :2 27 :2 10 5e
:2 d :2 a :4 16 :2 a 7 :3 26 7 f
19 :3 7 :2 10 1c 7 16 2d 3a
49 11 13 20 22 31 33 f
1b 1d 22 28 2d 3c 41 43
4f 51 11 13 20 22 31 33
f 1e 20 25 2b 30 3c 41
43 4f 51 a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 5a
5b :2 56 :2 2c :3 10 :2 16 1b 27 68
6b :2 27 78 7b :2 27 7f 82 :2 27
8e 91 :2 27 99 9c :2 27 a8 ab
b2 bb be :2 ab :2 27 :2 10 5e :2 d
:2 a :4 16 :2 a 7 :3 26 7 c 1e
20 2f 3b 3d 4a 5d 66 68
73 75 c 22 24 29 33 38
3a 52 54 60 62 7 c 12
17 26 2d 2f 3b 3f 17 19
27 33 35 45 58 68 73 75
c 22 24 29 32 37 39 51
53 60 62 7 c 1d 22 24
2f 31 7 c 1d 22 24 2f
31 7 c 12 17 26 2d 2f
3b 3f 17 1a 29 35 37 44
59 62 64 76 c 21 25 2f
d 10 1b 7 a 18 1a 19
1c 2d 43 4c 4f 5d 60 10
1e 17 7 17 a :2 14 26 :2 30
3c 3f 4f 53 54 :2 4f :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 e 7 4 26 22 a 13
1e :2 a 21 23 :2 21 7 c 1f
21 2d 2f 3c 4f 58 5a 6c
c 16 18 1d 27 a c 19
1b d f b d 17 10 18
7 18 a :2 14 26 :2 30 3c 3f
4f 53 54 :2 4f :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 57 :3 7 e
7 4 26 22 b 14 1f :2 b
24 22 :2 2d :2 22 a 4e 11 1c
:2 4e 21 1f :2 2a :2 1f 4d :2 a 7
c 23 25 34 40 42 4f 5c
65 74 7d 7f 91 c 20 24
2e d 10 1d b e 1c 1e
10 1c 7 1c a :2 14 26 :2 30
3c 3f 4f 53 54 :2 4f :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 e 7 48 22 a :2 14 26
:2 30 3c 3f 4f 53 54 :2 4f :2 26
:3 a :2 10 15 21 62 65 :2 21 72
75 :2 21 79 7c :2 21 86 89 92
9a :2 a3 :2 92 b4 :2 89 :2 21 bc bf
:2 21 c7 ca :2 21 cf d2 :2 21 d5
d8 :2 21 :2 a 57 :3 7 :2 12 24 :2 2d
3d 41 :2 7 :4 4 1 9 12 9
a :2 14 26 :2 30 3c 40 50 54
55 :2 50 :2 26 :3 a :2 10 15 21 62
65 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 58 :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 4d 51
52 :2 4d :2 23 :3 7 :2 d 12 1e 5f
62 :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 55 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
1f2b
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :6 e :6 f
:6 10 :6 11 :6 12 :6 13
:7 16 :7 19 :7 1c :7 1f
:7 22 :7 25 :7 28 :7 2b
:7 2e :7 31 :7 34 :7 37
:7 3a :7 3d :7 40 :7 42
:b 44 :11 45 46 :2 45
:2 46 :2 45 :2 46 :2 45
:2 47 :2 45 :9 47 :2 45
:2 48 :2 45 :2 48 :2 45
:2 48 :2 45 :2 48 :2 45
:2 48 :4 45 :3 44 :11 4b
:b 4c :3 4b :5 51 :11 52
:30 53 :3 52 :11 55 :b 56
:3 55 :a 58 :3 51 :3 5d
:3 5e :3 5f :16 62 :9 64
:4 65 :b 66 64 :5 67
63 :2 69 :5 6b :11 6c
:24 6d :3 6c :2 6a :6 69
68 :3 62 :a 73 :7 75
:3 76 :b 77 75 :5 78
74 :2 7a :5 7c :11 7d
:24 7e :3 7d :2 7b :6 7a
79 :3 73 :a 84 :5 86
:5 87 85 :2 89 :5 8b
:11 8c :24 8d :3 8c :2 8a
:6 89 88 :3 84 :a 92
:11 93 :30 94 :3 93 :11 96
:b 97 :3 96 :a 99 :3 92
:3 84 :3 73 9d 62
:9 9d :2 9f :3 a0 9f
:5 a1 9e :2 a3 :5 a5
:11 a6 :24 a7 :3 a6 :2 a4
:6 a3 a2 :3 9d :a ac
:11 ad :30 ae :3 ad :11 b0
:b b1 :3 b0 :a b3 :3 ac
:5 b7 :3 b8 b7 :5 b9
b6 :2 bb :5 bd :11 be
:24 bf :3 be :2 bc :6 bb
ba :3 9d c3 9d
62 :9 c3 :6 c5 :5 c6
c4 :2 c8 :5 ca :11 cb
:24 cc :3 cb :2 c9 :6 c8
c7 :3 c3 :a d1 :11 d2
:30 d3 :3 d2 :11 d5 :b d6
:3 d5 :a d8 :3 d1 :3 db
dc c3 62 :18 dc
:c dd :2 dc dd :2 de
:2 dd :6 de dd :2 dc
:5 e0 :3 e1 e0 :5 e2
df :2 e4 :5 e6 :11 e7
:24 e8 :3 e7 :2 e5 :6 e4
e3 :3 de :a ed :11 ee
:30 ef :3 ee :11 f1 :b f2
:3 f1 :a f4 :3 ed de
:3 62 :9 fa :5 fc :5 fd
100 102 103 104
105 106 107 108
:2 10b :2 10c :2 10d :2 10e
:2 10f :2 110 :2 111 :9 112
:3 113 100 :6 114 :5 115
114 :5 117 116 :3 114
ff :2 11a :5 11c :11 11d
:24 11e :3 11d :2 11b :6 11a
119 :3 fa :5 124 :5 125
:2 128 129 12a :3 12b
128 :6 12c :5 12d 12c
:5 12f 12e :3 12c 127
:2 132 :5 134 :11 135 :24 136
:3 135 :2 133 :6 132 131
:3 fa :c 13b :e 13c :13 13d
:9 13e :7 13f :7 140 :9 141
:9 145 :5 146 :9 147 :a 148
:9 149 :9 14a :9 14b :9 14c
:9 150 :5 151 :9 152 :a 153
:9 154 :7 155 :9 156 :9 157
:9 158 :9 15c :5 15d :9 15e
:a 15f :9 160 :7 161 :9 162
:9 163 :9 164 :3 165 :3 13b
:11 166 :b 167 :3 166 :3 169
16a fa :16 16a :5 16c
:5 16d :3 170 :2 172 :3 173
:e 174 :7 175 :9 176 170
:6 177 :5 178 177 :5 17a
179 :3 177 16f :2 17d
:5 17f :11 180 :24 181 :3 180
:2 17e :6 17d 17c :3 16a
:7 186 :3 189 :4 18a :b 18b
:7 18c :7 18d :9 18e :5 18f
189 :6 190 :5 191 190
:5 193 192 :3 190 188
:2 196 :5 198 :11 199 :24 19a
:3 199 :2 197 :6 196 195
:3 16a :d 19f :5 1a0 :b 1a1
:6 1a2 :9 1a3 :5 1a7 :5 1a8
:9 1a9 :8 1aa 1ab 1ac
:3 19f :11 1ad :b 1ae :3 1ad
:3 1b0 1b1 16a fa
:9 1b1 :9 1b2 :e 1b3 :f 1b4
:16 1b5 :14 1b6 :2 1b7 :e 1b8
:12 1b9 :c 1ba :9 1bb :6 1bc
:3 1b2 :11 1bd :b 1be :3 1bd
:3 1c0 1c1 1b1 fa
:9 1c1 :c 1c2 :3 1c3 :8 1c5
:5 1c6 1c4 :2 1c8 :5 1ca
:11 1cb :24 1cc :3 1cb :2 1c9
:6 1c8 1c7 :3 1c2 :9 1d1
:3 1d2 1d1 :3 1d5 :6 1d6
1d5 :5 1d7 1d4 :2 1d9
:5 1db :11 1dc :24 1dd :3 1dc
:2 1da :6 1d9 1d8 :3 1d3
:9 1e2 :3 1e4 :5 1e5 :8 1e6
:6 1e7 :6 1e8 1e4 :5 1e9
1e3 :2 1eb :5 1ed :11 1ee
:24 1ef :3 1ee :2 1ec :6 1eb
1ea :3 1e2 :9 1f4 :3 1f5
1f4 :3 1f7 1f6 :3 1f4
1e2 :3 1fa 1f9 :3 1e2
1d3 :3 1d1 :11 202 :a 203
:c 204 :3 205 :c 206 :5 207
:a 208 :a 209 :5 20a :6 20b
:b 20c :b 20d :9 20e :5 20f
:5 210 :9 211 :5 212 :2 213
:d 214 :9 215 :6 216 :9 218
:a 219 :9 21a :5 21b :9 21c
:1c 21d :4 21e :5 21f :9 220
221 :a 222 :6 223 :a 224
:6 225 :9 226 :11 227 :a 228
:b 229 :17 22a :d 22b :8 22c
:8 22d :d 22e :2 22f :3 230
:2 231 :5 232 :5 233 :b 234
:9 235 :c 236 :9 237 :9 238
:9 239 :9 23a :8 23b :2 23c
:3 202 :11 23d :b 23e :3 23d
:3 240 1c2 :b 244 :a 245
:9 246 :5 247 :8 248 :a 249
:6 24a :6 24b :6 24c :a 24d
:6 24e :9 24f :11 250 :a 251
:b 252 :17 253 :b 254 :a 255
:f 256 :2 257 :3 258 :2 259
:5 25a :5 25b :b 25c :9 25d
:c 25e :9 25f :9 260 :9 261
:9 262 :5 263 :2 264 :3 244
:11 265 :b 266 :3 265 :3 268
241 :3 1c2 26a 1c1
fa :9 26a :5 26c :5 26d
270 272 273 274
275 276 277 278
279 27a 27d 27e
:3 27f :3 280 :3 281 :3 282
:3 283 :3 284 :3 285 :6 286
270 :6 287 :5 288 287
:5 28a 289 :3 287 26f
:2 28d :5 28f :11 290 :24 291
:3 290 :2 28e :6 28d 28c
:3 26a :7 296 :8 299 :2 29a
:4 29b :e 29c :12 29d :7 29e
299 :6 29f :5 2a0 29f
:5 2a2 2a1 :3 29f 298
:2 2a5 :5 2a7 :11 2a8 :24 2a9
:3 2a8 :2 2a6 :6 2a5 2a4
:3 26a :c 2ae :11 2af :a 2b0
:b 2b1 :5 2b5 :a 2b6 :9 2b7
:2 2b8 :3 2ae :11 2b9 :b 2ba
:3 2b9 :3 2bc 2bd 26a
fa :9 2bd :5 2bf :5 2c0
2c3 2c5 2c6 2c7
2c8 2c9 2ca 2cb
2cc 2cd 2d0 2d1
:3 2d2 :3 2d3 :3 2d4 :3 2d5
:3 2d6 :3 2d7 :3 2d8 :6 2d9
2c3 :6 2da :5 2db 2da
:5 2dd 2dc :3 2da 2c2
:2 2e0 :5 2e2 :11 2e3 :24 2e4
:3 2e3 :2 2e1 :6 2e0 2df
:3 2bd :7 2e9 :b 2ec :3 2ed
:4 2ee :e 2ef :12 2f1 :7 2f2
:6 2f4 :2 2f5 :4 2f6 :4 2f7
:7 2f8 :4 2f9 :4 2fa :a 2fb
2ec :6 2fc :5 2fd 2fc
:5 2ff 2fe :3 2fc 2eb
:2 302 :5 304 :11 305 :24 306
:3 305 :2 303 :6 302 301
:3 2bd :c 30b :11 30c :a 30d
:b 30e :5 310 :a 311 :9 312
:3 313 :5 315 :3 316 :9 317
:7 318 319 :2 31a :2 31b
:3 30b :11 31c :b 31d :3 31c
:3 31f 362 2bd fa
:9 362 :d 363 :10 364 :a 365
:8 366 :a 367 :8 368 :6 369
:6 36a :c 36b :a 36c :a 36d
:7 36e :9 36f :a 371 :e 372
:6 373 :8 374 :a 375 :8 376
:6 377 :6 378 :9 379 :7 37a
:a 37b :5 37c :2 37d :3 363
:11 37e :b 37f :3 37e :3 381
382 362 fa :9 382
:5 384 :5 385 388 389
38a 38b 38c 38d
38e 38f 390 391
392 393 396 397
:3 398 :3 399 :3 39a :4 39b
:3 39c :3 39d :3 39e :4 39f
3a0 :4 3a1 :2 3a2 388
:6 3a3 :5 3a4 3a3 :5 3a6
3a5 :3 3a3 387 :2 3a9
:5 3ab :11 3ac :24 3ad :3 3ac
:2 3aa :6 3a9 3a8 :3 382
:5 3b4 :5 3b5 3b8 3ba
3bb 3bc 3bd 3be
3bf 3c0 3c1 3c2
3c3 3c4 3c5 3c6
3c7 3c8 3c9 3ca
3cb 3cc 3cd 3ce
3cf 3d0 3d1 3d2
3d3 3d4 3d5 3d6
3d7 3d8 :8 3db :8 3dc
:8 3dd :6 3de :8 3df :6 3e0
:6 3e1 :8 3e2 :9 3e3 :b 3e4
:3 3e5 3b8 :6 3e6 :5 3e7
3e6 :5 3e9 3e8 :3 3e6
3b7 :2 3ec :5 3ee :11 3ef
:24 3f0 :3 3ef :2 3ed :6 3ec
3eb :3 382 :4 3f7 :c 3f8
3f7 :6 3f9 :5 3fa 3f9
:5 3fc 3fb :3 3f9 3f6
:2 3ff :5 401 :11 402 :24 403
:3 402 :2 400 :6 3ff 3fe
:3 382 :d 408 :11 409 :a 40a
:13 40b :2 40c :8 40d :6 40e
:6 40f :a 410 :b 411 :9 413
:11 414 :9 415 :13 416 :2 417
:8 418 :6 419 :6 41a :a 41b
:b 41c :7 41d :7 41e :3 408
:11 41f :b 420 :3 41f :3 422
423 382 fa :b 423
:6 425 :5 426 424 :2 428
:5 42a :11 42b :24 42c :3 42b
:2 429 :6 428 427 :3 423
:a 431 :c 432 :c 433 :2 434
:7 435 :7 436 :7 437 :3 438
:8 43a :e 43b :6 43c :b 43d
:c 43e :8 440 :e 441 :6 442
:b 443 :c 444 :2 445 :3 432
:11 446 :b 447 :3 446 :3 449
:3 431 44b 423 fa
:9 44b :b 44c :a 44d :9 44e
:5 44f :8 450 :a 451 :4 452
:5 453 :9 454 455 :a 456
:6 457 :a 458 :6 459 :9 45a
:11 45b :a 45c :b 45d :17 45e
:d 45f :8 460 :8 461 :c 462
:f 463 :2 464 :3 465 :2 466
:5 467 :5 468 :c 469 :9 46a
:c 46b :9 46c :9 46d :9 46e
:9 46f :2 470 :3 44c :11 471
:b 472 :3 471 :3 474 475
44b fa :9 475 :7 476
:a 477 :9 478 :d 479 :5 47a
:5 47b :5 47c :5 47d :4 47e
:7 47f :e 480 :4 481 :a 482
483 :3 484 :5 485 :4 486
:6 487 488 :2 489 :9 48a
:c 48b :5 48c :2 48d :3 476
:11 48e :b 48f :3 48e :3 491
492 475 fa :9 492
:5 496 :5 497 :4 49a :3 49b
49c :2 49d 49e :3 49f
:2 4a0 49a :6 4a1 :5 4a2
4a1 :5 4a4 4a3 :3 4a1
499 :2 4a7 :5 4a9 :11 4aa
:24 4ab :3 4aa :2 4a8 :6 4a7
4a6 :3 492 :5 4b1 :5 4b2
:4 4b5 :3 4b6 4b7 :2 4b8
:2 4b9 :2 4ba 4b5 :6 4bb
:5 4bc 4bb :5 4be 4bd
:3 4bb 4b4 :2 4c1 :5 4c3
:11 4c4 :24 4c5 :3 4c4 :2 4c2
:6 4c1 4c0 :3 492 :5 4cb
:5 4cc :4 4cf :6 4d0 :b 4d1
:6 4d3 :b 4d4 4cf :6 4d5
:5 4d6 4d5 :5 4d8 4d7
:3 4d5 4ce :2 4db :5 4dd
:11 4de :24 4df :3 4de :2 4dc
:6 4db 4da :3 492 :d 4e4
:b 4e5 :9 4e6 :a 4ea :b 4eb
:7 4ec :7 4ed :9 4ee :a 4f2
:4 4f3 :3 4f4 :4 4f5 :8 4f6
:2 4f7 :3 4e4 :11 4f8 :b 4f9
:3 4f8 :3 4fb 4fc 492
fa :9 4fc :b 500 :5 501
:4 502 :2 503 :3 504 505
:3 500 :11 506 :b 507 :3 506
:3 509 50a 4fc fa
:d 50a :2 50b :2 50a :6 50b
:3 50a :e 50f :4 510 :3 511
:4 512 513 :3 50f :11 514
:b 515 :3 514 :3 517 50b
fa :11 519 :30 51a :3 519
:a 51c 518 :3 fa 43
:3 521 :11 522 :b 523 :17 524
:3 522 :2 526 :3 527 :3 528
529 527 526 527
:3 52a :3 521 :2 52b :5 52d
:11 52e :b 52f :18 530 :3 52e
:2 532 533 :3 534 535
533 532 533 :3 536
:2 52c :6 52b 520 :7 1

7410
4
:3 0 1 :3 0 2
:a 0 1f26 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 1f26 2 14
:2 0 e :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 1f24
0 b :6 0 e
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 1f24
0 d :6 0 e
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 1f24
0 f :6 0 12
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 1f24
0 10 :6 0 14
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 1f24
0 11 :6 0 16
:2 0 23 4 :3 0
21 3a 3c :6 0
3f 3d 0 1f24
0 13 :6 0 16
:2 0 25 6 :3 0
41 :7 0 45 42
43 1f24 0 15
:6 0 16 :2 0 27
6 :3 0 47 :7 0
4b 48 49 1f24
0 17 :6 0 16
:2 0 29 6 :3 0
4d :7 0 51 4e
4f 1f24 0 18
:6 0 16 :2 0 2b
6 :3 0 53 :7 0
57 54 55 1f24
0 19 :6 0 16
:2 0 2d 6 :3 0
59 :7 0 5d 5a
5b 1f24 0 1a
:6 0 65 66 0
2f 6 :3 0 5f
:7 0 63 60 61
1f24 0 1b :6 0
6c 6d 0 31
9 :3 0 a :2 0
4 67 :7 0 6a
68 0 1f24 0
1c :6 0 73 74
0 33 9 :3 0
a :2 0 4 6e
:7 0 71 6f 0
1f24 0 1d :6 0
7a 7b 0 35
9 :3 0 a :2 0
4 75 :7 0 78
76 0 1f24 0
1e :6 0 81 82
0 37 9 :3 0
a :2 0 4 7c
:7 0 7f 7d 0
1f24 0 1f :6 0
88 89 0 39
9 :3 0 a :2 0
4 83 :7 0 86
84 0 1f24 0
20 :6 0 8f 90
0 3b 9 :3 0
a :2 0 4 8a
:7 0 8d 8b 0
1f24 0 21 :6 0
96 97 0 3d
9 :3 0 a :2 0
4 91 :7 0 94
92 0 1f24 0
22 :6 0 9d 9e
0 3f 9 :3 0
a :2 0 4 98
:7 0 9b 99 0
1f24 0 23 :6 0
a4 a5 0 41
9 :3 0 a :2 0
4 9f :7 0 a2
a0 0 1f24 0
24 :6 0 ab ac
0 43 9 :3 0
a :2 0 4 a6
:7 0 a9 a7 0
1f24 0 25 :6 0
b2 b3 0 45
9 :3 0 a :2 0
4 ad :7 0 b0
ae 0 1f24 0
26 :6 0 b9 ba
0 47 9 :3 0
a :2 0 4 b4
:7 0 b7 b5 0
1f24 0 27 :6 0
c0 c1 0 49
9 :3 0 a :2 0
4 bb :7 0 be
bc 0 1f24 0
28 :6 0 c7 c8
0 4b 9 :3 0
a :2 0 4 c2
:7 0 c5 c3 0
1f24 0 29 :6 0
ce cf 0 4d
9 :3 0 a :2 0
4 c9 :7 0 cc
ca 0 1f24 0
2a :6 0 d4 d5
0 4f 9 :3 0
a :2 0 4 d0
:7 0 d3 d1 0
1f24 0 2b :6 0
2c :3 0 2d :3 0
2c :3 0 2e :3 0
d7 d8 0 2
:4 0 51 d9 db
d6 dd dc :2 0
2f :3 0 30 :3 0
df e0 0 31
:4 0 2c :3 0 32
:3 0 e3 e4 0
2 :4 0 53 e5
e7 33 :4 0 34
:2 0 35 :3 0 55
ea ec :3 0 36
:4 0 34 :2 0 37
:4 0 58 ef f1
:3 0 34 :2 0 3
:3 0 5b f3 f5
:3 0 34 :2 0 37
:4 0 5e f7 f9
:3 0 34 :2 0 38
:4 0 61 fb fd
:3 0 34 :2 0 39
:3 0 3a :3 0 5
:3 0 64 101 103
3b :4 0 66 100
106 69 ff 108
:3 0 34 :2 0 38
:4 0 6c 10a 10c
:3 0 34 :2 0 37
:4 0 6f 10e 110
:3 0 34 :2 0 7
:3 0 72 112 114
:3 0 34 :2 0 37
:4 0 75 116 118
:3 0 34 :2 0 3c
:4 0 78 11a 11c
:3 0 7b e1 11e
:2 0 120 80 121
de 120 0 122
82 0 1e84 2c
:3 0 2d :3 0 123
124 0 2c :3 0
3d :3 0 126 127
0 14 :2 0 2
:4 0 3e :2 0 3f
:2 0 14 :2 0 84
12c 12e :3 0 87
128 130 125 132
131 :2 0 2f :3 0
40 :3 0 134 135
0 31 :4 0 41
:4 0 34 :2 0 35
:3 0 8b 139 13b
:3 0 8e 136 13d
:2 0 13f 91 140
133 13f 0 141
93 0 1e84 3
:3 0 42 :2 0 95
143 144 :3 0 145
:2 0 2c :3 0 2d
:3 0 147 148 0
2c :3 0 3d :3 0
14a 14b 0 e
:2 0 2 :4 0 43
:2 0 3f :2 0 14
:2 0 97 150 152
:3 0 9a 14c 154
149 156 155 :2 0
2f :3 0 40 :3 0
158 159 0 31
:4 0 44 :4 0 34
:2 0 35 :3 0 9e
15d 15f :3 0 34
:2 0 45 :4 0 a1
161 163 :3 0 34
:2 0 46 :4 0 a4
165 167 :3 0 34
:2 0 39 :3 0 3a
:3 0 47 :3 0 48
:3 0 16c 16d 0
a7 16b 16f 3b
:4 0 a9 16a 172
ac 169 174 :3 0
34 :2 0 49 :4 0
af 176 178 :3 0
34 :2 0 37 :4 0
b2 17a 17c :3 0
34 :2 0 3 :3 0
b5 17e 180 :3 0
34 :2 0 37 :4 0
b8 182 184 :3 0
bb 15a 186 :2 0
188 be 189 157
188 0 18a c0
0 1b4 2c :3 0
2d :3 0 18b 18c
0 2c :3 0 3d
:3 0 18e 18f 0
14 :2 0 2 :4 0
4a :2 0 3f :2 0
14 :2 0 c2 194
196 :3 0 c5 190
198 18d 19a 199
:2 0 2f :3 0 40
:3 0 19c 19d 0
31 :4 0 4b :4 0
34 :2 0 35 :3 0
c9 1a1 1a3 :3 0
cc 19e 1a5 :2 0
1a7 cf 1a8 19b
1a7 0 1a9 d1
0 1b4 4c :3 0
4d :3 0 1aa 1ab
0 47 :3 0 48
:3 0 1ad 1ae 0
3 :3 0 4e :3 0
d3 1ac 1b2 :2 0
1b4 d7 1b5 146
1b4 0 1b6 db
0 1e84 d :3 0
3 :3 0 1b7 1b8
0 1e84 15 :3 0
5 :3 0 1ba 1bb
0 1e84 f :3 0
7 :3 0 1bd 1be
0 1e84 39 :3 0
15 :3 0 16 :2 0
dd 1c0 1c3 4f
:2 0 50 :2 0 e2
1c5 1c7 :3 0 1c8
:2 0 39 :3 0 15
:3 0 16 :2 0 e5
1ca 1cd 4f :2 0
51 :2 0 ea 1cf
1d1 :3 0 1d2 :2 0
1c9 1d4 1d3 :2 0
52 :3 0 53 :3 0
52 :3 0 54 :3 0
39 :3 0 55 :3 0
56 :3 0 52 :3 0
57 :3 0 10 :3 0
18 :3 0 17 :3 0
1b :3 0 58 :3 0
55 :3 0 58 :3 0
52 :3 0 52 :3 0
59 :3 0 d :3 0
55 :3 0 59 :3 0
52 :3 0 53 :4 0
5a 1 :8 0 1f4
9 :3 0 5b :3 0
1ef 1f0 0 5c
:3 0 1f1 1f2 0
1f4 ed 23e 5d
:3 0 9 :3 0 5b
:3 0 1f7 1f8 0
5c :3 0 1f9 1fa
0 234 2c :3 0
2d :3 0 1fc 1fd
0 2c :3 0 3d
:3 0 1ff 200 0
5e :2 0 2 :4 0
5f :2 0 3f :2 0
14 :2 0 f0 205
207 :3 0 f3 201
209 1fe 20b 20a
:2 0 2f :3 0 40
:3 0 20d 20e 0
31 :4 0 60 :4 0
34 :2 0 35 :3 0
f7 212 214 :3 0
34 :2 0 45 :4 0
fa 216 218 :3 0
34 :2 0 61 :4 0
fd 21a 21c :3 0
34 :2 0 5c :3 0
100 21e 220 :3 0
34 :2 0 62 :4 0
103 222 224 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 106 227
22b 10a 226 22d
:3 0 10d 20f 22f
:2 0 231 110 232
20c 231 0 233
112 0 234 114
237 :3 0 237 0
237 236 234 235
:6 0 239 2 :3 0
117 23b 119 23a
239 :2 0 23c 11b
:2 0 23e 0 23e
23d 1f4 23c :6 0
392 1 :3 0 9
:3 0 5b :3 0 240
241 0 9 :3 0
4f :2 0 66 :3 0
243 245 0 11f
244 247 :3 0 248
:2 0 52 :3 0 53
:3 0 52 :3 0 54
:3 0 39 :3 0 55
:3 0 56 :3 0 10
:3 0 18 :3 0 17
:3 0 58 :3 0 55
:3 0 67 :3 0 52
:3 0 52 :3 0 59
:3 0 d :3 0 55
:3 0 59 :3 0 52
:3 0 53 :4 0 68
1 :8 0 265 9
:3 0 5b :3 0 260
261 0 5c :3 0
262 263 0 265
122 2af 5d :3 0
9 :3 0 5b :3 0
268 269 0 5c
:3 0 26a 26b 0
2a5 2c :3 0 2d
:3 0 26d 26e 0
2c :3 0 3d :3 0
270 271 0 5e
:2 0 2 :4 0 69
:2 0 3f :2 0 14
:2 0 125 276 278
:3 0 128 272 27a
26f 27c 27b :2 0
2f :3 0 40 :3 0
27e 27f 0 31
:4 0 6a :4 0 34
:2 0 35 :3 0 12c
283 285 :3 0 34
:2 0 45 :4 0 12f
287 289 :3 0 34
:2 0 61 :4 0 132
28b 28d :3 0 34
:2 0 5c :3 0 135
28f 291 :3 0 34
:2 0 62 :4 0 138
293 295 :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 13b 298 29c
13f 297 29e :3 0
142 280 2a0 :2 0
2a2 145 2a3 27d
2a2 0 2a4 147
0 2a5 149 2a8
:3 0 2a8 0 2a8
2a7 2a5 2a6 :6 0
2aa 4 :3 0 14c
2ac 14e 2ab 2aa
:2 0 2ad 150 :2 0
2af 0 2af 2ae
265 2ad :6 0 38e
1 :3 0 9 :3 0
5b :3 0 2b1 2b2
0 9 :3 0 4f
:2 0 66 :3 0 2b4
2b6 0 154 2b5
2b8 :3 0 2b9 :2 0
17 :3 0 6b :3 0
59 :3 0 d :4 0
6c 1 :8 0 2c5
9 :3 0 5b :3 0
2c0 2c1 0 5c
:3 0 2c2 2c3 0
2c5 157 30f 5d
:3 0 9 :3 0 5b
:3 0 2c8 2c9 0
5c :3 0 2ca 2cb
0 305 2c :3 0
2d :3 0 2cd 2ce
0 2c :3 0 3d
:3 0 2d0 2d1 0
5e :2 0 2 :4 0
6d :2 0 3f :2 0
14 :2 0 15a 2d6
2d8 :3 0 15d 2d2
2da 2cf 2dc 2db
:2 0 2f :3 0 40
:3 0 2de 2df 0
31 :4 0 6e :4 0
34 :2 0 35 :3 0
161 2e3 2e5 :3 0
34 :2 0 45 :4 0
164 2e7 2e9 :3 0
34 :2 0 61 :4 0
167 2eb 2ed :3 0
34 :2 0 5c :3 0
16a 2ef 2f1 :3 0
34 :2 0 62 :4 0
16d 2f3 2f5 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 170 2f8
2fc 174 2f7 2fe
:3 0 177 2e0 300
:2 0 302 17a 303
2dd 302 0 304
17c 0 305 17e
308 :3 0 308 0
308 307 305 306
:6 0 30a 6 :3 0
181 30c 183 30b
30a :2 0 30d 185
:2 0 30f 0 30f
30e 2c5 30d :6 0
38b 1 :3 0 9
:3 0 5b :3 0 311
312 0 9 :3 0
4f :2 0 66 :3 0
314 316 0 189
315 318 :3 0 319
:2 0 2c :3 0 2d
:3 0 31b 31c 0
2c :3 0 3d :3 0
31e 31f 0 e
:2 0 2 :4 0 6f
:2 0 3f :2 0 14
:2 0 18c 324 326
:3 0 18f 320 328
31d 32a 329 :2 0
2f :3 0 40 :3 0
32c 32d 0 31
:4 0 70 :4 0 34
:2 0 35 :3 0 193
331 333 :3 0 34
:2 0 45 :4 0 196
335 337 :3 0 34
:2 0 46 :4 0 199
339 33b :3 0 34
:2 0 39 :3 0 3a
:3 0 47 :3 0 48
:3 0 340 341 0
19c 33f 343 3b
:4 0 19e 33e 346
1a1 33d 348 :3 0
34 :2 0 49 :4 0
1a4 34a 34c :3 0
34 :2 0 37 :4 0
1a7 34e 350 :3 0
34 :2 0 d :3 0
1aa 352 354 :3 0
34 :2 0 37 :4 0
1ad 356 358 :3 0
1b0 32e 35a :2 0
35c 1b3 35d 32b
35c 0 35e 1b5
0 388 2c :3 0
2d :3 0 35f 360
0 2c :3 0 3d
:3 0 362 363 0
14 :2 0 2 :4 0
71 :2 0 3f :2 0
14 :2 0 1b7 368
36a :3 0 1ba 364
36c 361 36e 36d
:2 0 2f :3 0 40
:3 0 370 371 0
31 :4 0 72 :4 0
34 :2 0 35 :3 0
1be 375 377 :3 0
1c1 372 379 :2 0
37b 1c4 37c 36f
37b 0 37d 1c6
0 388 4c :3 0
4d :3 0 37e 37f
0 47 :3 0 48
:3 0 381 382 0
d :3 0 4e :3 0
1c8 380 386 :2 0
388 1cc 389 31a
388 0 38a 1d0
0 38b 1d2 38c
2ba 38b 0 38d
1d5 0 38e 1d7
38f 249 38e 0
390 1da 0 392
73 :3 0 1dc 6b4
39 :3 0 15 :3 0
16 :2 0 1df 393
396 4f :2 0 74
:2 0 1e4 398 39a
:3 0 53 :3 0 10
:3 0 75 :3 0 76
:3 0 d :4 0 77
1 :8 0 3a7 9
:3 0 5b :3 0 3a2
3a3 0 5c :3 0
3a4 3a5 0 3a7
1e7 3f1 5d :3 0
9 :3 0 5b :3 0
3aa 3ab 0 5c
:3 0 3ac 3ad 0
3e7 2c :3 0 2d
:3 0 3af 3b0 0
2c :3 0 3d :3 0
3b2 3b3 0 5e
:2 0 2 :4 0 78
:2 0 3f :2 0 14
:2 0 1ea 3b8 3ba
:3 0 1ed 3b4 3bc
3b1 3be 3bd :2 0
2f :3 0 40 :3 0
3c0 3c1 0 31
:4 0 79 :4 0 34
:2 0 35 :3 0 1f1
3c5 3c7 :3 0 34
:2 0 45 :4 0 1f4
3c9 3cb :3 0 34
:2 0 61 :4 0 1f7
3cd 3cf :3 0 34
:2 0 5c :3 0 1fa
3d1 3d3 :3 0 34
:2 0 62 :4 0 1fd
3d5 3d7 :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 200 3da 3de
204 3d9 3e0 :3 0
207 3c2 3e2 :2 0
3e4 20a 3e5 3bf
3e4 0 3e6 20c
0 3e7 20e 3ea
:3 0 3ea 0 3ea
3e9 3e7 3e8 :6 0
3ec 8 :3 0 211
3ee 213 3ed 3ec
:2 0 3ef 215 :2 0
3f1 0 3f1 3f0
3a7 3ef :6 0 4c8
1 :3 0 9 :3 0
5b :3 0 3f3 3f4
0 9 :3 0 4f
:2 0 66 :3 0 3f6
3f8 0 219 3f7
3fa :3 0 3fb :2 0
2c :3 0 2d :3 0
3fd 3fe 0 2c
:3 0 3d :3 0 400
401 0 e :2 0
2 :4 0 7a :2 0
3f :2 0 14 :2 0
21c 406 408 :3 0
21f 402 40a 3ff
40c 40b :2 0 2f
:3 0 40 :3 0 40e
40f 0 31 :4 0
7b :4 0 34 :2 0
35 :3 0 223 413
415 :3 0 34 :2 0
45 :4 0 226 417
419 :3 0 34 :2 0
46 :4 0 229 41b
41d :3 0 34 :2 0
39 :3 0 3a :3 0
47 :3 0 48 :3 0
422 423 0 22c
421 425 3b :4 0
22e 420 428 231
41f 42a :3 0 34
:2 0 49 :4 0 234
42c 42e :3 0 34
:2 0 37 :4 0 237
430 432 :3 0 34
:2 0 3 :3 0 23a
434 436 :3 0 34
:2 0 37 :4 0 23d
438 43a :3 0 240
410 43c :2 0 43e
243 43f 40d 43e
0 440 245 0
46a 2c :3 0 2d
:3 0 441 442 0
2c :3 0 3d :3 0
444 445 0 14
:2 0 2 :4 0 7c
:2 0 3f :2 0 14
:2 0 247 44a 44c
:3 0 24a 446 44e
443 450 44f :2 0
2f :3 0 40 :3 0
452 453 0 31
:4 0 7d :4 0 34
:2 0 35 :3 0 24e
457 459 :3 0 251
454 45b :2 0 45d
254 45e 451 45d
0 45f 256 0
46a 4c :3 0 4d
:3 0 460 461 0
47 :3 0 48 :3 0
463 464 0 3
:3 0 4e :3 0 258
462 468 :2 0 46a
25c 46b 3fc 46a
0 46c 260 0
4c8 39 :3 0 56
:3 0 57 :3 0 17
:3 0 1b :3 0 58
:3 0 59 :3 0 d
:4 0 7e 1 :8 0
47b 9 :3 0 5b
:3 0 476 477 0
5c :3 0 478 479
0 47b 262 4c5
5d :3 0 9 :3 0
5b :3 0 47e 47f
0 5c :3 0 480
481 0 4bb 2c
:3 0 2d :3 0 483
484 0 2c :3 0
3d :3 0 486 487
0 5e :2 0 2
:4 0 7f :2 0 3f
:2 0 14 :2 0 265
48c 48e :3 0 268
488 490 485 492
491 :2 0 2f :3 0
40 :3 0 494 495
0 31 :4 0 80
:4 0 34 :2 0 35
:3 0 26c 499 49b
:3 0 34 :2 0 45
:4 0 26f 49d 49f
:3 0 34 :2 0 61
:4 0 272 4a1 4a3
:3 0 34 :2 0 5c
:3 0 275 4a5 4a7
:3 0 34 :2 0 62
:4 0 278 4a9 4ab
:3 0 34 :2 0 63
:3 0 64 :3 0 14
:2 0 65 :2 0 27b
4ae 4b2 27f 4ad
4b4 :3 0 282 496
4b6 :2 0 4b8 285
4b9 493 4b8 0
4ba 287 0 4bb
289 4be :3 0 4be
0 4be 4bd 4bb
4bc :6 0 4c0 a
:3 0 28c 4c2 28e
4c1 4c0 :2 0 4c3
290 :2 0 4c5 0
4c5 4c4 47b 4c3
:6 0 4c8 1 :3 0
73 :3 0 292 4c9
39b 4c8 0 6b5
39 :3 0 15 :3 0
16 :2 0 296 4ca
4cd 4f :2 0 81
:2 0 29b 4cf 4d1
:3 0 82 :3 0 b
:3 0 6b :3 0 59
:3 0 d :4 0 83
1 :8 0 4de 9
:3 0 5b :3 0 4d9
4da 0 5c :3 0
4db 4dc 0 4de
29e 528 5d :3 0
9 :3 0 5b :3 0
4e1 4e2 0 5c
:3 0 4e3 4e4 0
51e 2c :3 0 2d
:3 0 4e6 4e7 0
2c :3 0 3d :3 0
4e9 4ea 0 5e
:2 0 2 :4 0 84
:2 0 3f :2 0 14
:2 0 2a1 4ef 4f1
:3 0 2a4 4eb 4f3
4e8 4f5 4f4 :2 0
2f :3 0 40 :3 0
4f7 4f8 0 31
:4 0 85 :4 0 34
:2 0 35 :3 0 2a8
4fc 4fe :3 0 34
:2 0 45 :4 0 2ab
500 502 :3 0 34
:2 0 61 :4 0 2ae
504 506 :3 0 34
:2 0 5c :3 0 2b1
508 50a :3 0 34
:2 0 62 :4 0 2b4
50c 50e :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 2b7 511 515
2bb 510 517 :3 0
2be 4f9 519 :2 0
51b 2c1 51c 4f6
51b 0 51d 2c3
0 51e 2c5 521
:3 0 521 0 521
520 51e 51f :6 0
523 c :3 0 2c8
525 2ca 524 523
:2 0 526 2cc :2 0
528 0 528 527
4de 526 :6 0 5a8
1 :3 0 9 :3 0
5b :3 0 52a 52b
0 9 :3 0 4f
:2 0 66 :3 0 52d
52f 0 2d0 52e
531 :3 0 532 :2 0
2c :3 0 2d :3 0
534 535 0 2c
:3 0 3d :3 0 537
538 0 e :2 0
2 :4 0 86 :2 0
3f :2 0 14 :2 0
2d3 53d 53f :3 0
2d6 539 541 536
543 542 :2 0 2f
:3 0 40 :3 0 545
546 0 31 :4 0
87 :4 0 34 :2 0
35 :3 0 2da 54a
54c :3 0 34 :2 0
45 :4 0 2dd 54e
550 :3 0 34 :2 0
46 :4 0 2e0 552
554 :3 0 34 :2 0
39 :3 0 3a :3 0
47 :3 0 48 :3 0
559 55a 0 2e3
558 55c 3b :4 0
2e5 557 55f 2e8
556 561 :3 0 34
:2 0 49 :4 0 2eb
563 565 :3 0 34
:2 0 37 :4 0 2ee
567 569 :3 0 34
:2 0 3 :3 0 2f1
56b 56d :3 0 34
:2 0 37 :4 0 2f4
56f 571 :3 0 2f7
547 573 :2 0 575
2fa 576 544 575
0 577 2fc 0
5a1 2c :3 0 2d
:3 0 578 579 0
2c :3 0 3d :3 0
57b 57c 0 14
:2 0 2 :4 0 88
:2 0 3f :2 0 14
:2 0 2fe 581 583
:3 0 301 57d 585
57a 587 586 :2 0
2f :3 0 40 :3 0
589 58a 0 31
:4 0 89 :4 0 34
:2 0 35 :3 0 305
58e 590 :3 0 308
58b 592 :2 0 594
30b 595 588 594
0 596 30d 0
5a1 4c :3 0 4d
:3 0 597 598 0
47 :3 0 48 :3 0
59a 59b 0 3
:3 0 4e :3 0 30f
599 59f :2 0 5a1
313 5a2 533 5a1
0 5a3 317 0
5a8 17 :3 0 8a
:2 0 5a4 5a5 0
5a8 73 :3 0 319
5a9 4d2 5a8 0
6b5 39 :3 0 15
:3 0 16 :2 0 31d
5aa 5ad 47 :3 0
8b :2 0 8c :3 0
5af 5b1 0 322
5b0 5b3 :3 0 5b4
:2 0 39 :3 0 15
:3 0 16 :2 0 325
5b6 5b9 8b :2 0
8d :2 0 32a 5bb
5bd :3 0 5be :2 0
5b5 5c0 5bf :2 0
39 :3 0 15 :3 0
16 :2 0 32d 5c2
5c5 47 :3 0 8b
:2 0 8e :3 0 5c7
5c9 0 332 5c8
5cb :3 0 5cc :2 0
5c1 5ce 5cd :2 0
39 :3 0 15 :3 0
16 :2 0 335 5d0
5d3 47 :3 0 8b
:2 0 8f :3 0 5d5
5d7 0 33a 5d6
5d9 :3 0 5da :2 0
5cf 5dc 5db :2 0
39 :3 0 56 :3 0
57 :3 0 17 :3 0
1b :3 0 58 :3 0
59 :3 0 3 :4 0
90 1 :8 0 5ec
9 :3 0 5b :3 0
5e7 5e8 0 5c
:3 0 5e9 5ea 0
5ec 33d 636 5d
:3 0 9 :3 0 5b
:3 0 5ef 5f0 0
5c :3 0 5f1 5f2
0 62c 2c :3 0
2d :3 0 5f4 5f5
0 2c :3 0 3d
:3 0 5f7 5f8 0
5e :2 0 2 :4 0
91 :2 0 3f :2 0
14 :2 0 340 5fd
5ff :3 0 343 5f9
601 5f6 603 602
:2 0 2f :3 0 40
:3 0 605 606 0
31 :4 0 92 :4 0
34 :2 0 35 :3 0
347 60a 60c :3 0
34 :2 0 45 :4 0
34a 60e 610 :3 0
34 :2 0 61 :4 0
34d 612 614 :3 0
34 :2 0 5c :3 0
350 616 618 :3 0
34 :2 0 62 :4 0
353 61a 61c :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 356 61f
623 35a 61e 625
:3 0 35d 607 627
:2 0 629 360 62a
604 629 0 62b
362 0 62c 364
62f :3 0 62f 0
62f 62e 62c 62d
:6 0 631 e :3 0
367 633 369 632
631 :2 0 634 36b
:2 0 636 0 636
635 5ec 634 :6 0
6b2 1 :3 0 9
:3 0 5b :3 0 638
639 0 9 :3 0
4f :2 0 66 :3 0
63b 63d 0 36f
63c 63f :3 0 640
:2 0 2c :3 0 2d
:3 0 642 643 0
2c :3 0 3d :3 0
645 646 0 e
:2 0 2 :4 0 93
:2 0 3f :2 0 14
:2 0 372 64b 64d
:3 0 375 647 64f
644 651 650 :2 0
2f :3 0 40 :3 0
653 654 0 31
:4 0 94 :4 0 34
:2 0 35 :3 0 379
658 65a :3 0 34
:2 0 45 :4 0 37c
65c 65e :3 0 34
:2 0 46 :4 0 37f
660 662 :3 0 34
:2 0 39 :3 0 3a
:3 0 47 :3 0 48
:3 0 667 668 0
382 666 66a 3b
:4 0 384 665 66d
387 664 66f :3 0
34 :2 0 49 :4 0
38a 671 673 :3 0
34 :2 0 37 :4 0
38d 675 677 :3 0
34 :2 0 3 :3 0
390 679 67b :3 0
34 :2 0 37 :4 0
393 67d 67f :3 0
396 655 681 :2 0
683 399 684 652
683 0 685 39b
0 6af 2c :3 0
2d :3 0 686 687
0 2c :3 0 3d
:3 0 689 68a 0
14 :2 0 2 :4 0
95 :2 0 3f :2 0
14 :2 0 39d 68f
691 :3 0 3a0 68b
693 688 695 694
:2 0 2f :3 0 40
:3 0 697 698 0
31 :4 0 96 :4 0
34 :2 0 35 :3 0
3a4 69c 69e :3 0
3a7 699 6a0 :2 0
6a2 3aa 6a3 696
6a2 0 6a4 3ac
0 6af 4c :3 0
4d :3 0 6a5 6a6
0 47 :3 0 48
:3 0 6a8 6a9 0
3 :3 0 4e :3 0
3ae 6a7 6ad :2 0
6af 3b2 6b0 641
6af 0 6b1 3b6
0 6b2 3b8 6b3
5dd 6b2 0 6b5
1d5 392 0 6b5
3bb 0 1e84 39
:3 0 15 :3 0 16
:2 0 3c0 6b6 6b9
4f :2 0 16 :2 0
3c5 6bb 6bd :3 0
97 :3 0 98 :3 0
99 :4 0 6c1 :4 0
6c2 :2 0 913 9
:3 0 5b :3 0 6c4
6c5 0 16 :2 0
6c6 6c7 0 913
9a :3 0 9b :3 0
9c :3 0 9d :3 0
9e :3 0 9f :3 0
a0 :3 0 a1 :3 0
55 :3 0 9b :3 0
a2 :3 0 9c :3 0
a2 :3 0 9d :3 0
a2 :3 0 9e :3 0
a2 :3 0 9f :3 0
a2 :3 0 a0 :3 0
a2 :3 0 a1 :3 0
a3 :3 0 55 :3 0
a4 :3 0 a5 :3 0
a2 :3 0 55 :3 0
9b :3 0 a2 :3 0
9b :3 0 53 :3 0
d :3 0 a6 :4 0
a7 1 :8 0 701
a8 :4 0 6ec :3 0
4e :3 0 4f :2 0
3ca 6ef 6f0 :3 0
9 :3 0 5b :3 0
6f2 6f3 0 16
:2 0 6f4 6f5 0
6f7 3cd 6fe 9
:3 0 5b :3 0 6f8
6f9 0 a9 :2 0
6fa 6fb 0 6fd
3cf 6ff 6f1 6f7
0 700 0 6fd
0 700 3d1 0
701 3d4 74b 5d
:3 0 9 :3 0 5b
:3 0 704 705 0
5c :3 0 706 707
0 741 2c :3 0
2d :3 0 709 70a
0 2c :3 0 3d
:3 0 70c 70d 0
5e :2 0 2 :4 0
aa :2 0 3f :2 0
14 :2 0 3d7 712
714 :3 0 3da 70e
716 70b 718 717
:2 0 2f :3 0 40
:3 0 71a 71b 0
31 :4 0 ab :4 0
34 :2 0 35 :3 0
3de 71f 721 :3 0
34 :2 0 45 :4 0
3e1 723 725 :3 0
34 :2 0 61 :4 0
3e4 727 729 :3 0
34 :2 0 5c :3 0
3e7 72b 72d :3 0
34 :2 0 62 :4 0
3ea 72f 731 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 3ed 734
738 3f1 733 73a
:3 0 3f4 71c 73c
:2 0 73e 3f7 73f
719 73e 0 740
3f9 0 741 3fb
744 :3 0 744 0
744 743 741 742
:6 0 746 10 :3 0
3fe 748 400 747
746 :2 0 749 402
:2 0 74b 0 74b
74a 701 749 :6 0
913 1 :3 0 97
:3 0 98 :3 0 ac
:4 0 74f :4 0 750
:2 0 913 9 :3 0
5b :3 0 752 753
0 16 :2 0 754
755 0 913 ad
:3 0 ae :3 0 9b
:3 0 a3 :3 0 53
:3 0 d :3 0 a6
:4 0 af 1 :8 0
774 a8 :4 0 75f
:3 0 4e :3 0 4f
:2 0 406 762 763
:3 0 9 :3 0 5b
:3 0 765 766 0
16 :2 0 767 768
0 76a 409 771
9 :3 0 5b :3 0
76b 76c 0 a9
:2 0 76d 76e 0
770 40b 772 764
76a 0 773 0
770 0 773 40d
0 774 410 7be
5d :3 0 9 :3 0
5b :3 0 777 778
0 5c :3 0 779
77a 0 7b4 2c
:3 0 2d :3 0 77c
77d 0 2c :3 0
3d :3 0 77f 780
0 5e :2 0 2
:4 0 b0 :2 0 3f
:2 0 14 :2 0 413
785 787 :3 0 416
781 789 77e 78b
78a :2 0 2f :3 0
40 :3 0 78d 78e
0 31 :4 0 b1
:4 0 34 :2 0 35
:3 0 41a 792 794
:3 0 34 :2 0 45
:4 0 41d 796 798
:3 0 34 :2 0 61
:4 0 420 79a 79c
:3 0 34 :2 0 5c
:3 0 423 79e 7a0
:3 0 34 :2 0 62
:4 0 426 7a2 7a4
:3 0 34 :2 0 63
:3 0 64 :3 0 14
:2 0 65 :2 0 429
7a7 7ab 42d 7a6
7ad :3 0 430 78f
7af :2 0 7b1 433
7b2 78c 7b1 0
7b3 435 0 7b4
437 7b7 :3 0 7b7
0 7b7 7b6 7b4
7b5 :6 0 7b9 12
:3 0 43a 7bb 43c
7ba 7b9 :2 0 7bc
43e :2 0 7be 0
7be 7bd 774 7bc
:6 0 913 1 :3 0
b2 :3 0 1c :3 0
75 :3 0 b3 :3 0
b3 :3 0 53 :3 0
d :3 0 b3 :3 0
9b :3 0 b4 :3 0
9b :3 0 b5 :3 0
b4 :3 0 9b :3 0
b6 :3 0 b7 :3 0
b8 :3 0 b6 :3 0
b9 :3 0 b6 :3 0
ba :3 0 bb :3 0
54 :3 0 bb :3 0
b8 :3 0 bc :3 0
b4 :3 0 9e :3 0
b4 :3 0 9f :3 0
b4 :3 0 a0 :3 0
b4 :3 0 a1 :3 0
bd :3 0 be :3 0
bf :3 0 be :3 0
c0 :3 0 be :3 0
c1 :3 0 be :3 0
c2 :3 0 c3 :3 0
82 :3 0 9a :3 0
b4 :3 0 a4 :3 0
c4 :3 0 b6 :3 0
b4 :3 0 9b :3 0
b6 :3 0 9b :3 0
a4 :3 0 a5 :3 0
c5 :3 0 c5 :3 0
59 :3 0 b4 :3 0
9c :3 0 a4 :3 0
a5 :3 0 bb :3 0
bb :3 0 59 :3 0
c5 :3 0 9c :3 0
c6 :3 0 c7 :3 0
a4 :3 0 c8 :3 0
be :3 0 be :3 0
9d :3 0 b4 :3 0
9d :3 0 b5 :3 0
c9 :3 0 ae :3 0
9b :3 0 b6 :3 0
ca :3 0 b8 :3 0
b9 :3 0 ba :3 0
c5 :3 0 54 :3 0
c5 :3 0 b8 :3 0
bc :3 0 a2 :3 0
9e :3 0 a2 :3 0
9f :3 0 a2 :3 0
a0 :3 0 a2 :3 0
a1 :3 0 bd :3 0
be :3 0 bf :3 0
be :3 0 c0 :3 0
be :3 0 c1 :3 0
be :3 0 c2 :3 0
c3 :3 0 82 :3 0
ad :3 0 c9 :3 0
a4 :3 0 cb :3 0
b6 :3 0 c9 :3 0
ae :3 0 b6 :3 0
ae :3 0 c6 :3 0
c7 :3 0 a4 :3 0
a5 :3 0 a2 :3 0
b6 :3 0 cc :3 0
a2 :3 0 59 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 a5 :3 0
c5 :3 0 c5 :3 0
59 :3 0 a2 :3 0
9c :3 0 c6 :3 0
c7 :3 0 a4 :3 0
c8 :3 0 be :3 0
be :3 0 9d :3 0
a2 :3 0 9d :3 0
b5 :3 0 c9 :3 0
ae :3 0 9b :3 0
b6 :3 0 ca :3 0
b8 :3 0 b9 :3 0
ba :3 0 c5 :3 0
54 :3 0 c5 :3 0
b8 :3 0 bc :3 0
a2 :3 0 9e :3 0
a2 :3 0 9f :3 0
a2 :3 0 a0 :3 0
a2 :3 0 a1 :3 0
bd :3 0 be :3 0
bf :3 0 be :3 0
c0 :3 0 be :3 0
c1 :3 0 be :3 0
c2 :3 0 c3 :3 0
82 :3 0 ad :3 0
c9 :3 0 a4 :3 0
cb :3 0 b6 :3 0
c9 :3 0 ae :3 0
b6 :3 0 ae :3 0
a4 :3 0 cd :3 0
ce :3 0 b6 :3 0
ae :3 0 ce :3 0
cf :3 0 c6 :3 0
c7 :3 0 a4 :3 0
a5 :3 0 a2 :3 0
ce :3 0 d0 :3 0
a2 :3 0 59 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 a5 :3 0
c5 :3 0 c5 :3 0
59 :3 0 a2 :3 0
9c :3 0 c6 :3 0
c7 :3 0 a4 :3 0
c8 :3 0 be :3 0
be :3 0 9d :3 0
a2 :3 0 9d :3 0
b5 :3 0 c9 :3 0
ae :3 0 9b :3 0
b6 :3 0 ca :3 0
b8 :3 0 b9 :3 0
ba :3 0 c5 :3 0
54 :3 0 c5 :3 0
b8 :3 0 bc :3 0
a2 :3 0 9e :3 0
a2 :3 0 9f :3 0
a2 :3 0 a0 :3 0
a2 :3 0 a1 :3 0
bd :3 0 be :3 0
bf :3 0 be :3 0
c0 :3 0 be :3 0
c1 :3 0 be :3 0
c2 :3 0 c3 :3 0
82 :3 0 ad :3 0
c9 :3 0 a4 :3 0
cb :3 0 b6 :3 0
c9 :3 0 ae :3 0
b6 :3 0 ae :3 0
a4 :3 0 d1 :3 0
ce :3 0 b6 :3 0
ae :3 0 ce :3 0
cf :3 0 c6 :3 0
c7 :3 0 a4 :3 0
a5 :3 0 a2 :3 0
ce :3 0 cc :3 0
a2 :3 0 59 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 a5 :3 0
c5 :3 0 c5 :3 0
59 :3 0 a2 :3 0
9c :3 0 c6 :3 0
c7 :3 0 a4 :3 0
c8 :3 0 be :3 0
be :3 0 9d :3 0
a2 :3 0 9d :3 0
b5 :3 0 9b :3 0
54 :4 0 d2 1
:a 0 8ef :2 0 913
7c1 8ed :2 0 2c
:3 0 2d :3 0 8f0
8f1 0 2c :3 0
3d :3 0 8f3 8f4
0 14 :2 0 2
:4 0 d3 :2 0 3f
:2 0 14 :2 0 440
8f9 8fb :3 0 443
8f5 8fd 8f2 8ff
8fe :2 0 2f :3 0
40 :3 0 901 902
0 31 :4 0 d4
:4 0 34 :2 0 35
:3 0 447 906 908
:3 0 44a 903 90a
:2 0 90c 44d 90d
900 90c 0 90e
44f 0 913 8
:3 0 1c :3 0 910
:2 0 913 73 :3 0
451 1e81 39 :3 0
15 :3 0 16 :2 0
45b 914 917 4f
:2 0 14 :2 0 460
919 91b :3 0 91c
:2 0 39 :3 0 15
:3 0 16 :2 0 463
91e 921 4f :2 0
d5 :2 0 468 923
925 :3 0 926 :2 0
91d 928 927 :2 0
97 :3 0 98 :3 0
d6 :4 0 92c :4 0
92d :2 0 ac2 9
:3 0 5b :3 0 92f
930 0 16 :2 0
931 932 0 ac2
d7 :3 0 9b :3 0
54 :3 0 d8 :3 0
9b :3 0 b3 :3 0
76 :3 0 54 :3 0
a3 :3 0 d8 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 75 :3 0
b3 :3 0 b3 :3 0
53 :3 0 d :3 0
d8 :3 0 9b :3 0
b3 :3 0 9b :3 0
d8 :3 0 53 :3 0
d :3 0 d8 :3 0
a6 :3 0 b3 :3 0
d9 :3 0 75 :3 0
da :3 0 d8 :3 0
9b :3 0 da :3 0
9b :3 0 da :3 0
db :3 0 d :4 0
dc 1 :8 0 970
a8 :4 0 95b :3 0
4e :3 0 4f :2 0
46d 95e 95f :3 0
9 :3 0 5b :3 0
961 962 0 16
:2 0 963 964 0
966 470 96d 9
:3 0 5b :3 0 967
968 0 a9 :2 0
969 96a 0 96c
472 96e 960 966
0 96f 0 96c
0 96f 474 0
970 477 9ba 5d
:3 0 9 :3 0 5b
:3 0 973 974 0
5c :3 0 975 976
0 9b0 2c :3 0
2d :3 0 978 979
0 2c :3 0 3d
:3 0 97b 97c 0
5e :2 0 2 :4 0
dd :2 0 3f :2 0
14 :2 0 47a 981
983 :3 0 47d 97d
985 97a 987 986
:2 0 2f :3 0 40
:3 0 989 98a 0
31 :4 0 de :4 0
34 :2 0 35 :3 0
481 98e 990 :3 0
34 :2 0 45 :4 0
484 992 994 :3 0
34 :2 0 61 :4 0
487 996 998 :3 0
34 :2 0 5c :3 0
48a 99a 99c :3 0
34 :2 0 62 :4 0
48d 99e 9a0 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 490 9a3
9a7 494 9a2 9a9
:3 0 497 98b 9ab
:2 0 9ad 49a 9ae
988 9ad 0 9af
49c 0 9b0 49e
9b3 :3 0 9b3 0
9b3 9b2 9b0 9b1
:6 0 9b5 14 :3 0
4a1 9b7 4a3 9b6
9b5 :2 0 9b8 4a5
:2 0 9ba 0 9ba
9b9 970 9b8 :6 0
ac2 1 :3 0 9
:3 0 5b :3 0 9bc
9bd 0 df :4 0
9bf 9c0 :3 0 9be
9c1 0 ac2 e0
:3 0 59 :3 0 b8
:3 0 a2 :3 0 ae
:3 0 a2 :3 0 ca
:3 0 a3 :3 0 55
:3 0 a4 :3 0 cb
:3 0 a2 :3 0 55
:3 0 a6 :3 0 a2
:3 0 ae :3 0 55
:3 0 9b :3 0 a4
:3 0 a5 :3 0 c5
:3 0 c5 :3 0 59
:3 0 a2 :3 0 cc
:3 0 a4 :3 0 a5
:3 0 bb :3 0 bb
:3 0 59 :3 0 c5
:3 0 9c :3 0 a4
:3 0 75 :3 0 da
:3 0 da :3 0 cf
:3 0 55 :3 0 cf
:3 0 da :3 0 d9
:3 0 55 :3 0 53
:3 0 d :3 0 55
:3 0 e1 :4 0 e2
1 :8 0 a07 a8
:4 0 9f2 :3 0 4e
:3 0 4f :2 0 4a9
9f5 9f6 :3 0 9
:3 0 5b :3 0 9f8
9f9 0 16 :2 0
9fa 9fb 0 9fd
4ac a04 9 :3 0
5b :3 0 9fe 9ff
0 a9 :2 0 a00
a01 0 a03 4ae
a05 9f7 9fd 0
a06 0 a03 0
a06 4b0 0 a07
4b3 a51 5d :3 0
9 :3 0 5b :3 0
a0a a0b 0 5c
:3 0 a0c a0d 0
a47 2c :3 0 2d
:3 0 a0f a10 0
2c :3 0 3d :3 0
a12 a13 0 5e
:2 0 2 :4 0 e3
:2 0 3f :2 0 14
:2 0 4b6 a18 a1a
:3 0 4b9 a14 a1c
a11 a1e a1d :2 0
2f :3 0 40 :3 0
a20 a21 0 31
:4 0 e4 :4 0 34
:2 0 35 :3 0 4bd
a25 a27 :3 0 34
:2 0 45 :4 0 4c0
a29 a2b :3 0 34
:2 0 61 :4 0 4c3
a2d a2f :3 0 34
:2 0 5c :3 0 4c6
a31 a33 :3 0 34
:2 0 62 :4 0 4c9
a35 a37 :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 4cc a3a a3e
4d0 a39 a40 :3 0
4d3 a22 a42 :2 0
a44 4d6 a45 a1f
a44 0 a46 4d8
0 a47 4da a4a
:3 0 a4a 0 a4a
a49 a47 a48 :6 0
a4c 16 :3 0 4dd
a4e 4df a4d a4c
:2 0 a4f 4e1 :2 0
a51 0 a51 a50
a07 a4f :6 0 ac2
1 :3 0 b2 :3 0
1d :3 0 55 :3 0
9b :3 0 59 :3 0
cf :3 0 b6 :3 0
b7 :3 0 b8 :3 0
55 :3 0 54 :3 0
b6 :3 0 ba :3 0
e5 :3 0 e6 :3 0
e5 :3 0 e7 :3 0
e8 :3 0 e5 :3 0
e9 :3 0 e5 :3 0
ea :3 0 eb :3 0
ec :3 0 ed :3 0
17 :3 0 56 :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 f3 :3 0
c3 :3 0 82 :3 0
d7 :3 0 55 :3 0
a4 :3 0 c4 :3 0
b6 :3 0 55 :3 0
9b :3 0 b6 :3 0
9b :3 0 59 :3 0
cf :3 0 b8 :3 0
54 :3 0 ba :3 0
e5 :3 0 e6 :3 0
e5 :3 0 e7 :3 0
e8 :3 0 e5 :3 0
e9 :3 0 e5 :3 0
ea :3 0 eb :3 0
ec :3 0 ed :3 0
17 :3 0 56 :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 f3 :3 0
c3 :3 0 82 :3 0
e0 :3 0 54 :4 0
f4 1 :a 0 a9e
:2 0 ac2 a54 a9c
:2 0 2c :3 0 2d
:3 0 a9f aa0 0
2c :3 0 3d :3 0
aa2 aa3 0 14
:2 0 2 :4 0 f5
:2 0 3f :2 0 14
:2 0 4e3 aa8 aaa
:3 0 4e6 aa4 aac
aa1 aae aad :2 0
2f :3 0 40 :3 0
ab0 ab1 0 31
:4 0 f6 :4 0 34
:2 0 35 :3 0 4ea
ab5 ab7 :3 0 4ed
ab2 ab9 :2 0 abb
4f0 abc aaf abb
0 abd 4f2 0
ac2 8 :3 0 1d
:3 0 abf :2 0 ac2
73 :3 0 4f4 ac3
929 ac2 0 1e83
39 :3 0 15 :3 0
16 :2 0 4fd ac4
ac7 4f :2 0 50
:2 0 502 ac9 acb
:3 0 b2 :3 0 1e
:3 0 da :3 0 76
:3 0 da :3 0 76
:3 0 55 :3 0 cf
:3 0 59 :3 0 55
:3 0 ae :3 0 b6
:3 0 ca :3 0 b8
:3 0 54 :3 0 55
:3 0 cf :3 0 55
:3 0 f7 :3 0 da
:3 0 e6 :3 0 da
:3 0 e7 :3 0 da
:3 0 f1 :3 0 da
:3 0 f8 :3 0 da
:3 0 f9 :3 0 17
:3 0 56 :3 0 55
:3 0 fa :3 0 55
:3 0 fb :3 0 fc
:3 0 b8 :3 0 fd
:3 0 39 :3 0 55
:3 0 fe :3 0 55
:3 0 fb :3 0 fe
:3 0 ff :3 0 b8
:3 0 100 :3 0 da
:3 0 bf :3 0 da
:3 0 101 :3 0 da
:3 0 c1 :3 0 da
:3 0 102 :3 0 103
:3 0 55 :3 0 104
:3 0 da :3 0 f3
:3 0 da :3 0 d9
:3 0 da :3 0 105
:3 0 106 :3 0 b8
:3 0 107 :3 0 da
:3 0 ed :3 0 da
:3 0 108 :3 0 da
:3 0 109 :3 0 da
:3 0 10a :3 0 da
:3 0 10b :3 0 da
:3 0 10c :3 0 10d
:3 0 da :3 0 10e
:3 0 a3 :3 0 55
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 75
:3 0 da :3 0 da
:3 0 db :3 0 d
:3 0 55 :3 0 cf
:3 0 da :3 0 cf
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 cb
:3 0 b6 :3 0 55
:3 0 9b :3 0 b6
:3 0 ae :3 0 c6
:3 0 c7 :3 0 a4
:3 0 10f :3 0 fc
:3 0 55 :3 0 fb
:3 0 fc :3 0 59
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 10f
:3 0 ff :3 0 39
:3 0 55 :3 0 fe
:3 0 55 :3 0 fb
:3 0 ff :3 0 59
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 110
:3 0 106 :3 0 106
:3 0 59 :3 0 da
:3 0 105 :3 0 55
:3 0 59 :3 0 d
:3 0 55 :3 0 a6
:3 0 b8 :4 0 111
1 :a 0 b5c :2 0
b80 ace b5a :2 0
2c :3 0 2d :3 0
b5d b5e 0 2c
:3 0 3d :3 0 b60
b61 0 14 :2 0
2 :4 0 112 :2 0
3f :2 0 14 :2 0
505 b66 b68 :3 0
508 b62 b6a b5f
b6c b6b :2 0 2f
:3 0 40 :3 0 b6e
b6f 0 31 :4 0
113 :4 0 34 :2 0
35 :3 0 50c b73
b75 :3 0 50f b70
b77 :2 0 b79 512
b7a b6d b79 0
b7b 514 0 b80
8 :3 0 1e :3 0
b7d :2 0 b80 73
:3 0 516 b81 acc
b80 0 1e83 39
:3 0 15 :3 0 16
:2 0 51a b82 b85
4f :2 0 51 :2 0
51f b87 b89 :3 0
114 :3 0 39 :3 0
18 :3 0 16 :2 0
522 b8c b8f 525
b8b b91 8b :2 0
16 :2 0 529 b93
b95 :3 0 19 :3 0
16 :2 0 b97 b98
0 f0e 115 :3 0
19 :3 0 75 :3 0
53 :3 0 10 :3 0
db :3 0 d :4 0
116 1 :8 0 ba7
9 :3 0 5b :3 0
ba2 ba3 0 5c
:3 0 ba4 ba5 0
ba7 52c bf1 5d
:3 0 9 :3 0 5b
:3 0 baa bab 0
5c :3 0 bac bad
0 be7 2c :3 0
2d :3 0 baf bb0
0 2c :3 0 3d
:3 0 bb2 bb3 0
5e :2 0 2 :4 0
117 :2 0 3f :2 0
14 :2 0 52f bb8
bba :3 0 532 bb4
bbc bb1 bbe bbd
:2 0 2f :3 0 40
:3 0 bc0 bc1 0
31 :4 0 118 :4 0
34 :2 0 35 :3 0
536 bc5 bc7 :3 0
34 :2 0 45 :4 0
539 bc9 bcb :3 0
34 :2 0 61 :4 0
53c bcd bcf :3 0
34 :2 0 5c :3 0
53f bd1 bd3 :3 0
34 :2 0 62 :4 0
542 bd5 bd7 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 545 bda
bde 549 bd9 be0
:3 0 54c bc2 be2
:2 0 be4 54f be5
bbf be4 0 be6
551 0 be7 553
bea :3 0 bea 0
bea be9 be7 be8
:6 0 bec 18 :3 0
556 bee 558 bed
bec :2 0 bef 55a
:2 0 bf1 0 bf1
bf0 ba7 bef :6 0
f0e 1 :3 0 39
:3 0 19 :3 0 16
:2 0 55c bf3 bf6
4f :2 0 16 :2 0
561 bf8 bfa :3 0
13 :3 0 14 :4 0
bfc bfd 0 bff
564 cef 115 :3 0
19 :3 0 119 :3 0
75 :3 0 53 :3 0
10 :3 0 db :3 0
d :3 0 11a :4 0
11b 1 :8 0 c0f
9 :3 0 5b :3 0
c0a c0b 0 5c
:3 0 c0c c0d 0
c0f 566 c59 5d
:3 0 9 :3 0 5b
:3 0 c12 c13 0
5c :3 0 c14 c15
0 c4f 2c :3 0
2d :3 0 c17 c18
0 2c :3 0 3d
:3 0 c1a c1b 0
5e :2 0 2 :4 0
11c :2 0 3f :2 0
14 :2 0 569 c20
c22 :3 0 56c c1c
c24 c19 c26 c25
:2 0 2f :3 0 40
:3 0 c28 c29 0
31 :4 0 11d :4 0
34 :2 0 35 :3 0
570 c2d c2f :3 0
34 :2 0 45 :4 0
573 c31 c33 :3 0
34 :2 0 61 :4 0
576 c35 c37 :3 0
34 :2 0 5c :3 0
579 c39 c3b :3 0
34 :2 0 62 :4 0
57c c3d c3f :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 57f c42
c46 583 c41 c48
:3 0 586 c2a c4a
:2 0 c4c 589 c4d
c27 c4c 0 c4e
58b 0 c4f 58d
c52 :3 0 c52 0
c52 c51 c4f c50
:6 0 c54 1a :3 0
590 c56 592 c55
c54 :2 0 c57 594
:2 0 c59 0 c59
c58 c0f c57 :6 0
cee 1 :3 0 39
:3 0 19 :3 0 16
:2 0 596 c5b c5e
4f :2 0 16 :2 0
59b c60 c62 :3 0
115 :3 0 19 :3 0
119 :3 0 75 :3 0
b3 :3 0 a4 :3 0
11e :3 0 11f :3 0
11f :3 0 59 :3 0
b3 :3 0 53 :3 0
11f :3 0 9b :3 0
b3 :3 0 9b :3 0
b3 :3 0 53 :3 0
10 :3 0 b3 :3 0
db :3 0 d :3 0
120 :3 0 63 :3 0
b3 :3 0 121 :3 0
11f :3 0 122 :4 0
123 1 :8 0 c86
9 :3 0 5b :3 0
c81 c82 0 5c
:3 0 c83 c84 0
c86 59e cd0 5d
:3 0 9 :3 0 5b
:3 0 c89 c8a 0
5c :3 0 c8b c8c
0 cc6 2c :3 0
2d :3 0 c8e c8f
0 2c :3 0 3d
:3 0 c91 c92 0
5e :2 0 2 :4 0
124 :2 0 3f :2 0
14 :2 0 5a1 c97
c99 :3 0 5a4 c93
c9b c90 c9d c9c
:2 0 2f :3 0 40
:3 0 c9f ca0 0
31 :4 0 125 :4 0
34 :2 0 35 :3 0
5a8 ca4 ca6 :3 0
34 :2 0 45 :4 0
5ab ca8 caa :3 0
34 :2 0 61 :4 0
5ae cac cae :3 0
34 :2 0 5c :3 0
5b1 cb0 cb2 :3 0
34 :2 0 62 :4 0
5b4 cb4 cb6 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 5b7 cb9
cbd 5bb cb8 cbf
:3 0 5be ca1 cc1
:2 0 cc3 5c1 cc4
c9e cc3 0 cc5
5c3 0 cc6 5c5
cc9 :3 0 cc9 0
cc9 cc8 cc6 cc7
:6 0 ccb 1c :3 0
5c8 ccd 5ca ccc
ccb :2 0 cce 5cc
:2 0 cd0 0 cd0
ccf c86 cce :6 0
ce6 1 :3 0 39
:3 0 19 :3 0 16
:2 0 5ce cd2 cd5
4f :2 0 16 :2 0
5d3 cd7 cd9 :3 0
13 :3 0 50 :4 0
cdb cdc 0 cde
5d6 ce3 13 :3 0
14 :4 0 cdf ce0
0 ce2 5d8 ce4
cda cde 0 ce5
0 ce2 0 ce5
5da 0 ce6 5dd
ceb 13 :3 0 14
:4 0 ce7 ce8 0
cea 5e0 cec c63
ce6 0 ced 0
cea 0 ced 5e2
0 cee 5e5 cf0
bfb bff 0 cf1
0 cee 0 cf1
5e8 0 f0e b2
:3 0 1f :3 0 da
:3 0 59 :3 0 55
:3 0 9b :3 0 da
:3 0 b8 :3 0 da
:3 0 54 :3 0 cf
:3 0 55 :3 0 f7
:3 0 da :3 0 f8
:3 0 da :3 0 f9
:3 0 da :3 0 126
:3 0 da :3 0 127
:3 0 da :3 0 f8
:3 0 e6 :3 0 da
:3 0 f9 :3 0 e7
:3 0 da :3 0 128
:3 0 da :3 0 e8
:3 0 f1 :3 0 da
:3 0 128 :3 0 da
:3 0 e8 :3 0 da
:3 0 129 :3 0 ec
:3 0 12a :3 0 da
:3 0 12b :3 0 da
:3 0 129 :3 0 12c
:3 0 12d :3 0 da
:3 0 129 :3 0 12d
:3 0 da :3 0 128
:3 0 da :3 0 e8
:3 0 12e :3 0 e5
:3 0 12f :3 0 e5
:3 0 130 :3 0 131
:3 0 da :3 0 132
:3 0 da :3 0 133
:3 0 da :3 0 134
:3 0 da :3 0 121
:3 0 da :3 0 135
:3 0 da :3 0 129
:3 0 136 :3 0 da
:3 0 137 :3 0 da
:3 0 138 :3 0 da
:3 0 139 :3 0 13a
:3 0 17 :3 0 56
:3 0 fa :3 0 fb
:3 0 fd :3 0 fe
:3 0 100 :3 0 bf
:3 0 101 :3 0 c1
:3 0 102 :3 0 103
:3 0 da :3 0 104
:3 0 f3 :3 0 da
:3 0 13b :3 0 da
:3 0 13c :3 0 da
:3 0 13d :3 0 13e
:3 0 d9 :3 0 105
:3 0 13f :3 0 ed
:3 0 108 :3 0 109
:3 0 10a :3 0 10b
:3 0 10c :3 0 10d
:3 0 140 :3 0 10e
:3 0 13 :3 0 11a
:3 0 141 :3 0 da
:3 0 142 :3 0 da
:3 0 143 :3 0 144
:3 0 1b :3 0 da
:3 0 145 :3 0 e5
:3 0 145 :3 0 1b
:3 0 da :3 0 146
:3 0 e5 :3 0 146
:3 0 1b :3 0 da
:3 0 147 :3 0 148
:3 0 da :3 0 12e
:3 0 149 :3 0 14a
:3 0 14b :3 0 14c
:3 0 14d :3 0 14e
:3 0 14f :3 0 150
:3 0 151 :3 0 152
:3 0 58 :3 0 da
:3 0 c6 :3 0 a4
:3 0 a3 :3 0 55
:3 0 55 :3 0 59
:3 0 da :3 0 59
:3 0 55 :3 0 9b
:3 0 f :3 0 c6
:3 0 c7 :3 0 a4
:3 0 10f :3 0 fc
:3 0 55 :3 0 fb
:3 0 fc :3 0 59
:3 0 da :3 0 53
:3 0 10 :3 0 da
:3 0 59 :3 0 d
:3 0 da :3 0 76
:3 0 da :3 0 76
:3 0 55 :3 0 cf
:3 0 59 :3 0 55
:3 0 9b :3 0 55
:3 0 a6 :3 0 b6
:3 0 ca :3 0 cb
:3 0 b6 :3 0 55
:3 0 9b :3 0 b6
:3 0 ae :3 0 a2
:3 0 b7 :3 0 c4
:3 0 a2 :3 0 55
:3 0 9b :3 0 a2
:3 0 9b :3 0 b8
:3 0 da :3 0 76
:3 0 55 :3 0 a6
:3 0 54 :3 0 55
:3 0 cf :3 0 55
:3 0 f7 :3 0 da
:3 0 f8 :3 0 da
:3 0 153 :3 0 f9
:3 0 da :3 0 126
:3 0 47 :3 0 154
:3 0 da :3 0 126
:3 0 47 :3 0 155
:3 0 47 :3 0 156
:3 0 da :3 0 126
:3 0 126 :3 0 da
:3 0 127 :3 0 47
:3 0 157 :3 0 47
:3 0 158 :3 0 da
:3 0 127 :3 0 127
:3 0 da :3 0 159
:3 0 e6 :3 0 da
:3 0 153 :3 0 e7
:3 0 11a :3 0 15a
:3 0 f1 :3 0 f1
:3 0 11a :3 0 15a
:3 0 129 :3 0 f1
:3 0 ec :3 0 da
:3 0 15b :3 0 da
:3 0 15c :3 0 da
:3 0 15b :3 0 da
:3 0 15c :3 0 12a
:3 0 12b :3 0 da
:3 0 129 :3 0 12c
:3 0 12d :3 0 da
:3 0 129 :3 0 12d
:3 0 f1 :3 0 15a
:3 0 12e :3 0 da
:3 0 12f :3 0 da
:3 0 130 :3 0 da
:3 0 131 :3 0 da
:3 0 132 :3 0 da
:3 0 133 :3 0 da
:3 0 134 :3 0 da
:3 0 121 :3 0 da
:3 0 135 :3 0 da
:3 0 129 :3 0 136
:3 0 137 :3 0 138
:3 0 13a :3 0 17
:3 0 56 :3 0 55
:3 0 fa :3 0 55
:3 0 fb :3 0 fc
:3 0 b8 :3 0 fd
:3 0 39 :3 0 55
:3 0 fe :3 0 55
:3 0 fb :3 0 fe
:3 0 ff :3 0 b8
:3 0 100 :3 0 da
:3 0 bf :3 0 da
:3 0 101 :3 0 da
:3 0 c1 :3 0 da
:3 0 102 :3 0 55
:3 0 a6 :3 0 a2
:3 0 103 :3 0 c4
:3 0 a2 :3 0 55
:3 0 9b :3 0 a2
:3 0 9b :3 0 103
:3 0 55 :3 0 104
:3 0 da :3 0 f3
:3 0 da :3 0 13b
:3 0 da :3 0 13c
:3 0 da :3 0 13e
:3 0 da :3 0 d9
:3 0 da :3 0 105
:3 0 106 :3 0 b8
:3 0 13f :3 0 da
:3 0 ed :3 0 da
:3 0 108 :3 0 da
:3 0 109 :3 0 da
:3 0 10a :3 0 da
:3 0 10b :3 0 da
:3 0 10c :3 0 da
:3 0 10d :3 0 da
:3 0 140 :3 0 da
:3 0 10e :3 0 da
:3 0 11a :3 0 da
:3 0 11a :3 0 11a
:3 0 da :3 0 141
:3 0 142 :3 0 da
:3 0 143 :3 0 144
:3 0 1b :3 0 39
:3 0 da :3 0 145
:3 0 da :3 0 159
:3 0 e5 :3 0 145
:3 0 1b :3 0 39
:3 0 da :3 0 146
:3 0 da :3 0 153
:3 0 e5 :3 0 146
:3 0 1b :3 0 da
:3 0 148 :3 0 da
:3 0 134 :3 0 da
:3 0 148 :3 0 148
:3 0 da :3 0 12b
:3 0 149 :3 0 14a
:3 0 14b :3 0 da
:3 0 14c :3 0 15d
:3 0 b8 :3 0 14d
:3 0 da :3 0 14e
:3 0 15e :3 0 b8
:3 0 14f :3 0 da
:3 0 150 :3 0 da
:3 0 151 :3 0 15f
:3 0 b8 :3 0 152
:3 0 a3 :3 0 55
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 75
:3 0 da :3 0 55
:3 0 cf :3 0 da
:3 0 cf :3 0 c6
:3 0 c7 :3 0 a4
:3 0 10f :3 0 fc
:3 0 55 :3 0 fb
:3 0 fc :3 0 59
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 10f
:3 0 ff :3 0 39
:3 0 55 :3 0 fe
:3 0 55 :3 0 fb
:3 0 ff :3 0 59
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 110
:3 0 106 :3 0 106
:3 0 59 :3 0 da
:3 0 105 :3 0 c6
:3 0 c7 :3 0 a4
:3 0 160 :3 0 15d
:3 0 15d :3 0 59
:3 0 da :3 0 14c
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 160
:3 0 15e :3 0 15e
:3 0 59 :3 0 da
:3 0 14e :3 0 c6
:3 0 c7 :3 0 a4
:3 0 161 :3 0 15f
:3 0 15f :3 0 59
:3 0 da :3 0 151
:3 0 55 :3 0 53
:3 0 10 :3 0 55
:3 0 59 :3 0 d
:3 0 55 :3 0 104
:3 0 14a :3 0 b8
:4 0 162 1 :a 0
eeb :2 0 f0e cf3
ee9 :2 0 2c :3 0
2d :3 0 eec eed
0 2c :3 0 3d
:3 0 eef ef0 0
14 :2 0 2 :4 0
163 :2 0 3f :2 0
14 :2 0 5eb ef5
ef7 :3 0 5ee ef1
ef9 eee efb efa
:2 0 2f :3 0 40
:3 0 efd efe 0
31 :4 0 164 :4 0
34 :2 0 35 :3 0
5f2 f02 f04 :3 0
5f5 eff f06 :2 0
f08 5f8 f09 efc
f08 0 f0a 5fa
0 f0e 8 :3 0
1f :3 0 f0c :2 0
f0e 5fc 1052 b2
:3 0 20 :3 0 da
:3 0 76 :3 0 da
:3 0 76 :3 0 55
:3 0 cf :3 0 59
:3 0 55 :3 0 9b
:3 0 55 :3 0 a6
:3 0 b6 :3 0 ca
:3 0 cb :3 0 b6
:3 0 55 :3 0 9b
:3 0 b6 :3 0 ae
:3 0 a2 :3 0 b7
:3 0 c4 :3 0 a2
:3 0 55 :3 0 9b
:3 0 a2 :3 0 9b
:3 0 b8 :3 0 da
:3 0 76 :3 0 55
:3 0 a6 :3 0 54
:3 0 55 :3 0 cf
:3 0 55 :3 0 f7
:3 0 da :3 0 f8
:3 0 da :3 0 f9
:3 0 da :3 0 126
:3 0 da :3 0 127
:3 0 da :3 0 159
:3 0 e6 :3 0 da
:3 0 153 :3 0 e7
:3 0 165 :3 0 f1
:3 0 11a :3 0 15a
:3 0 f1 :3 0 ec
:3 0 da :3 0 15c
:3 0 12a :3 0 da
:3 0 12b :3 0 12e
:3 0 da :3 0 12f
:3 0 da :3 0 130
:3 0 da :3 0 131
:3 0 da :3 0 132
:3 0 da :3 0 133
:3 0 da :3 0 134
:3 0 da :3 0 121
:3 0 da :3 0 135
:3 0 da :3 0 129
:3 0 136 :3 0 137
:3 0 138 :3 0 13a
:3 0 17 :3 0 56
:3 0 55 :3 0 fa
:3 0 55 :3 0 fb
:3 0 fc :3 0 b8
:3 0 fd :3 0 39
:3 0 55 :3 0 fe
:3 0 55 :3 0 fb
:3 0 fe :3 0 ff
:3 0 b8 :3 0 100
:3 0 da :3 0 bf
:3 0 da :3 0 101
:3 0 da :3 0 c1
:3 0 da :3 0 102
:3 0 55 :3 0 a6
:3 0 a2 :3 0 103
:3 0 c4 :3 0 a2
:3 0 55 :3 0 9b
:3 0 a2 :3 0 9b
:3 0 103 :3 0 55
:3 0 104 :3 0 da
:3 0 f3 :3 0 da
:3 0 13b :3 0 da
:3 0 13c :3 0 da
:3 0 13e :3 0 da
:3 0 d9 :3 0 da
:3 0 105 :3 0 106
:3 0 b8 :3 0 13f
:3 0 da :3 0 ed
:3 0 da :3 0 108
:3 0 da :3 0 109
:3 0 da :3 0 10a
:3 0 da :3 0 10b
:3 0 da :3 0 10c
:3 0 da :3 0 10d
:3 0 da :3 0 140
:3 0 da :3 0 10e
:3 0 da :3 0 11a
:3 0 da :3 0 11a
:3 0 11a :3 0 da
:3 0 141 :3 0 142
:3 0 144 :3 0 da
:3 0 145 :3 0 da
:3 0 146 :3 0 da
:3 0 148 :3 0 da
:3 0 12b :3 0 149
:3 0 14a :3 0 da
:3 0 76 :3 0 da
:3 0 d9 :3 0 da
:3 0 76 :3 0 da
:3 0 145 :3 0 da
:3 0 159 :3 0 da
:3 0 146 :3 0 da
:3 0 153 :3 0 14b
:3 0 da :3 0 14c
:3 0 15d :3 0 b8
:3 0 14d :3 0 da
:3 0 14e :3 0 15e
:3 0 b8 :3 0 14f
:3 0 da :3 0 150
:3 0 da :3 0 151
:3 0 15f :3 0 b8
:3 0 152 :3 0 a3
:3 0 55 :3 0 c6
:3 0 c7 :3 0 a4
:3 0 75 :3 0 da
:3 0 55 :3 0 cf
:3 0 da :3 0 cf
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 10f
:3 0 fc :3 0 55
:3 0 fb :3 0 fc
:3 0 59 :3 0 c6
:3 0 c7 :3 0 a4
:3 0 10f :3 0 ff
:3 0 39 :3 0 55
:3 0 fe :3 0 55
:3 0 fb :3 0 ff
:3 0 59 :3 0 c6
:3 0 c7 :3 0 a4
:3 0 110 :3 0 106
:3 0 106 :3 0 59
:3 0 da :3 0 105
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 160
:3 0 15d :3 0 15d
:3 0 59 :3 0 da
:3 0 14c :3 0 c6
:3 0 c7 :3 0 a4
:3 0 160 :3 0 15e
:3 0 15e :3 0 59
:3 0 da :3 0 14e
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 161
:3 0 15f :3 0 15f
:3 0 59 :3 0 da
:3 0 151 :3 0 55
:3 0 104 :3 0 55
:3 0 59 :3 0 d
:3 0 54 :3 0 b8
:4 0 166 1 :a 0
102e :2 0 1051 f10
102c :2 0 2c :3 0
2d :3 0 102f 1030
0 2c :3 0 3d
:3 0 1032 1033 0
14 :2 0 2 :4 0
167 :2 0 3f :2 0
14 :2 0 603 1038
103a :3 0 606 1034
103c 1031 103e 103d
:2 0 2f :3 0 40
:3 0 1040 1041 0
31 :4 0 168 :4 0
34 :2 0 35 :3 0
60a 1045 1047 :3 0
60d 1042 1049 :2 0
104b 610 104c 103f
104b 0 104d 612
0 1051 8 :3 0
20 :3 0 104f :2 0
1051 614 1053 b96
f0e 0 1054 0
1051 0 1054 618
0 1056 73 :3 0
61b 1057 b8a 1056
0 1e83 39 :3 0
15 :3 0 16 :2 0
61d 1058 105b 4f
:2 0 169 :2 0 622
105d 105f :3 0 97
:3 0 98 :3 0 16a
:4 0 1063 :4 0 1064
:2 0 1204 9 :3 0
5b :3 0 1066 1067
0 16 :2 0 1068
1069 0 1204 16b
:3 0 9b :3 0 a6
:3 0 e6 :3 0 e7
:3 0 e8 :3 0 e9
:3 0 ea :3 0 eb
:3 0 ec :3 0 9b
:3 0 a6 :3 0 16c
:3 0 e6 :3 0 e6
:3 0 16d :3 0 e7
:3 0 e7 :3 0 16e
:3 0 f1 :3 0 e8
:3 0 16c :3 0 16f
:3 0 e9 :3 0 16d
:3 0 170 :3 0 ea
:3 0 16e :3 0 15a
:3 0 eb :3 0 16e
:3 0 134 :3 0 ec
:3 0 75 :3 0 53
:3 0 d :3 0 d9
:3 0 9b :3 0 a6
:4 0 171 1 :8 0
10a8 a8 :4 0 1093
:3 0 4e :3 0 4f
:2 0 627 1096 1097
:3 0 9 :3 0 5b
:3 0 1099 109a 0
16 :2 0 109b 109c
0 109e 62a 10a5
9 :3 0 5b :3 0
109f 10a0 0 a9
:2 0 10a1 10a2 0
10a4 62c 10a6 1098
109e 0 10a7 0
10a4 0 10a7 62e
0 10a8 631 10f2
5d :3 0 9 :3 0
5b :3 0 10ab 10ac
0 5c :3 0 10ad
10ae 0 10e8 2c
:3 0 2d :3 0 10b0
10b1 0 2c :3 0
3d :3 0 10b3 10b4
0 5e :2 0 2
:4 0 172 :2 0 3f
:2 0 14 :2 0 634
10b9 10bb :3 0 637
10b5 10bd 10b2 10bf
10be :2 0 2f :3 0
40 :3 0 10c1 10c2
0 31 :4 0 173
:4 0 34 :2 0 35
:3 0 63b 10c6 10c8
:3 0 34 :2 0 45
:4 0 63e 10ca 10cc
:3 0 34 :2 0 61
:4 0 641 10ce 10d0
:3 0 34 :2 0 5c
:3 0 644 10d2 10d4
:3 0 34 :2 0 62
:4 0 647 10d6 10d8
:3 0 34 :2 0 63
:3 0 64 :3 0 14
:2 0 65 :2 0 64a
10db 10df 64e 10da
10e1 :3 0 651 10c3
10e3 :2 0 10e5 654
10e6 10c0 10e5 0
10e7 656 0 10e8
658 10eb :3 0 10eb
0 10eb 10ea 10e8
10e9 :6 0 10ed 1e
:3 0 65b 10ef 65d
10ee 10ed :2 0 10f0
65f :2 0 10f2 0
10f2 10f1 10a8 10f0
:6 0 1204 1 :3 0
9 :3 0 5b :3 0
10f4 10f5 0 df
:4 0 10f7 10f8 :3 0
10f6 10f9 0 1204
e0 :3 0 59 :3 0
b8 :3 0 e6 :3 0
e7 :3 0 e8 :3 0
e9 :3 0 ea :3 0
eb :3 0 ec :3 0
a2 :3 0 ae :3 0
a2 :3 0 ca :3 0
55 :3 0 e6 :3 0
55 :3 0 e7 :3 0
55 :3 0 e8 :3 0
55 :3 0 e9 :3 0
55 :3 0 ea :3 0
55 :3 0 eb :3 0
55 :3 0 ec :3 0
16b :3 0 55 :3 0
a4 :3 0 cb :3 0
a2 :3 0 55 :3 0
a6 :3 0 a2 :3 0
ae :3 0 55 :3 0
9b :3 0 a4 :3 0
a5 :3 0 c5 :3 0
c5 :3 0 59 :3 0
a2 :3 0 cc :3 0
a4 :3 0 a5 :3 0
bb :3 0 bb :3 0
59 :3 0 c5 :3 0
9c :4 0 174 1
:8 0 1146 a8 :4 0
1131 :3 0 4e :3 0
4f :2 0 663 1134
1135 :3 0 9 :3 0
5b :3 0 1137 1138
0 16 :2 0 1139
113a 0 113c 666
1143 9 :3 0 5b
:3 0 113d 113e 0
a9 :2 0 113f 1140
0 1142 668 1144
1136 113c 0 1145
0 1142 0 1145
66a 0 1146 66d
1190 5d :3 0 9
:3 0 5b :3 0 1149
114a 0 5c :3 0
114b 114c 0 1186
2c :3 0 2d :3 0
114e 114f 0 2c
:3 0 3d :3 0 1151
1152 0 5e :2 0
2 :4 0 175 :2 0
3f :2 0 14 :2 0
670 1157 1159 :3 0
673 1153 115b 1150
115d 115c :2 0 2f
:3 0 40 :3 0 115f
1160 0 31 :4 0
176 :4 0 34 :2 0
35 :3 0 677 1164
1166 :3 0 34 :2 0
45 :4 0 67a 1168
116a :3 0 34 :2 0
61 :4 0 67d 116c
116e :3 0 34 :2 0
5c :3 0 680 1170
1172 :3 0 34 :2 0
62 :4 0 683 1174
1176 :3 0 34 :2 0
63 :3 0 64 :3 0
14 :2 0 65 :2 0
686 1179 117d 68a
1178 117f :3 0 68d
1161 1181 :2 0 1183
690 1184 115e 1183
0 1185 692 0
1186 694 1189 :3 0
1189 0 1189 1188
1186 1187 :6 0 118b
20 :3 0 697 118d
699 118c 118b :2 0
118e 69b :2 0 1190
0 1190 118f 1146
118e :6 0 1204 1
:3 0 b2 :3 0 21
:3 0 55 :3 0 9b
:3 0 59 :3 0 cf
:3 0 b6 :3 0 b7
:3 0 b8 :3 0 54
:3 0 b6 :3 0 ba
:3 0 55 :3 0 e6
:3 0 55 :3 0 e7
:3 0 55 :3 0 e8
:3 0 55 :3 0 e9
:3 0 55 :3 0 ea
:3 0 55 :3 0 eb
:3 0 55 :3 0 ec
:3 0 ed :3 0 17
:3 0 56 :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 b6
:3 0 103 :3 0 c3
:3 0 82 :3 0 16b
:3 0 55 :3 0 a4
:3 0 c4 :3 0 b6
:3 0 55 :3 0 a6
:3 0 55 :3 0 9b
:3 0 b6 :3 0 9b
:3 0 59 :3 0 cf
:3 0 b8 :3 0 54
:3 0 ba :3 0 e6
:3 0 e7 :3 0 e8
:3 0 e9 :3 0 ea
:3 0 eb :3 0 ec
:3 0 ed :3 0 17
:3 0 56 :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 103
:3 0 c3 :3 0 82
:3 0 e0 :3 0 54
:4 0 177 1 :a 0
11e0 :2 0 1204 1193
11de :2 0 2c :3 0
2d :3 0 11e1 11e2
0 2c :3 0 3d
:3 0 11e4 11e5 0
14 :2 0 2 :4 0
178 :2 0 3f :2 0
14 :2 0 69d 11ea
11ec :3 0 6a0 11e6
11ee 11e3 11f0 11ef
:2 0 2f :3 0 40
:3 0 11f2 11f3 0
31 :4 0 179 :4 0
34 :2 0 35 :3 0
6a4 11f7 11f9 :3 0
6a7 11f4 11fb :2 0
11fd 6aa 11fe 11f1
11fd 0 11ff 6ac
0 1204 8 :3 0
21 :3 0 1201 :2 0
1204 73 :3 0 6ae
1205 1060 1204 0
1e83 39 :3 0 15
:3 0 16 :2 0 6b7
1206 1209 4f :2 0
17a :2 0 6bc 120b
120d :3 0 97 :3 0
98 :3 0 16a :4 0
1211 :4 0 1212 :2 0
13fd 9 :3 0 5b
:3 0 1214 1215 0
16 :2 0 1216 1217
0 13fd 16b :3 0
9b :3 0 a6 :3 0
e6 :3 0 e7 :3 0
e8 :3 0 e9 :3 0
ea :3 0 eb :3 0
ec :3 0 9b :3 0
a6 :3 0 16c :3 0
e6 :3 0 e6 :3 0
16d :3 0 e7 :3 0
e7 :3 0 16e :3 0
f1 :3 0 e8 :3 0
16c :3 0 16f :3 0
e9 :3 0 16d :3 0
170 :3 0 ea :3 0
16e :3 0 15a :3 0
eb :3 0 16e :3 0
134 :3 0 ec :3 0
75 :3 0 53 :3 0
d :3 0 d9 :3 0
9b :3 0 a6 :4 0
171 1 :8 0 1256
a8 :4 0 1241 :3 0
4e :3 0 4f :2 0
6c1 1244 1245 :3 0
9 :3 0 5b :3 0
1247 1248 0 16
:2 0 1249 124a 0
124c 6c4 1253 9
:3 0 5b :3 0 124d
124e 0 a9 :2 0
124f 1250 0 1252
6c6 1254 1246 124c
0 1255 0 1252
0 1255 6c8 0
1256 6cb 12a0 5d
:3 0 9 :3 0 5b
:3 0 1259 125a 0
5c :3 0 125b 125c
0 1296 2c :3 0
2d :3 0 125e 125f
0 2c :3 0 3d
:3 0 1261 1262 0
5e :2 0 2 :4 0
17b :2 0 3f :2 0
14 :2 0 6ce 1267
1269 :3 0 6d1 1263
126b 1260 126d 126c
:2 0 2f :3 0 40
:3 0 126f 1270 0
31 :4 0 17c :4 0
34 :2 0 35 :3 0
6d5 1274 1276 :3 0
34 :2 0 45 :4 0
6d8 1278 127a :3 0
34 :2 0 61 :4 0
6db 127c 127e :3 0
34 :2 0 5c :3 0
6de 1280 1282 :3 0
34 :2 0 62 :4 0
6e1 1284 1286 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 6e4 1289
128d 6e8 1288 128f
:3 0 6eb 1271 1291
:2 0 1293 6ee 1294
126e 1293 0 1295
6f0 0 1296 6f2
1299 :3 0 1299 0
1299 1298 1296 1297
:6 0 129b 22 :3 0
6f5 129d 6f7 129c
129b :2 0 129e 6f9
:2 0 12a0 0 12a0
129f 1256 129e :6 0
13fd 1 :3 0 9
:3 0 5b :3 0 12a2
12a3 0 df :4 0
12a5 12a6 :3 0 12a4
12a7 0 13fd e0
:3 0 59 :3 0 b8
:3 0 a6 :3 0 54
:3 0 ba :3 0 e6
:3 0 e7 :3 0 e8
:3 0 e9 :3 0 ea
:3 0 eb :3 0 ec
:3 0 103 :3 0 a2
:3 0 ae :3 0 a2
:3 0 ca :3 0 55
:3 0 e6 :3 0 55
:3 0 e7 :3 0 55
:3 0 e8 :3 0 55
:3 0 e9 :3 0 55
:3 0 ea :3 0 55
:3 0 eb :3 0 55
:3 0 ec :3 0 16b
:3 0 55 :3 0 a4
:3 0 cb :3 0 a2
:3 0 55 :3 0 a6
:3 0 a2 :3 0 ae
:3 0 55 :3 0 9b
:3 0 a4 :3 0 a5
:3 0 c5 :3 0 c5
:3 0 59 :3 0 a2
:3 0 cc :3 0 a4
:3 0 a5 :3 0 bb
:3 0 bb :3 0 59
:3 0 c5 :3 0 9c
:3 0 d8 :3 0 9b
:3 0 b6 :3 0 b7
:3 0 b6 :3 0 ba
:3 0 e5 :3 0 e5
:3 0 e5 :3 0 e5
:3 0 b6 :3 0 103
:3 0 a3 :3 0 d8
:3 0 c4 :3 0 b6
:3 0 d8 :3 0 53
:3 0 d :3 0 d8
:3 0 9b :3 0 b6
:3 0 9b :3 0 b3
:3 0 76 :3 0 75
:3 0 b3 :3 0 b3
:3 0 cf :3 0 55
:3 0 cf :3 0 a3
:3 0 55 :3 0 55
:3 0 53 :3 0 d8
:3 0 53 :3 0 55
:3 0 9b :3 0 d8
:3 0 9b :4 0 17d
1 :8 0 1321 a8
:4 0 130c :3 0 4e
:3 0 4f :2 0 6fd
130f 1310 :3 0 9
:3 0 5b :3 0 1312
1313 0 16 :2 0
1314 1315 0 1317
700 131e 9 :3 0
5b :3 0 1318 1319
0 a9 :2 0 131a
131b 0 131d 702
131f 1311 1317 0
1320 0 131d 0
1320 704 0 1321
707 136b 5d :3 0
9 :3 0 5b :3 0
1324 1325 0 5c
:3 0 1326 1327 0
1361 2c :3 0 2d
:3 0 1329 132a 0
2c :3 0 3d :3 0
132c 132d 0 5e
:2 0 2 :4 0 17e
:2 0 3f :2 0 14
:2 0 70a 1332 1334
:3 0 70d 132e 1336
132b 1338 1337 :2 0
2f :3 0 40 :3 0
133a 133b 0 31
:4 0 17f :4 0 34
:2 0 35 :3 0 711
133f 1341 :3 0 34
:2 0 45 :4 0 714
1343 1345 :3 0 34
:2 0 61 :4 0 717
1347 1349 :3 0 34
:2 0 5c :3 0 71a
134b 134d :3 0 34
:2 0 62 :4 0 71d
134f 1351 :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 720 1354 1358
724 1353 135a :3 0
727 133c 135c :2 0
135e 72a 135f 1339
135e 0 1360 72c
0 1361 72e 1364
:3 0 1364 0 1364
1363 1361 1362 :6 0
1366 24 :3 0 731
1368 733 1367 1366
:2 0 1369 735 :2 0
136b 0 136b 136a
1321 1369 :6 0 13fd
1 :3 0 b2 :3 0
22 :3 0 55 :3 0
9b :3 0 59 :3 0
cf :3 0 b6 :3 0
b7 :3 0 b8 :3 0
54 :3 0 b6 :3 0
ba :3 0 55 :3 0
e6 :3 0 55 :3 0
e7 :3 0 55 :3 0
e8 :3 0 55 :3 0
e9 :3 0 55 :3 0
ea :3 0 55 :3 0
eb :3 0 55 :3 0
ec :3 0 ed :3 0
17 :3 0 56 :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 f3 :3 0
b6 :3 0 103 :3 0
c3 :3 0 82 :3 0
16b :3 0 55 :3 0
a4 :3 0 c4 :3 0
b6 :3 0 55 :3 0
a6 :3 0 55 :3 0
9b :3 0 b6 :3 0
9b :3 0 59 :3 0
cf :3 0 b8 :3 0
54 :3 0 ba :3 0
e6 :3 0 e7 :3 0
e8 :3 0 e9 :3 0
ea :3 0 eb :3 0
ec :3 0 ed :3 0
17 :3 0 56 :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 f3 :3 0
103 :3 0 c3 :3 0
82 :3 0 e0 :3 0
a6 :3 0 54 :3 0
59 :3 0 cf :3 0
b8 :3 0 54 :3 0
ba :3 0 e6 :3 0
e7 :3 0 e8 :3 0
e9 :3 0 ea :3 0
eb :3 0 ec :3 0
ed :3 0 17 :3 0
56 :3 0 ee :3 0
ef :3 0 f0 :3 0
f1 :3 0 f2 :3 0
f3 :3 0 103 :3 0
c3 :3 0 82 :3 0
e0 :3 0 a6 :3 0
54 :3 0 54 :3 0
b8 :4 0 180 1
:a 0 13d9 :2 0 13fd
136e 13d7 :2 0 2c
:3 0 2d :3 0 13da
13db 0 2c :3 0
3d :3 0 13dd 13de
0 14 :2 0 2
:4 0 181 :2 0 3f
:2 0 14 :2 0 737
13e3 13e5 :3 0 73a
13df 13e7 13dc 13e9
13e8 :2 0 2f :3 0
40 :3 0 13eb 13ec
0 31 :4 0 182
:4 0 34 :2 0 35
:3 0 73e 13f0 13f2
:3 0 741 13ed 13f4
:2 0 13f6 744 13f7
13ea 13f6 0 13f8
746 0 13fd 8
:3 0 22 :3 0 13fa
:2 0 13fd 73 :3 0
748 13fe 120e 13fd
0 1e83 39 :3 0
15 :3 0 16 :2 0
751 13ff 1402 4f
:2 0 183 :2 0 756
1404 1406 :3 0 b2
:3 0 23 :3 0 da
:3 0 9b :3 0 59
:3 0 da :3 0 cf
:3 0 b6 :3 0 b7
:3 0 b8 :3 0 54
:3 0 b6 :3 0 ba
:3 0 52 :3 0 e6
:3 0 52 :3 0 e7
:3 0 52 :3 0 165
:3 0 e8 :3 0 52
:3 0 f1 :3 0 184
:3 0 55 :3 0 12f
:3 0 e9 :3 0 55
:3 0 130 :3 0 ea
:3 0 55 :3 0 165
:3 0 eb :3 0 55
:3 0 15a :3 0 ec
:3 0 17 :3 0 56
:3 0 ee :3 0 ef
:3 0 f0 :3 0 f1
:3 0 f2 :3 0 f3
:3 0 b6 :3 0 103
:3 0 c3 :3 0 82
:3 0 185 :3 0 bf
:3 0 185 :3 0 101
:3 0 185 :3 0 c1
:3 0 185 :3 0 102
:3 0 185 :3 0 186
:3 0 185 :3 0 187
:3 0 185 :3 0 188
:3 0 185 :3 0 189
:3 0 185 :3 0 18a
:3 0 185 :3 0 18b
:3 0 185 :3 0 18c
:3 0 185 :3 0 18d
:3 0 185 :3 0 18e
:3 0 185 :3 0 18f
:3 0 185 :3 0 190
:3 0 a3 :3 0 da
:3 0 a4 :3 0 191
:3 0 185 :3 0 185
:3 0 53 :3 0 d
:3 0 185 :3 0 9b
:3 0 da :3 0 9b
:3 0 c6 :3 0 a4
:3 0 75 :3 0 55
:3 0 55 :3 0 cf
:3 0 da :3 0 cf
:3 0 55 :3 0 11a
:3 0 c6 :3 0 a4
:3 0 75 :3 0 52
:3 0 52 :3 0 cf
:3 0 da :3 0 cf
:3 0 52 :3 0 11a
:3 0 a4 :3 0 c4
:3 0 b6 :3 0 da
:3 0 9b :3 0 b6
:3 0 9b :3 0 da
:3 0 59 :3 0 d
:3 0 da :3 0 a6
:3 0 55 :3 0 76
:3 0 52 :3 0 76
:3 0 da :3 0 9b
:3 0 59 :3 0 55
:3 0 cf :3 0 b6
:3 0 ca :3 0 b8
:3 0 54 :3 0 ba
:3 0 da :3 0 e6
:3 0 da :3 0 e7
:3 0 da :3 0 165
:3 0 e8 :3 0 da
:3 0 f1 :3 0 184
:3 0 e5 :3 0 e9
:3 0 e5 :3 0 ea
:3 0 eb :3 0 ec
:3 0 17 :3 0 56
:3 0 ee :3 0 ef
:3 0 f0 :3 0 f1
:3 0 f2 :3 0 da
:3 0 f3 :3 0 103
:3 0 c3 :3 0 82
:3 0 185 :3 0 bf
:3 0 185 :3 0 101
:3 0 185 :3 0 c1
:3 0 185 :3 0 102
:3 0 185 :3 0 186
:3 0 185 :3 0 187
:3 0 185 :3 0 188
:3 0 185 :3 0 189
:3 0 185 :3 0 18a
:3 0 185 :3 0 18b
:3 0 185 :3 0 18c
:3 0 185 :3 0 18d
:3 0 185 :3 0 18e
:3 0 185 :3 0 18f
:3 0 185 :3 0 190
:3 0 a3 :3 0 55
:3 0 a4 :3 0 cb
:3 0 b6 :3 0 55
:3 0 9b :3 0 b6
:3 0 ae :3 0 a4
:3 0 75 :3 0 da
:3 0 da :3 0 cf
:3 0 55 :3 0 cf
:3 0 a4 :3 0 191
:3 0 185 :3 0 185
:3 0 53 :3 0 d
:3 0 185 :3 0 9b
:3 0 55 :3 0 9b
:3 0 55 :3 0 59
:3 0 d :3 0 55
:3 0 a6 :3 0 54
:3 0 b8 :4 0 192
1 :a 0 14ec :2 0
1510 1409 14ea :2 0
2c :3 0 2d :3 0
14ed 14ee 0 2c
:3 0 3d :3 0 14f0
14f1 0 14 :2 0
2 :4 0 193 :2 0
3f :2 0 14 :2 0
759 14f6 14f8 :3 0
75c 14f2 14fa 14ef
14fc 14fb :2 0 2f
:3 0 40 :3 0 14fe
14ff 0 31 :4 0
194 :4 0 34 :2 0
35 :3 0 760 1503
1505 :3 0 763 1500
1507 :2 0 1509 766
150a 14fd 1509 0
150b 768 0 1510
8 :3 0 23 :3 0
150d :2 0 1510 73
:3 0 76a 1511 1407
1510 0 1e83 39
:3 0 15 :3 0 16
:2 0 76e 1512 1515
4f :2 0 195 :2 0
773 1517 1519 :3 0
97 :3 0 98 :3 0
196 :4 0 151d :4 0
151e :2 0 1800 9
:3 0 5b :3 0 1520
1521 0 16 :2 0
1522 1523 0 1800
197 :3 0 9b :3 0
a6 :3 0 198 :3 0
199 :3 0 184 :3 0
e8 :3 0 19a :3 0
19b :3 0 19c :3 0
eb :3 0 54 :3 0
9b :3 0 a6 :3 0
16c :3 0 e6 :3 0
198 :3 0 16d :3 0
e7 :3 0 199 :3 0
16e :3 0 f1 :3 0
184 :3 0 16e :3 0
11a :3 0 165 :3 0
e8 :3 0 16c :3 0
16f :3 0 19a :3 0
16d :3 0 170 :3 0
19b :3 0 16e :3 0
15a :3 0 19c :3 0
16e :3 0 11a :3 0
165 :3 0 eb :3 0
75 :3 0 53 :3 0
d :3 0 db :3 0
d :3 0 9b :3 0
a6 :4 0 19d 1
:8 0 156a a8 :4 0
1555 :3 0 4e :3 0
4f :2 0 778 1558
1559 :3 0 9 :3 0
5b :3 0 155b 155c
0 16 :2 0 155d
155e 0 1560 77b
1567 9 :3 0 5b
:3 0 1561 1562 0
a9 :2 0 1563 1564
0 1566 77d 1568
155a 1560 0 1569
0 1566 0 1569
77f 0 156a 782
15b4 5d :3 0 9
:3 0 5b :3 0 156d
156e 0 5c :3 0
156f 1570 0 15aa
2c :3 0 2d :3 0
1572 1573 0 2c
:3 0 3d :3 0 1575
1576 0 5e :2 0
2 :4 0 19e :2 0
3f :2 0 14 :2 0
785 157b 157d :3 0
788 1577 157f 1574
1581 1580 :2 0 2f
:3 0 40 :3 0 1583
1584 0 31 :4 0
19f :4 0 34 :2 0
35 :3 0 78c 1588
158a :3 0 34 :2 0
45 :4 0 78f 158c
158e :3 0 34 :2 0
61 :4 0 792 1590
1592 :3 0 34 :2 0
5c :3 0 795 1594
1596 :3 0 34 :2 0
62 :4 0 798 1598
159a :3 0 34 :2 0
63 :3 0 64 :3 0
14 :2 0 65 :2 0
79b 159d 15a1 79f
159c 15a3 :3 0 7a2
1585 15a5 :2 0 15a7
7a5 15a8 1582 15a7
0 15a9 7a7 0
15aa 7a9 15ad :3 0
15ad 0 15ad 15ac
15aa 15ab :6 0 15af
26 :3 0 7ac 15b1
7ae 15b0 15af :2 0
15b2 7b0 :2 0 15b4
0 15b4 15b3 156a
15b2 :6 0 1800 1
:3 0 97 :3 0 98
:3 0 1a0 :4 0 15b8
:4 0 15b9 :2 0 1800
9 :3 0 5b :3 0
15bb 15bc 0 16
:2 0 15bd 15be 0
1800 1a1 :3 0 9b
:3 0 a6 :3 0 e6
:3 0 e7 :3 0 e8
:3 0 e9 :3 0 ea
:3 0 eb :3 0 ec
:3 0 198 :3 0 199
:3 0 184 :3 0 19a
:3 0 19b :3 0 19c
:3 0 187 :3 0 188
:3 0 189 :3 0 18a
:3 0 18b :3 0 18c
:3 0 18d :3 0 18e
:3 0 18f :3 0 190
:3 0 bf :3 0 101
:3 0 c1 :3 0 102
:3 0 54 :3 0 186
:3 0 55 :3 0 9b
:3 0 55 :3 0 a6
:3 0 55 :3 0 e6
:3 0 55 :3 0 e7
:3 0 55 :3 0 f1
:3 0 55 :3 0 16f
:3 0 55 :3 0 170
:3 0 55 :3 0 15a
:3 0 55 :3 0 134
:3 0 52 :3 0 198
:3 0 52 :3 0 199
:3 0 52 :3 0 184
:3 0 52 :3 0 19a
:3 0 52 :3 0 19b
:3 0 52 :3 0 19c
:3 0 55 :3 0 187
:3 0 55 :3 0 188
:3 0 55 :3 0 189
:3 0 55 :3 0 18a
:3 0 55 :3 0 18b
:3 0 55 :3 0 18c
:3 0 55 :3 0 18d
:3 0 55 :3 0 18e
:3 0 55 :3 0 18f
:3 0 55 :3 0 190
:3 0 55 :3 0 bf
:3 0 55 :3 0 101
:3 0 55 :3 0 c1
:3 0 55 :3 0 102
:3 0 39 :3 0 52
:3 0 54 :3 0 55
:3 0 f1 :3 0 55
:3 0 15a :3 0 55
:3 0 186 :3 0 191
:3 0 55 :3 0 c6
:3 0 c7 :3 0 a4
:3 0 197 :3 0 52
:3 0 55 :3 0 9b
:3 0 52 :3 0 9b
:3 0 55 :3 0 53
:3 0 d :4 0 1a2
1 :8 0 1647 a8
:4 0 1632 :3 0 4e
:3 0 4f :2 0 7b4
1635 1636 :3 0 9
:3 0 5b :3 0 1638
1639 0 16 :2 0
163a 163b 0 163d
7b7 1644 9 :3 0
5b :3 0 163e 163f
0 a9 :2 0 1640
1641 0 1643 7b9
1645 1637 163d 0
1646 0 1643 0
1646 7bb 0 1647
7be 1691 5d :3 0
9 :3 0 5b :3 0
164a 164b 0 5c
:3 0 164c 164d 0
1687 2c :3 0 2d
:3 0 164f 1650 0
2c :3 0 3d :3 0
1652 1653 0 5e
:2 0 2 :4 0 1a3
:2 0 3f :2 0 14
:2 0 7c1 1658 165a
:3 0 7c4 1654 165c
1651 165e 165d :2 0
2f :3 0 40 :3 0
1660 1661 0 31
:4 0 1a4 :4 0 34
:2 0 35 :3 0 7c8
1665 1667 :3 0 34
:2 0 45 :4 0 7cb
1669 166b :3 0 34
:2 0 61 :4 0 7ce
166d 166f :3 0 34
:2 0 5c :3 0 7d1
1671 1673 :3 0 34
:2 0 62 :4 0 7d4
1675 1677 :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 7d7 167a 167e
7db 1679 1680 :3 0
7de 1662 1682 :2 0
1684 7e1 1685 165f
1684 0 1686 7e3
0 1687 7e5 168a
:3 0 168a 0 168a
1689 1687 1688 :6 0
168c 28 :3 0 7e8
168e 7ea 168d 168c
:2 0 168f 7ec :2 0
1691 0 1691 1690
1647 168f :6 0 1800
1 :3 0 1a1 :3 0
1a5 :3 0 54 :3 0
54 :3 0 db :3 0
75 :3 0 da :3 0
da :3 0 53 :3 0
d :3 0 da :3 0
9b :3 0 1a5 :3 0
9b :3 0 da :3 0
a6 :4 0 1a6 1
:8 0 16b9 a8 :4 0
16a4 :3 0 4e :3 0
4f :2 0 7f0 16a7
16a8 :3 0 9 :3 0
5b :3 0 16aa 16ab
0 16 :2 0 16ac
16ad 0 16af 7f3
16b6 9 :3 0 5b
:3 0 16b0 16b1 0
a9 :2 0 16b2 16b3
0 16b5 7f5 16b7
16a9 16af 0 16b8
0 16b5 0 16b8
7f7 0 16b9 7fa
1703 5d :3 0 9
:3 0 5b :3 0 16bc
16bd 0 5c :3 0
16be 16bf 0 16f9
2c :3 0 2d :3 0
16c1 16c2 0 2c
:3 0 3d :3 0 16c4
16c5 0 5e :2 0
2 :4 0 1a7 :2 0
3f :2 0 14 :2 0
7fd 16ca 16cc :3 0
800 16c6 16ce 16c3
16d0 16cf :2 0 2f
:3 0 40 :3 0 16d2
16d3 0 31 :4 0
1a8 :4 0 34 :2 0
35 :3 0 804 16d7
16d9 :3 0 34 :2 0
45 :4 0 807 16db
16dd :3 0 34 :2 0
61 :4 0 80a 16df
16e1 :3 0 34 :2 0
5c :3 0 80d 16e3
16e5 :3 0 34 :2 0
62 :4 0 810 16e7
16e9 :3 0 34 :2 0
63 :3 0 64 :3 0
14 :2 0 65 :2 0
813 16ec 16f0 817
16eb 16f2 :3 0 81a
16d4 16f4 :2 0 16f6
81d 16f7 16d1 16f6
0 16f8 81f 0
16f9 821 16fc :3 0
16fc 0 16fc 16fb
16f9 16fa :6 0 16fe
2a :3 0 824 1700
826 16ff 16fe :2 0
1701 828 :2 0 1703
0 1703 1702 16b9
1701 :6 0 1800 1
:3 0 b2 :3 0 24
:3 0 55 :3 0 9b
:3 0 59 :3 0 cf
:3 0 b6 :3 0 b7
:3 0 b8 :3 0 55
:3 0 54 :3 0 b6
:3 0 ba :3 0 55
:3 0 e6 :3 0 55
:3 0 e7 :3 0 55
:3 0 e8 :3 0 55
:3 0 e9 :3 0 55
:3 0 ea :3 0 55
:3 0 eb :3 0 55
:3 0 ec :3 0 ed
:3 0 17 :3 0 56
:3 0 ee :3 0 ef
:3 0 f0 :3 0 f1
:3 0 f2 :3 0 f3
:3 0 b6 :3 0 103
:3 0 c3 :3 0 82
:3 0 55 :3 0 198
:3 0 55 :3 0 19a
:3 0 55 :3 0 9b
:3 0 d9 :3 0 55
:3 0 198 :3 0 55
:3 0 199 :3 0 55
:3 0 184 :3 0 55
:3 0 19a :3 0 55
:3 0 19b :3 0 55
:3 0 19c :3 0 d
:3 0 53 :3 0 55
:3 0 187 :3 0 55
:3 0 188 :3 0 55
:3 0 189 :3 0 55
:3 0 18a :3 0 55
:3 0 18b :3 0 55
:3 0 18c :3 0 55
:3 0 18d :3 0 55
:3 0 18e :3 0 55
:3 0 18f :3 0 55
:3 0 190 :3 0 55
:3 0 bf :3 0 55
:3 0 101 :3 0 55
:3 0 c1 :3 0 55
:3 0 102 :3 0 55
:3 0 186 :3 0 1a1
:3 0 55 :3 0 a4
:3 0 c4 :3 0 b6
:3 0 55 :3 0 a6
:3 0 55 :3 0 9b
:3 0 b6 :3 0 9b
:3 0 a2 :3 0 ae
:3 0 59 :3 0 cf
:3 0 a2 :3 0 ca
:3 0 b8 :3 0 54
:3 0 ba :3 0 55
:3 0 e6 :3 0 55
:3 0 e7 :3 0 55
:3 0 e8 :3 0 55
:3 0 e9 :3 0 55
:3 0 ea :3 0 55
:3 0 eb :3 0 55
:3 0 ec :3 0 ed
:3 0 17 :3 0 56
:3 0 ee :3 0 ef
:3 0 f0 :3 0 f1
:3 0 f2 :3 0 f3
:3 0 103 :3 0 c3
:3 0 82 :3 0 55
:3 0 198 :3 0 55
:3 0 19a :3 0 55
:3 0 9b :3 0 d9
:3 0 55 :3 0 198
:3 0 55 :3 0 199
:3 0 55 :3 0 184
:3 0 55 :3 0 19a
:3 0 55 :3 0 19b
:3 0 55 :3 0 19c
:3 0 d :3 0 53
:3 0 55 :3 0 187
:3 0 55 :3 0 188
:3 0 55 :3 0 189
:3 0 55 :3 0 18a
:3 0 55 :3 0 18b
:3 0 55 :3 0 18c
:3 0 55 :3 0 18d
:3 0 55 :3 0 18e
:3 0 55 :3 0 18f
:3 0 55 :3 0 190
:3 0 55 :3 0 bf
:3 0 55 :3 0 101
:3 0 55 :3 0 c1
:3 0 55 :3 0 102
:3 0 55 :3 0 186
:3 0 1a1 :3 0 55
:3 0 a4 :3 0 cb
:3 0 a2 :3 0 55
:3 0 a6 :3 0 a2
:3 0 ae :3 0 55
:3 0 9b :3 0 a4
:3 0 a5 :3 0 c5
:3 0 c5 :3 0 59
:3 0 a2 :3 0 cc
:3 0 a4 :3 0 a5
:3 0 bb :3 0 bb
:3 0 59 :3 0 c5
:3 0 9c :4 0 1a9
1 :a 0 17dc :2 0
1800 1706 17da :2 0
2c :3 0 2d :3 0
17dd 17de 0 2c
:3 0 3d :3 0 17e0
17e1 0 14 :2 0
2 :4 0 1aa :2 0
3f :2 0 14 :2 0
82a 17e6 17e8 :3 0
82d 17e2 17ea 17df
17ec 17eb :2 0 2f
:3 0 40 :3 0 17ee
17ef 0 31 :4 0
1ab :4 0 34 :2 0
35 :3 0 831 17f3
17f5 :3 0 834 17f0
17f7 :2 0 17f9 837
17fa 17ed 17f9 0
17fb 839 0 1800
8 :3 0 24 :3 0
17fd :2 0 1800 73
:3 0 83b 1801 151a
1800 0 1e83 39
:3 0 15 :3 0 16
:2 0 846 1802 1805
47 :3 0 4f :2 0
8c :3 0 1807 1809
0 84b 1808 180b
:3 0 ca :3 0 11
:3 0 cb :3 0 ae
:3 0 d :4 0 1ac
1 :8 0 1818 9
:3 0 5b :3 0 1813
1814 0 5c :3 0
1815 1816 0 1818
84e 1862 5d :3 0
9 :3 0 5b :3 0
181b 181c 0 5c
:3 0 181d 181e 0
1858 2c :3 0 2d
:3 0 1820 1821 0
2c :3 0 3d :3 0
1823 1824 0 5e
:2 0 2 :4 0 1ad
:2 0 3f :2 0 14
:2 0 851 1829 182b
:3 0 854 1825 182d
1822 182f 182e :2 0
2f :3 0 40 :3 0
1831 1832 0 31
:4 0 1ae :4 0 34
:2 0 35 :3 0 858
1836 1838 :3 0 34
:2 0 45 :4 0 85b
183a 183c :3 0 34
:2 0 61 :4 0 85e
183e 1840 :3 0 34
:2 0 5c :3 0 861
1842 1844 :3 0 34
:2 0 62 :4 0 864
1846 1848 :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 867 184b 184f
86b 184a 1851 :3 0
86e 1833 1853 :2 0
1855 871 1856 1830
1855 0 1857 873
0 1858 875 185b
:3 0 185b 0 185b
185a 1858 1859 :6 0
185d 2c :3 0 878
185f 87a 185e 185d
:2 0 1860 87c :2 0
1862 0 1862 1861
1818 1860 :6 0 1931
1 :3 0 9 :3 0
5b :3 0 1864 1865
0 9 :3 0 4f
:2 0 1af :3 0 1867
1869 0 880 1868
186b :3 0 186c :2 0
b2 :3 0 25 :3 0
d :3 0 59 :3 0
11 :3 0 b8 :3 0
54 :3 0 1b0 :3 0
b6 :3 0 cc :3 0
11 :3 0 bc :3 0
1b1 :3 0 1b2 :3 0
b8 :3 0 1b3 :3 0
1b4 :3 0 1b5 :3 0
b8 :3 0 1b6 :3 0
1b7 :3 0 1b8 :3 0
b8 :3 0 1b9 :3 0
cb :3 0 b6 :3 0
c6 :3 0 a4 :3 0
1ba :3 0 1b2 :3 0
1b2 :3 0 59 :3 0
1b1 :3 0 c6 :3 0
a4 :3 0 1bb :3 0
1b5 :3 0 1b5 :3 0
59 :3 0 1b4 :3 0
c6 :3 0 a4 :3 0
6b :3 0 1b8 :3 0
1b8 :3 0 59 :3 0
1b7 :3 0 b6 :3 0
ae :3 0 d :3 0
d :3 0 59 :3 0
11 :3 0 b8 :3 0
54 :3 0 1bc :3 0
54 :3 0 1b0 :3 0
1bd :3 0 59 :3 0
cc :3 0 1be :3 0
1bf :3 0 1be :3 0
1bf :3 0 1c0 :3 0
1bc :3 0 b8 :3 0
1c0 :3 0 1bd :3 0
b8 :3 0 bc :3 0
1b1 :3 0 1b3 :3 0
1b4 :3 0 1b6 :3 0
1b7 :3 0 1b9 :3 0
d1 :3 0 a2 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 a5 :3 0
1bd :3 0 a2 :3 0
cc :3 0 1bd :3 0
59 :3 0 c6 :3 0
c7 :3 0 a4 :3 0
a5 :3 0 1bc :3 0
1bc :3 0 59 :3 0
1bd :3 0 9c :3 0
a2 :3 0 cf :3 0
d :3 0 d :3 0
59 :3 0 11 :3 0
b8 :3 0 54 :3 0
1bc :3 0 54 :3 0
1b0 :3 0 1bd :3 0
59 :3 0 cc :3 0
1be :3 0 1bf :3 0
1be :3 0 1bf :3 0
1c0 :3 0 1bc :3 0
b8 :3 0 1c0 :3 0
1bd :3 0 b8 :3 0
bc :3 0 1b1 :3 0
1b3 :3 0 1b4 :3 0
1b6 :3 0 1b7 :3 0
1b9 :3 0 cd :3 0
ce :3 0 c6 :3 0
c7 :3 0 a4 :3 0
a5 :3 0 1bd :3 0
ce :3 0 d0 :3 0
1bd :3 0 59 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 a5 :3 0
1bc :3 0 1bc :3 0
59 :3 0 1bd :3 0
9c :3 0 ce :3 0
cf :3 0 d :3 0
59 :3 0 54 :4 0
1c1 1 :a 0 190a
:2 0 192d 186f 1908
:2 0 2c :3 0 2d
:3 0 190b 190c 0
2c :3 0 3d :3 0
190e 190f 0 14
:2 0 2 :4 0 1c2
:2 0 3f :2 0 14
:2 0 883 1914 1916
:3 0 886 1910 1918
190d 191a 1919 :2 0
2f :3 0 40 :3 0
191c 191d 0 31
:4 0 1c3 :4 0 34
:2 0 35 :3 0 88a
1921 1923 :3 0 88d
191e 1925 :2 0 1927
890 1928 191b 1927
0 1929 892 0
192d 8 :3 0 25
:3 0 192b :2 0 192d
894 192e 186d 192d
0 192f 898 0
1931 73 :3 0 89a
1932 180c 1931 0
1e83 39 :3 0 15
:3 0 16 :2 0 89d
1933 1936 4f :2 0
74 :2 0 8a2 1938
193a :3 0 b2 :3 0
26 :3 0 da :3 0
76 :3 0 da :3 0
76 :3 0 55 :3 0
cf :3 0 59 :3 0
55 :3 0 9b :3 0
55 :3 0 a6 :3 0
b6 :3 0 ca :3 0
cb :3 0 b6 :3 0
55 :3 0 9b :3 0
b6 :3 0 ae :3 0
a2 :3 0 b7 :3 0
c4 :3 0 a2 :3 0
55 :3 0 9b :3 0
a2 :3 0 9b :3 0
b8 :3 0 da :3 0
76 :3 0 55 :3 0
a6 :3 0 54 :3 0
55 :3 0 cf :3 0
55 :3 0 f7 :3 0
da :3 0 f8 :3 0
da :3 0 f9 :3 0
da :3 0 126 :3 0
da :3 0 127 :3 0
da :3 0 159 :3 0
e6 :3 0 da :3 0
153 :3 0 e7 :3 0
11a :3 0 15a :3 0
f1 :3 0 f1 :3 0
11a :3 0 15a :3 0
129 :3 0 f1 :3 0
ec :3 0 da :3 0
15b :3 0 da :3 0
15c :3 0 da :3 0
15b :3 0 da :3 0
15c :3 0 12a :3 0
12b :3 0 da :3 0
129 :3 0 12c :3 0
12d :3 0 da :3 0
129 :3 0 12d :3 0
f1 :3 0 15a :3 0
12e :3 0 da :3 0
12f :3 0 da :3 0
130 :3 0 da :3 0
131 :3 0 da :3 0
132 :3 0 da :3 0
133 :3 0 da :3 0
134 :3 0 da :3 0
121 :3 0 da :3 0
135 :3 0 da :3 0
129 :3 0 136 :3 0
137 :3 0 138 :3 0
13a :3 0 17 :3 0
56 :3 0 55 :3 0
fa :3 0 55 :3 0
fb :3 0 fc :3 0
b8 :3 0 fd :3 0
39 :3 0 55 :3 0
fe :3 0 55 :3 0
fb :3 0 fe :3 0
ff :3 0 b8 :3 0
100 :3 0 da :3 0
bf :3 0 da :3 0
101 :3 0 da :3 0
c1 :3 0 da :3 0
102 :3 0 55 :3 0
a6 :3 0 a2 :3 0
103 :3 0 c4 :3 0
a2 :3 0 55 :3 0
9b :3 0 a2 :3 0
9b :3 0 103 :3 0
55 :3 0 104 :3 0
da :3 0 f3 :3 0
da :3 0 13b :3 0
da :3 0 13c :3 0
da :3 0 13e :3 0
da :3 0 d9 :3 0
da :3 0 105 :3 0
106 :3 0 b8 :3 0
13f :3 0 da :3 0
ed :3 0 da :3 0
108 :3 0 da :3 0
109 :3 0 da :3 0
10a :3 0 da :3 0
10b :3 0 da :3 0
10c :3 0 da :3 0
10d :3 0 da :3 0
140 :3 0 da :3 0
10e :3 0 da :3 0
11a :3 0 da :3 0
11a :3 0 11a :3 0
da :3 0 141 :3 0
142 :3 0 da :3 0
143 :3 0 144 :3 0
1b :3 0 39 :3 0
da :3 0 145 :3 0
da :3 0 159 :3 0
e5 :3 0 145 :3 0
1b :3 0 39 :3 0
da :3 0 146 :3 0
da :3 0 153 :3 0
e5 :3 0 146 :3 0
1b :3 0 da :3 0
148 :3 0 da :3 0
134 :3 0 da :3 0
148 :3 0 148 :3 0
da :3 0 12b :3 0
149 :3 0 14a :3 0
da :3 0 76 :3 0
da :3 0 d9 :3 0
da :3 0 76 :3 0
da :3 0 145 :3 0
da :3 0 159 :3 0
da :3 0 146 :3 0
da :3 0 153 :3 0
14b :3 0 da :3 0
14c :3 0 15d :3 0
b8 :3 0 14d :3 0
da :3 0 14e :3 0
15e :3 0 b8 :3 0
14f :3 0 da :3 0
150 :3 0 da :3 0
151 :3 0 15f :3 0
b8 :3 0 152 :3 0
a3 :3 0 55 :3 0
a4 :3 0 75 :3 0
da :3 0 da :3 0
76 :3 0 d :3 0
55 :3 0 cf :3 0
da :3 0 cf :3 0
c6 :3 0 c7 :3 0
a4 :3 0 10f :3 0
fc :3 0 55 :3 0
fb :3 0 fc :3 0
59 :3 0 c6 :3 0
c7 :3 0 a4 :3 0
10f :3 0 ff :3 0
39 :3 0 55 :3 0
fe :3 0 55 :3 0
fb :3 0 ff :3 0
59 :3 0 c6 :3 0
c7 :3 0 a4 :3 0
110 :3 0 106 :3 0
106 :3 0 59 :3 0
da :3 0 105 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 160 :3 0
15d :3 0 15d :3 0
59 :3 0 da :3 0
14c :3 0 c6 :3 0
c7 :3 0 a4 :3 0
160 :3 0 15e :3 0
15e :3 0 59 :3 0
da :3 0 14e :3 0
c6 :3 0 c7 :3 0
a4 :3 0 161 :3 0
15f :3 0 15f :3 0
59 :3 0 da :3 0
151 :3 0 54 :3 0
b8 :4 0 1c4 1
:a 0 1a7c :2 0 1aa0
193d 1a7a :2 0 2c
:3 0 2d :3 0 1a7d
1a7e 0 2c :3 0
3d :3 0 1a80 1a81
0 14 :2 0 2
:4 0 1c5 :2 0 3f
:2 0 14 :2 0 8a5
1a86 1a88 :3 0 8a8
1a82 1a8a 1a7f 1a8c
1a8b :2 0 2f :3 0
40 :3 0 1a8e 1a8f
0 31 :4 0 1c6
:4 0 34 :2 0 35
:3 0 8ac 1a93 1a95
:3 0 8af 1a90 1a97
:2 0 1a99 8b2 1a9a
1a8d 1a99 0 1a9b
8b4 0 1aa0 8
:3 0 26 :3 0 1a9d
:2 0 1aa0 73 :3 0
8b6 1aa1 193b 1aa0
0 1e83 39 :3 0
15 :3 0 16 :2 0
8ba 1aa2 1aa5 4f
:2 0 8d :2 0 8bf
1aa7 1aa9 :3 0 b2
:3 0 27 :3 0 55
:3 0 cf :3 0 59
:3 0 55 :3 0 9b
:3 0 55 :3 0 a6
:3 0 b6 :3 0 ca
:3 0 cb :3 0 b6
:3 0 55 :3 0 9b
:3 0 b6 :3 0 ae
:3 0 a2 :3 0 b7
:3 0 c4 :3 0 a2
:3 0 55 :3 0 9b
:3 0 a2 :3 0 9b
:3 0 b8 :3 0 55
:3 0 a6 :3 0 47
:3 0 1c7 :3 0 54
:3 0 55 :3 0 cf
:3 0 55 :3 0 f7
:3 0 e5 :3 0 e6
:3 0 e5 :3 0 e7
:3 0 f1 :3 0 e5
:3 0 f8 :3 0 e5
:3 0 f9 :3 0 e5
:3 0 16f :3 0 e5
:3 0 170 :3 0 15a
:3 0 e5 :3 0 12f
:3 0 e5 :3 0 130
:3 0 131 :3 0 e5
:3 0 132 :3 0 e5
:3 0 133 :3 0 134
:3 0 e5 :3 0 121
:3 0 e5 :3 0 135
:3 0 136 :3 0 17
:3 0 56 :3 0 55
:3 0 fa :3 0 e5
:3 0 1c8 :3 0 55
:3 0 fb :3 0 fc
:3 0 b8 :3 0 fd
:3 0 39 :3 0 55
:3 0 fe :3 0 55
:3 0 fb :3 0 fe
:3 0 ff :3 0 b8
:3 0 100 :3 0 bf
:3 0 101 :3 0 c1
:3 0 102 :3 0 55
:3 0 a6 :3 0 a2
:3 0 103 :3 0 c4
:3 0 a2 :3 0 55
:3 0 9b :3 0 a2
:3 0 9b :3 0 103
:3 0 55 :3 0 104
:3 0 f3 :3 0 e5
:3 0 13b :3 0 e5
:3 0 13c :3 0 13e
:3 0 d9 :3 0 105
:3 0 13f :3 0 ed
:3 0 108 :3 0 109
:3 0 10a :3 0 10b
:3 0 10c :3 0 10d
:3 0 1c9 :3 0 a3
:3 0 55 :3 0 c6
:3 0 c7 :3 0 a4
:3 0 10f :3 0 fc
:3 0 55 :3 0 fb
:3 0 fc :3 0 59
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 10f
:3 0 ff :3 0 39
:3 0 55 :3 0 fe
:3 0 55 :3 0 fb
:3 0 ff :3 0 59
:3 0 55 :3 0 104
:3 0 55 :3 0 59
:3 0 d :3 0 54
:3 0 b8 :4 0 1ca
1 :a 0 1b41 :2 0
1b65 1aac 1b3f :2 0
2c :3 0 2d :3 0
1b42 1b43 0 2c
:3 0 3d :3 0 1b45
1b46 0 14 :2 0
2 :4 0 1cb :2 0
3f :2 0 14 :2 0
8c2 1b4b 1b4d :3 0
8c5 1b47 1b4f 1b44
1b51 1b50 :2 0 2f
:3 0 40 :3 0 1b53
1b54 0 31 :4 0
1cc :4 0 34 :2 0
35 :3 0 8c9 1b58
1b5a :3 0 8cc 1b55
1b5c :2 0 1b5e 8cf
1b5f 1b52 1b5e 0
1b60 8d1 0 1b65
8 :3 0 27 :3 0
1b62 :2 0 1b65 73
:3 0 8d3 1b66 1aaa
1b65 0 1e83 39
:3 0 15 :3 0 16
:2 0 8d7 1b67 1b6a
4f :2 0 1cd :2 0
8dc 1b6c 1b6e :3 0
97 :3 0 98 :3 0
1ce :4 0 1b72 :4 0
1b73 :2 0 1d8a 9
:3 0 5b :3 0 1b75
1b76 0 16 :2 0
1b77 1b78 0 1d8a
1cf :3 0 9b :3 0
a6 :3 0 1d0 :3 0
9b :3 0 a6 :3 0
1d0 :3 0 75 :3 0
53 :3 0 d :3 0
d9 :3 0 1d1 :3 0
47 :3 0 1d2 :3 0
9b :3 0 a6 :4 0
1d3 1 :8 0 1ba0
a8 :4 0 1b8b :3 0
4e :3 0 4f :2 0
8e1 1b8e 1b8f :3 0
9 :3 0 5b :3 0
1b91 1b92 0 16
:2 0 1b93 1b94 0
1b96 8e4 1b9d 9
:3 0 5b :3 0 1b97
1b98 0 a9 :2 0
1b99 1b9a 0 1b9c
8e6 1b9e 1b90 1b96
0 1b9f 0 1b9c
0 1b9f 8e8 0
1ba0 8eb 1bea 5d
:3 0 9 :3 0 5b
:3 0 1ba3 1ba4 0
5c :3 0 1ba5 1ba6
0 1be0 2c :3 0
2d :3 0 1ba8 1ba9
0 2c :3 0 3d
:3 0 1bab 1bac 0
5e :2 0 2 :4 0
1d4 :2 0 3f :2 0
14 :2 0 8ee 1bb1
1bb3 :3 0 8f1 1bad
1bb5 1baa 1bb7 1bb6
:2 0 2f :3 0 40
:3 0 1bb9 1bba 0
31 :4 0 1d5 :4 0
34 :2 0 35 :3 0
8f5 1bbe 1bc0 :3 0
34 :2 0 45 :4 0
8f8 1bc2 1bc4 :3 0
34 :2 0 61 :4 0
8fb 1bc6 1bc8 :3 0
34 :2 0 5c :3 0
8fe 1bca 1bcc :3 0
34 :2 0 62 :4 0
901 1bce 1bd0 :3 0
34 :2 0 63 :3 0
64 :3 0 14 :2 0
65 :2 0 904 1bd3
1bd7 908 1bd2 1bd9
:3 0 90b 1bbb 1bdb
:2 0 1bdd 90e 1bde
1bb8 1bdd 0 1bdf
910 0 1be0 912
1be3 :3 0 1be3 0
1be3 1be2 1be0 1be1
:6 0 1be5 2e :3 0
915 1be7 917 1be6
1be5 :2 0 1be8 919
:2 0 1bea 0 1bea
1be9 1ba0 1be8 :6 0
1d8a 1 :3 0 97
:3 0 98 :3 0 1d6
:4 0 1bee :4 0 1bef
:2 0 1d8a 9 :3 0
5b :3 0 1bf1 1bf2
0 16 :2 0 1bf3
1bf4 0 1d8a 1d7
:3 0 9b :3 0 a6
:3 0 1d0 :3 0 9b
:3 0 a6 :3 0 1d0
:3 0 75 :3 0 53
:3 0 d :3 0 db
:3 0 d :3 0 9b
:3 0 a6 :4 0 1d8
1 :8 0 1c1a a8
:4 0 1c05 :3 0 4e
:3 0 4f :2 0 91d
1c08 1c09 :3 0 9
:3 0 5b :3 0 1c0b
1c0c 0 16 :2 0
1c0d 1c0e 0 1c10
920 1c17 9 :3 0
5b :3 0 1c11 1c12
0 a9 :2 0 1c13
1c14 0 1c16 922
1c18 1c0a 1c10 0
1c19 0 1c16 0
1c19 924 0 1c1a
927 1c64 5d :3 0
9 :3 0 5b :3 0
1c1d 1c1e 0 5c
:3 0 1c1f 1c20 0
1c5a 2c :3 0 2d
:3 0 1c22 1c23 0
2c :3 0 3d :3 0
1c25 1c26 0 5e
:2 0 2 :4 0 1d9
:2 0 3f :2 0 14
:2 0 92a 1c2b 1c2d
:3 0 92d 1c27 1c2f
1c24 1c31 1c30 :2 0
2f :3 0 40 :3 0
1c33 1c34 0 31
:4 0 1da :4 0 34
:2 0 35 :3 0 931
1c38 1c3a :3 0 34
:2 0 45 :4 0 934
1c3c 1c3e :3 0 34
:2 0 61 :4 0 937
1c40 1c42 :3 0 34
:2 0 5c :3 0 93a
1c44 1c46 :3 0 34
:2 0 62 :4 0 93d
1c48 1c4a :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 940 1c4d 1c51
944 1c4c 1c53 :3 0
947 1c35 1c55 :2 0
1c57 94a 1c58 1c32
1c57 0 1c59 94c
0 1c5a 94e 1c5d
:3 0 1c5d 0 1c5d
1c5c 1c5a 1c5b :6 0
1c5f 30 :3 0 951
1c61 953 1c60 1c5f
:2 0 1c62 955 :2 0
1c64 0 1c64 1c63
1c1a 1c62 :6 0 1d8a
1 :3 0 97 :3 0
98 :3 0 1db :4 0
1c68 :4 0 1c69 :2 0
1d8a 9 :3 0 5b
:3 0 1c6b 1c6c 0
16 :2 0 1c6d 1c6e
0 1d8a 1dc :3 0
9b :3 0 a6 :3 0
1d0 :3 0 55 :3 0
9b :3 0 55 :3 0
a6 :3 0 55 :3 0
1d0 :3 0 1cf :3 0
55 :3 0 c6 :3 0
c7 :3 0 a4 :3 0
1d7 :3 0 52 :3 0
55 :3 0 9b :3 0
52 :3 0 9b :3 0
52 :3 0 9b :3 0
52 :3 0 a6 :3 0
52 :3 0 1d0 :3 0
1d7 :3 0 52 :3 0
c6 :3 0 c7 :3 0
a4 :3 0 1cf :3 0
55 :3 0 55 :3 0
9b :3 0 52 :3 0
9b :4 0 1dd 1
:8 0 1cac a8 :4 0
1c97 :3 0 4e :3 0
4f :2 0 959 1c9a
1c9b :3 0 9 :3 0
5b :3 0 1c9d 1c9e
0 16 :2 0 1c9f
1ca0 0 1ca2 95c
1ca9 9 :3 0 5b
:3 0 1ca3 1ca4 0
a9 :2 0 1ca5 1ca6
0 1ca8 95e 1caa
1c9c 1ca2 0 1cab
0 1ca8 0 1cab
960 0 1cac 963
1cf6 5d :3 0 9
:3 0 5b :3 0 1caf
1cb0 0 5c :3 0
1cb1 1cb2 0 1cec
2c :3 0 2d :3 0
1cb4 1cb5 0 2c
:3 0 3d :3 0 1cb7
1cb8 0 5e :2 0
2 :4 0 1de :2 0
3f :2 0 14 :2 0
966 1cbd 1cbf :3 0
969 1cb9 1cc1 1cb6
1cc3 1cc2 :2 0 2f
:3 0 40 :3 0 1cc5
1cc6 0 31 :4 0
1df :4 0 34 :2 0
35 :3 0 96d 1cca
1ccc :3 0 34 :2 0
45 :4 0 970 1cce
1cd0 :3 0 34 :2 0
61 :4 0 973 1cd2
1cd4 :3 0 34 :2 0
5c :3 0 976 1cd6
1cd8 :3 0 34 :2 0
62 :4 0 979 1cda
1cdc :3 0 34 :2 0
63 :3 0 64 :3 0
14 :2 0 65 :2 0
97c 1cdf 1ce3 980
1cde 1ce5 :3 0 983
1cc7 1ce7 :2 0 1ce9
986 1cea 1cc4 1ce9
0 1ceb 988 0
1cec 98a 1cef :3 0
1cef 0 1cef 1cee
1cec 1ced :6 0 1cf1
32 :3 0 98d 1cf3
98f 1cf2 1cf1 :2 0
1cf4 991 :2 0 1cf6
0 1cf6 1cf5 1cac
1cf4 :6 0 1d8a 1
:3 0 b2 :3 0 28
:3 0 55 :3 0 9b
:3 0 59 :3 0 b6
:3 0 b7 :3 0 b8
:3 0 54 :3 0 b6
:3 0 1e0 :3 0 55
:3 0 1d0 :3 0 1dc
:3 0 55 :3 0 a4
:3 0 c4 :3 0 b6
:3 0 55 :3 0 a6
:3 0 55 :3 0 9b
:3 0 b6 :3 0 9b
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 1d7
:3 0 1e1 :3 0 55
:3 0 9b :3 0 1e1
:3 0 9b :3 0 a2
:3 0 ae :3 0 59
:3 0 a2 :3 0 ca
:3 0 b8 :3 0 54
:3 0 1e0 :3 0 55
:3 0 1d0 :3 0 1dc
:3 0 55 :3 0 a4
:3 0 cb :3 0 a2
:3 0 55 :3 0 a6
:3 0 a2 :3 0 ae
:3 0 55 :3 0 9b
:3 0 a4 :3 0 a5
:3 0 c5 :3 0 c5
:3 0 59 :3 0 a2
:3 0 cc :3 0 a4
:3 0 a5 :3 0 bb
:3 0 bb :3 0 59
:3 0 c5 :3 0 9c
:3 0 c6 :3 0 c7
:3 0 a4 :3 0 1d7
:3 0 1e1 :3 0 55
:3 0 9b :3 0 1e1
:3 0 9b :3 0 d8
:3 0 9b :3 0 59
:3 0 b6 :3 0 b7
:3 0 b8 :3 0 54
:3 0 b6 :3 0 1e0
:3 0 1d0 :3 0 a3
:3 0 d8 :3 0 c4
:3 0 b6 :3 0 d8
:3 0 53 :3 0 d
:3 0 d8 :3 0 9b
:3 0 b6 :3 0 9b
:3 0 1e2 :3 0 9b
:3 0 1dc :3 0 1e2
:3 0 d8 :3 0 9b
:3 0 1e2 :3 0 9b
:3 0 54 :3 0 b8
:4 0 1e3 1 :a 0
1d66 :2 0 1d8a 1cf9
1d64 :2 0 2c :3 0
2d :3 0 1d67 1d68
0 2c :3 0 3d
:3 0 1d6a 1d6b 0
14 :2 0 2 :4 0
1e4 :2 0 3f :2 0
14 :2 0 993 1d70
1d72 :3 0 996 1d6c
1d74 1d69 1d76 1d75
:2 0 2f :3 0 40
:3 0 1d78 1d79 0
31 :4 0 1e5 :4 0
34 :2 0 35 :3 0
99a 1d7d 1d7f :3 0
99d 1d7a 1d81 :2 0
1d83 9a0 1d84 1d77
1d83 0 1d85 9a2
0 1d8a 8 :3 0
28 :3 0 1d87 :2 0
1d8a 73 :3 0 9a4
1d8b 1b6f 1d8a 0
1e83 39 :3 0 15
:3 0 16 :2 0 9b1
1d8c 1d8f 4f :2 0
81 :2 0 9b6 1d91
1d93 :3 0 b2 :3 0
29 :3 0 da :3 0
59 :3 0 b6 :3 0
b7 :3 0 b8 :3 0
54 :3 0 b6 :3 0
1e0 :3 0 1d0 :3 0
6b :3 0 da :3 0
a4 :3 0 c4 :3 0
b6 :3 0 da :3 0
59 :3 0 b6 :3 0
9b :3 0 da :3 0
54 :3 0 da :3 0
82 :3 0 b :3 0
b8 :4 0 1e6 1
:a 0 1db1 :2 0 1dd5
1d96 1daf :2 0 2c
:3 0 2d :3 0 1db2
1db3 0 2c :3 0
3d :3 0 1db5 1db6
0 14 :2 0 2
:4 0 1e7 :2 0 3f
:2 0 14 :2 0 9b9
1dbb 1dbd :3 0 9bc
1db7 1dbf 1db4 1dc1
1dc0 :2 0 2f :3 0
40 :3 0 1dc3 1dc4
0 31 :4 0 1e8
:4 0 34 :2 0 35
:3 0 9c0 1dc8 1dca
:3 0 9c3 1dc5 1dcc
:2 0 1dce 9c6 1dcf
1dc2 1dce 0 1dd0
9c8 0 1dd5 8
:3 0 29 :3 0 1dd2
:2 0 1dd5 73 :3 0
9ca 1dd6 1d94 1dd5
0 1e83 39 :3 0
15 :3 0 16 :2 0
9ce 1dd7 1dda 47
:3 0 4f :2 0 8e
:3 0 1ddc 1dde 0
9d3 1ddd 1de0 :3 0
1de1 :2 0 39 :3 0
15 :3 0 16 :2 0
9d6 1de3 1de6 47
:3 0 4f :2 0 8f
:3 0 1de8 1dea 0
9db 1de9 1dec :3 0
1ded :2 0 1de2 1def
1dee :2 0 b2 :3 0
2a :3 0 a2 :3 0
9b :3 0 59 :3 0
a2 :3 0 b7 :3 0
b8 :3 0 47 :3 0
1e9 :3 0 54 :3 0
a2 :3 0 1e0 :3 0
1d0 :3 0 191 :3 0
d8 :3 0 c4 :3 0
a2 :3 0 d8 :3 0
53 :3 0 d :3 0
d8 :3 0 9b :3 0
a2 :3 0 9b :3 0
b8 :4 0 1ea 1
:a 0 1e0d :2 0 1e30
1df2 1e0b :2 0 2c
:3 0 2d :3 0 1e0e
1e0f 0 2c :3 0
3d :3 0 1e11 1e12
0 14 :2 0 2
:4 0 1eb :2 0 3f
:2 0 14 :2 0 9de
1e17 1e19 :3 0 9e1
1e13 1e1b 1e10 1e1d
1e1c :2 0 2f :3 0
40 :3 0 1e1f 1e20
0 31 :4 0 1ec
:4 0 34 :2 0 35
:3 0 9e5 1e24 1e26
:3 0 9e8 1e21 1e28
:2 0 1e2a 9eb 1e2b
1e1e 1e2a 0 1e2c
9ed 0 1e30 8
:3 0 2a :3 0 1e2e
:2 0 1e30 9ef 1e31
1df0 1e30 0 1e83
2c :3 0 2d :3 0
1e32 1e33 0 2c
:3 0 3d :3 0 1e35
1e36 0 169 :2 0
2 :4 0 1ed :2 0
3f :2 0 14 :2 0
9f3 1e3b 1e3d :3 0
9f6 1e37 1e3f 1e34
1e41 1e40 :2 0 2f
:3 0 40 :3 0 1e43
1e44 0 31 :4 0
1ee :4 0 34 :2 0
35 :3 0 9fa 1e48
1e4a :3 0 34 :2 0
45 :4 0 9fd 1e4c
1e4e :3 0 34 :2 0
46 :4 0 a00 1e50
1e52 :3 0 34 :2 0
39 :3 0 3a :3 0
47 :3 0 48 :3 0
1e57 1e58 0 a03
1e56 1e5a 3b :4 0
a05 1e55 1e5d a08
1e54 1e5f :3 0 34
:2 0 49 :4 0 a0b
1e61 1e63 :3 0 34
:2 0 37 :4 0 a0e
1e65 1e67 :3 0 34
:2 0 3 :3 0 a11
1e69 1e6b :3 0 34
:2 0 37 :4 0 a14
1e6d 1e6f :3 0 a17
1e45 1e71 :2 0 1e73
a1a 1e74 1e42 1e73
0 1e75 a1c 0
1e80 4c :3 0 1ef
:3 0 1e76 1e77 0
47 :3 0 48 :3 0
1e79 1e7a 0 3
:3 0 4e :3 0 a1e
1e78 1e7e :2 0 1e80
a22 1e82 6be 913
0 1e83 0 1e80
0 1e83 a25 0
1e84 a35 1f25 9
:3 0 1f0 :2 0 4
1e85 1e86 0 2c
:3 0 2d :3 0 1e88
1e89 0 2c :3 0
3d :3 0 1e8b 1e8c
0 5e :2 0 2
:4 0 1f1 :2 0 3f
:2 0 14 :2 0 a3e
1e91 1e93 :3 0 a41
1e8d 1e95 1e8a 1e97
1e96 :2 0 2f :3 0
40 :3 0 1e99 1e9a
0 31 :4 0 1f2
:4 0 34 :2 0 35
:3 0 a45 1e9e 1ea0
:3 0 a48 1e9b 1ea2
:2 0 1ebb 2f :3 0
40 :3 0 1ea4 1ea5
0 31 :4 0 1f3
:4 0 34 :2 0 9
:3 0 1f4 :3 0 1eaa
1eab 0 a4b 1ea9
1ead :3 0 34 :2 0
49 :4 0 a4e 1eaf
1eb1 :3 0 34 :2 0
9 :3 0 1f5 :3 0
1eb4 1eb5 0 a51
1eb3 1eb7 :3 0 a54
1ea6 1eb9 :2 0 1ebb
a57 1ebc 1e98 1ebb
0 1ebd a5a 0
1ecd b2 :3 0 2b
:3 0 9 :3 0 1f4
:3 0 1f6 :3 0 9
:3 0 1f5 :3 0 3
:3 0 119 :4 0 1f7
1 :a 0 1ec9 :2 0
1ecd 1ebf 1ec7 :2 0
8 :3 0 2b :3 0
1ecb :2 0 1ecd a5c
1ecf a60 1ece 1ecd
:2 0 1f23 5d :3 0
9 :3 0 5b :3 0
1ed2 1ed3 0 5c
:3 0 1ed4 1ed5 0
1f1b 2c :3 0 2d
:3 0 1ed7 1ed8 0
2c :3 0 3d :3 0
1eda 1edb 0 5e
:2 0 2 :4 0 1f8
:2 0 3f :2 0 14
:2 0 a62 1ee0 1ee2
:3 0 a65 1edc 1ee4
1ed9 1ee6 1ee5 :2 0
2f :3 0 40 :3 0
1ee8 1ee9 0 31
:4 0 1f9 :4 0 34
:2 0 35 :3 0 a69
1eed 1eef :3 0 a6c
1eea 1ef1 :2 0 1f0b
2f :3 0 40 :3 0
1ef3 1ef4 0 31
:4 0 61 :4 0 34
:2 0 5c :3 0 a6f
1ef8 1efa :3 0 34
:2 0 62 :4 0 a72
1efc 1efe :3 0 34
:2 0 63 :3 0 64
:3 0 14 :2 0 65
:2 0 a75 1f01 1f05
a79 1f00 1f07 :3 0
a7c 1ef5 1f09 :2 0
1f0b a7f 1f0c 1ee7
1f0b 0 1f0d a82
0 1f1b b2 :3 0
2b :3 0 1f6 :3 0
9 :3 0 1f5 :3 0
3 :3 0 119 :4 0
1fa 1 :a 0 1f17
:2 0 1f1b 1f0f 1f15
:2 0 8 :3 0 2b
:3 0 1f19 :2 0 1f1b
a84 1f1e :3 0 1f1e
0 1f1e 1f1d 1f1b
1f1c :6 0 1f20 1
:3 0 a89 1f22 a8b
1f21 1f20 :2 0 1f23
a8d :2 0 1f25 a90
1f25 1f24 1e84 1f23
:6 0 1f26 :2 0 2
14 1f25 1f29 :3 0
1f28 1f26 1f2a :8 0

aad
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
40 1 46 1
4c 1 52 1
58 1 5e 1
64 1 6b 1
72 1 79 1
80 1 87 1
8e 1 95 1
9c 1 a3 1
aa 1 b1 1
b8 1 bf 1
c6 1 cd 1
da 1 e6 2
e9 eb 2 ee
f0 2 f2 f4
2 f6 f8 2
fa fc 1 102
2 104 105 2
fe 107 2 109
10b 2 10d 10f
2 111 113 2
115 117 2 119
11b 4 e2 e8
ed 11d 1 11f
1 121 2 12b
12d 3 129 12a
12f 2 138 13a
2 137 13c 1
13e 1 140 1
142 2 14f 151
3 14d 14e 153
2 15c 15e 2
160 162 2 164
166 1 16e 2
170 171 2 168
173 2 175 177
2 179 17b 2
17d 17f 2 181
183 2 15b 185
1 187 1 189
2 193 195 3
191 192 197 2
1a0 1a2 2 19f
1a4 1 1a6 1
1a8 3 1af 1b0
1b1 3 18a 1a9
1b3 1 1b5 2
1c1 1c2 1 1c6
2 1c4 1c6 2
1cb 1cc 1 1d0
2 1ce 1d0 2
1ee 1f3 2 204
206 3 202 203
208 2 211 213
2 215 217 2
219 21b 2 21d
21f 2 221 223
3 228 229 22a
2 225 22c 2
210 22e 1 230
1 232 2 1fb
233 1 237 1
1f6 1 23b 1
246 2 242 246
2 25f 264 2
275 277 3 273
274 279 2 282
284 2 286 288
2 28a 28c 2
28e 290 2 292
294 3 299 29a
29b 2 296 29d
2 281 29f 1
2a1 1 2a3 2
26c 2a4 1 2a8
1 267 1 2ac
1 2b7 2 2b3
2b7 2 2bf 2c4
2 2d5 2d7 3
2d3 2d4 2d9 2
2e2 2e4 2 2e6
2e8 2 2ea 2ec
2 2ee 2f0 2
2f2 2f4 3 2f9
2fa 2fb 2 2f6
2fd 2 2e1 2ff
1 301 1 303
2 2cc 304 1
308 1 2c7 1
30c 1 317 2
313 317 2 323
325 3 321 322
327 2 330 332
2 334 336 2
338 33a 1 342
2 344 345 2
33c 347 2 349
34b 2 34d 34f
2 351 353 2
355 357 2 32f
359 1 35b 1
35d 2 367 369
3 365 366 36b
2 374 376 2
373 378 1 37a
1 37c 3 383
384 385 3 35e
37d 387 1 389
2 30f 38a 1
38c 2 2af 38d
1 38f 2 23e
390 2 394 395
1 399 2 397
399 2 3a1 3a6
2 3b7 3b9 3
3b5 3b6 3bb 2
3c4 3c6 2 3c8
3ca 2 3cc 3ce
2 3d0 3d2 2
3d4 3d6 3 3db
3dc 3dd 2 3d8
3df 2 3c3 3e1
1 3e3 1 3e5
2 3ae 3e6 1
3ea 1 3a9 1
3ee 1 3f9 2
3f5 3f9 2 405
407 3 403 404
409 2 412 414
2 416 418 2
41a 41c 1 424
2 426 427 2
41e 429 2 42b
42d 2 42f 431
2 433 435 2
437 439 2 411
43b 1 43d 1
43f 2 449 44b
3 447 448 44d
2 456 458 2
455 45a 1 45c
1 45e 3 465
466 467 3 440
45f 469 1 46b
2 475 47a 2
48b 48d 3 489
48a 48f 2 498
49a 2 49c 49e
2 4a0 4a2 2
4a4 4a6 2 4a8
4aa 3 4af 4b0
4b1 2 4ac 4b3
2 497 4b5 1
4b7 1 4b9 2
482 4ba 1 4be
1 47d 1 4c2
3 3f1 46c 4c5
2 4cb 4cc 1
4d0 2 4ce 4d0
2 4d8 4dd 2
4ee 4f0 3 4ec
4ed 4f2 2 4fb
4fd 2 4ff 501
2 503 505 2
507 509 2 50b
50d 3 512 513
514 2 50f 516
2 4fa 518 1
51a 1 51c 2
4e5 51d 1 521
1 4e0 1 525
1 530 2 52c
530 2 53c 53e
3 53a 53b 540
2 549 54b 2
54d 54f 2 551
553 1 55b 2
55d 55e 2 555
560 2 562 564
2 566 568 2
56a 56c 2 56e
570 2 548 572
1 574 1 576
2 580 582 3
57e 57f 584 2
58d 58f 2 58c
591 1 593 1
595 3 59c 59d
59e 3 577 596
5a0 1 5a2 3
528 5a3 5a6 2
5ab 5ac 1 5b2
2 5ae 5b2 2
5b7 5b8 1 5bc
2 5ba 5bc 2
5c3 5c4 1 5ca
2 5c6 5ca 2
5d1 5d2 1 5d8
2 5d4 5d8 2
5e6 5eb 2 5fc
5fe 3 5fa 5fb
600 2 609 60b
2 60d 60f 2
611 613 2 615
617 2 619 61b
3 620 621 622
2 61d 624 2
608 626 1 628
1 62a 2 5f3
62b 1 62f 1
5ee 1 633 1
63e 2 63a 63e
2 64a 64c 3
648 649 64e 2
657 659 2 65b
65d 2 65f 661
1 669 2 66b
66c 2 663 66e
2 670 672 2
674 676 2 678
67a 2 67c 67e
2 656 680 1
682 1 684 2
68e 690 3 68c
68d 692 2 69b
69d 2 69a 69f
1 6a1 1 6a3
3 6aa 6ab 6ac
3 685 6a4 6ae
1 6b0 2 636
6b1 4 6b4 4c9
5a9 6b3 2 6b7
6b8 1 6bc 2
6ba 6bc 1 6ee
2 6ed 6ee 1
6f6 1 6fc 2
6fe 6ff 2 6eb
700 2 711 713
3 70f 710 715
2 71e 720 2
722 724 2 726
728 2 72a 72c
2 72e 730 3
735 736 737 2
732 739 2 71d
73b 1 73d 1
73f 2 708 740
1 744 1 703
1 748 1 761
2 760 761 1
769 1 76f 2
771 772 2 75e
773 2 784 786
3 782 783 788
2 791 793 2
795 797 2 799
79b 2 79d 79f
2 7a1 7a3 3
7a8 7a9 7aa 2
7a5 7ac 2 790
7ae 1 7b0 1
7b2 2 77b 7b3
1 7b7 1 776
1 7bb 2 8f8
8fa 3 8f6 8f7
8fc 2 905 907
2 904 909 1
90b 1 90d 9
6c3 6c8 74b 751
756 7be 8ee 90e
911 2 915 916
1 91a 2 918
91a 2 91f 920
1 924 2 922
924 1 95d 2
95c 95d 1 965
1 96b 2 96d
96e 2 95a 96f
2 980 982 3
97e 97f 984 2
98d 98f 2 991
993 2 995 997
2 999 99b 2
99d 99f 3 9a4
9a5 9a6 2 9a1
9a8 2 98c 9aa
1 9ac 1 9ae
2 977 9af 1
9b3 1 972 1
9b7 1 9f4 2
9f3 9f4 1 9fc
1 a02 2 a04
a05 2 9f1 a06
2 a17 a19 3
a15 a16 a1b 2
a24 a26 2 a28
a2a 2 a2c a2e
2 a30 a32 2
a34 a36 3 a3b
a3c a3d 2 a38
a3f 2 a23 a41
1 a43 1 a45
2 a0e a46 1
a4a 1 a09 1
a4e 2 aa7 aa9
3 aa5 aa6 aab
2 ab4 ab6 2
ab3 ab8 1 aba
1 abc 8 92e
933 9ba 9c2 a51
a9d abd ac0 2
ac5 ac6 1 aca
2 ac8 aca 2
b65 b67 3 b63
b64 b69 2 b72
b74 2 b71 b76
1 b78 1 b7a
3 b5b b7b b7e
2 b83 b84 1
b88 2 b86 b88
2 b8d b8e 1
b90 1 b94 2
b92 b94 2 ba1
ba6 2 bb7 bb9
3 bb5 bb6 bbb
2 bc4 bc6 2
bc8 bca 2 bcc
bce 2 bd0 bd2
2 bd4 bd6 3
bdb bdc bdd 2
bd8 bdf 2 bc3
be1 1 be3 1
be5 2 bae be6
1 bea 1 ba9
1 bee 2 bf4
bf5 1 bf9 2
bf7 bf9 1 bfe
2 c09 c0e 2
c1f c21 3 c1d
c1e c23 2 c2c
c2e 2 c30 c32
2 c34 c36 2
c38 c3a 2 c3c
c3e 3 c43 c44
c45 2 c40 c47
2 c2b c49 1
c4b 1 c4d 2
c16 c4e 1 c52
1 c11 1 c56
2 c5c c5d 1
c61 2 c5f c61
2 c80 c85 2
c96 c98 3 c94
c95 c9a 2 ca3
ca5 2 ca7 ca9
2 cab cad 2
caf cb1 2 cb3
cb5 3 cba cbb
cbc 2 cb7 cbe
2 ca2 cc0 1
cc2 1 cc4 2
c8d cc5 1 cc9
1 c88 1 ccd
2 cd3 cd4 1
cd8 2 cd6 cd8
1 cdd 1 ce1
2 ce3 ce4 2
cd0 ce5 1 ce9
2 ceb cec 2
c59 ced 2 cef
cf0 2 ef4 ef6
3 ef2 ef3 ef8
2 f01 f03 2
f00 f05 1 f07
1 f09 6 b99
bf1 cf1 eea f0a
f0d 2 1037 1039
3 1035 1036 103b
2 1044 1046 2
1043 1048 1 104a
1 104c 3 102d
104d 1050 2 1052
1053 1 1054 2
1059 105a 1 105e
2 105c 105e 1
1095 2 1094 1095
1 109d 1 10a3
2 10a5 10a6 2
1092 10a7 2 10b8
10ba 3 10b6 10b7
10bc 2 10c5 10c7
2 10c9 10cb 2
10cd 10cf 2 10d1
10d3 2 10d5 10d7
3 10dc 10dd 10de
2 10d9 10e0 2
10c4 10e2 1 10e4
1 10e6 2 10af
10e7 1 10eb 1
10aa 1 10ef 1
1133 2 1132 1133
1 113b 1 1141
2 1143 1144 2
1130 1145 2 1156
1158 3 1154 1155
115a 2 1163 1165
2 1167 1169 2
116b 116d 2 116f
1171 2 1173 1175
3 117a 117b 117c
2 1177 117e 2
1162 1180 1 1182
1 1184 2 114d
1185 1 1189 1
1148 1 118d 2
11e9 11eb 3 11e7
11e8 11ed 2 11f6
11f8 2 11f5 11fa
1 11fc 1 11fe
8 1065 106a 10f2
10fa 1190 11df 11ff
1202 2 1207 1208
1 120c 2 120a
120c 1 1243 2
1242 1243 1 124b
1 1251 2 1253
1254 2 1240 1255
2 1266 1268 3
1264 1265 126a 2
1273 1275 2 1277
1279 2 127b 127d
2 127f 1281 2
1283 1285 3 128a
128b 128c 2 1287
128e 2 1272 1290
1 1292 1 1294
2 125d 1295 1
1299 1 1258 1
129d 1 130e 2
130d 130e 1 1316
1 131c 2 131e
131f 2 130b 1320
2 1331 1333 3
132f 1330 1335 2
133e 1340 2 1342
1344 2 1346 1348
2 134a 134c 2
134e 1350 3 1355
1356 1357 2 1352
1359 2 133d 135b
1 135d 1 135f
2 1328 1360 1
1364 1 1323 1
1368 2 13e2 13e4
3 13e0 13e1 13e6
2 13ef 13f1 2
13ee 13f3 1 13f5
1 13f7 8 1213
1218 12a0 12a8 136b
13d8 13f8 13fb 2
1400 1401 1 1405
2 1403 1405 2
14f5 14f7 3 14f3
14f4 14f9 2 1502
1504 2 1501 1506
1 1508 1 150a
3 14eb 150b 150e
2 1513 1514 1
1518 2 1516 1518
1 1557 2 1556
1557 1 155f 1
1565 2 1567 1568
2 1554 1569 2
157a 157c 3 1578
1579 157e 2 1587
1589 2 158b 158d
2 158f 1591 2
1593 1595 2 1597
1599 3 159e 159f
15a0 2 159b 15a2
2 1586 15a4 1
15a6 1 15a8 2
1571 15a9 1 15ad
1 156c 1 15b1
1 1634 2 1633
1634 1 163c 1
1642 2 1644 1645
2 1631 1646 2
1657 1659 3 1655
1656 165b 2 1664
1666 2 1668 166a
2 166c 166e 2
1670 1672 2 1674
1676 3 167b 167c
167d 2 1678 167f
2 1663 1681 1
1683 1 1685 2
164e 1686 1 168a
1 1649 1 168e
1 16a6 2 16a5
16a6 1 16ae 1
16b4 2 16b6 16b7
2 16a3 16b8 2
16c9 16cb 3 16c7
16c8 16cd 2 16d6
16d8 2 16da 16dc
2 16de 16e0 2
16e2 16e4 2 16e6
16e8 3 16ed 16ee
16ef 2 16ea 16f1
2 16d5 16f3 1
16f5 1 16f7 2
16c0 16f8 1 16fc
1 16bb 1 1700
2 17e5 17e7 3
17e3 17e4 17e9 2
17f2 17f4 2 17f1
17f6 1 17f8 1
17fa a 151f 1524
15b4 15ba 15bf 1691
1703 17db 17fb 17fe
2 1803 1804 1
180a 2 1806 180a
2 1812 1817 2
1828 182a 3 1826
1827 182c 2 1835
1837 2 1839 183b
2 183d 183f 2
1841 1843 2 1845
1847 3 184c 184d
184e 2 1849 1850
2 1834 1852 1
1854 1 1856 2
181f 1857 1 185b
1 181a 1 185f
1 186a 2 1866
186a 2 1913 1915
3 1911 1912 1917
2 1920 1922 2
191f 1924 1 1926
1 1928 3 1909
1929 192c 1 192e
2 1862 192f 2
1934 1935 1 1939
2 1937 1939 2
1a85 1a87 3 1a83
1a84 1a89 2 1a92
1a94 2 1a91 1a96
1 1a98 1 1a9a
3 1a7b 1a9b 1a9e
2 1aa3 1aa4 1
1aa8 2 1aa6 1aa8
2 1b4a 1b4c 3
1b48 1b49 1b4e 2
1b57 1b59 2 1b56
1b5b 1 1b5d 1
1b5f 3 1b40 1b60
1b63 2 1b68 1b69
1 1b6d 2 1b6b
1b6d 1 1b8d 2
1b8c 1b8d 1 1b95
1 1b9b 2 1b9d
1b9e 2 1b8a 1b9f
2 1bb0 1bb2 3
1bae 1baf 1bb4 2
1bbd 1bbf 2 1bc1
1bc3 2 1bc5 1bc7
2 1bc9 1bcb 2
1bcd 1bcf 3 1bd4
1bd5 1bd6 2 1bd1
1bd8 2 1bbc 1bda
1 1bdc 1 1bde
2 1ba7 1bdf 1
1be3 1 1ba2 1
1be7 1 1c07 2
1c06 1c07 1 1c0f
1 1c15 2 1c17
1c18 2 1c04 1c19
2 1c2a 1c2c 3
1c28 1c29 1c2e 2
1c37 1c39 2 1c3b
1c3d 2 1c3f 1c41
2 1c43 1c45 2
1c47 1c49 3 1c4e
1c4f 1c50 2 1c4b
1c52 2 1c36 1c54
1 1c56 1 1c58
2 1c21 1c59 1
1c5d 1 1c1c 1
1c61 1 1c99 2
1c98 1c99 1 1ca1
1 1ca7 2 1ca9
1caa 2 1c96 1cab
2 1cbc 1cbe 3
1cba 1cbb 1cc0 2
1cc9 1ccb 2 1ccd
1ccf 2 1cd1 1cd3
2 1cd5 1cd7 2
1cd9 1cdb 3 1ce0
1ce1 1ce2 2 1cdd
1ce4 2 1cc8 1ce6
1 1ce8 1 1cea
2 1cb3 1ceb 1
1cef 1 1cae 1
1cf3 2 1d6f 1d71
3 1d6d 1d6e 1d73
2 1d7c 1d7e 2
1d7b 1d80 1 1d82
1 1d84 c 1b74
1b79 1bea 1bf0 1bf5
1c64 1c6a 1c6f 1cf6
1d65 1d85 1d88 2
1d8d 1d8e 1 1d92
2 1d90 1d92 2
1dba 1dbc 3 1db8
1db9 1dbe 2 1dc7
1dc9 2 1dc6 1dcb
1 1dcd 1 1dcf
3 1db0 1dd0 1dd3
2 1dd8 1dd9 1
1ddf 2 1ddb 1ddf
2 1de4 1de5 1
1deb 2 1de7 1deb
2 1e16 1e18 3
1e14 1e15 1e1a 2
1e23 1e25 2 1e22
1e27 1 1e29 1
1e2b 3 1e0c 1e2c
1e2f 2 1e3a 1e3c
3 1e38 1e39 1e3e
2 1e47 1e49 2
1e4b 1e4d 2 1e4f
1e51 1 1e59 2
1e5b 1e5c 2 1e53
1e5e 2 1e60 1e62
2 1e64 1e66 2
1e68 1e6a 2 1e6c
1e6e 2 1e46 1e70
1 1e72 1 1e74
3 1e7b 1e7c 1e7d
2 1e75 1e7f f
1e81 ac3 b81 1057
1205 13fe 1511 1801
1932 1aa1 1b66 1d8b
1dd6 1e31 1e82 8
122 141 1b6 1b9
1bc 1bf 6b5 1e83
2 1e90 1e92 3
1e8e 1e8f 1e94 2
1e9d 1e9f 2 1e9c
1ea1 2 1ea8 1eac
2 1eae 1eb0 2
1eb2 1eb6 2 1ea7
1eb8 2 1ea3 1eba
1 1ebc 3 1ebd
1ec8 1ecc 1 1e87
2 1edf 1ee1 3
1edd 1ede 1ee3 2
1eec 1eee 2 1eeb
1ef0 2 1ef7 1ef9
2 1efb 1efd 3
1f02 1f03 1f04 2
1eff 1f06 2 1ef6
1f08 2 1ef2 1f0a
1 1f0c 4 1ed6
1f0d 1f16 1f1a 1
1f1e 1 1ed1 2
1ecf 1f22 1c 1b
22 29 30 37
3e 44 4a 50
56 5c 62 69
70 77 7e 85
8c 93 9a a1
a8 af b6 bd
c4 cb d2 
1
4
0 
1f29
0
1
50
34
20
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3 1 0
c6 1 0
b 1 0
bf 1 0
52 1 0
2 0 1
64 1 0
6b 1 0
72 1 0
58 1 0
80 1 0
4c 1 0
87 1 0
8e 1 0
95 1 0
9c 1 0
a3 1 0
aa 1 0
b1 1 0
b8 1 0
79 1 0
40 1 0
1d 1 0
16 1 0
5e 1 0
39 1 0
32 1 0
2b 1 0
46 1 0
7 1 0
24 1 0
cd 1 0
0

/
SHOW ERRORS FUNCTION SP_S_PROFILE;
ALTER FUNCTION SP_S_PROFILE COMPILE DEBUG;
/*********************************************************************************************************************************************/
Prompt == FUNCTION FC_U_NAMES ==
CREATE OR REPLACE FUNCTION FC_U_NAMES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
6e
2 :e:
1FUNCTION:
1FC_U_NAMES:
1A_ELEMENT_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1H_FULL_NAME:
1A_PARTICIPANT_ID:
1SH_H_TABLE_TYPE:
1PLS_INTEGER:
1RETURN:
1H_TABLE_TYPE:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_NAMES(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
119:
1+:
1FPUT:
1               ENTER:: FC_U_NAMES(20) :: cplan.sql(13657) :: :
1PMO_CNST:
1SC_TABLE_SCD:
1TMT_ASSIGNED_SCORECARDS:
1ASSIGN_NAMES:
1INSTR:
1REPLACE:
1LENGTH:
1ELEMENT_ID:
1UPDATE TMT_ASSIGNED_SCORECARDS SET ASSIGN_NAMES =:n            CASE:n        +
1    WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_ful+
1l_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            +
1ELSE:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_+
1NAMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIG+
1N_NAMES:n            END:n            END:n            WHERE ELEMENT_ID = a_e+
1lement_id:
1FOUND:
1TRUE:
1=:
1PMO_DB2M:
1SC_STATE:
10:
1100:
1OTHERS:
1SQLCODE:
116:
146:
1           EXCEPTION:: FC_U_NAMES(47) :: cplan.sql(13684) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_TABLE_POL:
1TMT_POOLS:
1MANAGER_ID:
1UPDATE TMT_POOLS SET MANAGER_ID = a_participant_id, ASSIGN_NAMES =:n         +
1   CASE:n            WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n     +
1       THEN h_full_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', +
1''):n            ELSE:n            CASE:n            WHEN LENGTH(h_full_name)+
1 + LENGTH(ASSIGN_NAMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_nam+
1e || ';' || ASSIGN_NAMES:n            END:n            END:n            WHERE+
1 ELEMENT_ID = a_element_id:
176:
1           EXCEPTION:: FC_U_NAMES(77) :: cplan.sql(13714) :: :
1SC_TABLE_CRI:
1TMT_CRI:
1UPDATE TMT_CRI SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || ';' ||+
1 REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n          +
1  CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2040 TH+
1EN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n       +
1     END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1105:
1           EXCEPTION:: FC_U_NAMES(106) :: cplan.sql(13743) :: :
1SC_TABLE_DOC:
1TMT_DOCUMENTS:
1UPDATE TMT_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            WHEN I+
1nStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || +
1';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n    +
1        CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2+
1040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n +
1           END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1135:
1           EXCEPTION:: FC_U_NAMES(136) :: cplan.sql(13773) :: :
1SC_TABLE_POL_DOC:
1TMT_POOL_DOCUMENTS:
1UPDATE TMT_POOL_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            W+
1HEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_nam+
1e || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE+
1:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAME+
1S) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NA+
1MES:n            END:n            END:n            WHERE ELEMENT_ID = a_eleme+
1nt_id:
1165:
1           EXCEPTION:: FC_U_NAMES(166) :: cplan.sql(13803) :: :
1SC_TABLE_RES_DOC:
1TMT_RESOURCE_DOCUMENTS:
1UPDATE TMT_RESOURCE_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n         +
1   WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full+
1_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            E+
1LSE:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_N+
1AMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN+
1_NAMES:n            END:n            END:n            WHERE ELEMENT_ID = a_el+
1ement_id:
1195:
1           EXCEPTION:: FC_U_NAMES(196) :: cplan.sql(13833) :: :
1SC_TABLE_AST_DOC:
1TMT_ASSET_DOCUMENTS:
1UPDATE TMT_ASSET_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            +
1WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_na+
1me || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE+
1:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAME+
1S) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NA+
1MES:n            END:n            END:n            WHERE ELEMENT_ID = a_eleme+
1nt_id:
1225:
1           EXCEPTION:: FC_U_NAMES(226) :: cplan.sql(13863) :: :
1SC_TABLE_CLN_DOC:
1TMT_CLIENT_DOCUMENTS:
1UPDATE TMT_CLIENT_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n           +
1 WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_n+
1ame || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELS+
1E:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAM+
1ES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_N+
1AMES:n            END:n            END:n            WHERE ELEMENT_ID = a_elem+
1ent_id:
1255:
1           EXCEPTION:: FC_U_NAMES(256) :: cplan.sql(13893) :: :
1SC_TABLE_VDR_DOC:
1TMT_VENDOR_DOCUMENTS:
1UPDATE TMT_VENDOR_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n           +
1 WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_n+
1ame || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELS+
1E:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAM+
1ES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_N+
1AMES:n            END:n            END:n            WHERE ELEMENT_ID = a_elem+
1ent_id:
1285:
1           EXCEPTION:: FC_U_NAMES(286) :: cplan.sql(13923) :: :
1TMT_WBS:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || ';' ||+
1 REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n          +
1  CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2040 TH+
1EN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n       +
1     END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1315:
1           EXCEPTION:: FC_U_NAMES(316) :: cplan.sql(13953) :: :
1323:
1                EXIT:: FC_U_NAMES(324) :: cplan.sql(13961) :: :
1STATE:: :
0

0
0
5a2
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 8f
a0 b0 3d b4 :2 a0 2c 6a a3
a0 1c a0 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b :12 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a6 9 :2 a0
6b :14 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a6 9 :2 a0 6b :12 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a6 9 :2 a0 6b :12 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 a6
9 :2 a0 6b :12 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a6 9 :2 a0
6b :12 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a6 9 :2 a0 6b :12 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a6 9 :2 a0 6b :12 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 a6
9 :2 a0 6b :12 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a6 9 :12 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 9 a4 14 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
a4 b1 11 68 4f 1d 17 b5 
5a2
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 73 6f 37
7b 6e 80 84 88 8c a9 94
98 a0 a4 6b 90 b0 b4 b7
bb bf c2 c7 c8 1 ca cf
d3 d7 da df e3 e7 ea ef
f0 f2 f7 fa fe ff 104 109
10c 111 112 117 11a 11e 11f 124
127 12c 12d 132 135 13a 13b 140
143 148 149 14e 151 155 156 15b
15e 163 164 169 16c 171 172 177
17a 17f 180 185 188 18c 18d 192
195 19a 19b 1a0 1a3 1a8 1a9 1ae
1b1 1b5 1b9 1bd 1be 1c0 1c5 1c6
1c8 1c9 1ce 1d1 1d6 1d7 1dc 1dd
1e2 1e4 1e8 1eb 1ef 1f3 1f6 1fa
1fe 201 204 209 20c 20f 212 213
218 219 1 21b 220 224 228 22b
230 235 238 23c 23d 242 243 248
24a 24e 251 255 259 25d 260 264
268 26c 270 274 278 27c 280 284
288 28c 290 294 298 29c 2a0 2a4
2a8 2b4 2b8 2bd 2c1 2c4 2c5 2ca
2ce 2d2 2d5 2d8 2dc 2de 2e2 2e6
2e9 2ec 2f0 2f2 2f6 2fa 2fd 2ff
1 303 307 30b 30e 312 316 31a
31e 321 325 329 32c 32f 334 337
33a 33d 33e 343 344 1 346 34b
34f 353 356 35b 360 363 367 368
36d 370 375 376 37b 37e 383 384
389 38c 390 391 396 399 39e 39f
3a4 3a7 3ab 3af 3b2 3b5 3b6 3b8
3b9 3be 3bf 3c4 3c6 3ca 3cd 3cf
3d3 3d5 3e1 3e3 3e5 3e6 3eb 3ef
3f1 3fd 3ff 401 402 407 40b 40f
412 416 41a 41e 422 426 42a 42e
432 436 43a 43e 442 446 44a 44e
452 456 45a 45e 462 46e 472 477
47b 47e 47f 484 488 48c 48f 492
496 498 49c 4a0 4a3 4a6 4aa 4ac
4b0 4b4 4b7 4b9 1 4bd 4c1 4c5
4c8 4cc 4d0 4d4 4d8 4db 4df 4e3
4e6 4e9 4ee 4f1 4f4 4f7 4f8 4fd
4fe 1 500 505 509 50d 510 515
51a 51d 521 522 527 52a 52f 530
535 538 53d 53e 543 546 54a 54b
550 553 558 559 55e 561 565 569
56c 56f 570 572 573 578 579 57e
580 584 587 589 58d 58f 59b 59d
59f 5a0 5a5 5a9 5ab 5b7 5b9 5bb
5bc 5c1 5c5 5c9 5cc 5d0 5d4 5d8
5dc 5e0 5e4 5e8 5ec 5f0 5f4 5f8
5fc 600 604 608 60c 610 614 620
624 629 62d 630 631 636 63a 63e
641 644 648 64a 64e 652 655 658
65c 65e 662 666 669 66b 1 66f
673 677 67a 67e 682 686 68a 68d
691 695 698 69b 6a0 6a3 6a6 6a9
6aa 6af 6b0 1 6b2 6b7 6bb 6bf
6c2 6c7 6cc 6cf 6d3 6d4 6d9 6dc
6e1 6e2 6e7 6ea 6ef 6f0 6f5 6f8
6fc 6fd 702 705 70a 70b 710 713
717 71b 71e 721 722 724 725 72a
72b 730 732 736 739 73b 73f 741
74d 74f 751 752 757 75b 75d 769
76b 76d 76e 773 777 77b 77e 782
786 78a 78e 792 796 79a 79e 7a2
7a6 7aa 7ae 7b2 7b6 7ba 7be 7c2
7c6 7d2 7d6 7db 7df 7e2 7e3 7e8
7ec 7f0 7f3 7f6 7fa 7fc 800 804
807 80a 80e 810 814 818 81b 81d
1 821 825 829 82c 830 834 838
83c 83f 843 847 84a 84d 852 855
858 85b 85c 861 862 1 864 869
86d 871 874 879 87e 881 885 886
88b 88e 893 894 899 89c 8a1 8a2
8a7 8aa 8ae 8af 8b4 8b7 8bc 8bd
8c2 8c5 8c9 8cd 8d0 8d3 8d4 8d6
8d7 8dc 8dd 8e2 8e4 8e8 8eb 8ed
8f1 8f3 8ff 901 903 904 909 90d
90f 91b 91d 91f 920 925 929 92d
930 934 938 93c 940 944 948 94c
950 954 958 95c 960 964 968 96c
970 974 978 984 988 98d 991 994
995 99a 99e 9a2 9a5 9a8 9ac 9ae
9b2 9b6 9b9 9bc 9c0 9c2 9c6 9ca
9cd 9cf 1 9d3 9d7 9db 9de 9e2
9e6 9ea 9ee 9f1 9f5 9f9 9fc 9ff
a04 a07 a0a a0d a0e a13 a14 1
a16 a1b a1f a23 a26 a2b a30 a33
a37 a38 a3d a40 a45 a46 a4b a4e
a53 a54 a59 a5c a60 a61 a66 a69
a6e a6f a74 a77 a7b a7f a82 a85
a86 a88 a89 a8e a8f a94 a96 a9a
a9d a9f aa3 aa5 ab1 ab3 ab5 ab6
abb abf ac1 acd acf ad1 ad2 ad7
adb adf ae2 ae6 aea aee af2 af6
afa afe b02 b06 b0a b0e b12 b16
b1a b1e b22 b26 b2a b36 b3a b3f
b43 b46 b47 b4c b50 b54 b57 b5a
b5e b60 b64 b68 b6b b6e b72 b74
b78 b7c b7f b81 1 b85 b89 b8d
b90 b94 b98 b9c ba0 ba3 ba7 bab
bae bb1 bb6 bb9 bbc bbf bc0 bc5
bc6 1 bc8 bcd bd1 bd5 bd8 bdd
be2 be5 be9 bea bef bf2 bf7 bf8
bfd c00 c05 c06 c0b c0e c12 c13
c18 c1b c20 c21 c26 c29 c2d c31
c34 c37 c38 c3a c3b c40 c41 c46
c48 c4c c4f c51 c55 c57 c63 c65
c67 c68 c6d c71 c73 c7f c81 c83
c84 c89 c8d c91 c94 c98 c9c ca0
ca4 ca8 cac cb0 cb4 cb8 cbc cc0
cc4 cc8 ccc cd0 cd4 cd8 cdc ce8
cec cf1 cf5 cf8 cf9 cfe d02 d06
d09 d0c d10 d12 d16 d1a d1d d20
d24 d26 d2a d2e d31 d33 1 d37
d3b d3f d42 d46 d4a d4e d52 d55
d59 d5d d60 d63 d68 d6b d6e d71
d72 d77 d78 1 d7a d7f d83 d87
d8a d8f d94 d97 d9b d9c da1 da4
da9 daa daf db2 db7 db8 dbd dc0
dc4 dc5 dca dcd dd2 dd3 dd8 ddb
ddf de3 de6 de9 dea dec ded df2
df3 df8 dfa dfe e01 e03 e07 e09
e15 e17 e19 e1a e1f e23 e25 e31
e33 e35 e36 e3b e3f e43 e46 e4a
e4e e52 e56 e5a e5e e62 e66 e6a
e6e e72 e76 e7a e7e e82 e86 e8a
e8e e9a e9e ea3 ea7 eaa eab eb0
eb4 eb8 ebb ebe ec2 ec4 ec8 ecc
ecf ed2 ed6 ed8 edc ee0 ee3 ee5
1 ee9 eed ef1 ef4 ef8 efc f00
f04 f07 f0b f0f f12 f15 f1a f1d
f20 f23 f24 f29 f2a 1 f2c f31
f35 f39 f3c f41 f46 f49 f4d f4e
f53 f56 f5b f5c f61 f64 f69 f6a
f6f f72 f76 f77 f7c f7f f84 f85
f8a f8d f91 f95 f98 f9b f9c f9e
f9f fa4 fa5 faa fac fb0 fb3 fb5
fb9 fbb fc7 fc9 fcb fcc fd1 fd5
fd7 fe3 fe5 fe7 fe8 fed ff1 ff5
ff8 ffc 1000 1004 1008 100c 1010 1014
1018 101c 1020 1024 1028 102c 1030 1034
1038 103c 1040 104c 1050 1055 1059 105c
105d 1062 1066 106a 106d 1070 1074 1076
107a 107e 1081 1084 1088 108a 108e 1092
1095 1097 1 109b 109f 10a3 10a6 10aa
10ae 10b2 10b6 10b9 10bd 10c1 10c4 10c7
10cc 10cf 10d2 10d5 10d6 10db 10dc 1
10de 10e3 10e7 10eb 10ee 10f3 10f8 10fb
10ff 1100 1105 1108 110d 110e 1113 1116
111b 111c 1121 1124 1128 1129 112e 1131
1136 1137 113c 113f 1143 1147 114a 114d
114e 1150 1151 1156 1157 115c 115e 1162
1165 1167 116b 116d 1179 117b 117d 117e
1183 1187 1189 1195 1197 1199 119a 119f
11a3 11a7 11ab 11af 11b3 11b7 11bb 11bf
11c3 11c7 11cb 11cf 11d3 11d7 11db 11df
11e3 11e7 11f3 11f7 11fc 1200 1203 1204
1209 120d 1211 1214 1217 121b 121d 1221
1225 1228 122b 122f 1231 1235 1239 123c
123e 1 1242 1246 124a 124d 1251 1255
1259 125d 1260 1264 1268 126b 126e 1273
1276 1279 127c 127d 1282 1283 1 1285
128a 128e 1292 1295 129a 129f 12a2 12a6
12a7 12ac 12af 12b4 12b5 12ba 12bd 12c2
12c3 12c8 12cb 12cf 12d0 12d5 12d8 12dd
12de 12e3 12e6 12ea 12ee 12f1 12f4 12f5
12f7 12f8 12fd 12fe 1303 1305 1309 130c
130e 1312 1314 1320 1322 1324 1325 132a
132e 1330 133c 133e 1340 1345 1349 134e
1352 1356 1359 135d 1361 1364 1367 136c
136f 1372 1375 1376 137b 137c 1 137e
1383 1387 138b 138e 1393 1398 139b 139f
13a0 13a5 13a8 13ad 13ae 13b3 13b6 13bb
13bc 13c1 13c4 13c8 13cc 13cf 13d0 13d5
13d6 13db 13dd 13e1 13e4 13e8 13ec 13f0
13f3 13f7 13f9 13fd 13ff 140b 140f 1411
1412 141b 
5a2
2
0 1 a 6 16 1a 21 :3 6
15 19 20 :3 6 1a 1e 25 :3 6
16 :2 6 1 3 a :2 1 4 :2 11
20 11 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
52 58 5b :2 52 69 7d 8 :2 69
d 10 :2 69 1d 20 :2 69 b e
:2 69 13 16 :2 69 1b 1e :2 69 2a
2d :2 69 b e :2 69 13 16 :2 69
1b 1e :2 69 2f 32 :2 69 b e
:2 69 13 16 1f 27 :2 1f 39 :2 16
:2 69 41 44 :2 69 :2 7 48 :2 4 7
:2 11 23 :2 2d 39 3c 4a 4c 4d
:2 4a :2 23 :3 7 :2 d 12 1e 5b 5e
:2 1e :2 7 50 :2 4 9 c :2 15 14
30 12 19 27 12 28 31 3f
12 19 28 2f 49 12 28 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 57 59 5a :2 57
:2 2f :3 13 :2 19 1e 2a 67 6a :2 2a
77 7a :2 2a 7e 81 :2 2a 8d 90
:2 2a 98 9b :2 2a a7 aa b1 ba
bd :2 aa :2 2a :2 13 5d :2 10 :2 d :4 19
:2 d a :4 22 :2 7 c :2 15 14 22
2f 41 12 19 27 12 28 31
3f 12 19 28 2f 49 12 28
13 20 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 57 59 5a
:2 57 :2 2f :3 13 :2 19 1e 2a 67 6a
:2 2a 77 7a :2 2a 7e 81 :2 2a 8d
90 :2 2a 98 9b :2 2a a7 aa b1
ba bd :2 aa :2 2a :2 13 5d :2 10 :2 d
:4 19 :2 d a :4 22 :2 7 c :2 15 14
20 12 19 27 12 28 31 3f
12 19 28 2f 49 12 28 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 57 5a 5b :2 57
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5e :2 10 :2 d :4 19
:2 d a :4 22 :2 7 c :2 15 14 26
12 19 27 12 28 31 3f 12
19 28 2f 49 12 28 13 20
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 57 5a 5b :2 57 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5e :2 10 :2 d :4 19 :2 d
a :4 22 :2 7 c :2 15 14 2b 12
19 27 12 28 31 3f 12 19
28 2f 49 12 28 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 57 5a 5b :2 57 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5e :2 10 :2 d :4 19 :2 d a
:4 26 :2 7 c :2 15 14 2f 12 19
27 12 28 31 3f 12 19 28
2f 49 12 28 13 20 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 57 5a 5b :2 57 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5e :2 10 :2 d :4 19 :2 d a :4 26
:2 7 c :2 15 14 2c 12 19 27
12 28 31 3f 12 19 28 2f
49 12 28 13 20 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
57 5a 5b :2 57 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5e :2 10 :2 d :4 19 :2 d a :4 26 :2 7
c :2 15 14 2d 12 19 27 12
28 31 3f 12 19 28 2f 49
12 28 13 20 d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 57
5a 5b :2 57 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5e
:2 10 :2 d :4 19 :2 d a :4 26 :2 7 c
:2 15 14 2d 12 19 27 12 28
31 3f 12 19 28 2f 49 12
28 13 20 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 57 5a
5b :2 57 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5e :2 10
:2 d :4 19 :2 d a :4 26 :2 7 14 20
12 19 27 12 28 31 3f 12
19 28 2f 49 12 28 13 20
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 57 5a 5b :2 57 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5e :2 10 :2 d :4 19 :2 d
a :4 7 :3 4 7 :2 11 23 :2 2d 39
3c 4a 4d 4e :2 4a :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e 6c 6f :2 1e
73 76 :2 1e 80 83 :2 8c :2 1e :2 7
51 :3 4 b :2 14 4 :9 1 
5a2
4
0 :2 1 :6 3 :6 4
:6 5 :4 6 2 :2 7
:2 1 :6 9 :b b :11 c
d :2 c :2 d :2 c
:2 d :2 c :2 e :2 c
:2 e :2 c :2 e :2 c
:2 e :2 c :2 f :2 c
:2 f :2 c :2 f :2 c
:2 f :2 c :2 10 :2 c
:9 10 :2 c :2 10 :4 c
:3 b :11 13 :b 14 :3 13
17 :3 18 :2 1a :3 1c
:4 1d :5 20 :2 21 :2 24
1a :6 25 :5 26 25
:5 28 27 :3 25 19
:2 2b :5 2d :11 2e :24 2f
:3 2e :2 2c :6 2b 2a
:6 18 :3 36 :4 38 :3 3a
:4 3b :5 3e :2 3f :2 42
38 :6 43 :5 44 43
:5 46 45 :3 43 37
:2 49 :5 4b :11 4c :24 4d
:3 4c :2 4a :6 49 48
:6 36 :3 53 :2 55 :3 57
:4 58 :5 5b :2 5c :2 5f
55 :6 60 :5 61 60
:5 63 62 :3 60 54
:2 66 :5 68 :11 69 :24 6a
:3 69 :2 67 :6 66 65
:6 53 :3 71 :2 73 :3 75
:4 76 :5 79 :2 7a :2 7d
73 :6 7e :5 7f 7e
:5 81 80 :3 7e 72
:2 84 :5 86 :11 87 :24 88
:3 87 :2 85 :6 84 83
:6 71 :3 8f :2 91 :3 93
:4 94 :5 97 :2 98 :2 9b
91 :6 9c :5 9d 9c
:5 9f 9e :3 9c 90
:2 a2 :5 a4 :11 a5 :24 a6
:3 a5 :2 a3 :6 a2 a1
:6 8f :3 ad :2 af :3 b1
:4 b2 :5 b5 :2 b6 :2 b9
af :6 ba :5 bb ba
:5 bd bc :3 ba ae
:2 c0 :5 c2 :11 c3 :24 c4
:3 c3 :2 c1 :6 c0 bf
:6 ad :3 cb :2 cd :3 cf
:4 d0 :5 d3 :2 d4 :2 d7
cd :6 d8 :5 d9 d8
:5 db da :3 d8 cc
:2 de :5 e0 :11 e1 :24 e2
:3 e1 :2 df :6 de dd
:6 cb :3 e9 :2 eb :3 ed
:4 ee :5 f1 :2 f2 :2 f5
eb :6 f6 :5 f7 f6
:5 f9 f8 :3 f6 ea
:2 fc :5 fe :11 ff :24 100
:3 ff :2 fd :6 fc fb
:6 e9 :3 107 :2 109 :3 10b
:4 10c :5 10f :2 110 :2 113
109 :6 114 :5 115 114
:5 117 116 :3 114 108
:2 11a :5 11c :11 11d :24 11e
:3 11d :2 11b :6 11a 119
:6 107 :2 127 :3 129 :4 12a
:5 12d :2 12e :2 131 127
:6 132 :5 133 132 :5 135
134 :3 132 126 :2 138
:5 13a :11 13b :24 13c :3 13b
:2 139 :6 138 137 :4 125
:3 17 :11 143 :19 144 :3 143
:5 146 :2 a :7 1 
141d
4
:3 0 1 :3 0 2
:a 0 59d 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
6 :3 0 8 :5 0
1 13 12 :3 0
10 90 0 b
a :3 0 9 :7 0
17 16 :3 0 b
:3 0 a :3 0 19
1b 0 59d 2
1c :2 0 d :3 0
a :3 0 1f :7 0
9 :3 0 23 20
21 59b 0 c
:6 0 e :3 0 24
25 0 d :3 0
f :3 0 27 28
0 2 :4 0 12
29 2b 26 2d
2c :2 0 10 :3 0
11 :3 0 2f 30
0 12 :4 0 d
:3 0 13 :3 0 33
34 0 2 :4 0
14 35 37 14
:4 0 15 :2 0 16
:3 0 16 3a 3c
:3 0 17 :4 0 15
:2 0 18 :4 0 19
3f 41 :3 0 15
:2 0 3 :3 0 1c
43 45 :3 0 15
:2 0 18 :4 0 1f
47 49 :3 0 15
:2 0 19 :4 0 22
4b 4d :3 0 15
:2 0 18 :4 0 25
4f 51 :3 0 15
:2 0 7 :3 0 28
53 55 :3 0 15
:2 0 18 :4 0 2b
57 59 :3 0 15
:2 0 19 :4 0 2e
5b 5d :3 0 15
:2 0 18 :4 0 31
5f 61 :3 0 15
:2 0 8 :3 0 34
63 65 :3 0 15
:2 0 18 :4 0 37
67 69 :3 0 15
:2 0 19 :4 0 3a
6b 6d :3 0 15
:2 0 1a :3 0 1b
:3 0 9 :3 0 3d
71 73 1c :4 0
3f 70 76 42
6f 78 :3 0 15
:2 0 1d :4 0 45
7a 7c :3 0 48
31 7e :2 0 80
4d 81 2e 80
0 82 4f 0
599 d :3 0 e
:3 0 83 84 0
d :3 0 1e :3 0
86 87 0 1f
:2 0 2 :4 0 20
:2 0 21 :2 0 1f
:2 0 51 8c 8e
:3 0 54 88 90
85 92 91 :2 0
10 :3 0 22 :3 0
94 95 0 12
:4 0 23 :4 0 15
:2 0 16 :3 0 58
99 9b :3 0 5b
96 9d :2 0 9f
5e a0 93 9f
0 a1 60 0
599 c :3 0 24
:3 0 25 :3 0 a3
a4 0 26 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 2c 1
:8 0 ce 2d :4 0
b9 :3 0 2e :3 0
2f :2 0 64 bc
bd :3 0 30 :3 0
31 :3 0 bf c0
0 32 :2 0 c1
c2 0 c4 67
cb 30 :3 0 31
:3 0 c5 c6 0
33 :2 0 c7 c8
0 ca 69 cc
be c4 0 cd
0 ca 0 cd
6b 0 ce 6e
118 34 :3 0 30
:3 0 31 :3 0 d1
d2 0 35 :3 0
d3 d4 0 10e
d :3 0 e :3 0
d6 d7 0 d
:3 0 1e :3 0 d9
da 0 36 :2 0
2 :4 0 37 :2 0
21 :2 0 1f :2 0
71 df e1 :3 0
74 db e3 d8
e5 e4 :2 0 10
:3 0 22 :3 0 e7
e8 0 12 :4 0
38 :4 0 15 :2 0
16 :3 0 78 ec
ee :3 0 15 :2 0
39 :4 0 7b f0
f2 :3 0 15 :2 0
3a :4 0 7e f4
f6 :3 0 15 :2 0
35 :3 0 81 f8
fa :3 0 15 :2 0
3b :4 0 84 fc
fe :3 0 15 :2 0
3c :3 0 3d :3 0
1f :2 0 3e :2 0
87 101 105 8b
100 107 :3 0 8e
e9 109 :2 0 10b
91 10c e6 10b
0 10d 93 0
10e 95 111 :3 0
111 0 111 110
10e 10f :6 0 113
2 :3 0 98 115
9a 114 113 :2 0
116 9c :2 0 118
0 118 117 ce
116 :6 0 11a 1
:3 0 9e 11c a0
11b 11a :2 0 565
24 :3 0 3f :3 0
11d 11e 0 40
:3 0 41 :3 0 8
:3 0 27 :3 0 28
:3 0 27 :3 0 7
:3 0 7 :3 0 29
:3 0 27 :3 0 7
:3 0 2a :3 0 7
:3 0 2a :3 0 27
:3 0 27 :3 0 7
:3 0 27 :3 0 2b
:3 0 3 :4 0 42
1 :8 0 14a 2d
:4 0 135 :3 0 2e
:3 0 2f :2 0 a4
138 139 :3 0 30
:3 0 31 :3 0 13b
13c 0 32 :2 0
13d 13e 0 140
a7 147 30 :3 0
31 :3 0 141 142
0 33 :2 0 143
144 0 146 a9
148 13a 140 0
149 0 146 0
149 ab 0 14a
ae 194 34 :3 0
30 :3 0 31 :3 0
14d 14e 0 35
:3 0 14f 150 0
18a d :3 0 e
:3 0 152 153 0
d :3 0 1e :3 0
155 156 0 36
:2 0 2 :4 0 43
:2 0 21 :2 0 1f
:2 0 b1 15b 15d
:3 0 b4 157 15f
154 161 160 :2 0
10 :3 0 22 :3 0
163 164 0 12
:4 0 44 :4 0 15
:2 0 16 :3 0 b8
168 16a :3 0 15
:2 0 39 :4 0 bb
16c 16e :3 0 15
:2 0 3a :4 0 be
170 172 :3 0 15
:2 0 35 :3 0 c1
174 176 :3 0 15
:2 0 3b :4 0 c4
178 17a :3 0 15
:2 0 3c :3 0 3d
:3 0 1f :2 0 3e
:2 0 c7 17d 181
cb 17c 183 :3 0
ce 165 185 :2 0
187 d1 188 162
187 0 189 d3
0 18a d5 18d
:3 0 18d 0 18d
18c 18a 18b :6 0
18f 4 :3 0 d8
191 da 190 18f
:2 0 192 dc :2 0
194 0 194 193
14a 192 :6 0 196
1 :3 0 de 198
e0 197 196 :2 0
565 24 :3 0 45
:3 0 199 19a 0
46 :3 0 27 :3 0
28 :3 0 27 :3 0
7 :3 0 7 :3 0
29 :3 0 27 :3 0
7 :3 0 2a :3 0
7 :3 0 2a :3 0
27 :3 0 27 :3 0
7 :3 0 27 :3 0
2b :3 0 3 :4 0
47 1 :8 0 1c4
2d :4 0 1af :3 0
2e :3 0 2f :2 0
e4 1b2 1b3 :3 0
30 :3 0 31 :3 0
1b5 1b6 0 32
:2 0 1b7 1b8 0
1ba e7 1c1 30
:3 0 31 :3 0 1bb
1bc 0 33 :2 0
1bd 1be 0 1c0
e9 1c2 1b4 1ba
0 1c3 0 1c0
0 1c3 eb 0
1c4 ee 20e 34
:3 0 30 :3 0 31
:3 0 1c7 1c8 0
35 :3 0 1c9 1ca
0 204 d :3 0
e :3 0 1cc 1cd
0 d :3 0 1e
:3 0 1cf 1d0 0
36 :2 0 2 :4 0
48 :2 0 21 :2 0
1f :2 0 f1 1d5
1d7 :3 0 f4 1d1
1d9 1ce 1db 1da
:2 0 10 :3 0 22
:3 0 1dd 1de 0
12 :4 0 49 :4 0
15 :2 0 16 :3 0
f8 1e2 1e4 :3 0
15 :2 0 39 :4 0
fb 1e6 1e8 :3 0
15 :2 0 3a :4 0
fe 1ea 1ec :3 0
15 :2 0 35 :3 0
101 1ee 1f0 :3 0
15 :2 0 3b :4 0
104 1f2 1f4 :3 0
15 :2 0 3c :3 0
3d :3 0 1f :2 0
3e :2 0 107 1f7
1fb 10b 1f6 1fd
:3 0 10e 1df 1ff
:2 0 201 111 202
1dc 201 0 203
113 0 204 115
207 :3 0 207 0
207 206 204 205
:6 0 209 6 :3 0
118 20b 11a 20a
209 :2 0 20c 11c
:2 0 20e 0 20e
20d 1c4 20c :6 0
210 1 :3 0 11e
212 120 211 210
:2 0 565 24 :3 0
4a :3 0 213 214
0 4b :3 0 27
:3 0 28 :3 0 27
:3 0 7 :3 0 7
:3 0 29 :3 0 27
:3 0 7 :3 0 2a
:3 0 7 :3 0 2a
:3 0 27 :3 0 27
:3 0 7 :3 0 27
:3 0 2b :3 0 3
:4 0 4c 1 :8 0
23e 2d :4 0 229
:3 0 2e :3 0 2f
:2 0 124 22c 22d
:3 0 30 :3 0 31
:3 0 22f 230 0
32 :2 0 231 232
0 234 127 23b
30 :3 0 31 :3 0
235 236 0 33
:2 0 237 238 0
23a 129 23c 22e
234 0 23d 0
23a 0 23d 12b
0 23e 12e 288
34 :3 0 30 :3 0
31 :3 0 241 242
0 35 :3 0 243
244 0 27e d
:3 0 e :3 0 246
247 0 d :3 0
1e :3 0 249 24a
0 36 :2 0 2
:4 0 4d :2 0 21
:2 0 1f :2 0 131
24f 251 :3 0 134
24b 253 248 255
254 :2 0 10 :3 0
22 :3 0 257 258
0 12 :4 0 4e
:4 0 15 :2 0 16
:3 0 138 25c 25e
:3 0 15 :2 0 39
:4 0 13b 260 262
:3 0 15 :2 0 3a
:4 0 13e 264 266
:3 0 15 :2 0 35
:3 0 141 268 26a
:3 0 15 :2 0 3b
:4 0 144 26c 26e
:3 0 15 :2 0 3c
:3 0 3d :3 0 1f
:2 0 3e :2 0 147
271 275 14b 270
277 :3 0 14e 259
279 :2 0 27b 151
27c 256 27b 0
27d 153 0 27e
155 281 :3 0 281
0 281 280 27e
27f :6 0 283 8
:3 0 158 285 15a
284 283 :2 0 286
15c :2 0 288 0
288 287 23e 286
:6 0 28a 1 :3 0
15e 28c 160 28b
28a :2 0 565 24
:3 0 4f :3 0 28d
28e 0 50 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 51 1
:8 0 2b8 2d :4 0
2a3 :3 0 2e :3 0
2f :2 0 164 2a6
2a7 :3 0 30 :3 0
31 :3 0 2a9 2aa
0 32 :2 0 2ab
2ac 0 2ae 167
2b5 30 :3 0 31
:3 0 2af 2b0 0
33 :2 0 2b1 2b2
0 2b4 169 2b6
2a8 2ae 0 2b7
0 2b4 0 2b7
16b 0 2b8 16e
302 34 :3 0 30
:3 0 31 :3 0 2bb
2bc 0 35 :3 0
2bd 2be 0 2f8
d :3 0 e :3 0
2c0 2c1 0 d
:3 0 1e :3 0 2c3
2c4 0 36 :2 0
2 :4 0 52 :2 0
21 :2 0 1f :2 0
171 2c9 2cb :3 0
174 2c5 2cd 2c2
2cf 2ce :2 0 10
:3 0 22 :3 0 2d1
2d2 0 12 :4 0
53 :4 0 15 :2 0
16 :3 0 178 2d6
2d8 :3 0 15 :2 0
39 :4 0 17b 2da
2dc :3 0 15 :2 0
3a :4 0 17e 2de
2e0 :3 0 15 :2 0
35 :3 0 181 2e2
2e4 :3 0 15 :2 0
3b :4 0 184 2e6
2e8 :3 0 15 :2 0
3c :3 0 3d :3 0
1f :2 0 3e :2 0
187 2eb 2ef 18b
2ea 2f1 :3 0 18e
2d3 2f3 :2 0 2f5
191 2f6 2d0 2f5
0 2f7 193 0
2f8 195 2fb :3 0
2fb 0 2fb 2fa
2f8 2f9 :6 0 2fd
a :3 0 198 2ff
19a 2fe 2fd :2 0
300 19c :2 0 302
0 302 301 2b8
300 :6 0 304 1
:3 0 19e 306 1a0
305 304 :2 0 565
24 :3 0 54 :3 0
307 308 0 55
:3 0 27 :3 0 28
:3 0 27 :3 0 7
:3 0 7 :3 0 29
:3 0 27 :3 0 7
:3 0 2a :3 0 7
:3 0 2a :3 0 27
:3 0 27 :3 0 7
:3 0 27 :3 0 2b
:3 0 3 :4 0 56
1 :8 0 332 2d
:4 0 31d :3 0 2e
:3 0 2f :2 0 1a4
320 321 :3 0 30
:3 0 31 :3 0 323
324 0 32 :2 0
325 326 0 328
1a7 32f 30 :3 0
31 :3 0 329 32a
0 33 :2 0 32b
32c 0 32e 1a9
330 322 328 0
331 0 32e 0
331 1ab 0 332
1ae 37c 34 :3 0
30 :3 0 31 :3 0
335 336 0 35
:3 0 337 338 0
372 d :3 0 e
:3 0 33a 33b 0
d :3 0 1e :3 0
33d 33e 0 36
:2 0 2 :4 0 57
:2 0 21 :2 0 1f
:2 0 1b1 343 345
:3 0 1b4 33f 347
33c 349 348 :2 0
10 :3 0 22 :3 0
34b 34c 0 12
:4 0 58 :4 0 15
:2 0 16 :3 0 1b8
350 352 :3 0 15
:2 0 39 :4 0 1bb
354 356 :3 0 15
:2 0 3a :4 0 1be
358 35a :3 0 15
:2 0 35 :3 0 1c1
35c 35e :3 0 15
:2 0 3b :4 0 1c4
360 362 :3 0 15
:2 0 3c :3 0 3d
:3 0 1f :2 0 3e
:2 0 1c7 365 369
1cb 364 36b :3 0
1ce 34d 36d :2 0
36f 1d1 370 34a
36f 0 371 1d3
0 372 1d5 375
:3 0 375 0 375
374 372 373 :6 0
377 c :3 0 1d8
379 1da 378 377
:2 0 37a 1dc :2 0
37c 0 37c 37b
332 37a :6 0 37e
1 :3 0 1de 380
1e0 37f 37e :2 0
565 24 :3 0 59
:3 0 381 382 0
5a :3 0 27 :3 0
28 :3 0 27 :3 0
7 :3 0 7 :3 0
29 :3 0 27 :3 0
7 :3 0 2a :3 0
7 :3 0 2a :3 0
27 :3 0 27 :3 0
7 :3 0 27 :3 0
2b :3 0 3 :4 0
5b 1 :8 0 3ac
2d :4 0 397 :3 0
2e :3 0 2f :2 0
1e4 39a 39b :3 0
30 :3 0 31 :3 0
39d 39e 0 32
:2 0 39f 3a0 0
3a2 1e7 3a9 30
:3 0 31 :3 0 3a3
3a4 0 33 :2 0
3a5 3a6 0 3a8
1e9 3aa 39c 3a2
0 3ab 0 3a8
0 3ab 1eb 0
3ac 1ee 3f6 34
:3 0 30 :3 0 31
:3 0 3af 3b0 0
35 :3 0 3b1 3b2
0 3ec d :3 0
e :3 0 3b4 3b5
0 d :3 0 1e
:3 0 3b7 3b8 0
36 :2 0 2 :4 0
5c :2 0 21 :2 0
1f :2 0 1f1 3bd
3bf :3 0 1f4 3b9
3c1 3b6 3c3 3c2
:2 0 10 :3 0 22
:3 0 3c5 3c6 0
12 :4 0 5d :4 0
15 :2 0 16 :3 0
1f8 3ca 3cc :3 0
15 :2 0 39 :4 0
1fb 3ce 3d0 :3 0
15 :2 0 3a :4 0
1fe 3d2 3d4 :3 0
15 :2 0 35 :3 0
201 3d6 3d8 :3 0
15 :2 0 3b :4 0
204 3da 3dc :3 0
15 :2 0 3c :3 0
3d :3 0 1f :2 0
3e :2 0 207 3df
3e3 20b 3de 3e5
:3 0 20e 3c7 3e7
:2 0 3e9 211 3ea
3c4 3e9 0 3eb
213 0 3ec 215
3ef :3 0 3ef 0
3ef 3ee 3ec 3ed
:6 0 3f1 e :3 0
218 3f3 21a 3f2
3f1 :2 0 3f4 21c
:2 0 3f6 0 3f6
3f5 3ac 3f4 :6 0
3f8 1 :3 0 21e
3fa 220 3f9 3f8
:2 0 565 24 :3 0
5e :3 0 3fb 3fc
0 5f :3 0 27
:3 0 28 :3 0 27
:3 0 7 :3 0 7
:3 0 29 :3 0 27
:3 0 7 :3 0 2a
:3 0 7 :3 0 2a
:3 0 27 :3 0 27
:3 0 7 :3 0 27
:3 0 2b :3 0 3
:4 0 60 1 :8 0
426 2d :4 0 411
:3 0 2e :3 0 2f
:2 0 224 414 415
:3 0 30 :3 0 31
:3 0 417 418 0
32 :2 0 419 41a
0 41c 227 423
30 :3 0 31 :3 0
41d 41e 0 33
:2 0 41f 420 0
422 229 424 416
41c 0 425 0
422 0 425 22b
0 426 22e 470
34 :3 0 30 :3 0
31 :3 0 429 42a
0 35 :3 0 42b
42c 0 466 d
:3 0 e :3 0 42e
42f 0 d :3 0
1e :3 0 431 432
0 36 :2 0 2
:4 0 61 :2 0 21
:2 0 1f :2 0 231
437 439 :3 0 234
433 43b 430 43d
43c :2 0 10 :3 0
22 :3 0 43f 440
0 12 :4 0 62
:4 0 15 :2 0 16
:3 0 238 444 446
:3 0 15 :2 0 39
:4 0 23b 448 44a
:3 0 15 :2 0 3a
:4 0 23e 44c 44e
:3 0 15 :2 0 35
:3 0 241 450 452
:3 0 15 :2 0 3b
:4 0 244 454 456
:3 0 15 :2 0 3c
:3 0 3d :3 0 1f
:2 0 3e :2 0 247
459 45d 24b 458
45f :3 0 24e 441
461 :2 0 463 251
464 43e 463 0
465 253 0 466
255 469 :3 0 469
0 469 468 466
467 :6 0 46b 10
:3 0 258 46d 25a
46c 46b :2 0 46e
25c :2 0 470 0
470 46f 426 46e
:6 0 472 1 :3 0
25e 474 260 473
472 :2 0 565 24
:3 0 63 :3 0 475
476 0 64 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 65 1
:8 0 4a0 2d :4 0
48b :3 0 2e :3 0
2f :2 0 264 48e
48f :3 0 30 :3 0
31 :3 0 491 492
0 32 :2 0 493
494 0 496 267
49d 30 :3 0 31
:3 0 497 498 0
33 :2 0 499 49a
0 49c 269 49e
490 496 0 49f
0 49c 0 49f
26b 0 4a0 26e
4ea 34 :3 0 30
:3 0 31 :3 0 4a3
4a4 0 35 :3 0
4a5 4a6 0 4e0
d :3 0 e :3 0
4a8 4a9 0 d
:3 0 1e :3 0 4ab
4ac 0 36 :2 0
2 :4 0 66 :2 0
21 :2 0 1f :2 0
271 4b1 4b3 :3 0
274 4ad 4b5 4aa
4b7 4b6 :2 0 10
:3 0 22 :3 0 4b9
4ba 0 12 :4 0
67 :4 0 15 :2 0
16 :3 0 278 4be
4c0 :3 0 15 :2 0
39 :4 0 27b 4c2
4c4 :3 0 15 :2 0
3a :4 0 27e 4c6
4c8 :3 0 15 :2 0
35 :3 0 281 4ca
4cc :3 0 15 :2 0
3b :4 0 284 4ce
4d0 :3 0 15 :2 0
3c :3 0 3d :3 0
1f :2 0 3e :2 0
287 4d3 4d7 28b
4d2 4d9 :3 0 28e
4bb 4db :2 0 4dd
291 4de 4b8 4dd
0 4df 293 0
4e0 295 4e3 :3 0
4e3 0 4e3 4e2
4e0 4e1 :6 0 4e5
12 :3 0 298 4e7
29a 4e6 4e5 :2 0
4e8 29c :2 0 4ea
0 4ea 4e9 4a0
4e8 :6 0 4ec 1
:3 0 29e 4ee 2a0
4ed 4ec :2 0 565
68 :3 0 27 :3 0
28 :3 0 27 :3 0
7 :3 0 7 :3 0
29 :3 0 27 :3 0
7 :3 0 2a :3 0
7 :3 0 2a :3 0
27 :3 0 27 :3 0
7 :3 0 27 :3 0
2b :3 0 3 :4 0
69 1 :8 0 517
2d :4 0 502 :3 0
2e :3 0 2f :2 0
2a4 505 506 :3 0
30 :3 0 31 :3 0
508 509 0 32
:2 0 50a 50b 0
50d 2a7 514 30
:3 0 31 :3 0 50e
50f 0 33 :2 0
510 511 0 513
2a9 515 507 50d
0 516 0 513
0 516 2ab 0
517 2ae 561 34
:3 0 30 :3 0 31
:3 0 51a 51b 0
35 :3 0 51c 51d
0 557 d :3 0
e :3 0 51f 520
0 d :3 0 1e
:3 0 522 523 0
36 :2 0 2 :4 0
6a :2 0 21 :2 0
1f :2 0 2b1 528
52a :3 0 2b4 524
52c 521 52e 52d
:2 0 10 :3 0 22
:3 0 530 531 0
12 :4 0 6b :4 0
15 :2 0 16 :3 0
2b8 535 537 :3 0
15 :2 0 39 :4 0
2bb 539 53b :3 0
15 :2 0 3a :4 0
2be 53d 53f :3 0
15 :2 0 35 :3 0
2c1 541 543 :3 0
15 :2 0 3b :4 0
2c4 545 547 :3 0
15 :2 0 3c :3 0
3d :3 0 1f :2 0
3e :2 0 2c7 54a
54e 2cb 549 550
:3 0 2ce 532 552
:2 0 554 2d1 555
52f 554 0 556
2d3 0 557 2d5
55a :3 0 55a 0
55a 559 557 558
:6 0 55c 14 :3 0
2d8 55e 2da 55d
55c :2 0 55f 2dc
:2 0 561 0 561
560 517 55f :6 0
563 1 :3 0 2de
564 0 563 :2 0
565 2e0 :2 0 566
a2 565 0 599
0 d :3 0 e
:3 0 567 568 0
d :3 0 1e :3 0
56a 56b 0 1f
:2 0 2 :4 0 6c
:2 0 21 :2 0 1f
:2 0 2eb 570 572
:3 0 2ee 56c 574
569 576 575 :2 0
10 :3 0 22 :3 0
578 579 0 12
:4 0 6d :4 0 15
:2 0 16 :3 0 2f2
57d 57f :3 0 15
:2 0 39 :4 0 2f5
581 583 :3 0 15
:2 0 6e :4 0 2f8
585 587 :3 0 15
:2 0 30 :3 0 31
:3 0 58a 58b 0
2fb 589 58d :3 0
2fe 57a 58f :2 0
591 301 592 577
591 0 593 303
0 599 b :3 0
30 :3 0 31 :3 0
595 596 0 597
:2 0 599 305 59c
:3 0 59c 30b 59c
59b 599 59a :6 0
59d :2 0 2 1c
59c 5a0 :3 0 59f
59d 5a1 :8 0 
30d
4
:3 0 1 3 1
9 1 f 1
15 4 8 e
14 18 1 1e
1 2a 1 36
2 39 3b 2
3e 40 2 42
44 2 46 48
2 4a 4c 2
4e 50 2 52
54 2 56 58
2 5a 5c 2
5e 60 2 62
64 2 66 68
2 6a 6c 1
72 2 74 75
2 6e 77 2
79 7b 4 32
38 3d 7d 1
7f 1 81 2
8b 8d 3 89
8a 8f 2 98
9a 2 97 9c
1 9e 1 a0
1 bb 2 ba
bb 1 c3 1
c9 2 cb cc
2 b8 cd 2
de e0 3 dc
dd e2 2 eb
ed 2 ef f1
2 f3 f5 2
f7 f9 2 fb
fd 3 102 103
104 2 ff 106
2 ea 108 1
10a 1 10c 2
d5 10d 1 111
1 d0 1 115
1 118 1 a5
1 137 2 136
137 1 13f 1
145 2 147 148
2 134 149 2
15a 15c 3 158
159 15e 2 167
169 2 16b 16d
2 16f 171 2
173 175 2 177
179 3 17e 17f
180 2 17b 182
2 166 184 1
186 1 188 2
151 189 1 18d
1 14c 1 191
1 194 1 11f
1 1b1 2 1b0
1b1 1 1b9 1
1bf 2 1c1 1c2
2 1ae 1c3 2
1d4 1d6 3 1d2
1d3 1d8 2 1e1
1e3 2 1e5 1e7
2 1e9 1eb 2
1ed 1ef 2 1f1
1f3 3 1f8 1f9
1fa 2 1f5 1fc
2 1e0 1fe 1
200 1 202 2
1cb 203 1 207
1 1c6 1 20b
1 20e 1 19b
1 22b 2 22a
22b 1 233 1
239 2 23b 23c
2 228 23d 2
24e 250 3 24c
24d 252 2 25b
25d 2 25f 261
2 263 265 2
267 269 2 26b
26d 3 272 273
274 2 26f 276
2 25a 278 1
27a 1 27c 2
245 27d 1 281
1 240 1 285
1 288 1 215
1 2a5 2 2a4
2a5 1 2ad 1
2b3 2 2b5 2b6
2 2a2 2b7 2
2c8 2ca 3 2c6
2c7 2cc 2 2d5
2d7 2 2d9 2db
2 2dd 2df 2
2e1 2e3 2 2e5
2e7 3 2ec 2ed
2ee 2 2e9 2f0
2 2d4 2f2 1
2f4 1 2f6 2
2bf 2f7 1 2fb
1 2ba 1 2ff
1 302 1 28f
1 31f 2 31e
31f 1 327 1
32d 2 32f 330
2 31c 331 2
342 344 3 340
341 346 2 34f
351 2 353 355
2 357 359 2
35b 35d 2 35f
361 3 366 367
368 2 363 36a
2 34e 36c 1
36e 1 370 2
339 371 1 375
1 334 1 379
1 37c 1 309
1 399 2 398
399 1 3a1 1
3a7 2 3a9 3aa
2 396 3ab 2
3bc 3be 3 3ba
3bb 3c0 2 3c9
3cb 2 3cd 3cf
2 3d1 3d3 2
3d5 3d7 2 3d9
3db 3 3e0 3e1
3e2 2 3dd 3e4
2 3c8 3e6 1
3e8 1 3ea 2
3b3 3eb 1 3ef
1 3ae 1 3f3
1 3f6 1 383
1 413 2 412
413 1 41b 1
421 2 423 424
2 410 425 2
436 438 3 434
435 43a 2 443
445 2 447 449
2 44b 44d 2
44f 451 2 453
455 3 45a 45b
45c 2 457 45e
2 442 460 1
462 1 464 2
42d 465 1 469
1 428 1 46d
1 470 1 3fd
1 48d 2 48c
48d 1 495 1
49b 2 49d 49e
2 48a 49f 2
4b0 4b2 3 4ae
4af 4b4 2 4bd
4bf 2 4c1 4c3
2 4c5 4c7 2
4c9 4cb 2 4cd
4cf 3 4d4 4d5
4d6 2 4d1 4d8
2 4bc 4da 1
4dc 1 4de 2
4a7 4df 1 4e3
1 4a2 1 4e7
1 4ea 1 477
1 504 2 503
504 1 50c 1
512 2 514 515
2 501 516 2
527 529 3 525
526 52b 2 534
536 2 538 53a
2 53c 53e 2
540 542 2 544
546 3 54b 54c
54d 2 548 54f
2 533 551 1
553 1 555 2
51e 556 1 55a
1 519 1 55e
1 561 a 11c
198 212 28c 306
380 3fa 474 4ee
564 2 56f 571
3 56d 56e 573
2 57c 57e 2
580 582 2 584
586 2 588 58c
2 57b 58e 1
590 1 592 5
82 a1 566 593
598 1 22 
1
4
0 
5a0
0
1
28
15
6
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

2 0 1
f 1 0
3 1 0
1e 1 0
9 1 0
15 1 0
0

/
SHOW ERRORS FUNCTION FC_U_NAMES;
ALTER FUNCTION FC_U_NAMES COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_WP_DATES ==
CREATE OR REPLACE FUNCTION SP_U_WP_DATES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ee
2 :e:
1FUNCTION:
1SP_U_WP_DATES:
1ASSIGN_ID:
1VARCHAR2:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_PROJECT_ID:
1H_ACTUAL_START:
1H_START_DATE:
1H_FINISH_DATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_SD:
1DATE:
1H_FD:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_BILLABLE:
1PLS_INTEGER:
10:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DAYOFYEAR:
1H_LAST_SUBMITTED:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_TRANSFED_CRI:
1H_TASK_ID:
1H_RES_ID:
1H_REC_USER:
1H_EFFORT:
1H_CONTOUR:
1H_DELAY:
1H_PERCENT_UNITS:
1H_WORK_PERCENT:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_WORK:
1H_SKIP:
1H_LAST_DAY:
1H_MINUTES:
1H_PER_DAY:
1H_WORK_TYPE:
1H_ASSIGN_COUNT:
1H_DURATION:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_SCHED_EFFORT:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_DATES(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1);:
1CHECK_TRACE:
174:
1+:
1FPUT:
1               ENTER:: SP_U_WP_DATES(75) :: cplan.sql(14051) :: :
1PROJECT_ASSIGNMENT_ID:
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1LAST_SUBMITTED:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1UNITS_MSP:
1ACTUAL_START:
1WORK_TODATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1ASSIGNMENT_DELAY:
1LAST_SCHED_MIN:
1TO_DATE:
1SUBSTR:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ASSIGNMENT_ID, PROJECT_ID, RESOURCE_ID,:n      RESOURCE_TYPE, +
1BIT_FLAG, LAST_SUBMITTED, C_CONTOUR, C_EFFORT, T_UNIT, C_UNIT,:n      UNITS_M+
1SP, ACTUAL_START, WORK_TODATE, UNRESOLVED_START, UNRESOLVED_FINISH,:n      CA+
1SE WHEN BIT_FLAG = '0' THEN PLANNED_WORK ELSE SCHED_WORK END, ASSIGNMENT_DELA+
1Y, LAST_SCHED_MIN,:n      TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n      REGULAR_C+
1OST, SPECIAL_COST, REGULAR_RATE, SPECIAL_RATE,:n      B_REGULAR_COST, B_SPECI+
1AL_COST, B_REGULAR_RATE, B_SPECIAL_RATE,:n      MILESTONE_PERCENT, TASK_ID:n +
1     INTO h_prj_assign_id, h_project_id, h_res_id,:n      h_res_type, h_bit_f+
1lag, h_last_submitted, h_contour, h_work, h_eunit, h_unit,:n      h_percent_u+
1nits, h_actual_start, h_work_todate, h_start_date, h_finish_date,:n      h_ef+
1fort, h_delay, h_last_day,:n      h_SD, h_FD, h_billable, h_capital_expense,+
1:n      h_reg_cost, h_spec_cost, h_reg_sale, h_spec_sale,:n      h_b_reg_cost+
1, h_b_spec_cost, h_b_reg_sale, h_b_spec_sale,:n      h_work_percent, h_task_i+
1d:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID = h_tsk_assignm+
1ent_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1108:
1           EXCEPTION:: SP_U_WP_DATES(109) :: cplan.sql(14085) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1116:
1        RETURN_ERROR:: SP_U_WP_DATES(117) :: cplan.sql(14093) :: :
1STATE:: :
1TO_CHAR:
1PMO_CNST:
1RECORD_NOT_FOUND:
1 ID:: :
1119:
1                EXIT:: SP_U_WP_DATES(120) :: cplan.sql(14096) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1>:
1!=:
1132:
1        RETURN_ERROR:: SP_U_WP_DATES(133) :: cplan.sql(14109) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1135:
1                EXIT:: SP_U_WP_DATES(136) :: cplan.sql(14112) :: :
1MINUTE_PER_DAY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, MINUTE_PER_DAY:n         INTO h_project_id, h_per_day:n   +
1      FROM TMT_WBS WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1151:
1           EXCEPTION:: SP_U_WP_DATES(152) :: cplan.sql(14128) :: :
18:
1163:
1      RETURN_INVALID:: SP_U_WP_DATES(164) :: cplan.sql(14140) :: :
1INVALID_PARAMS:
1166:
1                EXIT:: SP_U_WP_DATES(167) :: cplan.sql(14143) :: :
1PMO_RETURN_INVALID_SP:
1-:
1FC_TPHASE_SCHED_ASSIGN:
1FC_U_TDY_LAST_ACTUAL:
1FC_DEL_NOACTUAL:
12:
1DB2TIMESTAMP:
1TIME:
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n         INTO h_start_date:n         FRO+
1M DUAL:
1205:
1           EXCEPTION:: SP_U_WP_DATES(206) :: cplan.sql(14182) :: :
1FC_RESCHEDULE:
1222:
1        RETURN_ERROR:: SP_U_WP_DATES(223) :: cplan.sql(14199) :: :
1TASK_ASSIGNMENT_ERROR:
1225:
1                EXIT:: SP_U_WP_DATES(226) :: cplan.sql(14202) :: :
1CONSIDER:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_SCHED_BIT:
1SC_PLANNED_BIT:
1BAK_START_DT:
1SCHED_START:
1PLANNED_START:
1BAK_FINISH_DT:
1SCHED_FINISH:
1PLANNED_FINISH:
1BAK_ASSIGN_STRING:
1ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,(PMO_CNST.SC_SCHED_BIT+PMO_CNST.SC_PLANNED_BIT)),:n         BAK_START_+
1DT = COALESCE(SCHED_START,PLANNED_START), BAK_FINISH_DT = COALESCE(SCHED_FINI+
1SH,PLANNED_FINISH),:n         BAK_ASSIGN_STRING = ASSIGN_STRING:n         WHE+
1RE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1FOUND:
1100:
1245:
1           EXCEPTION:: SP_U_WP_DATES(246) :: cplan.sql(14222) :: :
1FC_ROLLUP:
1253:
1        RETURN_ERROR:: SP_U_WP_DATES(254) :: cplan.sql(14230) :: :
1256:
1                EXIT:: SP_U_WP_DATES(257) :: cplan.sql(14233) :: :
14:
1262:
1       RETURN_STATUS:: SP_U_WP_DATES(263) :: cplan.sql(14239) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1269:
1           EXCEPTION:: SP_U_WP_DATES(270) :: cplan.sql(14246) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1281:
1           EXCEPTION:: SP_U_WP_DATES(282) :: cplan.sql(14258) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
7cb
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6e 7e a0 b4 2e 7e
6e b4 2e 6e a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 6e a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:2 a0 d :49 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
a0 7e b4 2e 5a a0 7e b4
2e 5a a 10 :2 a0 d :2 a0 d
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :9 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d a0 51 d b7 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 :2 19 3c b7
19 3c a0 7e 51 b4 2e d
:c a0 a5 b d :2 a0 51 a5 b
7e 51 b4 2e 5a a0 7e b4
2e :2 5a a 10 :9 a0 51 a5 b
d b7 19 3c a0 7e b4 2e
5a :4 a0 51 a5 b d b7 :2 a0
:2 51 a5 b 7e 6e b4 2e :4 a0
51 a5 b d b7 :4 a0 51 a5
b d b7 :2 19 3c b7 :2 19 3c
a0 7e b4 2e 5a :a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d b7 19 3c a0
51 d :a a0 51 a5 b :2 a0 51
a5 b a5 b d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :16 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :3 a0 a5 b d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
7cb
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ee
dd e1 e9 bc 106 f5 f9 101
dc 122 111 115 11d d9 13a 129
12d 135 110 156 145 149 151 10d
16e 15d 161 169 144 18a 179 17d
185 141 1a6 191 195 198 199 1a1
178 1c3 1b1 175 1b5 1b6 1be 1b0
1df 1ce 1d2 1ad 1da 1cd 1fb 1ea
1ee 1ca 1f6 1e9 217 206 20a 1e6
212 205 233 222 226 22e 202 24b
23a 23e 246 221 267 256 25a 21e
262 255 283 272 276 252 27e 271
29f 28e 292 26e 29a 28d 2bb 2aa
2ae 28a 2b6 2a9 2d8 2c6 2a6 2ca
2cb 2d3 2c5 2f5 2e3 2c2 2e7 2e8
2f0 2e2 312 300 2df 304 305 30d
2ff 32e 31d 321 2fc 329 31c 34a
339 33d 319 345 338 366 355 359
335 361 354 382 371 375 351 37d
370 39e 38d 391 36d 399 38c 3ba
3a9 3ad 389 3b5 3a8 3d6 3c5 3c9
3a5 3d1 3c4 3f2 3e1 3e5 3c1 3ed
3e0 40e 3fd 401 3dd 409 3fc 42a
419 41d 3f9 425 418 446 435 439
415 441 434 462 451 455 431 45d
450 47e 46d 471 44d 479 46c 49a
489 48d 469 495 488 4b6 4a5 4a9
485 4b1 4a4 4d2 4c1 4c5 4a1 4cd
4c0 4ee 4dd 4e1 4bd 4e9 4dc 50a
4f9 4fd 4d9 505 4f8 526 515 519
4f5 521 514 542 531 535 511 53d
530 55e 54d 551 52d 559 54c 57a
569 56d 549 575 568 596 585 589
565 591 584 5b2 5a1 5a5 581 5ad
5a0 5ce 5bd 5c1 59d 5c9 5bc 5ea
5d9 5dd 5b9 5e5 5d8 606 5f5 5f9
5d5 601 5f4 622 611 615 5f1 61d
610 63e 62d 631 60d 639 62c 65a
649 64d 629 655 648 67a 665 669
645 66d 675 664 681 685 661 689
68d 691 694 699 69a 1 69c 6a1
6a5 6a9 6ac 6b1 6b5 6b9 6bc 6c1
6c2 6c4 6c9 6cc 6d0 6d1 6d6 6db
6de 6e3 6e4 6e9 6ec 6f0 6f1 6f6
6f9 6fe 6ff 704 707 70c 70d 712
715 719 71d 722 725 729 72a 72f
732 737 738 73d 742 743 745 74a
74b 74d 74e 753 756 75b 75c 761
764 768 76c 771 774 778 779 77e
781 786 787 78c 791 792 794 799
79a 79c 79d 7a2 7a5 7aa 7ab 7b0
7b3 7b8 7b9 7be 7c1 7c5 7c6 7cb
7ce 7d3 7d4 7d9 7dc 7e1 7e2 7e7
7e8 7ed 7ef 7f3 7f6 7fa 7fe 801
805 809 80c 80f 814 817 81a 81d
81e 823 824 1 826 82b 82f 833
836 83b 840 843 847 848 84d 84e
853 855 859 85c 860 864 868 86c
870 874 878 87c 880 884 888 88c
890 894 898 89c 8a0 8a4 8a8 8ac
8b0 8b4 8b8 8bc 8c0 8c4 8c8 8cc
8d0 8d4 8d8 8dc 8e0 8e4 8e8 8ec
8f0 8f4 8f8 8fc 900 904 908 90c
910 914 918 91c 920 924 928 92c
930 934 938 93c 940 944 948 94c
950 954 958 95c 960 964 968 96c
970 974 978 97c 980 984 988 98c
990 994 998 9a4 9a8 9ac 9af 9b3
9b7 9b9 1 9bd 9c1 9c5 9c8 9cc
9d0 9d4 9d8 9db 9df 9e3 9e6 9e9
9ee 9f1 9f4 9f7 9f8 9fd 9fe 1
a00 a05 a09 a0d a10 a15 a1a a1d
a21 a22 a27 a2a a2f a30 a35 a38
a3d a3e a43 a46 a4a a4b a50 a53
a58 a59 a5e a61 a65 a69 a6c a6f
a70 a72 a73 a78 a79 a7e a80 a84
a87 a89 a8d a8f a9b a9d a9f aa0
aa5 aa9 aab ab7 ab9 abd ac1 ac4
ac8 acb acf ad2 ad3 ad8 adb adf
ae3 ae6 aea aee af1 af4 af9 afc
aff b02 b03 b08 b09 1 b0b b10
b14 b18 b1b b20 b25 b28 b2c b2d
b32 b35 b3a b3b b40 b43 b48 b49
b4e b51 b55 b59 b5d b61 b64 b65
b67 b6c b6d b6f b70 b75 b78 b7d
b7e b83 b86 b8b b8c b91 b94 b98
b99 b9e ba1 ba6 ba7 bac bad bb2
bb4 bb8 bbb bbf bc3 bc6 bca bce
bd1 bd4 bd9 bdc bdf be2 be3 be8
be9 1 beb bf0 bf4 bf8 bfb c00
c05 c08 c0c c0d c12 c13 c18 c1a
c1e c21 c25 c29 c2c c30 c34 c37
c3b c3f c40 c45 c47 c4b c4e c52
c55 c56 c5b c5e c62 c65 c66 c6b
1 c6e c73 c77 c7b c7f c83 c87
c8b c8f c93 c96 c9a c9e ca1 ca2
ca4 ca7 caa cab cb0 cb3 cb7 cbb
cbe cc2 cc6 cc9 cca ccc ccf cd2
cd3 cd8 1 cdb ce0 ce4 ce8 ceb
cef cf3 cf6 cf9 cfe d01 d04 d07
d08 d0d d0e 1 d10 d15 d19 d1d
d20 d25 d2a d2d d31 d32 d37 d3a
d3f d40 d45 d48 d4d d4e d53 d56
d5a d5e d62 d66 d69 d6a d6c d71
d72 d74 d75 d7a d7d d82 d83 d88
d8b d90 d91 d96 d99 d9d d9e da3
da6 dab dac db1 db2 db7 db9 dbd
dc0 dc4 dc8 dcb dcf dd3 dd6 dd9
dde de1 de4 de7 de8 ded dee 1
df0 df5 df9 dfd e00 e05 e0a e0d
e11 e12 e17 e18 e1d e1f e23 e26
e2a e2e e31 e35 e39 e3c e40 e44
e45 e4a e4c e50 e53 e57 e5b e5f
e63 e67 e6b e6f e73 e77 e83 e87
e8b e8e e92 e96 e98 1 e9c ea0
ea4 ea7 eab eaf eb3 eb7 eba ebe
ec2 ec5 ec8 ecd ed0 ed3 ed6 ed7
edc edd 1 edf ee4 ee8 eec eef
ef4 ef9 efc f00 f01 f06 f09 f0e
f0f f14 f17 f1c f1d f22 f25 f29
f2a f2f f32 f37 f38 f3d f40 f44
f48 f4b f4e f4f f51 f52 f57 f58
f5d f5f f63 f66 f68 f6c f6e f7a
f7c f7e f7f f84 f88 f8a f96 f98
f9c fa0 fa3 fa7 fab fae faf fb1
fb4 fb7 fb8 fbd fc1 fc5 fc9 fcd
fd0 fd4 fd6 fda fde fe1 fe5 fe9
fec fef ff4 ff7 ffa ffd ffe 1003
1004 1 1006 100b 100f 1013 1016 101b
1020 1023 1027 1028 102d 1030 1035 1036
103b 103e 1043 1044 1049 104c 1050 1054
1058 105c 105f 1060 1062 1067 1068 106a
106b 1070 1071 1076 1078 107c 107f 1083
1087 108a 108e 1092 1095 1098 109d 10a0
10a3 10a6 10a7 10ac 10ad 1 10af 10b4
10b8 10bc 10bf 10c4 10c9 10cc 10d0 10d1
10d6 10d7 10dc 10de 10e2 10e5 10e9 10ed
10f0 10f4 10f8 10fb 10ff 1100 1105 1107
110b 110f 1112 1114 1118 111b 111f 1122
1125 1126 112b 112f 1133 1137 113b 113f
1143 1147 114b 114f 1153 1157 115b 115f
1160 1162 1166 116a 116e 1171 1172 1174
1177 117a 117b 1180 1183 1187 118a 118b
1190 1193 1 1196 119b 119f 11a3 11a7
11ab 11af 11b3 11b7 11bb 11bf 11c2 11c3
11c5 11c9 11cb 11cf 11d2 11d6 11d9 11da
11df 11e2 11e6 11ea 11ee 11f2 11f5 11f6
11f8 11fc 11fe 1202 1206 1209 120c 120d
120f 1212 1217 1218 121d 1221 1225 1229
122d 1230 1231 1233 1237 1239 123d 1241
1245 1249 124c 124d 124f 1253 1255 1259
125d 1260 1262 1266 126a 126d 1271 1274
1275 127a 127d 1281 1285 1289 128d 1291
1295 1299 129d 12a1 12a5 12b1 12b5 12b9
12bc 12c0 12c4 12c6 1 12ca 12ce 12d2
12d5 12d9 12dd 12e1 12e5 12e8 12ec 12f0
12f3 12f6 12fb 12fe 1301 1304 1305 130a
130b 1 130d 1312 1316 131a 131d 1322
1327 132a 132e 132f 1334 1337 133c 133d
1342 1345 134a 134b 1350 1353 1357 1358
135d 1360 1365 1366 136b 136e 1372 1376
1379 137c 137d 137f 1380 1385 1386 138b
138d 1391 1394 1396 139a 139c 13a8 13aa
13ac 13ad 13b2 13b6 13b8 13c4 13c6 13ca
13ce 13d2 13d5 13d6 13d8 13db 13df 13e3
13e6 13e7 13e9 13ea 13ef 13f3 13f5 13f9
13fc 1400 1403 1407 140b 140f 1413 1417
141b 141f 1423 1427 142b 142f 1432 1433
1435 1439 143d 1440 1441 1443 1444 1446
144a 144e 1452 1455 1456 1458 145b 145e
145f 1464 1468 146c 146f 1473 1477 147a
147d 1482 1485 1488 148b 148c 1491 1492
1 1494 1499 149d 14a1 14a4 14a9 14ae
14b1 14b5 14b6 14bb 14be 14c3 14c4 14c9
14cc 14d1 14d2 14d7 14da 14de 14e2 14e6
14ea 14ed 14ee 14f0 14f5 14f6 14f8 14f9
14fe 1501 1506 1507 150c 150f 1514 1515
151a 151d 1521 1522 1527 152a 152f 1530
1535 1536 153b 153d 1541 1544 1548 154c
154f 1553 1557 155a 155d 1562 1565 1568
156b 156c 1571 1572 1 1574 1579 157d
1581 1584 1589 158e 1591 1595 1596 159b
159c 15a1 15a3 15a7 15aa 15ae 15b2 15b5
15b9 15bd 15c0 15c4 15c8 15c9 15ce 15d0
15d4 15d8 15dc 15e0 15e4 15e8 15ec 15f0
15f4 15f8 15fc 1600 1604 1608 160c 1610
1614 1618 161c 1620 1624 1628 1634 1638
163d 1641 1644 1645 164a 164e 1652 1655
1658 165c 165e 1662 1666 1669 166c 1670
1672 1676 167a 167d 167f 1 1683 1687
168b 168e 1692 1696 169a 169e 16a1 16a5
16a9 16ac 16af 16b4 16b7 16ba 16bd 16be
16c3 16c4 1 16c6 16cb 16cf 16d3 16d6
16db 16e0 16e3 16e7 16e8 16ed 16f0 16f5
16f6 16fb 16fe 1703 1704 1709 170c 1710
1711 1716 1719 171e 171f 1724 1727 172b
172f 1732 1735 1736 1738 1739 173e 173f
1744 1746 174a 174d 174f 1753 1755 1761
1763 1765 1766 176b 176f 1771 177d 177f
1781 1785 1789 178c 1790 1794 1798 1799
179b 179f 17a3 17a7 17aa 17ae 17b2 17b5
17b8 17bd 17c0 17c3 17c6 17c7 17cc 17cd
1 17cf 17d4 17d8 17dc 17df 17e4 17e9
17ec 17f0 17f1 17f6 17f9 17fe 17ff 1804
1807 180c 180d 1812 1815 1819 181d 1821
1822 1824 1829 182a 182c 182d 1832 1835
183a 183b 1840 1843 1848 1849 184e 1851
1855 1856 185b 185e 1863 1864 1869 186a
186f 1871 1875 1878 187c 1880 1883 1887
188b 188e 1891 1896 1899 189c 189f 18a0
18a5 18a6 1 18a8 18ad 18b1 18b5 18b8
18bd 18c2 18c5 18c9 18ca 18cf 18d0 18d5
18d7 18db 18de 18e2 18e6 18e9 18ed 18f1
18f4 18f5 18f7 18fb 18ff 1900 1905 1909
190d 1910 1914 1918 191b 191e 1923 1926
1929 192c 192d 1932 1933 1 1935 193a
193e 1942 1945 194a 194f 1952 1956 1957
195c 195f 1964 1965 196a 196d 1972 1973
1978 197b 197f 1983 1987 198b 198e 198f
1991 1996 1997 1999 199a 199f 19a2 19a7
19a8 19ad 19b0 19b5 19b6 19bb 19be 19c2
19c3 19c8 19cb 19d0 19d1 19d6 19d7 19dc
19de 19e2 19e5 19e9 19ed 19f0 19f4 19f8
19fb 19ff 1a03 1a04 1a09 1a0b 1a0f 1a13
1a16 1a1a 1a1e 1a21 1a25 1a29 1a2c 1a2f
1a34 1a37 1a3a 1a3d 1a3e 1a43 1a44 1
1a46 1a4b 1a4f 1a53 1a56 1a5b 1a60 1a63
1a67 1a68 1a6d 1a6e 1a73 1a77 1a7b 1a7e
1a83 1a88 1a8b 1a8f 1a93 1a96 1a97 1a9c
1a9f 1aa4 1aa5 1aaa 1aad 1ab1 1ab5 1ab8
1ab9 1abe 1abf 1ac4 1ac6 1aca 1acd 1ad1
1ad5 1ad9 1add 1ae1 1ae5 1ae9 1aed 1af1
1afd 1b02 1b06 1b0a 1b0e 1b12 1b14 1b15
1b1a 1 1b1e 1b22 1b26 1b29 1b2d 1b31
1b35 1b39 1b3c 1b40 1b44 1b47 1b4a 1b4f
1b52 1b55 1b58 1b59 1b5e 1b5f 1 1b61
1b66 1b6a 1b6e 1b71 1b76 1b7b 1b7e 1b82
1b83 1b88 1b89 1b8e 1b92 1b96 1b99 1b9e
1ba3 1ba6 1baa 1bab 1bb0 1bb3 1bb8 1bb9
1bbe 1bc1 1bc5 1bc9 1bcc 1bcf 1bd0 1bd2
1bd3 1bd8 1bd9 1bde 1be0 1be4 1be7 1beb
1bef 1bf3 1bf7 1bfb 1bff 1c03 1c0f 1c14
1c18 1c1c 1c20 1c24 1c26 1c2a 1c2c 1c38
1c3a 1c3c 1c3d 1c42 1c46 1c48 1c54 1c58
1c5a 1c5b 1c64 
7cb
2
0 1 a 6 10 :3 6 16 :3 6
17 :3 6 10 :2 6 1 3 a 13
a :2 1 4 18 21 20 :2 18 :2 4
14 1d 1c :2 14 :2 4 11 1a 19
:2 11 :2 4 :3 13 :2 4 :3 11 :2 4 :3 12 :2 4
:3 12 :2 4 :3 13 :2 4 :3 9 :2 4 :3 9 :2 4
f 18 17 :2 f :2 4 f 18 17
:2 f :2 4 :2 f 1e f :2 4 :2 16 25
16 :2 4 :2 11 20 11 :2 4 :3 10 :2 4
:3 15 :2 4 :2 12 21 12 :2 4 :2 d 1c
d :2 4 :2 11 20 11 :2 4 :2 13 22
13 :2 4 e 17 16 :2 e :2 4 d
16 15 :2 d :2 4 f 18 17 :2 f
:2 4 :2 d 1c d :2 4 :2 e 1d e
:2 4 :2 c 1b c :2 4 :2 14 23 14
:2 4 :2 13 22 13 :2 4 :2 12 21 12
:2 4 :2 11 20 11 :2 4 :2 b 1a b
:2 4 :2 b 1a b :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 e 1d e
:2 4 :2 10 1f 10 :2 4 :2 13 22 13
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 f 1e f :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 13 22 13
:2 4 :2 14 23 14 :2 4 :2 f 1e f
:2 4 :2 f 19 f :2 4 :2 f 19 f
:2 4 :2 10 1a 10 :2 4 :2 10 1a 10
:2 4 :2 11 1b 11 :2 4 :2 11 1b 11
:2 4 :2 12 1c 12 :2 4 :2 12 1c 12
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 55 5b 5e :2 55 6c 83
8 :2 6c d 10 :2 6c 1a 1d :2 6c
b e :2 6c 13 16 1f 26 2b
2e :2 26 3e 41 :2 26 46 :2 1f 4f
:2 16 :2 6c b e :2 6c 13 16 1f
26 2b 2e :2 26 3f 42 :2 26 47
:2 1f 50 :2 16 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 28 2b :2 6c
30 33 :2 6c :2 7 4b :2 4 7 :2 11
23 :2 2d 39 3c 4d 4f 50 :2 4d
:2 23 :3 7 :2 d 12 1e 5e 61 :2 1e
:2 7 53 :3 4 1b :2 4 12 4 e
25 31 7 16 20 30 3b 45
4d 7 12 20 2d 3f 11 25
37 47 59 7 f 16 31 39
40 5c 66 7 15 23 31 7
17 27 37 7 1a c 1d 2b
7 13 1f 31 3c 44 4d 7
18 28 37 45 7 11 1a 7
d 13 1f 7 13 20 2c 7
15 24 32 7 17 c d 21
:2 7 :2 10 1c 7 4 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
54 57 58 :2 54 :2 29 :3 d :2 13 18
24 65 68 :2 24 75 78 :2 24 7c
7f :2 24 8b 8e :2 24 96 99 :2 24
a5 a8 af b8 bb :2 a8 :2 24 :2 d
5b :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a 7 a :2 14
26 :2 30 3c 40 51 54 55 :2 51
:2 26 :3 a :2 10 15 21 62 65 :2 21
72 75 :2 21 79 7c :2 21 86 89
92 9a :2 a3 :2 92 b6 :2 89 :2 21 be
c1 :2 21 c9 cc :2 21 d1 d4 :2 21
e8 eb :2 21 :2 a 58 :2 7 a :2 14
26 :2 30 3c 3f 50 53 54 :2 50
:2 26 :3 a :2 10 15 21 62 65 :2 21
:2 a 57 :3 7 :2 12 26 :2 2f 41 f
:2 7 35 :2 4 :4 8 7 :4 2a 29 :3 7
18 :2 7 19 7 b :2 16 1e 2d
3d :2 b 41 43 :2 41 a 4b :2 56
d 1d 2c :2 4b 30 33 :2 30 4a
:2 a d :2 17 29 :2 33 3f 43 54
57 58 :2 54 :2 29 :3 d :2 13 18 24
65 68 :2 24 75 78 :2 24 7c 7f
:2 24 89 8c 95 9d :2 a6 :2 95 c3
:2 8c :2 24 cb ce :2 24 d6 d9 :2 24
de e1 :2 24 f5 f8 :2 24 :2 d 5b
:2 a d :2 17 29 :2 33 3f 42 53
56 57 :2 53 :2 29 :3 d :2 13 18 24
65 68 :2 24 :2 d 5a :3 a :2 15 29
:2 32 4e 12 :2 a 36 :2 7 11 1d
f 1d f 1d 2a 3b 48 :2 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 57
5a 5b :2 57 :2 2c :3 10 :2 16 1b 27
68 6b :2 27 78 7b :2 27 7f 82
:2 27 8e 91 :2 27 99 9c :2 27 a8
ab b2 bb be :2 ab :2 27 :2 10 5e
:2 d :2 a :4 16 :2 a 7 :3 48 a :2 15
1d 2c 3a :2 a 3e 41 :2 3e a
1a :2 a 15 a 43 d :2 17 29
:2 33 3f 42 53 56 57 :2 53 :2 29
:3 d :2 13 18 24 65 68 :2 24 75
78 :2 24 7c 7f :2 24 89 8c 95
9d :2 a6 :2 95 b7 :2 8c :2 24 :2 d 5a
:2 a d :2 17 29 :2 33 3f 42 53
56 57 :2 53 :2 29 :3 d :2 13 18 24
65 68 :2 24 :2 d 5a :3 a :2 15 2b
:2 34 44 :2 a :4 7 48 :3 4 14 15
:2 14 :2 4 17 2e 3c 47 5c 62
2d 39 45 53 2d :2 17 4 8
11 1d :2 8 20 22 :2 20 7 :4 2b
2a 29 :3 7 15 2a 38 43 4d
26 3b 4d 59 :2 15 7 4a :2 4
:4 8 :2 7 1a 2a 38 4d :2 1a 7
25 a 11 1d 20 :2 a 23 25
:2 23 a 1d 2d 3b 50 :2 1d a
29 a 1d 2d 3b 50 :2 1d a
:4 7 :4 4 :4 8 7 11 1c 29 31
38 53 5e 63 :2 f :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 57 5a 5b
:2 57 :2 2c :3 10 :2 16 1b 27 68 6b
:2 27 78 7b :2 27 7f 82 :2 27 8e
91 :2 27 99 9c :2 27 a8 ab b2
bb be :2 ab :2 27 :2 10 5e :2 d :2 a
:4 16 :2 a 7 :3 26 7 13 1c 26
:2 13 29 2b 34 43 :2 2b :2 13 7
26 :3 4 12 :2 4 17 25 3a 48
52 5e 24 30 39 42 :2 30 46
4f 60 :2 46 :2 17 4 7 10 21
:2 7 24 27 :2 24 a :2 14 26 :2 30
3c 40 51 54 55 :2 51 :2 26 :3 a
:2 10 15 21 62 65 :2 21 72 75
:2 21 79 7c :2 21 86 89 92 9a
:2 a3 :2 92 bb :2 89 :2 21 c3 c6 :2 21
ce d1 :2 21 d6 d9 :2 21 ed f0
:2 21 :2 a 58 :2 7 a :2 14 26 :2 30
3c 3f 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 :2 12 26 :2 2f 46 f :2 7 29
11 26 34 42 4b 52 5f 68
75 7e a 19 22 2e 3e 4e
57 64 a 1e 10 24 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 57 5a 5b :2 57 :2 2c :3 10 :2 16
1b 27 68 6b :2 27 78 7b :2 27
7f 82 :2 27 8e 91 :2 27 99 9c
:2 27 a8 ab b2 bb be :2 ab :2 27
:2 10 5e :2 d :2 a :4 16 :2 a 7 :8 4
12 1c :2 12 4 7 :2 11 23 :2 2d
39 3d 4e 51 52 :2 4e :2 23 :3 7
:2 d 12 1e 5f 62 :2 1e 6f 72
:2 1e 76 79 :2 1e 83 86 8f 97
:2 8f a4 :2 86 :2 1e ac af :2 1e b7
ba :2 1e bf c2 :2 1e d6 d9 :2 1e
:2 7 55 :2 4 7 :2 11 23 :2 2d 39
3c 4d 50 51 :2 4d :2 23 :3 7 :2 d
12 1e 5f 62 :2 1e :2 7 54 :3 4
:2 f 23 2c 38 :2 23 3c c :2 4
7 :2 11 23 :2 2d 39 3c 4d 50
51 :2 4d :2 23 :3 7 :2 d 12 1e 5f
62 :2 1e 6f 72 :2 1e 76 79 :2 1e
83 86 8f 97 :2 a0 :2 8f ab :2 86
:2 1e b3 b6 :2 1e be c1 :2 1e c6
c9 :2 1e dd e0 :2 1e :2 7 54 :3 4
:2 f 21 :2 2a 34 49 :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
51 54 55 :2 51 :2 26 :3 a :2 10 15
21 62 65 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 58 :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4e 51 52 :2 4e :2 23 :3 7 :2 d 12
1e 5f 62 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 55 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
7cb
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:5 c :5 d :5 e :5 f
:5 10 :5 11 :5 12 :7 13
:7 14 :6 15 :6 16 :6 17
:5 18 :5 19 :6 1a :6 1b
:6 1c :6 1d :7 1e :7 1f
:7 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :7 40
:b 42 :11 43 44 :2 43
:2 44 :2 43 :2 44 :2 43
:2 45 :2 43 :12 45 :2 43
:2 46 :2 43 :12 46 :2 43
:2 47 :2 43 :2 47 :2 43
:2 47 :2 43 :2 47 :2 43
:2 47 :4 43 :3 42 :11 4a
:b 4b :3 4a :3 51 :3 52
:3 55 :7 56 :5 57 :5 58
:8 59 :4 5a :4 5b :2 5c
:3 5d :7 5e :5 5f :3 60
:4 61 :4 62 :4 63 :2 64
65 :2 66 55 :5 67
54 :2 69 :5 6b :11 6c
:24 6d :3 6c :2 6a :6 69
68 :3 41 :a 73 :11 74
:30 75 :3 74 :11 77 :b 78
:3 77 :7 7a 7b :2 7a
:3 73 :c 7e :3 7f :3 80
:10 82 :3 83 :2 82 :4 83
:3 82 :11 84 :30 85 :3 84
:11 87 :b 88 :3 87 :7 8a
8b :2 8a 83 :2 82
:2 8f :2 90 :5 91 8f
:5 92 8e :2 94 :5 96
:11 97 :24 98 :3 97 :2 95
:6 94 93 :3 7e :c 9f
:3 a0 :3 a1 9f :11 a3
:20 a4 :3 a3 :11 a6 :b a7
:3 a6 :9 a9 a2 :3 9f
:3 7e :6 ae :7 af :4 b0
b1 :3 af :12 b3 :6 b4
:4 b5 :3 b4 :3 b3 :5 b9
:8 ba b9 :a bc :8 bd
bc :8 bf be :3 bc
bb :3 b9 :5 c3 :8 c5
c6 c7 c5 :5 c8
c4 :2 ca :5 cc :11 cd
:24 ce :3 cd :2 cb :6 ca
c9 :3 c3 :f d3 :3 c3
:3 d8 :7 d9 :b da :3 d9
:9 dd :11 de :30 df :3 de
:11 e1 :b e2 :3 e1 :7 e4
e5 :2 e4 dd :a e8
:8 e9 :2 ea :2 eb e8
:6 ec :5 ed ec :5 ef
ee :3 ec e7 :2 f2
:5 f4 :11 f5 :24 f6 :3 f5
:2 f3 :6 f2 f1 :4 e6
:3 dd :6 fc :11 fd :2e fe
:3 fd :11 100 :b 101 :3 100
:9 103 104 :2 103 :11 106
:30 107 :3 106 :a 109 41
:3 10c :11 10d :b 10e :17 10f
:3 10d :2 111 :3 112 :3 113
114 112 111 112
:3 115 :3 10c :2 116 :5 118
:11 119 :b 11a :18 11b :3 119
:2 11d 11e :3 11f 120
11e 11d 11e :3 121
:2 117 :6 116 10b :7 1

1c66
4
:3 0 1 :3 0 2
:a 0 7c6 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 15 16 0
b 4 :3 0 8
:7 0 11 10 :3 0
9 :3 0 a :3 0
b :2 0 4 13
17 0 7c6 2
18 :2 0 d :2 0
12 4 :3 0 d
:2 0 10 1b 1d
:6 0 20 1e 0
7c4 0 c :6 0
d :2 0 16 4
:3 0 14 22 24
:6 0 27 25 0
7c4 0 e :6 0
1c d9 0 1a
4 :3 0 18 29
2b :6 0 2e 2c
0 7c4 0 f
:6 0 20 10d 0
1e 6 :3 0 30
:7 0 33 31 0
7c4 0 10 :6 0
6 :3 0 35 :7 0
38 36 0 7c4
0 11 :6 0 24
141 0 22 6
:3 0 3a :7 0 3d
3b 0 7c4 0
12 :6 0 6 :3 0
3f :7 0 42 40
0 7c4 0 13
:6 0 28 175 0
26 6 :3 0 44
:7 0 47 45 0
7c4 0 14 :6 0
16 :3 0 49 :7 0
4c 4a 0 7c4
0 15 :6 0 19
:2 0 2c 16 :3 0
4e :7 0 51 4f
0 7c4 0 17
:6 0 4 :3 0 19
:2 0 2a 53 55
:6 0 58 56 0
7c4 0 18 :6 0
1d :2 0 30 4
:3 0 2e 5a 5c
:6 0 5f 5d 0
7c4 0 1a :6 0
1d :2 0 32 1c
:3 0 61 :7 0 65
62 63 7c4 0
1b :6 0 1d :2 0
34 1c :3 0 67
:7 0 6b 68 69
7c4 0 1e :6 0
38 21e 0 36
1c :3 0 6d :7 0
71 6e 6f 7c4
0 1f :6 0 1d
:2 0 3a 16 :3 0
73 :7 0 76 74
0 7c4 0 20
:6 0 16 :3 0 78
:7 0 7b 79 0
7c4 0 21 :6 0
1d :2 0 3c 1c
:3 0 7d :7 0 81
7e 7f 7c4 0
22 :6 0 1d :2 0
3e 1c :3 0 83
:7 0 87 84 85
7c4 0 23 :6 0
1d :2 0 40 1c
:3 0 89 :7 0 8d
8a 8b 7c4 0
24 :6 0 d :2 0
42 1c :3 0 8f
:7 0 93 90 91
7c4 0 25 :6 0
d :2 0 46 4
:3 0 44 95 97
:6 0 9a 98 0
7c4 0 26 :6 0
d :2 0 4a 4
:3 0 48 9c 9e
:6 0 a1 9f 0
7c4 0 27 :6 0
1d :2 0 4e 4
:3 0 4c a3 a5
:6 0 a8 a6 0
7c4 0 28 :6 0
1d :2 0 50 1c
:3 0 aa :7 0 ae
ab ac 7c4 0
29 :6 0 1d :2 0
52 1c :3 0 b0
:7 0 b4 b1 b2
7c4 0 2a :6 0
1d :2 0 54 1c
:3 0 b6 :7 0 ba
b7 b8 7c4 0
2b :6 0 1d :2 0
56 1c :3 0 bc
:7 0 c0 bd be
7c4 0 2c :6 0
1d :2 0 58 1c
:3 0 c2 :7 0 c6
c3 c4 7c4 0
2d :6 0 1d :2 0
5a 1c :3 0 c8
:7 0 cc c9 ca
7c4 0 2e :6 0
1d :2 0 5c 1c
:3 0 ce :7 0 d2
cf d0 7c4 0
2f :6 0 1d :2 0
5e 1c :3 0 d4
:7 0 d8 d5 d6
7c4 0 30 :6 0
1d :2 0 60 1c
:3 0 da :7 0 de
db dc 7c4 0
31 :6 0 1d :2 0
62 1c :3 0 e0
:7 0 e4 e1 e2
7c4 0 32 :6 0
1d :2 0 64 1c
:3 0 e6 :7 0 ea
e7 e8 7c4 0
33 :6 0 1d :2 0
66 1c :3 0 ec
:7 0 f0 ed ee
7c4 0 34 :6 0
1d :2 0 68 1c
:3 0 f2 :7 0 f6
f3 f4 7c4 0
35 :6 0 1d :2 0
6a 1c :3 0 f8
:7 0 fc f9 fa
7c4 0 36 :6 0
1d :2 0 6c 1c
:3 0 fe :7 0 102
ff 100 7c4 0
37 :6 0 1d :2 0
6e 1c :3 0 104
:7 0 108 105 106
7c4 0 38 :6 0
1d :2 0 70 1c
:3 0 10a :7 0 10e
10b 10c 7c4 0
39 :6 0 1d :2 0
72 1c :3 0 110
:7 0 114 111 112
7c4 0 3a :6 0
1d :2 0 74 1c
:3 0 116 :7 0 11a
117 118 7c4 0
3b :6 0 1d :2 0
76 1c :3 0 11c
:7 0 120 11d 11e
7c4 0 3c :6 0
1d :2 0 78 1c
:3 0 122 :7 0 126
123 124 7c4 0
3d :6 0 1d :2 0
7a 1c :3 0 128
:7 0 12c 129 12a
7c4 0 3e :6 0
1d :2 0 7c 40
:3 0 12e :7 0 132
12f 130 7c4 0
3f :6 0 1d :2 0
7e 40 :3 0 134
:7 0 138 135 136
7c4 0 41 :6 0
1d :2 0 80 40
:3 0 13a :7 0 13e
13b 13c 7c4 0
42 :6 0 1d :2 0
82 40 :3 0 140
:7 0 144 141 142
7c4 0 43 :6 0
1d :2 0 84 40
:3 0 146 :7 0 14a
147 148 7c4 0
44 :6 0 1d :2 0
86 40 :3 0 14c
:7 0 150 14d 14e
7c4 0 45 :6 0
1d :2 0 88 40
:3 0 152 :7 0 156
153 154 7c4 0
46 :6 0 15e 15f
0 8a 40 :3 0
158 :7 0 15c 159
15a 7c4 0 47
:6 0 164 165 0
8c a :3 0 b
:2 0 4 160 :7 0
163 161 0 7c4
0 48 :6 0 49
:3 0 4a :3 0 49
:3 0 4b :3 0 167
168 0 2 :4 0
8e 169 16b 166
16d 16c :2 0 4c
:3 0 4d :3 0 16f
170 0 4e :4 0
49 :3 0 4f :3 0
173 174 0 2
:4 0 90 175 177
50 :4 0 51 :2 0
52 :3 0 92 17a
17c :3 0 53 :4 0
51 :2 0 54 :4 0
95 17f 181 :3 0
51 :2 0 3 :3 0
98 183 185 :3 0
51 :2 0 54 :4 0
9b 187 189 :3 0
51 :2 0 55 :4 0
9e 18b 18d :3 0
51 :2 0 56 :3 0
57 :3 0 54 :4 0
51 :2 0 5 :3 0
a1 193 195 :3 0
51 :2 0 54 :4 0
a4 197 199 :3 0
58 :4 0 a7 191
19c 59 :4 0 aa
190 19f ad 18f
1a1 :3 0 51 :2 0
55 :4 0 b0 1a3
1a5 :3 0 51 :2 0
56 :3 0 57 :3 0
54 :4 0 51 :2 0
7 :3 0 b3 1ab
1ad :3 0 51 :2 0
54 :4 0 b6 1af
1b1 :3 0 58 :4 0
b9 1a9 1b4 59
:4 0 bc 1a8 1b7
bf 1a7 1b9 :3 0
51 :2 0 55 :4 0
c2 1bb 1bd :3 0
51 :2 0 54 :4 0
c5 1bf 1c1 :3 0
51 :2 0 8 :3 0
c8 1c3 1c5 :3 0
51 :2 0 54 :4 0
cb 1c7 1c9 :3 0
51 :2 0 5a :4 0
ce 1cb 1cd :3 0
d1 171 1cf :2 0
1d1 d6 1d2 16e
1d1 0 1d3 d8
0 724 49 :3 0
4a :3 0 1d4 1d5
0 49 :3 0 5b
:3 0 1d7 1d8 0
19 :2 0 2 :4 0
5c :2 0 5d :2 0
19 :2 0 da 1dd
1df :3 0 dd 1d9
1e1 1d6 1e3 1e2
:2 0 4c :3 0 5e
:3 0 1e5 1e6 0
4e :4 0 5f :4 0
51 :2 0 52 :3 0
e1 1ea 1ec :3 0
e4 1e7 1ee :2 0
1f0 e7 1f1 1e4
1f0 0 1f2 e9
0 724 c :3 0
3 :3 0 1f3 1f4
0 724 28 :3 0
8 :3 0 1f6 1f7
0 724 60 :3 0
61 :3 0 62 :3 0
63 :3 0 64 :3 0
65 :3 0 66 :3 0
67 :3 0 68 :3 0
69 :3 0 6a :3 0
6b :3 0 6c :3 0
6d :3 0 6e :3 0
64 :3 0 6f :3 0
70 :3 0 71 :3 0
72 :3 0 73 :3 0
74 :3 0 6d :3 0
73 :3 0 74 :3 0
6e :3 0 75 :3 0
76 :3 0 77 :3 0
78 :3 0 79 :3 0
7a :3 0 7b :3 0
7c :3 0 7d :3 0
7e :3 0 7f :3 0
80 :3 0 e :3 0
f :3 0 27 :3 0
1a :3 0 18 :3 0
21 :3 0 2a :3 0
30 :3 0 3a :3 0
3b :3 0 2c :3 0
10 :3 0 2e :3 0
11 :3 0 12 :3 0
29 :3 0 2b :3 0
32 :3 0 15 :3 0
17 :3 0 1b :3 0
1e :3 0 3f :3 0
42 :3 0 41 :3 0
43 :3 0 44 :3 0
46 :3 0 45 :3 0
47 :3 0 2d :3 0
26 :3 0 81 :3 0
82 :3 0 c :4 0
83 1 :8 0 248
a :3 0 84 :3 0
243 244 0 85
:3 0 245 246 0
248 eb 292 86
:3 0 a :3 0 84
:3 0 24b 24c 0
85 :3 0 24d 24e
0 288 49 :3 0
4a :3 0 250 251
0 49 :3 0 5b
:3 0 253 254 0
87 :2 0 2 :4 0
88 :2 0 5d :2 0
19 :2 0 ee 259
25b :3 0 f1 255
25d 252 25f 25e
:2 0 4c :3 0 5e
:3 0 261 262 0
4e :4 0 89 :4 0
51 :2 0 52 :3 0
f5 266 268 :3 0
51 :2 0 8a :4 0
f8 26a 26c :3 0
51 :2 0 8b :4 0
fb 26e 270 :3 0
51 :2 0 85 :3 0
fe 272 274 :3 0
51 :2 0 8c :4 0
101 276 278 :3 0
51 :2 0 74 :3 0
8d :3 0 19 :2 0
8e :2 0 104 27b
27f 108 27a 281
:3 0 10b 263 283
:2 0 285 10e 286
260 285 0 287
110 0 288 112
28b :3 0 28b 0
28b 28a 288 289
:6 0 28d 2 :3 0
115 28f 117 28e
28d :2 0 290 119
:2 0 292 0 292
291 248 290 :6 0
724 1 :3 0 a
:3 0 84 :3 0 294
295 0 a :3 0
8f :2 0 90 :3 0
297 299 0 11d
298 29b :3 0 29c
:2 0 49 :3 0 4a
:3 0 29e 29f 0
49 :3 0 5b :3 0
2a1 2a2 0 d
:2 0 2 :4 0 91
:2 0 5d :2 0 19
:2 0 120 2a7 2a9
:3 0 123 2a3 2ab
2a0 2ad 2ac :2 0
4c :3 0 5e :3 0
2af 2b0 0 4e
:4 0 92 :4 0 51
:2 0 52 :3 0 127
2b4 2b6 :3 0 51
:2 0 8a :4 0 12a
2b8 2ba :3 0 51
:2 0 93 :4 0 12d
2bc 2be :3 0 51
:2 0 56 :3 0 94
:3 0 95 :3 0 96
:3 0 2c3 2c4 0
130 2c2 2c6 59
:4 0 132 2c1 2c9
135 2c0 2cb :3 0
51 :2 0 97 :4 0
138 2cd 2cf :3 0
51 :2 0 54 :4 0
13b 2d1 2d3 :3 0
51 :2 0 c :3 0
13e 2d5 2d7 :3 0
51 :2 0 54 :4 0
141 2d9 2db :3 0
144 2b1 2dd :2 0
2df 147 2e0 2ae
2df 0 2e1 149
0 30b 49 :3 0
4a :3 0 2e2 2e3
0 49 :3 0 5b
:3 0 2e5 2e6 0
19 :2 0 2 :4 0
98 :2 0 5d :2 0
19 :2 0 14b 2eb
2ed :3 0 14e 2e7
2ef 2e4 2f1 2f0
:2 0 4c :3 0 5e
:3 0 2f3 2f4 0
4e :4 0 99 :4 0
51 :2 0 52 :3 0
152 2f8 2fa :3 0
155 2f5 2fc :2 0
2fe 158 2ff 2f2
2fe 0 300 15a
0 30b 9a :3 0
9b :3 0 301 302
0 95 :3 0 96
:3 0 304 305 0
c :3 0 9c :3 0
15c 303 309 :2 0
30b 160 30c 29d
30b 0 30d 164
0 724 5 :3 0
9d :2 0 166 30f
310 :3 0 311 :2 0
7 :3 0 9d :2 0
168 314 315 :3 0
316 :2 0 312 318
317 :2 0 13 :3 0
5 :3 0 31a 31b
0 47a 14 :3 0
7 :3 0 31d 31e
0 47a 9e :3 0
9f :3 0 320 321
0 13 :3 0 14
:3 0 a0 :2 0 16a
322 326 a1 :2 0
1d :2 0 170 328
32a :3 0 32b :2 0
9e :3 0 9f :3 0
32d 32e 0 14
:3 0 12 :3 0 a0
:2 0 173 32f 333
a2 :2 0 1d :2 0
179 335 337 :3 0
338 :2 0 32c 33a
339 :2 0 49 :3 0
4a :3 0 33c 33d
0 49 :3 0 5b
:3 0 33f 340 0
d :2 0 2 :4 0
a3 :2 0 5d :2 0
19 :2 0 17c 345
347 :3 0 17f 341
349 33e 34b 34a
:2 0 4c :3 0 5e
:3 0 34d 34e 0
4e :4 0 a4 :4 0
51 :2 0 52 :3 0
183 352 354 :3 0
51 :2 0 8a :4 0
186 356 358 :3 0
51 :2 0 93 :4 0
189 35a 35c :3 0
51 :2 0 56 :3 0
94 :3 0 95 :3 0
a5 :3 0 361 362
0 18c 360 364
59 :4 0 18e 35f
367 191 35e 369
:3 0 51 :2 0 97
:4 0 194 36b 36d
:3 0 51 :2 0 54
:4 0 197 36f 371
:3 0 51 :2 0 c
:3 0 19a 373 375
:3 0 51 :2 0 54
:4 0 19d 377 379
:3 0 1a0 34f 37b
:2 0 37d 1a3 37e
34c 37d 0 37f
1a5 0 3a9 49
:3 0 4a :3 0 380
381 0 49 :3 0
5b :3 0 383 384
0 19 :2 0 2
:4 0 a6 :2 0 5d
:2 0 19 :2 0 1a7
389 38b :3 0 1aa
385 38d 382 38f
38e :2 0 4c :3 0
5e :3 0 391 392
0 4e :4 0 a7
:4 0 51 :2 0 52
:3 0 1ae 396 398
:3 0 1b1 393 39a
:2 0 39c 1b4 39d
390 39c 0 39e
1b6 0 3a9 9a
:3 0 9b :3 0 39f
3a0 0 95 :3 0
a5 :3 0 3a2 3a3
0 c :3 0 9c
:3 0 1b8 3a1 3a7
:2 0 3a9 1bc 3aa
33b 3a9 0 3ab
1c0 0 47a 61
:3 0 a8 :3 0 f
:3 0 34 :3 0 a9
:3 0 61 :3 0 f
:3 0 aa :3 0 26
:4 0 ab 1 :8 0
3bb a :3 0 84
:3 0 3b6 3b7 0
85 :3 0 3b8 3b9
0 3bb 1c2 405
86 :3 0 a :3 0
84 :3 0 3be 3bf
0 85 :3 0 3c0
3c1 0 3fb 49
:3 0 4a :3 0 3c3
3c4 0 49 :3 0
5b :3 0 3c6 3c7
0 87 :2 0 2
:4 0 ac :2 0 5d
:2 0 19 :2 0 1c5
3cc 3ce :3 0 1c8
3c8 3d0 3c5 3d2
3d1 :2 0 4c :3 0
5e :3 0 3d4 3d5
0 4e :4 0 ad
:4 0 51 :2 0 52
:3 0 1cc 3d9 3db
:3 0 51 :2 0 8a
:4 0 1cf 3dd 3df
:3 0 51 :2 0 8b
:4 0 1d2 3e1 3e3
:3 0 51 :2 0 85
:3 0 1d5 3e5 3e7
:3 0 51 :2 0 8c
:4 0 1d8 3e9 3eb
:3 0 51 :2 0 74
:3 0 8d :3 0 19
:2 0 8e :2 0 1db
3ee 3f2 1df 3ed
3f4 :3 0 1e2 3d6
3f6 :2 0 3f8 1e5
3f9 3d3 3f8 0
3fa 1e7 0 3fb
1e9 3fe :3 0 3fe
0 3fe 3fd 3fb
3fc :6 0 400 4
:3 0 1ec 402 1ee
401 400 :2 0 403
1f0 :2 0 405 0
405 404 3bb 403
:6 0 47a 1 :3 0
9e :3 0 9f :3 0
407 408 0 13
:3 0 11 :3 0 a0
:2 0 1f2 409 40d
a2 :2 0 1d :2 0
1f8 40f 411 :3 0
11 :3 0 13 :3 0
413 414 0 419
2b :3 0 1d :2 0
416 417 0 419
1fb 477 49 :3 0
4a :3 0 41a 41b
0 49 :3 0 5b
:3 0 41d 41e 0
ae :2 0 2 :4 0
af :2 0 5d :2 0
19 :2 0 1fe 423
425 :3 0 201 41f
427 41c 429 428
:2 0 4c :3 0 5e
:3 0 42b 42c 0
4e :4 0 b0 :4 0
51 :2 0 52 :3 0
205 430 432 :3 0
51 :2 0 8a :4 0
208 434 436 :3 0
51 :2 0 93 :4 0
20b 438 43a :3 0
51 :2 0 56 :3 0
94 :3 0 95 :3 0
b1 :3 0 43f 440
0 20e 43e 442
59 :4 0 210 43d
445 213 43c 447
:3 0 216 42d 449
:2 0 44b 219 44c
42a 44b 0 44d
21b 0 476 49
:3 0 4a :3 0 44e
44f 0 49 :3 0
5b :3 0 451 452
0 19 :2 0 2
:4 0 b2 :2 0 5d
:2 0 19 :2 0 21d
457 459 :3 0 220
453 45b 450 45d
45c :2 0 4c :3 0
5e :3 0 45f 460
0 4e :4 0 b3
:4 0 51 :2 0 52
:3 0 224 464 466
:3 0 227 461 468
:2 0 46a 22a 46b
45e 46a 0 46c
22c 0 476 9a
:3 0 b4 :3 0 46d
46e 0 95 :3 0
b1 :3 0 470 471
0 9c :3 0 22e
46f 474 :2 0 476
231 478 412 419
0 479 0 476
0 479 235 0
47a 238 47b 319
47a 0 47c 23e
0 724 1f :3 0
b5 :2 0 19 :2 0
240 47e 480 :3 0
47d 481 0 724
3d :3 0 b6 :3 0
f :3 0 26 :3 0
c :3 0 15 :3 0
17 :3 0 3f :3 0
41 :3 0 1f :3 0
1e :3 0 1b :3 0
242 484 48f 483
490 0 724 56
:3 0 32 :3 0 1d
:2 0 24d 492 495
a1 :2 0 1d :2 0
252 497 499 :3 0
49a :2 0 21 :3 0
9d :2 0 255 49d
49e :3 0 49f :2 0
4a0 :2 0 49b 4a2
4a1 :2 0 3e :3 0
b7 :3 0 f :3 0
26 :3 0 27 :3 0
e :3 0 c :3 0
21 :3 0 32 :3 0
1d :2 0 257 4a5
4ae 4a4 4af 0
4b1 260 4b2 4a3
4b1 0 4b3 262
0 724 e :3 0
9d :2 0 264 4b5
4b6 :3 0 4b7 :2 0
3d :3 0 b8 :3 0
f :3 0 c :3 0
b9 :2 0 266 4ba
4be 4b9 4bf 0
4c1 26a 4e2 74
:3 0 18 :3 0 19
:2 0 19 :2 0 26c
4c2 4c6 8f :2 0
b9 :4 0 272 4c8
4ca :3 0 3d :3 0
b8 :3 0 f :3 0
c :3 0 1d :2 0
275 4cd 4d1 4cc
4d2 0 4d4 279
4de 3d :3 0 b8
:3 0 f :3 0 c
:3 0 19 :2 0 27b
4d6 4da 4d5 4db
0 4dd 27f 4df
4cb 4d4 0 4e0
0 4dd 0 4e0
281 0 4e1 284
4e3 4b8 4c1 0
4e4 0 4e1 0
4e4 286 0 724
21 :3 0 9d :2 0
289 4e6 4e7 :3 0
4e8 :2 0 9e :3 0
ba :3 0 73 :3 0
74 :3 0 21 :3 0
9e :3 0 bb :3 0
11 :3 0 11 :3 0
bc :4 0 bd 1
:8 0 4fa a :3 0
84 :3 0 4f5 4f6
0 85 :3 0 4f7
4f8 0 4fa 28b
544 86 :3 0 a
:3 0 84 :3 0 4fd
4fe 0 85 :3 0
4ff 500 0 53a
49 :3 0 4a :3 0
502 503 0 49
:3 0 5b :3 0 505
506 0 87 :2 0
2 :4 0 be :2 0
5d :2 0 19 :2 0
28e 50b 50d :3 0
291 507 50f 504
511 510 :2 0 4c
:3 0 5e :3 0 513
514 0 4e :4 0
bf :4 0 51 :2 0
52 :3 0 295 518
51a :3 0 51 :2 0
8a :4 0 298 51c
51e :3 0 51 :2 0
8b :4 0 29b 520
522 :3 0 51 :2 0
85 :3 0 29e 524
526 :3 0 51 :2 0
8c :4 0 2a1 528
52a :3 0 51 :2 0
74 :3 0 8d :3 0
19 :2 0 8e :2 0
2a4 52d 531 2a8
52c 533 :3 0 2ab
515 535 :2 0 537
2ae 538 512 537
0 539 2b0 0
53a 2b2 53d :3 0
53d 0 53d 53c
53a 53b :6 0 53f
6 :3 0 2b5 541
2b7 540 53f :2 0
542 2b9 :2 0 544
0 544 543 4fa
542 :6 0 555 1
:3 0 29 :3 0 56
:3 0 29 :3 0 1d
:2 0 2bb 547 54a
b5 :2 0 56 :3 0
2e :3 0 1d :2 0
2be 54d 550 2c1
54c 552 :3 0 546
553 0 555 2c4
556 4e9 555 0
557 2c7 0 724
3e :3 0 b9 :2 0
558 559 0 724
3d :3 0 c0 :3 0
c :3 0 11 :3 0
29 :3 0 3e :3 0
2a :3 0 28 :3 0
56 :3 0 2b :3 0
1d :2 0 2c9 563
566 56 :3 0 2c
:3 0 1d :2 0 2cc
568 56b 2cf 55c
56d 55b 56e 0
724 56 :3 0 3d
:3 0 1d :2 0 2d8
570 573 a2 :2 0
1d :2 0 2dd 575
577 :3 0 49 :3 0
4a :3 0 579 57a
0 49 :3 0 5b
:3 0 57c 57d 0
d :2 0 2 :4 0
c1 :2 0 5d :2 0
19 :2 0 2e0 582
584 :3 0 2e3 57e
586 57b 588 587
:2 0 4c :3 0 5e
:3 0 58a 58b 0
4e :4 0 c2 :4 0
51 :2 0 52 :3 0
2e7 58f 591 :3 0
51 :2 0 8a :4 0
2ea 593 595 :3 0
51 :2 0 93 :4 0
2ed 597 599 :3 0
51 :2 0 56 :3 0
94 :3 0 95 :3 0
c3 :3 0 59e 59f
0 2f0 59d 5a1
59 :4 0 2f2 59c
5a4 2f5 59b 5a6
:3 0 51 :2 0 97
:4 0 2f8 5a8 5aa
:3 0 51 :2 0 54
:4 0 2fb 5ac 5ae
:3 0 51 :2 0 c
:3 0 2fe 5b0 5b2
:3 0 51 :2 0 54
:4 0 301 5b4 5b6
:3 0 304 58c 5b8
:2 0 5ba 307 5bb
589 5ba 0 5bc
309 0 5e6 49
:3 0 4a :3 0 5bd
5be 0 49 :3 0
5b :3 0 5c0 5c1
0 19 :2 0 2
:4 0 c4 :2 0 5d
:2 0 19 :2 0 30b
5c6 5c8 :3 0 30e
5c2 5ca 5bf 5cc
5cb :2 0 4c :3 0
5e :3 0 5ce 5cf
0 4e :4 0 c5
:4 0 51 :2 0 52
:3 0 312 5d3 5d5
:3 0 315 5d0 5d7
:2 0 5d9 318 5da
5cd 5d9 0 5db
31a 0 5e6 9a
:3 0 9b :3 0 5dc
5dd 0 95 :3 0
c3 :3 0 5df 5e0
0 c :3 0 9c
:3 0 31c 5de 5e4
:2 0 5e6 320 660
81 :3 0 c6 :3 0
c7 :3 0 c8 :3 0
c9 :3 0 c7 :3 0
95 :3 0 ca :3 0
95 :3 0 cb :3 0
cc :3 0 56 :3 0
cd :3 0 ce :3 0
cf :3 0 56 :3 0
d0 :3 0 d1 :3 0
d2 :3 0 d3 :3 0
82 :3 0 c :4 0
d4 1 :8 0 613
d5 :4 0 5fe :3 0
9c :3 0 8f :2 0
326 601 602 :3 0
a :3 0 84 :3 0
604 605 0 1d
:2 0 606 607 0
609 329 610 a
:3 0 84 :3 0 60a
60b 0 d6 :2 0
60c 60d 0 60f
32b 611 603 609
0 612 0 60f
0 612 32d 0
613 330 65d 86
:3 0 a :3 0 84
:3 0 616 617 0
85 :3 0 618 619
0 653 49 :3 0
4a :3 0 61b 61c
0 49 :3 0 5b
:3 0 61e 61f 0
87 :2 0 2 :4 0
d7 :2 0 5d :2 0
19 :2 0 333 624
626 :3 0 336 620
628 61d 62a 629
:2 0 4c :3 0 5e
:3 0 62c 62d 0
4e :4 0 d8 :4 0
51 :2 0 52 :3 0
33a 631 633 :3 0
51 :2 0 8a :4 0
33d 635 637 :3 0
51 :2 0 8b :4 0
340 639 63b :3 0
51 :2 0 85 :3 0
343 63d 63f :3 0
51 :2 0 8c :4 0
346 641 643 :3 0
51 :2 0 74 :3 0
8d :3 0 19 :2 0
8e :2 0 349 646
64a 34d 645 64c
:3 0 350 62e 64e
:2 0 650 353 651
62b 650 0 652
355 0 653 357
656 :3 0 656 0
656 655 653 654
:6 0 658 8 :3 0
35a 65a 35c 659
658 :2 0 65b 35e
:2 0 65d 0 65d
65c 613 65b :6 0
65f 1 :3 0 360
661 578 5e6 0
662 0 65f 0
662 362 0 724
3e :3 0 d9 :3 0
f :3 0 365 664
666 663 667 0
724 49 :3 0 4a
:3 0 669 66a 0
49 :3 0 5b :3 0
66c 66d 0 d
:2 0 2 :4 0 da
:2 0 5d :2 0 19
:2 0 367 672 674
:3 0 36a 66e 676
66b 678 677 :2 0
4c :3 0 5e :3 0
67a 67b 0 4e
:4 0 db :4 0 51
:2 0 52 :3 0 36e
67f 681 :3 0 51
:2 0 8a :4 0 371
683 685 :3 0 51
:2 0 93 :4 0 374
687 689 :3 0 51
:2 0 56 :3 0 94
:3 0 3e :3 0 377
68d 68f 59 :4 0
379 68c 692 37c
68b 694 :3 0 51
:2 0 97 :4 0 37f
696 698 :3 0 51
:2 0 54 :4 0 382
69a 69c :3 0 51
:2 0 c :3 0 385
69e 6a0 :3 0 51
:2 0 54 :4 0 388
6a2 6a4 :3 0 38b
67c 6a6 :2 0 6a8
38e 6a9 679 6a8
0 6aa 390 0
724 49 :3 0 4a
:3 0 6ab 6ac 0
49 :3 0 5b :3 0
6ae 6af 0 19
:2 0 2 :4 0 dc
:2 0 5d :2 0 19
:2 0 392 6b4 6b6
:3 0 395 6b0 6b8
6ad 6ba 6b9 :2 0
4c :3 0 5e :3 0
6bc 6bd 0 4e
:4 0 dd :4 0 51
:2 0 52 :3 0 399
6c1 6c3 :3 0 39c
6be 6c5 :2 0 6c7
39f 6c8 6bb 6c7
0 6c9 3a1 0
724 9a :3 0 9b
:3 0 6ca 6cb 0
56 :3 0 3e :3 0
1d :2 0 3a3 6cd
6d0 c :3 0 9c
:3 0 3a6 6cc 6d4
:2 0 724 49 :3 0
4a :3 0 6d6 6d7
0 49 :3 0 5b
:3 0 6d9 6da 0
de :2 0 2 :4 0
df :2 0 5d :2 0
19 :2 0 3aa 6df
6e1 :3 0 3ad 6db
6e3 6d8 6e5 6e4
:2 0 4c :3 0 5e
:3 0 6e7 6e8 0
4e :4 0 e0 :4 0
51 :2 0 52 :3 0
3b1 6ec 6ee :3 0
51 :2 0 8a :4 0
3b4 6f0 6f2 :3 0
51 :2 0 93 :4 0
3b7 6f4 6f6 :3 0
51 :2 0 56 :3 0
94 :3 0 a :3 0
84 :3 0 6fb 6fc
0 3ba 6fa 6fe
59 :4 0 3bc 6f9
701 3bf 6f8 703
:3 0 51 :2 0 97
:4 0 3c2 705 707
:3 0 51 :2 0 54
:4 0 3c5 709 70b
:3 0 51 :2 0 c
:3 0 3c8 70d 70f
:3 0 51 :2 0 54
:4 0 3cb 711 713
:3 0 3ce 6e9 715
:2 0 717 3d1 718
6e6 717 0 719
3d3 0 724 9a
:3 0 e1 :3 0 71a
71b 0 a :3 0
84 :3 0 71d 71e
0 c :3 0 9c
:3 0 3d5 71c 722
:2 0 724 3d9 7c5
a :3 0 e2 :2 0
4 725 726 0
49 :3 0 4a :3 0
728 729 0 49
:3 0 5b :3 0 72b
72c 0 87 :2 0
2 :4 0 e3 :2 0
5d :2 0 19 :2 0
3ef 731 733 :3 0
3f2 72d 735 72a
737 736 :2 0 4c
:3 0 5e :3 0 739
73a 0 4e :4 0
e4 :4 0 51 :2 0
52 :3 0 3f6 73e
740 :3 0 3f9 73b
742 :2 0 75b 4c
:3 0 5e :3 0 744
745 0 4e :4 0
e5 :4 0 51 :2 0
a :3 0 e6 :3 0
74a 74b 0 3fc
749 74d :3 0 51
:2 0 97 :4 0 3ff
74f 751 :3 0 51
:2 0 a :3 0 e7
:3 0 754 755 0
402 753 757 :3 0
405 746 759 :2 0
75b 408 75c 738
75b 0 75d 40b
0 76d e8 :3 0
48 :3 0 a :3 0
e6 :3 0 e9 :3 0
a :3 0 e7 :3 0
ea :3 0 bc :4 0
eb 1 :a 0 769
:2 0 76d 75f 767
:2 0 9 :3 0 48
:3 0 76b :2 0 76d
40d 76f 411 76e
76d :2 0 7c3 86
:3 0 a :3 0 84
:3 0 772 773 0
85 :3 0 774 775
0 7bb 49 :3 0
4a :3 0 777 778
0 49 :3 0 5b
:3 0 77a 77b 0
87 :2 0 2 :4 0
ec :2 0 5d :2 0
19 :2 0 413 780
782 :3 0 416 77c
784 779 786 785
:2 0 4c :3 0 5e
:3 0 788 789 0
4e :4 0 ed :4 0
51 :2 0 52 :3 0
41a 78d 78f :3 0
41d 78a 791 :2 0
7ab 4c :3 0 5e
:3 0 793 794 0
4e :4 0 8b :4 0
51 :2 0 85 :3 0
420 798 79a :3 0
51 :2 0 8c :4 0
423 79c 79e :3 0
51 :2 0 74 :3 0
8d :3 0 19 :2 0
8e :2 0 426 7a1
7a5 42a 7a0 7a7
:3 0 42d 795 7a9
:2 0 7ab 430 7ac
787 7ab 0 7ad
433 0 7bb e8
:3 0 48 :3 0 e9
:3 0 a :3 0 e7
:3 0 ea :3 0 bc
:4 0 ee 1 :a 0
7b7 :2 0 7bb 7af
7b5 :2 0 9 :3 0
48 :3 0 7b9 :2 0
7bb 435 7be :3 0
7be 0 7be 7bd
7bb 7bc :6 0 7c0
1 :3 0 43a 7c2
43c 7c1 7c0 :2 0
7c3 43e :2 0 7c5
441 7c5 7c4 724
7c3 :6 0 7c6 :2 0
2 18 7c5 7c9
:3 0 7c8 7c6 7ca
:8 0 
479
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 2f
1 34 1 39
1 3e 1 43
1 48 1 4d
1 54 1 52
1 5b 1 59
1 60 1 66
1 6c 1 72
1 77 1 7c
1 82 1 88
1 8e 1 96
1 94 1 9d
1 9b 1 a4
1 a2 1 a9
1 af 1 b5
1 bb 1 c1
1 c7 1 cd
1 d3 1 d9
1 df 1 e5
1 eb 1 f1
1 f7 1 fd
1 103 1 109
1 10f 1 115
1 11b 1 121
1 127 1 12d
1 133 1 139
1 13f 1 145
1 14b 1 151
1 157 1 15d
1 16a 1 176
2 179 17b 2
17e 180 2 182
184 2 186 188
2 18a 18c 2
192 194 2 196
198 2 19a 19b
2 19d 19e 2
18e 1a0 2 1a2
1a4 2 1aa 1ac
2 1ae 1b0 2
1b2 1b3 2 1b5
1b6 2 1a6 1b8
2 1ba 1bc 2
1be 1c0 2 1c2
1c4 2 1c6 1c8
2 1ca 1cc 4
172 178 17d 1ce
1 1d0 1 1d2
2 1dc 1de 3
1da 1db 1e0 2
1e9 1eb 2 1e8
1ed 1 1ef 1
1f1 2 242 247
2 258 25a 3
256 257 25c 2
265 267 2 269
26b 2 26d 26f
2 271 273 2
275 277 3 27c
27d 27e 2 279
280 2 264 282
1 284 1 286
2 24f 287 1
28b 1 24a 1
28f 1 29a 2
296 29a 2 2a6
2a8 3 2a4 2a5
2aa 2 2b3 2b5
2 2b7 2b9 2
2bb 2bd 1 2c5
2 2c7 2c8 2
2bf 2ca 2 2cc
2ce 2 2d0 2d2
2 2d4 2d6 2
2d8 2da 2 2b2
2dc 1 2de 1
2e0 2 2ea 2ec
3 2e8 2e9 2ee
2 2f7 2f9 2
2f6 2fb 1 2fd
1 2ff 3 306
307 308 3 2e1
300 30a 1 30c
1 30e 1 313
3 323 324 325
1 329 2 327
329 3 330 331
332 1 336 2
334 336 2 344
346 3 342 343
348 2 351 353
2 355 357 2
359 35b 1 363
2 365 366 2
35d 368 2 36a
36c 2 36e 370
2 372 374 2
376 378 2 350
37a 1 37c 1
37e 2 388 38a
3 386 387 38c
2 395 397 2
394 399 1 39b
1 39d 3 3a4
3a5 3a6 3 37f
39e 3a8 1 3aa
2 3b5 3ba 2
3cb 3cd 3 3c9
3ca 3cf 2 3d8
3da 2 3dc 3de
2 3e0 3e2 2
3e4 3e6 2 3e8
3ea 3 3ef 3f0
3f1 2 3ec 3f3
2 3d7 3f5 1
3f7 1 3f9 2
3c2 3fa 1 3fe
1 3bd 1 402
3 40a 40b 40c
1 410 2 40e
410 2 415 418
2 422 424 3
420 421 426 2
42f 431 2 433
435 2 437 439
1 441 2 443
444 2 43b 446
2 42e 448 1
44a 1 44c 2
456 458 3 454
455 45a 2 463
465 2 462 467
1 469 1 46b
2 472 473 3
44d 46c 475 2
477 478 5 31c
31f 3ab 405 479
1 47b 1 47f
a 485 486 487
488 489 48a 48b
48c 48d 48e 2
493 494 1 498
2 496 498 1
49c 8 4a6 4a7
4a8 4a9 4aa 4ab
4ac 4ad 1 4b0
1 4b2 1 4b4
3 4bb 4bc 4bd
1 4c0 3 4c3
4c4 4c5 1 4c9
2 4c7 4c9 3
4ce 4cf 4d0 1
4d3 3 4d7 4d8
4d9 1 4dc 2
4de 4df 1 4e0
2 4e2 4e3 1
4e5 2 4f4 4f9
2 50a 50c 3
508 509 50e 2
517 519 2 51b
51d 2 51f 521
2 523 525 2
527 529 3 52e
52f 530 2 52b
532 2 516 534
1 536 1 538
2 501 539 1
53d 1 4fc 1
541 2 548 549
2 54e 54f 2
54b 551 2 544
554 1 556 2
564 565 2 569
56a 8 55d 55e
55f 560 561 562
567 56c 2 571
572 1 576 2
574 576 2 581
583 3 57f 580
585 2 58e 590
2 592 594 2
596 598 1 5a0
2 5a2 5a3 2
59a 5a5 2 5a7
5a9 2 5ab 5ad
2 5af 5b1 2
5b3 5b5 2 58d
5b7 1 5b9 1
5bb 2 5c5 5c7
3 5c3 5c4 5c9
2 5d2 5d4 2
5d1 5d6 1 5d8
1 5da 3 5e1
5e2 5e3 3 5bc
5db 5e5 1 600
2 5ff 600 1
608 1 60e 2
610 611 2 5fd
612 2 623 625
3 621 622 627
2 630 632 2
634 636 2 638
63a 2 63c 63e
2 640 642 3
647 648 649 2
644 64b 2 62f
64d 1 64f 1
651 2 61a 652
1 656 1 615
1 65a 1 65d
2 660 661 1
665 2 671 673
3 66f 670 675
2 67e 680 2
682 684 2 686
688 1 68e 2
690 691 2 68a
693 2 695 697
2 699 69b 2
69d 69f 2 6a1
6a3 2 67d 6a5
1 6a7 1 6a9
2 6b3 6b5 3
6b1 6b2 6b7 2
6c0 6c2 2 6bf
6c4 1 6c6 1
6c8 2 6ce 6cf
3 6d1 6d2 6d3
2 6de 6e0 3
6dc 6dd 6e2 2
6eb 6ed 2 6ef
6f1 2 6f3 6f5
1 6fd 2 6ff
700 2 6f7 702
2 704 706 2
708 70a 2 70c
70e 2 710 712
2 6ea 714 1
716 1 718 3
71f 720 721 15
1d3 1f2 1f5 1f8
292 30d 47c 482
491 4b3 4e4 557
55a 56f 662 668
6aa 6c9 6d5 719
723 2 730 732
3 72e 72f 734
2 73d 73f 2
73c 741 2 748
74c 2 74e 750
2 752 756 2
747 758 2 743
75a 1 75c 3
75d 768 76c 1
727 2 77f 781
3 77d 77e 783
2 78c 78e 2
78b 790 2 797
799 2 79b 79d
3 7a2 7a3 7a4
2 79f 7a6 2
796 7a8 2 792
7aa 1 7ac 4
776 7ad 7b6 7ba
1 7be 1 771
2 76f 7c2 37
1f 26 2d 32
37 3c 41 46
4b 50 57 5e
64 6a 70 75
7a 80 86 8c
92 99 a0 a7
ad b3 b9 bf
c5 cb d1 d7
dd e3 e9 ef
f5 fb 101 107
10d 113 119 11f
125 12b 131 137
13d 143 149 14f
155 15b 162 
1
4
0 
7c9
0
1
14
a
3c
0 1 2 1 4 1 6 1
8 1 0 0 0 0 0 0
0 0 0 0 
11b 1 0
157 1 0
43 1 0
b5 1 0
127 1 0
d9 1 0
b 1 0
109 1 0
39 1 0
1a 1 0
6c 1 0
cd 1 0
df 1 0
f 1 0
59 1 0
3e 1 0
133 1 0
82 1 0
139 1 0
7c 1 0
72 1 0
121 1 0
e5 1 0
bb 1 0
f7 1 0
115 1 0
77 1 0
a9 1 0
c1 1 0
34 1 0
145 1 0
8e 1 0
60 1 0
103 1 0
4d 1 0
151 1 0
3 1 0
66 1 0
94 1 0
2f 1 0
c7 1 0
10f 1 0
d3 1 0
f1 1 0
52 1 0
13f 1 0
88 1 0
9b 1 0
28 1 0
eb 1 0
7 1 0
21 1 0
2 0 1
12d 1 0
48 1 0
fd 1 0
a2 1 0
af 1 0
14b 1 0
15d 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_DATES;
ALTER FUNCTION SP_U_WP_DATES COMPILE DEBUG;
/**************************************************************************/
Prompt == FUNCTION FC_U_WP_ACTUAL ==
CREATE OR REPLACE FUNCTION FC_U_WP_ACTUAL wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
144
2 :e:
1FUNCTION:
1FC_U_WP_ACTUAL:
1H_ASSIGN_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1SH_H_NEW_WORK_PERCENT:
1PLS_INTEGER:
1SH_H_ACTUAL:
1SH_H_UNITS:
1H_REC_USER:
1H_ERROR_ID:
1RETURN:
1H_NEW_WORK_PERCENT:
1H_ACTUAL:
1H_UNITS:
1H_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RES_ID:
1H_SD:
1DATE:
1H_FD:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_LAST_SUBMITTED:
1H_WEEK_OF:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_REC_STATUS:
1H_BILLABLE:
10:
1H_CAPITAL_EXPENSE:
1H_EFFORT:
1H_WORK_PERCENT:
1H_PERCENT_UNITS:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_LAST_DAY:
1H_PER_DAY:
1H_TASK_TYPE:
1H_TPH_DELETE:
1H_TEMP_VAR:
1H_MINUTES:
1H_DURATION:
1H_CONTOUR:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_WORK:
1H_SCHED_EFFORT:
1H_WORK_TYPE:
1H_ETC:
1H_CLOSE_TASK:
1H_REMAINING:
1H_ROLLUP_BITS:
1H_BITID:
1RAW:
136:
1PMO_CNST:
1SC_ZERO_BIT:
1H_BITID1:
1H_ASSIGN_STRING:
18192:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1DEBUG_PERFTIMING:
1T_TOTAL:
1S_TIME_1:
1S_TIME_2:
1S_TIME_3:
1S_TIME_4:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_WP_ACTUAL(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
182:
1+:
1FPUT:
1               ENTER:: FC_U_WP_ACTUAL(83) :: cplan.sql(14357) :: :
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1LAST_SUBMITTED:
1WORK_TODATE:
1SCHED_WORK:
1ETC:
1LAST_SCHED_MIN:
1PROJECT_ASSIGNMENT_ID:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1ASSIGN_UNITS:
1UNITS_MSP:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1TO_DATE:
1SUBSTR:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1ROLLUP_BITS:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, RESOURCE_ID, RESOURCE_TYPE, BIT_FLAG, LAST_SUBMITTED, WORK+
1_TODATE, SCHED_WORK-WORK_TODATE, ETC,:n      SCHED_WORK, LAST_SCHED_MIN, PROJ+
1ECT_ASSIGNMENT_ID, C_CONTOUR, C_EFFORT, T_UNIT, C_UNIT, CASE WHEN ASSIGN_UNIT+
1S > UNITS_MSP THEN ASSIGN_UNITS ELSE UNITS_MSP END,:n      UNRESOLVED_START, +
1UNRESOLVED_FINISH, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(SubStr(U+
1NRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n      REGULAR_COST, SP+
1ECIAL_COST, REGULAR_RATE, SPECIAL_RATE,:n      B_REGULAR_COST, B_SPECIAL_COST+
1, B_REGULAR_RATE, B_SPECIAL_RATE,:n      MILESTONE_PERCENT, TASK_ID, ROLLUP_B+
1ITS:n      INTO h_project_id, h_res_id, h_res_type, h_bit_flag, h_last_submit+
1ted, h_work_todate, h_remaining, h_etc,:n      h_effort, h_last_day, h_prj_as+
1sign_id, h_contour, h_work, h_eunit, h_unit, h_percent_units,:n      h_start_+
1date, h_finish_date, h_SD, h_FD, h_billable, h_capital_expense,:n      h_reg_+
1cost, h_spec_cost, h_reg_sale, h_spec_sale,:n      h_b_reg_cost, h_b_spec_cos+
1t, h_b_reg_sale, h_b_spec_sale,:n      h_work_percent, h_task_id, h_rollup_bi+
1ts:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID = h_id:
1PMO_DB2M:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1108:
1           EXCEPTION:: FC_U_WP_ACTUAL(109) :: cplan.sql(14383) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TASK_TYPE:
1SCHED_EFFORT:
1SCHED_DURATION:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, TASK_TYPE, SCHED_EFFORT, WORK_TODATE, MILESTONE_PERCENT, S+
1CHED_DURATION:n         INTO h_project_id, h_task_type, h_effort, h_work_toda+
1te, h_work_percent, h_duration:n         FROM TMT_WBS:n         WHERE ELEMENT+
1_ID = h_id:
1125:
1           EXCEPTION:: FC_U_WP_ACTUAL(126) :: cplan.sql(14400) :: :
1133:
1                EXIT:: FC_U_WP_ACTUAL(134) :: cplan.sql(14408) :: :
1RECORD_NOT_FOUND:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK:n         INTO h_temp_var:n         FROM PROJECT_DETAILS:n +
1        WHERE PROJECT_ID = h_project_id:
1150:
1           EXCEPTION:: FC_U_WP_ACTUAL(151) :: cplan.sql(14425) :: :
1>:
1REC_STATUS:
1SELECT REC_STATUS:n            INTO h_rec_status:n            FROM TMT_WBS:n +
1           WHERE ELEMENT_ID = h_project_id:
1167:
1           EXCEPTION:: FC_U_WP_ACTUAL(168) :: cplan.sql(14442) :: :
1PMO_ORASTD:
1STRCMP:
1L:
1175:
1                EXIT:: FC_U_WP_ACTUAL(176) :: cplan.sql(14450) :: :
1LEV_LOCKED_BY_COPY:
1COUNT:
1DUAL:
1A:
1TA:
1ACTIVITIES:
1TYPE_ID:
1SC_TIMESHEET_ACTIVITY:
1SELECT COUNT('X'):n         INTO h_temp_var:n         FROM DUAL:n         WHE+
1RE EXISTS(:n         SELECT A.ELEMENT_ID:n         FROM TASK_ASSIGNMENTS TA, +
1ACTIVITIES A:n         WHERE TA.PROJECT_ID = h_project_id:n         AND TA.TA+
1SK_ID = h_id:n         AND TA.TSK_ASSIGNMENT_ID = A.TSK_ASSIGNMENT_ID:n      +
1   AND A.TSK_ASSIGNMENT_ID <> A.ELEMENT_ID:n         AND A.TYPE_ID = PMO_CNST+
1.SC_TIMESHEET_ACTIVITY):
1200:
1           EXCEPTION:: FC_U_WP_ACTUAL(201) :: cplan.sql(14475) :: :
1208:
1                EXIT:: FC_U_WP_ACTUAL(209) :: cplan.sql(14483) :: :
1SC_TIMESHEET_STEP_EXISTS:
18:
1215:
1      RETURN_INVALID:: FC_U_WP_ACTUAL(216) :: cplan.sql(14490) :: :
1STATE:: :
1INVALID_PARAMS:
1218:
1                EXIT:: FC_U_WP_ACTUAL(219) :: cplan.sql(14493) :: :
1PMODEFINES:
1PMO_RETURN_INVALID:
1FALSE:
1ELSIF:
1!=:
1226:
1                EXIT:: FC_U_WP_ACTUAL(227) :: cplan.sql(14501) :: :
1SC_TASK_ACTUAL_GRATER_THAN_SCH:
1FC_U_TASK_PERCENT:
1238:
1      RETURN_INVALID:: FC_U_WP_ACTUAL(239) :: cplan.sql(14513) :: :
1241:
1                EXIT:: FC_U_WP_ACTUAL(242) :: cplan.sql(14516) :: :
1249:
1                EXIT:: FC_U_WP_ACTUAL(250) :: cplan.sql(14524) :: :
1266:
1           EXCEPTION:: FC_U_WP_ACTUAL(267) :: cplan.sql(14541) :: :
1283:
1           EXCEPTION:: FC_U_WP_ACTUAL(284) :: cplan.sql(14558) :: :
1291:
1                EXIT:: FC_U_WP_ACTUAL(292) :: cplan.sql(14566) :: :
1SELECT COUNT('X'):n         INTO h_temp_var:n         FROM DUAL:n         WHE+
1RE EXISTS(:n         SELECT ELEMENT_ID:n         FROM ACTIVITIES:n         WH+
1ERE TSK_ASSIGNMENT_ID = h_id:n         AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n +
1        AND TYPE_ID = PMO_CNST.SC_TIMESHEET_ACTIVITY):
1314:
1           EXCEPTION:: FC_U_WP_ACTUAL(315) :: cplan.sql(14589) :: :
1322:
1                EXIT:: FC_U_WP_ACTUAL(323) :: cplan.sql(14597) :: :
1MINUTE_PER_DAY:
1SELECT PROJECT_ID, MINUTE_PER_DAY:n         INTO h_project_id, h_per_day:n   +
1      FROM TMT_WBS:n         WHERE PROJECT_ID = h_project_id:n         AND EL+
1EMENT_ID = h_task_id:
1339:
1           EXCEPTION:: FC_U_WP_ACTUAL(340) :: cplan.sql(14614) :: :
1-:
1FC_TPHASE_SCHED_ASSIGN:
110000:
1<:
1CONSIDER:
1PMO_STPU:
1BIT_OR:
1SC_SCHED_BIT:
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_new_actual,:n           +
1                WORK_TODATE = h_new_actual,:n                           ETC =+
1 h_etc,:n                           MILESTONE_PERCENT = 10000:n              +
1             WHERE TSK_ASSIGNMENT_ID = h_id:
1FOUND:
1TRUE:
1100:
1380:
1           EXCEPTION:: FC_U_WP_ACTUAL(381) :: cplan.sql(14655) :: :
1PMO_FUNC:
1SC_BIT_30:
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_new_actual,:n           +
1                WORK_TODATE = h_new_actual,:n                           ETC =+
1 0,:n                           MILESTONE_PERCENT = 10000:n                  +
1         WHERE TSK_ASSIGNMENT_ID = h_id:
1406:
1           EXCEPTION:: FC_U_WP_ACTUAL(407) :: cplan.sql(14681) :: :
1TRUNC:
1/:
1*:
110000.00:
10.4:
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_etc,:n                  +
1         WORK_TODATE = h_new_actual:n                           WHERE TSK_ASS+
1IGNMENT_ID = h_id:
1433:
1           EXCEPTION:: FC_U_WP_ACTUAL(434) :: cplan.sql(14708) :: :
1460:
1           EXCEPTION:: FC_U_WP_ACTUAL(461) :: cplan.sql(14735) :: :
1UPDATE TASK_ASSIGNMENTS:n                     SET CONSIDER = 7,:n            +
1         ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_SCHED_BIT),:n +
1                    SCHED_WORK = h_new_actual,:n                     WORK_TOD+
1ATE = h_new_actual,:n                     ETC = 0,:n                     MILE+
1STONE_PERCENT = 10000:n                     WHERE TSK_ASSIGNMENT_ID = h_id:
1489:
1           EXCEPTION:: FC_U_WP_ACTUAL(490) :: cplan.sql(14764) :: :
1IS NOT NULL:
1MAX:
1WEEK_OF:
1TIMESHEET_APPROVAL_STATUS:
1SELECT MAX(WEEK_OF):n                     INTO h_week_of:n                   +
1  FROM TIMESHEET_APPROVAL_STATUS:n                     WHERE ELEMENT_ID = h_p+
1roject_id:n                     AND RESOURCE_ID = h_res_id:
1509:
1           EXCEPTION:: FC_U_WP_ACTUAL(510) :: cplan.sql(14784) :: :
1SELECT TO_DATE(SubStr(h_week_of, 1, 10)) + 7      INTO h_week_of FROM DUAL:
1524:
1           EXCEPTION:: FC_U_WP_ACTUAL(525) :: cplan.sql(14799) :: :
1STRNCMP:
110:
1DB2TIMESTAMP:
1TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)):n                        INTO h_start_date:n      +
1                  FROM DUAL:
1545:
1           EXCEPTION:: FC_U_WP_ACTUAL(546) :: cplan.sql(14820) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                        INTO h_start_dat+
1e:n                        FROM DUAL:
1560:
1           EXCEPTION:: FC_U_WP_ACTUAL(561) :: cplan.sql(14835) :: :
1FC_DEL_NOACTUAL:
12:
1FC_RESCHEDULE:
1586:
1                EXIT:: FC_U_WP_ACTUAL(587) :: cplan.sql(14861) :: :
1FC_U_ASSIGN_PERCENT:
1611:
1                EXIT:: FC_U_WP_ACTUAL(612) :: cplan.sql(14886) :: :
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS:n            SET MILESTONE_PERCENT = h_new_work_perce+
1nt,:n            ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_PERCEN+
1T_COMPLETE_BIT):n            WHERE TSK_ASSIGNMENT_ID = h_id:
1663:
1           EXCEPTION:: FC_U_WP_ACTUAL(664) :: cplan.sql(14938) :: :
1UPDATE TMT_WBS:n            SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO+
1_CNST.SC_PERCENT_COMPLETE_BIT):n            WHERE PROJECT_ID = h_project_id:n+
1            AND ELEMENT_ID = h_task_id:
1688:
1           EXCEPTION:: FC_U_WP_ACTUAL(689) :: cplan.sql(14963) :: :
1103079040:
1701:
1                EXIT:: FC_U_WP_ACTUAL(702) :: cplan.sql(14976) :: :
1SELECT UNITS_MSP:n               INTO h_temp_var:n               FROM TASK_AS+
1SIGNMENTS:n               WHERE TSK_ASSIGNMENT_ID = h_prj_assign_id:
1721:
1           EXCEPTION:: FC_U_WP_ACTUAL(722) :: cplan.sql(14996) :: :
1SC_SQL_SUCCESS:
1731:
1                EXIT:: FC_U_WP_ACTUAL(732) :: cplan.sql(15006) :: :
1TASK_ASSIGNMENT_ERROR:
1FC_U_TDY_LAST_ACTUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n               INTO h_start_date:n      +
1         FROM DUAL:
1825:
1           EXCEPTION:: FC_U_WP_ACTUAL(826) :: cplan.sql(15100) :: :
1844:
1                EXIT:: FC_U_WP_ACTUAL(845) :: cplan.sql(15119) :: :
1CONTOUR_TYPE:
1SC_PLANNED_BIT:
1UPDATE TASK_ASSIGNMENTS:n               SET CONSIDER = 7,:n               UNI+
1TS_MSP = h_percent_units,:n               C_EFFORT = 0,:n               C_UNI+
1T = 0,:n               C_CONTOUR = 0,:n               CONTOUR_TYPE = 0,:n    +
1           ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,(PMO_CNST.SC_SCHED_BIT+P+
1MO_CNST.SC_PLANNED_BIT)):n               WHERE TSK_ASSIGNMENT_ID = h_id:
1868:
1           EXCEPTION:: FC_U_WP_ACTUAL(869) :: cplan.sql(15143) :: :
1FC_ROLLUP:
1886:
1                EXIT:: FC_U_WP_ACTUAL(887) :: cplan.sql(15161) :: :
0

0
0
121e
2
0 a0 8d 90 :3 a0 b0 3f 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 90 :3 a0 b0 3f 90
:3 a0 b0 3f b4 :2 a0 2c 6a a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
:2 a0 6b 81 b0 a3 a0 51 a5
1c :2 a0 6b 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:4d a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :f a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c a0 51 d :5 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 6e
a5 b 7e 51 b4 2e :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c b7 19 3c :1b a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b :2 a0 6b a0 a5
b 65 a0 b7 :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
a0 51 d :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 a0
b7 :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e a0 51 d
b7 :2 19 3c :2 a0 d :8 a0 51 a5
b a5 b d b7 19 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
:2 a0 6b a0 a5 b 65 b7 :2 19
3c b7 :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c a0 51 d
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 6e a5 b 7e 51 b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c b7 19 3c :c a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c :9 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
51 a5 b d :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:2 a0 d :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e a0 7e
51 b4 2e d :c a0 a5 b d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e :2 a0 6b :2 a0 a5
b 7e 51 b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d a0 51 d :2 a0 51 a5 b
7e :2 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e 5a b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e 5a 7e :2 a0 51 a5 b
b4 2e d :11 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 6b :2 a0 51
a5 b :2 a0 6b a5 b d b7
:10 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :2 a0 51 a5
b 7e :2 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e 5a b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d :4 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e 5a
7e 51 b4 2e 5a 7e 51 b4
2e a5 b d :e a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d a0 51 d :10 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :2 19 3c b7 :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d a0 51 d :10 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
a0 7e b4 2e 5a a0 4d d
:8 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 7e b4 2e 5a
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d b7
19 3c a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :3 a0 6b :2 a0 51
a5 b :2 a0 6b a5 b 5a d
:a a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 :a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 19 3c a0 7e
b4 2e 5a :4 a0 51 a5 b d
b7 :2 a0 :2 51 a5 b 7e 6e b4
2e :4 a0 51 a5 b d b7 :4 a0
51 a5 b d b7 :2 19 3c b7
:2 19 3c a0 51 d :8 a0 51 :2 a0
51 a5 b a5 b d :2 a0 51
a5 b 7e 51 b4 2e :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 51 a5 b 65
b7 19 3c :2 a0 d b7 19 3c
b7 :4 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e 5a 7e 51 b4
2e 5a 7e 51 b4 2e a5 b
d b7 :2 19 3c :1b a0 51 a5 b
a5 b d :2 a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 51 a5 b 65 a0 b7 :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :b a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 b7 19
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a 52 10 :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 19 3c :3 a0
51 a5 b d b7 :2 19 3c a0
7e b4 2e 5a :5 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e 5a a 10 :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
19 3c b7 19 3c a0 7e 51
b4 2e d :c a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e 5a
a0 7e b4 2e :2 5a a 10 :9 a0
51 a5 b d b7 19 3c a0
7e b4 2e 5a :4 a0 51 a5 b
d b7 :2 a0 :2 51 a5 b 7e 6e
b4 2e :4 a0 51 a5 b d b7
:4 a0 51 a5 b d b7 :2 19 3c
b7 :2 19 3c a0 7e b4 2e 5a
:a a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e d b7
19 3c a0 51 d a0 51 d
:8 a0 51 :2 a0 51 a5 b a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 :12 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :2 19
3c b7 :2 19 3c :2 a0 6b :2 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 a4 b1
11 68 4f 1d 17 b5 
121e
2
0 3 7 2b 1f 23 27 1e
32 3f 3b 1b 47 50 4c 3a
58 65 61 37 6d 7e 72 76
7a 60 85 9a 8e 92 96 5d
a1 8d a6 aa ae b2 cf ba
be c6 ca 8a eb d6 da e2
e6 b9 10b f6 fa 102 106 b6
127 112 116 119 11a 122 f5 144
132 f2 136 137 13f 131 161 14f
12e 153 154 15c 14e 17e 16c 14b
170 171 179 16b 19b 189 168 18d
18e 196 188 1b7 1a6 1aa 1b2 185
1cf 1be 1c2 1ca 1a5 1eb 1da 1de
1e6 1a2 203 1f2 1f6 1fe 1d9 21f
20e 212 21a 1d6 237 226 22a 232
20d 254 242 20a 246 247 24f 241
271 25f 23e 263 264 26c 25e 28e
27c 25b 280 281 289 27b 2aa 299
29d 278 2a5 298 2c6 2b5 2b9 295
2c1 2b4 2e2 2d1 2d5 2b1 2dd 2d0
2fe 2ed 2f1 2cd 2f9 2ec 31a 309
30d 2e9 315 308 336 325 329 305
331 324 352 341 345 321 34d 340
36e 35d 361 33d 369 35c 38a 379
37d 359 385 378 3a6 395 399 375
3a1 394 3c2 3b1 3b5 391 3bd 3b0
3de 3cd 3d1 3ad 3d9 3cc 3fa 3e9
3ed 3c9 3f5 3e8 416 405 409 3e5
411 404 432 421 425 401 42d 420
44e 43d 441 41d 449 43c 46a 459
45d 439 465 458 486 475 479 455
481 474 4a2 491 495 471 49d 490
4be 4ad 4b1 48d 4b9 4ac 4da 4c9
4cd 4a9 4d5 4c8 4f6 4e5 4e9 4c5
4f1 4e4 512 501 505 4e1 50d 500
52e 51d 521 4fd 529 51c 54a 539
53d 519 545 538 566 555 559 535
561 554 58e 571 551 575 576 57e
582 586 589 570 5b6 599 56d 59d
59e 5a6 5aa 5ae 5b1 598 5d3 5c1
595 5c5 5c6 5ce 5c0 5ef 5de 5e2
5bd 5ea 5dd 60b 5fa 5fe 5da 606
5f9 627 616 61a 5f6 622 615 643
632 636 612 63e 631 65f 64e 652
62e 65a 64d 67b 66a 66e 64a 676
669 697 686 68a 666 692 685 6b3
6a2 6a6 682 6ae 6a1 6cf 6be 6c2
69e 6ca 6bd 6eb 6da 6de 6ba 6e6
6d9 707 6f6 6fa 6d6 702 6f5 723
712 716 6f2 71e 711 73f 72e 732
70e 73a 72d 75b 74a 74e 72a 756
749 762 766 746 76a 76e 772 775
77a 77b 1 77d 782 786 78a 78d
792 796 79a 79d 7a2 7a3 7a5 7aa
7ad 7b1 7b2 7b7 7bc 7bf 7c4 7c5
7ca 7cd 7d1 7d2 7d7 7da 7df 7e0
7e5 7e8 7ed 7ee 7f3 7f6 7fa 7fe
802 803 805 80a 80b 80d 80e 813
816 81b 81c 821 824 828 82c 830
831 833 838 839 83b 83c 841 844
849 84a 84f 852 856 85a 85e 85f
861 866 867 869 86a 86f 872 877
878 87d 880 885 886 88b 88e 892
893 898 89b 8a0 8a1 8a6 8a9 8ae
8af 8b4 8b7 8bc 8bd 8c2 8c5 8c9
8ca 8cf 8d2 8d7 8d8 8dd 8e0 8e5
8e6 8eb 8ec 8f1 8f3 8f7 8fa 8fe
902 905 909 90d 910 913 918 91b
91e 921 922 927 928 1 92a 92f
933 937 93a 93f 944 947 94b 94c
951 952 957 959 95d 960 964 968
96c 970 974 978 97c 980 984 988
98c 990 994 998 99c 9a0 9a4 9a8
9ac 9b0 9b4 9b8 9bc 9c0 9c4 9c8
9cc 9d0 9d4 9d8 9dc 9e0 9e4 9e8
9ec 9f0 9f4 9f8 9fc a00 a04 a08
a0c a10 a14 a18 a1c a20 a24 a28
a2c a30 a34 a38 a3c a40 a44 a48
a4c a50 a54 a58 a5c a60 a64 a68
a6c a70 a74 a78 a7c a80 a84 a88
a8c a90 a94 a98 a9c aa0 aac ab0
ab4 ab7 abb abf ac1 1 ac5 ac9
acd ad0 ad4 ad8 adc ae0 ae3 ae7
aeb aee af1 af6 af9 afc aff b00
b05 b06 1 b08 b0d b11 b15 b18
b1d b22 b25 b29 b2a b2f b32 b37
b38 b3d b40 b45 b46 b4b b4e b52
b53 b58 b5b b60 b61 b66 b69 b6d
b71 b74 b77 b78 b7a b7b b80 b81
b86 b88 b8c b8f b91 b95 b97 ba3
ba5 ba7 ba8 bad bb1 bb3 bbf bc1
bc5 bc9 bcc bd0 bd3 bd7 bda bdb
be0 be3 be7 beb bef bf3 bf7 bfb
bff c03 c07 c0b c0f c13 c17 c1b
c1f c2b c2f c33 c36 c3a c3e c40
1 c44 c48 c4c c4f c53 c57 c5b
c5f c62 c66 c6a c6d c70 c75 c78
c7b c7e c7f c84 c85 1 c87 c8c
c90 c94 c97 c9c ca1 ca4 ca8 ca9
cae cb1 cb6 cb7 cbc cbf cc4 cc5
cca ccd cd1 cd2 cd7 cda cdf ce0
ce5 ce8 cec cf0 cf3 cf6 cf7 cf9
cfa cff d00 d05 d07 d0b d0e d10
d14 d16 d22 d24 d26 d27 d2c d30
d32 d3e d40 d44 d48 d4b d4f d52
d56 d59 d5a d5f d62 d66 d6a d6e
d72 d76 d79 d7d d81 d84 d87 d8c
d8f d92 d95 d96 d9b d9c 1 d9e
da3 da7 dab dae db3 db8 dbb dbf
dc0 dc5 dc6 dcb dcd dd1 dd4 dd8
ddc de0 de3 de7 de9 ded df0 df4
df7 dfb dff e03 e07 e0b e0f e1b
e1f e23 e26 e2a e2e e30 1 e34
e38 e3c e3f e43 e47 e4b e4f e52
e56 e5a e5d e60 e65 e68 e6b e6e
e6f e74 e75 1 e77 e7c e80 e84
e87 e8c e91 e94 e98 e99 e9e ea1
ea6 ea7 eac eaf eb4 eb5 eba ebd
ec1 ec2 ec7 eca ecf ed0 ed5 ed8
edc ee0 ee3 ee6 ee7 ee9 eea eef
ef0 ef5 ef7 efb efe f00 f04 f06
f12 f14 f16 f17 f1c f20 f22 f2e
f30 f34 f38 f3b f3c f3e f41 f44
f45 f4a f4e f52 f56 f5a f5e f6a
f6e f72 f75 f79 f7d f7f 1 f83
f87 f8b f8e f92 f96 f9a f9e fa1
fa5 fa9 fac faf fb4 fb7 fba fbd
fbe fc3 fc4 1 fc6 fcb fcf fd3
fd6 fdb fe0 fe3 fe7 fe8 fed ff0
ff5 ff6 ffb ffe 1003 1004 1009 100c
1010 1011 1016 1019 101e 101f 1024 1027
102b 102f 1032 1035 1036 1038 1039 103e
103f 1044 1046 104a 104d 104f 1053 1055
1061 1063 1065 1066 106b 106f 1071 107d
107f 1083 1087 108a 108e 1093 1094 1096
1099 109c 109d 10a2 10a6 10aa 10ae 10b2
10b6 10b9 10bd 10c1 10c4 10c7 10cc 10cf
10d2 10d5 10d6 10db 10dc 1 10de 10e3
10e7 10eb 10ee 10f3 10f8 10fb 10ff 1100
1105 1106 110b 110d 1111 1114 1118 111c
1120 1123 1127 1129 112d 1130 1132 1136
1139 113d 1141 1145 1149 114d 1151 1155
1159 115d 1161 1165 1169 116d 1171 1175
1179 117d 1181 1185 1189 118d 1191 1195
1199 119d 11a1 11a5 11b1 11b5 11b9 11bc
11c0 11c4 11c6 1 11ca 11ce 11d2 11d5
11d9 11dd 11e1 11e5 11e8 11ec 11f0 11f3
11f6 11fb 11fe 1201 1204 1205 120a 120b
1 120d 1212 1216 121a 121d 1222 1227
122a 122e 122f 1234 1237 123c 123d 1242
1245 124a 124b 1250 1253 1257 1258 125d
1260 1265 1266 126b 126e 1272 1276 1279
127c 127d 127f 1280 1285 1286 128b 128d
1291 1294 1296 129a 129c 12a8 12aa 12ac
12ad 12b2 12b6 12b8 12c4 12c6 12ca 12ce
12d1 12d2 12d4 12d7 12da 12db 12e0 12e4
12e8 12ec 12f0 12f4 12f7 12fb 12ff 1302
1305 130a 130d 1310 1313 1314 1319 131a
1 131c 1321 1325 1329 132c 1331 1336
1339 133d 133e 1343 1344 1349 134b 134f
1352 1356 135a 135e 1361 1365 1367 136b
136e 1372 1376 1379 137a 137c 137f 1382
1383 1388 138c 1390 1393 1397 139b 139e
13a1 13a6 13a9 13ac 13af 13b0 13b5 13b6
1 13b8 13bd 13c1 13c5 13c8 13cd 13d2
13d5 13d9 13da 13df 13e2 13e7 13e8 13ed
13f0 13f5 13f6 13fb 13fe 1402 1406 140a
140e 1411 1412 1414 1419 141a 141c 141d
1422 1423 1428 142a 142e 1431 1435 1439
143c 1440 1444 1447 144a 144f 1452 1455
1458 1459 145e 145f 1 1461 1466 146a
146e 1471 1476 147b 147e 1482 1483 1488
1489 148e 1490 1494 1497 149b 149f 14a3
14a6 14aa 14ae 14b1 14b5 14b6 14b8 14bc
14c0 14c2 14c6 14ca 14cd 14ce 14d0 14d4
14d7 14db 14de 14df 14e1 14e2 14e7 14eb
14ee 14f2 14f6 14fa 14fd 14fe 1500 1504
1507 150b 150e 150f 1511 1512 1517 151b
151f 1523 1527 152b 152e 1532 1536 1539
153c 1541 1544 1547 154a 154b 1550 1551
1 1553 1558 155c 1560 1563 1568 156d
1570 1574 1575 157a 157b 1580 1582 1586
1589 158d 1591 1595 1598 159c 15a0 15a2
15a6 15aa 15ad 15ae 15b0 15b4 15b7 15bb
15be 15bf 15c1 15c2 15c7 15cb 15ce 15d2
15d4 15d8 15dc 15df 15e3 15e7 15eb 15ef
15f3 15f7 15fb 15ff 1603 1607 160b 160e
160f 1611 1612 1614 1618 161a 161e 1622
1626 1629 162d 1631 1634 1637 163c 163f
1642 1645 1646 164b 164c 1 164e 1653
1657 165b 165e 1663 1668 166b 166f 1670
1675 1678 167d 167e 1683 1686 168b 168c
1691 1694 1698 169c 16a0 16a4 16a7 16a8
16aa 16af 16b0 16b2 16b3 16b8 16b9 16be
16c0 16c4 16c7 16cb 16cf 16d2 16d6 16da
16dd 16e0 16e5 16e8 16eb 16ee 16ef 16f4
16f5 1 16f7 16fc 1700 1704 1707 170c
1711 1714 1718 1719 171e 171f 1724 1726
172a 172d 1731 1735 1739 173c 1740 1744
1747 174b 174c 174e 1752 1754 1758 175c
175f 1761 1765 1769 176c 176d 176f 1772
1775 1776 177b 177f 1783 1787 178b 178f
1792 1796 179a 179d 17a0 17a5 17a8 17ab
17ae 17af 17b4 17b5 1 17b7 17bc 17c0
17c4 17c7 17cc 17d1 17d4 17d8 17d9 17de
17df 17e4 17e6 17ea 17ed 17f1 17f5 17f9
17fc 1800 1802 1806 1809 180d 1810 1814
1818 181c 1820 1824 1828 1834 1838 183c
183f 1843 1847 1849 1 184d 1851 1855
1858 185c 1860 1864 1868 186b 186f 1873
1876 1879 187e 1881 1884 1887 1888 188d
188e 1 1890 1895 1899 189d 18a0 18a5
18aa 18ad 18b1 18b2 18b7 18ba 18bf 18c0
18c5 18c8 18cd 18ce 18d3 18d6 18da 18db
18e0 18e3 18e8 18e9 18ee 18f1 18f5 18f9
18fc 18ff 1900 1902 1903 1908 1909 190e
1910 1914 1917 1919 191d 191f 192b 192d
192f 1930 1935 1939 193b 1947 1949 194d
1951 1954 1955 1957 195a 195d 195e 1963
1967 196b 196f 1973 1977 1983 1987 198b
198e 1992 1996 1998 1 199c 19a0 19a4
19a7 19ab 19af 19b3 19b7 19ba 19be 19c2
19c5 19c8 19cd 19d0 19d3 19d6 19d7 19dc
19dd 1 19df 19e4 19e8 19ec 19ef 19f4
19f9 19fc 1a00 1a01 1a06 1a09 1a0e 1a0f
1a14 1a17 1a1c 1a1d 1a22 1a25 1a29 1a2a
1a2f 1a32 1a37 1a38 1a3d 1a40 1a44 1a48
1a4b 1a4e 1a4f 1a51 1a52 1a57 1a58 1a5d
1a5f 1a63 1a66 1a68 1a6c 1a6e 1a7a 1a7c
1a7e 1a7f 1a84 1a88 1a8a 1a96 1a98 1a9c
1aa0 1aa3 1aa7 1aac 1aad 1aaf 1ab2 1ab5
1ab6 1abb 1abf 1ac3 1ac7 1acb 1acf 1ad2
1ad6 1ada 1add 1ae0 1ae5 1ae8 1aeb 1aee
1aef 1af4 1af5 1 1af7 1afc 1b00 1b04
1b07 1b0c 1b11 1b14 1b18 1b19 1b1e 1b1f
1b24 1b26 1b2a 1b2d 1b31 1b35 1b39 1b3c
1b40 1b42 1b46 1b49 1b4b 1b4f 1b52 1b56
1b5a 1b5e 1b62 1b66 1b6a 1b6e 1b72 1b76
1b7a 1b7e 1b82 1b8e 1b92 1b96 1b99 1b9d
1ba1 1ba3 1 1ba7 1bab 1baf 1bb2 1bb6
1bba 1bbe 1bc2 1bc5 1bc9 1bcd 1bd0 1bd3
1bd8 1bdb 1bde 1be1 1be2 1be7 1be8 1
1bea 1bef 1bf3 1bf7 1bfa 1bff 1c04 1c07
1c0b 1c0c 1c11 1c14 1c19 1c1a 1c1f 1c22
1c27 1c28 1c2d 1c30 1c34 1c35 1c3a 1c3d
1c42 1c43 1c48 1c4b 1c4f 1c53 1c56 1c59
1c5a 1c5c 1c5d 1c62 1c63 1c68 1c6a 1c6e
1c71 1c73 1c77 1c79 1c85 1c87 1c89 1c8a
1c8f 1c93 1c95 1ca1 1ca3 1ca7 1cab 1cae
1caf 1cb1 1cb4 1cb7 1cb8 1cbd 1cc1 1cc5
1cc9 1ccd 1cd1 1cd4 1cd8 1cdc 1cdf 1ce2
1ce7 1cea 1ced 1cf0 1cf1 1cf6 1cf7 1
1cf9 1cfe 1d02 1d06 1d09 1d0e 1d13 1d16
1d1a 1d1b 1d20 1d21 1d26 1d28 1d2c 1d2f
1d33 1d37 1d3b 1d3e 1d42 1d44 1d48 1d4b
1d4f 1d53 1d57 1d5b 1d5f 1d63 1d67 1d6b
1d6f 1d7b 1d7f 1d83 1d86 1d8a 1d8e 1d90
1 1d94 1d98 1d9c 1d9f 1da3 1da7 1dab
1daf 1db2 1db6 1dba 1dbd 1dc0 1dc5 1dc8
1dcb 1dce 1dcf 1dd4 1dd5 1 1dd7 1ddc
1de0 1de4 1de7 1dec 1df1 1df4 1df8 1df9
1dfe 1e01 1e06 1e07 1e0c 1e0f 1e14 1e15
1e1a 1e1d 1e21 1e22 1e27 1e2a 1e2f 1e30
1e35 1e38 1e3c 1e40 1e43 1e46 1e47 1e49
1e4a 1e4f 1e50 1e55 1e57 1e5b 1e5e 1e60
1e64 1e66 1e72 1e74 1e76 1e77 1e7c 1e80
1e82 1e8e 1e90 1e94 1e98 1e9c 1e9f 1ea0
1ea2 1ea6 1eaa 1eae 1eb1 1eb2 1eb4 1eb8
1ebb 1ebf 1ec2 1ec3 1ec5 1ec6 1ecb 1ecf
1ed3 1ed7 1edb 1edf 1ee2 1ee3 1ee5 1ee9
1eec 1ef0 1ef3 1ef4 1ef6 1ef7 1efc 1f00
1f03 1f06 1f07 1f0c 1f10 1f14 1f18 1f1c
1f20 1f24 1f28 1f2c 1f30 1f34 1f38 1f3c
1f40 1f41 1f43 1f47 1f4b 1f4f 1f52 1f53
1f55 1f58 1f5b 1f5c 1f61 1f65 1f69 1f6c
1f6d 1f6f 1f73 1f76 1f7a 1f7d 1f7e 1f80
1f81 1f86 1f8a 1f8e 1f91 1f95 1f99 1f9a
1f9c 1f9f 1fa2 1fa3 1fa8 1fac 1fb0 1fb4
1fb7 1fb8 1fba 1fbd 1fc1 1fc5 1fc8 1fc9
1fcb 1fcc 1fd1 1fd5 1fd9 1fdc 1fe0 1fe4
1fe8 1feb 1fec 1fee 1ff1 1ff5 1ff9 1ffc
1ffd 1fff 2002 2006 200a 200d 200e 2010
2011 2016 2019 201a 201f 2023 2027 202b
202e 202f 2031 2034 2038 203c 203f 2040
2042 2043 2048 204b 204e 2052 2056 2059
205a 205c 205d 2062 2066 206a 206e 2072
2076 207a 207e 2082 2086 208a 208e 2092
2096 209a 209e 20a2 20a6 20aa 20b6 20ba
20bf 20c3 20c6 20c7 20cc 20d0 20d4 20d7
20da 20de 20e0 20e4 20e8 20eb 20ee 20f2
20f4 20f8 20fc 20ff 2101 1 2105 2109
210d 2110 2114 2118 211c 2120 2123 2127
212b 212e 2131 2136 2139 213c 213f 2140
2145 2146 1 2148 214d 2151 2155 2158
215d 2162 2165 2169 216a 216f 2172 2177
2178 217d 2180 2185 2186 218b 218e 2192
2193 2198 219b 21a0 21a1 21a6 21a9 21ad
21b1 21b4 21b7 21b8 21ba 21bb 21c0 21c1
21c6 21c8 21cc 21cf 21d1 21d5 21d7 21e3
21e5 21e7 21e8 21ed 21f1 21f3 21ff 2201
2205 2209 220d 2210 2214 2218 221b 221c
221e 2222 2226 2229 222a 222c 2230 2232
2236 223a 223e 2242 2246 224a 224e 2252
2256 225a 225e 2262 2266 226a 226e 2272
227e 2282 2287 228b 228e 228f 2294 2298
229c 229f 22a2 22a6 22a8 22ac 22b0 22b3
22b6 22ba 22bc 22c0 22c4 22c7 22c9 1
22cd 22d1 22d5 22d8 22dc 22e0 22e4 22e8
22eb 22ef 22f3 22f6 22f9 22fe 2301 2304
2307 2308 230d 230e 1 2310 2315 2319
231d 2320 2325 232a 232d 2331 2332 2337
233a 233f 2340 2345 2348 234d 234e 2353
2356 235a 235b 2360 2363 2368 2369 236e
2371 2375 2379 237c 237f 2380 2382 2383
2388 2389 238e 2390 2394 2397 2399 239d
239f 23ab 23ad 23af 23b0 23b5 23b9 23bb
23c7 23c9 23cb 23cf 23d3 23d6 23d8 23dc
23e0 23e3 23e4 23e6 23e9 23ed 23f1 23f4
23f5 23f7 23fa 23fe 2402 2405 2406 2408
2409 240e 2411 2412 2417 241b 241f 2423
2426 2427 2429 242c 2430 2434 2437 2438
243a 243b 2440 2444 2448 244c 2450 2454
2457 2458 245a 245d 2461 2465 2468 2469
246b 246c 2471 2474 2477 247a 247b 2480
2483 2486 2489 248a 248f 2490 2492 2496
249a 249e 24a2 24a6 24aa 24ae 24b2 24b6
24ba 24be 24c2 24c6 24ca 24ce 24da 24de
24e3 24e7 24ea 24eb 24f0 24f4 24f8 24fb
24fe 2502 2504 2508 250c 250f 2512 2516
2518 251c 2520 2523 2525 1 2529 252d
2531 2534 2538 253c 2540 2544 2547 254b
254f 2552 2555 255a 255d 2560 2563 2564
2569 256a 1 256c 2571 2575 2579 257c
2581 2586 2589 258d 258e 2593 2596 259b
259c 25a1 25a4 25a9 25aa 25af 25b2 25b6
25b7 25bc 25bf 25c4 25c5 25ca 25cd 25d1
25d5 25d8 25db 25dc 25de 25df 25e4 25e5
25ea 25ec 25f0 25f3 25f5 25f9 25fb 2607
2609 260b 260c 2611 2615 2617 2623 2625
2627 262b 262f 2633 2636 2637 2639 263c
2640 2644 2647 2648 264a 264b 2650 2654
2658 265b 265f 2663 2667 266b 266f 2673
2677 267b 267f 2683 2687 268b 268f 2693
2697 269b 269f 26ab 26af 26b4 26b8 26bb
26bc 26c1 26c5 26c9 26cc 26cf 26d3 26d5
26d9 26dd 26e0 26e3 26e7 26e9 26ed 26f1
26f4 26f6 1 26fa 26fe 2702 2705 2709
270d 2711 2715 2718 271c 2720 2723 2726
272b 272e 2731 2734 2735 273a 273b 1
273d 2742 2746 274a 274d 2752 2757 275a
275e 275f 2764 2767 276c 276d 2772 2775
277a 277b 2780 2783 2787 2788 278d 2790
2795 2796 279b 279e 27a2 27a6 27a9 27ac
27ad 27af 27b0 27b5 27b6 27bb 27bd 27c1
27c4 27c6 27ca 27cc 27d8 27da 27dc 27dd
27e2 27e6 27e8 27f4 27f6 27f8 27fc 2800
2803 2805 2809 280d 2810 2812 2816 281a
281e 2821 2822 2824 2827 282b 282f 2832
2833 2835 2836 283b 283f 2843 2846 284a
284e 2852 2856 285a 285e 2862 2866 286a
286e 2872 2876 287a 287e 2882 2886 288a
2896 289a 289f 28a3 28a6 28a7 28ac 28b0
28b4 28b7 28ba 28be 28c0 28c4 28c8 28cb
28ce 28d2 28d4 28d8 28dc 28df 28e1 1
28e5 28e9 28ed 28f0 28f4 28f8 28fc 2900
2903 2907 290b 290e 2911 2916 2919 291c
291f 2920 2925 2926 1 2928 292d 2931
2935 2938 293d 2942 2945 2949 294a 294f
2952 2957 2958 295d 2960 2965 2966 296b
296e 2972 2973 2978 297b 2980 2981 2986
2989 298d 2991 2994 2997 2998 299a 299b
29a0 29a1 29a6 29a8 29ac 29af 29b1 29b5
29b7 29c3 29c5 29c7 29c8 29cd 29d1 29d3
29df 29e1 29e3 29e7 29eb 29ee 29f2 29f5
29f6 29fb 29fe 2a02 2a03 2a07 2a0b 2a0f
2a13 2a17 2a1b 2a1f 2a23 2a27 2a33 2a37
2a3b 2a3e 2a42 2a46 2a48 1 2a4c 2a50
2a54 2a57 2a5b 2a5f 2a63 2a67 2a6a 2a6e
2a72 2a75 2a78 2a7d 2a80 2a83 2a86 2a87
2a8c 2a8d 1 2a8f 2a94 2a98 2a9c 2a9f
2aa4 2aa9 2aac 2ab0 2ab1 2ab6 2ab9 2abe
2abf 2ac4 2ac7 2acc 2acd 2ad2 2ad5 2ad9
2ada 2adf 2ae2 2ae7 2ae8 2aed 2af0 2af4
2af8 2afb 2afe 2aff 2b01 2b02 2b07 2b08
2b0d 2b0f 2b13 2b16 2b18 2b1c 2b1e 2b2a
2b2c 2b2e 2b2f 2b34 2b38 2b3a 2b46 2b48
2b4c 2b4f 2b50 2b55 2b58 2b5c 2b60 2b64
2b68 2b6c 2b78 2b7c 2b80 2b83 2b87 2b8b
2b8d 1 2b91 2b95 2b99 2b9c 2ba0 2ba4
2ba8 2bac 2baf 2bb3 2bb7 2bba 2bbd 2bc2
2bc5 2bc8 2bcb 2bcc 2bd1 2bd2 1 2bd4
2bd9 2bdd 2be1 2be4 2be9 2bee 2bf1 2bf5
2bf6 2bfb 2bfe 2c03 2c04 2c09 2c0c 2c11
2c12 2c17 2c1a 2c1e 2c1f 2c24 2c27 2c2c
2c2d 2c32 2c35 2c39 2c3d 2c40 2c43 2c44
2c46 2c47 2c4c 2c4d 2c52 2c54 2c58 2c5b
2c5d 2c61 2c63 2c6f 2c71 2c73 2c74 2c79
2c7d 2c7f 2c8b 2c8d 2c91 2c95 2c98 2c9c
2ca0 2ca3 2ca4 2ca6 2ca9 2cac 2cad 2cb2
2cb6 2cba 2cbe 2cc0 2cc4 2cc7 2ccb 2ccd
2cd1 2cd5 2cd8 2cd9 2cdb 2cde 2ce1 2ce2
2ce7 2ceb 2cef 2cf3 2cf6 2cfa 2cfe 2d01
2d02 2d04 2d08 2d0c 2d0f 2d10 2d12 2d15
2d19 2d1d 2d21 2d25 2d29 2d2d 2d31 2d35
2d39 2d3d 2d41 2d4d 2d51 2d55 2d58 2d5c
2d60 2d62 1 2d66 2d6a 2d6e 2d71 2d75
2d79 2d7d 2d81 2d84 2d88 2d8c 2d8f 2d92
2d97 2d9a 2d9d 2da0 2da1 2da6 2da7 1
2da9 2dae 2db2 2db6 2db9 2dbe 2dc3 2dc6
2dca 2dcb 2dd0 2dd3 2dd8 2dd9 2dde 2de1
2de6 2de7 2dec 2def 2df3 2df4 2df9 2dfc
2e01 2e02 2e07 2e0a 2e0e 2e12 2e15 2e18
2e19 2e1b 2e1c 2e21 2e22 2e27 2e29 2e2d
2e30 2e32 2e36 2e38 2e44 2e46 2e48 2e49
2e4e 2e52 2e54 2e60 2e62 2e64 2e68 2e6c
2e70 2e74 2e78 2e7c 2e80 2e84 2e88 2e8c
2e90 2e9c 2ea0 2ea4 2ea7 2eab 2eaf 2eb1
1 2eb5 2eb9 2ebd 2ec0 2ec4 2ec8 2ecc
2ed0 2ed3 2ed7 2edb 2ede 2ee1 2ee6 2ee9
2eec 2eef 2ef0 2ef5 2ef6 1 2ef8 2efd
2f01 2f05 2f08 2f0d 2f12 2f15 2f19 2f1a
2f1f 2f22 2f27 2f28 2f2d 2f30 2f35 2f36
2f3b 2f3e 2f42 2f43 2f48 2f4b 2f50 2f51
2f56 2f59 2f5d 2f61 2f64 2f67 2f68 2f6a
2f6b 2f70 2f71 2f76 2f78 2f7c 2f7f 2f81
2f85 2f87 2f93 2f95 2f97 2f98 2f9d 2fa1
2fa3 2faf 2fb1 2fb3 2fb7 2fbb 2fbe 2fc0
2fc4 2fc7 2fcb 2fce 2fcf 2fd4 2fd7 2fdb
2fdf 2fe3 2fe7 2fea 2feb 2fed 2ff1 2ff3
2ff7 2ffb 2ffe 3001 3002 3004 3007 300c
300d 3012 3016 301a 301e 3022 3025 3026
3028 302c 302e 3032 3036 303a 303e 3041
3042 3044 3048 304a 304e 3052 3055 3057
305b 305f 3062 3066 3069 306d 3071 3075
3079 307d 3081 3085 3089 308d 3090 3094
3098 309b 309c 309e 309f 30a1 30a5 30a9
30ad 30b0 30b1 30b3 30b6 30b9 30ba 30bf
30c3 30c7 30cb 30cf 30d3 30d6 30da 30de
30e1 30e4 30e9 30ec 30ef 30f2 30f3 30f8
30f9 1 30fb 3100 3104 3108 310b 3110
3115 3118 311c 311d 3122 3123 3128 312a
312e 3131 3135 3139 313d 3140 3141 3143
3147 3149 314d 3150 3154 3158 315c 315e
3162 3165 3167 316b 316f 3173 3177 317a
317b 317d 3180 3184 3188 318b 318c 318e
318f 3194 3197 319a 319d 319e 31a3 31a6
31a9 31ac 31ad 31b2 31b3 31b5 31b9 31bb
31bf 31c3 31c6 31ca 31ce 31d2 31d6 31da
31de 31e2 31e6 31ea 31ee 31f2 31f6 31fa
31fe 3202 3206 320a 320e 3212 3216 321a
321e 3222 3226 322a 322e 3232 3235 3236
3238 3239 323b 323f 3243 3247 324b 324f
3253 3256 325a 325e 3261 3264 3269 326c
326f 3272 3273 3278 3279 1 327b 3280
3284 3288 328b 3290 3295 3298 329c 329d
32a2 32a3 32a8 32aa 32ae 32b1 32b5 32b9
32bd 32c0 32c1 32c3 32c7 32cb 32cd 32d1
32d5 32d8 32d9 32db 32df 32e2 32e6 32e9
32ea 32ec 32ed 32f2 32f6 32fa 32fe 3302
3306 330a 330e 3312 3316 331a 331e 332a
332e 3333 3337 333a 333b 3340 3344 3348
334b 334e 3352 3354 3358 335c 335f 3362
3366 3368 336c 3370 3373 3375 1 3379
337d 3381 3384 3388 338c 3390 3394 3397
339b 339f 33a2 33a5 33aa 33ad 33b0 33b3
33b4 33b9 33ba 1 33bc 33c1 33c5 33c9
33cc 33d1 33d6 33d9 33dd 33de 33e3 33e6
33eb 33ec 33f1 33f4 33f9 33fa 33ff 3402
3406 3407 340c 340f 3414 3415 341a 341d
3421 3425 3428 342b 342c 342e 342f 3434
3435 343a 343c 3440 3443 3445 3449 344b
3457 3459 345b 345c 3461 3465 3467 3473
3475 3479 347d 3481 3485 3489 348d 3491
3495 3499 349d 34a1 34ad 34b1 34b6 34ba
34bd 34be 34c3 34c7 34cb 34ce 34d1 34d5
34d7 34db 34df 34e2 34e5 34e9 34eb 34ef
34f3 34f6 34f8 1 34fc 3500 3504 3507
350b 350f 3513 3517 351a 351e 3522 3525
3528 352d 3530 3533 3536 3537 353c 353d
1 353f 3544 3548 354c 354f 3554 3559
355c 3560 3561 3566 3569 356e 356f 3574
3577 357c 357d 3582 3585 3589 358a 358f
3592 3597 3598 359d 35a0 35a4 35a8 35ab
35ae 35af 35b1 35b2 35b7 35b8 35bd 35bf
35c3 35c6 35c8 35cc 35ce 35da 35dc 35de
35df 35e4 35e8 35ea 35f6 35f8 35fc 35fe
3602 3606 360a 360d 360e 3610 3614 3617
361b 361e 361f 3621 3622 3627 362b 362f
3632 3633 3635 3638 363b 363c 3641 3645
3648 364c 364e 3652 3656 3659 365a 365c
365f 3662 3663 3668 366b 366f 3673 3676
3677 3679 367c 367f 3680 3685 1 3688
368d 3691 3695 3699 369d 36a1 36a4 36a8
36ac 36af 36b2 36b7 36ba 36bd 36c0 36c1
36c6 36c7 1 36c9 36ce 36d2 36d6 36d9
36de 36e3 36e6 36ea 36eb 36f0 36f1 36f6
36f8 36fc 36ff 3703 3707 370b 370e 3712
3714 3718 371b 371f 3723 3727 372a 372b
372d 3731 3733 3737 373b 373e 3742 3745
3746 374b 374e 3752 3756 375a 375e 3762
376e 3772 3776 3779 377d 3781 3783 1
3787 378b 378f 3792 3796 379a 379e 37a2
37a5 37a9 37ad 37b0 37b3 37b8 37bb 37be
37c1 37c2 37c7 37c8 1 37ca 37cf 37d3
37d7 37da 37df 37e4 37e7 37eb 37ec 37f1
37f4 37f9 37fa 37ff 3802 3807 3808 380d
3810 3814 3815 381a 381d 3822 3823 3828
382b 382f 3833 3836 3839 383a 383c 383d
3842 3843 3848 384a 384e 3851 3853 3857
3859 3865 3867 3869 386a 386f 3873 3875
3881 3883 3887 388b 388e 3892 3895 3899
389c 389d 38a2 38a5 38a9 38ad 38b0 38b1
38b3 38b7 38ba 38be 38c1 38c2 38c4 38c5
38ca 1 38cd 38d2 38d6 38da 38de 38e2
38e6 38e9 38ed 38f1 38f4 38f7 38fc 38ff
3902 3905 3906 390b 390c 1 390e 3913
3917 391b 391e 3923 3928 392b 392f 3930
3935 3936 393b 393d 3941 3944 3948 394c
3950 3953 3957 3959 395d 3960 3962 3966
3969 396d 3970 3973 3974 3979 397d 3981
3985 3989 398d 3991 3995 3999 399d 39a1
39a5 39a9 39ad 39ae 39b0 39b4 39b8 39bc
39bf 39c0 39c2 39c5 39c8 39c9 39ce 39d1
39d5 39d8 39d9 39de 39e1 1 39e4 39e9
39ed 39f1 39f5 39f9 39fd 3a01 3a05 3a09
3a0d 3a10 3a11 3a13 3a17 3a19 3a1d 3a20
3a24 3a27 3a28 3a2d 3a30 3a34 3a38 3a3c
3a40 3a43 3a44 3a46 3a4a 3a4c 3a50 3a54
3a57 3a5a 3a5b 3a5d 3a60 3a65 3a66 3a6b
3a6f 3a73 3a77 3a7b 3a7e 3a7f 3a81 3a85
3a87 3a8b 3a8f 3a93 3a97 3a9a 3a9b 3a9d
3aa1 3aa3 3aa7 3aab 3aae 3ab0 3ab4 3ab8
3abb 3abf 3ac2 3ac3 3ac8 3acb 3acf 3ad3
3ad7 3adb 3adf 3ae3 3ae7 3aeb 3aef 3af3
3aff 3b03 3b07 3b0a 3b0e 3b12 3b14 1
3b18 3b1c 3b20 3b23 3b27 3b2b 3b2f 3b33
3b36 3b3a 3b3e 3b41 3b44 3b49 3b4c 3b4f
3b52 3b53 3b58 3b59 1 3b5b 3b60 3b64
3b68 3b6b 3b70 3b75 3b78 3b7c 3b7d 3b82
3b85 3b8a 3b8b 3b90 3b93 3b98 3b99 3b9e
3ba1 3ba5 3ba6 3bab 3bae 3bb3 3bb4 3bb9
3bbc 3bc0 3bc4 3bc7 3bca 3bcb 3bcd 3bce
3bd3 3bd4 3bd9 3bdb 3bdf 3be2 3be4 3be8
3bea 3bf6 3bf8 3bfa 3bfb 3c00 3c04 3c06
3c12 3c14 3c18 3c1c 3c20 3c23 3c24 3c26
3c29 3c2d 3c31 3c34 3c35 3c37 3c38 3c3d
3c41 3c43 3c47 3c4a 3c4e 3c51 3c55 3c59
3c5c 3c60 3c64 3c68 3c6c 3c70 3c74 3c78
3c7c 3c80 3c83 3c87 3c8b 3c8e 3c8f 3c91
3c92 3c94 3c98 3c9c 3ca0 3ca3 3ca4 3ca6
3ca9 3cac 3cad 3cb2 3cb6 3cba 3cbe 3cc2
3cc6 3cc9 3ccd 3cd1 3cd4 3cd7 3cdc 3cdf
3ce2 3ce5 3ce6 3ceb 3cec 1 3cee 3cf3
3cf7 3cfb 3cfe 3d03 3d08 3d0b 3d0f 3d10
3d15 3d16 3d1b 3d1d 3d21 3d24 3d28 3d2c
3d30 3d33 3d37 3d39 3d3d 3d41 3d45 3d49
3d4d 3d51 3d55 3d59 3d5d 3d61 3d65 3d69
3d6d 3d71 3d75 3d79 3d7d 3d81 3d8d 3d91
3d96 3d9a 3d9d 3d9e 3da3 3da7 3dab 3dae
3db1 3db5 3db7 3dbb 3dbf 3dc2 3dc5 3dc9
3dcb 3dcf 3dd3 3dd6 3dd8 1 3ddc 3de0
3de4 3de7 3deb 3def 3df3 3df7 3dfa 3dfe
3e02 3e05 3e08 3e0d 3e10 3e13 3e16 3e17
3e1c 3e1d 1 3e1f 3e24 3e28 3e2c 3e2f
3e34 3e39 3e3c 3e40 3e41 3e46 3e49 3e4e
3e4f 3e54 3e57 3e5c 3e5d 3e62 3e65 3e69
3e6a 3e6f 3e72 3e77 3e78 3e7d 3e80 3e84
3e88 3e8b 3e8e 3e8f 3e91 3e92 3e97 3e98
3e9d 3e9f 3ea3 3ea6 3ea8 3eac 3eae 3eba
3ebc 3ebe 3ebf 3ec4 3ec8 3eca 3ed6 3ed8
3eda 3ede 3ee2 3ee5 3ee7 3eeb 3eef 3ef2
3ef4 3ef8 3efc 3eff 3f03 3f07 3f0a 3f0e
3f12 3f13 3f15 3f19 3f1d 3f21 3f24 3f28
3f2c 3f2f 3f32 3f37 3f3a 3f3d 3f40 3f41
3f46 3f47 1 3f49 3f4e 3f52 3f56 3f59
3f5e 3f63 3f66 3f6a 3f6b 3f70 3f73 3f78
3f79 3f7e 3f81 3f86 3f87 3f8c 3f8f 3f93
3f97 3f9a 3f9b 3fa0 3fa1 3fa6 3fa8 3fac
3faf 3fb3 3fb7 3fbb 3fbe 3fc2 3fc4 3fc8
3fca 3fd6 3fda 3fdc 3fdd 3fe6 
121e
2
0 1 a 6 15 19 20 :3 6
1c :3 6 12 :3 6 11 :3 6 14 18
1f :3 6 14 18 1f :2 6 1 3
a :2 1 4 :2 17 26 17 :2 4 :2 d
1c d :2 4 :2 c 1b c :2 4 9
12 11 :2 9 :2 4 14 1d 1c :2 14
:2 4 11 1a 19 :2 11 :2 4 e 17
16 :2 e :2 4 d 16 15 :2 d :2 4
:3 9 :2 4 :3 9 :2 4 :3 11 :2 4 :3 12 :2 4
:3 15 :2 4 :3 e :2 4 f 18 17 :2 f
:2 4 f 18 17 :2 f :2 4 11 1a
19 :2 11 :2 4 :2 f 1e f :2 4 :2 16
25 16 :2 4 :2 d 1c d :2 4 :2 13
22 13 :2 4 :2 14 23 14 :2 4 :2 12
21 12 :2 4 :2 11 20 11 :2 4 :2 f
1e f :2 4 :2 e 1d e :2 4 :2 10
1f 10 :2 4 :2 11 20 11 :2 4 :2 f
1e f :2 4 :2 e 1d e :2 4 :2 f
1e f :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 f 1e f :2 4 :2 c
1b c :2 4 :2 b 1a b :2 4 :2 b
1a b :2 4 :2 13 22 13 :2 4 :2 10
1f 10 :2 4 :2 a 19 a :2 4 :2 11
20 11 :2 4 :2 10 1f 10 :2 4 :2 12
21 12 :2 4 c 10 f c 20
:2 29 c :2 4 d 11 10 d 21
:2 2a d :2 4 14 1d 1c :2 14 :2 4
:2 f 19 f :2 4 :2 f 19 f :2 4
:2 10 1a 10 :2 4 :2 10 1a 10 :2 4
:2 11 1b 11 :2 4 :2 11 1b 11 :2 4
:2 12 1c 12 :2 4 :2 12 1c 12 :2 4
:2 15 24 15 :2 4 :2 c 16 c :2 4
:2 d 1c d :2 4 :2 d 1c d :2 4
:2 d 1c d :2 4 :2 d 1c d 4
7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 56 5c 5f
:2 56 6d 85 8 :2 6d d 10 :2 6d
1c 1f :2 6d b e :2 6d 13 16
1f 27 :2 1f 3f :2 16 :2 6d b e
:2 6d 13 16 1f 27 :2 1f 35 :2 16
:2 6d b e :2 6d 13 16 1f 27
:2 1f 34 :2 16 :2 6d b e :2 6d 13
16 :2 6d 1b 1e :2 6d 29 2c :2 6d
b e :2 6d 13 16 :2 6d 1b 1e
:2 6d 29 2c :2 6d 31 34 :2 6d :2 7
4c :2 4 7 :2 11 23 :2 2d 39 3c
4e 50 51 :2 4e :2 23 :3 7 :2 d 12
1e 5f 62 :2 1e :2 7 54 :3 4 c
4 e 1a 27 36 40 50 5d
68 75 7 13 23 3a 45 4f
57 69 78 87 99 7 19 2c
34 3b 56 5e 65 81 8b 7
15 23 31 7 17 27 37 7
1a 23 c 1a 24 30 3c 4e
5d 6a 7 11 1d 2e 39 41
4a 52 7 15 24 2a 30 3c
7 13 20 2c 7 15 24 32
7 17 22 c d 21 :2 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 55 58
59 :2 55 :2 29 :3 d :2 13 18 24 66
69 :2 24 76 79 :2 24 7d 80 :2 24
8c 8f :2 24 97 9a :2 24 a6 a9
b0 b9 bc :2 a9 :2 24 :2 d 5c :2 a
:2 7 :4 13 :2 7 4 :3 1 8 :2 11 1c
1a :2 25 :2 1a 7 11 1d 28 36
43 56 f 1d 2a 34 43 53
f 10 1d :2 a :2 13 1f a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5b 5c :2 58 :2 2c
:3 10 :2 16 1b 27 69 6c :2 27 79
7c :2 27 80 83 :2 27 8f 92 :2 27
9a 9d :2 27 a9 ac b3 bc bf
:2 ac :2 27 :2 10 5f :2 d :2 a :4 16 :2 a
7 :3 35 b :2 14 1f 1d :2 28 :2 1d
:2 a 18 a d :2 17 29 :2 33 3f
42 54 57 58 :2 54 :2 29 :3 d :2 13
18 24 66 69 :2 24 :2 d 5b :3 a
11 :2 1a a 38 :3 7 15 7 11
:2 f 10 1d :2 a :2 13 1f a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5b 5c :2 58 :2 2c
:3 10 :2 16 1b 27 69 6c :2 27 79
7c :2 27 80 83 :2 27 8f 92 :2 27
9a 9d :2 27 a9 ac b3 bc bf
:2 ac :2 27 :2 10 5f :2 d :2 a :4 16 :2 a
7 :3 35 a 13 1f :2 a 22 24
:2 22 14 :2 12 13 20 :2 d :2 16 22
d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5e 5f
:2 5b :2 2f :3 13 :2 19 1e 2a 6c 6f
:2 2a 7c 7f :2 2a 83 86 :2 2a 92
95 :2 2a 9d a0 :2 2a ac af b6
bf c2 :2 af :2 2a :2 13 62 :2 10 :2 d
:4 19 :2 d a :3 26 d :2 18 1f 2d
:2 d 32 34 :2 32 d 1b d 10
:2 1a 2c :2 36 42 45 57 5a 5b
:2 57 :2 2c :3 10 :2 16 1b 27 69 6c
:2 27 :2 10 5e :3 d 14 :2 1d d 36
:2 a 26 :2 7 11 :2 f 11 13 f
20 24 2f 10 13 20 e 11
1b e 11 25 27 e 10 25
27 e 10 1a 23 :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5b 5c
:2 58 :2 2c :3 10 :2 16 1b 27 69 6c
:2 27 79 7c :2 27 80 83 :2 27 8f
92 :2 27 9a 9d :2 27 a9 ac b3
bc bf :2 ac :2 27 :2 10 5f :2 d :2 a
:4 16 :2 a 7 :3 35 a 13 1f :2 a
22 24 :2 22 a 18 a d :2 17
29 :2 33 3f 42 54 57 58 :2 54
:2 29 :3 d :2 13 18 24 66 69 :2 24
:2 d 5b :3 a 11 :2 1a a 26 :2 7
a 13 1d :2 a 20 22 :2 20 d
:2 17 29 :2 33 3f 42 54 57 58
:2 54 :2 29 :3 d :2 13 18 24 66 69
:2 24 76 79 :2 24 7d 80 :2 24 8a
8d 96 9e :2 a7 :2 96 b8 :2 8d :2 24
:2 d 5b :2 a d :2 17 29 :2 33 3f
42 54 57 58 :2 54 :2 29 :3 d :2 13
18 24 66 69 :2 24 :2 d 5b :3 a
11 :2 1c 2f :2 38 48 :2 11 a 7
24 d 16 20 :2 d 26 23 2f
3e :2 26 :2 23 a 1a a d 16
20 :2 d 25 23 2e 38 :2 25 :2 23
d 1b d 10 :2 1a 2c :2 36 42
45 57 5a 5b :2 57 :2 2c :3 10 :2 16
1b 27 69 6c :2 27 :2 10 5e :3 d
14 :2 1d d a 3b 10 19 23
:2 10 28 26 31 3b :2 28 :2 26 d
1d d 3e 3b :3 a 1a :2 a 18
2a 38 3e 4c 58 21 2f :2 58
:2 18 a 41 24 d :2 17 29 :2 33
3f 42 54 57 58 :2 54 :2 29 :3 d
:2 13 18 24 66 69 :2 24 76 79
:2 24 7d 80 :2 24 8a 8d 96 9e
:2 a7 :2 96 b8 :2 8d :2 24 :2 d 5b :2 a
d :2 17 29 :2 33 3f 42 54 57
58 :2 54 :2 29 :3 d :2 13 18 24 66
69 :2 24 :2 d 5b :3 a 11 :2 1c 2f
:2 38 48 :2 11 a :4 7 35 a 13
1d :2 a 20 22 :2 20 a 18 a
d :2 17 29 :2 33 3f 42 54 57
58 :2 54 :2 29 :3 d :2 13 18 24 66
69 :2 24 :2 d 5b :3 a 11 :2 1a a
24 :3 7 15 7 11 :2 f 10 1d
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
58 5b 5c :2 58 :2 2c :3 10 :2 16 1b
27 69 6c :2 27 79 7c :2 27 80
83 :2 27 8f 92 :2 27 9a 9d :2 27
a9 ac b3 bc bf :2 ac :2 27 :2 10
5f :2 d :2 a :4 16 :2 a 7 :3 4 a
13 1f :2 a 22 24 :2 22 14 :2 12
13 20 :2 d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5b 5e 5f :2 5b :2 2f :3 13
:2 19 1e 2a 6c 6f :2 2a 7c 7f
:2 2a 83 86 :2 2a 92 95 :2 2a 9d
a0 :2 2a ac af b6 bf c2 :2 af
:2 2a :2 13 62 :2 10 :2 d :4 19 :2 d a
:3 26 d :2 18 1f 2d :2 d 32 34
:2 32 d 1b d 10 :2 1a 2c :2 36
42 45 57 5a 5b :2 57 :2 2c :3 10
:2 16 1b 27 69 6c :2 27 :2 10 5e
:3 d 14 :2 1d d 36 :2 a 26 :2 7
11 :2 f 11 f 10 24 e 23
e 18 21 :2 a :2 13 1f a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5b 5c :2 58 :2 2c
:3 10 :2 16 1b 27 69 6c :2 27 79
7c :2 27 80 83 :2 27 8f 92 :2 27
9a 9d :2 27 a9 ac b3 bc bf
:2 ac :2 27 :2 10 5f :2 d :2 a :4 16 :2 a
7 :3 4 a 13 1f :2 a 22 24
:2 22 a 18 a d :2 17 29 :2 33
3f 42 54 57 58 :2 54 :2 29 :3 d
:2 13 18 24 66 69 :2 24 :2 d 5b
:3 a 11 :2 1a a 26 :2 7 11 1d
f 1d f 10 1d e 1b :2 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 58
5b 5c :2 58 :2 2c :3 10 :2 16 1b 27
69 6c :2 27 79 7c :2 27 80 83
:2 27 8f 92 :2 27 9a 9d :2 27 a9
ac b3 bc bf :2 ac :2 27 :2 10 5f
:2 d :2 a :4 16 :2 a 7 :3 4 7 19
22 2c :2 19 7 a 13 1d :2 a
23 20 2c 3b :2 23 :2 20 a 1a
a d 16 24 :2 d 29 27 32
3c :2 29 :2 27 d 1d 1e :2 1d :2 d
1b 32 40 4b 51 57 5d 28
34 42 55 :2 1b d 10 19 25
:2 10 28 2a :2 28 13 1c 29 :2 13
2f 2c 38 3f :2 2f :2 2c 16 :2 21
28 32 :2 16 3e 40 :2 3e 16 22
2b 39 :2 22 3c 3e 47 51 :2 3e
:2 22 :2 16 28 16 19 22 30 :2 19
33 36 3f 4e :2 36 51 53 5c
63 :2 53 :2 36 35 :2 33 19 23 2c
3b :2 23 3e 40 49 50 :2 40 :2 23
22 54 56 5f 6d :2 56 :2 22 19
23 20 1c 2a 33 3a 46 4f
1c 29 1c 2a 1c 22 1c 22
36 1c 23 1f 2b :3 29 1f :2 28
34 1f 30 1f :2 28 34 1f :4 1c
19 :2 21 1f :2 28 34 1f 22 :2 2c
3e :2 48 54 58 6a 6d 6e :2 6a
:2 3e :3 22 :2 28 2d 39 7b 7e :2 39
8b 8e :2 39 92 95 :2 39 a1 a4
:2 39 ac af :2 39 bb be c5 ce
d1 :2 be :2 39 :2 22 71 :2 1f :2 1c :4 28
:2 1c 19 :3 67 19 2b :2 34 3b 44
54 :2 3b 58 :2 61 :2 2b 19 67 23
20 1c 2a 33 3a 46 4f 1c
29 1c 2a :2 1c 22 36 1c 23
1f 2b :3 29 1f :2 28 34 1f 30
1f :2 28 34 1f :4 1c 19 :2 21 1f
:2 28 34 1f 22 :2 2c 3e :2 48 54
58 6a 6d 6e :2 6a :2 3e :3 22 :2 28
2d 39 7b 7e :2 39 8b 8e :2 39
92 95 :2 39 a1 a4 :2 39 ac af
:2 39 bb be c5 ce d1 :2 be :2 39
:2 22 71 :2 1f :2 1c :4 28 :2 1c 19 :7 16
42 19 22 30 :2 19 33 36 3f
4e :2 36 51 53 5c 63 :2 53 :2 36
35 :2 33 19 25 2e 35 :2 25 38
3a 43 4d :2 3a :2 25 :2 19 2b 33
3c 4a :2 33 4d 4f 58 62 :2 4f
:2 33 32 66 68 :2 32 31 72 74
:2 31 :2 2b 19 23 20 1c 2a 33
3a 46 4f 1c 29 1c 2a 22
36 1c 23 1f 2b :3 29 1f :2 28
34 1f 30 1f :2 28 34 1f :4 1c
19 :2 21 1f :2 28 34 1f 22 :2 2c
3e :2 48 54 58 6a 6d 6e :2 6a
:2 3e :3 22 :2 28 2d 39 7b 7e :2 39
8b 8e :2 39 92 95 :2 39 a1 a4
:2 39 ac af :2 39 bb be c5 ce
d1 :2 be :2 39 :2 22 71 :2 1f :2 1c :4 28
:2 1c 19 :4 67 19 25 2e 3c :2 25
3f 41 4a 54 :2 41 :2 25 :2 19 2b
19 23 20 1c 2a 33 3a 46
4f 1c 29 1c 2a :2 1c 22 36
1c 23 1f 2b :3 29 1f :2 28 34
1f 30 1f :2 28 34 1f :4 1c 19
:2 21 1f :2 28 34 1f 22 :2 2c 3e
:2 48 54 58 6a 6d 6e :2 6a :2 3e
:3 22 :2 28 2d 39 7b 7e :2 39 8b
8e :2 39 92 95 :2 39 a1 a4 :2 39
ac af :2 39 bb be c5 ce d1
:2 be :2 39 :2 22 71 :2 1f :2 1c :4 28 :2 1c
19 :7 16 :4 13 42 13 1f 28 36
:2 1f 39 3b 44 53 :2 3b :2 1f :2 13
25 13 1d 1a 16 24 2d 34
40 49 16 23 16 24 :2 16 1c
30 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 67 68 :2 64
:2 38 :3 1c :2 22 27 33 75 78 :2 33
85 88 :2 33 8c 8f :2 33 9b 9e
:2 33 a6 a9 :2 33 b5 b8 bf c8
cb :2 b8 :2 33 :2 1c 6b :2 19 :2 16 :4 22
:2 16 13 :7 10 :4 14 :2 13 20 13 1d
21 :2 1b 1c 29 1a 28 :2 16 :2 1f
2b 16 13 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 67
68 :2 64 :2 38 :3 1c :2 22 27 33 75
78 :2 33 85 88 :2 33 8c 8f :2 33
9b 9e :2 33 a6 a9 :2 33 b5 b8
bf c8 cb :2 b8 :2 33 :2 1c 6b :2 19
:2 16 :4 22 :2 16 13 :3 32 :4 17 16 20
28 2f 50 5f :2 19 :2 22 2e 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 67 6a 6b :2 67
:2 3b :3 1f :2 25 2a 36 78 7b :2 36
88 8b :2 36 8f 92 :2 36 9e a1
:2 36 a9 ac :2 36 b8 bb c2 cb
ce :2 bb :2 36 :2 1f 6e :2 1c :2 19 :4 25
:2 19 16 :3 2e 19 :2 24 2c 3e 49
:2 19 4d 4f :2 4d 19 29 19 51
:2 16 13 2e 19 22 2d :2 19 30
32 :2 30 16 24 :2 2d 34 3d 48
:2 34 4c :2 55 :2 24 23 16 20 2b
38 40 47 62 6d 72 :2 1e :2 19
:2 22 2e 19 16 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 67
6a 6b :2 67 :2 3b :3 1f :2 25 2a 36
78 7b :2 36 88 8b :2 36 8f 92
:2 36 9e a1 :2 36 a9 ac :2 36 b8
bb c2 cb ce :2 bb :2 36 :2 1f 6e
:2 1c :2 19 :4 25 :2 19 16 :4 34 2e 20
2b 38 40 47 62 6d 72 :2 1e
:2 19 :2 22 2e 19 16 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
67 6a 6b :2 67 :2 3b :3 1f :2 25 2a
36 78 7b :2 36 88 8b :2 36 8f
92 :2 36 9e a1 :2 36 a9 ac :2 36
b8 bb c2 cb ce :2 bb :2 36 :2 1f
6e :2 1c :2 19 :4 25 :2 19 16 :7 13 32
:2 10 :4 14 :2 13 21 31 3f 45 :2 21
13 31 16 1d 29 2c :2 16 2f
31 :2 2f 16 24 34 42 48 :2 24
16 35 16 24 34 42 48 :2 24
16 :4 13 :5 10 1e :2 10 1e 2c 32
40 4a 56 61 6d 1f 28 39
:2 1f :2 1e 10 13 1c 28 :2 13 2b
2e :2 2b 13 21 13 16 :2 20 32
:2 3c 48 4b 5d 60 61 :2 5d :2 32
:3 16 :2 1c 21 2d 6f 72 :2 2d :2 16
64 :3 13 1a 23 2f :2 1a 13 30
:3 10 1c 10 2c :2 d 3f d 1f
27 30 3e :2 27 41 43 4c 56
:2 43 :2 27 26 5a 5c :2 26 25 66
68 :2 25 :2 1f d :5 a 18 2c 3a
45 4f 55 25 31 3b 49 25
34 44 50 25 31 3e 4c 25
33 42 55 25 31 3d 46 51
:2 3d :2 18 :2 a 18 a d :2 17 29
:2 33 3f 42 54 57 58 :2 54 :2 29
:3 d :2 13 18 24 66 69 :2 24 :2 d
5b :3 a 11 1a 26 :2 11 a 7
3e d 16 2a :2 d 30 2d 39
49 :2 30 :2 2d 14 11 25 d 1b
24 2b 37 40 13 27 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5e 5f :2 5b :2 2f :3 13 :2 19
1e 2a 6c 6f :2 2a 7c 7f :2 2a
83 86 :2 2a 92 95 :2 2a 9d a0
:2 2a ac af b6 bf c2 :2 af :2 2a
:2 13 62 :2 10 :2 d :4 19 :2 d a :3 4c
14 11 1f 28 2f 3b 44 13
20 11 1e d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5e
5f :2 5b :2 2f :3 13 :2 19 1e 2a 6c
6f :2 2a 7c 7f :2 2a 83 86 :2 2a
92 95 :2 2a 9d a0 :2 2a ac af
b6 bf c2 :2 af :2 2a :2 13 62 :2 10
:2 d :4 19 :2 d a :3 4c 7 4c 3e
d 16 1f :2 d 25 22 2e 3f
:2 25 :2 22 d 16 1f :2 d 22 24
:2 22 d 20 d 26 11 1a 23
:2 11 26 28 :2 26 10 2f 38 41
:2 2f 44 46 :2 44 2e :3 10 1e 10
13 :2 1d 2f :2 39 45 48 5a 5d
5e :2 5a :2 2f :3 13 :2 19 1e 2a 6c
6f :2 2a :2 13 61 :3 10 17 :2 20 10
51 :3 d 20 29 32 :2 20 d :4 a
:4 e d 17 :2 15 16 2a :2 10 :2 19
25 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 61
62 :2 5e :2 32 :3 16 :2 1c 21 2d 6f
72 :2 2d 7f 82 :2 2d 86 89 :2 2d
95 98 :2 2d a0 a3 :2 2d af b2
b9 c2 c5 :2 b2 :2 2d :2 16 65 :2 13
:2 10 :4 1c :2 10 d :3 2b 11 :2 1a 25
23 :2 2e :2 23 10 43 4c 5d :2 43
62 60 13 1f :2 62 :2 60 42 :3 10
1e 10 13 :2 1d 2f :2 39 45 48
5a 5d 5e :2 5a :2 2f :3 13 :2 19 1e
2a 6c 6f :2 2a :2 13 61 :3 10 17
:2 20 10 23 :2 d 2b :3 a 1a 1b
:2 1a :2 a 18 2f 3d 48 4e 54
5a 28 34 42 55 :2 18 a e
17 23 :2 e 26 28 :2 26 d :4 31
30 2f :3 d 1b 30 3e 49 53
64 26 38 44 :2 1b d 50 :2 a
:4 e :2 d 1b 2b 39 3f :2 1b d
2b 10 17 23 26 :2 10 29 2b
:2 29 10 1e 2e 3c 42 :2 1e 10
2f 10 1e 2e 3c 42 :2 1e 10
:4 d :4 a :4 e d 17 22 2f 37
3e 59 64 69 :2 15 :2 10 :2 19 25
10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 61 62
:2 5e :2 32 :3 16 :2 1c 21 2d 6f 72
:2 2d 7f 82 :2 2d 86 89 :2 2d 95
98 :2 2d a0 a3 :2 2d af b2 b9
c2 c5 :2 b2 :2 2d :2 16 65 :2 13 :2 10
:4 1c :2 10 d :3 2c d 19 22 2c
:2 19 2f 31 3a 49 :2 31 :2 19 d
2c :3 a 17 :2 a 18 :2 a 18 26
2c 3a 44 50 5b 67 1f 28
39 :2 1f :2 18 a d 16 22 :2 d
25 28 :2 25 d 1b d 10 :2 1a
2c :2 36 42 45 57 5a 5b :2 57
:2 2c :3 10 :2 16 1b 27 69 6c :2 27
:2 10 5e :3 d 14 :2 1d d 2a 17
14 10 1c :5 10 1e 27 2e 3b
44 51 5a 16 2a 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 61 62 :2 5e :2 32 :3 16 :2 1c 21
2d 6f 72 :2 2d 7f 82 :2 2d 86
89 :2 2d 95 98 :2 2d a0 a3 :2 2d
af b2 b9 c2 c5 :2 b2 :2 2d :2 16
65 :2 13 :2 10 :4 1c :2 10 d :7 a 42
3e :2 7 :5 4 :2 d 19 23 :2 19 4
7 :2 11 23 :2 2d 39 3c 4e 51
52 :2 4e :2 23 :3 7 :2 d 12 1e 60
63 :2 1e 70 73 :2 1e 77 7a :2 1e
84 87 :2 90 :2 1e :2 7 55 :3 4 b
:2 14 4 :9 1 
121e
4
0 :2 1 :6 3 :4 4
:4 5 :4 6 :6 7 :6 8
2 :2 9 :2 1 :6 b
:6 c :6 d :7 e :7 f
:7 10 :7 11 :7 12 :5 13
:5 14 :5 15 :5 16 :5 17
:5 18 :7 19 :7 1a :7 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :a 36 :a 37
:7 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :b 48
:11 49 4a :2 49 :2 4a
:2 49 :2 4a :2 49 :2 4b
:2 49 :9 4b :2 49 :2 4c
:2 49 :9 4c :2 49 :2 4d
:2 49 :9 4d :2 49 :2 4e
:2 49 :2 4e :2 49 :2 4e
:2 49 :2 4e :2 49 :2 4f
:2 49 :2 4f :2 49 :2 4f
:2 49 :2 4f :2 49 :2 4f
:4 49 :3 48 :11 52 :b 53
:3 52 :3 56 :9 59 :b 5a
:a 5b :4 5c :4 5d :3 5e
:8 5f :8 60 :6 61 :4 62
:4 63 :3 64 65 :2 66
59 :5 67 58 :2 69
:5 6b :11 6c :24 6d :3 6c
:2 6a :6 69 68 :3 47
:a 72 :6 74 :6 75 76
:2 77 74 :5 78 73
:2 7a :5 7c :11 7d :24 7e
:3 7d :2 7b :6 7a 79
:3 72 :a 83 :3 84 :11 85
:b 86 :3 85 :5 88 :3 83
:3 8b 8d 8e 8f
:2 90 8d :5 91 8c
:2 93 :5 95 :11 96 :24 97
:3 96 :2 94 :6 93 92
:3 72 :9 9c 9e 9f
a0 :2 a1 9e :5 a2
9d :2 a4 :5 a6 :11 a7
:24 a8 :3 a7 :2 a5 :6 a4
a3 :3 9c :b ad :3 ae
:11 af :b b0 :3 af :5 b2
:3 ad :3 9c b8 b9
ba :2 bc :4 bd :3 be
:3 bf :4 c0 :4 c1 :4 c2
b8 :5 c3 b7 :2 c5
:5 c7 :11 c8 :24 c9 :3 c8
:2 c6 :6 c5 c4 :3 72
:9 ce :3 cf :11 d0 :b d1
:3 d0 :5 d3 :3 ce :9 d6
:11 d7 :20 d8 :3 d7 :11 da
:b db :3 da :b dd de
d6 :d de :3 df :d e0
:3 e1 :11 e2 :b e3 :3 e2
:5 e5 e6 e0 :d e6
:3 e7 e6 :3 e0 :3 ea
:7 eb :2 ec :5 eb de
d6 :11 ee :20 ef :3 ee
:11 f1 :b f2 :3 f1 :b f4
ed :3 d6 72 :9 f7
:3 f8 :11 f9 :b fa :3 f9
:5 fc :3 f7 :3 ff 101
102 103 :2 104 101
:5 105 100 :2 107 :5 109
:11 10a :24 10b :3 10a :2 108
:6 107 106 :3 f6 :9 110
112 113 114 :2 115
112 :5 116 111 :2 118
:5 11a :11 11b :24 11c :3 11b
:2 119 :6 118 117 :3 110
:b 121 :3 122 :11 123 :b 124
:3 123 :5 126 :3 121 :3 110
12c 12d 12e 130
131 :2 132 :2 133 :3 134
12c :5 135 12b :2 137
:5 139 :11 13a :24 13b :3 13a
:2 138 :6 137 136 :3 f6
:9 140 :3 141 :11 142 :b 143
:3 142 :5 145 :3 140 :2 149
:2 14a 14b :2 14c :2 14d
149 :5 14e 148 :2 150
:5 152 :11 153 :24 154 :3 153
:2 151 :6 150 14f :3 f6
:7 159 :d 15a :3 15b :d 15d
:6 15e :8 15f :4 160 :3 15f
:9 162 :d 163 :b 164 :f 165
:3 166 :16 168 :18 169 16b
16c :6 16d :2 16e :2 16f
:2 170 171 :2 172 16b
:6 173 :5 174 173 :5 176
175 :3 173 16a :2 179
:5 17b :11 17c :24 17d :3 17c
:2 17a :6 179 178 :3 168
:f 182 168 185 186
:6 187 :2 188 :2 189 18a
18b :2 18c 185 :6 18d
:5 18e 18d :5 190 18f
:3 18d 184 :2 193 :5 195
:11 196 :24 197 :3 196 :2 194
:6 193 192 :4 183 :3 168
164 :16 19d :f 19e :1c 19f
1a2 1a3 :6 1a4 :2 1a5
:2 1a6 :2 1a7 1a2 :6 1a8
:5 1a9 1a8 :5 1ab 1aa
:3 1a8 1a1 :2 1ae :5 1b0
:11 1b1 :24 1b2 :3 1b1 :2 1af
:6 1ae 1ad :4 19d :f 1b7
:3 1b8 1bb 1bc :6 1bd
:2 1be :2 1bf 1c0 1c1
:2 1c2 1bb :6 1c3 :5 1c4
1c3 :5 1c6 1c5 :3 1c3
1ba :2 1c9 :5 1cb :11 1cc
:24 1cd :3 1cc :2 1ca :6 1c9
1c8 :4 1b6 :3 19d 19c
:3 164 163 :f 1d4 :3 1d5
1d8 1d9 :6 1da :2 1db
:2 1dc 1dd 1de :2 1df
1d8 :6 1e0 :5 1e1 1e0
:5 1e3 1e2 :3 1e0 1d7
:2 1e6 :5 1e8 :11 1e9 :24 1ea
:3 1e9 :2 1e7 :6 1e6 1e5
:4 1d3 :3 163 :5 1f0 :3 1f1
:2 1f3 1f4 1f5 :2 1f6
:2 1f7 1f3 :5 1f8 1f2
:2 1fa :5 1fc :11 1fd :24 1fe
:3 1fd :2 1fb :6 1fa 1f9
:3 1f0 :5 204 :6 206 :5 207
205 :2 209 :5 20b :11 20c
:24 20d :3 20c :2 20a :6 209
208 :3 204 :c 212 :3 213
:3 212 215 204 :9 215
:10 216 :8 219 21a 21b
219 :5 21c 218 :2 21e
:5 220 :11 221 :24 222 :3 221
:2 21f :6 21e 21d :4 215
204 :8 228 229 22a
228 :5 22b 227 :2 22d
:5 22f :11 230 :24 231 :3 230
:2 22e :6 22d 22c :4 226
:3 204 :3 1f0 :5 23a :8 23b
23a :a 23d :8 23e 23d
:8 240 23f :3 23d 23c
:3 23a :3 244 :9 245 :5 246
:3 245 :9 248 :3 249 :11 24a
:b 24b :3 24a :7 24d :3 248
:3 250 :3 162 15d :1c 254
252 :3 15d :7 25a :4 25b
:4 25c :4 25d :4 25e :7 25f
:3 25a :3 262 :11 263 :b 264
:3 263 :7 266 267 15a
:d 267 28a :2 28b :6 28c
:2 28d 28a :6 28e :5 28f
28e :5 291 290 :3 28e
289 :2 294 :5 296 :11 297
:24 298 :3 297 :2 295 :6 294
293 :3 267 2a3 :6 2a4
:2 2a5 :2 2a6 2a3 :6 2a7
:5 2a8 2a7 :5 2aa 2a9
:3 2a7 2a2 :2 2ad :5 2af
:11 2b0 :24 2b1 :3 2b0 :2 2ae
:6 2ad 2ac :3 267 2b7
267 15a :d 2b7 :9 2b8
:3 2b9 2b8 :16 2bb :3 2bc
:11 2bd :b 2be :3 2bd :5 2c0
:3 2bb :7 2c3 2ba :3 2b8
:5 2c6 2c8 2c9 2ca
:2 2cb 2c8 :5 2cc 2c7
:2 2ce :5 2d0 :11 2d1 :24 2d2
:3 2d1 :2 2cf :6 2ce 2cd
:3 2c6 :11 2d8 :2 2d9 :7 2d8
:3 2da :11 2db :b 2dc :3 2db
:5 2de 2d9 :2 2d8 :3 2c6
:6 31b :8 31c :4 31d :3 31c
:12 31f :7 320 :3 321 :3 320
:3 31f :5 325 :8 326 325
:a 328 :8 329 328 :8 32b
32a :3 328 327 :3 325
:5 32f :8 331 332 333
331 :5 334 330 :2 336
:5 338 :11 339 :24 33a :3 339
:2 337 :6 336 335 :3 32f
:f 33f :3 32f :3 344 :3 345
:9 346 :5 347 :3 346 :9 34a
:3 34b :11 34c :b 34d :3 34c
:5 34f 34a 352 353
:2 354 355 356 357
358 :8 359 :2 35a 352
:6 35b :5 35c 35b :5 35e
35d :3 35b 351 :2 361
:5 363 :11 364 :24 365 :3 364
:2 362 :6 361 360 :4 350
:3 34a 2b7 :3 15a f6
:3 72 :8 36f :11 376 :19 377
:3 376 :5 379 :2 47 :7 1

3fe8
4
:3 0 1 :3 0 2
:a 0 1219 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 5d 0 7
8 :3 0 7 :7 0
b a :3 0 8
:3 0 9 :7 0 f
e :3 0 d 8a
0 b 8 :3 0
a :7 0 13 12
:3 0 4 :3 0 5
:3 0 6 :3 0 b
:5 0 1 19 18
:3 0 16 b6 0
f 4 :3 0 5
:3 0 6 :3 0 c
:5 0 1 1f 1e
:3 0 d :3 0 8
:3 0 21 23 0
1219 2 24 :2 0
1a f2 0 18
8 :3 0 27 :7 0
7 :3 0 2b 28
29 1217 0 e
:6 0 8 :3 0 2d
:7 0 9 :3 0 31
2e 2f 1217 0
f :6 0 12 :2 0
1e 8 :3 0 33
:7 0 a :3 0 37
34 35 1217 0
10 :6 0 6 :3 0
12 :2 0 1c 39
3b :6 0 3e 3c
0 1217 0 11
:6 0 12 :2 0 22
6 :3 0 20 40
42 :6 0 45 43
0 1217 0 13
:6 0 12 :2 0 26
6 :3 0 24 47
49 :6 0 4c 4a
0 1217 0 14
:6 0 12 :2 0 2a
6 :3 0 28 4e
50 :6 0 53 51
0 1217 0 15
:6 0 30 1a2 0
2e 6 :3 0 2c
55 57 :6 0 5a
58 0 1217 0
16 :6 0 34 1d6
0 32 18 :3 0
5c :7 0 5f 5d
0 1217 0 17
:6 0 18 :3 0 61
:7 0 64 62 0
1217 0 19 :6 0
38 20a 0 36
1b :3 0 66 :7 0
69 67 0 1217
0 1a :6 0 1b
:3 0 6b :7 0 6e
6c 0 1217 0
1c :6 0 20 :2 0
3a 18 :3 0 70
:7 0 73 71 0
1217 0 1d :6 0
18 :3 0 75 :7 0
78 76 0 1217
0 1e :6 0 20
:2 0 3e 6 :3 0
3c 7a 7c :6 0
7f 7d 0 1217
0 1f :6 0 20
:2 0 42 6 :3 0
40 81 83 :6 0
86 84 0 1217
0 21 :6 0 24
:2 0 46 6 :3 0
44 88 8a :6 0
8d 8b 0 1217
0 22 :6 0 24
:2 0 48 8 :3 0
8f :7 0 93 90
91 1217 0 23
:6 0 24 :2 0 4a
8 :3 0 95 :7 0
99 96 97 1217
0 25 :6 0 24
:2 0 4c 8 :3 0
9b :7 0 9f 9c
9d 1217 0 26
:6 0 24 :2 0 4e
8 :3 0 a1 :7 0
a5 a2 a3 1217
0 27 :6 0 24
:2 0 50 8 :3 0
a7 :7 0 ab a8
a9 1217 0 28
:6 0 24 :2 0 52
8 :3 0 ad :7 0
b1 ae af 1217
0 29 :6 0 24
:2 0 54 8 :3 0
b3 :7 0 b7 b4
b5 1217 0 2a
:6 0 24 :2 0 56
8 :3 0 b9 :7 0
bd ba bb 1217
0 2b :6 0 24
:2 0 58 8 :3 0
bf :7 0 c3 c0
c1 1217 0 2c
:6 0 24 :2 0 5a
8 :3 0 c5 :7 0
c9 c6 c7 1217
0 2d :6 0 24
:2 0 5c 8 :3 0
cb :7 0 cf cc
cd 1217 0 2e
:6 0 24 :2 0 5e
8 :3 0 d1 :7 0
d5 d2 d3 1217
0 2f :6 0 24
:2 0 60 8 :3 0
d7 :7 0 db d8
d9 1217 0 30
:6 0 24 :2 0 62
8 :3 0 dd :7 0
e1 de df 1217
0 31 :6 0 24
:2 0 64 8 :3 0
e3 :7 0 e7 e4
e5 1217 0 32
:6 0 24 :2 0 66
8 :3 0 e9 :7 0
ed ea eb 1217
0 33 :6 0 24
:2 0 68 8 :3 0
ef :7 0 f3 f0
f1 1217 0 34
:6 0 24 :2 0 6a
8 :3 0 f5 :7 0
f9 f6 f7 1217
0 35 :6 0 24
:2 0 6c 8 :3 0
fb :7 0 ff fc
fd 1217 0 36
:6 0 24 :2 0 6e
8 :3 0 101 :7 0
105 102 103 1217
0 37 :6 0 24
:2 0 70 8 :3 0
107 :7 0 10b 108
109 1217 0 38
:6 0 24 :2 0 72
8 :3 0 10d :7 0
111 10e 10f 1217
0 39 :6 0 24
:2 0 74 8 :3 0
113 :7 0 117 114
115 1217 0 3a
:6 0 24 :2 0 76
8 :3 0 119 :7 0
11d 11a 11b 1217
0 3b :6 0 24
:2 0 78 8 :3 0
11f :7 0 123 120
121 1217 0 3c
:6 0 40 :2 0 7a
8 :3 0 125 :7 0
129 126 127 1217
0 3d :6 0 40
:2 0 7e 3f :3 0
7c 12b 12d 2
:5 0 41 :3 0 42
:3 0 12f 130 0
133 12e 131 1217
0 3e :6 0 45
:2 0 82 3f :3 0
80 135 137 2
:5 0 41 :3 0 42
:3 0 139 13a 0
13d 138 13b 1217
0 43 :6 0 24
:2 0 86 6 :3 0
84 13f 141 :6 0
144 142 0 1217
0 44 :6 0 24
:2 0 88 47 :3 0
146 :7 0 14a 147
148 1217 0 46
:6 0 24 :2 0 8a
47 :3 0 14c :7 0
150 14d 14e 1217
0 48 :6 0 24
:2 0 8c 47 :3 0
152 :7 0 156 153
154 1217 0 49
:6 0 24 :2 0 8e
47 :3 0 158 :7 0
15c 159 15a 1217
0 4a :6 0 24
:2 0 90 47 :3 0
15e :7 0 162 15f
160 1217 0 4b
:6 0 24 :2 0 92
47 :3 0 164 :7 0
168 165 166 1217
0 4c :6 0 24
:2 0 94 47 :3 0
16a :7 0 16e 16b
16c 1217 0 4d
:6 0 24 :2 0 96
47 :3 0 170 :7 0
174 171 172 1217
0 4e :6 0 24
:2 0 98 8 :3 0
176 :7 0 17a 177
178 1217 0 4f
:6 0 24 :2 0 9a
47 :3 0 17c :7 0
180 17d 17e 1217
0 50 :6 0 24
:2 0 9c 8 :3 0
182 :7 0 186 183
184 1217 0 51
:6 0 24 :2 0 9e
8 :3 0 188 :7 0
18c 189 18a 1217
0 52 :6 0 24
:2 0 a0 8 :3 0
18e :7 0 192 18f
190 1217 0 53
:6 0 199 19a 0
a2 8 :3 0 194
:7 0 198 195 196
1217 0 54 :6 0
55 :3 0 56 :3 0
55 :3 0 57 :3 0
19c 19d 0 2
:4 0 a4 19e 1a0
19b 1a2 1a1 :2 0
58 :3 0 59 :3 0
1a4 1a5 0 5a
:4 0 55 :3 0 5b
:3 0 1a8 1a9 0
2 :4 0 a6 1aa
1ac 5c :4 0 5d
:2 0 5e :3 0 a8
1af 1b1 :3 0 5f
:4 0 5d :2 0 60
:4 0 ab 1b4 1b6
:3 0 5d :2 0 3
:3 0 ae 1b8 1ba
:3 0 5d :2 0 60
:4 0 b1 1bc 1be
:3 0 5d :2 0 61
:4 0 b4 1c0 1c2
:3 0 5d :2 0 62
:3 0 63 :3 0 7
:3 0 b7 1c6 1c8
64 :4 0 b9 1c5
1cb bc 1c4 1cd
:3 0 5d :2 0 61
:4 0 bf 1cf 1d1
:3 0 5d :2 0 62
:3 0 63 :3 0 9
:3 0 c2 1d5 1d7
64 :4 0 c4 1d4
1da c7 1d3 1dc
:3 0 5d :2 0 61
:4 0 ca 1de 1e0
:3 0 5d :2 0 62
:3 0 63 :3 0 a
:3 0 cd 1e4 1e6
64 :4 0 cf 1e3
1e9 d2 1e2 1eb
:3 0 5d :2 0 61
:4 0 d5 1ed 1ef
:3 0 5d :2 0 60
:4 0 d8 1f1 1f3
:3 0 5d :2 0 b
:3 0 db 1f5 1f7
:3 0 5d :2 0 60
:4 0 de 1f9 1fb
:3 0 5d :2 0 61
:4 0 e1 1fd 1ff
:3 0 5d :2 0 60
:4 0 e4 201 203
:3 0 5d :2 0 c
:3 0 e7 205 207
:3 0 5d :2 0 60
:4 0 ea 209 20b
:3 0 5d :2 0 65
:4 0 ed 20d 20f
:3 0 f0 1a6 211
:2 0 213 f5 214
1a3 213 0 215
f7 0 1215 55
:3 0 56 :3 0 216
217 0 55 :3 0
66 :3 0 219 21a
0 20 :2 0 2
:4 0 67 :2 0 68
:2 0 20 :2 0 f9
21f 221 :3 0 fc
21b 223 218 225
224 :2 0 58 :3 0
69 :3 0 227 228
0 5a :4 0 6a
:4 0 5d :2 0 5e
:3 0 100 22c 22e
:3 0 103 229 230
:2 0 232 106 233
226 232 0 234
108 0 1215 11
:3 0 3 :3 0 235
236 0 1215 6b
:3 0 6c :3 0 6d
:3 0 6e :3 0 6f
:3 0 70 :3 0 71
:3 0 70 :3 0 72
:3 0 71 :3 0 73
:3 0 74 :3 0 75
:3 0 76 :3 0 77
:3 0 78 :3 0 79
:3 0 7a :3 0 79
:3 0 7a :3 0 7b
:3 0 7c :3 0 7d
:3 0 7e :3 0 7b
:3 0 7d :3 0 7e
:3 0 7c :3 0 7f
:3 0 80 :3 0 81
:3 0 82 :3 0 83
:3 0 84 :3 0 85
:3 0 86 :3 0 87
:3 0 88 :3 0 89
:3 0 8a :3 0 8b
:3 0 14 :3 0 16
:3 0 21 :3 0 1f
:3 0 1d :3 0 29
:3 0 3c :3 0 3a
:3 0 26 :3 0 2b
:3 0 13 :3 0 32
:3 0 37 :3 0 35
:3 0 36 :3 0 28
:3 0 1a :3 0 1c
:3 0 17 :3 0 19
:3 0 23 :3 0 25
:3 0 46 :3 0 49
:3 0 48 :3 0 4a
:3 0 4b :3 0 4d
:3 0 4c :3 0 4e
:3 0 27 :3 0 15
:3 0 3d :3 0 8c
:3 0 8d :3 0 11
:4 0 8e 1 :8 0
28b 8f :3 0 90
:3 0 286 287 0
91 :3 0 288 289
0 28b 10a 2d5
92 :3 0 8f :3 0
90 :3 0 28e 28f
0 91 :3 0 290
291 0 2cb 55
:3 0 56 :3 0 293
294 0 55 :3 0
66 :3 0 296 297
0 93 :2 0 2
:4 0 94 :2 0 68
:2 0 20 :2 0 10d
29c 29e :3 0 110
298 2a0 295 2a2
2a1 :2 0 58 :3 0
69 :3 0 2a4 2a5
0 5a :4 0 95
:4 0 5d :2 0 5e
:3 0 114 2a9 2ab
:3 0 5d :2 0 96
:4 0 117 2ad 2af
:3 0 5d :2 0 97
:4 0 11a 2b1 2b3
:3 0 5d :2 0 91
:3 0 11d 2b5 2b7
:3 0 5d :2 0 98
:4 0 120 2b9 2bb
:3 0 5d :2 0 7e
:3 0 99 :3 0 20
:2 0 9a :2 0 123
2be 2c2 127 2bd
2c4 :3 0 12a 2a6
2c6 :2 0 2c8 12d
2c9 2a3 2c8 0
2ca 12f 0 2cb
131 2ce :3 0 2ce
0 2ce 2cd 2cb
2cc :6 0 2d0 2
:3 0 134 2d2 136
2d1 2d0 :2 0 2d3
138 :2 0 2d5 0
2d5 2d4 28b 2d3
:6 0 1215 1 :3 0
8f :3 0 90 :3 0
2d7 2d8 0 8f
:3 0 9b :2 0 9c
:3 0 2da 2dc 0
13c 2db 2de :3 0
2df :2 0 6b :3 0
9d :3 0 9e :3 0
70 :3 0 89 :3 0
9f :3 0 14 :3 0
2d :3 0 26 :3 0
29 :3 0 27 :3 0
31 :3 0 a0 :3 0
a1 :3 0 11 :4 0
a2 1 :8 0 2f6
8f :3 0 90 :3 0
2f1 2f2 0 91
:3 0 2f3 2f4 0
2f6 13f 340 92
:3 0 8f :3 0 90
:3 0 2f9 2fa 0
91 :3 0 2fb 2fc
0 336 55 :3 0
56 :3 0 2fe 2ff
0 55 :3 0 66
:3 0 301 302 0
93 :2 0 2 :4 0
a3 :2 0 68 :2 0
20 :2 0 142 307
309 :3 0 145 303
30b 300 30d 30c
:2 0 58 :3 0 69
:3 0 30f 310 0
5a :4 0 a4 :4 0
5d :2 0 5e :3 0
149 314 316 :3 0
5d :2 0 96 :4 0
14c 318 31a :3 0
5d :2 0 97 :4 0
14f 31c 31e :3 0
5d :2 0 91 :3 0
152 320 322 :3 0
5d :2 0 98 :4 0
155 324 326 :3 0
5d :2 0 7e :3 0
99 :3 0 20 :2 0
9a :2 0 158 329
32d 15c 328 32f
:3 0 15f 311 331
:2 0 333 162 334
30e 333 0 335
164 0 336 166
339 :3 0 339 0
339 338 336 337
:6 0 33b 4 :3 0
169 33d 16b 33c
33b :2 0 33e 16d
:2 0 340 0 340
33f 2f6 33e :6 0
640 1 :3 0 8f
:3 0 90 :3 0 342
343 0 8f :3 0
9b :2 0 9c :3 0
345 347 0 171
346 349 :3 0 34a
:2 0 c :3 0 11
:3 0 34c 34d 0
373 55 :3 0 56
:3 0 34f 350 0
55 :3 0 66 :3 0
352 353 0 20
:2 0 2 :4 0 a5
:2 0 68 :2 0 20
:2 0 174 358 35a
:3 0 177 354 35c
351 35e 35d :2 0
58 :3 0 69 :3 0
360 361 0 5a
:4 0 a6 :4 0 5d
:2 0 5e :3 0 17b
365 367 :3 0 17e
362 369 :2 0 36b
181 36c 35f 36b
0 36d 183 0
373 d :3 0 41
:3 0 a7 :3 0 36f
370 0 371 :2 0
373 185 374 34b
373 0 375 189
0 640 2f :3 0
24 :2 0 376 377
0 640 a8 :3 0
2f :3 0 a9 :3 0
6b :3 0 14 :4 0
aa 1 :8 0 384
8f :3 0 90 :3 0
37f 380 0 91
:3 0 381 382 0
384 18b 3ce 92
:3 0 8f :3 0 90
:3 0 387 388 0
91 :3 0 389 38a
0 3c4 55 :3 0
56 :3 0 38c 38d
0 55 :3 0 66
:3 0 38f 390 0
93 :2 0 2 :4 0
ab :2 0 68 :2 0
20 :2 0 18e 395
397 :3 0 191 391
399 38e 39b 39a
:2 0 58 :3 0 69
:3 0 39d 39e 0
5a :4 0 ac :4 0
5d :2 0 5e :3 0
195 3a2 3a4 :3 0
5d :2 0 96 :4 0
198 3a6 3a8 :3 0
5d :2 0 97 :4 0
19b 3aa 3ac :3 0
5d :2 0 91 :3 0
19e 3ae 3b0 :3 0
5d :2 0 98 :4 0
1a1 3b2 3b4 :3 0
5d :2 0 7e :3 0
99 :3 0 20 :2 0
9a :2 0 1a4 3b7
3bb 1a8 3b6 3bd
:3 0 1ab 39f 3bf
:2 0 3c1 1ae 3c2
39c 3c1 0 3c3
1b0 0 3c4 1b2
3c7 :3 0 3c7 0
3c7 3c6 3c4 3c5
:6 0 3c9 6 :3 0
1b5 3cb 1b7 3ca
3c9 :2 0 3cc 1b9
:2 0 3ce 0 3ce
3cd 384 3cc :6 0
640 1 :3 0 62
:3 0 2f :3 0 24
:2 0 1bb 3d0 3d3
ad :2 0 24 :2 0
1c0 3d5 3d7 :3 0
ae :3 0 22 :3 0
a0 :3 0 a1 :3 0
14 :4 0 af 1
:8 0 3e4 8f :3 0
90 :3 0 3df 3e0
0 91 :3 0 3e1
3e2 0 3e4 1c3
42e 92 :3 0 8f
:3 0 90 :3 0 3e7
3e8 0 91 :3 0
3e9 3ea 0 424
55 :3 0 56 :3 0
3ec 3ed 0 55
:3 0 66 :3 0 3ef
3f0 0 93 :2 0
2 :4 0 b0 :2 0
68 :2 0 20 :2 0
1c6 3f5 3f7 :3 0
1c9 3f1 3f9 3ee
3fb 3fa :2 0 58
:3 0 69 :3 0 3fd
3fe 0 5a :4 0
b1 :4 0 5d :2 0
5e :3 0 1cd 402
404 :3 0 5d :2 0
96 :4 0 1d0 406
408 :3 0 5d :2 0
97 :4 0 1d3 40a
40c :3 0 5d :2 0
91 :3 0 1d6 40e
410 :3 0 5d :2 0
98 :4 0 1d9 412
414 :3 0 5d :2 0
7e :3 0 99 :3 0
20 :2 0 9a :2 0
1dc 417 41b 1e0
416 41d :3 0 1e3
3ff 41f :2 0 421
1e6 422 3fc 421
0 423 1e8 0
424 1ea 427 :3 0
427 0 427 426
424 425 :6 0 429
8 :3 0 1ed 42b
1ef 42a 429 :2 0
42c 1f1 :2 0 42e
0 42e 42d 3e4
42c :6 0 465 1
:3 0 b2 :3 0 b3
:3 0 430 431 0
22 :3 0 b4 :4 0
1f3 432 435 9b
:2 0 24 :2 0 1f8
437 439 :3 0 c
:3 0 14 :3 0 43b
43c 0 462 55
:3 0 56 :3 0 43e
43f 0 55 :3 0
66 :3 0 441 442
0 20 :2 0 2
:4 0 b5 :2 0 68
:2 0 20 :2 0 1fb
447 449 :3 0 1fe
443 44b 440 44d
44c :2 0 58 :3 0
69 :3 0 44f 450
0 5a :4 0 b6
:4 0 5d :2 0 5e
:3 0 202 454 456
:3 0 205 451 458
:2 0 45a 208 45b
44e 45a 0 45c
20a 0 462 d
:3 0 41 :3 0 b7
:3 0 45e 45f 0
460 :2 0 462 20c
463 43a 462 0
464 210 0 465
212 466 3d8 465
0 467 215 0
640 b8 :3 0 2f
:3 0 b9 :3 0 ba
:3 0 a1 :3 0 8c
:3 0 bb :3 0 bc
:3 0 ba :3 0 bb
:3 0 6b :3 0 14
:3 0 bb :3 0 8a
:3 0 11 :3 0 bb
:3 0 8d :3 0 ba
:3 0 8d :3 0 ba
:3 0 8d :3 0 ba
:3 0 a1 :3 0 ba
:3 0 bd :3 0 41
:3 0 be :4 0 bf
1 :8 0 489 8f
:3 0 90 :3 0 484
485 0 91 :3 0
486 487 0 489
217 4d3 92 :3 0
8f :3 0 90 :3 0
48c 48d 0 91
:3 0 48e 48f 0
4c9 55 :3 0 56
:3 0 491 492 0
55 :3 0 66 :3 0
494 495 0 93
:2 0 2 :4 0 c0
:2 0 68 :2 0 20
:2 0 21a 49a 49c
:3 0 21d 496 49e
493 4a0 49f :2 0
58 :3 0 69 :3 0
4a2 4a3 0 5a
:4 0 c1 :4 0 5d
:2 0 5e :3 0 221
4a7 4a9 :3 0 5d
:2 0 96 :4 0 224
4ab 4ad :3 0 5d
:2 0 97 :4 0 227
4af 4b1 :3 0 5d
:2 0 91 :3 0 22a
4b3 4b5 :3 0 5d
:2 0 98 :4 0 22d
4b7 4b9 :3 0 5d
:2 0 7e :3 0 99
:3 0 20 :2 0 9a
:2 0 230 4bc 4c0
234 4bb 4c2 :3 0
237 4a4 4c4 :2 0
4c6 23a 4c7 4a1
4c6 0 4c8 23c
0 4c9 23e 4cc
:3 0 4cc 0 4cc
4cb 4c9 4ca :6 0
4ce a :3 0 241
4d0 243 4cf 4ce
:2 0 4d1 245 :2 0
4d3 0 4d3 4d2
489 4d1 :6 0 640
1 :3 0 62 :3 0
2f :3 0 24 :2 0
247 4d5 4d8 ad
:2 0 24 :2 0 24c
4da 4dc :3 0 c
:3 0 11 :3 0 4de
4df 0 505 55
:3 0 56 :3 0 4e1
4e2 0 55 :3 0
66 :3 0 4e4 4e5
0 20 :2 0 2
:4 0 c2 :2 0 68
:2 0 20 :2 0 24f
4ea 4ec :3 0 252
4e6 4ee 4e3 4f0
4ef :2 0 58 :3 0
69 :3 0 4f2 4f3
0 5a :4 0 c3
:4 0 5d :2 0 5e
:3 0 256 4f7 4f9
:3 0 259 4f4 4fb
:2 0 4fd 25c 4fe
4f1 4fd 0 4ff
25e 0 505 d
:3 0 41 :3 0 c4
:3 0 501 502 0
503 :2 0 505 260
506 4dd 505 0
507 264 0 640
62 :3 0 26 :3 0
24 :2 0 266 508
50b 9b :2 0 24
:2 0 26b 50d 50f
:3 0 55 :3 0 56
:3 0 511 512 0
55 :3 0 66 :3 0
514 515 0 c5
:2 0 2 :4 0 c6
:2 0 68 :2 0 20
:2 0 26e 51a 51c
:3 0 271 516 51e
513 520 51f :2 0
58 :3 0 69 :3 0
522 523 0 5a
:4 0 c7 :4 0 5d
:2 0 5e :3 0 275
527 529 :3 0 5d
:2 0 96 :4 0 278
52b 52d :3 0 5d
:2 0 c8 :4 0 27b
52f 531 :3 0 5d
:2 0 62 :3 0 63
:3 0 41 :3 0 c9
:3 0 536 537 0
27e 535 539 64
:4 0 280 534 53c
283 533 53e :3 0
286 524 540 :2 0
542 289 543 521
542 0 544 28b
0 570 55 :3 0
56 :3 0 545 546
0 55 :3 0 66
:3 0 548 549 0
20 :2 0 2 :4 0
ca :2 0 68 :2 0
20 :2 0 28d 54e
550 :3 0 290 54a
552 547 554 553
:2 0 58 :3 0 69
:3 0 556 557 0
5a :4 0 cb :4 0
5d :2 0 5e :3 0
294 55b 55d :3 0
297 558 55f :2 0
561 29a 562 555
561 0 563 29c
0 570 d :3 0
cc :3 0 cd :3 0
565 566 0 41
:3 0 c9 :3 0 568
569 0 ce :3 0
29e 567 56c 56d
:2 0 570 cf :3 0
2a1 63d 62 :3 0
f :3 0 24 :2 0
2a5 571 574 62
:3 0 d0 :2 0 29
:3 0 24 :2 0 2a8
576 57a 2ad 577
57c :3 0 3b :3 0
24 :2 0 57e 57f
0 5dc 62 :3 0
f :3 0 24 :2 0
2b0 581 584 62
:3 0 ad :2 0 26
:3 0 24 :2 0 2b3
586 58a 2b8 587
58c :3 0 c :3 0
11 :3 0 58e 58f
0 5b6 55 :3 0
56 :3 0 591 592
0 55 :3 0 66
:3 0 594 595 0
20 :2 0 2 :4 0
d1 :2 0 68 :2 0
20 :2 0 2bb 59a
59c :3 0 2be 596
59e 593 5a0 59f
:2 0 58 :3 0 69
:3 0 5a2 5a3 0
5a :4 0 d2 :4 0
5d :2 0 5e :3 0
2c2 5a7 5a9 :3 0
2c5 5a4 5ab :2 0
5ad 2c8 5ae 5a1
5ad 0 5af 2ca
0 5b6 d :3 0
41 :3 0 d3 :3 0
5b1 5b2 0 5b3
:2 0 5b6 cf :3 0
2cc 5c9 62 :3 0
f :3 0 24 :2 0
2d0 5b7 5ba 62
:3 0 9b :2 0 26
:3 0 24 :2 0 2d3
5bc 5c0 2d8 5bd
5c2 :3 0 3b :3 0
20 :2 0 5c4 5c5
0 5c7 2db 5c8
5c3 5c7 0 5ca
58d 5b6 0 5ca
2dd 0 5dc 2a
:3 0 f :3 0 5cb
5cc 0 5dc 2f
:3 0 d4 :3 0 14
:3 0 11 :3 0 2a
:3 0 b :3 0 62
:3 0 3b :3 0 24
:2 0 2e0 5d4 5d7
2e3 5cf 5d9 5ce
5da 0 5dc 2e9
5dd 57d 5dc 0
63f 55 :3 0 56
:3 0 5de 5df 0
55 :3 0 66 :3 0
5e1 5e2 0 c5
:2 0 2 :4 0 d5
:2 0 68 :2 0 20
:2 0 2ee 5e7 5e9
:3 0 2f1 5e3 5eb
5e0 5ed 5ec :2 0
58 :3 0 69 :3 0
5ef 5f0 0 5a
:4 0 d6 :4 0 5d
:2 0 5e :3 0 2f5
5f4 5f6 :3 0 5d
:2 0 96 :4 0 2f8
5f8 5fa :3 0 5d
:2 0 c8 :4 0 2fb
5fc 5fe :3 0 5d
:2 0 62 :3 0 63
:3 0 41 :3 0 c9
:3 0 603 604 0
2fe 602 606 64
:4 0 300 601 609
303 600 60b :3 0
306 5f1 60d :2 0
60f 309 610 5ee
60f 0 611 30b
0 63c 55 :3 0
56 :3 0 612 613
0 55 :3 0 66
:3 0 615 616 0
20 :2 0 2 :4 0
d7 :2 0 68 :2 0
20 :2 0 30d 61b
61d :3 0 310 617
61f 614 621 620
:2 0 58 :3 0 69
:3 0 623 624 0
5a :4 0 d8 :4 0
5d :2 0 5e :3 0
314 628 62a :3 0
317 625 62c :2 0
62e 31a 62f 622
62e 0 630 31c
0 63c d :3 0
cc :3 0 cd :3 0
632 633 0 41
:3 0 c9 :3 0 635
636 0 ce :3 0
31e 634 639 63a
:2 0 63c 321 63e
510 570 0 63f
0 63c 0 63f
325 0 640 329
11d8 62 :3 0 26
:3 0 24 :2 0 332
641 644 9b :2 0
24 :2 0 337 646
648 :3 0 c :3 0
11 :3 0 64a 64b
0 671 55 :3 0
56 :3 0 64d 64e
0 55 :3 0 66
:3 0 650 651 0
20 :2 0 2 :4 0
d9 :2 0 68 :2 0
20 :2 0 33a 656
658 :3 0 33d 652
65a 64f 65c 65b
:2 0 58 :3 0 69
:3 0 65e 65f 0
5a :4 0 da :4 0
5d :2 0 5e :3 0
341 663 665 :3 0
344 660 667 :2 0
669 347 66a 65d
669 0 66b 349
0 671 d :3 0
41 :3 0 c9 :3 0
66d 66e 0 66f
:2 0 671 34b 672
649 671 0 673
34f 0 11d7 2f
:3 0 24 :2 0 674
675 0 11d7 a8
:3 0 2f :3 0 a9
:3 0 6b :3 0 14
:4 0 aa 1 :8 0
682 8f :3 0 90
:3 0 67d 67e 0
91 :3 0 67f 680
0 682 351 6cc
92 :3 0 8f :3 0
90 :3 0 685 686
0 91 :3 0 687
688 0 6c2 55
:3 0 56 :3 0 68a
68b 0 55 :3 0
66 :3 0 68d 68e
0 93 :2 0 2
:4 0 db :2 0 68
:2 0 20 :2 0 354
693 695 :3 0 357
68f 697 68c 699
698 :2 0 58 :3 0
69 :3 0 69b 69c
0 5a :4 0 dc
:4 0 5d :2 0 5e
:3 0 35b 6a0 6a2
:3 0 5d :2 0 96
:4 0 35e 6a4 6a6
:3 0 5d :2 0 97
:4 0 361 6a8 6aa
:3 0 5d :2 0 91
:3 0 364 6ac 6ae
:3 0 5d :2 0 98
:4 0 367 6b0 6b2
:3 0 5d :2 0 7e
:3 0 99 :3 0 20
:2 0 9a :2 0 36a
6b5 6b9 36e 6b4
6bb :3 0 371 69d
6bd :2 0 6bf 374
6c0 69a 6bf 0
6c1 376 0 6c2
378 6c5 :3 0 6c5
0 6c5 6c4 6c2
6c3 :6 0 6c7 c
:3 0 37b 6c9 37d
6c8 6c7 :2 0 6ca
37f :2 0 6cc 0
6cc 6cb 682 6ca
:6 0 11d7 1 :3 0
62 :3 0 2f :3 0
24 :2 0 381 6ce
6d1 ad :2 0 24
:2 0 386 6d3 6d5
:3 0 ae :3 0 22
:3 0 a0 :3 0 a1
:3 0 14 :4 0 af
1 :8 0 6e2 8f
:3 0 90 :3 0 6dd
6de 0 91 :3 0
6df 6e0 0 6e2
389 72c 92 :3 0
8f :3 0 90 :3 0
6e5 6e6 0 91
:3 0 6e7 6e8 0
722 55 :3 0 56
:3 0 6ea 6eb 0
55 :3 0 66 :3 0
6ed 6ee 0 93
:2 0 2 :4 0 dd
:2 0 68 :2 0 20
:2 0 38c 6f3 6f5
:3 0 38f 6ef 6f7
6ec 6f9 6f8 :2 0
58 :3 0 69 :3 0
6fb 6fc 0 5a
:4 0 de :4 0 5d
:2 0 5e :3 0 393
700 702 :3 0 5d
:2 0 96 :4 0 396
704 706 :3 0 5d
:2 0 97 :4 0 399
708 70a :3 0 5d
:2 0 91 :3 0 39c
70c 70e :3 0 5d
:2 0 98 :4 0 39f
710 712 :3 0 5d
:2 0 7e :3 0 99
:3 0 20 :2 0 9a
:2 0 3a2 715 719
3a6 714 71b :3 0
3a9 6fd 71d :2 0
71f 3ac 720 6fa
71f 0 721 3ae
0 722 3b0 725
:3 0 725 0 725
724 722 723 :6 0
727 e :3 0 3b3
729 3b5 728 727
:2 0 72a 3b7 :2 0
72c 0 72c 72b
6e2 72a :6 0 763
1 :3 0 b2 :3 0
b3 :3 0 72e 72f
0 22 :3 0 b4
:4 0 3b9 730 733
9b :2 0 24 :2 0
3be 735 737 :3 0
c :3 0 14 :3 0
739 73a 0 760
55 :3 0 56 :3 0
73c 73d 0 55
:3 0 66 :3 0 73f
740 0 20 :2 0
2 :4 0 df :2 0
68 :2 0 20 :2 0
3c1 745 747 :3 0
3c4 741 749 73e
74b 74a :2 0 58
:3 0 69 :3 0 74d
74e 0 5a :4 0
e0 :4 0 5d :2 0
5e :3 0 3c8 752
754 :3 0 3cb 74f
756 :2 0 758 3ce
759 74c 758 0
75a 3d0 0 760
d :3 0 41 :3 0
b7 :3 0 75c 75d
0 75e :2 0 760
3d2 761 738 760
0 762 3d6 0
763 3d8 764 6d6
763 0 765 3db
0 11d7 b8 :3 0
2f :3 0 b9 :3 0
a1 :3 0 bc :3 0
8d :3 0 11 :3 0
8d :3 0 a1 :3 0
bd :3 0 41 :3 0
be :4 0 e1 1
:8 0 778 8f :3 0
90 :3 0 773 774
0 91 :3 0 775
776 0 778 3dd
7c2 92 :3 0 8f
:3 0 90 :3 0 77b
77c 0 91 :3 0
77d 77e 0 7b8
55 :3 0 56 :3 0
780 781 0 55
:3 0 66 :3 0 783
784 0 93 :2 0
2 :4 0 e2 :2 0
68 :2 0 20 :2 0
3e0 789 78b :3 0
3e3 785 78d 782
78f 78e :2 0 58
:3 0 69 :3 0 791
792 0 5a :4 0
e3 :4 0 5d :2 0
5e :3 0 3e7 796
798 :3 0 5d :2 0
96 :4 0 3ea 79a
79c :3 0 5d :2 0
97 :4 0 3ed 79e
7a0 :3 0 5d :2 0
91 :3 0 3f0 7a2
7a4 :3 0 5d :2 0
98 :4 0 3f3 7a6
7a8 :3 0 5d :2 0
7e :3 0 99 :3 0
20 :2 0 9a :2 0
3f6 7ab 7af 3fa
7aa 7b1 :3 0 3fd
793 7b3 :2 0 7b5
400 7b6 790 7b5
0 7b7 402 0
7b8 404 7bb :3 0
7bb 0 7bb 7ba
7b8 7b9 :6 0 7bd
10 :3 0 407 7bf
409 7be 7bd :2 0
7c0 40b :2 0 7c2
0 7c2 7c1 778
7c0 :6 0 11d7 1
:3 0 62 :3 0 2f
:3 0 24 :2 0 40d
7c4 7c7 ad :2 0
24 :2 0 412 7c9
7cb :3 0 c :3 0
11 :3 0 7cd 7ce
0 7f4 55 :3 0
56 :3 0 7d0 7d1
0 55 :3 0 66
:3 0 7d3 7d4 0
20 :2 0 2 :4 0
e4 :2 0 68 :2 0
20 :2 0 415 7d9
7db :3 0 418 7d5
7dd 7d2 7df 7de
:2 0 58 :3 0 69
:3 0 7e1 7e2 0
5a :4 0 e5 :4 0
5d :2 0 5e :3 0
41c 7e6 7e8 :3 0
41f 7e3 7ea :2 0
7ec 422 7ed 7e0
7ec 0 7ee 424
0 7f4 d :3 0
41 :3 0 c4 :3 0
7f0 7f1 0 7f2
:2 0 7f4 426 7f5
7cc 7f4 0 7f6
42a 0 11d7 6b
:3 0 e6 :3 0 14
:3 0 2c :3 0 a0
:3 0 6b :3 0 14
:3 0 a1 :3 0 15
:4 0 e7 1 :8 0
806 8f :3 0 90
:3 0 801 802 0
91 :3 0 803 804
0 806 42c 850
92 :3 0 8f :3 0
90 :3 0 809 80a
0 91 :3 0 80b
80c 0 846 55
:3 0 56 :3 0 80e
80f 0 55 :3 0
66 :3 0 811 812
0 93 :2 0 2
:4 0 e8 :2 0 68
:2 0 20 :2 0 42f
817 819 :3 0 432
813 81b 810 81d
81c :2 0 58 :3 0
69 :3 0 81f 820
0 5a :4 0 e9
:4 0 5d :2 0 5e
:3 0 436 824 826
:3 0 5d :2 0 96
:4 0 439 828 82a
:3 0 5d :2 0 97
:4 0 43c 82c 82e
:3 0 5d :2 0 91
:3 0 43f 830 832
:3 0 5d :2 0 98
:4 0 442 834 836
:3 0 5d :2 0 7e
:3 0 99 :3 0 20
:2 0 9a :2 0 445
839 83d 449 838
83f :3 0 44c 821
841 :2 0 843 44f
844 81e 843 0
845 451 0 846
453 849 :3 0 849
0 849 848 846
847 :6 0 84b 12
:3 0 456 84d 458
84c 84b :2 0 84e
45a :2 0 850 0
850 84f 806 84e
:6 0 11d7 1 :3 0
38 :3 0 62 :3 0
26 :3 0 24 :2 0
45c 853 856 852
857 0 11d7 62
:3 0 f :3 0 24
:2 0 45f 859 85c
62 :3 0 d0 :2 0
29 :3 0 24 :2 0
462 85e 862 467
85f 864 :3 0 2a
:3 0 f :3 0 866
867 0 e45 62
:3 0 2a :3 0 24
:2 0 46a 869 86c
62 :3 0 ad :2 0
26 :3 0 24 :2 0
46d 86e 872 472
86f 874 :3 0 2e
:3 0 ea :2 0 20
:2 0 475 877 879
:3 0 876 87a 0
dd9 2f :3 0 eb
:3 0 14 :3 0 15
:3 0 11 :3 0 17
:3 0 19 :3 0 46
:3 0 48 :3 0 2e
:3 0 25 :3 0 23
:3 0 477 87d 888
87c 889 0 dd9
62 :3 0 2f :3 0
24 :2 0 482 88b
88e 9b :2 0 24
:2 0 487 890 892
:3 0 62 :3 0 3c
:3 0 24 :2 0 48a
894 897 62 :3 0
d0 :2 0 3a :3 0
24 :2 0 48d 899
89d 492 89a 89f
:3 0 b2 :3 0 b3
:3 0 8a1 8a2 0
16 :3 0 b :3 0
495 8a3 8a6 9b
:2 0 24 :2 0 49a
8a8 8aa :3 0 26
:3 0 62 :3 0 2a
:3 0 24 :2 0 49d
8ad 8b0 ea :2 0
62 :3 0 26 :3 0
24 :2 0 4a0 8b3
8b6 4a3 8b2 8b8
:3 0 8ac 8b9 0
9e5 27 :3 0 ec
:2 0 8bb 8bc 0
9e5 62 :3 0 2a
:3 0 24 :2 0 4a6
8be 8c1 ed :2 0
62 :3 0 29 :3 0
24 :2 0 4a9 8c4
8c7 68 :2 0 62
:3 0 3a :3 0 24
:2 0 4ac 8ca 8cd
4af 8c9 8cf :3 0
8d0 :2 0 4b4 8c3
8d2 :3 0 3a :3 0
62 :3 0 29 :3 0
24 :2 0 4b7 8d5
8d8 68 :2 0 62
:3 0 3a :3 0 24
:2 0 4ba 8db 8de
4bd 8da 8e0 :3 0
8e1 :2 0 ea :2 0
62 :3 0 2a :3 0
24 :2 0 4c0 8e4
8e7 4c3 8e3 8e9
:3 0 8d4 8ea 0
96e 8c :3 0 ee
:3 0 8b :3 0 ef
:3 0 f0 :3 0 8b
:3 0 41 :3 0 f1
:3 0 71 :3 0 2a
:3 0 70 :3 0 2a
:3 0 72 :3 0 3a
:3 0 89 :3 0 8d
:3 0 11 :4 0 f2
1 :8 0 913 f3
:4 0 8fe :3 0 f4
:3 0 9b :2 0 4c8
901 902 :3 0 8f
:3 0 90 :3 0 904
905 0 24 :2 0
906 907 0 909
4cb 910 8f :3 0
90 :3 0 90a 90b
0 f5 :2 0 90c
90d 0 90f 4cd
911 903 909 0
912 0 90f 0
912 4cf 0 913
4d2 95d 92 :3 0
8f :3 0 90 :3 0
916 917 0 91
:3 0 918 919 0
953 55 :3 0 56
:3 0 91b 91c 0
55 :3 0 66 :3 0
91e 91f 0 93
:2 0 2 :4 0 f6
:2 0 68 :2 0 20
:2 0 4d5 924 926
:3 0 4d8 920 928
91d 92a 929 :2 0
58 :3 0 69 :3 0
92c 92d 0 5a
:4 0 f7 :4 0 5d
:2 0 5e :3 0 4dc
931 933 :3 0 5d
:2 0 96 :4 0 4df
935 937 :3 0 5d
:2 0 97 :4 0 4e2
939 93b :3 0 5d
:2 0 91 :3 0 4e5
93d 93f :3 0 5d
:2 0 98 :4 0 4e8
941 943 :3 0 5d
:2 0 7e :3 0 99
:3 0 20 :2 0 9a
:2 0 4eb 946 94a
4ef 945 94c :3 0
4f2 92e 94e :2 0
950 4f5 951 92b
950 0 952 4f7
0 953 4f9 956
:3 0 956 0 956
955 953 954 :6 0
958 14 :3 0 4fc
95a 4fe 959 958
:2 0 95b 500 :2 0
95d 0 95d 95c
913 95b :6 0 96e
1 :3 0 27 :3 0
f8 :3 0 f0 :3 0
960 961 0 62
:3 0 27 :3 0 24
:2 0 502 963 966
41 :3 0 f9 :3 0
968 969 0 505
962 96b 95f 96c
0 96e 508 9e2
8c :3 0 ee :3 0
8b :3 0 ef :3 0
f0 :3 0 8b :3 0
41 :3 0 f1 :3 0
71 :3 0 2a :3 0
70 :3 0 2a :3 0
72 :3 0 89 :3 0
8d :3 0 11 :4 0
fa 1 :8 0 995
f3 :4 0 980 :3 0
f4 :3 0 9b :2 0
50e 983 984 :3 0
8f :3 0 90 :3 0
986 987 0 24
:2 0 988 989 0
98b 511 992 8f
:3 0 90 :3 0 98c
98d 0 f5 :2 0
98e 98f 0 991
513 993 985 98b
0 994 0 991
0 994 515 0
995 518 9df 92
:3 0 8f :3 0 90
:3 0 998 999 0
91 :3 0 99a 99b
0 9d5 55 :3 0
56 :3 0 99d 99e
0 55 :3 0 66
:3 0 9a0 9a1 0
93 :2 0 2 :4 0
fb :2 0 68 :2 0
20 :2 0 51b 9a6
9a8 :3 0 51e 9a2
9aa 99f 9ac 9ab
:2 0 58 :3 0 69
:3 0 9ae 9af 0
5a :4 0 fc :4 0
5d :2 0 5e :3 0
522 9b3 9b5 :3 0
5d :2 0 96 :4 0
525 9b7 9b9 :3 0
5d :2 0 97 :4 0
528 9bb 9bd :3 0
5d :2 0 91 :3 0
52b 9bf 9c1 :3 0
5d :2 0 98 :4 0
52e 9c3 9c5 :3 0
5d :2 0 7e :3 0
99 :3 0 20 :2 0
9a :2 0 531 9c8
9cc 535 9c7 9ce
:3 0 538 9b0 9d0
:2 0 9d2 53b 9d3
9ad 9d2 0 9d4
53d 0 9d5 53f
9d8 :3 0 9d8 0
9d8 9d7 9d5 9d6
:6 0 9da 16 :3 0
542 9dc 544 9db
9da :2 0 9dd 546
:2 0 9df 0 9df
9de 995 9dd :6 0
9e1 1 :3 0 548
9e3 8d3 96e 0
9e4 0 9e1 0
9e4 54a 0 9e5
54d b21 62 :3 0
2a :3 0 24 :2 0
551 9e6 9e9 ed
:2 0 62 :3 0 29
:3 0 24 :2 0 554
9ec 9ef 68 :2 0
62 :3 0 3a :3 0
24 :2 0 557 9f2
9f5 55a 9f1 9f7
:3 0 9f8 :2 0 55f
9eb 9fa :3 0 26
:3 0 62 :3 0 3a
:3 0 24 :2 0 562
9fd a00 ea :2 0
62 :3 0 26 :3 0
24 :2 0 565 a03
a06 568 a02 a08
:3 0 9fc a09 0
a97 27 :3 0 fd
:3 0 62 :3 0 2a
:3 0 24 :2 0 56b
a0d a10 fe :2 0
62 :3 0 26 :3 0
24 :2 0 56e a13
a16 571 a12 a18
:3 0 a19 :2 0 ff
:2 0 100 :2 0 574
a1b a1d :3 0 a1e
:2 0 68 :2 0 101
:2 0 577 a20 a22
:3 0 57a a0c a24
a0b a25 0 a97
8c :3 0 ee :3 0
8b :3 0 ef :3 0
f0 :3 0 8b :3 0
41 :3 0 f1 :3 0
71 :3 0 3a :3 0
70 :3 0 2a :3 0
8d :3 0 11 :4 0
102 1 :8 0 a4b
f3 :4 0 a36 :3 0
f4 :3 0 9b :2 0
57e a39 a3a :3 0
8f :3 0 90 :3 0
a3c a3d 0 24
:2 0 a3e a3f 0
a41 581 a48 8f
:3 0 90 :3 0 a42
a43 0 f5 :2 0
a44 a45 0 a47
583 a49 a3b a41
0 a4a 0 a47
0 a4a 585 0
a4b 588 a95 92
:3 0 8f :3 0 90
:3 0 a4e a4f 0
91 :3 0 a50 a51
0 a8b 55 :3 0
56 :3 0 a53 a54
0 55 :3 0 66
:3 0 a56 a57 0
93 :2 0 2 :4 0
103 :2 0 68 :2 0
20 :2 0 58b a5c
a5e :3 0 58e a58
a60 a55 a62 a61
:2 0 58 :3 0 69
:3 0 a64 a65 0
5a :4 0 104 :4 0
5d :2 0 5e :3 0
592 a69 a6b :3 0
5d :2 0 96 :4 0
595 a6d a6f :3 0
5d :2 0 97 :4 0
598 a71 a73 :3 0
5d :2 0 91 :3 0
59b a75 a77 :3 0
5d :2 0 98 :4 0
59e a79 a7b :3 0
5d :2 0 7e :3 0
99 :3 0 20 :2 0
9a :2 0 5a1 a7e
a82 5a5 a7d a84
:3 0 5a8 a66 a86
:2 0 a88 5ab a89
a63 a88 0 a8a
5ad 0 a8b 5af
a8e :3 0 a8e 0
a8e a8d a8b a8c
:6 0 a90 18 :3 0
5b2 a92 5b4 a91
a90 :2 0 a93 5b6
:2 0 a95 0 a95
a94 a4b a93 :6 0
a97 1 :3 0 5b8
b1d 26 :3 0 62
:3 0 2a :3 0 24
:2 0 5bc a99 a9c
ea :2 0 62 :3 0
26 :3 0 24 :2 0
5bf a9f aa2 5c2
a9e aa4 :3 0 a98
aa5 0 b1c 27
:3 0 ec :2 0 aa7
aa8 0 b1c 8c
:3 0 ee :3 0 8b
:3 0 ef :3 0 f0
:3 0 8b :3 0 41
:3 0 f1 :3 0 71
:3 0 2a :3 0 70
:3 0 2a :3 0 72
:3 0 89 :3 0 8d
:3 0 11 :4 0 fa
1 :8 0 ad0 f3
:4 0 abb :3 0 f4
:3 0 9b :2 0 5c7
abe abf :3 0 8f
:3 0 90 :3 0 ac1
ac2 0 24 :2 0
ac3 ac4 0 ac6
5ca acd 8f :3 0
90 :3 0 ac7 ac8
0 f5 :2 0 ac9
aca 0 acc 5cc
ace ac0 ac6 0
acf 0 acc 0
acf 5ce 0 ad0
5d1 b1a 92 :3 0
8f :3 0 90 :3 0
ad3 ad4 0 91
:3 0 ad5 ad6 0
b10 55 :3 0 56
:3 0 ad8 ad9 0
55 :3 0 66 :3 0
adb adc 0 93
:2 0 2 :4 0 105
:2 0 68 :2 0 20
:2 0 5d4 ae1 ae3
:3 0 5d7 add ae5
ada ae7 ae6 :2 0
58 :3 0 69 :3 0
ae9 aea 0 5a
:4 0 106 :4 0 5d
:2 0 5e :3 0 5db
aee af0 :3 0 5d
:2 0 96 :4 0 5de
af2 af4 :3 0 5d
:2 0 97 :4 0 5e1
af6 af8 :3 0 5d
:2 0 91 :3 0 5e4
afa afc :3 0 5d
:2 0 98 :4 0 5e7
afe b00 :3 0 5d
:2 0 7e :3 0 99
:3 0 20 :2 0 9a
:2 0 5ea b03 b07
5ee b02 b09 :3 0
5f1 aeb b0b :2 0
b0d 5f4 b0e ae8
b0d 0 b0f 5f6
0 b10 5f8 b13
:3 0 b13 0 b13
b12 b10 b11 :6 0
b15 1a :3 0 5fb
b17 5fd b16 b15
:2 0 b18 5ff :2 0
b1a 0 b1a b19
ad0 b18 :6 0 b1c
1 :3 0 601 b1e
9fb a97 0 b1f
0 b1c 0 b1f
605 0 b20 608
b22 8ab 9e5 0
b23 0 b20 0
b23 60a 0 b24
60d baa 26 :3 0
62 :3 0 2a :3 0
24 :2 0 60f b26
b29 ea :2 0 62
:3 0 29 :3 0 24
:2 0 612 b2c b2f
615 b2b b31 :3 0
b25 b32 0 ba9
27 :3 0 ec :2 0
b34 b35 0 ba9
8c :3 0 ee :3 0
8b :3 0 ef :3 0
f0 :3 0 8b :3 0
41 :3 0 f1 :3 0
71 :3 0 2a :3 0
70 :3 0 2a :3 0
72 :3 0 89 :3 0
8d :3 0 11 :4 0
107 1 :8 0 b5d
f3 :4 0 b48 :3 0
f4 :3 0 9b :2 0
61a b4b b4c :3 0
8f :3 0 90 :3 0
b4e b4f 0 24
:2 0 b50 b51 0
b53 61d b5a 8f
:3 0 90 :3 0 b54
b55 0 f5 :2 0
b56 b57 0 b59
61f b5b b4d b53
0 b5c 0 b59
0 b5c 621 0
b5d 624 ba7 92
:3 0 8f :3 0 90
:3 0 b60 b61 0
91 :3 0 b62 b63
0 b9d 55 :3 0
56 :3 0 b65 b66
0 55 :3 0 66
:3 0 b68 b69 0
93 :2 0 2 :4 0
108 :2 0 68 :2 0
20 :2 0 627 b6e
b70 :3 0 62a b6a
b72 b67 b74 b73
:2 0 58 :3 0 69
:3 0 b76 b77 0
5a :4 0 109 :4 0
5d :2 0 5e :3 0
62e b7b b7d :3 0
5d :2 0 96 :4 0
631 b7f b81 :3 0
5d :2 0 97 :4 0
634 b83 b85 :3 0
5d :2 0 91 :3 0
637 b87 b89 :3 0
5d :2 0 98 :4 0
63a b8b b8d :3 0
5d :2 0 7e :3 0
99 :3 0 20 :2 0
9a :2 0 63d b90
b94 641 b8f b96
:3 0 644 b78 b98
:2 0 b9a 647 b9b
b75 b9a 0 b9c
649 0 b9d 64b
ba0 :3 0 ba0 0
ba0 b9f b9d b9e
:6 0 ba2 1c :3 0
64e ba4 650 ba3
ba2 :2 0 ba5 652
:2 0 ba7 0 ba7
ba6 b5d ba5 :6 0
ba9 1 :3 0 654
bab 8a0 b24 0
bac 0 ba9 0
bac 658 0 dd6
1d :3 0 10a :2 0
65b bae baf :3 0
bb0 :2 0 1e :4 0
bb2 bb3 0 d56
10b :3 0 10c :3 0
1e :3 0 10d :3 0
a1 :3 0 14 :3 0
6c :3 0 16 :4 0
10e 1 :8 0 bc3
8f :3 0 90 :3 0
bbe bbf 0 91
:3 0 bc0 bc1 0
bc3 65d c0d 92
:3 0 8f :3 0 90
:3 0 bc6 bc7 0
91 :3 0 bc8 bc9
0 c03 55 :3 0
56 :3 0 bcb bcc
0 55 :3 0 66
:3 0 bce bcf 0
93 :2 0 2 :4 0
10f :2 0 68 :2 0
20 :2 0 660 bd4
bd6 :3 0 663 bd0
bd8 bcd bda bd9
:2 0 58 :3 0 69
:3 0 bdc bdd 0
5a :4 0 110 :4 0
5d :2 0 5e :3 0
667 be1 be3 :3 0
5d :2 0 96 :4 0
66a be5 be7 :3 0
5d :2 0 97 :4 0
66d be9 beb :3 0
5d :2 0 91 :3 0
670 bed bef :3 0
5d :2 0 98 :4 0
673 bf1 bf3 :3 0
5d :2 0 7e :3 0
99 :3 0 20 :2 0
9a :2 0 676 bf6
bfa 67a bf5 bfc
:3 0 67d bde bfe
:2 0 c00 680 c01
bdb c00 0 c02
682 0 c03 684
c06 :3 0 c06 0
c06 c05 c03 c04
:6 0 c08 1e :3 0
687 c0a 689 c09
c08 :2 0 c0b 68b
:2 0 c0d 0 c0d
c0c bc3 c0b :6 0
d56 1 :3 0 1e
:3 0 10a :2 0 68d
c10 c11 :3 0 c12
:2 0 7d :3 0 7e
:3 0 1e :3 0 1e
:3 0 b9 :4 0 111
1 :8 0 c1f 8f
:3 0 90 :3 0 c1a
c1b 0 91 :3 0
c1c c1d 0 c1f
68f c69 92 :3 0
8f :3 0 90 :3 0
c22 c23 0 91
:3 0 c24 c25 0
c5f 55 :3 0 56
:3 0 c27 c28 0
55 :3 0 66 :3 0
c2a c2b 0 93
:2 0 2 :4 0 112
:2 0 68 :2 0 20
:2 0 692 c30 c32
:3 0 695 c2c c34
c29 c36 c35 :2 0
58 :3 0 69 :3 0
c38 c39 0 5a
:4 0 113 :4 0 5d
:2 0 5e :3 0 699
c3d c3f :3 0 5d
:2 0 96 :4 0 69c
c41 c43 :3 0 5d
:2 0 97 :4 0 69f
c45 c47 :3 0 5d
:2 0 91 :3 0 6a2
c49 c4b :3 0 5d
:2 0 98 :4 0 6a5
c4d c4f :3 0 5d
:2 0 7e :3 0 99
:3 0 20 :2 0 9a
:2 0 6a8 c52 c56
6ac c51 c58 :3 0
6af c3a c5a :2 0
c5c 6b2 c5d c37
c5c 0 c5e 6b4
0 c5f 6b6 c62
:3 0 c62 0 c62
c61 c5f c60 :6 0
c64 20 :3 0 6b9
c66 6bb c65 c64
:2 0 c67 6bd :2 0
c69 0 c69 c68
c1f c67 :6 0 c7e
1 :3 0 b2 :3 0
114 :3 0 c6b c6c
0 1d :3 0 1e
:3 0 115 :2 0 6bf
c6d c71 ed :2 0
24 :2 0 6c5 c73
c75 :3 0 1a :3 0
1e :3 0 c77 c78
0 c7a 6c8 c7b
c76 c7a 0 c7c
6ca 0 c7e cf
:3 0 6cc d53 62
:3 0 32 :3 0 24
:2 0 6cf c7f c82
ad :2 0 24 :2 0
6d4 c84 c86 :3 0
32 :3 0 f8 :3 0
f0 :3 0 c89 c8a
0 62 :3 0 32
:3 0 24 :2 0 6d7
c8c c8f 41 :3 0
f9 :3 0 c91 c92
0 6da c8b c94
c95 :2 0 c88 c96
0 cf4 b2 :3 0
116 :3 0 7d :3 0
7e :3 0 1d :3 0
b2 :3 0 117 :3 0
1a :3 0 1a :3 0
b9 :4 0 118 1
:8 0 ca8 8f :3 0
90 :3 0 ca3 ca4
0 91 :3 0 ca5
ca6 0 ca8 6dd
cf2 92 :3 0 8f
:3 0 90 :3 0 cab
cac 0 91 :3 0
cad cae 0 ce8
55 :3 0 56 :3 0
cb0 cb1 0 55
:3 0 66 :3 0 cb3
cb4 0 93 :2 0
2 :4 0 119 :2 0
68 :2 0 20 :2 0
6e0 cb9 cbb :3 0
6e3 cb5 cbd cb2
cbf cbe :2 0 58
:3 0 69 :3 0 cc1
cc2 0 5a :4 0
11a :4 0 5d :2 0
5e :3 0 6e7 cc6
cc8 :3 0 5d :2 0
96 :4 0 6ea cca
ccc :3 0 5d :2 0
97 :4 0 6ed cce
cd0 :3 0 5d :2 0
91 :3 0 6f0 cd2
cd4 :3 0 5d :2 0
98 :4 0 6f3 cd6
cd8 :3 0 5d :2 0
7e :3 0 99 :3 0
20 :2 0 9a :2 0
6f6 cdb cdf 6fa
cda ce1 :3 0 6fd
cc3 ce3 :2 0 ce5
700 ce6 cc0 ce5
0 ce7 702 0
ce8 704 ceb :3 0
ceb 0 ceb cea
ce8 ce9 :6 0 ced
22 :3 0 707 cef
709 cee ced :2 0
cf0 70b :2 0 cf2
0 cf2 cf1 ca8
cf0 :6 0 cf4 1
:3 0 70d cf5 c87
cf4 0 d55 b2
:3 0 116 :3 0 7d
:3 0 7e :3 0 1d
:3 0 b2 :3 0 117
:3 0 1a :3 0 1a
:3 0 b9 :4 0 11b
1 :8 0 d06 8f
:3 0 90 :3 0 d01
d02 0 91 :3 0
d03 d04 0 d06
710 d50 92 :3 0
8f :3 0 90 :3 0
d09 d0a 0 91
:3 0 d0b d0c 0
d46 55 :3 0 56
:3 0 d0e d0f 0
55 :3 0 66 :3 0
d11 d12 0 93
:2 0 2 :4 0 11c
:2 0 68 :2 0 20
:2 0 713 d17 d19
:3 0 716 d13 d1b
d10 d1d d1c :2 0
58 :3 0 69 :3 0
d1f d20 0 5a
:4 0 11d :4 0 5d
:2 0 5e :3 0 71a
d24 d26 :3 0 5d
:2 0 96 :4 0 71d
d28 d2a :3 0 5d
:2 0 97 :4 0 720
d2c d2e :3 0 5d
:2 0 91 :3 0 723
d30 d32 :3 0 5d
:2 0 98 :4 0 726
d34 d36 :3 0 5d
:2 0 7e :3 0 99
:3 0 20 :2 0 9a
:2 0 729 d39 d3d
72d d38 d3f :3 0
730 d21 d41 :2 0
d43 733 d44 d1e
d43 0 d45 735
0 d46 737 d49
:3 0 d49 0 d49
d48 d46 d47 :6 0
d4b 24 :3 0 73a
d4d 73c d4c d4b
:2 0 d4e 73e :2 0
d50 0 d50 d4f
d06 d4e :6 0 d52
1 :3 0 740 d54
c13 c7e 0 d55
0 d52 0 d55
742 0 d56 746
d57 bb1 d56 0
d58 74a 0 dd6
13 :3 0 10a :2 0
74c d5a d5b :3 0
d5c :2 0 2f :3 0
11e :3 0 14 :3 0
11 :3 0 11f :2 0
74e d5f d63 d5e
d64 0 d66 752
d87 7e :3 0 1f
:3 0 20 :2 0 20
:2 0 754 d67 d6b
9b :2 0 11f :4 0
75a d6d d6f :3 0
2f :3 0 11e :3 0
14 :3 0 11 :3 0
24 :2 0 75d d72
d76 d71 d77 0
d79 761 d83 2f
:3 0 11e :3 0 14
:3 0 11 :3 0 20
:2 0 763 d7b d7f
d7a d80 0 d82
767 d84 d70 d79
0 d85 0 d82
0 d85 769 0
d86 76c d88 d5d
d66 0 d89 0
d86 0 d89 76e
0 dd6 2f :3 0
11f :2 0 d8a d8b
0 dd6 2f :3 0
120 :3 0 11 :3 0
1a :3 0 26 :3 0
2f :3 0 32 :3 0
b :3 0 24 :2 0
62 :3 0 28 :3 0
24 :2 0 771 d96
d99 774 d8e d9b
d8d d9c 0 dd6
62 :3 0 2f :3 0
24 :2 0 77d d9e
da1 d0 :2 0 24
:2 0 782 da3 da5
:3 0 c :3 0 11
:3 0 da7 da8 0
dd0 55 :3 0 56
:3 0 daa dab 0
55 :3 0 66 :3 0
dad dae 0 20
:2 0 2 :4 0 121
:2 0 68 :2 0 20
:2 0 785 db3 db5
:3 0 788 daf db7
dac db9 db8 :2 0
58 :3 0 69 :3 0
dbb dbc 0 5a
:4 0 122 :4 0 5d
:2 0 5e :3 0 78c
dc0 dc2 :3 0 78f
dbd dc4 :2 0 dc6
792 dc7 dba dc6
0 dc8 794 0
dd0 d :3 0 62
:3 0 2f :3 0 24
:2 0 796 dca dcd
dce :2 0 dd0 799
dd1 da6 dd0 0
dd2 79d 0 dd6
26 :3 0 2a :3 0
dd3 dd4 0 dd6
79f dd7 893 dd6
0 dd8 7a7 0
dd9 7a9 df7 27
:3 0 fd :3 0 62
:3 0 2a :3 0 24
:2 0 7ad ddc ddf
fe :2 0 62 :3 0
26 :3 0 24 :2 0
7b0 de2 de5 7b3
de1 de7 :3 0 de8
:2 0 ff :2 0 100
:2 0 7b6 dea dec
:3 0 ded :2 0 68
:2 0 101 :2 0 7b9
def df1 :3 0 7bc
ddb df3 dda df4
0 df6 7be df8
875 dd9 0 df9
0 df6 0 df9
7c0 0 e45 2f
:3 0 123 :3 0 14
:3 0 15 :3 0 16
:3 0 11 :3 0 1d
:3 0 1f :3 0 26
:3 0 2a :3 0 38
:3 0 29 :3 0 27
:3 0 46 :3 0 49
:3 0 48 :3 0 4a
:3 0 4b :3 0 4d
:3 0 4c :3 0 4e
:3 0 25 :3 0 23
:3 0 2b :3 0 b
:3 0 62 :3 0 2c
:3 0 24 :2 0 7c3
e13 e16 7c6 dfb
e18 dfa e19 0
e45 c :3 0 11
:3 0 e1b e1c 0
e45 55 :3 0 56
:3 0 e1e e1f 0
55 :3 0 66 :3 0
e21 e22 0 20
:2 0 2 :4 0 124
:2 0 68 :2 0 20
:2 0 7df e27 e29
:3 0 7e2 e23 e2b
e20 e2d e2c :2 0
58 :3 0 69 :3 0
e2f e30 0 5a
:4 0 125 :4 0 5d
:2 0 5e :3 0 7e6
e34 e36 :3 0 7e9
e31 e38 :2 0 e3a
7ec e3b e2e e3a
0 e3c 7ee 0
e45 d :3 0 62
:3 0 2f :3 0 24
:2 0 7f0 e3e e41
e42 :2 0 e45 cf
:3 0 7f3 11d5 62
:3 0 e :3 0 24
:2 0 7fa e46 e49
62 :3 0 d0 :2 0
27 :3 0 24 :2 0
7fd e4b e4f 802
e4c e51 :3 0 8c
:3 0 89 :3 0 e
:3 0 8b :3 0 ef
:3 0 f0 :3 0 8b
:3 0 41 :3 0 126
:3 0 8d :3 0 11
:4 0 127 1 :8 0
e74 f3 :4 0 e5f
:3 0 f4 :3 0 9b
:2 0 807 e62 e63
:3 0 8f :3 0 90
:3 0 e65 e66 0
24 :2 0 e67 e68
0 e6a 80a e71
8f :3 0 90 :3 0
e6b e6c 0 f5
:2 0 e6d e6e 0
e70 80c e72 e64
e6a 0 e73 0
e70 0 e73 80e
0 e74 811 ebe
92 :3 0 8f :3 0
90 :3 0 e77 e78
0 91 :3 0 e79
e7a 0 eb4 55
:3 0 56 :3 0 e7c
e7d 0 55 :3 0
66 :3 0 e7f e80
0 93 :2 0 2
:4 0 128 :2 0 68
:2 0 20 :2 0 814
e85 e87 :3 0 817
e81 e89 e7e e8b
e8a :2 0 58 :3 0
69 :3 0 e8d e8e
0 5a :4 0 129
:4 0 5d :2 0 5e
:3 0 81b e92 e94
:3 0 5d :2 0 96
:4 0 81e e96 e98
:3 0 5d :2 0 97
:4 0 821 e9a e9c
:3 0 5d :2 0 91
:3 0 824 e9e ea0
:3 0 5d :2 0 98
:4 0 827 ea2 ea4
:3 0 5d :2 0 7e
:3 0 99 :3 0 20
:2 0 9a :2 0 82a
ea7 eab 82e ea6
ead :3 0 831 e8f
eaf :2 0 eb1 834
eb2 e8c eb1 0
eb3 836 0 eb4
838 eb7 :3 0 eb7
0 eb7 eb6 eb4
eb5 :6 0 eb9 26
:3 0 83b ebb 83d
eba eb9 :2 0 ebc
83f :2 0 ebe 0
ebe ebd e74 ebc
:6 0 f2e 1 :3 0
a0 :3 0 8b :3 0
ef :3 0 f0 :3 0
8b :3 0 41 :3 0
126 :3 0 6b :3 0
14 :3 0 a1 :3 0
15 :4 0 12a 1
:8 0 ee1 f3 :4 0
ecc :3 0 f4 :3 0
9b :2 0 843 ecf
ed0 :3 0 8f :3 0
90 :3 0 ed2 ed3
0 24 :2 0 ed4
ed5 0 ed7 846
ede 8f :3 0 90
:3 0 ed8 ed9 0
f5 :2 0 eda edb
0 edd 848 edf
ed1 ed7 0 ee0
0 edd 0 ee0
84a 0 ee1 84d
f2b 92 :3 0 8f
:3 0 90 :3 0 ee4
ee5 0 91 :3 0
ee6 ee7 0 f21
55 :3 0 56 :3 0
ee9 eea 0 55
:3 0 66 :3 0 eec
eed 0 93 :2 0
2 :4 0 12b :2 0
68 :2 0 20 :2 0
850 ef2 ef4 :3 0
853 eee ef6 eeb
ef8 ef7 :2 0 58
:3 0 69 :3 0 efa
efb 0 5a :4 0
12c :4 0 5d :2 0
5e :3 0 857 eff
f01 :3 0 5d :2 0
96 :4 0 85a f03
f05 :3 0 5d :2 0
97 :4 0 85d f07
f09 :3 0 5d :2 0
91 :3 0 860 f0b
f0d :3 0 5d :2 0
98 :4 0 863 f0f
f11 :3 0 5d :2 0
7e :3 0 99 :3 0
20 :2 0 9a :2 0
866 f14 f18 86a
f13 f1a :3 0 86d
efc f1c :2 0 f1e
870 f1f ef9 f1e
0 f20 872 0
f21 874 f24 :3 0
f24 0 f24 f23
f21 f22 :6 0 f26
28 :3 0 877 f28
879 f27 f26 :2 0
f29 87b :2 0 f2b
0 f2b f2a ee1
f29 :6 0 f2e 1
:3 0 cf :3 0 87d
f2f e52 f2e 0
11d6 62 :3 0 10
:3 0 24 :2 0 880
f30 f33 62 :3 0
d0 :2 0 28 :3 0
24 :2 0 883 f35
f39 888 f36 f3b
:3 0 62 :3 0 10
:3 0 24 :2 0 88b
f3d f40 9b :2 0
24 :2 0 890 f42
f44 :3 0 28 :3 0
f5 :2 0 f46 f47
0 f49 893 f92
62 :3 0 10 :3 0
24 :2 0 895 f4a
f4d ed :2 0 20
:2 0 89a f4f f51
:3 0 f52 :2 0 62
:3 0 10 :3 0 24
:2 0 89d f54 f57
ad :2 0 12d :2 0
8a2 f59 f5b :3 0
f5c :2 0 f53 f5e
f5d :2 0 c :3 0
11 :3 0 f60 f61
0 f87 55 :3 0
56 :3 0 f63 f64
0 55 :3 0 66
:3 0 f66 f67 0
20 :2 0 2 :4 0
12e :2 0 68 :2 0
20 :2 0 8a5 f6c
f6e :3 0 8a8 f68
f70 f65 f72 f71
:2 0 58 :3 0 69
:3 0 f74 f75 0
5a :4 0 12f :4 0
5d :2 0 5e :3 0
8ac f79 f7b :3 0
8af f76 f7d :2 0
f7f 8b2 f80 f73
f7f 0 f81 8b4
0 f87 d :3 0
41 :3 0 c9 :3 0
f83 f84 0 f85
:2 0 f87 8b6 f88
f5f f87 0 f89
8ba 0 f91 28
:3 0 62 :3 0 10
:3 0 24 :2 0 8bc
f8b f8e f8a f8f
0 f91 8bf f93
f45 f49 0 f94
0 f91 0 f94
8c2 0 11d3 13
:3 0 10a :2 0 8c5
f96 f97 :3 0 f98
:2 0 7a :3 0 2f
:3 0 8c :3 0 8d
:3 0 13 :4 0 130
1 :8 0 fa5 8f
:3 0 90 :3 0 fa0
fa1 0 91 :3 0
fa2 fa3 0 fa5
8c7 fef 92 :3 0
8f :3 0 90 :3 0
fa8 fa9 0 91
:3 0 faa fab 0
fe5 55 :3 0 56
:3 0 fad fae 0
55 :3 0 66 :3 0
fb0 fb1 0 93
:2 0 2 :4 0 131
:2 0 68 :2 0 20
:2 0 8ca fb6 fb8
:3 0 8cd fb2 fba
faf fbc fbb :2 0
58 :3 0 69 :3 0
fbe fbf 0 5a
:4 0 132 :4 0 5d
:2 0 5e :3 0 8d1
fc3 fc5 :3 0 5d
:2 0 96 :4 0 8d4
fc7 fc9 :3 0 5d
:2 0 97 :4 0 8d7
fcb fcd :3 0 5d
:2 0 91 :3 0 8da
fcf fd1 :3 0 5d
:2 0 98 :4 0 8dd
fd3 fd5 :3 0 5d
:2 0 7e :3 0 99
:3 0 20 :2 0 9a
:2 0 8e0 fd8 fdc
8e4 fd7 fde :3 0
8e7 fc0 fe0 :2 0
fe2 8ea fe3 fbd
fe2 0 fe4 8ec
0 fe5 8ee fe8
:3 0 fe8 0 fe8
fe7 fe5 fe6 :6 0
fea 2a :3 0 8f1
fec 8f3 feb fea
:2 0 fed 8f5 :2 0
fef 0 fef fee
fa5 fed :6 0 1035
1 :3 0 8f :3 0
90 :3 0 ff1 ff2
0 8f :3 0 9b
:2 0 133 :3 0 ff4
ff6 0 8f9 ff5
ff8 :3 0 ff9 :2 0
62 :3 0 28 :3 0
24 :2 0 8fc ffb
ffe 62 :3 0 ad
:2 0 2f :3 0 24
:2 0 8ff 1000 1004
904 1001 1006 :3 0
1007 :2 0 ffa 1009
1008 :2 0 c :3 0
13 :3 0 100b 100c
0 1032 55 :3 0
56 :3 0 100e 100f
0 55 :3 0 66
:3 0 1011 1012 0
20 :2 0 2 :4 0
134 :2 0 68 :2 0
20 :2 0 907 1017
1019 :3 0 90a 1013
101b 1010 101d 101c
:2 0 58 :3 0 69
:3 0 101f 1020 0
5a :4 0 135 :4 0
5d :2 0 5e :3 0
90e 1024 1026 :3 0
911 1021 1028 :2 0
102a 914 102b 101e
102a 0 102c 916
0 1032 d :3 0
41 :3 0 136 :3 0
102e 102f 0 1030
:2 0 1032 918 1033
100a 1032 0 1034
91c 0 1035 91e
1036 f99 1035 0
1037 921 0 11d3
2e :3 0 ea :2 0
20 :2 0 923 1039
103b :3 0 1038 103c
0 11d3 2f :3 0
eb :3 0 14 :3 0
15 :3 0 11 :3 0
17 :3 0 19 :3 0
46 :3 0 48 :3 0
2e :3 0 25 :3 0
23 :3 0 925 103f
104a 103e 104b 0
11d3 62 :3 0 2b
:3 0 24 :2 0 930
104d 1050 ad :2 0
24 :2 0 935 1052
1054 :3 0 1055 :2 0
1d :3 0 10a :2 0
938 1058 1059 :3 0
105a :2 0 105b :2 0
1056 105d 105c :2 0
2f :3 0 137 :3 0
14 :3 0 15 :3 0
16 :3 0 13 :3 0
11 :3 0 1d :3 0
2b :3 0 24 :2 0
93a 1060 1069 105f
106a 0 106c 943
106d 105e 106c 0
106e 945 0 11d3
13 :3 0 10a :2 0
947 1070 1071 :3 0
1072 :2 0 2f :3 0
11e :3 0 14 :3 0
11 :3 0 11f :2 0
949 1075 1079 1074
107a 0 107c 94d
109d 7e :3 0 1f
:3 0 20 :2 0 20
:2 0 94f 107d 1081
9b :2 0 11f :4 0
955 1083 1085 :3 0
2f :3 0 11e :3 0
14 :3 0 11 :3 0
24 :2 0 958 1088
108c 1087 108d 0
108f 95c 1099 2f
:3 0 11e :3 0 14
:3 0 11 :3 0 20
:2 0 95e 1091 1095
1090 1096 0 1098
962 109a 1086 108f
0 109b 0 1098
0 109b 964 0
109c 967 109e 1073
107c 0 109f 0
109c 0 109f 969
0 11d3 1d :3 0
10a :2 0 96c 10a1
10a2 :3 0 10a3 :2 0
b2 :3 0 116 :3 0
7d :3 0 7e :3 0
1d :3 0 b2 :3 0
117 :3 0 1a :3 0
1a :3 0 b9 :4 0
138 1 :8 0 10b5
8f :3 0 90 :3 0
10b0 10b1 0 91
:3 0 10b2 10b3 0
10b5 96e 10ff 92
:3 0 8f :3 0 90
:3 0 10b8 10b9 0
91 :3 0 10ba 10bb
0 10f5 55 :3 0
56 :3 0 10bd 10be
0 55 :3 0 66
:3 0 10c0 10c1 0
93 :2 0 2 :4 0
139 :2 0 68 :2 0
20 :2 0 971 10c6
10c8 :3 0 974 10c2
10ca 10bf 10cc 10cb
:2 0 58 :3 0 69
:3 0 10ce 10cf 0
5a :4 0 13a :4 0
5d :2 0 5e :3 0
978 10d3 10d5 :3 0
5d :2 0 96 :4 0
97b 10d7 10d9 :3 0
5d :2 0 97 :4 0
97e 10db 10dd :3 0
5d :2 0 91 :3 0
981 10df 10e1 :3 0
5d :2 0 98 :4 0
984 10e3 10e5 :3 0
5d :2 0 7e :3 0
99 :3 0 20 :2 0
9a :2 0 987 10e8
10ec 98b 10e7 10ee
:3 0 98e 10d0 10f0
:2 0 10f2 991 10f3
10cd 10f2 0 10f4
993 0 10f5 995
10f8 :3 0 10f8 0
10f8 10f7 10f5 10f6
:6 0 10fa 2c :3 0
998 10fc 99a 10fb
10fa :2 0 10fd 99c
:2 0 10ff 0 10ff
10fe 10b5 10fd :6 0
1110 1 :3 0 26
:3 0 62 :3 0 26
:3 0 24 :2 0 99e
1102 1105 ea :2 0
62 :3 0 29 :3 0
24 :2 0 9a1 1108
110b 9a4 1107 110d
:3 0 1101 110e 0
1110 9a7 1111 10a4
1110 0 1112 9aa
0 11d3 32 :3 0
24 :2 0 1113 1114
0 11d3 2f :3 0
11f :2 0 1116 1117
0 11d3 2f :3 0
120 :3 0 11 :3 0
1a :3 0 26 :3 0
2f :3 0 32 :3 0
b :3 0 24 :2 0
62 :3 0 28 :3 0
24 :2 0 9ac 1122
1125 9af 111a 1127
1119 1128 0 11d3
62 :3 0 2f :3 0
24 :2 0 9b8 112a
112d d0 :2 0 24
:2 0 9bd 112f 1131
:3 0 c :3 0 11
:3 0 1133 1134 0
115a 55 :3 0 56
:3 0 1136 1137 0
55 :3 0 66 :3 0
1139 113a 0 20
:2 0 2 :4 0 13b
:2 0 68 :2 0 20
:2 0 9c0 113f 1141
:3 0 9c3 113b 1143
1138 1145 1144 :2 0
58 :3 0 69 :3 0
1147 1148 0 5a
:4 0 13c :4 0 5d
:2 0 5e :3 0 9c7
114c 114e :3 0 9ca
1149 1150 :2 0 1152
9cd 1153 1146 1152
0 1154 9cf 0
115a d :3 0 41
:3 0 136 :3 0 1156
1157 0 1158 :2 0
115a 9d1 11d0 8c
:3 0 ee :3 0 7a
:3 0 28 :3 0 76
:3 0 78 :3 0 75
:3 0 13d :3 0 8b
:3 0 ef :3 0 f0
:3 0 8b :3 0 41
:3 0 f1 :3 0 41
:3 0 13e :3 0 8d
:3 0 11 :4 0 13f
1 :8 0 1183 f3
:4 0 116e :3 0 f4
:3 0 9b :2 0 9d7
1171 1172 :3 0 8f
:3 0 90 :3 0 1174
1175 0 24 :2 0
1176 1177 0 1179
9da 1180 8f :3 0
90 :3 0 117a 117b
0 f5 :2 0 117c
117d 0 117f 9dc
1181 1173 1179 0
1182 0 117f 0
1182 9de 0 1183
9e1 11cd 92 :3 0
8f :3 0 90 :3 0
1186 1187 0 91
:3 0 1188 1189 0
11c3 55 :3 0 56
:3 0 118b 118c 0
55 :3 0 66 :3 0
118e 118f 0 93
:2 0 2 :4 0 140
:2 0 68 :2 0 20
:2 0 9e4 1194 1196
:3 0 9e7 1190 1198
118d 119a 1199 :2 0
58 :3 0 69 :3 0
119c 119d 0 5a
:4 0 141 :4 0 5d
:2 0 5e :3 0 9eb
11a1 11a3 :3 0 5d
:2 0 96 :4 0 9ee
11a5 11a7 :3 0 5d
:2 0 97 :4 0 9f1
11a9 11ab :3 0 5d
:2 0 91 :3 0 9f4
11ad 11af :3 0 5d
:2 0 98 :4 0 9f7
11b1 11b3 :3 0 5d
:2 0 7e :3 0 99
:3 0 20 :2 0 9a
:2 0 9fa 11b6 11ba
9fe 11b5 11bc :3 0
a01 119e 11be :2 0
11c0 a04 11c1 119b
11c0 0 11c2 a06
0 11c3 a08 11c6
:3 0 11c6 0 11c6
11c5 11c3 11c4 :6 0
11c8 2e :3 0 a0b
11ca a0d 11c9 11c8
:2 0 11cb a0f :2 0
11cd 0 11cd 11cc
1183 11cb :6 0 11cf
1 :3 0 a11 11d1
1132 115a 0 11d2
0 11cf 0 11d2
a13 0 11d3 a16
11d4 f3c 11d3 0
11d6 865 e45 0
11d6 a22 0 11d7
a26 11d9 2e0 640
0 11da 0 11d7
0 11da a30 0
1215 8f :3 0 90
:3 0 11db 11dc 0
142 :3 0 14 :3 0
a33 11de 11e0 11dd
11e1 0 1215 55
:3 0 56 :3 0 11e3
11e4 0 55 :3 0
66 :3 0 11e6 11e7
0 20 :2 0 2
:4 0 143 :2 0 68
:2 0 20 :2 0 a35
11ec 11ee :3 0 a38
11e8 11f0 11e5 11f2
11f1 :2 0 58 :3 0
69 :3 0 11f4 11f5
0 5a :4 0 144
:4 0 5d :2 0 5e
:3 0 a3c 11f9 11fb
:3 0 5d :2 0 96
:4 0 a3f 11fd 11ff
:3 0 5d :2 0 c8
:4 0 a42 1201 1203
:3 0 5d :2 0 8f
:3 0 90 :3 0 1206
1207 0 a45 1205
1209 :3 0 a48 11f6
120b :2 0 120d a4b
120e 11f3 120d 0
120f a4d 0 1215
d :3 0 8f :3 0
90 :3 0 1211 1212
0 1213 :2 0 1215
a4f 1218 :3 0 1218
a58 1218 1217 1215
1216 :6 0 1219 :2 0
2 24 1218 121c
:3 0 121b 1219 121d
:8 0 
a95
4
:3 0 1 3 1
9 1 d 1
11 1 15 1
1b 6 8 c
10 14 1a 20
1 26 1 2c
1 32 1 3a
1 38 1 41
1 3f 1 48
1 46 1 4f
1 4d 1 56
1 54 1 5b
1 60 1 65
1 6a 1 6f
1 74 1 7b
1 79 1 82
1 80 1 89
1 87 1 8e
1 94 1 9a
1 a0 1 a6
1 ac 1 b2
1 b8 1 be
1 c4 1 ca
1 d0 1 d6
1 dc 1 e2
1 e8 1 ee
1 f4 1 fa
1 100 1 106
1 10c 1 112
1 118 1 11e
1 124 1 12c
1 12a 1 136
1 134 1 140
1 13e 1 145
1 14b 1 151
1 157 1 15d
1 163 1 169
1 16f 1 175
1 17b 1 181
1 187 1 18d
1 193 1 19f
1 1ab 2 1ae
1b0 2 1b3 1b5
2 1b7 1b9 2
1bb 1bd 2 1bf
1c1 1 1c7 2
1c9 1ca 2 1c3
1cc 2 1ce 1d0
1 1d6 2 1d8
1d9 2 1d2 1db
2 1dd 1df 1
1e5 2 1e7 1e8
2 1e1 1ea 2
1ec 1ee 2 1f0
1f2 2 1f4 1f6
2 1f8 1fa 2
1fc 1fe 2 200
202 2 204 206
2 208 20a 2
20c 20e 4 1a7
1ad 1b2 210 1
212 1 214 2
21e 220 3 21c
21d 222 2 22b
22d 2 22a 22f
1 231 1 233
2 285 28a 2
29b 29d 3 299
29a 29f 2 2a8
2aa 2 2ac 2ae
2 2b0 2b2 2
2b4 2b6 2 2b8
2ba 3 2bf 2c0
2c1 2 2bc 2c3
2 2a7 2c5 1
2c7 1 2c9 2
292 2ca 1 2ce
1 28d 1 2d2
1 2dd 2 2d9
2dd 2 2f0 2f5
2 306 308 3
304 305 30a 2
313 315 2 317
319 2 31b 31d
2 31f 321 2
323 325 3 32a
32b 32c 2 327
32e 2 312 330
1 332 1 334
2 2fd 335 1
339 1 2f8 1
33d 1 348 2
344 348 2 357
359 3 355 356
35b 2 364 366
2 363 368 1
36a 1 36c 3
34e 36d 372 1
374 2 37e 383
2 394 396 3
392 393 398 2
3a1 3a3 2 3a5
3a7 2 3a9 3ab
2 3ad 3af 2
3b1 3b3 3 3b8
3b9 3ba 2 3b5
3bc 2 3a0 3be
1 3c0 1 3c2
2 38b 3c3 1
3c7 1 386 1
3cb 2 3d1 3d2
1 3d6 2 3d4
3d6 2 3de 3e3
2 3f4 3f6 3
3f2 3f3 3f8 2
401 403 2 405
407 2 409 40b
2 40d 40f 2
411 413 3 418
419 41a 2 415
41c 2 400 41e
1 420 1 422
2 3eb 423 1
427 1 3e6 1
42b 2 433 434
1 438 2 436
438 2 446 448
3 444 445 44a
2 453 455 2
452 457 1 459
1 45b 3 43d
45c 461 1 463
2 42e 464 1
466 2 483 488
2 499 49b 3
497 498 49d 2
4a6 4a8 2 4aa
4ac 2 4ae 4b0
2 4b2 4b4 2
4b6 4b8 3 4bd
4be 4bf 2 4ba
4c1 2 4a5 4c3
1 4c5 1 4c7
2 490 4c8 1
4cc 1 48b 1
4d0 2 4d6 4d7
1 4db 2 4d9
4db 2 4e9 4eb
3 4e7 4e8 4ed
2 4f6 4f8 2
4f5 4fa 1 4fc
1 4fe 3 4e0
4ff 504 1 506
2 509 50a 1
50e 2 50c 50e
2 519 51b 3
517 518 51d 2
526 528 2 52a
52c 2 52e 530
1 538 2 53a
53b 2 532 53d
2 525 53f 1
541 1 543 2
54d 54f 3 54b
54c 551 2 55a
55c 2 559 55e
1 560 1 562
2 56a 56b 3
544 563 56e 2
572 573 2 578
579 1 57b 2
575 57b 2 582
583 2 588 589
1 58b 2 585
58b 2 599 59b
3 597 598 59d
2 5a6 5a8 2
5a5 5aa 1 5ac
1 5ae 3 590
5af 5b4 2 5b8
5b9 2 5be 5bf
1 5c1 2 5bb
5c1 1 5c6 2
5c9 5c8 2 5d5
5d6 5 5d0 5d1
5d2 5d3 5d8 4
580 5ca 5cd 5db
2 5e6 5e8 3
5e4 5e5 5ea 2
5f3 5f5 2 5f7
5f9 2 5fb 5fd
1 605 2 607
608 2 5ff 60a
2 5f2 60c 1
60e 1 610 2
61a 61c 3 618
619 61e 2 627
629 2 626 62b
1 62d 1 62f
2 637 638 3
611 630 63b 3
63d 5dd 63e 8
340 375 378 3ce
467 4d3 507 63f
2 642 643 1
647 2 645 647
2 655 657 3
653 654 659 2
662 664 2 661
666 1 668 1
66a 3 64c 66b
670 1 672 2
67c 681 2 692
694 3 690 691
696 2 69f 6a1
2 6a3 6a5 2
6a7 6a9 2 6ab
6ad 2 6af 6b1
3 6b6 6b7 6b8
2 6b3 6ba 2
69e 6bc 1 6be
1 6c0 2 689
6c1 1 6c5 1
684 1 6c9 2
6cf 6d0 1 6d4
2 6d2 6d4 2
6dc 6e1 2 6f2
6f4 3 6f0 6f1
6f6 2 6ff 701
2 703 705 2
707 709 2 70b
70d 2 70f 711
3 716 717 718
2 713 71a 2
6fe 71c 1 71e
1 720 2 6e9
721 1 725 1
6e4 1 729 2
731 732 1 736
2 734 736 2
744 746 3 742
743 748 2 751
753 2 750 755
1 757 1 759
3 73b 75a 75f
1 761 2 72c
762 1 764 2
772 777 2 788
78a 3 786 787
78c 2 795 797
2 799 79b 2
79d 79f 2 7a1
7a3 2 7a5 7a7
3 7ac 7ad 7ae
2 7a9 7b0 2
794 7b2 1 7b4
1 7b6 2 77f
7b7 1 7bb 1
77a 1 7bf 2
7c5 7c6 1 7ca
2 7c8 7ca 2
7d8 7da 3 7d6
7d7 7dc 2 7e5
7e7 2 7e4 7e9
1 7eb 1 7ed
3 7cf 7ee 7f3
1 7f5 2 800
805 2 816 818
3 814 815 81a
2 823 825 2
827 829 2 82b
82d 2 82f 831
2 833 835 3
83a 83b 83c 2
837 83e 2 822
840 1 842 1
844 2 80d 845
1 849 1 808
1 84d 2 854
855 2 85a 85b
2 860 861 1
863 2 85d 863
2 86a 86b 2
870 871 1 873
2 86d 873 1
878 a 87e 87f
880 881 882 883
884 885 886 887
2 88c 88d 1
891 2 88f 891
2 895 896 2
89b 89c 1 89e
2 898 89e 2
8a4 8a5 1 8a9
2 8a7 8a9 2
8ae 8af 2 8b4
8b5 2 8b1 8b7
2 8bf 8c0 2
8c5 8c6 2 8cb
8cc 2 8c8 8ce
1 8d1 2 8c2
8d1 2 8d6 8d7
2 8dc 8dd 2
8d9 8df 2 8e5
8e6 2 8e2 8e8
1 900 2 8ff
900 1 908 1
90e 2 910 911
2 8fd 912 2
923 925 3 921
922 927 2 930
932 2 934 936
2 938 93a 2
93c 93e 2 940
942 3 947 948
949 2 944 94b
2 92f 94d 1
94f 1 951 2
91a 952 1 956
1 915 1 95a
2 964 965 2
967 96a 3 8eb
95d 96d 1 982
2 981 982 1
98a 1 990 2
992 993 2 97f
994 2 9a5 9a7
3 9a3 9a4 9a9
2 9b2 9b4 2
9b6 9b8 2 9ba
9bc 2 9be 9c0
2 9c2 9c4 3
9c9 9ca 9cb 2
9c6 9cd 2 9b1
9cf 1 9d1 1
9d3 2 99c 9d4
1 9d8 1 997
1 9dc 1 9df
2 9e2 9e3 3
8ba 8bd 9e4 2
9e7 9e8 2 9ed
9ee 2 9f3 9f4
2 9f0 9f6 1
9f9 2 9ea 9f9
2 9fe 9ff 2
a04 a05 2 a01
a07 2 a0e a0f
2 a14 a15 2
a11 a17 2 a1a
a1c 2 a1f a21
1 a23 1 a38
2 a37 a38 1
a40 1 a46 2
a48 a49 2 a35
a4a 2 a5b a5d
3 a59 a5a a5f
2 a68 a6a 2
a6c a6e 2 a70
a72 2 a74 a76
2 a78 a7a 3
a7f a80 a81 2
a7c a83 2 a67
a85 1 a87 1
a89 2 a52 a8a
1 a8e 1 a4d
1 a92 3 a0a
a26 a95 2 a9a
a9b 2 aa0 aa1
2 a9d aa3 1
abd 2 abc abd
1 ac5 1 acb
2 acd ace 2
aba acf 2 ae0
ae2 3 ade adf
ae4 2 aed aef
2 af1 af3 2
af5 af7 2 af9
afb 2 afd aff
3 b04 b05 b06
2 b01 b08 2
aec b0a 1 b0c
1 b0e 2 ad7
b0f 1 b13 1
ad2 1 b17 3
aa6 aa9 b1a 2
b1d b1e 1 b1f
2 b21 b22 1
b23 2 b27 b28
2 b2d b2e 2
b2a b30 1 b4a
2 b49 b4a 1
b52 1 b58 2
b5a b5b 2 b47
b5c 2 b6d b6f
3 b6b b6c b71
2 b7a b7c 2
b7e b80 2 b82
b84 2 b86 b88
2 b8a b8c 3
b91 b92 b93 2
b8e b95 2 b79
b97 1 b99 1
b9b 2 b64 b9c
1 ba0 1 b5f
1 ba4 3 b33
b36 ba7 2 baa
bab 1 bad 2
bbd bc2 2 bd3
bd5 3 bd1 bd2
bd7 2 be0 be2
2 be4 be6 2
be8 bea 2 bec
bee 2 bf0 bf2
3 bf7 bf8 bf9
2 bf4 bfb 2
bdf bfd 1 bff
1 c01 2 bca
c02 1 c06 1
bc5 1 c0a 1
c0f 2 c19 c1e
2 c2f c31 3
c2d c2e c33 2
c3c c3e 2 c40
c42 2 c44 c46
2 c48 c4a 2
c4c c4e 3 c53
c54 c55 2 c50
c57 2 c3b c59
1 c5b 1 c5d
2 c26 c5e 1
c62 1 c21 1
c66 3 c6e c6f
c70 1 c74 2
c72 c74 1 c79
1 c7b 2 c69
c7c 2 c80 c81
1 c85 2 c83
c85 2 c8d c8e
2 c90 c93 2
ca2 ca7 2 cb8
cba 3 cb6 cb7
cbc 2 cc5 cc7
2 cc9 ccb 2
ccd ccf 2 cd1
cd3 2 cd5 cd7
3 cdc cdd cde
2 cd9 ce0 2
cc4 ce2 1 ce4
1 ce6 2 caf
ce7 1 ceb 1
caa 1 cef 2
c97 cf2 2 d00
d05 2 d16 d18
3 d14 d15 d1a
2 d23 d25 2
d27 d29 2 d2b
d2d 2 d2f d31
2 d33 d35 3
d3a d3b d3c 2
d37 d3e 2 d22
d40 1 d42 1
d44 2 d0d d45
1 d49 1 d08
1 d4d 1 d50
3 d53 cf5 d54
3 bb4 c0d d55
1 d57 1 d59
3 d60 d61 d62
1 d65 3 d68
d69 d6a 1 d6e
2 d6c d6e 3
d73 d74 d75 1
d78 3 d7c d7d
d7e 1 d81 2
d83 d84 1 d85
2 d87 d88 2
d97 d98 8 d8f
d90 d91 d92 d93
d94 d95 d9a 2
d9f da0 1 da4
2 da2 da4 2
db2 db4 3 db0
db1 db6 2 dbf
dc1 2 dbe dc3
1 dc5 1 dc7
2 dcb dcc 3
da9 dc8 dcf 1
dd1 7 bac d58
d89 d8c d9d dd2
dd5 1 dd7 3
87b 88a dd8 2
ddd dde 2 de3
de4 2 de0 de6
2 de9 deb 2
dee df0 1 df2
1 df5 2 df7
df8 2 e14 e15
18 dfc dfd dfe
dff e00 e01 e02
e03 e04 e05 e06
e07 e08 e09 e0a
e0b e0c e0d e0e
e0f e10 e11 e12
e17 2 e26 e28
3 e24 e25 e2a
2 e33 e35 2
e32 e37 1 e39
1 e3b 2 e3f
e40 6 868 df9
e1a e1d e3c e43
2 e47 e48 2
e4d e4e 1 e50
2 e4a e50 1
e61 2 e60 e61
1 e69 1 e6f
2 e71 e72 2
e5e e73 2 e84
e86 3 e82 e83
e88 2 e91 e93
2 e95 e97 2
e99 e9b 2 e9d
e9f 2 ea1 ea3
3 ea8 ea9 eaa
2 ea5 eac 2
e90 eae 1 eb0
1 eb2 2 e7b
eb3 1 eb7 1
e76 1 ebb 1
ece 2 ecd ece
1 ed6 1 edc
2 ede edf 2
ecb ee0 2 ef1
ef3 3 eef ef0
ef5 2 efe f00
2 f02 f04 2
f06 f08 2 f0a
f0c 2 f0e f10
3 f15 f16 f17
2 f12 f19 2
efd f1b 1 f1d
1 f1f 2 ee8
f20 1 f24 1
ee3 1 f28 2
ebe f2b 2 f31
f32 2 f37 f38
1 f3a 2 f34
f3a 2 f3e f3f
1 f43 2 f41
f43 1 f48 2
f4b f4c 1 f50
2 f4e f50 2
f55 f56 1 f5a
2 f58 f5a 2
f6b f6d 3 f69
f6a f6f 2 f78
f7a 2 f77 f7c
1 f7e 1 f80
3 f62 f81 f86
1 f88 2 f8c
f8d 2 f89 f90
2 f92 f93 1
f95 2 f9f fa4
2 fb5 fb7 3
fb3 fb4 fb9 2
fc2 fc4 2 fc6
fc8 2 fca fcc
2 fce fd0 2
fd2 fd4 3 fd9
fda fdb 2 fd6
fdd 2 fc1 fdf
1 fe1 1 fe3
2 fac fe4 1
fe8 1 fa7 1
fec 1 ff7 2
ff3 ff7 2 ffc
ffd 2 1002 1003
1 1005 2 fff
1005 2 1016 1018
3 1014 1015 101a
2 1023 1025 2
1022 1027 1 1029
1 102b 3 100d
102c 1031 1 1033
2 fef 1034 1
1036 1 103a a
1040 1041 1042 1043
1044 1045 1046 1047
1048 1049 2 104e
104f 1 1053 2
1051 1053 1 1057
8 1061 1062 1063
1064 1065 1066 1067
1068 1 106b 1
106d 1 106f 3
1076 1077 1078 1
107b 3 107e 107f
1080 1 1084 2
1082 1084 3 1089
108a 108b 1 108e
3 1092 1093 1094
1 1097 2 1099
109a 1 109b 2
109d 109e 1 10a0
2 10af 10b4 2
10c5 10c7 3 10c3
10c4 10c9 2 10d2
10d4 2 10d6 10d8
2 10da 10dc 2
10de 10e0 2 10e2
10e4 3 10e9 10ea
10eb 2 10e6 10ed
2 10d1 10ef 1
10f1 1 10f3 2
10bc 10f4 1 10f8
1 10b7 1 10fc
2 1103 1104 2
1109 110a 2 1106
110c 2 10ff 110f
1 1111 2 1123
1124 8 111b 111c
111d 111e 111f 1120
1121 1126 2 112b
112c 1 1130 2
112e 1130 2 113e
1140 3 113c 113d
1142 2 114b 114d
2 114a 114f 1
1151 1 1153 3
1135 1154 1159 1
1170 2 116f 1170
1 1178 1 117e
2 1180 1181 2
116d 1182 2 1193
1195 3 1191 1192
1197 2 11a0 11a2
2 11a4 11a6 2
11a8 11aa 2 11ac
11ae 2 11b0 11b2
3 11b7 11b8 11b9
2 11b4 11bb 2
119f 11bd 1 11bf
1 11c1 2 118a
11c2 1 11c6 1
1185 1 11ca 1
11cd 2 11d0 11d1
b f94 1037 103d
104c 106e 109f 1112
1115 1118 1129 11d2
3 11d5 f2f 11d4
9 673 676 6cc
765 7c2 7f6 850
858 11d6 2 11d8
11d9 1 11df 2
11eb 11ed 3 11e9
11ea 11ef 2 11f8
11fa 2 11fc 11fe
2 1200 1202 2
1204 1208 2 11f7
120a 1 120c 1
120e 8 215 234
237 2d5 11da 11e2
120f 1214 3c 2a
30 36 3d 44
4b 52 59 5e
63 68 6d 72
77 7e 85 8c
92 98 9e a4
aa b0 b6 bc
c2 c8 ce d4
da e0 e6 ec
f2 f8 fe 104
10a 110 116 11c
122 128 132 13c
143 149 14f 155
15b 161 167 16d
173 179 17f 185
18b 191 197 
1
4
0 
121c
0
1
50
2f
43
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

106 1 0
1b 1 0
16f 1 0
11e 1 0
d0 1 0
ee 1 0
6a 1 0
118 1 0
ca 1 0
b2 1 0
112 1 0
b8 1 0
134 1 0
80 1 0
175 1 0
14b 1 0
17b 1 0
3 1 0
26 1 0
151 1 0
12a 1 0
d6 1 0
d 1 0
a6 1 0
fa 1 0
6f 1 0
9a 1 0
87 1 0
a0 1 0
65 1 0
15d 1 0
8e 1 0
9 1 0
e8 1 0
124 1 0
11 1 0
60 1 0
169 1 0
2c 1 0
94 1 0
4d 1 0
38 1 0
ac 1 0
f4 1 0
2 0 1
100 1 0
32 1 0
10c 1 0
79 1 0
74 1 0
157 1 0
c4 1 0
54 1 0
46 1 0
be 1 0
3f 1 0
145 1 0
5b 1 0
181 1 0
187 1 0
dc 1 0
15 1 0
18d 1 0
193 1 0
13e 1 0
e2 1 0
163 1 0
0

/
SHOW ERRORS FUNCTION FC_U_WP_ACTUAL;
ALTER FUNCTION FC_U_WP_ACTUAL COMPILE DEBUG;
/******************************************************************************************************************
update Actual Work, %W, %C in Work Packages
assign_id:      TSK_ASSIGNMENT_ID or TASK_ID
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_WP_ACTUAL ==
CREATE OR REPLACE FUNCTION SP_U_WP_ACTUAL wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
4d
2 :e:
1FUNCTION:
1SP_U_WP_ACTUAL:
1ASSIGN_ID:
1VARCHAR2:
1P_WORK_PERCENT:
1PLS_INTEGER:
1P_ACTUAL:
1P_UNITS:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ASSIGN_ID:
132:
1H_NEW_WORK_PERCENT:
10:
1H_ACTUAL:
1H_UNITS:
1H_REC_USER:
1H_ERROR_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_ACTUAL(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
128:
1+:
1FPUT:
1               ENTER:: SP_U_WP_ACTUAL(29) :: cplan.sql(15203) :: :
1SC_STATE:
1FC_U_WP_ACTUAL:
14:
143:
1       RETURN_STATUS:: SP_U_WP_ACTUAL(44) :: cplan.sql(15218) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
150:
1           EXCEPTION:: SP_U_WP_ACTUAL(51) :: cplan.sql(15225) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
162:
1           EXCEPTION:: SP_U_WP_ACTUAL(63) :: cplan.sql(15237) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
1ec
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c a0
4d d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 6b :7 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
1ec
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 56
7c 80 84 88 8b 8f ac 97
9b 9e 9f a7 96 c8 b7 bb
93 c3 b6 e4 d3 d7 b3 df
d2 100 ef f3 cf fb ee 11d
10b eb 10f 110 118 10a 13a 128
107 12c 12d 135 127 15a 145 149
124 14d 155 144 161 165 141 169
16d 171 174 179 17a 1 17c 181
185 189 18c 191 195 199 19c 1a1
1a2 1a4 1a9 1ac 1b0 1b1 1b6 1bb
1be 1c3 1c4 1c9 1cc 1d0 1d1 1d6
1d9 1de 1df 1e4 1e7 1ec 1ed 1f2
1f5 1f9 1fd 201 202 204 209 20a
20c 20d 212 215 21a 21b 220 223
227 22b 22f 230 232 237 238 23a
23b 240 243 248 249 24e 251 255
259 25d 25e 260 265 266 268 269
26e 271 276 277 27c 27f 284 285
28a 28d 291 292 297 29a 29f 2a0
2a5 2a8 2ad 2ae 2b3 2b4 2b9 2bb
2bf 2c2 2c6 2ca 2cd 2d1 2d5 2d8
2db 2e0 2e3 2e6 2e9 2ea 2ef 2f0
1 2f2 2f7 2fb 2ff 302 307 30c
30f 313 314 319 31a 31f 321 325
328 32c 32d 331 335 339 33d 341
345 349 34d 351 355 359 35d 361
365 369 36d 371 375 378 37c 380
384 388 38c 390 394 395 397 39b
39f 3a3 3a6 3aa 3ae 3b1 3b4 3b9
3bc 3bf 3c2 3c3 3c8 3c9 1 3cb
3d0 3d4 3d8 3db 3e0 3e5 3e8 3ec
3ed 3f2 3f5 3fa 3fb 400 403 408
409 40e 411 415 419 41d 421 424
425 427 42c 42d 42f 430 435 438
43d 43e 443 446 44b 44c 451 454
458 459 45e 461 466 467 46c 46d
472 474 478 47b 47f 483 486 48a
48e 491 495 499 49a 49f 4a1 4a5
4a9 4ac 4b0 4b4 4b7 4bb 4bf 4c2
4c5 4ca 4cd 4d0 4d3 4d4 4d9 4da
1 4dc 4e1 4e5 4e9 4ec 4f1 4f6
4f9 4fd 4fe 503 504 509 50d 511
514 519 51e 521 525 529 52c 52d
532 535 53a 53b 540 543 547 54b
54e 54f 554 555 55a 55c 560 563
567 56b 56f 573 577 57b 57f 583
587 593 598 59c 5a0 5a4 5a8 5aa
5ab 5b0 1 5b4 5b8 5bc 5bf 5c3
5c7 5cb 5cf 5d2 5d6 5da 5dd 5e0
5e5 5e8 5eb 5ee 5ef 5f4 5f5 1
5f7 5fc 600 604 607 60c 611 614
618 619 61e 61f 624 628 62c 62f
634 639 63c 640 641 646 649 64e
64f 654 657 65b 65f 662 665 666
668 669 66e 66f 674 676 67a 67d
681 685 689 68d 691 695 699 6a5
6aa 6ae 6b2 6b6 6ba 6bc 6c0 6c2
6ce 6d0 6d2 6d3 6d8 6dc 6de 6ea
6ee 6f0 6f1 6fa 
1ec
2
0 1 a 6 10 :3 6 15 :3 6
f :3 6 e :3 6 10 :2 6 1 3
a 13 a :2 1 4 10 19 18
:2 10 :2 4 :2 17 26 17 :2 4 :2 d 1c
d :2 4 :2 c 1b c :2 4 f 18
17 :2 f :2 4 f 18 17 :2 f :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 56 5c 5f :2 56 6d 85 8
:2 6d d 10 :2 6d 1a 1d :2 6d b
e :2 6d 13 16 1f 27 :2 1f 38
:2 16 :2 6d b e :2 6d 13 16 1f
27 :2 1f 32 :2 16 :2 6d b e :2 6d
13 16 1f 27 :2 1f 31 :2 16 :2 6d
b e :2 6d 13 16 :2 6d 1b 1e
:2 6d 28 2b :2 6d 30 33 :2 6d :2 7
4c :2 4 7 :2 11 23 :2 2d 39 3c
4e 50 51 :2 4e :2 23 :3 7 :2 d 12
1e 5f 62 :2 1e :2 7 54 :3 4 12
:2 4 13 :2 4 1a :2 4 10 :2 4 f
:2 4 12 :2 4 :2 d 19 28 35 49
53 5c 27 :2 19 4 7 :2 11 23
:2 2d 39 3c 4e 50 51 :2 4e :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e 6f
72 :2 1e 76 79 :2 1e 83 86 8f
97 :2 a0 :2 8f ab :2 86 :2 1e b3 b6
:2 1e be c1 :2 1e c6 c9 :2 1e d4
d7 :2 1e :2 7 54 :3 4 :2 f 21 :2 2a
34 40 :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 52 54 55
:2 52 :2 26 :3 a :2 10 15 21 62 65
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 58 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4f 51 52
:2 4f :2 23 :3 7 :2 d 12 1e 5f 62
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 55 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
1ec
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 2
:4 8 :2 1 :7 a :6 b
:6 c :6 d :7 e :7 f
:7 11 :b 13 :11 14 15
:2 14 :2 15 :2 14 :2 15
:2 14 :2 16 :2 14 :9 16
:2 14 :2 17 :2 14 :9 17
:2 14 :2 18 :2 14 :9 18
:2 14 :2 19 :2 14 :2 19
:2 14 :2 19 :2 14 :2 19
:2 14 :2 19 :4 14 :3 13
:11 1c :b 1d :3 1c :3 20
:3 22 :3 23 :3 24 :3 25
:3 26 :9 28 29 :3 28
:11 2b :30 2c :3 2b :a 2e
12 :3 31 :11 32 :b 33
:17 34 :3 32 :2 36 :3 37
:3 38 39 37 36
37 :3 3a :3 31 :2 3b
:5 3d :11 3e :b 3f :18 40
:3 3e :2 42 43 :3 44
45 43 42 43
:3 46 :2 3c :6 3b 30
:7 1 
6fc
4
:3 0 1 :3 0 2
:a 0 1e7 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d :2 0 b
6 :3 0 8 :7 0
11 10 :3 0 4
:3 0 9 :7 0 15
14 :3 0 a :3 0
b :3 0 c :2 0
4 19 1a 0
17 1b 0 1e7
2 1c :2 0 10
:2 0 15 4 :3 0
e :2 0 13 1f
21 :6 0 24 22
0 1e5 0 d
:6 0 10 :2 0 17
6 :3 0 26 :7 0
2a 27 28 1e5
0 f :6 0 10
:2 0 19 6 :3 0
2c :7 0 30 2d
2e 1e5 0 11
:6 0 e :2 0 1b
6 :3 0 32 :7 0
36 33 34 1e5
0 12 :6 0 e
:2 0 1f 4 :3 0
1d 38 3a :6 0
3d 3b 0 1e5
0 13 :6 0 46
47 0 23 4
:3 0 21 3f 41
:6 0 44 42 0
1e5 0 14 :6 0
4c 4d 0 25
b :3 0 c :2 0
4 48 :7 0 4b
49 0 1e5 0
15 :6 0 16 :3 0
17 :3 0 16 :3 0
18 :3 0 4f 50
0 2 :4 0 27
51 53 4e 55
54 :2 0 19 :3 0
1a :3 0 57 58
0 1b :4 0 16
:3 0 1c :3 0 5b
5c 0 2 :4 0
29 5d 5f 1d
:4 0 1e :2 0 1f
:3 0 2b 62 64
:3 0 20 :4 0 1e
:2 0 21 :4 0 2e
67 69 :3 0 1e
:2 0 3 :3 0 31
6b 6d :3 0 1e
:2 0 21 :4 0 34
6f 71 :3 0 1e
:2 0 22 :4 0 37
73 75 :3 0 1e
:2 0 23 :3 0 24
:3 0 5 :3 0 3a
79 7b 25 :4 0
3c 78 7e 3f
77 80 :3 0 1e
:2 0 22 :4 0 42
82 84 :3 0 1e
:2 0 23 :3 0 24
:3 0 7 :3 0 45
88 8a 25 :4 0
47 87 8d 4a
86 8f :3 0 1e
:2 0 22 :4 0 4d
91 93 :3 0 1e
:2 0 23 :3 0 24
:3 0 8 :3 0 50
97 99 25 :4 0
52 96 9c 55
95 9e :3 0 1e
:2 0 22 :4 0 58
a0 a2 :3 0 1e
:2 0 21 :4 0 5b
a4 a6 :3 0 1e
:2 0 9 :3 0 5e
a8 aa :3 0 1e
:2 0 21 :4 0 61
ac ae :3 0 1e
:2 0 26 :4 0 64
b0 b2 :3 0 67
59 b4 :2 0 b6
6c b7 56 b6
0 b8 6e 0
145 16 :3 0 17
:3 0 b9 ba 0
16 :3 0 27 :3 0
bc bd 0 28
:2 0 2 :4 0 29
:2 0 2a :2 0 28
:2 0 70 c2 c4
:3 0 73 be c6
bb c8 c7 :2 0
19 :3 0 2b :3 0
ca cb 0 1b
:4 0 2c :4 0 1e
:2 0 1f :3 0 77
cf d1 :3 0 7a
cc d3 :2 0 d5
7d d6 c9 d5
0 d7 7f 0
145 14 :4 0 d8
d9 0 145 d
:3 0 3 :3 0 db
dc 0 145 f
:3 0 5 :3 0 de
df 0 145 11
:3 0 7 :3 0 e1
e2 0 145 12
:3 0 8 :3 0 e4
e5 0 145 13
:3 0 9 :3 0 e7
e8 0 145 b
:3 0 2d :3 0 ea
eb 0 2e :3 0
d :3 0 f :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
81 ed f4 ec
f5 0 145 16
:3 0 17 :3 0 f7
f8 0 16 :3 0
27 :3 0 fa fb
0 2f :2 0 2
:4 0 30 :2 0 2a
:2 0 28 :2 0 88
100 102 :3 0 8b
fc 104 f9 106
105 :2 0 19 :3 0
2b :3 0 108 109
0 1b :4 0 31
:4 0 1e :2 0 1f
:3 0 8f 10d 10f
:3 0 1e :2 0 32
:4 0 92 111 113
:3 0 1e :2 0 33
:4 0 95 115 117
:3 0 1e :2 0 23
:3 0 24 :3 0 b
:3 0 2d :3 0 11c
11d 0 98 11b
11f 25 :4 0 9a
11a 122 9d 119
124 :3 0 1e :2 0
34 :4 0 a0 126
128 :3 0 1e :2 0
21 :4 0 a3 12a
12c :3 0 1e :2 0
14 :3 0 a6 12e
130 :3 0 1e :2 0
21 :4 0 a9 132
134 :3 0 ac 10a
136 :2 0 138 af
139 107 138 0
13a b1 0 145
35 :3 0 36 :3 0
13b 13c 0 b
:3 0 2d :3 0 13e
13f 0 14 :3 0
37 :3 0 b3 13d
143 :2 0 145 b7
1e6 b :3 0 38
:2 0 4 146 147
0 16 :3 0 17
:3 0 149 14a 0
16 :3 0 27 :3 0
14c 14d 0 39
:2 0 2 :4 0 3a
:2 0 2a :2 0 28
:2 0 c3 152 154
:3 0 c6 14e 156
14b 158 157 :2 0
19 :3 0 2b :3 0
15a 15b 0 1b
:4 0 3b :4 0 1e
:2 0 1f :3 0 ca
15f 161 :3 0 cd
15c 163 :2 0 17c
19 :3 0 2b :3 0
165 166 0 1b
:4 0 3c :4 0 1e
:2 0 b :3 0 3d
:3 0 16b 16c 0
d0 16a 16e :3 0
1e :2 0 34 :4 0
d3 170 172 :3 0
1e :2 0 b :3 0
3e :3 0 175 176
0 d6 174 178
:3 0 d9 167 17a
:2 0 17c dc 17d
159 17c 0 17e
df 0 18e 3f
:3 0 15 :3 0 b
:3 0 3d :3 0 40
:3 0 b :3 0 3e
:3 0 41 :3 0 42
:4 0 43 1 :a 0
18a :2 0 18e 180
188 :2 0 a :3 0
15 :3 0 18c :2 0
18e e1 190 e5
18f 18e :2 0 1e4
44 :3 0 b :3 0
2d :3 0 193 194
0 45 :3 0 195
196 0 1dc 16
:3 0 17 :3 0 198
199 0 16 :3 0
27 :3 0 19b 19c
0 39 :2 0 2
:4 0 46 :2 0 2a
:2 0 28 :2 0 e7
1a1 1a3 :3 0 ea
19d 1a5 19a 1a7
1a6 :2 0 19 :3 0
2b :3 0 1a9 1aa
0 1b :4 0 47
:4 0 1e :2 0 1f
:3 0 ee 1ae 1b0
:3 0 f1 1ab 1b2
:2 0 1cc 19 :3 0
2b :3 0 1b4 1b5
0 1b :4 0 48
:4 0 1e :2 0 45
:3 0 f4 1b9 1bb
:3 0 1e :2 0 49
:4 0 f7 1bd 1bf
:3 0 1e :2 0 4a
:3 0 4b :3 0 28
:2 0 4c :2 0 fa
1c2 1c6 fe 1c1
1c8 :3 0 101 1b6
1ca :2 0 1cc 104
1cd 1a8 1cc 0
1ce 107 0 1dc
3f :3 0 15 :3 0
40 :3 0 b :3 0
3e :3 0 41 :3 0
42 :4 0 4d 1
:a 0 1d8 :2 0 1dc
1d0 1d6 :2 0 a
:3 0 15 :3 0 1da
:2 0 1dc 109 1df
:3 0 1df 0 1df
1de 1dc 1dd :6 0
1e1 1 :3 0 10e
1e3 110 1e2 1e1
:2 0 1e4 112 :2 0
1e6 115 1e6 1e5
145 1e4 :6 0 1e7
:2 0 2 1c 1e6
1ea :3 0 1e9 1e7
1eb :8 0 
11d
4
:3 0 1 3 1
7 1 b 1
f 1 13 5
6 a e 12
16 1 20 1
1e 1 25 1
2b 1 31 1
39 1 37 1
40 1 3e 1
45 1 52 1
5e 2 61 63
2 66 68 2
6a 6c 2 6e
70 2 72 74
1 7a 2 7c
7d 2 76 7f
2 81 83 1
89 2 8b 8c
2 85 8e 2
90 92 1 98
2 9a 9b 2
94 9d 2 9f
a1 2 a3 a5
2 a7 a9 2
ab ad 2 af
b1 4 5a 60
65 b3 1 b5
1 b7 2 c1
c3 3 bf c0
c5 2 ce d0
2 cd d2 1
d4 1 d6 6
ee ef f0 f1
f2 f3 2 ff
101 3 fd fe
103 2 10c 10e
2 110 112 2
114 116 1 11e
2 120 121 2
118 123 2 125
127 2 129 12b
2 12d 12f 2
131 133 2 10b
135 1 137 1
139 3 140 141
142 b b8 d7
da dd e0 e3
e6 e9 f6 13a
144 2 151 153
3 14f 150 155
2 15e 160 2
15d 162 2 169
16d 2 16f 171
2 173 177 2
168 179 2 164
17b 1 17d 3
17e 189 18d 1
148 2 1a0 1a2
3 19e 19f 1a4
2 1ad 1af 2
1ac 1b1 2 1b8
1ba 2 1bc 1be
3 1c3 1c4 1c5
2 1c0 1c7 2
1b7 1c9 2 1b3
1cb 1 1cd 4
197 1ce 1d7 1db
1 1df 1 192
2 190 1e3 7
23 29 2f 35
3c 43 4a 
1
4
0 
1ea
0
1
14
2
d
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
3e 1 0
2 0 1
13 1 0
1e 1 0
25 1 0
2b 1 0
3 1 0
31 1 0
f 1 0
7 1 0
b 1 0
37 1 0
45 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_ACTUAL;
ALTER FUNCTION SP_U_WP_ACTUAL COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_PARTICIPANT ==
CREATE OR REPLACE FUNCTION SP_U_PARTICIPANT wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
215
2 :e:
1FUNCTION:
1SP_U_PARTICIPANT:
1ASSIGN_ID:
1VARCHAR2:
1SECURITY_ID001:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1P_DELAY:
1PLS_INTEGER:
1P_UNITS:
1P_WORK_PERCENT:
1P_ACTUAL:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_SECURITY_ID:
132:
1A_ELEMENT_ID:
1A_PARTICIPANT_ID:
1255:
1A_PARTICIPANT_NAME:
1A_SECURITY_NAME:
1H_FULL_NAME:
1A_RES_ASSIGNMENT_ID:
1A_SECURITY_ID:
1A_TEMP_ID:
1H_PRJ_ASSIGN_ID:
1H_CREATED_BY:
1H_PROJECT_ID:
1H_CRI_SECURITY_ID:
1H_ACTUAL_START:
1H_START_DATE:
1H_FINISH_DATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_START_DT:
1H_SD:
1DATE:
1H_FD:
1H_WEEK_OF:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_BILLABLE:
10:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DAYOFYEAR:
1H_LAST_SUBMITTED:
1A_ASSIGNMENT_COUNT:
1A_ELEMENT_TYPE:
1H_RESPONSIBLE:
1A_PARTICIPANT:
1A_RESOURCE_TYPE:
1A_SECURITY_VALUE:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_TRANSFED_CRI:
1H_TASK_ID:
1H_RES_ID:
1H_REC_USER:
1H_EFFORT:
1H_CONTOUR:
1H_DELAY:
1H_PERCENT_UNITS:
1H_WORK_PERCENT:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_WORK:
1H_LAST_DAY:
1H_MINUTES:
1H_TASK_TYPE:
1H_PER_DAY:
1H_WORK_TYPE:
1H_ASSIGN_COUNT:
1H_DURATION:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_SCHED_EFFORT:
1H_ETC:
1H_ROLLUP_BITS:
1H_CLOSE_TASK:
1H_DAY_MIN:
1H_ASSIGN_STRING:
18192:
1H_TEMP_RES_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1STMT:
17999:
1I_RESCHED:
1I_BITFLAG:
1C_P_DELAY:
1C_R_DELAY:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_PARTICIPANT(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
1120:
1+:
1FPUT:
1               ENTER:: SP_U_PARTICIPANT(121) :: cplan.sql(15379) :: :
1:
1RA:
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1ELEMENT_ID:
1ELEMENT_TYPE:
1RESOURCE_TYPE:
1CRI_SECURITY_ID:
1RESOURCE_ID:
1PROJECT_ID:
1TABLE_TYPE:
1RESOURCE_ASSIGNMENTS:
1SELECT ra.RES_ASSIGNMENT_ID, ra.PARTICIPANT, ra.ELEMENT_ID, ra.ELEMENT_TYPE,+
1:n      CASE WHEN ra.RESOURCE_TYPE = '0' THEN 0 ELSE 1 END,:n      CASE WHEN +
1ra.CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END,:n      ra.RESOURCE_ID,:n      r+
1a.PROJECT_ID, ra.TABLE_TYPE:n      INTO a_res_assignment_id, a_participant, a+
1_element_id, a_element_type,:n      a_resource_type,:n      h_transfed_cri,:n+
1      a_participant_id,:n      h_project_id, h_table_type:n      FROM RESOURC+
1E_ASSIGNMENTS ra:n      WHERE ra.RES_ASSIGNMENT_ID = a_temp_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1152:
1           EXCEPTION:: SP_U_PARTICIPANT(153) :: cplan.sql(15411) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1PROJECT_ASSIGNMENT_ID:
1BIT_FLAG:
1LAST_SUBMITTED:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1CONTOUR_TYPE:
1ASSIGN_UNITS:
1UNITS_MSP:
1ACTUAL_START:
1WORK_TODATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1ASSIGNMENT_DELAY:
1LAST_SCHED_MIN:
1TO_DATE:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1ROLLUP_BITS:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT RES_ASSIGNMENT_ID, PROJECT_ASSIGNMENT_ID, PROJECT_ID, RESOURCE_ID,:n  +
1       RESOURCE_TYPE, BIT_FLAG, LAST_SUBMITTED, C_CONTOUR, C_EFFORT, T_UNIT, +
1C_UNIT, CONTOUR_TYPE, :n         CASE WHEN ASSIGN_UNITS > UNITS_MSP THEN ASSI+
1GN_UNITS ELSE UNITS_MSP END, ACTUAL_START, WORK_TODATE, UNRESOLVED_START, UNR+
1ESOLVED_FINISH,:n         CASE WHEN BIT_FLAG = '0' THEN PLANNED_WORK ELSE SCH+
1ED_WORK END, ASSIGNMENT_DELAY,LAST_SCHED_MIN,:n         TO_DATE(SubStr(UNRESO+
1LVED_START, 1, 10)), TO_DATE(SubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAP+
1ITAL_EXPENSE,:n         REGULAR_COST, SPECIAL_COST, REGULAR_RATE, SPECIAL_RAT+
1E,:n         B_REGULAR_COST, B_SPECIAL_COST, B_REGULAR_RATE, B_SPECIAL_RATE,+
1:n         MILESTONE_PERCENT, TASK_ID, ROLLUP_BITS:n         INTO a_res_assig+
1nment_id, h_prj_assign_id, h_project_id, h_res_id,:n         h_res_type, h_bi+
1t_flag, h_last_submitted, h_contour, h_work, h_eunit, h_unit, h_bitflag,:n   +
1      h_percent_units, h_actual_start, h_work_todate, h_start_date, h_finish_+
1date,:n         h_effort, h_delay, h_last_day,:n         h_SD, h_FD, h_billab+
1le, h_capital_expense,:n         h_reg_cost, h_spec_cost, h_reg_sale, h_spec_+
1sale,:n         h_b_reg_cost, h_b_spec_cost, h_b_reg_sale, h_b_spec_sale,:n  +
1       h_work_percent, h_task_id, h_rollup_bits:n         FROM TASK_ASSIGNMEN+
1TS:n         WHERE TSK_ASSIGNMENT_ID = a_temp_id:
1184:
1           EXCEPTION:: SP_U_PARTICIPANT(185) :: cplan.sql(15443) :: :
1TASK_TYPE:
1MINUTE_PER_DAY:
1START_DT:
1FINISH_DT:
1UNRESOLVED_DURATION:
1ASSIGN_COUNT:
1SD:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1WORK_PERCENT:
1ETC:
1FORECAST_START:
1FORECAST_FINISH:
1TMT_WBS:
1SELECT PROJECT_ID, TASK_TYPE, MINUTE_PER_DAY,/*UNRESOLVED_START, UNRESOLVED_F+
1INISH*/ START_DT, FINISH_DT, UNRESOLVED_DURATION,:n            ASSIGN_COUNT, +
1SD, WORK_TODATE, PLANNED_EFFORT + SCHED_EFFORT, WORK_PERCENT, ETC, COALESCE(F+
1ORECAST_START,FORECAST_FINISH):n            INTO h_project_id, h_task_type, h+
1_per_day, h_start_date, h_finish_date, h_duration,:n            h_assign_coun+
1t, h_work_type, h_work_todate, h_effort, h_work_percent, h_etc, h_start_DT:n +
1           FROM TMT_WBS WHERE ELEMENT_ID = a_temp_id:
1204:
1           EXCEPTION:: SP_U_PARTICIPANT(205) :: cplan.sql(15463) :: :
1212:
1        RETURN_ERROR:: SP_U_PARTICIPANT(213) :: cplan.sql(15471) :: :
1STATE:: :
1PMO_CNST:
1RECORD_NOT_FOUND:
1 ID:: :
1215:
1                EXIT:: SP_U_PARTICIPANT(216) :: cplan.sql(15474) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1PMO_ORASTD:
1STRNCMP:
110:
1>:
1!=:
1225:
1        RETURN_ERROR:: SP_U_PARTICIPANT(226) :: cplan.sql(15484) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1228:
1                EXIT:: SP_U_PARTICIPANT(229) :: cplan.sql(15487) :: :
1IS NOT NULL:
1-:
1240:
1        RETURN_ERROR:: SP_U_PARTICIPANT(241) :: cplan.sql(15499) :: :
1CANNOT_UPDATE_ASSIGN_ACCEPT_RE:
1243:
1                EXIT:: SP_U_PARTICIPANT(244) :: cplan.sql(15502) :: :
1DB2TIMESTAMP:
1DAY_YEAR:
1TIME:
1PMO_STPU:
1FIRST_AVAIL_TIME:
1BIT_SCHED:
1CALENDAR_DAY_OF_YEAR:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.FIRST_AVAIL+
1_TIME(BIT_SCHED))) INTO h_sched_start:n                     FROM CALENDAR_DAY+
1_OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n             +
1        AND DAY_YEAR = TO_DATE(SubStr(h_sched_start, 1, 10)):
1264:
1           EXCEPTION:: SP_U_PARTICIPANT(265) :: cplan.sql(15523) :: :
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_start, 1, 10)), PMO_ORA+
1STD.TIME('08::00')) INTO h_sched_start:n                        FROM DUAL:
1279:
1           EXCEPTION:: SP_U_PARTICIPANT(280) :: cplan.sql(15538) :: :
1LAST_AVAIL_TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.LAST_AVAIL_+
1TIME(BIT_SCHED))) INTO h_sched_finish:n                     FROM CALENDAR_DAY+
1_OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n             +
1        AND DAY_YEAR = TO_DATE(SubStr(h_sched_finish, 1, 10)):
1300:
1           EXCEPTION:: SP_U_PARTICIPANT(301) :: cplan.sql(15559) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_finish, 1, 10)), PMO_OR+
1ASTD.TIME('17::00')) INTO h_sched_finish:n                        FROM DUAL:
1315:
1           EXCEPTION:: SP_U_PARTICIPANT(316) :: cplan.sql(15574) :: :
1SC_SS:
1SCHED_START:
1SCHED_FINISH:
1SCHED_DURATION:
1UPDATE TMT_WBS SET SCHED_START = h_sched_start, SCHED_FINISH = h_sched_finish+
1, SCHED_DURATION = h_duration:n                     WHERE ELEMENT_ID = a_temp+
1_id:
1FOUND:
1100:
1338:
1           EXCEPTION:: SP_U_PARTICIPANT(339) :: cplan.sql(15597) :: :
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_DURATION:
1UPDATE TMT_WBS SET PLANNED_START = h_sched_start, PLANNED_FINISH = h_sched_fi+
1nish, PLANNED_DURATION = h_duration:n                     WHERE ELEMENT_ID = +
1a_temp_id:
1356:
1           EXCEPTION:: SP_U_PARTICIPANT(357) :: cplan.sql(15615) :: :
1SC_SQL_SUCCESS:
1FC_ROLLUP:
1COUNT:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n                 +
1 SELECT 'X' FROM TASK_ASSIGNMENTS:n                  WHERE PROJECT_ID = h_pro+
1ject_id AND TASK_ID = a_temp_id:n                  AND ACTUAL_START IS NOT Nu+
1LL):
1377:
1           EXCEPTION:: SP_U_PARTICIPANT(378) :: cplan.sql(15636) :: :
1385:
1        RETURN_ERROR:: SP_U_PARTICIPANT(386) :: cplan.sql(15644) :: :
1CANNOT_UPDATE_HAS_ACTUAL:
1388:
1                EXIT:: SP_U_PARTICIPANT(389) :: cplan.sql(15647) :: :
1406:
1           EXCEPTION:: SP_U_PARTICIPANT(407) :: cplan.sql(15665) :: :
1421:
1           EXCEPTION:: SP_U_PARTICIPANT(422) :: cplan.sql(15680) :: :
1438:
1           EXCEPTION:: SP_U_PARTICIPANT(439) :: cplan.sql(15697) :: :
1453:
1           EXCEPTION:: SP_U_PARTICIPANT(454) :: cplan.sql(15712) :: :
1FC_CHANGE_TA_DATES:
1468:
1        RETURN_ERROR:: SP_U_PARTICIPANT(469) :: cplan.sql(15727) :: :
1471:
1                EXIT:: SP_U_PARTICIPANT(472) :: cplan.sql(15730) :: :
1ELSIF:
18:
1480:
1      RETURN_INVALID:: SP_U_PARTICIPANT(481) :: cplan.sql(15739) :: :
1SC_TASK_ACTUAL_GRATER_THAN_SCH:
1483:
1                EXIT:: SP_U_PARTICIPANT(484) :: cplan.sql(15742) :: :
1PMO_RETURN_INVALID_SP:
1A:
1TA:
1ACTIVITIES:
1TYPE_ID:
1SC_TIMESHEET_ACTIVITY:
1SELECT COUNT('X') INTO h_temp_var:n               FROM DUAL:n               W+
1HERE EXISTS(SELECT A.ELEMENT_ID FROM TASK_ASSIGNMENTS TA, ACTIVITIES A:n     +
1          WHERE TA.TASK_ID = a_temp_id:n               AND TA.TSK_ASSIGNMENT_+
1ID = A.TSK_ASSIGNMENT_ID:n               AND A.TSK_ASSIGNMENT_ID <> A.ELEMENT+
1_ID:n               AND A.TYPE_ID = PMO_CNST.SC_TIMESHEET_ACTIVITY):
1506:
1           EXCEPTION:: SP_U_PARTICIPANT(507) :: cplan.sql(15765) :: :
1513:
1        RETURN_ERROR:: SP_U_PARTICIPANT(514) :: cplan.sql(15772) :: :
1SC_TIMESHEET_STEP_EXISTS:
1516:
1                EXIT:: SP_U_PARTICIPANT(517) :: cplan.sql(15775) :: :
1JOIN:
1TIMESHEET_APPROVAL_STATUS:
1APV:
1WEEK_OF:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n               SE+
1LECT 'X' FROM TASK_ASSIGNMENTS ta JOIN TIMESHEET_APPROVAL_STATUS apv:n       +
1        ON apv.ELEMENT_ID = ta.PROJECT_ID AND apv.RESOURCE_ID = ta.RESOURCE_I+
1D:n               WHERE ta.PROJECT_ID = h_project_id AND ta.TASK_ID = a_temp_+
1id AND:n               (TO_DATE(SubStr(ta.ACTUAL_START, 1, 10)) - 7     ) <= +
1apv.WEEK_OF):
1535:
1           EXCEPTION:: SP_U_PARTICIPANT(536) :: cplan.sql(15794) :: :
1543:
1        RETURN_ERROR:: SP_U_PARTICIPANT(544) :: cplan.sql(15802) :: :
1TS_APPROVAL_ERROR:
1546:
1                EXIT:: SP_U_PARTICIPANT(547) :: cplan.sql(15805) :: :
1FC_U_TASK_PERCENT:
1567:
1        RETURN_ERROR:: SP_U_PARTICIPANT(568) :: cplan.sql(15826) :: :
1570:
1                EXIT:: SP_U_PARTICIPANT(571) :: cplan.sql(15829) :: :
1580:
1        RETURN_ERROR:: SP_U_PARTICIPANT(581) :: cplan.sql(15839) :: :
1583:
1                EXIT:: SP_U_PARTICIPANT(584) :: cplan.sql(15842) :: :
1SELECT PROJECT_ID, TASK_TYPE, MINUTE_PER_DAY:n            INTO h_project_id, +
1h_task_type, h_per_day:n            FROM TMT_WBS WHERE PROJECT_ID = h_project+
1_id AND ELEMENT_ID = h_task_id:
1599:
1           EXCEPTION:: SP_U_PARTICIPANT(600) :: cplan.sql(15858) :: :
1SELECT TASK_TYPE, MINUTE_PER_DAY INTO h_task_type, h_per_day:n               +
1   FROM TMT_WBS:n                  WHERE PROJECT_ID = h_project_id AND ELEMEN+
1T_ID = h_task_id:
1633:
1           EXCEPTION:: SP_U_PARTICIPANT(634) :: cplan.sql(15892) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_finish, 1, 10)), PMO_OR+
1ASTD.TIME(h_finish_date)):n                  INTO h_sched_finish:n           +
1       FROM DUAL:
1732:
1           EXCEPTION:: SP_U_PARTICIPANT(733) :: cplan.sql(15991) :: :
1STRCMP:
1FC_TPHASE_SCHED_ASSIGN:
1TASK_DAY_OF_YEAR:
1SCHED_MIN:
1ACTUAL_MIN:
1UPDATE TASK_DAY_OF_YEAR SET SCHED_MIN = ACTUAL_MIN:n                     WHER+
1E PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = a_temp_id AND DAY_YEAR = +
1TO_DATE(SubStr(h_last_submitted, 1, 10)):
1757:
1           EXCEPTION:: SP_U_PARTICIPANT(758) :: cplan.sql(16016) :: :
12:
1FC_FD_CTD_TDY:
1SELECT TO_DATE(SubStr(h_start_date, 1, 10)), TO_DATE(SubStr(h_sched_finish, 1+
1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULAR_COST, REGULAR_RATE:n              +
1    INTO h_SD, h_FD, h_billable, h_capital_expense, h_reg_cost, h_reg_sale:n +
1                 FROM TASK_ASSIGNMENTS:n                  WHERE TSK_ASSIGNMEN+
1T_ID = a_temp_id:
1784:
1           EXCEPTION:: SP_U_PARTICIPANT(785) :: cplan.sql(16043) :: :
14:
1797:
1       RETURN_STATUS:: SP_U_PARTICIPANT(798) :: cplan.sql(16056) :: :
1PMO_RETURN_STATUS:
1<:
1SELECT START_DT INTO h_start_date:n                  FROM TMT_WBS:n          +
1        WHERE ELEMENT_ID = h_task_id:
1817:
1           EXCEPTION:: SP_U_PARTICIPANT(818) :: cplan.sql(16076) :: :
1SELECT * FROM (SELECT DAY_YEAR FROM CALENDAR_DAY_OF_YEAR :
1WHERE ELEMENT_ID = ':
1' AND DAY_YEAR < TO_DATE(SubStr(':
1', 1, 10)) :
1ORDER BY DAY_YEAR DESC) WHERE ROWNUM<=:
1OPEN:
1LOOP:
1EXIT:
1CLOSE:
1873:
1           EXCEPTION:: SP_U_PARTICIPANT(874) :: cplan.sql(16132) :: :
1886:
1           EXCEPTION:: SP_U_PARTICIPANT(887) :: cplan.sql(16145) :: :
1IS NULL:
1896:
1        RETURN_ERROR:: SP_U_PARTICIPANT(897) :: cplan.sql(16155) :: :
1899:
1                EXIT:: SP_U_PARTICIPANT(900) :: cplan.sql(16158) :: :
1904:
1        RETURN_ERROR:: SP_U_PARTICIPANT(905) :: cplan.sql(16163) :: :
1907:
1                EXIT:: SP_U_PARTICIPANT(908) :: cplan.sql(16166) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_dayofyear, 1, 10)), PMO_ORAST+
1D.TIME(h_start_date)):n                  INTO h_start_date:n                 +
1 FROM DUAL:
1923:
1           EXCEPTION:: SP_U_PARTICIPANT(924) :: cplan.sql(16182) :: :
1934:
1        RETURN_ERROR:: SP_U_PARTICIPANT(935) :: cplan.sql(16193) :: :
1937:
1                EXIT:: SP_U_PARTICIPANT(938) :: cplan.sql(16196) :: :
1103079040:
1947:
1      RETURN_INVALID:: SP_U_PARTICIPANT(948) :: cplan.sql(16206) :: :
1INVALID_PARAMS:
1950:
1                EXIT:: SP_U_PARTICIPANT(951) :: cplan.sql(16209) :: :
1SELECT UNITS_MSP INTO h_temp_var:n                  FROM TASK_ASSIGNMENTS:n  +
1                WHERE TSK_ASSIGNMENT_ID = h_prj_assign_id:
1982:
1           EXCEPTION:: SP_U_PARTICIPANT(983) :: cplan.sql(16241) :: :
1990:
1        RETURN_ERROR:: SP_U_PARTICIPANT(991) :: cplan.sql(16249) :: :
1TASK_ASSIGNMENT_ERROR:
1993:
1                EXIT:: SP_U_PARTICIPANT(994) :: cplan.sql(16252) :: :
190:
1CONSIDER:
1BIT_OR:
1SC_SCHED_BIT:
1SC_PLANNED_BIT:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, UNITS_MSP = h_percent_units,:n     +
1          C_EFFORT = 0, C_UNIT = 0, C_CONTOUR = 0, CONTOUR_TYPE = 1,:n       +
1        ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,(PMO_CNST.SC_SCHED_BIT+PMO_+
1CNST.SC_PLANNED_BIT)):n               WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11081:
1           EXCEPTION:: SP_U_PARTICIPANT(1082) :: cplan.sql(16340) :: :
1FC_U_TDY_LAST_ACTUAL:
1FC_DEL_NOACTUAL:
1PMO_FUNC:
1SC_BIT_30:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)):n                     INTO h_start_date:n         +
1            FROM DUAL:
11129:
1           EXCEPTION:: SP_U_PARTICIPANT(1130) :: cplan.sql(16388) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                     INTO h_start_date:n+
1                     FROM DUAL:
11144:
1           EXCEPTION:: SP_U_PARTICIPANT(1145) :: cplan.sql(16403) :: :
1FC_RESCHEDULE:
11162:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1163) :: cplan.sql(16421) :: :
11165:
1                EXIT:: SP_U_PARTICIPANT(1166) :: cplan.sql(16424) :: :
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_ASSIGN_STRING:
1ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,(PMO_CNST.SC_SCHED_BIT+PMO_CNST.SC_PLANNED_BIT)),:n                  B+
1AK_START_DT = COALESCE(SCHED_START,PLANNED_START), BAK_FINISH_DT = COALESCE(S+
1CHED_FINISH,PLANNED_FINISH),:n                  BAK_ASSIGN_STRING = ASSIGN_ST+
1RING:n                  WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11184:
1           EXCEPTION:: SP_U_PARTICIPANT(1185) :: cplan.sql(16443) :: :
11192:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1193) :: cplan.sql(16451) :: :
11195:
1                EXIT:: SP_U_PARTICIPANT(1196) :: cplan.sql(16454) :: :
1SELECT COUNT('X') INTO h_temp_var:n               FROM DUAL:n               W+
1HERE EXISTS(SELECT ELEMENT_ID FROM ACTIVITIES:n               WHERE TSK_ASSIG+
1NMENT_ID = a_temp_id:n               AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n   +
1            AND TYPE_ID = PMO_CNST.SC_TIMESHEET_ACTIVITY):
11215:
1           EXCEPTION:: SP_U_PARTICIPANT(1216) :: cplan.sql(16474) :: :
11222:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1223) :: cplan.sql(16481) :: :
11225:
1                EXIT:: SP_U_PARTICIPANT(1226) :: cplan.sql(16484) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)):n                        INTO h_start_date:n      +
1                  FROM DUAL:
11263:
1           EXCEPTION:: SP_U_PARTICIPANT(1264) :: cplan.sql(16522) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                        INTO h_start_dat+
1e:n                        FROM DUAL:
11278:
1           EXCEPTION:: SP_U_PARTICIPANT(1279) :: cplan.sql(16537) :: :
1SELECT SCHED_MIN - ACTUAL_MIN INTO h_minutes:n                        FROM TA+
1SK_DAY_OF_YEAR :n                        WHERE PROJECT_ID = h_project_id AND +
1TSK_ASSIGNMENT_ID = a_temp_id AND DAY_YEAR = TO_DATE(SubStr(h_last_submitted,+
1 1, 10)):
11295:
1           EXCEPTION:: SP_U_PARTICIPANT(1296) :: cplan.sql(16554) :: :
110000:
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,PMO_CNST.SC_SCHED_BIT),:n                  SCHED_WORK = h_new_actual, +
1WORK_TODATE = h_new_actual, ETC = 0, MILESTONE_PERCENT = 10000,:n            +
1      FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION = 0:n +
1                 WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11321:
1           EXCEPTION:: SP_U_PARTICIPANT(1322) :: cplan.sql(16580) :: :
11335:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1336) :: cplan.sql(16594) :: :
11338:
1                EXIT:: SP_U_PARTICIPANT(1339) :: cplan.sql(16597) :: :
1TRUNC:
1/:
1*:
110000.00:
10.4:
1FC_U_ASSIGN_PERCENT:
11360:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1361) :: cplan.sql(16619) :: :
11363:
1                EXIT:: SP_U_PARTICIPANT(1364) :: cplan.sql(16622) :: :
11369:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1370) :: cplan.sql(16628) :: :
11372:
1                EXIT:: SP_U_PARTICIPANT(1373) :: cplan.sql(16631) :: :
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = p_work_percent,:n            +
1   ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_PERCENT_COMPLETE_BIT+
1):n               WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11424:
1           EXCEPTION:: SP_U_PARTICIPANT(1425) :: cplan.sql(16683) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_PERC+
1ENT_COMPLETE_BIT):n               WHERE PROJECT_ID = h_project_id AND ELEMENT+
1_ID = h_task_id:
11446:
1           EXCEPTION:: SP_U_PARTICIPANT(1447) :: cplan.sql(16705) :: :
11456:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1457) :: cplan.sql(16715) :: :
11459:
1                EXIT:: SP_U_PARTICIPANT(1460) :: cplan.sql(16718) :: :
1SECURITY_ID:
1SELECT ra.SECURITY_ID, ra.PARTICIPANT, ra.ELEMENT_ID, ra.ELEMENT_TYPE,:n     +
1       CASE WHEN ra.RESOURCE_TYPE = '0' THEN 0 ELSE 1 END,:n            CASE +
1WHEN ra.CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END,:n            ra.RESOURCE_I+
1D,:n            ra.PROJECT_ID, ra.TABLE_TYPE:n            INTO h_security_id,+
1 a_participant, a_element_id, a_element_type,:n            a_resource_type,:n+
1            h_transfed_cri,:n            a_participant_id,:n            h_pro+
1ject_id, h_table_type:n            FROM RESOURCE_ASSIGNMENTS ra WHERE ra.RES_+
1ASSIGNMENT_ID = a_res_assignment_id:
11481:
1           EXCEPTION:: SP_U_PARTICIPANT(1482) :: cplan.sql(16740) :: :
1NOT:
11489:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1490) :: cplan.sql(16748) :: :
11492:
1                EXIT:: SP_U_PARTICIPANT(1493) :: cplan.sql(16751) :: :
11501:
1        RETURN_ERROR:: SP_U_PARTICIPANT(1502) :: cplan.sql(16760) :: :
11504:
1                EXIT:: SP_U_PARTICIPANT(1505) :: cplan.sql(16763) :: :
1SC_TABLE_WBS:
1FC_U_ASSIGNED_SECURITY:
11519:
1       RETURN_STATUS:: SP_U_PARTICIPANT(1520) :: cplan.sql(16778) :: :
1RETURN_ERROR_EXCEPTION:
11526:
1           EXCEPTION:: SP_U_PARTICIPANT(1527) :: cplan.sql(16785) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11538:
1           EXCEPTION:: SP_U_PARTICIPANT(1539) :: cplan.sql(16797) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
24c7
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 :2 a0 6b
1c 81 b0 a3 :2 a0 6b 1c 81
b0 a3 :2 a0 6b 1c 81 b0 :2 a0
6b :2 a0 6b 6e a5 b a 10
:2 a0 6b 6e :2 a0 6b 6e a5 b
6e 7e a0 b4 2e 6e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :2 a0
6e 7e a0 b4 2e 7e 6e b4
2e 6e a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :2 a0 6e
7e a0 b4 2e 7e 6e b4 2e
6e a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
a0 51 d a0 6e d :2 a0 d
:2 a0 d :2 a0 d :20 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:52 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :20 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :2 a0 d :2 a0 d :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
a0 7e b4 2e :2 5a :2 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
5a a0 7e a0 51 a5 b b4
2e 5a 52 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
:10 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :9 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 3c :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e a0 4d d b7
19 3c b7 :10 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :9 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c a0 51 d
b7 :2 19 3c :2 a0 51 a5 b a0
7e a0 6b b4 2e :9 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a :3 a0 a5 b d
b7 19 3c b7 :9 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e :10 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :9 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 :10 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :9 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 :2 19 3c :c a0 51 a5 b 51
a5 b d :2 a0 51 a5 b 7e
51 b4 2e :3 a0 a5 b d b7
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 51 a5 b :2 a0 a5 57
b7 :2 19 3c b7 :2 19 3c a0 b7
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
a0 51 d :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 a0 b7
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e a0 51 d b7
:2 19 3c a0 51 d :18 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :1c a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :2 a0
d :8 a0 51 a5 b a5 b d
b7 :2 19 3c :2 a0 51 a5 b 7e
51 b4 2e :3 a0 a5 b d b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 51 a5 b :2 a0
a5 57 a0 b7 a0 7e b4 2e
5a a0 7e b4 2e 5a a 10
:2 a0 d :2 a0 d :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :b a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 :2 51 a5 b 7e 6e b4
2e a0 51 d b7 a0 51 d
b7 :2 19 3c a0 51 d a0 51
d :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 5a 52 10
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e :9 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 d a0
51 d a0 51 d a0 b7 :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e :a a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 6b :2 a0 a5
b d a0 7e 51 b4 2e d
:c a0 a5 b d :2 a0 51 a5 b
7e 51 b4 2e 5a a0 7e b4
2e :2 5a a 10 :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
:2 a0 :2 51 a5 b 7e 6e b4 2e
a0 51 d b7 a0 51 d b7
:2 19 3c :f a0 51 a0 51 a5 b
d :13 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 51 d :c a0
a5 b d :3 a0 a5 b d :2 a0
6b 51 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 a0
b7 19 :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d a0 51 d a0 b7 19
:2 a0 51 a5 b 7e 51 b4 2e
a0 51 d a0 51 d :5 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 19 :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d a0 4d d a0
6e d :2 a0 51 a5 b 7e 51
b4 2e a0 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e d :3 a0 11c
11d b7 a0 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e d :3 a0 11c
11d b7 :2 19 3c :3 a0 51 a5 b
7e 51 b4 2e :2 a0 e9 d3 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :2 a0 e9
d3 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 2b b7 19 3c
b7 a0 47 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 a0 e9 c1 :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c a0
7e b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 19 3c b7 19
3c :a a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 51 d a0
51 d b7 :2 19 3c a0 b7 :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c :2 a0 d b7 :2 19 3c
a0 7e b4 2e 5a :5 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 5a a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c b7 19 3c a0 51 d
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e a0 51 d b7 19
3c :12 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 19 3c
b7 :2 19 3c a0 7e 51 b4 2e
a0 7e 51 b4 2e d :c a0 a5
b d :2 a0 51 a5 b 7e 51
b4 2e 5a a0 7e b4 2e :2 5a
a 10 :9 a0 51 a5 b d b7
19 3c a0 7e b4 2e 5a :4 a0
51 a5 b d b7 :2 a0 :2 51 a5
b 7e 6e b4 2e :4 a0 51 a5
b d b7 :4 a0 51 a5 b d
b7 :2 19 3c b7 :2 19 3c a0 7e
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e :3 a0 6b :2 a0 51 a5
b :2 a0 6b a5 b 5a d :a a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :a a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d b7 19 3c
a0 51 d :a a0 51 a5 b :2 a0
51 a5 b a5 b d :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 a0 b7 a0
7e 51 b4 2e :16 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:3 a0 a5 b d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 19 3c :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :c a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:2 a0 d :3 a0 51 a5 b d :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e a0 7e 51 b4 2e
d :c a0 a5 b d a0 7e b4
2e 5a :4 a0 51 a5 b d b7
:2 a0 :2 51 a5 b 7e 6e b4 2e
:4 a0 51 a5 b d b7 :4 a0 51
a5 b d b7 :2 19 3c b7 :2 19
3c a0 51 d a0 7e b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e :3 a0 6b :2 a0 51 a5 b :2 a0
6b a5 b 5a d :a a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :a a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
51 a5 b 7e 51 b4 2e :c a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 19 3c
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e 7e :2 a0 51 a5 b
b4 2e d a0 51 d :13 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 51 d :8 a0 51 :2 a0 51 a5
b a5 b d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 19 3c b7
19 3c :3 a0 51 a5 b d b7
:4 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e 5a 7e 51 b4 2e
5a 7e 51 b4 2e a5 b d
b7 :2 19 3c :1b a0 51 a5 b a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 51 a5 b :2 a0
a5 57 a0 b7 :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :b a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :b a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :3 a0 a5 b d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 51 a5 b :2 a0 a5 57 b7
19 :20 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a 7e b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :2 a0 6b :2 a0 a5 b 7e
51 b4 2e :2 a0 6b 51 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 :2 19 3c b7 19 3c :2 a0
d :2 a0 d :2 a0 d :3 a0 6b d
:2 a0 6b :5 a0 a5 b d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :2 a0 6b :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e :2 a0 6b b4 2e 7e 6e b4
2e 7e :2 a0 6b b4 2e a5 57
b7 19 3c :9 a0 12a e9 dd :2 a0
65 b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c :7 a0 12a e9 dd :2 a0 65 b7
a4 b1 11 4f b7 a6 9 a4
b1 11 68 4f 1d 17 b5 
24c7
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 a2
c8 cc d0 d4 d7 db f8 e3
e7 ea eb f3 e2 115 103 df
107 108 110 102 132 120 ff 124
125 12d 11f 14f 13d 11c 141 142
14a 13c 16c 15a 139 15e 15f 167
159 189 177 156 17b 17c 184 176
1a6 194 173 198 199 1a1 193 1c3
1b1 190 1b5 1b6 1be 1b0 1e0 1ce
1ad 1d2 1d3 1db 1cd 1fd 1eb 1ca
1ef 1f0 1f8 1ea 21a 208 1e7 20c
20d 215 207 237 225 204 229 22a
232 224 254 242 221 246 247 24f
241 270 25f 263 26b 23e 288 277
27b 283 25e 2a4 293 297 29f 25b
2bc 2ab 2af 2b7 292 2d8 2c7 2cb
2d3 28f 2f0 2df 2e3 2eb 2c6 30c
2fb 2ff 307 2c3 324 313 317 31f
2fa 340 32f 333 33b 2f7 35c 347
34b 34e 34f 357 32e 379 367 32b
36b 36c 374 366 395 384 388 363
390 383 3b1 3a0 3a4 380 3ac 39f
3cd 3bc 3c0 39c 3c8 3bb 3e9 3d8
3dc 3e4 3b8 401 3f0 3f4 3fc 3d7
41d 40c 410 3d4 418 40b 439 428
42c 408 434 427 455 444 448 424
450 443 471 460 464 440 46c 45f
48d 47c 480 45c 488 47b 4a9 498
49c 478 4a4 497 4c5 4b4 4b8 494
4c0 4b3 4e1 4d0 4d4 4b0 4dc 4cf
4fd 4ec 4f0 4cc 4f8 4eb 519 508
50c 4e8 514 507 536 524 504 528
529 531 523 553 541 520 545 546
54e 540 570 55e 53d 562 563 56b
55d 58c 57b 57f 55a 587 57a 5a8
597 59b 577 5a3 596 5c4 5b3 5b7
593 5bf 5b2 5e0 5cf 5d3 5af 5db
5ce 5fc 5eb 5ef 5cb 5f7 5ea 618
607 60b 5e7 613 606 634 623 627
603 62f 622 650 63f 643 61f 64b
63e 66c 65b 65f 63b 667 65a 688
677 67b 657 683 676 6a4 693 697
673 69f 692 6c0 6af 6b3 68f 6bb
6ae 6dc 6cb 6cf 6ab 6d7 6ca 6f8
6e7 6eb 6c7 6f3 6e6 714 703 707
6e3 70f 702 730 71f 723 6ff 72b
71e 74c 73b 73f 71b 747 73a 768
757 75b 737 763 756 784 773 777
753 77f 772 7a0 78f 793 76f 79b
78e 7bc 7ab 7af 78b 7b7 7aa 7d8
7c7 7cb 7a7 7d3 7c6 7f4 7e3 7e7
7c3 7ef 7e2 810 7ff 803 7df 80b
7fe 82d 81b 7fb 81f 820 828 81a
84a 838 817 83c 83d 845 837 866
855 859 834 861 854 883 871 851
875 876 87e 870 89f 88e 892 86d
89a 88d 8bb 8aa 8ae 88a 8b6 8a9
8d7 8c6 8ca 8a6 8d2 8c5 8f3 8e2
8e6 8c2 8ee 8e1 90f 8fe 902 8de
90a 8fd 92b 91a 91e 8fa 926 919
947 936 93a 916 942 935 963 952
956 932 95e 951 97f 96e 972 94e
97a 96d 99b 98a 98e 96a 996 989
9b7 9a6 9aa 986 9b2 9a5 9d4 9c2
9a2 9c6 9c7 9cf 9c1 9f0 9df 9e3
9eb 9be a08 9f7 9fb a03 9de a28
a13 a17 9db a1b a23 a12 a48 a33
a37 a0f a3b a43 a32 a68 a53 a57
a2f a5b a63 a52 a6f a73 a4f a77
a7b a7f a82 a87 a88 1 a8a a8f
a93 a97 a9a a9f aa3 aa7 aaa aaf
ab0 ab2 ab7 aba abe abf ac4 ac9
acc ad1 ad2 ad7 ada ade adf ae4
ae7 aec aed af2 af5 afa afb b00
b03 b08 b09 b0e b11 b15 b16 b1b
b1e b23 b24 b29 b2c b31 b32 b37
b3a b3e b42 b47 b4a b4e b4f b54
b57 b5c b5d b62 b67 b68 b6a b6f
b70 b72 b73 b78 b7b b80 b81 b86
b89 b8d b91 b96 b99 b9d b9e ba3
ba6 bab bac bb1 bb6 bb7 bb9 bbe
bbf bc1 bc2 bc7 bca bcf bd0 bd5
bd8 bdc be0 be4 be5 be7 bec bed
bef bf0 bf5 bf8 bfd bfe c03 c06
c0a c0e c12 c13 c15 c1a c1b c1d
c1e c23 c26 c2b c2c c31 c34 c38
c3c c40 c41 c43 c48 c49 c4b c4c
c51 c54 c59 c5a c5f c62 c66 c6a
c6e c6f c71 c76 c77 c79 c7a c7f
c82 c87 c88 c8d c90 c95 c96 c9b
c9e ca2 ca3 ca8 cab cb0 cb1 cb6
cb9 cbe cbf cc4 cc5 cca ccc cd0
cd3 cd7 cdb cde ce2 ce6 ce9 cec
cf1 cf4 cf7 cfa cfb d00 d01 1
d03 d08 d0c d10 d13 d18 d1d d20
d24 d25 d2a d2b d30 d32 d36 d39
d3d d40 d44 d48 d4d d51 d55 d59
d5d d61 d65 d69 d6d d71 d75 d79
d7d d81 d85 d89 d8d d91 d95 d99
d9d da1 da5 da9 dad db1 db5 db9
dbd dc1 dc5 dc9 dcd dd1 dd5 dd9
ddd de1 de5 de9 ded df1 df5 e01
e05 e09 e0c e10 e14 e16 1 e1a
e1e e22 e25 e29 e2d e31 e35 e38
e3c e40 e43 e46 e4b e4e e51 e54
e55 e5a e5b 1 e5d e62 e66 e6a
e6d e72 e77 e7a e7e e7f e84 e87
e8c e8d e92 e95 e9a e9b ea0 ea3
ea7 ea8 ead eb0 eb5 eb6 ebb ebe
ec2 ec6 ec9 ecc ecd ecf ed0 ed5
ed6 edb edd ee1 ee4 ee6 eea eec
ef8 efa efc efd f02 f06 f08 f14
f16 f1a f1e f21 f25 f28 f2c f2f
f30 f35 f38 f3c f40 f44 f48 f4c
f50 f54 f58 f5c f60 f64 f68 f6c
f70 f74 f78 f7c f80 f84 f88 f8c
f90 f94 f98 f9c fa0 fa4 fa8 fac
fb0 fb4 fb8 fbc fc0 fc4 fc8 fcc
fd0 fd4 fd8 fdc fe0 fe4 fe8 fec
ff0 ff4 ff8 ffc 1000 1004 1008 100c
1010 1014 1018 101c 1020 1024 1028 102c
1030 1034 1038 103c 1040 1044 1048 104c
1050 1054 1058 105c 1060 1064 1068 106c
1070 1074 1078 107c 1080 108c 1090 1094
1097 109b 109f 10a1 1 10a5 10a9 10ad
10b0 10b4 10b8 10bc 10c0 10c3 10c7 10cb
10ce 10d1 10d6 10d9 10dc 10df 10e0 10e5
10e6 1 10e8 10ed 10f1 10f5 10f8 10fd
1102 1105 1109 110a 110f 1112 1117 1118
111d 1120 1125 1126 112b 112e 1132 1133
1138 113b 1140 1141 1146 1149 114d 1151
1154 1157 1158 115a 115b 1160 1161 1166
1168 116c 116f 1171 1175 1177 1183 1185
1187 1188 118d 1191 1193 119f 11a1 11a5
11a9 11ac 11b0 11b3 11b7 11ba 11bb 11c0
11c3 11c7 11cb 11cf 11d3 11d7 11db 11df
11e3 11e7 11eb 11ef 11f3 11f7 11fb 11ff
1203 1207 120b 120f 1213 1217 121b 121f
1223 1227 122b 122f 1233 1237 123b 123f
1243 124f 1253 1257 125a 125e 1262 1264
1 1268 126c 1270 1273 1277 127b 127f
1283 1286 128a 128e 1291 1294 1299 129c
129f 12a2 12a3 12a8 12a9 1 12ab 12b0
12b4 12b8 12bb 12c0 12c5 12c8 12cc 12cd
12d2 12d5 12da 12db 12e0 12e3 12e8 12e9
12ee 12f1 12f5 12f6 12fb 12fe 1303 1304
1309 130c 1310 1314 1317 131a 131b 131d
131e 1323 1324 1329 132b 132f 1332 1334
1338 133a 1346 1348 134a 134b 1350 1354
1356 1362 1364 1368 136c 136f 1373 1376
137a 137d 137e 1383 1386 138a 138e 1391
1395 1399 139c 139f 13a4 13a7 13aa 13ad
13ae 13b3 13b4 1 13b6 13bb 13bf 13c3
13c6 13cb 13d0 13d3 13d7 13d8 13dd 13e0
13e5 13e6 13eb 13ee 13f3 13f4 13f9 13fc
1400 1404 1408 140c 140f 1410 1412 1417
1418 141a 141b 1420 1423 1428 1429 142e
1431 1436 1437 143c 143f 1443 1444 1449
144c 1451 1452 1457 1458 145d 145f 1463
1466 146a 146e 1471 1475 1479 147c 147f
1484 1487 148a 148d 148e 1493 1494 1
1496 149b 149f 14a3 14a6 14ab 14b0 14b3
14b7 14b8 14bd 14be 14c3 14c5 14c9 14cc
14d0 14d4 14d7 14db 14df 14e2 14e6 14ea
14eb 14f0 14f2 14f6 14f9 14fd 1501 1505
1509 150d 1511 1515 1519 151c 1520 1524
1527 1528 152a 152d 1530 1531 1536 1539
153d 1541 1544 1548 154c 154f 1550 1552
1555 1558 1559 155e 1 1561 1566 156a
156e 1571 1575 1579 157c 157f 1584 1587
158a 158d 158e 1593 1594 1 1596 159b
159f 15a3 15a6 15ab 15b0 15b3 15b7 15b8
15bd 15c0 15c5 15c6 15cb 15ce 15d3 15d4
15d9 15dc 15e0 15e4 15e8 15ec 15ef 15f0
15f2 15f7 15f8 15fa 15fb 1600 1603 1608
1609 160e 1611 1616 1617 161c 161f 1623
1624 1629 162c 1631 1632 1637 1638 163d
163f 1643 1646 164a 164e 1651 1655 1659
165c 165f 1664 1667 166a 166d 166e 1673
1674 1 1676 167b 167f 1683 1686 168b
1690 1693 1697 1698 169d 169e 16a3 16a5
16a9 16ac 16b0 16b4 16b7 16bb 16bf 16c2
16c6 16ca 16cb 16d0 16d2 16d6 16d9 16dd
16e0 16e1 16e6 16e9 16ec 16f0 16f4 16f7
16f8 16fa 16fd 1701 1705 1708 1709 170b
170c 1711 1714 1718 171b 171f 1722 1723
1725 1726 172b 1 172e 1733 1737 173b
173e 1742 1746 1749 174c 1751 1754 1757
175a 175b 1760 1761 1 1763 1768 176c
1770 1773 1778 177d 1780 1784 1785 178a
178d 1792 1793 1798 179b 17a0 17a1 17a6
17a9 17ad 17b1 17b5 17b9 17bc 17bd 17bf
17c4 17c5 17c7 17c8 17cd 17d0 17d5 17d6
17db 17de 17e3 17e4 17e9 17ec 17f0 17f1
17f6 17f9 17fe 17ff 1804 1805 180a 180c
1810 1813 1817 181b 181e 1822 1826 1829
182c 1831 1834 1837 183a 183b 1840 1841
1 1843 1848 184c 1850 1853 1858 185d
1860 1864 1865 186a 186b 1870 1872 1876
1879 187d 1881 1884 1888 188c 188f 1893
1897 1898 189d 189f 18a3 18a6 18aa 18ae
18b1 18b5 18b9 18bc 18bd 18bf 18c2 18c5
18c6 18cb 18ce 18d2 18d6 18d9 18dd 18e1
18e4 18e5 18e7 18ea 18ed 18ee 18f3 1
18f6 18fb 18ff 1903 1906 1907 1909 190c
190f 1910 1915 1919 191d 1920 1924 1928
192b 192c 192e 1931 1934 1935 193a 193e
1942 1946 194a 194e 1952 1956 195a 195e
1962 1966 196a 196e 1972 1976 197a 1986
198a 198e 1991 1995 1999 199b 1 199f
19a3 19a7 19aa 19ae 19b2 19b6 19ba 19bd
19c1 19c5 19c8 19cb 19d0 19d3 19d6 19d9
19da 19df 19e0 1 19e2 19e7 19eb 19ef
19f2 19f7 19fc 19ff 1a03 1a04 1a09 1a0c
1a11 1a12 1a17 1a1a 1a1f 1a20 1a25 1a28
1a2c 1a2d 1a32 1a35 1a3a 1a3b 1a40 1a43
1a47 1a4b 1a4e 1a51 1a52 1a54 1a55 1a5a
1a5b 1a60 1a62 1a66 1a69 1a6b 1a6f 1a71
1a7d 1a7f 1a81 1a82 1a87 1a8b 1a8d 1a99
1a9b 1a9f 1aa3 1aa6 1aaa 1aad 1ab1 1ab4
1ab5 1aba 1abd 1ac1 1ac5 1ac9 1acd 1ad1
1ad5 1ad9 1add 1ae1 1aed 1af1 1af5 1af8
1afc 1b00 1b02 1 1b06 1b0a 1b0e 1b11
1b15 1b19 1b1d 1b21 1b24 1b28 1b2c 1b2f
1b32 1b37 1b3a 1b3d 1b40 1b41 1b46 1b47
1 1b49 1b4e 1b52 1b56 1b59 1b5e 1b63
1b66 1b6a 1b6b 1b70 1b73 1b78 1b79 1b7e
1b81 1b86 1b87 1b8c 1b8f 1b93 1b94 1b99
1b9c 1ba1 1ba2 1ba7 1baa 1bae 1bb2 1bb5
1bb8 1bb9 1bbb 1bbc 1bc1 1bc2 1bc7 1bc9
1bcd 1bd0 1bd2 1bd6 1bd8 1be4 1be6 1be8
1be9 1bee 1bf2 1bf4 1c00 1c02 1c04 1c08
1c0b 1c0f 1c13 1c16 1c1a 1c1e 1c21 1c22
1c24 1c27 1c2a 1c2b 1c30 1c34 1c35 1c39
1c3b 1c3f 1c42 1c44 1c48 1c4c 1c50 1c54
1c58 1c5c 1c60 1c64 1c68 1c6c 1c70 1c74
1c78 1c7c 1c80 1c84 1c90 1c94 1c98 1c9b
1c9f 1ca3 1ca5 1 1ca9 1cad 1cb1 1cb4
1cb8 1cbc 1cc0 1cc4 1cc7 1ccb 1ccf 1cd2
1cd5 1cda 1cdd 1ce0 1ce3 1ce4 1ce9 1cea
1 1cec 1cf1 1cf5 1cf9 1cfc 1d01 1d06
1d09 1d0d 1d0e 1d13 1d16 1d1b 1d1c 1d21
1d24 1d29 1d2a 1d2f 1d32 1d36 1d37 1d3c
1d3f 1d44 1d45 1d4a 1d4d 1d51 1d55 1d58
1d5b 1d5c 1d5e 1d5f 1d64 1d65 1d6a 1d6c
1d70 1d73 1d75 1d79 1d7b 1d87 1d89 1d8b
1d8c 1d91 1d95 1d97 1da3 1da5 1da9 1dad
1db0 1db4 1db7 1dbb 1dbe 1dbf 1dc4 1dc7
1dcb 1dcf 1dd3 1dd7 1ddb 1ddf 1de3 1de7
1deb 1df7 1dfb 1dff 1e02 1e06 1e0a 1e0c
1 1e10 1e14 1e18 1e1b 1e1f 1e23 1e27
1e2b 1e2e 1e32 1e36 1e39 1e3c 1e41 1e44
1e47 1e4a 1e4b 1e50 1e51 1 1e53 1e58
1e5c 1e60 1e63 1e68 1e6d 1e70 1e74 1e75
1e7a 1e7d 1e82 1e83 1e88 1e8b 1e90 1e91
1e96 1e99 1e9d 1e9e 1ea3 1ea6 1eab 1eac
1eb1 1eb4 1eb8 1ebc 1ebf 1ec2 1ec3 1ec5
1ec6 1ecb 1ecc 1ed1 1ed3 1ed7 1eda 1edc
1ee0 1ee2 1eee 1ef0 1ef2 1ef3 1ef8 1efc
1efe 1f0a 1f0c 1f0e 1f12 1f15 1f19 1f1c
1f20 1f22 1f26 1f2a 1f2d 1f31 1f35 1f38
1f39 1f3b 1f3f 1f42 1f46 1f49 1f4a 1f4f
1f53 1f57 1f5b 1f5f 1f63 1f67 1f6b 1f6f
1f73 1f7f 1f83 1f88 1f8c 1f8f 1f90 1f95
1f99 1f9d 1fa0 1fa3 1fa7 1fa9 1fad 1fb1
1fb4 1fb7 1fbb 1fbd 1fc1 1fc5 1fc8 1fca
1 1fce 1fd2 1fd6 1fd9 1fdd 1fe1 1fe5
1fe9 1fec 1ff0 1ff4 1ff7 1ffa 1fff 2002
2005 2008 2009 200e 200f 1 2011 2016
201a 201e 2021 2026 202b 202e 2032 2033
2038 203b 2040 2041 2046 2049 204e 204f
2054 2057 205b 205c 2061 2064 2069 206a
206f 2072 2076 207a 207d 2080 2081 2083
2084 2089 208a 208f 2091 2095 2098 209a
209e 20a0 20ac 20ae 20b0 20b1 20b6 20ba
20bc 20c8 20ca 20cc 20d0 20d4 20d8 20dc
20e0 20e4 20e8 20ec 20f0 20fc 2100 2105
2109 210c 210d 2112 2116 211a 211d 2120
2124 2126 212a 212e 2131 2134 2138 213a
213e 2142 2145 2147 1 214b 214f 2153
2156 215a 215e 2162 2166 2169 216d 2171
2174 2177 217c 217f 2182 2185 2186 218b
218c 1 218e 2193 2197 219b 219e 21a3
21a8 21ab 21af 21b0 21b5 21b8 21bd 21be
21c3 21c6 21cb 21cc 21d1 21d4 21d8 21d9
21de 21e1 21e6 21e7 21ec 21ef 21f3 21f7
21fa 21fd 21fe 2200 2201 2206 2207 220c
220e 2212 2215 2217 221b 221d 2229 222b
222d 222e 2233 2237 2239 2245 2247 2249
224d 2251 2254 2258 225c 225f 2263 2266
226a 226d 226e 2273 2276 227a 227e 2282
2283 2285 2289 228b 228f 2292 2294 2298
229c 22a0 22a4 22a8 22ac 22b0 22b4 22b8
22c4 22c8 22cc 22cf 22d3 22d7 22d9 1
22dd 22e1 22e5 22e8 22ec 22f0 22f4 22f8
22fb 22ff 2303 2306 2309 230e 2311 2314
2317 2318 231d 231e 1 2320 2325 2329
232d 2330 2335 233a 233d 2341 2342 2347
234a 234f 2350 2355 2358 235d 235e 2363
2366 236a 236b 2370 2373 2378 2379 237e
2381 2385 2389 238c 238f 2390 2392 2393
2398 2399 239e 23a0 23a4 23a7 23a9 23ad
23af 23bb 23bd 23bf 23c0 23c5 23c9 23cb
23d7 23d9 23dd 23e1 23e4 23e5 23e7 23ea
23ed 23ee 23f3 23f7 23fb 23fe 2402 2406
2409 240c 2411 2414 2417 241a 241b 2420
2421 1 2423 2428 242c 2430 2433 2438
243d 2440 2444 2445 244a 244d 2452 2453
2458 245b 2460 2461 2466 2469 246d 2471
2475 2479 247c 247d 247f 2484 2485 2487
2488 248d 2490 2495 2496 249b 249e 24a3
24a4 24a9 24ac 24b0 24b1 24b6 24b9 24be
24bf 24c4 24c5 24ca 24cc 24d0 24d3 24d7
24db 24de 24e2 24e6 24e9 24ec 24f1 24f4
24f7 24fa 24fb 2500 2501 1 2503 2508
250c 2510 2513 2518 251d 2520 2524 2525
252a 252b 2530 2532 2536 2539 253d 2541
2544 2548 254c 254f 2553 2557 2558 255d
255f 2563 2566 256a 256e 2571 2575 2579
257c 257d 257f 2582 2585 2586 258b 258f
2593 2597 259b 259f 25a3 25a7 25ab 25af
25b3 25b7 25bb 25bf 25c3 25c7 25cb 25d7
25db 25df 25e2 25e6 25ea 25ec 1 25f0
25f4 25f8 25fb 25ff 2603 2607 260b 260e
2612 2616 2619 261c 2621 2624 2627 262a
262b 2630 2631 1 2633 2638 263c 2640
2643 2648 264d 2650 2654 2655 265a 265d
2662 2663 2668 266b 2670 2671 2676 2679
267d 267e 2683 2686 268b 268c 2691 2694
2698 269c 269f 26a2 26a3 26a5 26a6 26ab
26ac 26b1 26b3 26b7 26ba 26bc 26c0 26c2
26ce 26d0 26d2 26d3 26d8 26dc 26de 26ea
26ec 26f0 26f4 26f7 26fb 26fe 2702 2705
2706 270b 270e 2712 2716 271a 271e 2722
2726 272a 272e 2732 273e 2742 2746 2749
274d 2751 2753 1 2757 275b 275f 2762
2766 276a 276e 2772 2775 2779 277d 2780
2783 2788 278b 278e 2791 2792 2797 2798
1 279a 279f 27a3 27a7 27aa 27af 27b4
27b7 27bb 27bc 27c1 27c4 27c9 27ca 27cf
27d2 27d7 27d8 27dd 27e0 27e4 27e5 27ea
27ed 27f2 27f3 27f8 27fb 27ff 2803 2806
2809 280a 280c 280d 2812 2813 2818 281a
281e 2821 2823 2827 2829 2835 2837 2839
283a 283f 2843 2845 2851 2853 2855 2859
285c 285e 2862 2866 286a 286e 2872 2876
287a 287e 2882 2886 288a 288e 2892 2896
289a 289e 28aa 28ae 28b2 28b5 28b9 28bd
28bf 1 28c3 28c7 28cb 28ce 28d2 28d6
28da 28de 28e1 28e5 28e9 28ec 28ef 28f4
28f7 28fa 28fd 28fe 2903 2904 1 2906
290b 290f 2913 2916 291b 2920 2923 2927
2928 292d 2930 2935 2936 293b 293e 2943
2944 2949 294c 2950 2951 2956 2959 295e
295f 2964 2967 296b 296f 2972 2975 2976
2978 2979 297e 297f 2984 2986 298a 298d
298f 2993 2995 29a1 29a3 29a5 29a6 29ab
29af 29b1 29bd 29bf 29c3 29c7 29ca 29ce
29d1 29d5 29d8 29d9 29de 29e1 29e5 29e9
29ed 29f1 29f5 29f9 29fd 2a01 2a05 2a11
2a15 2a19 2a1c 2a20 2a24 2a26 1 2a2a
2a2e 2a32 2a35 2a39 2a3d 2a41 2a45 2a48
2a4c 2a50 2a53 2a56 2a5b 2a5e 2a61 2a64
2a65 2a6a 2a6b 1 2a6d 2a72 2a76 2a7a
2a7d 2a82 2a87 2a8a 2a8e 2a8f 2a94 2a97
2a9c 2a9d 2aa2 2aa5 2aaa 2aab 2ab0 2ab3
2ab7 2ab8 2abd 2ac0 2ac5 2ac6 2acb 2ace
2ad2 2ad6 2ad9 2adc 2add 2adf 2ae0 2ae5
2ae6 2aeb 2aed 2af1 2af4 2af6 2afa 2afc
2b08 2b0a 2b0c 2b0d 2b12 2b16 2b18 2b24
2b26 2b28 2b2c 2b2f 2b31 2b35 2b39 2b3c
2b40 2b44 2b48 2b4c 2b50 2b54 2b58 2b5c
2b60 2b64 2b68 2b6c 2b6f 2b70 2b72 2b75
2b76 2b78 2b7c 2b80 2b84 2b87 2b88 2b8a
2b8d 2b90 2b91 2b96 2b9a 2b9e 2ba2 2ba3
2ba5 2ba9 2bab 2baf 2bb3 2bb6 2bba 2bbe
2bc1 2bc4 2bc9 2bcc 2bcf 2bd2 2bd3 2bd8
2bd9 1 2bdb 2be0 2be4 2be8 2beb 2bf0
2bf5 2bf8 2bfc 2bfd 2c02 2c05 2c0a 2c0b
2c10 2c13 2c18 2c19 2c1e 2c21 2c25 2c29
2c2d 2c2e 2c30 2c35 2c36 2c38 2c39 2c3e
2c41 2c46 2c47 2c4c 2c4f 2c54 2c55 2c5a
2c5d 2c61 2c62 2c67 2c6a 2c6f 2c70 2c75
2c76 2c7b 2c7d 2c81 2c84 2c88 2c8c 2c8f
2c93 2c97 2c9a 2c9d 2ca2 2ca5 2ca8 2cab
2cac 2cb1 2cb2 1 2cb4 2cb9 2cbd 2cc1
2cc4 2cc9 2cce 2cd1 2cd5 2cd6 2cdb 2cdc
2ce1 2ce3 2ce7 2cea 2cee 2cf2 2cf5 2cf9
2cfd 2d00 2d01 2d03 2d07 2d0b 2d0c 2d11
2d13 2d17 2d1b 2d1e 2d20 2d24 2d28 2d2b
2d2f 2d31 2d35 2d39 2d3c 2d3d 2d3f 2d43
2d46 2d4a 2d4d 2d4e 2d50 2d51 2d56 2d59
2d5d 2d61 2d64 2d65 2d67 2d6a 2d6d 2d6e
2d73 1 2d76 2d7b 2d7f 2d82 2d86 2d8a
2d8e 2d91 2d92 2d94 2d98 2d9b 2d9f 2da2
2da3 2da5 2da6 2dab 2daf 2db3 2db6 2dba
2dbe 2dc1 2dc4 2dc9 2dcc 2dcf 2dd2 2dd3
2dd8 2dd9 1 2ddb 2de0 2de4 2de8 2deb
2df0 2df5 2df8 2dfc 2dfd 2e02 2e05 2e0a
2e0b 2e10 2e13 2e18 2e19 2e1e 2e21 2e25
2e29 2e2d 2e31 2e34 2e35 2e37 2e3c 2e3d
2e3f 2e40 2e45 2e46 2e4b 2e4d 2e51 2e54
2e58 2e5c 2e5f 2e63 2e67 2e6a 2e6d 2e72
2e75 2e78 2e7b 2e7c 2e81 2e82 1 2e84
2e89 2e8d 2e91 2e94 2e99 2e9e 2ea1 2ea5
2ea6 2eab 2eac 2eb1 2eb3 2eb7 2eba 2ebe
2ec2 2ec5 2ec9 2ecd 2ed0 2ed4 2ed5 2eda
2ede 2ee0 2ee4 2ee8 2eeb 2eec 2eee 2ef2
2ef5 2ef9 2efc 2efd 2eff 2f00 2f05 2f09
2f0c 2f10 2f12 2f16 2f1a 2f1d 2f21 2f24
2f28 2f2c 2f30 2f34 2f38 2f3c 2f40 2f44
2f48 2f4c 2f50 2f54 2f58 2f5c 2f60 2f64
2f68 2f6c 2f70 2f74 2f78 2f7c 2f80 2f84
2f88 2f94 2f98 2f9c 2f9f 2fa3 2fa7 2fa9
1 2fad 2fb1 2fb5 2fb8 2fbc 2fc0 2fc4
2fc8 2fcb 2fcf 2fd3 2fd6 2fd9 2fde 2fe1
2fe4 2fe7 2fe8 2fed 2fee 1 2ff0 2ff5
2ff9 2ffd 3000 3005 300a 300d 3011 3012
3017 301a 301f 3020 3025 3028 302d 302e
3033 3036 303a 303b 3040 3043 3048 3049
304e 3051 3055 3059 305c 305f 3060 3062
3063 3068 3069 306e 3070 3074 3077 3079
307d 307f 308b 308d 308f 3090 3095 3099
309b 30a7 30a9 30ad 30b1 30b4 30b5 30b7
30ba 30bd 30be 30c3 30c7 30cb 30ce 30d2
30d6 30d9 30dc 30e1 30e4 30e7 30ea 30eb
30f0 30f1 1 30f3 30f8 30fc 3100 3103
3108 310d 3110 3114 3115 311a 311d 3122
3123 3128 312b 3130 3131 3136 3139 313d
3141 3145 3149 314c 314d 314f 3154 3155
3157 3158 315d 3160 3165 3166 316b 316e
3173 3174 3179 317c 3180 3181 3186 3189
318e 318f 3194 3195 319a 319c 31a0 31a3
31a7 31ab 31ae 31b2 31b6 31b9 31bc 31c1
31c4 31c7 31ca 31cb 31d0 31d1 1 31d3
31d8 31dc 31e0 31e3 31e8 31ed 31f0 31f4
31f5 31fa 31fb 3200 3202 3206 3209 320d
3211 3214 3218 321c 321f 3223 3227 3228
322d 322f 3233 3236 323a 323e 3242 3246
324a 324e 3252 3256 325a 325e 3262 3266
326a 326e 3272 3276 327a 327e 3282 3286
328a 328e 3292 3296 329a 329e 32a2 32a6
32b2 32b6 32ba 32bd 32c1 32c5 32c7 1
32cb 32cf 32d3 32d6 32da 32de 32e2 32e6
32e9 32ed 32f1 32f4 32f7 32fc 32ff 3302
3305 3306 330b 330c 1 330e 3313 3317
331b 331e 3323 3328 332b 332f 3330 3335
3338 333d 333e 3343 3346 334b 334c 3351
3354 3358 3359 335e 3361 3366 3367 336c
336f 3373 3377 337a 337d 337e 3380 3381
3386 3387 338c 338e 3392 3395 3397 339b
339d 33a9 33ab 33ad 33ae 33b3 33b7 33b9
33c5 33c7 33cb 33cf 33d2 33d3 33d5 33d8
33db 33dc 33e1 33e5 33e9 33ec 33f0 33f4
33f7 33fa 33ff 3402 3405 3408 3409 340e
340f 1 3411 3416 341a 341e 3421 3426
342b 342e 3432 3433 3438 343b 3440 3441
3446 3449 344e 344f 3454 3457 345b 345f
3463 3467 346a 346b 346d 3472 3473 3475
3476 347b 347e 3483 3484 3489 348c 3491
3492 3497 349a 349e 349f 34a4 34a7 34ac
34ad 34b2 34b3 34b8 34ba 34be 34c1 34c5
34c9 34cc 34d0 34d4 34d7 34da 34df 34e2
34e5 34e8 34e9 34ee 34ef 1 34f1 34f6
34fa 34fe 3501 3506 350b 350e 3512 3513
3518 3519 351e 3520 3524 3527 352b 352f
3532 3536 353a 353d 3541 3545 3546 354b
354d 3551 3554 3558 355c 3560 3564 3568
356c 3570 3574 3578 357c 3580 3583 3584
3586 3587 3589 358d 358f 3593 3597 359a
359e 35a2 35a5 35a6 35a8 35ab 35ae 35af
35b4 35b8 35bc 35c0 35c1 35c3 35c7 35c9
35cd 35d0 35d4 35d8 35db 35df 35e3 35e6
35e9 35ee 35f1 35f4 35f7 35f8 35fd 35fe
1 3600 3605 3609 360d 3610 3615 361a
361d 3621 3622 3627 362a 362f 3630 3635
3638 363d 363e 3643 3646 364a 364e 3652
3653 3655 365a 365b 365d 365e 3663 3666
366b 366c 3671 3674 3679 367a 367f 3682
3686 3687 368c 368f 3694 3695 369a 369b
36a0 36a2 36a6 36a9 36ad 36b1 36b4 36b8
36bc 36bf 36c2 36c7 36ca 36cd 36d0 36d1
36d6 36d7 1 36d9 36de 36e2 36e6 36e9
36ee 36f3 36f6 36fa 36fb 3700 3701 3706
3708 370c 370f 3713 3717 371a 371e 3722
3725 3726 3728 372c 3730 3731 3736 373a
373c 3740 3743 3744 3749 374c 3750 3753
3754 3759 1 375c 3761 3765 3769 376d
3771 3775 3779 377d 3781 3784 3788 378c
378f 3790 3792 3795 3798 3799 379e 37a1
37a5 37a9 37ac 37b0 37b4 37b7 37b8 37ba
37bd 37c0 37c1 37c6 1 37c9 37ce 37d2
37d6 37d9 37dd 37e1 37e4 37e7 37ec 37ef
37f2 37f5 37f6 37fb 37fc 1 37fe 3803
3807 380b 380e 3813 3818 381b 381f 3820
3825 3828 382d 382e 3833 3836 383b 383c
3841 3844 3848 384c 3850 3854 3857 3858
385a 385f 3860 3862 3863 3868 386b 3870
3871 3876 3879 387e 387f 3884 3887 388b
388c 3891 3894 3899 389a 389f 38a0 38a5
38a7 38ab 38ae 38b2 38b6 38b9 38bd 38c1
38c4 38c7 38cc 38cf 38d2 38d5 38d6 38db
38dc 1 38de 38e3 38e7 38eb 38ee 38f3
38f8 38fb 38ff 3900 3905 3906 390b 390d
3911 3914 3918 391c 391f 3923 3927 392a
392e 3932 3933 3938 393a 393e 3941 3945
3949 394d 3951 3955 3959 395d 3961 3965
3969 396d 3979 397d 3981 3984 3988 398c
398e 1 3992 3996 399a 399d 39a1 39a5
39a9 39ad 39b0 39b4 39b8 39bb 39be 39c3
39c6 39c9 39cc 39cd 39d2 39d3 1 39d5
39da 39de 39e2 39e5 39ea 39ef 39f2 39f6
39f7 39fc 39ff 3a04 3a05 3a0a 3a0d 3a12
3a13 3a18 3a1b 3a1f 3a20 3a25 3a28 3a2d
3a2e 3a33 3a36 3a3a 3a3e 3a41 3a44 3a45
3a47 3a48 3a4d 3a4e 3a53 3a55 3a59 3a5c
3a5e 3a62 3a64 3a70 3a72 3a74 3a75 3a7a
3a7e 3a80 3a8c 3a8e 3a92 3a96 3a99 3a9c
3a9d 3a9f 3aa2 3aa7 3aa8 3aad 3ab1 3ab4
3ab8 3aba 3abe 3ac1 3ac5 3ac7 3acb 3acf
3ad2 3ad6 3ad9 3add 3ae1 3ae4 3ae8 3aec
3af0 3af3 3af7 3afb 3afe 3aff 3b01 3b04
3b07 3b08 3b0d 3b10 3b14 3b18 3b1b 3b1f
3b23 3b26 3b27 3b29 3b2c 3b2f 3b30 3b35
1 3b38 3b3d 3b41 3b45 3b48 3b49 3b4b
3b4f 3b52 3b56 3b59 3b5a 3b5c 3b5d 3b62
1 3b65 3b6a 3b6e 3b72 3b75 3b79 3b7d
3b80 3b81 3b83 3b86 3b89 3b8a 3b8f 3b93
3b97 3b9b 3b9f 3ba3 3ba7 3bab 3baf 3bb3
3bbf 3bc3 3bc7 3bca 3bce 3bd2 3bd4 1
3bd8 3bdc 3be0 3be3 3be7 3beb 3bef 3bf3
3bf6 3bfa 3bfe 3c01 3c04 3c09 3c0c 3c0f
3c12 3c13 3c18 3c19 1 3c1b 3c20 3c24
3c28 3c2b 3c30 3c35 3c38 3c3c 3c3d 3c42
3c45 3c4a 3c4b 3c50 3c53 3c58 3c59 3c5e
3c61 3c65 3c66 3c6b 3c6e 3c73 3c74 3c79
3c7c 3c80 3c84 3c87 3c8a 3c8b 3c8d 3c8e
3c93 3c94 3c99 3c9b 3c9f 3ca2 3ca4 3ca8
3caa 3cb6 3cb8 3cba 3cbb 3cc0 3cc4 3cc6
3cd2 3cd4 3cd8 3cdc 3ce0 3ce4 3ce7 3ceb
3cef 3cf2 3cf6 3cfa 3cfc 3d00 3d04 3d07
3d0b 3d0f 3d12 3d13 3d15 3d18 3d1b 3d1c
3d21 3d25 3d29 3d2d 3d31 3d35 3d39 3d3d
3d41 3d45 3d49 3d55 3d59 3d5d 3d60 3d64
3d68 3d6a 1 3d6e 3d72 3d76 3d79 3d7d
3d81 3d85 3d89 3d8c 3d90 3d94 3d97 3d9a
3d9f 3da2 3da5 3da8 3da9 3dae 3daf 1
3db1 3db6 3dba 3dbe 3dc1 3dc6 3dcb 3dce
3dd2 3dd3 3dd8 3ddb 3de0 3de1 3de6 3de9
3dee 3def 3df4 3df7 3dfb 3dfc 3e01 3e04
3e09 3e0a 3e0f 3e12 3e16 3e1a 3e1d 3e20
3e21 3e23 3e24 3e29 3e2a 3e2f 3e31 3e35
3e38 3e3a 3e3e 3e40 3e4c 3e4e 3e50 3e51
3e56 3e5a 3e5c 3e68 3e6a 3e6e 3e72 3e76
3e79 3e7d 3e81 3e82 3e84 3e88 3e8c 3e8f
3e92 3e93 3e98 3e9c 3ea0 3ea4 3ea8 3eac
3eb0 3eb4 3eb8 3ebc 3ec0 3ec4 3ec8 3ecc
3ecd 3ecf 3ed3 3ed7 3edb 3ede 3edf 3ee1
3ee4 3ee7 3ee8 3eed 3ef0 3ef4 3ef7 3ef8
3efd 3f00 1 3f03 3f08 3f0c 3f10 3f14
3f18 3f1c 3f20 3f24 3f28 3f2c 3f30 3f34
3f40 3f44 3f49 3f4d 3f50 3f51 3f56 3f5a
3f5e 3f61 3f64 3f68 3f6a 3f6e 3f72 3f75
3f78 3f7c 3f7e 3f82 3f86 3f89 3f8b 1
3f8f 3f93 3f97 3f9a 3f9e 3fa2 3fa6 3faa
3fad 3fb1 3fb5 3fb8 3fbb 3fc0 3fc3 3fc6
3fc9 3fca 3fcf 3fd0 1 3fd2 3fd7 3fdb
3fdf 3fe2 3fe7 3fec 3fef 3ff3 3ff4 3ff9
3ffc 4001 4002 4007 400a 400f 4010 4015
4018 401c 401d 4022 4025 402a 402b 4030
4033 4037 403b 403e 4041 4042 4044 4045
404a 404b 4050 4052 4056 4059 405b 405f
4061 406d 406f 4071 4072 4077 407b 407d
4089 408b 408d 4091 4094 4098 409c 409f
40a2 40a3 40a5 40a8 40ad 40ae 40b3 40b7
40ba 40be 40c0 40c4 40c7 40cb 40cd 40d1
40d5 40d8 40dc 40e0 40e4 40e8 40ec 40f0
40f4 40f8 40fc 4100 4104 4108 410c 4110
4114 4117 411b 411e 411f 4121 4125 4129
412d 4131 4135 4139 413d 4141 4145 4149
414d 4151 4155 4159 415d 4161 4165 4169
416d 4171 417d 4181 4185 4188 418c 4190
4192 1 4196 419a 419e 41a1 41a5 41a9
41ad 41b1 41b4 41b8 41bc 41bf 41c2 41c7
41ca 41cd 41d0 41d1 41d6 41d7 1 41d9
41de 41e2 41e6 41e9 41ee 41f3 41f6 41fa
41fb 4200 4203 4208 4209 420e 4211 4216
4217 421c 421f 4223 4224 4229 422c 4231
4232 4237 423a 423e 4242 4245 4248 4249
424b 424c 4251 4252 4257 4259 425d 4260
4262 4266 4268 4274 4276 4278 4279 427e
4282 4284 4290 4292 4296 4299 429d 42a1
42a5 42a9 42ad 42b1 42b5 42b9 42bd 42c1
42c5 42c9 42cd 42ce 42d0 42d4 42d8 42dc
42e0 42e1 42e3 42e7 42eb 42ef 42f2 42f5
42f9 42fd 4301 4304 4308 430c 430f 4312
4317 431a 431d 4320 4321 4326 4327 1
4329 432e 4332 4336 4339 433e 4343 4346
434a 434b 4350 4353 4358 4359 435e 4361
4366 4367 436c 436f 4373 4377 437b 437f
4382 4383 4385 438a 438b 438d 438e 4393
4396 439b 439c 43a1 43a4 43a9 43aa 43af
43b2 43b6 43b7 43bc 43bf 43c4 43c5 43ca
43cb 43d0 43d2 43d6 43d9 43dd 43e1 43e4
43e8 43ec 43ef 43f3 43f7 43f8 43fd 4401
4403 4407 440b 440f 4412 4413 4415 4419
441c 4420 4423 4424 4426 4427 442c 4430
4434 4438 443b 443c 443e 4441 4445 4449
444c 444d 444f 4450 4455 4459 445d 4460
4464 4468 446a 446e 4472 4476 4479 447a
447c 447f 4482 4483 4488 448c 448f 4493
4497 449a 449e 44a2 44a6 44aa 44ae 44b2
44be 44c2 44c6 44c9 44cd 44d1 44d3 1
44d7 44db 44df 44e2 44e6 44ea 44ee 44f2
44f5 44f9 44fd 4500 4503 4508 450b 450e
4511 4512 4517 4518 1 451a 451f 4523
4527 452a 452f 4534 4537 453b 453c 4541
4544 4549 454a 454f 4552 4557 4558 455d
4560 4564 4565 456a 456d 4572 4573 4578
457b 457f 4583 4586 4589 458a 458c 458d
4592 4593 4598 459a 459e 45a1 45a3 45a7
45a9 45b5 45b7 45b9 45ba 45bf 45c3 45c5
45d1 45d3 45d7 45d9 45dd 45e1 45e5 45e8
45e9 45eb 45ef 45f2 45f6 45f9 45fa 45fc
45fd 4602 4606 460a 460e 4611 4612 4614
4617 461b 461f 4622 4623 4625 4626 462b
462f 4633 4634 4638 463c 4641 4645 4649
464d 4650 4651 4653 4656 4659 465a 465f
4663 4668 466b 4670 4671 4676 4679 467d
467e 4683 4686 468b 468c 4691 4694 4698
4699 469e 46a1 46a6 46a7 46ac 46af 46b4
46b5 46ba 46bd 46c1 46c5 46c9 46cc 46cd
46cf 46d0 46d2 46d3 46d8 46dc 46e0 46e4
46e8 46eb 46ef 46f1 46f5 46fa 46fd 4702
4703 4708 470b 470f 4710 4715 4718 471d
471e 4723 4726 472a 472b 4730 4733 4738
4739 473e 4741 4746 4747 474c 474f 4753
4757 475b 475e 475f 4761 4762 4764 4765
476a 476e 4772 4776 477a 477d 4781 4783
4787 478b 478e 4792 4796 479a 479d 479e
47a0 47a3 47a6 47a7 47ac 47b0 47b4 47b9
47be 47c2 47c6 47cb 47cf 47d3 47d6 47d9
47dd 47df 47e3 47e7 47ea 47ed 47f1 47f3
47f7 47fb 47fe 4800 4804 4808 480d 4812
4816 481a 481f 4823 4827 482a 482d 4831
4833 4837 483b 483e 4841 4845 4847 484b
484f 4852 4854 4858 485c 485f 4863 4867
486a 486e 4871 4875 4878 4879 487e 4881
4885 488b 488d 4891 4894 4896 489a 48a1
48a5 48a9 48ac 48ad 48af 48b2 48b5 48b6
48bb 48bf 48c3 48c8 48ca 48ce 48d2 48d5
48d9 48dd 48df 1 48e3 48e7 48eb 48ee
48f2 48f6 48fa 48fe 4901 4905 4909 490c
490f 4914 4917 491a 491d 491e 4923 4924
1 4926 492b 492f 4933 4936 493b 4940
4943 4947 4948 494d 4950 4955 4956 495b
495e 4963 4964 4969 496c 4970 4971 4976
4979 497e 497f 4984 4987 498b 498f 4992
4995 4996 4998 4999 499e 499f 49a4 49a6
49aa 49ad 49af 49b3 49b5 49c1 49c3 49c5
49c6 49cb 49cf 49d1 49dd 49df 49e1 49e5
49e9 49ee 49f0 49f4 49f8 49fb 49ff 4a03
4a05 1 4a09 4a0d 4a11 4a14 4a18 4a1c
4a20 4a24 4a27 4a2b 4a2f 4a32 4a35 4a3a
4a3d 4a40 4a43 4a44 4a49 4a4a 1 4a4c
4a51 4a55 4a59 4a5c 4a61 4a66 4a69 4a6d
4a6e 4a73 4a76 4a7b 4a7c 4a81 4a84 4a89
4a8a 4a8f 4a92 4a96 4a97 4a9c 4a9f 4aa4
4aa5 4aaa 4aad 4ab1 4ab5 4ab8 4abb 4abc
4abe 4abf 4ac4 4ac5 4aca 4acc 4ad0 4ad3
4ad5 4ad9 4adb 4ae7 4ae9 4aeb 4aec 4af1
4af5 4af7 4b03 4b05 4b07 4b0b 4b0f 4b12
4b16 4b19 4b1a 4b1f 4b22 4b26 4b2a 4b2d
4b2e 4b30 4b33 4b36 4b37 4b3c 4b40 4b44
4b47 4b4b 4b4f 4b52 4b55 4b5a 4b5d 4b60
4b63 4b64 4b69 4b6a 1 4b6c 4b71 4b75
4b79 4b7c 4b81 4b86 4b89 4b8d 4b8e 4b93
4b96 4b9b 4b9c 4ba1 4ba4 4ba9 4baa 4baf
4bb2 4bb6 4bba 4bbe 4bc2 4bc5 4bc6 4bc8
4bcd 4bce 4bd0 4bd1 4bd6 4bd9 4bde 4bdf
4be4 4be7 4bec 4bed 4bf2 4bf5 4bf9 4bfa
4bff 4c02 4c07 4c08 4c0d 4c0e 4c13 4c15
4c19 4c1c 4c20 4c24 4c27 4c2b 4c2f 4c32
4c35 4c3a 4c3d 4c40 4c43 4c44 4c49 4c4a
1 4c4c 4c51 4c55 4c59 4c5c 4c61 4c66
4c69 4c6d 4c6e 4c73 4c74 4c79 4c7b 4c7f
4c82 4c86 4c8a 4c8d 4c91 4c95 4c98 4c9c
4ca0 4ca1 4ca6 4ca8 4cac 4cb0 4cb3 4cb7
4cbb 4cbe 4cc1 4cc6 4cc9 4ccc 4ccf 4cd0
4cd5 4cd6 1 4cd8 4cdd 4ce1 4ce5 4ce8
4ced 4cf2 4cf5 4cf9 4cfa 4cff 4d02 4d07
4d08 4d0d 4d10 4d15 4d16 4d1b 4d1e 4d22
4d26 4d2a 4d2e 4d31 4d32 4d34 4d39 4d3a
4d3c 4d3d 4d42 4d45 4d4a 4d4b 4d50 4d53
4d58 4d59 4d5e 4d61 4d65 4d66 4d6b 4d6e
4d73 4d74 4d79 4d7a 4d7f 4d81 4d85 4d88
4d8c 4d90 4d93 4d97 4d9b 4d9e 4da1 4da6
4da9 4dac 4daf 4db0 4db5 4db6 1 4db8
4dbd 4dc1 4dc5 4dc8 4dcd 4dd2 4dd5 4dd9
4dda 4ddf 4de0 4de5 4de7 4deb 4dee 4df2
4df6 4df9 4dfd 4e01 4e04 4e08 4e0c 4e0d
4e12 4e14 4e18 4e1c 4e1f 4e21 4e25 4e28
4e2c 4e30 4e34 4e38 4e3c 4e40 4e44 4e48
4e4c 4e50 4e5c 4e60 4e64 4e67 4e6b 4e6f
4e71 1 4e75 4e79 4e7d 4e80 4e84 4e88
4e8c 4e90 4e93 4e97 4e9b 4e9e 4ea1 4ea6
4ea9 4eac 4eaf 4eb0 4eb5 4eb6 1 4eb8
4ebd 4ec1 4ec5 4ec8 4ecd 4ed2 4ed5 4ed9
4eda 4edf 4ee2 4ee7 4ee8 4eed 4ef0 4ef5
4ef6 4efb 4efe 4f02 4f03 4f08 4f0b 4f10
4f11 4f16 4f19 4f1d 4f21 4f24 4f27 4f28
4f2a 4f2b 4f30 4f31 4f36 4f38 4f3c 4f3f
4f41 4f45 4f47 4f53 4f55 4f57 4f58 4f5d
4f61 4f63 4f6f 4f71 4f75 4f78 4f7c 4f80
4f83 4f87 4f89 4f8d 4f91 4f94 4f98 4f9a
4f9e 4fa2 4fa5 4fa6 4fa8 4fac 4faf 4fb3
4fb6 4fb7 4fb9 4fba 4fbf 4fc3 4fc7 4fca
4fcb 4fcd 4fd1 4fd4 4fd8 4fdb 4fdc 4fde
4fdf 4fe4 4fe8 4fec 4fef 4ff3 4ff7 4ffa
4ffd 5002 5005 5008 500b 500c 5011 5012
1 5014 5019 501d 5021 5024 5029 502e
5031 5035 5036 503b 503e 5043 5044 5049
504c 5051 5052 5057 505a 505e 5062 5066
506a 506d 506e 5070 5075 5076 5078 5079
507e 5081 5086 5087 508c 508f 5094 5095
509a 509d 50a1 50a2 50a7 50aa 50af 50b0
50b5 50b6 50bb 50bd 50c1 50c4 50c8 50cc
50cf 50d3 50d7 50da 50dd 50e2 50e5 50e8
50eb 50ec 50f1 50f2 1 50f4 50f9 50fd
5101 5104 5109 510e 5111 5115 5116 511b
511c 5121 5123 5127 512a 512e 5132 5135
5139 513d 5140 5144 5148 5149 514e 5150
5154 5157 515b 515f 5162 5163 5165 5168
516b 516c 5171 5175 5178 517c 517e 5182
5186 5189 518a 518c 518f 5192 5193 5198
519b 519f 51a3 51a6 51a7 51a9 51ac 51af
51b0 51b5 1 51b8 51bd 51c1 51c5 51c8
51cc 51d0 51d3 51d6 51db 51de 51e1 51e4
51e5 51ea 51eb 1 51ed 51f2 51f6 51fa
51fd 5202 5207 520a 520e 520f 5214 5217
521c 521d 5222 5225 522a 522b 5230 5233
5237 523b 523f 5243 5246 5247 5249 524e
524f 5251 5252 5257 5258 525d 525f 5263
5266 526a 526e 5271 5275 5279 527c 527f
5284 5287 528a 528d 528e 5293 5294 1
5296 529b 529f 52a3 52a6 52ab 52b0 52b3
52b7 52b8 52bd 52be 52c3 52c5 52c9 52cc
52d0 52d4 52d7 52db 52df 52e2 52e6 52e7
52ec 52ee 52f2 52f5 52f9 52fd 5301 5303
5307 530b 530e 5312 5315 5316 531b 531e
5322 5326 532a 532e 5332 533e 5342 5346
5349 534d 5351 5353 1 5357 535b 535f
5362 5366 536a 536e 5372 5375 5379 537d
5380 5383 5388 538b 538e 5391 5392 5397
5398 1 539a 539f 53a3 53a7 53aa 53af
53b4 53b7 53bb 53bc 53c1 53c4 53c9 53ca
53cf 53d2 53d7 53d8 53dd 53e0 53e4 53e5
53ea 53ed 53f2 53f3 53f8 53fb 53ff 5403
5406 5409 540a 540c 540d 5412 5413 5418
541a 541e 5421 5423 5427 5429 5435 5437
5439 543a 543f 5443 5445 5451 5453 5457
545b 545e 5462 5465 5469 546c 546d 5472
5475 5479 547d 5480 5481 5483 5487 548a
548e 5491 5492 5494 5495 549a 1 549d
54a2 54a6 54aa 54ad 54b1 54b5 54b8 54bb
54c0 54c3 54c6 54c9 54ca 54cf 54d0 1
54d2 54d7 54db 54df 54e2 54e7 54ec 54ef
54f3 54f4 54f9 54fc 5501 5502 5507 550a
550f 5510 5515 5518 551c 5520 5524 5528
552b 552c 552e 5533 5534 5536 5537 553c
553f 5544 5545 554a 554d 5552 5553 5558
555b 555f 5560 5565 5568 556d 556e 5573
5574 5579 557b 557f 5582 5586 558a 558d
5591 5595 5598 559b 55a0 55a3 55a6 55a9
55aa 55af 55b0 1 55b2 55b7 55bb 55bf
55c2 55c7 55cc 55cf 55d3 55d4 55d9 55da
55df 55e1 55e5 55e8 55ec 55f0 55f3 55f7
55fb 55fe 5602 5606 5607 560c 560e 5612
5615 5617 561b 561e 5622 5625 5629 562d
5630 5634 5638 563c 563f 5640 5642 5645
5648 5649 564e 5652 5655 5659 565b 565f
5662 5666 566a 566e 5672 5676 567a 567e
5682 5686 568a 568e 5692 5696 569a 569e
56a2 56a6 56aa 56b6 56ba 56bf 56c3 56c6
56c7 56cc 56d0 56d4 56d7 56da 56de 56e0
56e4 56e8 56eb 56ee 56f2 56f4 56f8 56fc
56ff 5701 1 5705 5709 570d 5710 5714
5718 571c 5720 5723 5727 572b 572e 5731
5736 5739 573c 573f 5740 5745 5746 1
5748 574d 5751 5755 5758 575d 5762 5765
5769 576a 576f 5772 5777 5778 577d 5780
5785 5786 578b 578e 5792 5793 5798 579b
57a0 57a1 57a6 57a9 57ad 57b1 57b4 57b7
57b8 57ba 57bb 57c0 57c1 57c6 57c8 57cc
57cf 57d1 57d5 57d7 57e3 57e5 57e7 57e8
57ed 57f1 57f3 57ff 5801 5805 5809 580c
580d 580f 5812 5815 5816 581b 581f 5822
5826 5828 582c 582f 5831 5835 5839 583c
5840 5843 5846 5847 584c 5850 5853 5856
5857 585c 5860 5864 5868 586c 5870 5874
5878 587c 5880 5884 5888 588c 5890 5891
5893 5897 589b 589f 58a2 58a3 58a5 58a8
58ab 58ac 58b1 58b4 58b8 58bb 58bc 58c1
58c4 1 58c7 58cc 58d0 58d4 58d8 58dc
58e0 58e4 58e8 58ec 58f0 58f3 58f4 58f6
58fa 58fc 5900 5903 5907 590a 590b 5910
5913 5917 591b 591f 5923 5926 5927 5929
592d 592f 5933 5937 593a 593d 593e 5940
5943 5948 5949 594e 5952 5956 595a 595e
5961 5962 5964 5968 596a 596e 5972 5976
597a 597d 597e 5980 5984 5986 598a 598e
5991 5993 5997 599b 599e 59a2 59a5 59a6
59ab 59ae 59b2 59b6 59b9 59ba 59bc 59bf
59c2 59c3 59c8 59cc 59d0 59d4 59d7 59db
59df 59e2 59e3 59e5 59e9 59ed 59f0 59f1
59f3 59f6 59fa 59fe 5a02 5a06 5a0a 5a0e
5a12 5a16 5a1a 5a1e 5a22 5a2e 5a32 5a36
5a39 5a3d 5a41 5a43 1 5a47 5a4b 5a4f
5a52 5a56 5a5a 5a5e 5a62 5a65 5a69 5a6d
5a70 5a73 5a78 5a7b 5a7e 5a81 5a82 5a87
5a88 1 5a8a 5a8f 5a93 5a97 5a9a 5a9f
5aa4 5aa7 5aab 5aac 5ab1 5ab4 5ab9 5aba
5abf 5ac2 5ac7 5ac8 5acd 5ad0 5ad4 5ad5
5ada 5add 5ae2 5ae3 5ae8 5aeb 5aef 5af3
5af6 5af9 5afa 5afc 5afd 5b02 5b03 5b08
5b0a 5b0e 5b11 5b13 5b17 5b19 5b25 5b27
5b29 5b2a 5b2f 5b33 5b35 5b41 5b43 5b45
5b49 5b4d 5b51 5b55 5b59 5b5d 5b61 5b65
5b69 5b6d 5b79 5b7d 5b81 5b84 5b88 5b8c
5b8e 1 5b92 5b96 5b9a 5b9d 5ba1 5ba5
5ba9 5bad 5bb0 5bb4 5bb8 5bbb 5bbe 5bc3
5bc6 5bc9 5bcc 5bcd 5bd2 5bd3 1 5bd5
5bda 5bde 5be2 5be5 5bea 5bef 5bf2 5bf6
5bf7 5bfc 5bff 5c04 5c05 5c0a 5c0d 5c12
5c13 5c18 5c1b 5c1f 5c20 5c25 5c28 5c2d
5c2e 5c33 5c36 5c3a 5c3e 5c41 5c44 5c45
5c47 5c48 5c4d 5c4e 5c53 5c55 5c59 5c5c
5c5e 5c62 5c64 5c70 5c72 5c74 5c75 5c7a
5c7e 5c80 5c8c 5c8e 5c90 5c94 5c98 5c9b
5c9f 5ca3 5ca7 5caa 5cab 5cad 5cb0 5cb4
5cb8 5cbb 5cbc 5cbe 5cbf 5cc4 5cc8 5cca
5cce 5cd1 5cd5 5cd8 5cdc 5ce0 5ce4 5ce8
5cec 5cf0 5cf4 5cf8 5cfc 5d00 5d04 5d07
5d08 5d0a 5d0e 5d12 5d15 5d16 5d18 5d19
5d1b 5d1f 5d23 5d27 5d2a 5d2b 5d2d 5d30
5d33 5d34 5d39 5d3d 5d41 5d44 5d48 5d4c
5d4f 5d52 5d57 5d5a 5d5d 5d60 5d61 5d66
5d67 1 5d69 5d6e 5d72 5d76 5d79 5d7e
5d83 5d86 5d8a 5d8b 5d90 5d93 5d98 5d99
5d9e 5da1 5da6 5da7 5dac 5daf 5db3 5db7
5dbb 5dbf 5dc2 5dc3 5dc5 5dca 5dcb 5dcd
5dce 5dd3 5dd6 5ddb 5ddc 5de1 5de4 5de9
5dea 5def 5df2 5df6 5df7 5dfc 5dff 5e04
5e05 5e0a 5e0b 5e10 5e12 5e16 5e19 5e1d
5e21 5e24 5e28 5e2c 5e2f 5e32 5e37 5e3a
5e3d 5e40 5e41 5e46 5e47 1 5e49 5e4e
5e52 5e56 5e59 5e5e 5e63 5e66 5e6a 5e6b
5e70 5e71 5e76 5e78 5e7c 5e7f 5e83 5e87
5e8a 5e8e 5e92 5e95 5e99 5e9d 5e9e 5ea3
5ea7 5ea9 5ead 5eb0 5eb3 5eb4 5eb9 5ebd
5ec1 5ec5 5ec9 5ecd 5ed1 5ed5 5ed9 5edd
5ee1 5ee5 5ee9 5eed 5ef1 5ef5 5ef9 5efd
5f01 5f05 5f09 5f0d 5f11 5f1d 5f21 5f26
5f2a 5f2d 5f2e 5f33 5f37 5f3b 5f3e 5f41
5f45 5f47 5f4b 5f4f 5f52 5f55 5f59 5f5b
5f5f 5f63 5f66 5f68 1 5f6c 5f70 5f74
5f77 5f7b 5f7f 5f83 5f87 5f8a 5f8e 5f92
5f95 5f98 5f9d 5fa0 5fa3 5fa6 5fa7 5fac
5fad 1 5faf 5fb4 5fb8 5fbc 5fbf 5fc4
5fc9 5fcc 5fd0 5fd1 5fd6 5fd9 5fde 5fdf
5fe4 5fe7 5fec 5fed 5ff2 5ff5 5ff9 5ffa
5fff 6002 6007 6008 600d 6010 6014 6018
601b 601e 601f 6021 6022 6027 6028 602d
602f 6033 6036 6038 603c 603e 604a 604c
604e 604f 6054 6058 605a 6066 6068 606a
606e 6072 6075 6079 607d 6081 6082 6084
6088 608c 6090 6093 6097 609b 609e 60a1
60a6 60a9 60ac 60af 60b0 60b5 60b6 1
60b8 60bd 60c1 60c5 60c8 60cd 60d2 60d5
60d9 60da 60df 60e2 60e7 60e8 60ed 60f0
60f5 60f6 60fb 60fe 6102 6106 610a 610b
610d 6112 6113 6115 6116 611b 611e 6123
6124 6129 612c 6131 6132 6137 613a 613e
613f 6144 6147 614c 614d 6152 6153 6158
615a 615e 6161 6165 6169 616c 6170 6174
6177 617a 617f 6182 6185 6188 6189 618e
618f 1 6191 6196 619a 619e 61a1 61a6
61ab 61ae 61b2 61b3 61b8 61b9 61be 61c0
61c4 61c7 61cb 61cf 61d2 61d6 61da 61dd
61de 61e0 61e4 61e8 61e9 61ee 61f0 61f4
61f7 61fb 61ff 6202 6203 6205 6209 620c
6210 6213 6214 6216 6217 621c 6220 6224
6228 622c 6230 6234 6238 623c 6240 6244
6248 624c 6258 625c 6260 6263 6267 626b
626d 1 6271 6275 6279 627c 6280 6284
6288 628c 628f 6293 6297 629a 629d 62a2
62a5 62a8 62ab 62ac 62b1 62b2 1 62b4
62b9 62bd 62c1 62c4 62c9 62ce 62d1 62d5
62d6 62db 62de 62e3 62e4 62e9 62ec 62f1
62f2 62f7 62fa 62fe 62ff 6304 6307 630c
630d 6312 6315 6319 631d 6320 6323 6324
6326 6327 632c 632d 6332 6334 6338 633b
633d 6341 6343 634f 6351 6353 6354 6359
635d 635f 636b 636d 6371 6375 6378 6379
637b 637e 6381 6382 6387 638b 638f 6392
6396 639a 639d 63a0 63a5 63a8 63ab 63ae
63af 63b4 63b5 1 63b7 63bc 63c0 63c4
63c7 63cc 63d1 63d4 63d8 63d9 63de 63e1
63e6 63e7 63ec 63ef 63f4 63f5 63fa 63fd
6401 6405 6409 640d 6410 6411 6413 6418
6419 641b 641c 6421 6424 6429 642a 642f
6432 6437 6438 643d 6440 6444 6445 644a
644d 6452 6453 6458 6459 645e 6460 6464
6467 646b 646f 6472 6476 647a 647d 6480
6485 6488 648b 648e 648f 6494 6495 1
6497 649c 64a0 64a4 64a7 64ac 64b1 64b4
64b8 64b9 64be 64bf 64c4 64c6 64ca 64cd
64d1 64d5 64d8 64dc 64e0 64e3 64e7 64eb
64ec 64f1 64f3 64f7 64fa 64fe 6502 6506
650a 650e 6512 6515 6516 6518 651c 6520
6524 6527 6528 652a 652e 6531 6535 6538
6539 653b 653c 6541 6545 6548 654b 654c
6551 6555 6559 655d 6561 6565 6569 656d
6571 6575 6579 657d 6581 6585 6586 6588
658c 6590 6593 6594 6599 659c 65a0 65a4
65a8 65ac 65af 65b0 65b2 65b6 65b8 65bc
65c0 65c3 65c6 65c7 65c9 65cc 65d1 65d2
65d7 65db 65df 65e3 65e7 65ea 65eb 65ed
65f1 65f3 65f7 65fb 65ff 6603 6606 6607
6609 660d 660f 6613 6617 661a 661c 6620
6624 6627 662b 662e 6632 6636 6639 663a
663f 6642 6646 664a 664d 664e 6650 6653
6656 6657 665c 6660 6664 6668 666b 666f
6673 6676 6677 6679 667d 6681 6684 6685
6687 668a 668e 6692 6696 669a 669e 66a2
66a6 66aa 66ae 66b2 66b6 66c2 66c6 66ca
66cd 66d1 66d5 66d7 1 66db 66df 66e3
66e6 66ea 66ee 66f2 66f6 66f9 66fd 6701
6704 6707 670c 670f 6712 6715 6716 671b
671c 1 671e 6723 6727 672b 672e 6733
6738 673b 673f 6740 6745 6748 674d 674e
6753 6756 675b 675c 6761 6764 6768 6769
676e 6771 6776 6777 677c 677f 6783 6787
678a 678d 678e 6790 6791 6796 6797 679c
679e 67a2 67a5 67a7 67ab 67ad 67b9 67bb
67bd 67be 67c3 67c7 67c9 67d5 67d7 67d9
67dd 67e1 67e5 67e9 67ed 67f1 67f5 67f9
67fd 6801 680d 6811 6815 6818 681c 6820
6822 1 6826 682a 682e 6831 6835 6839
683d 6841 6844 6848 684c 684f 6852 6857
685a 685d 6860 6861 6866 6867 1 6869
686e 6872 6876 6879 687e 6883 6886 688a
688b 6890 6893 6898 6899 689e 68a1 68a6
68a7 68ac 68af 68b3 68b4 68b9 68bc 68c1
68c2 68c7 68ca 68ce 68d2 68d5 68d8 68d9
68db 68dc 68e1 68e2 68e7 68e9 68ed 68f0
68f2 68f6 68f8 6904 6906 6908 6909 690e
6912 6914 6920 6922 6924 6928 692c 692f
6933 6937 693a 693b 693d 6940 6943 6944
6949 694d 6951 6955 6959 695d 6961 6965
6969 696d 6971 6975 6979 6985 6989 698d
6990 6994 6998 699a 1 699e 69a2 69a6
69a9 69ad 69b1 69b5 69b9 69bc 69c0 69c4
69c7 69ca 69cf 69d2 69d5 69d8 69d9 69de
69df 1 69e1 69e6 69ea 69ee 69f1 69f6
69fb 69fe 6a02 6a03 6a08 6a0b 6a10 6a11
6a16 6a19 6a1e 6a1f 6a24 6a27 6a2b 6a2c
6a31 6a34 6a39 6a3a 6a3f 6a42 6a46 6a4a
6a4d 6a50 6a51 6a53 6a54 6a59 6a5a 6a5f
6a61 6a65 6a68 6a6a 6a6e 6a70 6a7c 6a7e
6a80 6a81 6a86 6a8a 6a8c 6a98 6a9a 6a9c
6aa0 6aa3 6aa5 6aa9 6aac 6ab0 6ab4 6ab8
6abb 6abc 6abe 6ac1 6ac5 6ac9 6acc 6acd
6acf 6ad0 6ad5 6ad8 6adc 6ae0 6ae3 6ae4
6ae6 6ae7 6aec 6af0 6af4 6af7 6afb 6aff
6b03 6b07 6b0b 6b0f 6b13 6b17 6b1b 6b1f
6b23 6b27 6b2b 6b2f 6b33 6b37 6b3b 6b3f
6b43 6b47 6b53 6b57 6b5c 6b60 6b63 6b64
6b69 6b6d 6b71 6b74 6b77 6b7b 6b7d 6b81
6b85 6b88 6b8b 6b8f 6b91 6b95 6b99 6b9c
6b9e 1 6ba2 6ba6 6baa 6bad 6bb1 6bb5
6bb9 6bbd 6bc0 6bc4 6bc8 6bcb 6bce 6bd3
6bd6 6bd9 6bdc 6bdd 6be2 6be3 1 6be5
6bea 6bee 6bf2 6bf5 6bfa 6bff 6c02 6c06
6c07 6c0c 6c0f 6c14 6c15 6c1a 6c1d 6c22
6c23 6c28 6c2b 6c2f 6c30 6c35 6c38 6c3d
6c3e 6c43 6c46 6c4a 6c4e 6c51 6c54 6c55
6c57 6c58 6c5d 6c5e 6c63 6c65 6c69 6c6c
6c6e 6c72 6c74 6c80 6c82 6c84 6c85 6c8a
6c8e 6c90 6c9c 6c9e 6ca2 6ca6 6ca9 6cad
6cb0 6cb4 6cb7 6cb8 6cbd 6cc0 6cc4 6cc7
6ccb 6ccf 6cd3 6cd7 6cdb 6cdf 6ce3 6ce7
6ceb 6cee 6cf2 6cf6 6cf9 6cfa 6cfc 6cfd
6cff 6d03 6d07 6d0b 6d0e 6d0f 6d11 6d14
6d17 6d18 6d1d 6d21 6d25 6d28 6d2c 6d30
6d33 6d36 6d3b 6d3e 6d41 6d44 6d45 6d4a
6d4b 1 6d4d 6d52 6d56 6d5a 6d5d 6d62
6d67 6d6a 6d6e 6d6f 6d74 6d77 6d7c 6d7d
6d82 6d85 6d8a 6d8b 6d90 6d93 6d97 6d9b
6d9f 6da0 6da2 6da7 6da8 6daa 6dab 6db0
6db3 6db8 6db9 6dbe 6dc1 6dc6 6dc7 6dcc
6dcf 6dd3 6dd4 6dd9 6ddc 6de1 6de2 6de7
6de8 6ded 6def 6df3 6df6 6dfa 6dfe 6e01
6e05 6e09 6e0c 6e0f 6e14 6e17 6e1a 6e1d
6e1e 6e23 6e24 1 6e26 6e2b 6e2f 6e33
6e36 6e3b 6e40 6e43 6e47 6e48 6e4d 6e4e
6e53 6e55 6e59 6e5c 6e60 6e64 6e67 6e6b
6e6f 6e72 6e73 6e75 6e79 6e7d 6e7e 6e83
6e85 6e89 6e8c 6e8e 6e92 6e95 6e99 6e9d
6ea1 6ea4 6ea5 6ea7 6eab 6ead 6eb1 6eb5
6eb9 6ebd 6ec0 6ec1 6ec3 6ec6 6eca 6ece
6ed1 6ed2 6ed4 6ed5 6eda 6edd 6ee0 6ee3
6ee4 6ee9 6eec 6eef 6ef2 6ef3 6ef8 6ef9
6efb 6eff 6f01 6f05 6f09 6f0c 6f10 6f14
6f18 6f1c 6f20 6f24 6f28 6f2c 6f30 6f34
6f38 6f3c 6f40 6f44 6f48 6f4c 6f50 6f54
6f58 6f5c 6f60 6f64 6f68 6f6c 6f70 6f74
6f78 6f7b 6f7c 6f7e 6f7f 6f81 6f85 6f89
6f8d 6f90 6f94 6f98 6f9b 6f9e 6fa3 6fa6
6fa9 6fac 6fad 6fb2 6fb3 1 6fb5 6fba
6fbe 6fc2 6fc5 6fca 6fcf 6fd2 6fd6 6fd7
6fdc 6fdf 6fe4 6fe5 6fea 6fed 6ff2 6ff3
6ff8 6ffb 6fff 7003 7007 7008 700a 700f
7010 7012 7013 7018 701b 7020 7021 7026
7029 702e 702f 7034 7037 703b 703c 7041
7044 7049 704a 704f 7050 7055 7057 705b
705e 7062 7066 7069 706d 7071 7074 7077
707c 707f 7082 7085 7086 708b 708c 1
708e 7093 7097 709b 709e 70a3 70a8 70ab
70af 70b0 70b5 70b6 70bb 70bd 70c1 70c4
70c8 70cc 70cf 70d3 70d7 70da 70db 70dd
70e1 70e5 70e6 70eb 70ef 70f1 70f5 70f9
70fc 70fd 70ff 7103 7106 710a 710d 710e
7110 7111 7116 711a 711e 7121 7122 7124
7127 712a 712b 7130 7133 7137 713b 713e
713f 7141 7144 7147 7148 714d 1 7150
7155 7159 715d 7160 7164 7168 716b 716e
7173 7176 7179 717c 717d 7182 7183 1
7185 718a 718e 7192 7195 719a 719f 71a2
71a6 71a7 71ac 71af 71b4 71b5 71ba 71bd
71c2 71c3 71c8 71cb 71cf 71d3 71d7 71db
71de 71df 71e1 71e6 71e7 71e9 71ea 71ef
71f2 71f7 71f8 71fd 7200 7205 7206 720b
720e 7212 7213 7218 721b 7220 7221 7226
7227 722c 722e 7232 7235 7239 723d 7240
7244 7248 724b 724e 7253 7256 7259 725c
725d 7262 7263 1 7265 726a 726e 7272
7275 727a 727f 7282 7286 7287 728c 728d
7292 7294 7298 729b 729f 72a3 72a6 72aa
72ae 72b1 72b5 72b9 72ba 72bf 72c1 72c5
72c8 72cc 72d0 72d4 72d8 72dc 72e0 72e4
72e8 72ec 72f0 72f4 7300 7304 7309 730d
7310 7311 7316 731a 731e 7321 7324 7328
732a 732e 7332 7335 7338 733c 733e 7342
7346 7349 734b 1 734f 7353 7357 735a
735e 7362 7366 736a 736d 7371 7375 7378
737b 7380 7383 7386 7389 738a 738f 7390
1 7392 7397 739b 739f 73a2 73a7 73ac
73af 73b3 73b4 73b9 73bc 73c1 73c2 73c7
73ca 73cf 73d0 73d5 73d8 73dc 73dd 73e2
73e5 73ea 73eb 73f0 73f3 73f7 73fb 73fe
7401 7402 7404 7405 740a 740b 7410 7412
7416 7419 741b 741f 7421 742d 742f 7431
7432 7437 743b 743d 7449 744b 744f 7453
7457 745b 745f 7463 7467 746b 746f 7473
7477 7483 7487 748c 7490 7493 7494 7499
749d 74a1 74a4 74a7 74ab 74ad 74b1 74b5
74b8 74bb 74bf 74c1 74c5 74c9 74cc 74ce
1 74d2 74d6 74da 74dd 74e1 74e5 74e9
74ed 74f0 74f4 74f8 74fb 74fe 7503 7506
7509 750c 750d 7512 7513 1 7515 751a
751e 7522 7525 752a 752f 7532 7536 7537
753c 753f 7544 7545 754a 754d 7552 7553
7558 755b 755f 7560 7565 7568 756d 756e
7573 7576 757a 757e 7581 7584 7585 7587
7588 758d 758e 7593 7595 7599 759c 759e
75a2 75a4 75b0 75b2 75b4 75b5 75ba 75be
75c0 75cc 75ce 75d0 75d4 75d8 75db 75df
75e3 75e7 75e8 75ea 75ee 75f2 75f6 75f9
75fd 7601 7604 7607 760c 760f 7612 7615
7616 761b 761c 1 761e 7623 7627 762b
762e 7633 7638 763b 763f 7640 7645 7648
764d 764e 7653 7656 765b 765c 7661 7664
7668 766c 7670 7671 7673 7678 7679 767b
767c 7681 7684 7689 768a 768f 7692 7697
7698 769d 76a0 76a4 76a5 76aa 76ad 76b2
76b3 76b8 76b9 76be 76c0 76c4 76c7 76cb
76cf 76d2 76d6 76da 76dd 76e0 76e5 76e8
76eb 76ee 76ef 76f4 76f5 1 76f7 76fc
7700 7704 7707 770c 7711 7714 7718 7719
771e 771f 7724 7726 772a 772d 7731 7735
7738 773c 7740 7743 7744 7746 774a 774e
774f 7754 7756 775a 775e 7762 7766 776a
776e 7772 7776 777a 777e 7782 7786 778a
778e 7792 7796 779a 779e 77a2 77a6 77aa
77ae 77b2 77b6 77ba 77be 77c2 77c6 77ca
77ce 77d2 77d6 77da 77e6 77ea 77ee 77f1
77f5 77f9 77fb 1 77ff 7803 7807 780a
780e 7812 7816 781a 781d 7821 7825 7828
782b 7830 7833 7836 7839 783a 783f 7840
1 7842 7847 784b 784f 7852 7857 785c
785f 7863 7864 7869 786c 7871 7872 7877
787a 787f 7880 7885 7888 788c 788d 7892
7895 789a 789b 78a0 78a3 78a7 78ab 78ae
78b1 78b2 78b4 78b5 78ba 78bb 78c0 78c2
78c6 78c9 78cb 78cf 78d1 78dd 78df 78e1
78e2 78e7 78eb 78ed 78f9 78fb 78ff 7903
7906 790a 790d 7911 7914 7915 791a 791d
7920 7921 7926 792a 792e 7931 7935 7939
793c 793f 7944 7947 794a 794d 794e 7953
7954 1 7956 795b 795f 7963 7966 796b
7970 7973 7977 7978 797d 7980 7985 7986
798b 798e 7993 7994 7999 799c 79a0 79a4
79a8 79ac 79af 79b0 79b2 79b7 79b8 79ba
79bb 79c0 79c3 79c8 79c9 79ce 79d1 79d6
79d7 79dc 79df 79e3 79e4 79e9 79ec 79f1
79f2 79f7 79f8 79fd 79ff 7a03 7a06 7a0a
7a0e 7a11 7a15 7a19 7a1c 7a1f 7a24 7a27
7a2a 7a2d 7a2e 7a33 7a34 1 7a36 7a3b
7a3f 7a43 7a46 7a4b 7a50 7a53 7a57 7a58
7a5d 7a5e 7a63 7a65 7a69 7a6c 7a70 7a74
7a77 7a7b 7a7f 7a82 7a86 7a8a 7a8b 7a90
7a92 7a96 7a99 7a9d 7aa1 7aa4 7aa8 7aac
7aad 7aaf 7ab2 7ab5 7ab6 7abb 7abf 7ac3
7ac6 7ac9 7acd 7ad1 7ad5 7ad8 7adc 7ae0
7ae3 7ae6 7aeb 7aee 7af1 7af4 7af5 7afa
7afb 1 7afd 7b02 7b06 7b0a 7b0d 7b12
7b17 7b1a 7b1e 7b1f 7b24 7b27 7b2c 7b2d
7b32 7b35 7b3a 7b3b 7b40 7b43 7b47 7b4b
7b4f 7b53 7b56 7b57 7b59 7b5e 7b5f 7b61
7b62 7b67 7b6a 7b6f 7b70 7b75 7b78 7b7d
7b7e 7b83 7b86 7b8a 7b8b 7b90 7b93 7b98
7b99 7b9e 7b9f 7ba4 7ba6 7baa 7bad 7bb1
7bb5 7bb8 7bbc 7bc0 7bc3 7bc6 7bcb 7bce
7bd1 7bd4 7bd5 7bda 7bdb 1 7bdd 7be2
7be6 7bea 7bed 7bf2 7bf7 7bfa 7bfe 7bff
7c04 7c05 7c0a 7c0c 7c10 7c13 7c17 7c1b
7c1e 7c22 7c26 7c29 7c2d 7c31 7c32 7c37
7c39 7c3d 7c40 7c42 7c46 7c4a 7c4d 7c4f
7c53 7c56 7c5a 7c5e 7c62 7c66 7c6a 7c6e
7c72 7c76 7c7a 7c7e 7c82 7c86 7c89 7c8d
7c91 7c95 7c98 7c9c 7ca0 7ca4 7ca8 7cac
7cad 7caf 7cb3 7cb7 7cbb 7cbe 7cc2 7cc6
7cc9 7ccc 7cd1 7cd4 7cd7 7cda 7cdb 7ce0
7ce1 1 7ce3 7ce8 7cec 7cf0 7cf3 7cf8
7cfd 7d00 7d04 7d05 7d0a 7d0d 7d12 7d13
7d18 7d1b 7d20 7d21 7d26 7d29 7d2d 7d31
7d35 7d39 7d3c 7d3d 7d3f 7d44 7d45 7d47
7d48 7d4d 7d50 7d55 7d56 7d5b 7d5e 7d63
7d64 7d69 7d6c 7d70 7d71 7d76 7d79 7d7e
7d7f 7d84 7d85 7d8a 7d8c 7d90 7d93 7d97
7d9b 7d9e 7da2 7da6 7da9 7dad 7db1 7db2
7db7 7db9 7dbd 7dc1 7dc4 7dc8 7dcc 7dcf
7dd3 7dd7 7dda 7ddd 7de2 7de5 7de8 7deb
7dec 7df1 7df2 1 7df4 7df9 7dfd 7e01
7e04 7e09 7e0e 7e11 7e15 7e16 7e1b 7e1c
7e21 7e25 7e29 7e2c 7e31 7e36 7e39 7e3d
7e41 7e44 7e45 7e4a 7e4d 7e52 7e53 7e58
7e5b 7e5f 7e63 7e66 7e67 7e6c 7e6d 7e72
7e74 7e78 7e7b 7e7f 7e83 7e87 7e8b 7e8f
7e93 7e97 7e9b 7e9f 7eab 7eb0 7eb4 7eb8
7ebc 7ec0 7ec2 7ec3 7ec8 1 7ecc 7ed0
7ed4 7ed7 7edb 7edf 7ee3 7ee7 7eea 7eee
7ef2 7ef5 7ef8 7efd 7f00 7f03 7f06 7f07
7f0c 7f0d 1 7f0f 7f14 7f18 7f1c 7f1f
7f24 7f29 7f2c 7f30 7f31 7f36 7f37 7f3c
7f40 7f44 7f47 7f4c 7f51 7f54 7f58 7f59
7f5e 7f61 7f66 7f67 7f6c 7f6f 7f73 7f77
7f7a 7f7d 7f7e 7f80 7f81 7f86 7f87 7f8c
7f8e 7f92 7f95 7f99 7f9d 7fa1 7fa5 7fa9
7fad 7fb1 7fbd 7fc2 7fc6 7fca 7fce 7fd2
7fd4 7fd8 7fda 7fe6 7fe8 7fea 7feb 7ff0
7ff4 7ff6 8002 8006 8008 8009 8012 
24c7
2
0 1 a 6 10 :3 6 15 :3 6
16 :3 6 17 :3 6 e :3 6 e :3 6
15 :3 6 f :3 6 10 :2 6 1 3
a 13 a :2 1 4 12 1b 1a
:2 12 :2 4 11 1a 19 :2 11 :2 4 15
1e 1d :2 15 :2 4 17 20 1f :2 17
:2 4 14 1d 1c :2 14 :2 4 10 19
18 :2 10 :2 4 18 21 20 :2 18 :2 4
12 1b 1a :2 12 :2 4 e 17 16
:2 e :2 4 14 1d 1c :2 14 :2 4 11
1a 19 :2 11 :2 4 11 1a 19 :2 11
:2 4 16 1f 1e :2 16 :2 4 :3 13 :2 4
:3 11 :2 4 :3 12 :2 4 :3 12 :2 4 :3 13 :2 4
:3 f :2 4 :3 9 :2 4 :3 9 :2 4 :3 e :2 4
f 18 17 :2 f :2 4 f 18 17
:2 f :2 4 :2 f 1e f :2 4 :2 16 25
16 :2 4 :2 11 20 11 :2 4 :3 10 :2 4
:3 15 :2 4 :2 17 26 17 :2 4 :2 13 22
13 :2 4 :2 12 21 12 :2 4 :2 12 21
12 :2 4 :2 14 23 14 :2 4 :2 15 24
15 :2 4 :2 12 21 12 :2 4 :2 d 1c
d :2 4 :2 11 20 11 :2 4 :2 13 22
13 :2 4 e 17 16 :2 e :2 4 d
16 15 :2 d :2 4 f 18 17 :2 f
:2 4 :2 d 1c d :2 4 :2 e 1d e
:2 4 :2 c 1b c :2 4 :2 14 23 14
:2 4 :2 13 22 13 :2 4 :2 12 21 12
:2 4 :2 11 20 11 :2 4 :2 b 1a b
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 10 1f 10 :2 4 :2 e 1d e
:2 4 :2 10 1f 10 :2 4 :2 13 22 13
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 f 1e f :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 13 22 13
:2 4 :2 a 19 a :2 4 :2 12 21 12
:2 4 :2 11 20 11 :2 4 :2 e 1d e
:2 4 14 1d 1c :2 14 :2 4 14 1d
1c :2 14 :2 4 :2 17 26 17 :2 4 17
20 1f :2 17 :2 4 :2 13 22 13 :2 4
:2 14 23 14 :2 4 :2 f 1e f :2 4
:2 f 19 f :2 4 :2 f 19 f :2 4
:2 10 1a 10 :2 4 :2 10 1a 10 :2 4
:2 11 1b 11 :2 4 :2 11 1b 11 :2 4
:2 12 1c 12 :2 4 :2 12 1c 12 :2 4
9 12 11 :2 9 :2 4 :3 e :2 4 :3 e
4 7 11 1a :3 11 :2 7 11 1a
:3 11 7 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 58 5e 61 :2 58
6f 89 8 :2 6f d 10 :2 6f 1a
1d :2 6f b e :2 6f 13 16 :2 6f
1b 1e :2 6f 2d 30 :2 6f b e
:2 6f 13 16 1f 26 2b 2e :2 26
3e 41 :2 26 46 :2 1f 4f :2 16 :2 6f
b e :2 6f 13 16 1f 26 2b
2e :2 26 3f 42 :2 26 47 :2 1f 50
:2 16 :2 6f b e :2 6f 13 16 1f
27 :2 1f 31 :2 16 :2 6f b e :2 6f
13 16 1f 27 :2 1f 31 :2 16 :2 6f
b e :2 6f 13 16 1f 27 :2 1f
38 :2 16 :2 6f b e :2 6f 13 16
1f 27 :2 1f 32 :2 16 :2 6f b e
:2 6f 13 16 :2 6f 1b 1e :2 6f 28
2b :2 6f 30 33 :2 6f :2 7 4e :2 4
7 :2 11 23 :2 2d 39 3c 50 53
54 :2 50 :2 23 :3 7 :2 d 12 1e 62
65 :2 1e :2 7 57 :3 4 13 :2 4 14
:2 4 12 :2 4 15 :2 4 11 4 e
11 24 27 34 37 43 46 11
14 11 14 7 a 7 a 16
19 c 21 30 3e :4 7 15 c
21 d 10 24 :2 7 :2 10 1c 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 57 5a 5b :2 57
:2 29 :3 d :2 13 18 24 68 6b :2 24
78 7b :2 24 7f 82 :2 24 8e 91
:2 24 99 9c :2 24 a8 ab b2 bb
be :2 ab :2 24 :2 d 5e :2 a :2 7 :4 13
:2 7 4 :3 1 8 :2 11 1c 1a :2 25
:2 1a 7 11 24 3b 47 a 19
23 33 3e 48 50 58 14 23
32 44 53 61 6e 80 14 28
3a 4a 5b a 12 19 34 3c
43 5f 69 a 18 26 34 a
1a 2a 3a a 1d 26 f 24
35 43 a 16 22 34 3f 47
50 58 a 1b 2b 3a 48 a
14 1d a 10 16 22 a 16
23 2f a 18 27 35 a 1a
25 f 10 24 :2 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 5a 5d 5e :2 5a
:2 2c :3 10 :2 16 1b 27 6b 6e :2 27
7b 7e :2 27 82 85 :2 27 91 94
:2 27 9c 9f :2 27 ab ae b5 be
c1 :2 ae :2 27 :2 10 61 :2 d :2 a :4 16
:2 a 7 :3 35 b :2 14 1f 1d :2 28
:2 1d a 14 20 2b 62 6c 77
d 1b 1f 2c 3d 4b 59 5e
67 76 12 20 2d 38 46 55
d 1d 2a 39 43 53 5a 12
20 2d :2 d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5d 60 61 :2 5d :2 2f :3 13
:2 19 1e 2a 6e 71 :2 2a 7e 81
:2 2a 85 88 :2 2a 94 97 :2 2a 9f
a2 :2 2a ae b1 b8 c1 c4 :2 b1
:2 2a :2 13 64 :2 10 :2 d :4 19 :2 d a
:3 38 e :2 17 22 20 :2 2b :2 20 d
10 :2 1a 2c :2 36 42 46 5a 5d
5e :2 5a :2 2c :3 10 :2 16 1b 27 6b
6e :2 27 7b 7e :2 27 82 85 :2 27
8f 92 9b a3 :2 ac :2 9b bf :2 92
:2 27 c7 ca :2 27 d2 d5 :2 27 da
dd :2 27 e7 ea :2 27 :2 10 61 :2 d
10 :2 1a 2c :2 36 42 45 59 5c
5d :2 59 :2 2c :3 10 :2 16 1b 27 6b
6e :2 27 :2 10 60 :3 d :2 18 2c :2 35
47 52 :2 d 3b :3 a 1b :2 a 1c
a e :2 19 21 30 40 :2 e 44
46 :2 44 d 4e :2 59 10 20 2f
:2 4e 33 36 :2 33 4d :2 d 10 :2 1a
2c :2 36 42 46 5a 5d 5e :2 5a
:2 2c :3 10 :2 16 1b 27 6b 6e :2 27
7b 7e :2 27 82 85 :2 27 8f 92
9b a3 :2 ac :2 9b c9 :2 92 :2 27 d1
d4 :2 27 dc df :2 27 e4 e7 :2 27
f1 f4 :2 27 :2 10 61 :2 d 10 :2 1a
2c :2 36 42 45 59 5c 5d :2 59
:2 2c :3 10 :2 16 1b 27 6b 6e :2 27
:2 10 60 :3 d :2 18 2c :2 35 51 15
:2 d 39 :2 a :4 f e d 2d 36
40 :2 2d 43 45 4e 5d :2 45 :2 2d
2c 64 61 10 17 :2 64 :2 61 2b
:2 d 10 :2 1a 2c :2 36 42 46 5a
5d 5e :2 5a :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 7b 7e :2 27 82 85
:2 27 8f 92 9b a3 :2 ac :2 9b cd
:2 92 :2 27 d5 d8 :2 27 e0 e3 :2 27
e8 eb :2 27 f5 f8 :2 27 :2 10 61
:2 d 10 :2 1a 2c :2 36 42 45 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 :2 10 60 :3 d :2 18 2c
:2 35 55 15 :2 d 1b :2 a e :2 19
21 30 3e :2 e 42 45 :2 42 d
4c :2 57 5f 12 21 :2 4c 25 28
:2 25 4b :2 d 10 19 29 :2 10 2c
2e :2 2c 13 :2 1e 26 35 43 :2 13
47 4a :2 47 1d 28 35 3f 4a
4f 58 69 7b 1b 1c 29 1a
25 2d 34 :2 16 :2 1f 2b 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9d a0 :2 33
a8 ab :2 33 b7 ba c1 ca cd
:2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16
13 :3 4c 17 :2 20 2b 29 :2 34 :2 29
16 20 2b 38 40 47 5f 6a
7e 1e :2 19 :2 22 2e 19 16 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 69 6c 6d :2 69 :2 3b :3 1f
:2 25 2a 36 7a 7d :2 36 8a 8d
:2 36 91 94 :2 36 a0 a3 :2 36 ab
ae :2 36 ba bd c4 cd d0 :2 bd
:2 36 :2 1f 70 :2 1c :2 19 :4 25 :2 19 16
:4 44 :2 13 16 :2 21 29 38 48 :2 16
4c 4e :2 4c 16 28 16 50 :2 13
4c 1d 28 35 3f 4a 4f 58
68 7a 1b 1c 29 1a 25 2d
34 :2 16 :2 1f 2b 16 13 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 66 69 6a :2 66 :2 38 :3 1c :2 22
27 33 77 7a :2 33 87 8a :2 33
8e 91 :2 33 9d a0 :2 33 a8 ab
:2 33 b7 ba c1 ca cd :2 ba :2 33
:2 1c 6d :2 19 :2 16 :4 22 :2 16 13 :3 10
17 :2 20 2b 29 :2 34 :2 29 16 20
2b 38 40 47 60 6b 7f 1e
:2 19 :2 22 2e 19 16 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
69 6c 6d :2 69 :2 3b :3 1f :2 25 2a
36 7a 7d :2 36 8a 8d :2 36 91
94 :2 36 a0 a3 :2 36 ab ae :2 36
ba bd c4 cd d0 :2 bd :2 36 :2 1f
70 :2 1c :2 19 :4 25 :2 19 16 :4 44 :3 13
21 13 :4 10 13 1c 29 :2 13 2e
2c :2 37 :2 2c 1d 29 37 46 55
65 76 1c 29 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :4 3d 1d 29
39 48 59 69 7c 1c 29 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:7 10 14 :2 1d 28 26 :2 31 :2 26 :2 13
21 2b :2 21 13 41 :2 10 30 1a
2a 3a 23 19 26 37 41 17
:2 13 :2 1c 28 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 66 67 :2 63 :2 35 :3 19 :2 1f 24
30 74 77 :2 30 84 87 :2 30 8b
8e :2 30 9a 9d :2 30 a5 a8 :2 30
b4 b7 be c7 ca :2 b7 :2 30 :2 19
6a :2 16 :2 13 :4 1f :2 13 10 :3 d 13
1c 28 :2 13 2b 2d :2 2b 16 :2 20
32 :2 3c 48 4c 60 63 64 :2 60
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
81 84 :2 2d 88 8b :2 2d 95 98
a1 a9 :2 b2 :2 a1 cd :2 98 :2 2d d5
d8 :2 2d e0 e3 :2 2d e8 eb :2 2d
f5 f8 :2 2d :2 16 67 :2 13 16 :2 20
32 :2 3c 48 4b 5f 62 63 :2 5f
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
:2 16 66 :3 13 :2 1e 32 :2 3b 55 1b
:2 13 2f :2 10 13 :2 1e 26 35 43
:2 13 47 4a :2 47 1d 28 35 3f
4a 4f 58 69 7b 1b 1c 29
1a 25 2d 34 :2 16 :2 1f 2b 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :3 4c 17 :2 20 2b 29 :2 34
:2 29 16 20 2b 38 40 47 5f
6a 7e 1e :2 19 :2 22 2e 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 69 6c 6d :2 69 :2 3b
:3 1f :2 25 2a 36 7a 7d :2 36 8a
8d :2 36 91 94 :2 36 a0 a3 :2 36
ab ae :2 36 ba bd c4 cd d0
:2 bd :2 36 :2 1f 70 :2 1c :2 19 :4 25 :2 19
16 :4 44 :2 13 4c 1d 28 35 3f
4a 4f 58 68 7a 1b 1c 29
1a 25 2d 34 :2 16 :2 1f 2b 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :3 10 17 :2 20 2b 29 :2 34
:2 29 16 20 2b 38 40 47 60
6b 7f 1e :2 19 :2 22 2e 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 69 6c 6d :2 69 :2 3b
:3 1f :2 25 2a 36 7a 7d :2 36 8a
8d :2 36 91 94 :2 36 a0 a3 :2 36
ab ae :2 36 ba bd c4 cd d0
:2 bd :2 36 :2 1f 70 :2 1c :2 19 :4 25 :2 19
16 :4 44 :2 13 :5 10 1e 31 3f 4a
58 67 24 34 3f 4b 54 61
:2 4b 24 :2 1e 10 13 1c 28 :2 13
2b 2d :2 2b 13 21 2b :2 21 13
2f 16 :2 20 32 :2 3c 48 4c 60
63 64 :2 60 :2 32 :3 16 :2 1c 21 2d
71 74 :2 2d 81 84 :2 2d 88 8b
:2 2d 95 98 a1 a9 :2 a1 b6 :2 98
:2 2d be c1 :2 2d c9 cc :2 2d d1
d4 :2 2d de e1 :2 2d :2 16 67 :2 13
16 :2 20 32 :2 3c 48 4b 5f 62
63 :2 5f :2 32 :3 16 :2 1c 21 2d 71
74 :2 2d :2 16 66 :3 13 :2 1e 32 3b
47 :2 32 4b 56 :2 13 :4 10 :4 d a
2b 11 1a 24 :2 11 2a 27 33
42 :2 2a :2 27 10 4b 54 5e :2 4b
61 63 :2 61 4a :2 10 d 1d d
10 19 23 :2 10 28 26 31 3b
:2 28 :2 26 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 92 95 9e a6 :2 af :2 9e
d0 :2 95 :2 2a :2 13 63 :2 10 13 :2 1d
2f :2 39 45 48 5c 5f 60 :2 5c
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
:2 13 63 :3 10 :2 1b 31 :2 3a 5a :2 10
d 3e 13 1c 26 :2 13 2b 29
34 3e :2 2b :2 29 10 20 10 41
3e :3 d 1b d 17 27 15 24
26 36 47 4b 56 16 19 23
14 17 2b 2d 14 16 2b 2d
14 16 20 29 :2 10 :2 19 25 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 60 63 64 :2 60
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
81 84 :2 2d 88 8b :2 2d 97 9a
:2 2d a2 a5 :2 2d b1 b4 bb c4
c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c
:2 10 d :3 66 10 19 25 :2 10 28
2a :2 28 13 :2 1d 2f :2 39 45 49
5d 60 61 :2 5d :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 92 95 9e a6 :2 af :2 9e
ca :2 95 :2 2a d2 d5 :2 2a dd e0
:2 2a e5 e8 :2 2a f2 f5 :2 2a :2 13
64 :2 10 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a :2 13 63 :3 10 :2 1b
2f :2 38 52 18 :2 10 2c :2 d 17
27 37 20 31 34 39 53 13
17 24 27 36 3a 48 4b 16
19 26 37 3a 44 11 19 20
23 46 4a :2 10 :2 19 25 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :3 66 10 19 25 :2 10 28 2a
:2 28 13 :2 1d 2f :2 39 45 49 5d
60 61 :2 5d :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a 7e 81 :2 2a 85 88
:2 2a 92 95 9e a6 :2 af :2 9e c3
:2 95 :2 2a cb ce :2 2a d6 d9 :2 2a
de e1 :2 2a eb ee :2 2a :2 13 64
:2 10 13 :2 1d 2f :2 39 45 48 5c
5f 60 :2 5c :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a :2 13 63 :3 10 :2 1b 2f
:2 38 4b 56 :2 10 2c :3 d 1d :2 d
1b 2d 3b 46 54 60 21 2f
:2 60 :2 1b d 66 2b :2 a d 16
22 :2 d 25 27 :2 25 d 1b 25
:2 1b d 29 :2 a d :2 17 29 :2 33
3f 43 57 5a 5b :2 57 :2 29 :3 d
:2 13 18 24 68 6b :2 24 78 7b
:2 24 7f 82 :2 24 8c 8f 98 a0
:2 98 ad :2 8f :2 24 b5 b8 :2 24 c0
c3 :2 24 c8 cb :2 24 d5 d8 :2 24
:2 d 5e :2 a d :2 17 29 :2 33 3f
42 56 59 5a :2 56 :2 29 :3 d :2 13
18 24 68 6b :2 24 :2 d 5d :3 a
:2 15 29 32 3e :2 29 42 4d :2 a
7 38 :4 e d :4 30 2f :2 d a
1b :2 a 1c a e :2 19 21 30
40 :2 e 44 46 :2 44 d 4e :2 59
10 20 2f :2 4e 33 36 :2 33 4d
:2 d 10 :2 1a 2c :2 36 42 46 5a
5d 5e :2 5a :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 7b 7e :2 27 82 85
:2 27 8f 92 9b a3 :2 ac :2 9b c9
:2 92 :2 27 d1 d4 :2 27 dc df :2 27
e4 e7 :2 27 f1 f4 :2 27 :2 10 61
:2 d 10 :2 1a 2c :2 36 42 45 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 :2 10 60 :3 d :2 18 2c
:2 35 51 15 :2 d 39 :2 a 14 20
2b 12 20 2d 12 20 2d 3e
4b :2 d :2 16 22 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5d 60 61 :2 5d :2 2f :3 13 :2 19
1e 2a 6e 71 :2 2a 7e 81 :2 2a
85 88 :2 2a 94 97 :2 2a 9f a2
:2 2a ae b1 b8 c1 c4 :2 b1 :2 2a
:2 13 64 :2 10 :2 d :4 19 :2 d a :3 4e
d 14 20 23 :2 d 26 28 :2 26
d 20 d 2c d 20 d :5 a
17 :2 a 17 a e :2 19 21 30
3e :2 e 42 45 :2 42 d 4c :2 57
5f 12 21 :2 4c 25 28 :2 25 4b
:2 d 2f 38 41 :2 2f 47 44 50
59 :2 47 :2 44 2e :2 d 10 :2 1b 23
32 40 :2 10 44 47 :2 44 1a 25
39 46 18 19 26 37 44 :2 13
:2 1c 28 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 63
66 67 :2 63 :2 35 :3 19 :2 1f 24 30
74 77 :2 30 84 87 :2 30 8b 8e
:2 30 9a 9d :2 30 a5 a8 :2 30 b4
b7 be c7 ca :2 b7 :2 30 :2 19 6a
:2 16 :2 13 :4 1f :2 13 10 :3 49 10 20
:2 10 1b :2 10 1d 10 d 49 13
:2 1e 26 36 45 :2 13 49 4c :2 49
1a 25 32 3a 41 5a 65 6a
:2 18 :2 13 :2 1c 28 13 10 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 63 66 67 :2 63 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 84 87 :2 30
8b 8e :2 30 9a 9d :2 30 a5 a8
:2 30 b4 b7 be c7 ca :2 b7 :2 30
:2 19 6a :2 16 :2 13 :4 1f :2 13 10 :3 4e
10 1d :2 28 2f 3f :2 1d :2 10 20
21 :2 20 :2 10 1e 35 43 4e 59
5f 65 28 34 42 55 :2 1e 10
14 1d 29 :2 14 2c 2e :2 2c 13
:4 37 36 35 :2 13 1d 32 3e 1c
29 3a 4e 5c 67 6f 76 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:4 56 :2 10 13 1a 26 29 :2 13 2c
2e :2 2c 13 22 13 32 13 22
13 :5 10 1e 2c 3a 45 50 5a
66 6c 1f 2d 3d 4a 55 1f
2b 2e 39 :2 1e 10 1a 22 29
40 48 4f 68 72 83 91 18
1e 24 30 43 4f 18 19 2d
:2 13 :2 1c 28 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 66 67 :2 63 :2 35 :3 19 :2 1f 24
30 74 77 :2 30 84 87 :2 30 8b
8e :2 30 9a 9d :2 30 a5 a8 :2 30
b4 b7 be c7 ca :2 b7 :2 30 :2 19
6a :2 16 :2 13 :4 1f :2 13 10 :3 4e 10
20 :2 10 1e 35 43 4e 59 5f
65 28 34 42 55 :2 1e :2 10 1e
28 :2 1e :2 10 :2 19 25 10 13 :2 1d
2f :2 39 45 48 5c 5f 60 :2 5c
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
7e 81 :2 2a 85 88 :2 2a 92 95
9e a6 :2 af :2 9e ba :2 95 :2 2a c2
c5 :2 2a cd d0 :2 2a d5 d8 :2 2a
ec ef :2 2a :2 13 63 :3 10 :2 1b 2d
:2 36 40 55 :2 10 d 4e 49 13
1c 25 :2 13 2a 28 33 3c :2 2a
:2 28 10 1b 24 2d :2 1b 30 32
3b 44 :2 32 :2 1b :2 10 1d 10 d
3f 49 13 1c 25 :2 13 28 2a
:2 28 10 1b :2 10 1d 10 1a 28
18 19 26 :2 13 :2 1c 28 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 63 66 67 :2 63 :2 35
:3 19 :2 1f 24 30 74 77 :2 30 84
87 :2 30 8b 8e :2 30 9a 9d :2 30
a5 a8 :2 30 b4 b7 be c7 ca
:2 b7 :2 30 :2 19 6a :2 16 :2 13 :4 1f :2 13
10 :3 2c d 2c 49 13 1c 25
:2 13 2a 28 33 3c :2 2a :2 28 10
1b 24 2d :2 1b 30 32 3b 44
:2 32 :2 1b :2 10 1f :2 10 18 10 13
1c 2d :2 13 30 32 :2 30 13 1b
1a 1d :2 1b 35 38 :2 1b 45 48
:2 1b 1f 22 :2 1b 2f 32 :2 1b 1a
1d :2 1b 46 49 51 5a 63 :2 51
:2 49 :2 1b :2 13 18 :2 26 13 34 13
1b 1a 1d :2 1b 35 38 :2 1b 41
44 :2 1b 6a 6d :2 1b 1f 22 :2 1b
1a 1d :2 1b 46 49 51 5a 63
:2 51 :2 49 :2 1b :2 13 18 :2 26 13 :5 10
16 1f 30 :2 16 33 35 :2 33 1c
2b :2 16 19 23 :2 19 :2 22 2e 19
29 19 :2 22 2e 19 :4 16 37 1c
2b :2 16 19 23 :2 19 :2 22 2e 19
29 19 :2 22 2e 19 :4 16 :4 13 17
:2 20 2c 29 :2 35 :2 29 :3 16 45 :2 13
10 14 3f 13 1c 2d :2 13 30
32 :2 30 16 1c :3 16 :2 1f 2b 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :4 34 16 1c :3 16 :2 1f 2b
16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :7 10 :4 14 13 16 1f
30 :2 16 33 35 :2 33 19 :2 23 35
:2 3f 4b 4f 63 66 67 :2 63 :2 35
:3 19 :2 1f 24 30 74 77 :2 30 84
87 :2 30 8b 8e :2 30 98 9b a4
ac :2 b5 :2 a4 c8 :2 9b :2 30 d0 d3
:2 30 db de :2 30 e3 e6 :2 30 f3
f6 :2 30 :2 19 6a :2 16 19 :2 23 35
:2 3f 4b 4e 62 65 66 :2 62 :2 35
:3 19 :2 1f 24 30 74 77 :2 30 :2 19
69 :3 16 :2 21 35 :2 3e 50 5e :2 16
37 19 :2 23 35 :2 3f 4b 4f 63
66 67 :2 63 :2 35 :3 19 :2 1f 24 30
74 77 :2 30 84 87 :2 30 8b 8e
:2 30 98 9b a4 ac :2 b5 :2 a4 c8
:2 9b :2 30 d0 d3 :2 30 db de :2 30
e3 e6 :2 30 ef f2 :2 30 :2 19 6a
:2 16 19 :2 23 35 :2 3f 4b 4e 62
65 66 :2 62 :2 35 :3 19 :2 1f 24 30
74 77 :2 30 :2 19 69 :3 16 :2 21 35
:2 3e 50 5a :2 16 :4 13 29 :2 10 1a
25 32 3a 41 57 62 67 :2 18
:2 13 :2 1c 28 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 66 67 :2 63 :2 35 :3 19 :2 1f 24
30 74 77 :2 30 84 87 :2 30 8b
8e :2 30 9a 9d :2 30 a5 a8 :2 30
b4 b7 be c7 ca :2 b7 :2 30 :2 19
6a :2 16 :2 13 :4 1f :2 13 10 :3 3f 10
1b :2 10 1d 10 3f 49 :2 d a
5d 10 19 22 :2 10 28 25 31
42 :2 28 :2 25 10 19 28 :2 10 2d
2b 36 40 :2 2d :2 2b 13 :2 1d 2f
:2 39 45 49 5d 60 61 :2 5d :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a 7e
81 :2 2a 85 88 :2 2a 92 95 9e
a6 :2 af :2 9e ba :2 95 :2 2a c2 c5
:2 2a cd d0 :2 2a d5 d8 :2 2a e2
e5 :2 2a :2 13 64 :2 10 13 :2 1d 2f
:2 39 45 48 5c 5f 60 :2 5c :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a :2 13
63 :3 10 :2 1b 2f :2 38 42 4d :2 10
43 :2 d 10 19 22 :2 10 25 27
:2 25 10 23 10 29 14 1d 26
:2 14 29 2b :2 29 13 32 3b 44
:2 32 47 49 :2 47 31 :2 13 16 :2 20
32 :2 3c 48 4b 5f 62 63 :2 5f
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
81 84 :2 2d 88 8b :2 2d 95 98
a1 a9 :2 b2 :2 a1 c3 :2 98 :2 2d :2 16
66 :2 13 16 :2 20 32 :2 3c 48 4b
5f 62 63 :2 5f :2 32 :3 16 :2 1c 21
2d 71 74 :2 2d :2 16 66 :3 13 :2 1e
34 :2 3d 4d :2 13 54 :3 10 23 10
:4 d :4 11 10 1a 29 18 19 2d
:2 13 :2 1c 28 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 66 67 :2 63 :2 35 :3 19 :2 1f 24
30 74 77 :2 30 84 87 :2 30 8b
8e :2 30 9a 9d :2 30 a5 a8 :2 30
b4 b7 be c7 ca :2 b7 :2 30 :2 19
6a :2 16 :2 13 :4 1f :2 13 10 :3 2e 14
:2 1d 28 26 :2 31 :2 26 13 46 4f
60 :2 46 65 63 16 22 :2 65 :2 63
45 :2 13 16 :2 20 32 :2 3c 48 4c
60 63 64 :2 60 :2 32 :3 16 :2 1c 21
2d 71 74 :2 2d 81 84 :2 2d 88
8b :2 2d 95 98 a1 a9 :2 b2 :2 a1
ca :2 98 :2 2d d2 d5 :2 2d dd e0
:2 2d e5 e8 :2 2d f8 fb :2 2d :2 16
67 :2 13 16 :2 20 32 :2 3c 48 4b
5f 62 63 :2 5f :2 32 :3 16 :2 1c 21
2d 71 74 :2 2d :2 16 66 :3 13 :2 1e
32 :2 3b 52 1b :2 13 26 :2 10 2e
:3 d 18 :2 d 1a d 10 19 24
:2 10 27 29 :2 27 10 1d 10 2c
:2 d 17 2c 3a 46 10 1e 2a
39 10 1e 27 2e 3b 44 51
5a 16 2a 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 60 64
65 :2 60 :2 32 :3 16 :2 1c 21 2d 72
75 :2 2d 82 85 :2 2d 89 8c :2 2d
98 9b :2 2d a3 a6 :2 2d b2 b5
bc c5 c8 :2 b5 :2 2d :2 16 68 :2 13
:2 10 :4 1c :2 10 d :3 45 10 19 24
:2 10 27 2a :2 27 10 1d 10 2c
:2 d 45 5d :2 a d 17 19 :2 17
d 1d 1e :2 1d :2 d 20 37 45
50 5b 61 67 2d 39 47 5a
:2 20 d 11 1a 26 :2 11 29 2b
:2 29 10 :4 34 33 32 :3 10 1e 33
41 4c 56 67 26 38 44 :2 1e
10 53 :2 d :4 11 :2 10 23 33 41
4c :2 23 10 2e 13 1a 26 29
:2 13 2c 2e :2 2c 13 26 36 44
4f :2 26 13 32 13 26 36 44
4f :2 26 13 :4 10 :4 d :4 11 10 13
1c 27 :2 13 2a 2c :2 2a 13 21
:2 2a 31 3a 45 :2 31 49 :2 52 :2 21
20 13 1d 28 35 3d 44 5f
6a 6f :2 1b :2 16 :2 1f 2b 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 6a 6b :2 66 :2 38
:3 1c :2 22 27 33 78 7b :2 33 88
8b :2 33 8f 92 :2 33 9e a1 :2 33
a9 ac :2 33 b8 bb c2 cb ce
:2 bb :2 33 :2 1c 6e :2 19 :2 16 :4 22 :2 16
13 :4 2e 1d 28 35 3d 44 5f
6a 6f :2 1b :2 16 :2 1f 2b 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 6a 6b :2 66 :2 38
:3 1c :2 22 27 33 78 7b :2 33 88
8b :2 33 8f 92 :2 33 9e a1 :2 33
a9 ac :2 33 b8 bb c2 cb ce
:2 bb :2 33 :2 1c 6e :2 19 :2 16 :4 22 :2 16
13 :8 10 1c 25 2f :2 1c 32 34
3d 4c :2 34 :2 1c 10 2f :3 d 1f
:2 d 20 2e 39 47 51 61 24
30 39 42 :2 30 46 4f 60 :2 46
:2 20 d 10 19 2a :2 10 2d 30
:2 2d 13 :2 1d 2f :2 39 45 49 5d
61 62 :2 5d :2 2f :3 13 :2 19 1e 2a
6f 72 :2 2a 7f 82 :2 2a 86 89
:2 2a 93 96 9f a7 :2 b0 :2 9f c8
:2 96 :2 2a d0 d3 :2 2a db de :2 2a
e3 e6 :2 2a f0 f3 :2 2a :2 13 65
:2 10 13 :2 1d 2f :2 39 45 48 5c
60 61 :2 5c :2 2f :3 13 :2 19 1e 2a
6f 72 :2 2a :2 13 64 :3 10 :2 1b 2f
:2 38 4f 5a :2 10 d 32 13 1d
1f :2 1d 1a 2f 3d 4b 54 5b
68 71 7e 87 13 22 2b 37
47 57 60 6d 13 27 19 2d
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 63 67 68 :2 63 :2 35
:3 19 :2 1f 24 30 75 78 :2 30 85
88 :2 30 8c 8f :2 30 9b 9e :2 30
a6 a9 :2 30 b5 b8 bf c8 cb
:2 b8 :2 30 :2 19 6b :2 16 :2 13 :4 1f :2 13
10 :4 21 32 :3 d 1b 25 :2 1b d
10 :2 1a 2c :2 36 42 46 5a 5e
5f :2 5a :2 2c :3 10 :2 16 1b 27 6c
6f :2 27 7c 7f :2 27 83 86 :2 27
90 93 9c a4 :2 9c b1 :2 93 :2 27
b9 bc :2 27 c4 c7 :2 27 cc cf
:2 27 d9 dc :2 27 :2 10 62 :2 d 10
:2 1a 2c :2 36 42 45 59 5d 5e
:2 59 :2 2c :3 10 :2 16 1b 27 6c 6f
:2 27 :2 10 61 :3 d :2 18 2c 35 41
:2 2c 45 50 :2 d 1b :2 a d 16
20 :2 d 26 23 2f 3e :2 26 :2 23
17 27 15 24 34 16 2a 14
29 14 1e 27 :2 10 :2 19 25 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 60 64 65 :2 60
:2 32 :3 16 :2 1c 21 2d 72 75 :2 2d
82 85 :2 2d 89 8c :2 2d 98 9b
:2 2d a3 a6 :2 2d b2 b5 bc c5
c8 :2 b5 :2 2d :2 16 68 :2 13 :2 10 :4 1c
:2 10 d :3 41 10 19 25 :2 10 28
2a :2 28 13 :2 1d 2f :2 39 45 49
5d 61 62 :2 5d :2 2f :3 13 :2 19 1e
2a 6f 72 :2 2a 7f 82 :2 2a 86
89 :2 2a 93 96 9f a7 :2 b0 :2 9f
cb :2 96 :2 2a d3 d6 :2 2a de e1
:2 2a e6 e9 :2 2a f3 f6 :2 2a :2 13
65 :2 10 13 :2 1d 2f :2 39 45 48
5c 60 61 :2 5c :2 2f :3 13 :2 19 1e
2a 6f 72 :2 2a :2 13 64 :3 10 :2 1b
2f :2 38 52 18 :2 10 2c :3 d 1d
:2 d 1f 28 32 :2 1f d 10 19
27 :2 10 2c 2a 35 3f :2 2c :2 2a
10 20 21 :2 20 :2 10 23 3a 48
53 5e 64 6a 2d 39 47 5a
:2 23 10 :4 14 :2 13 26 36 44 4f
:2 26 13 31 16 1d 29 2c :2 16
2f 31 :2 2f 16 29 39 47 52
:2 29 16 35 16 29 39 47 52
:2 29 16 :4 13 :5 10 1d 10 :4 14 13
16 1f 2a :2 16 2d 2f :2 2d 16
24 :2 2d 34 3d 48 :2 34 4c :2 55
:2 24 23 16 20 2b 38 40 47
62 6d 72 :2 1e :2 19 :2 22 2e 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 69 6d 6e :2 69
:2 3b :3 1f :2 25 2a 36 7b 7e :2 36
8b 8e :2 36 92 95 :2 36 a1 a4
:2 36 ac af :2 36 bb be c5 ce
d1 :2 be :2 36 :2 1f 71 :2 1c :2 19 :4 25
:2 19 16 :4 31 20 2b 38 40 47
62 6d 72 :2 1e :2 19 :2 22 2e 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 69 6d 6e :2 69
:2 3b :3 1f :2 25 2a 36 7b 7e :2 36
8b 8e :2 36 92 95 :2 36 a1 a4
:2 36 ac af :2 36 bb be c5 ce
d1 :2 be :2 36 :2 1f 71 :2 1c :2 19 :4 25
:2 19 16 :7 13 16 1f 2b :2 16 2e
30 :2 2e 20 2c 3c 1e 1f 2c
3d 51 5f 6a 72 79 :2 19 :2 22
2e 19 16 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 69 6d
6e :2 69 :2 3b :3 1f :2 25 2a 36 7b
7e :2 36 8b 8e :2 36 92 95 :2 36
a1 a4 :2 36 ac af :2 36 bb be
c5 ce d1 :2 be :2 36 :2 1f 71 :2 1c
:2 19 :4 25 :2 19 16 :4 32 :2 13 32 :3 10
1c 25 33 :2 1c 36 38 41 50
:2 38 :2 1c 53 55 5e 69 :2 55 :2 1c
:2 10 22 10 1a 2f 3d 4b 54
5b 67 70 13 20 2e 3c 4a
53 13 2a 42 19 2d 13 1a
16 22 :3 20 16 :2 1f 2b 16 27
16 :2 1f 2b 16 :4 13 10 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 63 67 68 :2 63 :2 35 :3 19 :2 1f
24 30 75 78 :2 30 85 88 :2 30
8c 8f :2 30 9b 9e :2 30 a6 a9
:2 30 b5 b8 bf c8 cb :2 b8 :2 30
:2 19 6b :2 16 :2 13 :4 1f :2 13 10 :3 42
14 :2 1d 28 26 :2 31 :2 26 :2 13 25
:2 13 21 2f 3a 48 52 62 6d
1f 22 2b 3c :2 22 :2 21 13 16
1f 2b :2 16 2e 31 :2 2e 19 :2 23
35 :2 3f 4b 4f 63 67 68 :2 63
:2 35 :3 19 :2 1f 24 30 75 78 :2 30
85 88 :2 30 8c 8f :2 30 99 9c
a5 ad :2 a5 ba :2 9c :2 30 c2 c5
:2 30 cd d0 :2 30 d5 d8 :2 30 e2
e5 :2 30 :2 19 6b :2 16 19 :2 23 35
:2 3f 4b 4e 62 66 67 :2 62 :2 35
:3 19 :2 1f 24 30 75 78 :2 30 :2 19
6a :3 16 :2 21 35 3e 4a :2 35 4e
59 :2 16 33 :2 13 41 :3 10 1c 25
33 :2 1c 10 42 10 22 2a 33
41 :2 2a 44 46 4f 59 :2 46 :2 2a
29 5d 5f :2 29 28 69 6b :2 28
:2 22 10 :5 d 1b 2f 3d 48 52
5d 25 31 3b 49 25 34 44
50 25 31 3e 4c 25 33 42
55 25 31 3d 46 51 :2 3d :2 1b
d 10 :2 1a 2c :2 36 42 46 5a
5e 5f :2 5a :2 2c :3 10 :2 16 1b 27
6c 6f :2 27 7c 7f :2 27 83 86
:2 27 90 93 9c a4 :2 9c b1 :2 93
:2 27 b9 bc :2 27 c4 c7 :2 27 cc
cf :2 27 d9 dc :2 27 :2 10 62 :2 d
10 :2 1a 2c :2 36 42 45 59 5d
5e :2 59 :2 2c :3 10 :2 16 1b 27 6c
6f :2 27 :2 10 61 :3 d :2 18 2c 35
41 :2 2c 45 50 :2 d a 41 10
19 29 :2 10 2f 2c 38 48 :2 2f
:2 2c 11 1a 29 :2 11 2c 2e :2 2c
10 36 3f 4f :2 36 52 54 :2 52
35 :2 10 13 :2 1d 2f :2 39 45 49
5d 61 62 :2 5d :2 2f :3 13 :2 19 1e
2a 6f 72 :2 2a 7f 82 :2 2a 86
89 :2 2a 93 96 9f a7 :2 b0 :2 9f
bb :2 96 :2 2a c3 c6 :2 2a ce d1
:2 2a d6 d9 :2 2a e3 e6 :2 2a :2 13
65 :2 10 13 :2 1d 2f :2 39 45 48
5c 60 61 :2 5c :2 2f :3 13 :2 19 1e
2a 6f 72 :2 2a :2 13 64 :3 10 :2 1b
2f :2 38 42 4d :2 10 57 :2 d 17
2c 40 10 1e 27 2e 3a 43
16 2a 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 60 64 65
:2 60 :2 32 :3 16 :2 1c 21 2d 72 75
:2 2d 82 85 :2 2d 89 8c :2 2d 98
9b :2 2d a3 a6 :2 2d b2 b5 bc
c5 c8 :2 b5 :2 2d :2 16 68 :2 13 :2 10
:4 1c :2 10 d :3 4b 17 23 31 3a
41 4d 56 16 23 34 41 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 60 64 65 :2 60 :2 32 :3 16
:2 1c 21 2d 72 75 :2 2d 82 85
:2 2d 89 8c :2 2d 98 9b :2 2d a3
a6 :2 2d b2 b5 bc c5 c8 :2 b5
:2 2d :2 16 68 :2 13 :2 10 :4 1c :2 10 d
:4 4b 41 :3 a 18 22 :2 18 a d
:2 17 29 :2 33 3f 43 57 5b 5c
:2 57 :2 29 :3 d :2 13 18 24 69 6c
:2 24 79 7c :2 24 80 83 :2 24 8d
90 99 a1 :2 99 ae :2 90 :2 24 b6
b9 :2 24 c1 c4 :2 24 c9 cc :2 24
d6 d9 :2 24 :2 d 5f :2 a d :2 17
29 :2 33 3f 42 56 5a 5b :2 56
:2 29 :3 d :2 13 18 24 69 6c :2 24
:2 d 5e :3 a :2 15 29 32 3e :2 29
42 4d :2 a 4e 38 14 17 24
27 34 37 43 46 17 1a 17
1a d 10 d 10 1c 1f 12
21 30 3e :4 d 1b 12 27 30
33 47 :2 d :2 16 22 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5d 61 62 :2 5d :2 2f :3 13
:2 19 1e 2a 6f 72 :2 2a 7f 82
:2 2a 86 89 :2 2a 95 98 :2 2a a0
a3 :2 2a af b2 b9 c2 c5 :2 b2
:2 2a :2 13 65 :2 10 :2 d :4 19 :2 d a
:3 7 12 :2 1b 26 24 :2 2f :2 24 11
:3 d 10 :2 1a 2c :2 36 42 46 5a
5e 5f :2 5a :2 2c :3 10 :2 16 1b 27
6c 6f :2 27 7c 7f :2 27 83 86
:2 27 90 93 9c a4 :2 ad :2 9c c0
:2 93 :2 27 c8 cb :2 27 d3 d6 :2 27
db de :2 27 f2 f5 :2 27 :2 10 62
:2 d 10 :2 1a 2c :2 36 42 45 59
5d 5e :2 59 :2 2c :3 10 :2 16 1b 27
6c 6f :2 27 :2 10 61 :3 d :2 18 2c
:2 35 47 15 :2 d 3f :2 a d :2 18
1f 2e :2 d 3d 3f :2 3d d :2 16
22 d 10 :2 1a 2c :2 36 42 46
5a 5e 5f :2 5a :2 2c :3 10 :2 16 1b
27 6c 6f :2 27 7c 7f :2 27 83
86 :2 27 90 93 9c a4 :2 ad :2 9c
b8 :2 93 :2 27 c0 c3 :2 27 cb ce
:2 27 d3 d6 :2 27 ea ed :2 27 :2 10
62 :2 d 10 :2 1a 2c :2 36 42 45
59 5d 5e :2 59 :2 2c :3 10 :2 16 1b
27 6c 6f :2 27 :2 10 61 :3 d :2 18
2c :2 35 3f 54 :2 d 41 :2 a :4 7
35 :3 4 11 :2 4 15 :2 4 12 :2 4
14 :2 1d :2 4 :2 d 19 30 3e 49
58 :2 19 4 7 :2 11 23 :2 2d 39
3c 50 54 55 :2 50 :2 23 :3 7 :2 d
12 1e 63 66 :2 1e 73 76 :2 1e
7a 7d :2 1e 87 8a 93 9b :2 a4
:2 93 af :2 8a :2 1e b7 ba :2 1e c2
c5 :2 1e ca cd :2 1e d7 da :2 1e
:2 7 58 :3 4 :2 f 21 :2 2a 34 3f
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 54 58 59 :2 54 :2 26
:3 a :2 10 15 21 66 69 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 5c
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 51 55 56 :2 51 :2 23
:3 7 :2 d 12 1e 63 66 :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 59 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
24c7
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b 2
:4 c :2 1 :7 e :7 f
:7 10 :7 11 :7 12 :7 13
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :5 1b
:5 1c :5 1d :5 1e :5 1f
:5 20 :5 21 :5 22 :5 23
:7 24 :7 25 :6 26 :6 27
:6 28 :5 29 :5 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :7 35 :7 36 :7 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:7 50 :7 51 :6 52 :7 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :6 5a :6 5b
:6 5c :6 5d :6 5e :7 5f
:5 60 :5 61 :7 64 :7 67
:7 69 :b 6b :11 6c 6d
:2 6c :2 6d :2 6c :2 6d
:2 6c :2 6e :2 6c :2 6e
:2 6c :2 6e :2 6c :2 6e
:2 6c :2 6f :2 6c :12 6f
:2 6c :2 70 :2 6c :12 70
:2 6c :2 71 :2 6c :9 71
:2 6c :2 72 :2 6c :9 72
:2 6c :2 73 :2 6c :9 73
:2 6c :2 74 :2 6c :9 74
:2 6c :2 75 :2 6c :2 75
:2 6c :2 75 :2 6c :2 75
:2 6c :2 75 :4 6c :3 6b
:11 78 :b 79 :3 78 :3 7e
:3 7f :3 80 :3 81 :3 84
:8 87 :2 88 :2 89 :2 8a
:4 8b :4 8c 8d 8e
8f :2 90 :2 91 :3 92
87 :5 93 86 :2 95
:5 97 :11 98 :24 99 :3 98
:2 96 :6 95 94 :3 6a
:a 9f :4 a1 :8 a2 :8 a3
:5 a4 :8 a5 :4 a6 :4 a7
:3 a8 :4 a9 :8 aa :5 ab
:3 ac :4 ad :4 ae :4 af
:3 b0 b1 :2 b2 a1
:5 b3 a0 :2 b5 :5 b7
:11 b8 :24 b9 :3 b8 :2 b6
:6 b5 b4 :3 9f :a c0
:6 c2 :a c3 :6 c4 :7 c5
:3 c6 c2 :5 c7 c1
:2 c9 :5 cb :11 cc :24 cd
:3 cc :2 ca :6 c9 c8
:3 c0 :a d3 :11 d4 :30 d5
:3 d4 :11 d7 :b d8 :3 d7
:a da :3 d3 :3 dd :3 de
:10 df :3 e0 :2 df :4 e0
:3 df :11 e1 :30 e2 :3 e1
:11 e4 :b e5 :3 e4 :7 e7
e8 :2 e7 e0 :2 df
:16 ed :2 ee :7 ed :11 f0
:30 f1 :3 f0 :11 f3 :b f4
:3 f3 :7 f6 f7 :2 f6
ee :2 ed :11 fa :2 fb
:2 fa :4 fb :3 fa :9 fc
:c fd :9 ff 100 :2 101
:4 102 ff :5 103 fe
:2 105 :5 107 :11 108 :24 109
:3 108 :2 106 :6 105 104
:3 fd :a 10e :8 110 111
110 :5 112 10f :2 114
:5 116 :11 117 :24 118 :3 117
:2 115 :6 114 113 :6 10e
:c 11e :3 11f :3 11e fd
:9 123 124 :2 125 :4 126
123 :5 127 122 :2 129
:5 12b :11 12c :24 12d :3 12c
:2 12a :6 129 128 :3 121
:a 132 :8 134 135 134
:5 136 133 :2 138 :5 13a
:11 13b :24 13c :3 13b :2 139
:6 138 137 :6 132 :3 142
121 :3 fd :b 145 :7 147
:2 148 147 :6 149 :5 14a
149 :5 14c 14b :3 149
146 :2 14f :5 151 :11 152
:24 153 :3 152 :2 150 :6 14f
14e :4 145 :7 159 :2 15a
159 :6 15b :5 15c 15b
:5 15e 15d :3 15b 158
:2 161 :5 163 :11 164 :24 165
:3 164 :2 162 :6 161 160
:4 157 :3 145 :a 16b :6 16c
:3 16b fc :3 170 171
:4 172 173 170 :5 174
16f :2 176 :5 178 :11 179
:24 17a :3 179 :2 177 :6 176
175 :3 16e :9 180 :11 181
:30 182 :3 181 :11 184 :b 185
:3 184 :7 187 188 :2 187
:3 180 :c 18b :9 18d 18e
:2 18f :4 190 18d :5 191
18c :2 193 :5 195 :11 196
:24 197 :3 196 :2 194 :6 193
192 :3 18b :a 19c :8 19e
19f 19e :5 1a0 19d
:2 1a2 :5 1a4 :11 1a5 :24 1a6
:3 1a5 :2 1a3 :6 1a2 1a1
:6 19c 18b :9 1ad 1ae
:2 1af :4 1b0 1ad :5 1b1
1ac :2 1b3 :5 1b5 :11 1b6
:24 1b7 :3 1b6 :2 1b4 :6 1b3
1b2 :3 1ab :a 1bc :8 1be
1bf 1be :5 1c0 1bd
:2 1c2 :5 1c4 :11 1c5 :24 1c6
:3 1c5 :2 1c3 :6 1c2 1c1
:6 1bc 1ab :3 18b :7 1cd
:8 1ce 1cf :3 1cd :9 1d1
:6 1d2 1d1 :11 1d4 :2e 1d5
:3 1d4 :11 1d7 :b 1d8 :3 1d7
:c 1da 1d3 :3 1d1 16e
:3 fc 1dd fb :1a 1dd
:3 1de :d 1df :11 1e0 :20 1e1
:3 1e0 :11 1e3 :b 1e4 :3 1e3
:9 1e6 1e7 1df :d 1e7
:3 1e8 1e7 :3 1df :3 1ec
:2 1ee 1ef :6 1f0 :3 1f1
:4 1f2 :4 1f3 :4 1f4 1ee
:5 1f5 1ed :2 1f7 :5 1f9
:11 1fa :24 1fb :3 1fa :2 1f8
:6 1f7 1f6 :3 1dd :9 200
:11 201 :30 202 :3 201 :11 204
:b 205 :3 204 :7 207 208
:2 207 :3 200 :3 20d :5 20e
:8 20f :6 210 :6 211 20d
:5 212 20c :2 214 :5 216
:11 217 :24 218 :3 217 :2 215
:6 214 213 :3 1dd :9 21e
:11 21f :30 220 :3 21f :11 222
:b 223 :3 222 :a 225 :3 21e
:3 228 :7 22e :2 22f :5 22e
1dd fb :2 fa :9 233
:6 234 :3 233 :11 237 :2e 238
:3 237 :11 23a :b 23b :3 23a
:c 23d 23e c0 :c 23e
:3 23f :3 240 :10 242 :3 243
:2 242 :4 243 :3 242 :11 244
:30 245 :3 244 :11 247 :b 248
:3 247 :7 24a 24b :2 24a
243 :2 242 :3 24f :3 250
:5 251 24f :5 252 24e
:2 254 :5 256 :11 257 :24 258
:3 257 :2 255 :6 254 253
:3 23e :a 25e :3 25f 25e
:3 261 260 :3 25e :3 264
:3 265 :11 26d :2 26e :2 26d
:4 26e :3 26d :e 26e :2 26d
:c 26f :4 271 272 :4 273
271 :5 274 270 :2 276
:5 278 :11 279 :24 27a :3 279
:2 277 :6 276 275 :3 26f
:3 2ce :3 2cf :3 2d0 2d2
26f :c 2d2 :8 2d4 2d5
2d6 2d4 :5 2d7 2d3
:2 2d9 :5 2db :11 2dc :24 2dd
:3 2dc :2 2da :6 2d9 2d8
:3 2d2 :9 2e2 :6 2e4 :8 2e5
:4 2e6 :3 2e5 :12 2e8 :3 2ea
:8 2eb 2ea :6 2ec :5 2ed
2ec :5 2ef 2ee :3 2ec
2e9 :2 2f2 :5 2f4 :11 2f5
:24 2f6 :3 2f5 :2 2f3 :6 2f2
2f1 :6 2e8 :a 2fc :3 2fd
2fc :3 2ff 2fe :3 2fc
:9 302 :5 303 :4 304 :3 302
:a 307 :6 308 309 :2 30a
307 :5 30b 306 :2 30d
:5 30f :11 310 :24 311 :3 310
:2 30e :6 30d 30c :3 2d2
:3 316 :8 317 :4 318 :3 317
:6 31a :5 31c :11 31d :30 31e
:3 31d :a 320 321 2d2
26f :d 321 :f 322 :3 323
324 321 26f :9 324
:3 325 :3 326 :2 329 32a
:2 32b 329 :5 32c 328
:2 32e :5 330 :11 331 :24 332
:3 331 :2 32f :6 32e 32d
:3 324 336 324 26f
:d 336 :f 337 :3 338 :3 339
:9 33b :2 33c :2 33d :2 33c
:2 33d :2 33c :2 33d :2 33c
:2 33e :2 33c :2 33e :2 33c
:2 33f :2 33c :9 33f :3 33c
:5 341 33b :2 343 :2 344
:2 343 :2 344 :2 343 :2 344
:2 343 :2 344 :2 343 :2 345
:2 343 :2 346 :2 343 :9 346
:3 343 :5 348 342 :3 33b
34b :9 34c :4 34d :3 34e
:5 34f 34e :5 351 350
:3 34e 34c :4 354 :3 355
:5 356 355 :5 358 357
:3 355 353 :3 34c :a 35c
:2 35d :3 35c 34b 35f
336 :9 361 :4 363 :5 364
362 :2 366 :5 368 :11 369
:24 36a :3 369 :2 367 :6 366
365 :4 361 :4 370 :5 371
36f :2 373 :5 375 :11 376
:24 377 :3 376 :2 374 :6 373
372 :4 36e :3 361 :5 37e
:9 37f :11 380 :30 381 :3 380
:11 383 :b 384 :3 383 :a 386
37f :11 388 :30 389 :3 388
:11 38b :b 38c :3 38b :a 38e
387 :3 37f :3 37e :8 393
394 395 393 :5 396
392 :2 398 :5 39a :11 39b
:24 39c :3 39b :2 399 :6 398
397 :3 336 :3 3a1 :3 3a2
336 :3 26f 3a4 26e
:d 3a4 :d 3a5 :11 3a6 :30 3a7
:3 3a6 :11 3a9 :b 3aa :3 3a9
:a 3ac :3 3a5 :9 3af :3 3b0
3af :16 3b2 :11 3b3 :20 3b4
:3 3b3 :11 3b6 :b 3b7 :3 3b6
:9 3b9 :3 3b2 :3 3bc 3b1
:3 3af :5 3cc :2 3ce 3cf
:2 3d0 3ce :5 3d1 3cd
:2 3d3 :5 3d5 :11 3d6 :24 3d7
:3 3d6 :2 3d4 :6 3d3 3d2
:3 3cc :11 3dc :2 3dd :7 3dc
:11 3de :30 3df :3 3de :11 3e1
:b 3e2 :3 3e1 :7 3e4 3e5
:2 3e4 3dd :2 3dc :3 3cc
:3 423 :3 424 :9 425 :3 426
:3 425 :4 42c :4 42d :8 42e
:2 42f 42c :6 430 :5 431
430 :5 433 432 :3 430
42b :2 436 :5 438 :11 439
:24 43a :3 439 :2 437 :6 436
435 :3 3a4 :9 43f :3 440
:3 43f 3a4 26e :2 26d
:5 447 :6 448 :8 449 :4 44a
:3 449 :12 44c :7 44d :3 44e
:3 44d :3 44c :5 452 :8 453
452 :a 455 :8 456 455
:8 458 457 :3 455 454
:3 452 :5 45c :9 45d :10 45e
:8 461 462 463 461
:5 464 460 :2 466 :5 468
:11 469 :24 46a :3 469 :2 467
:6 466 465 :4 45d :8 470
471 472 470 :5 473
46f :2 475 :5 477 :11 478
:24 479 :3 478 :2 476 :6 475
474 :4 46e :3 45d :f 47f
:3 45c :3 484 :7 485 :b 486
:3 485 :9 489 :11 48a :30 48b
:3 48a :11 48d :b 48e :3 48d
:a 490 491 489 :5 491
:a 493 :8 494 :2 495 :2 496
493 :6 497 :5 498 497
:5 49a 499 :3 497 492
:2 49d :5 49f :11 4a0 :24 4a1
:3 4a0 :2 49e :6 49d 49c
:4 491 :3 489 :6 4a7 :11 4a8
:2e 4a9 :3 4a8 :11 4ab :b 4ac
:3 4ab :c 4ae :3 447 :d 4b1
:2 4b4 4b5 :2 4b6 :2 4b7
:2 4b8 :3 4b9 4b4 :5 4ba
4b3 :2 4bc :5 4be :11 4bf
:24 4c0 :3 4bf :2 4bd :6 4bc
4bb :3 4b1 :9 4c5 :11 4c6
:30 4c7 :3 4c6 :11 4c9 :b 4ca
:3 4c9 :7 4cc 4cd :2 4cc
:3 4c5 :3 4d0 :7 4d2 :d 4d3
:6 4d4 :8 4d5 :4 4d6 :3 4d5
:5 4d8 :8 4d9 4d8 :a 4db
:8 4dc 4db :8 4de 4dd
:3 4db 4da :3 4d8 :3 4e2
:5 4e3 :9 4e4 :10 4e5 :8 4e7
4e8 4e9 4e7 :5 4ea
4e6 :2 4ec :5 4ee :11 4ef
:24 4f0 :3 4ef :2 4ed :6 4ec
4eb :4 4e4 :8 4f6 4f7
4f8 4f6 :5 4f9 4f5
:2 4fb :5 4fd :11 4fe :24 4ff
:3 4fe :2 4fc :6 4fb 4fa
:4 4f4 :3 4e4 :9 505 :3 507
508 :8 509 507 :5 50a
506 :2 50c :5 50e :11 50f
:24 510 :3 50f :2 50d :6 50c
50b :6 505 :3 4e3 :17 517
:3 519 :8 51c :6 51d :3 51e
:2 51f 51c :6 520 :5 521
520 :5 523 522 :3 520
51b :2 526 :5 528 :11 529
:24 52a :3 529 :2 527 :6 526
525 :3 4d3 :a 52f :3 531
:8 532 :6 533 :3 532 :9 536
:11 537 :2e 538 :3 537 :11 53a
:b 53b :3 53a :c 53d :3 536
:3 52f :7 541 4d3 :1c 543
542 :3 4d3 :7 549 :4 54a
:4 54b :4 54c :4 54d :7 54e
:3 549 :11 550 :2e 551 :3 550
:11 553 :b 554 :3 553 :c 556
557 4b1 :d 557 :16 558
:11 559 :30 55a :3 559 :11 55c
:b 55d :3 55c :a 55f :3 558
:3 584 :6 585 :2 586 584
:6 587 :5 588 587 :5 58a
589 :3 587 583 :2 58d
:5 58f :11 590 :24 591 :3 590
:2 58e :6 58d 58c :3 557
:7 59b :4 59c 59b :6 59d
:5 59e 59d :5 5a0 59f
:3 59d 59a :2 5a3 :5 5a5
:11 5a6 :24 5a7 :3 5a6 :2 5a4
:6 5a3 5a2 :4 557 :3 4b1
:6 5af :11 5b0 :2e 5b1 :3 5b0
:11 5b3 :b 5b4 :3 5b3 :c 5b6
23e c0 :8 5b9 :2 5ba
:2 5bb :2 5bc :4 5bd :4 5be
5bf 5c0 5c1 :2 5c2
:5 5c3 5b9 :5 5c4 5b8
:2 5c6 :5 5c8 :11 5c9 :24 5ca
:3 5c9 :2 5c7 :6 5c6 5c5
:3 5b7 :d 5d0 :11 5d1 :30 5d2
:3 5d1 :11 5d4 :b 5d5 :3 5d4
:7 5d7 5d8 :2 5d7 :3 5d0
:b 5db :5 5dc :11 5dd :30 5de
:3 5dd :11 5e0 :b 5e1 :3 5e0
:a 5e3 :3 5db 5b7 :3 c0
:3 9f :3 5e8 :3 5e9 :3 5ea
:5 5ec :b 5ed :11 5ef :30 5f0
:3 5ef :a 5f2 6a :3 5f5
:11 5f6 :b 5f7 :17 5f8 :3 5f6
:2 5fa :3 5fb :3 5fc 5fd
5fb 5fa 5fb :3 5fe
:3 5f5 :2 5ff :5 601 :11 602
:b 603 :18 604 :3 602 :2 606
607 :3 608 609 607
606 607 :3 60a :2 600
:6 5ff 5f4 :7 1 
8014
4
:3 0 1 :3 0 2
:a 0 24c2 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 7 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 7 :3 0 8
:7 0 11 10 :3 0
a :3 0 9 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 b :7 0 19
18 :3 0 a :3 0
c :7 0 1d 1c
:3 0 15 :2 0 13
a :3 0 d :7 0
21 20 :3 0 4
:3 0 e :7 0 25
24 :3 0 f :3 0
10 :3 0 11 :2 0
4 29 2a 0
27 2b 0 24c2
2 2c :2 0 13
:2 0 21 4 :3 0
13 :2 0 1f 2f
31 :6 0 34 32
0 24c0 0 12
:6 0 16 :2 0 25
4 :3 0 23 36
38 :6 0 3b 39
0 24c0 0 14
:6 0 16 :2 0 29
4 :3 0 27 3d
3f :6 0 42 40
0 24c0 0 15
:6 0 13 :2 0 2d
4 :3 0 2b 44
46 :6 0 49 47
0 24c0 0 17
:6 0 16 :2 0 31
4 :3 0 2f 4b
4d :6 0 50 4e
0 24c0 0 18
:6 0 13 :2 0 35
4 :3 0 33 52
54 :6 0 57 55
0 24c0 0 19
:6 0 13 :2 0 39
4 :3 0 37 59
5b :6 0 5e 5c
0 24c0 0 1a
:6 0 13 :2 0 3d
4 :3 0 3b 60
62 :6 0 65 63
0 24c0 0 1b
:6 0 13 :2 0 41
4 :3 0 3f 67
69 :6 0 6c 6a
0 24c0 0 1c
:6 0 13 :2 0 45
4 :3 0 43 6e
70 :6 0 73 71
0 24c0 0 1d
:6 0 13 :2 0 49
4 :3 0 47 75
77 :6 0 7a 78
0 24c0 0 1e
:6 0 13 :2 0 4d
4 :3 0 4b 7c
7e :6 0 81 7f
0 24c0 0 1f
:6 0 53 25b 0
51 4 :3 0 4f
83 85 :6 0 88
86 0 24c0 0
20 :6 0 57 28f
0 55 7 :3 0
8a :7 0 8d 8b
0 24c0 0 21
:6 0 7 :3 0 8f
:7 0 92 90 0
24c0 0 22 :6 0
5b 2c3 0 59
7 :3 0 94 :7 0
97 95 0 24c0
0 23 :6 0 7
:3 0 99 :7 0 9c
9a 0 24c0 0
24 :6 0 5f 2f7
0 5d 7 :3 0
9e :7 0 a1 9f
0 24c0 0 25
:6 0 7 :3 0 a3
:7 0 a6 a4 0
24c0 0 26 :6 0
63 32b 0 61
28 :3 0 a8 :7 0
ab a9 0 24c0
0 27 :6 0 28
:3 0 ad :7 0 b0
ae 0 24c0 0
29 :6 0 2c :2 0
67 28 :3 0 b2
:7 0 b5 b3 0
24c0 0 2a :6 0
4 :3 0 2c :2 0
65 b7 b9 :6 0
bc ba 0 24c0
0 2b :6 0 2f
:2 0 6b 4 :3 0
69 be c0 :6 0
c3 c1 0 24c0
0 2d :6 0 2f
:2 0 6d a :3 0
c5 :7 0 c9 c6
c7 24c0 0 2e
:6 0 2f :2 0 6f
a :3 0 cb :7 0
cf cc cd 24c0
0 30 :6 0 73
3d4 0 71 a
:3 0 d1 :7 0 d5
d2 d3 24c0 0
31 :6 0 2f :2 0
75 28 :3 0 d7
:7 0 da d8 0
24c0 0 32 :6 0
28 :3 0 dc :7 0
df dd 0 24c0
0 33 :6 0 2f
:2 0 77 a :3 0
e1 :7 0 e5 e2
e3 24c0 0 34
:6 0 2f :2 0 79
a :3 0 e7 :7 0
eb e8 e9 24c0
0 35 :6 0 2f
:2 0 7b a :3 0
ed :7 0 f1 ee
ef 24c0 0 36
:6 0 2f :2 0 7d
a :3 0 f3 :7 0
f7 f4 f5 24c0
0 37 :6 0 2f
:2 0 7f a :3 0
f9 :7 0 fd fa
fb 24c0 0 38
:6 0 2f :2 0 81
a :3 0 ff :7 0
103 100 101 24c0
0 39 :6 0 2f
:2 0 83 a :3 0
105 :7 0 109 106
107 24c0 0 3a
:6 0 2f :2 0 85
a :3 0 10b :7 0
10f 10c 10d 24c0
0 3b :6 0 2f
:2 0 87 a :3 0
111 :7 0 115 112
113 24c0 0 3c
:6 0 13 :2 0 89
a :3 0 117 :7 0
11b 118 119 24c0
0 3d :6 0 13
:2 0 8d 4 :3 0
8b 11d 11f :6 0
122 120 0 24c0
0 3e :6 0 13
:2 0 91 4 :3 0
8f 124 126 :6 0
129 127 0 24c0
0 3f :6 0 2f
:2 0 95 4 :3 0
93 12b 12d :6 0
130 12e 0 24c0
0 40 :6 0 2f
:2 0 97 a :3 0
132 :7 0 136 133
134 24c0 0 41
:6 0 2f :2 0 99
a :3 0 138 :7 0
13c 139 13a 24c0
0 42 :6 0 2f
:2 0 9b a :3 0
13e :7 0 142 13f
140 24c0 0 43
:6 0 2f :2 0 9d
a :3 0 144 :7 0
148 145 146 24c0
0 44 :6 0 2f
:2 0 9f a :3 0
14a :7 0 14e 14b
14c 24c0 0 45
:6 0 2f :2 0 a1
a :3 0 150 :7 0
154 151 152 24c0
0 46 :6 0 2f
:2 0 a3 a :3 0
156 :7 0 15a 157
158 24c0 0 47
:6 0 2f :2 0 a5
a :3 0 15c :7 0
160 15d 15e 24c0
0 48 :6 0 2f
:2 0 a7 a :3 0
162 :7 0 166 163
164 24c0 0 49
:6 0 2f :2 0 a9
a :3 0 168 :7 0
16c 169 16a 24c0
0 4a :6 0 2f
:2 0 ab a :3 0
16e :7 0 172 16f
170 24c0 0 4b
:6 0 2f :2 0 ad
a :3 0 174 :7 0
178 175 176 24c0
0 4c :6 0 2f
:2 0 af a :3 0
17a :7 0 17e 17b
17c 24c0 0 4d
:6 0 2f :2 0 b1
a :3 0 180 :7 0
184 181 182 24c0
0 4e :6 0 2f
:2 0 b3 a :3 0
186 :7 0 18a 187
188 24c0 0 4f
:6 0 2f :2 0 b5
a :3 0 18c :7 0
190 18d 18e 24c0
0 50 :6 0 2f
:2 0 b7 a :3 0
192 :7 0 196 193
194 24c0 0 51
:6 0 2f :2 0 b9
a :3 0 198 :7 0
19c 199 19a 24c0
0 52 :6 0 2f
:2 0 bb a :3 0
19e :7 0 1a2 19f
1a0 24c0 0 53
:6 0 2f :2 0 bd
a :3 0 1a4 :7 0
1a8 1a5 1a6 24c0
0 54 :6 0 2f
:2 0 bf a :3 0
1aa :7 0 1ae 1ab
1ac 24c0 0 55
:6 0 2f :2 0 c1
a :3 0 1b0 :7 0
1b4 1b1 1b2 24c0
0 56 :6 0 2f
:2 0 c3 a :3 0
1b6 :7 0 1ba 1b7
1b8 24c0 0 57
:6 0 5a :2 0 c5
a :3 0 1bc :7 0
1c0 1bd 1be 24c0
0 58 :6 0 2c
:2 0 c9 4 :3 0
c7 1c2 1c4 :6 0
1c7 1c5 0 24c0
0 59 :6 0 2f
:2 0 cd 4 :3 0
cb 1c9 1cb :6 0
1ce 1cc 0 24c0
0 5b :6 0 13
:2 0 cf a :3 0
1d0 :7 0 1d4 1d1
1d2 24c0 0 5c
:6 0 2f :2 0 d3
4 :3 0 d1 1d6
1d8 :6 0 1db 1d9
0 24c0 0 5d
:6 0 2f :2 0 d5
a :3 0 1dd :7 0
1e1 1de 1df 24c0
0 5e :6 0 2f
:2 0 d7 a :3 0
1e3 :7 0 1e7 1e4
1e5 24c0 0 5f
:6 0 2f :2 0 d9
a :3 0 1e9 :7 0
1ed 1ea 1eb 24c0
0 60 :6 0 2f
:2 0 db 62 :3 0
1ef :7 0 1f3 1f0
1f1 24c0 0 61
:6 0 2f :2 0 dd
62 :3 0 1f5 :7 0
1f9 1f6 1f7 24c0
0 63 :6 0 2f
:2 0 df 62 :3 0
1fb :7 0 1ff 1fc
1fd 24c0 0 64
:6 0 2f :2 0 e1
62 :3 0 201 :7 0
205 202 203 24c0
0 65 :6 0 2f
:2 0 e3 62 :3 0
207 :7 0 20b 208
209 24c0 0 66
:6 0 2f :2 0 e5
62 :3 0 20d :7 0
211 20e 20f 24c0
0 67 :6 0 2f
:2 0 e7 62 :3 0
213 :7 0 217 214
215 24c0 0 68
:6 0 6b :2 0 e9
62 :3 0 219 :7 0
21d 21a 21b 24c0
0 69 :6 0 ef
9db 0 ed 4
:3 0 eb 21f 221
:6 0 224 222 0
24c0 0 6a :6 0
230 231 0 f1
a :3 0 226 :7 0
229 227 0 24c0
0 6c :6 0 a
:3 0 22b :7 0 22e
22c 0 24c0 0
6d :6 0 237 238
0 f3 10 :3 0
11 :2 0 4 232
:7 0 235 233 0
24c0 0 6e :6 0
23e 23f 0 f5
10 :3 0 11 :2 0
4 239 :7 0 23c
23a 0 24c0 0
6f :6 0 244 245
0 f7 10 :3 0
11 :2 0 4 240
:7 0 243 241 0
24c0 0 70 :6 0
71 :3 0 72 :3 0
71 :3 0 73 :3 0
247 248 0 2
:4 0 f9 249 24b
246 24d 24c :2 0
74 :3 0 75 :3 0
24f 250 0 76
:4 0 71 :3 0 77
:3 0 253 254 0
2 :4 0 fb 255
257 78 :4 0 79
:2 0 7a :3 0 fd
25a 25c :3 0 7b
:4 0 79 :2 0 7c
:4 0 100 25f 261
:3 0 79 :2 0 3
:3 0 103 263 265
:3 0 79 :2 0 7c
:4 0 106 267 269
:3 0 79 :2 0 7d
:4 0 109 26b 26d
:3 0 79 :2 0 7c
:4 0 10c 26f 271
:3 0 79 :2 0 5
:3 0 10f 273 275
:3 0 79 :2 0 7c
:4 0 112 277 279
:3 0 79 :2 0 7d
:4 0 115 27b 27d
:3 0 79 :2 0 7e
:3 0 7f :3 0 7c
:4 0 79 :2 0 6
:3 0 118 283 285
:3 0 79 :2 0 7c
:4 0 11b 287 289
:3 0 80 :4 0 11e
281 28c 81 :4 0
121 280 28f 124
27f 291 :3 0 79
:2 0 7d :4 0 127
293 295 :3 0 79
:2 0 7e :3 0 7f
:3 0 7c :4 0 79
:2 0 8 :3 0 12a
29b 29d :3 0 79
:2 0 7c :4 0 12d
29f 2a1 :3 0 80
:4 0 130 299 2a4
81 :4 0 133 298
2a7 136 297 2a9
:3 0 79 :2 0 7d
:4 0 139 2ab 2ad
:3 0 79 :2 0 7e
:3 0 82 :3 0 9
:3 0 13c 2b1 2b3
81 :4 0 13e 2b0
2b6 141 2af 2b8
:3 0 79 :2 0 7d
:4 0 144 2ba 2bc
:3 0 79 :2 0 7e
:3 0 82 :3 0 b
:3 0 147 2c0 2c2
81 :4 0 149 2bf
2c5 14c 2be 2c7
:3 0 79 :2 0 7d
:4 0 14f 2c9 2cb
:3 0 79 :2 0 7e
:3 0 82 :3 0 c
:3 0 152 2cf 2d1
81 :4 0 154 2ce
2d4 157 2cd 2d6
:3 0 79 :2 0 7d
:4 0 15a 2d8 2da
:3 0 79 :2 0 7e
:3 0 82 :3 0 d
:3 0 15d 2de 2e0
81 :4 0 15f 2dd
2e3 162 2dc 2e5
:3 0 79 :2 0 7d
:4 0 165 2e7 2e9
:3 0 79 :2 0 7c
:4 0 168 2eb 2ed
:3 0 79 :2 0 e
:3 0 16b 2ef 2f1
:3 0 79 :2 0 7c
:4 0 16e 2f3 2f5
:3 0 79 :2 0 83
:4 0 171 2f7 2f9
:3 0 174 251 2fb
:2 0 2fd 179 2fe
24e 2fd 0 2ff
17b 0 2420 71
:3 0 72 :3 0 300
301 0 71 :3 0
84 :3 0 303 304
0 2c :2 0 2
:4 0 85 :2 0 86
:2 0 2c :2 0 17d
309 30b :3 0 180
305 30d 302 30f
30e :2 0 74 :3 0
87 :3 0 311 312
0 76 :4 0 88
:4 0 79 :2 0 7a
:3 0 184 316 318
:3 0 187 313 31a
:2 0 31c 18a 31d
310 31c 0 31e
18c 0 2420 4b
:3 0 2f :2 0 31f
320 0 2420 1e
:3 0 89 :4 0 322
323 0 2420 40
:3 0 e :3 0 325
326 0 2420 1b
:3 0 5 :3 0 328
329 0 2420 1c
:3 0 3 :3 0 32b
32c 0 2420 8a
:3 0 8b :3 0 8a
:3 0 8c :3 0 8a
:3 0 8d :3 0 8a
:3 0 8e :3 0 8a
:3 0 8f :3 0 8a
:3 0 90 :3 0 8a
:3 0 91 :3 0 8a
:3 0 92 :3 0 8a
:3 0 93 :3 0 1a
:3 0 37 :3 0 14
:3 0 35 :3 0 38
:3 0 3d :3 0 15
:3 0 1f :3 0 3c
:3 0 94 :3 0 8a
:3 0 8a :3 0 8b
:3 0 1c :4 0 95
1 :8 0 354 10
:3 0 96 :3 0 34f
350 0 97 :3 0
351 352 0 354
18e 39e 98 :3 0
10 :3 0 96 :3 0
357 358 0 97
:3 0 359 35a 0
394 71 :3 0 72
:3 0 35c 35d 0
71 :3 0 84 :3 0
35f 360 0 99
:2 0 2 :4 0 9a
:2 0 86 :2 0 2c
:2 0 191 365 367
:3 0 194 361 369
35e 36b 36a :2 0
74 :3 0 87 :3 0
36d 36e 0 76
:4 0 9b :4 0 79
:2 0 7a :3 0 198
372 374 :3 0 79
:2 0 9c :4 0 19b
376 378 :3 0 79
:2 0 9d :4 0 19e
37a 37c :3 0 79
:2 0 97 :3 0 1a1
37e 380 :3 0 79
:2 0 9e :4 0 1a4
382 384 :3 0 79
:2 0 9f :3 0 a0
:3 0 2c :2 0 a1
:2 0 1a7 387 38b
1ab 386 38d :3 0
1ae 36f 38f :2 0
391 1b1 392 36c
391 0 393 1b3
0 394 1b5 397
:3 0 397 0 397
396 394 395 :6 0
399 2 :3 0 1b8
39b 1ba 39a 399
:2 0 39c 1bc :2 0
39e 0 39e 39d
354 39c :6 0 2420
1 :3 0 10 :3 0
96 :3 0 3a0 3a1
0 10 :3 0 a2
:2 0 a3 :3 0 3a3
3a5 0 1c0 3a4
3a7 :3 0 3a8 :2 0
8b :3 0 a4 :3 0
92 :3 0 91 :3 0
8f :3 0 a5 :3 0
a6 :3 0 a7 :3 0
a8 :3 0 a9 :3 0
aa :3 0 ab :3 0
ac :3 0 ad :3 0
ac :3 0 ad :3 0
ae :3 0 af :3 0
b0 :3 0 b1 :3 0
a5 :3 0 b2 :3 0
b3 :3 0 b4 :3 0
b5 :3 0 b6 :3 0
9f :3 0 b0 :3 0
b6 :3 0 9f :3 0
b1 :3 0 b7 :3 0
b8 :3 0 b9 :3 0
ba :3 0 bb :3 0
bc :3 0 bd :3 0
be :3 0 bf :3 0
c0 :3 0 c1 :3 0
c2 :3 0 c3 :3 0
1a :3 0 1d :3 0
1f :3 0 3f :3 0
2d :3 0 2b :3 0
33 :3 0 42 :3 0
48 :3 0 52 :3 0
53 :3 0 50 :3 0
44 :3 0 21 :3 0
46 :3 0 22 :3 0
23 :3 0 41 :3 0
43 :3 0 49 :3 0
27 :3 0 29 :3 0
2e :3 0 30 :3 0
61 :3 0 64 :3 0
63 :3 0 65 :3 0
66 :3 0 68 :3 0
67 :3 0 69 :3 0
45 :3 0 3e :3 0
56 :3 0 c4 :3 0
c5 :3 0 1c :4 0
c6 1 :8 0 402
10 :3 0 96 :3 0
3fd 3fe 0 97
:3 0 3ff 400 0
402 1c3 44c 98
:3 0 10 :3 0 96
:3 0 405 406 0
97 :3 0 407 408
0 442 71 :3 0
72 :3 0 40a 40b
0 71 :3 0 84
:3 0 40d 40e 0
99 :2 0 2 :4 0
c7 :2 0 86 :2 0
2c :2 0 1c6 413
415 :3 0 1c9 40f
417 40c 419 418
:2 0 74 :3 0 87
:3 0 41b 41c 0
76 :4 0 c8 :4 0
79 :2 0 7a :3 0
1cd 420 422 :3 0
79 :2 0 9c :4 0
1d0 424 426 :3 0
79 :2 0 9d :4 0
1d3 428 42a :3 0
79 :2 0 97 :3 0
1d6 42c 42e :3 0
79 :2 0 9e :4 0
1d9 430 432 :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 1dc 435
439 1e0 434 43b
:3 0 1e3 41d 43d
:2 0 43f 1e6 440
41a 43f 0 441
1e8 0 442 1ea
445 :3 0 445 0
445 444 442 443
:6 0 447 4 :3 0
1ed 449 1ef 448
447 :2 0 44a 1f1
:2 0 44c 0 44c
44b 402 44a :6 0
23b6 1 :3 0 10
:3 0 96 :3 0 44e
44f 0 10 :3 0
a2 :2 0 a3 :3 0
451 453 0 1f5
452 455 :3 0 456
:2 0 92 :3 0 c9
:3 0 ca :3 0 cb
:3 0 cc :3 0 cd
:3 0 ce :3 0 cf
:3 0 af :3 0 d0
:3 0 d1 :3 0 d2
:3 0 d3 :3 0 7e
:3 0 d4 :3 0 d5
:3 0 1f :3 0 4b
:3 0 4c :3 0 22
:3 0 23 :3 0 4f
:3 0 4e :3 0 4d
:3 0 46 :3 0 41
:3 0 45 :3 0 55
:3 0 26 :3 0 d6
:3 0 8d :3 0 1c
:4 0 d7 1 :8 0
47e 10 :3 0 96
:3 0 479 47a 0
97 :3 0 47b 47c
0 47e 1f8 4c8
98 :3 0 10 :3 0
96 :3 0 481 482
0 97 :3 0 483
484 0 4be 71
:3 0 72 :3 0 486
487 0 71 :3 0
84 :3 0 489 48a
0 99 :2 0 2
:4 0 d8 :2 0 86
:2 0 2c :2 0 1fb
48f 491 :3 0 1fe
48b 493 488 495
494 :2 0 74 :3 0
87 :3 0 497 498
0 76 :4 0 d9
:4 0 79 :2 0 7a
:3 0 202 49c 49e
:3 0 79 :2 0 9c
:4 0 205 4a0 4a2
:3 0 79 :2 0 9d
:4 0 208 4a4 4a6
:3 0 79 :2 0 97
:3 0 20b 4a8 4aa
:3 0 79 :2 0 9e
:4 0 20e 4ac 4ae
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 211
4b1 4b5 215 4b0
4b7 :3 0 218 499
4b9 :2 0 4bb 21b
4bc 496 4bb 0
4bd 21d 0 4be
21f 4c1 :3 0 4c1
0 4c1 4c0 4be
4bf :6 0 4c3 6
:3 0 222 4c5 224
4c4 4c3 :2 0 4c6
226 :2 0 4c8 0
4c8 4c7 47e 4c6
:6 0 f4f 1 :3 0
10 :3 0 96 :3 0
4ca 4cb 0 10
:3 0 a2 :2 0 a3
:3 0 4cd 4cf 0
22a 4ce 4d1 :3 0
4d2 :2 0 71 :3 0
72 :3 0 4d4 4d5
0 71 :3 0 84
:3 0 4d7 4d8 0
13 :2 0 2 :4 0
da :2 0 86 :2 0
2c :2 0 22d 4dd
4df :3 0 230 4d9
4e1 4d6 4e3 4e2
:2 0 74 :3 0 87
:3 0 4e5 4e6 0
76 :4 0 db :4 0
79 :2 0 7a :3 0
234 4ea 4ec :3 0
79 :2 0 9c :4 0
237 4ee 4f0 :3 0
79 :2 0 dc :4 0
23a 4f2 4f4 :3 0
79 :2 0 7e :3 0
82 :3 0 dd :3 0
de :3 0 4f9 4fa
0 23d 4f8 4fc
81 :4 0 23f 4f7
4ff 242 4f6 501
:3 0 79 :2 0 df
:4 0 245 503 505
:3 0 79 :2 0 7c
:4 0 248 507 509
:3 0 79 :2 0 1c
:3 0 24b 50b 50d
:3 0 79 :2 0 7c
:4 0 24e 50f 511
:3 0 251 4e7 513
:2 0 515 254 516
4e4 515 0 517
256 0 541 71
:3 0 72 :3 0 518
519 0 71 :3 0
84 :3 0 51b 51c
0 2c :2 0 2
:4 0 e0 :2 0 86
:2 0 2c :2 0 258
521 523 :3 0 25b
51d 525 51a 527
526 :2 0 74 :3 0
87 :3 0 529 52a
0 76 :4 0 e1
:4 0 79 :2 0 7a
:3 0 25f 52e 530
:3 0 262 52b 532
:2 0 534 265 535
528 534 0 536
267 0 541 e2
:3 0 e3 :3 0 537
538 0 dd :3 0
de :3 0 53a 53b
0 1c :3 0 e4
:3 0 269 539 53f
:2 0 541 26d 542
4d3 541 0 543
271 0 f4f 24
:3 0 6 :3 0 544
545 0 f4f 25
:3 0 8 :3 0 547
548 0 f4f e5
:3 0 e6 :3 0 54a
54b 0 24 :3 0
25 :3 0 e7 :2 0
273 54c 550 e8
:2 0 2f :2 0 279
552 554 :3 0 555
:2 0 e5 :3 0 e6
:3 0 557 558 0
25 :3 0 23 :3 0
e7 :2 0 27c 559
55d e9 :2 0 2f
:2 0 282 55f 561
:3 0 562 :2 0 556
564 563 :2 0 71
:3 0 72 :3 0 566
567 0 71 :3 0
84 :3 0 569 56a
0 13 :2 0 2
:4 0 ea :2 0 86
:2 0 2c :2 0 285
56f 571 :3 0 288
56b 573 568 575
574 :2 0 74 :3 0
87 :3 0 577 578
0 76 :4 0 eb
:4 0 79 :2 0 7a
:3 0 28c 57c 57e
:3 0 79 :2 0 9c
:4 0 28f 580 582
:3 0 79 :2 0 dc
:4 0 292 584 586
:3 0 79 :2 0 7e
:3 0 82 :3 0 dd
:3 0 ec :3 0 58b
58c 0 295 58a
58e 81 :4 0 297
589 591 29a 588
593 :3 0 79 :2 0
df :4 0 29d 595
597 :3 0 79 :2 0
7c :4 0 2a0 599
59b :3 0 79 :2 0
1c :3 0 2a3 59d
59f :3 0 79 :2 0
7c :4 0 2a6 5a1
5a3 :3 0 2a9 579
5a5 :2 0 5a7 2ac
5a8 576 5a7 0
5a9 2ae 0 5d3
71 :3 0 72 :3 0
5aa 5ab 0 71
:3 0 84 :3 0 5ad
5ae 0 2c :2 0
2 :4 0 ed :2 0
86 :2 0 2c :2 0
2b0 5b3 5b5 :3 0
2b3 5af 5b7 5ac
5b9 5b8 :2 0 74
:3 0 87 :3 0 5bb
5bc 0 76 :4 0
ee :4 0 79 :2 0
7a :3 0 2b7 5c0
5c2 :3 0 2ba 5bd
5c4 :2 0 5c6 2bd
5c7 5ba 5c6 0
5c8 2bf 0 5d3
e2 :3 0 e3 :3 0
5c9 5ca 0 dd
:3 0 ec :3 0 5cc
5cd 0 1c :3 0
e4 :3 0 2c1 5cb
5d1 :2 0 5d3 2c5
5d4 565 5d3 0
5d5 2c9 0 f4f
26 :3 0 ef :2 0
2cb 5d7 5d8 :3 0
5d9 :2 0 5da :2 0
7e :3 0 41 :3 0
2f :2 0 2cd 5dc
5df f0 :2 0 7e
:3 0 46 :3 0 2f
:2 0 2d0 5e2 5e5
2d3 5e1 5e7 :3 0
5e8 :2 0 7e :3 0
e9 :2 0 55 :3 0
2f :2 0 2d6 5ea
5ee 2db 5eb 5f0
:3 0 5f1 :2 0 5db
5f3 5f2 :2 0 71
:3 0 72 :3 0 5f5
5f6 0 71 :3 0
84 :3 0 5f8 5f9
0 13 :2 0 2
:4 0 f1 :2 0 86
:2 0 2c :2 0 2de
5fe 600 :3 0 2e1
5fa 602 5f7 604
603 :2 0 74 :3 0
87 :3 0 606 607
0 76 :4 0 f2
:4 0 79 :2 0 7a
:3 0 2e5 60b 60d
:3 0 79 :2 0 9c
:4 0 2e8 60f 611
:3 0 79 :2 0 dc
:4 0 2eb 613 615
:3 0 79 :2 0 7e
:3 0 82 :3 0 dd
:3 0 f3 :3 0 61a
61b 0 2ee 619
61d 81 :4 0 2f0
618 620 2f3 617
622 :3 0 79 :2 0
df :4 0 2f6 624
626 :3 0 79 :2 0
7c :4 0 2f9 628
62a :3 0 79 :2 0
1c :3 0 2fc 62c
62e :3 0 79 :2 0
7c :4 0 2ff 630
632 :3 0 302 608
634 :2 0 636 305
637 605 636 0
638 307 0 662
71 :3 0 72 :3 0
639 63a 0 71
:3 0 84 :3 0 63c
63d 0 2c :2 0
2 :4 0 f4 :2 0
86 :2 0 2c :2 0
309 642 644 :3 0
30c 63e 646 63b
648 647 :2 0 74
:3 0 87 :3 0 64a
64b 0 76 :4 0
f5 :4 0 79 :2 0
7a :3 0 310 64f
651 :3 0 313 64c
653 :2 0 655 316
656 649 655 0
657 318 0 662
e2 :3 0 e3 :3 0
658 659 0 dd
:3 0 f3 :3 0 65b
65c 0 1c :3 0
e4 :3 0 31a 65a
660 :2 0 662 31e
663 5f4 662 0
664 322 0 f4f
e5 :3 0 e6 :3 0
665 666 0 24
:3 0 22 :3 0 e7
:2 0 324 667 66b
e9 :2 0 2f :2 0
32a 66d 66f :3 0
670 :2 0 e5 :3 0
e6 :3 0 672 673
0 25 :3 0 23
:3 0 e7 :2 0 32d
674 678 e9 :2 0
2f :2 0 333 67a
67c :3 0 67d :2 0
671 67f 67e :2 0
7e :3 0 4e :3 0
2f :2 0 336 681
684 a2 :2 0 2f
:2 0 33b 686 688
:3 0 e5 :3 0 e6
:3 0 68a 68b 0
24 :3 0 22 :3 0
e7 :2 0 33e 68c
690 e9 :2 0 2f
:2 0 344 692 694
:3 0 e5 :3 0 f6
:3 0 f7 :3 0 e5
:3 0 f8 :3 0 f9
:3 0 fa :3 0 fb
:3 0 24 :3 0 fc
:3 0 8d :3 0 1f
:3 0 f7 :3 0 b6
:3 0 9f :3 0 24
:4 0 fd 1 :8 0
6ac 10 :3 0 96
:3 0 6a7 6a8 0
97 :3 0 6a9 6aa
0 6ac 347 6f6
98 :3 0 10 :3 0
96 :3 0 6af 6b0
0 97 :3 0 6b1
6b2 0 6ec 71
:3 0 72 :3 0 6b4
6b5 0 71 :3 0
84 :3 0 6b7 6b8
0 99 :2 0 2
:4 0 fe :2 0 86
:2 0 2c :2 0 34a
6bd 6bf :3 0 34d
6b9 6c1 6b6 6c3
6c2 :2 0 74 :3 0
87 :3 0 6c5 6c6
0 76 :4 0 ff
:4 0 79 :2 0 7a
:3 0 351 6ca 6cc
:3 0 79 :2 0 9c
:4 0 354 6ce 6d0
:3 0 79 :2 0 9d
:4 0 357 6d2 6d4
:3 0 79 :2 0 97
:3 0 35a 6d6 6d8
:3 0 79 :2 0 9e
:4 0 35d 6da 6dc
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 360
6df 6e3 364 6de
6e5 :3 0 367 6c7
6e7 :2 0 6e9 36a
6ea 6c4 6e9 0
6eb 36c 0 6ec
36e 6ef :3 0 6ef
0 6ef 6ee 6ec
6ed :6 0 6f1 8
:3 0 371 6f3 373
6f2 6f1 :2 0 6f4
375 :2 0 6f6 0
6f6 6f5 6ac 6f4
:6 0 772 1 :3 0
10 :3 0 96 :3 0
6f8 6f9 0 10
:3 0 a2 :2 0 a3
:3 0 6fb 6fd 0
379 6fc 6ff :3 0
700 :2 0 e5 :3 0
f6 :3 0 b6 :3 0
9f :3 0 24 :3 0
e5 :3 0 f8 :3 0
24 :3 0 100 :4 0
101 1 :8 0 711
10 :3 0 96 :3 0
70c 70d 0 97
:3 0 70e 70f 0
711 37c 75b 98
:3 0 10 :3 0 96
:3 0 714 715 0
97 :3 0 716 717
0 751 71 :3 0
72 :3 0 719 71a
0 71 :3 0 84
:3 0 71c 71d 0
99 :2 0 2 :4 0
102 :2 0 86 :2 0
2c :2 0 37f 722
724 :3 0 382 71e
726 71b 728 727
:2 0 74 :3 0 87
:3 0 72a 72b 0
76 :4 0 103 :4 0
79 :2 0 7a :3 0
386 72f 731 :3 0
79 :2 0 9c :4 0
389 733 735 :3 0
79 :2 0 9d :4 0
38c 737 739 :3 0
79 :2 0 97 :3 0
38f 73b 73d :3 0
79 :2 0 9e :4 0
392 73f 741 :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 395 744
748 399 743 74a
:3 0 39c 72c 74c
:2 0 74e 39f 74f
729 74e 0 750
3a1 0 751 3a3
754 :3 0 754 0
754 753 751 752
:6 0 756 a :3 0
3a6 758 3a8 757
756 :2 0 759 3aa
:2 0 75b 0 75b
75a 711 759 :6 0
75d 1 :3 0 3ac
75e 701 75d 0
75f 3ae 0 772
e5 :3 0 e6 :3 0
760 761 0 24
:3 0 25 :3 0 e7
:2 0 3b0 762 766
e8 :2 0 2f :2 0
3b6 768 76a :3 0
25 :4 0 76c 76d
0 76f 3b9 770
76b 76f 0 771
3bb 0 772 3bd
841 e5 :3 0 f6
:3 0 f7 :3 0 e5
:3 0 f8 :3 0 f9
:3 0 104 :3 0 fb
:3 0 25 :3 0 fc
:3 0 8d :3 0 1f
:3 0 f7 :3 0 b6
:3 0 9f :3 0 25
:4 0 105 1 :8 0
789 10 :3 0 96
:3 0 784 785 0
97 :3 0 786 787
0 789 3c1 7d3
98 :3 0 10 :3 0
96 :3 0 78c 78d
0 97 :3 0 78e
78f 0 7c9 71
:3 0 72 :3 0 791
792 0 71 :3 0
84 :3 0 794 795
0 99 :2 0 2
:4 0 106 :2 0 86
:2 0 2c :2 0 3c4
79a 79c :3 0 3c7
796 79e 793 7a0
79f :2 0 74 :3 0
87 :3 0 7a2 7a3
0 76 :4 0 107
:4 0 79 :2 0 7a
:3 0 3cb 7a7 7a9
:3 0 79 :2 0 9c
:4 0 3ce 7ab 7ad
:3 0 79 :2 0 9d
:4 0 3d1 7af 7b1
:3 0 79 :2 0 97
:3 0 3d4 7b3 7b5
:3 0 79 :2 0 9e
:4 0 3d7 7b7 7b9
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 3da
7bc 7c0 3de 7bb
7c2 :3 0 3e1 7a4
7c4 :2 0 7c6 3e4
7c7 7a1 7c6 0
7c8 3e6 0 7c9
3e8 7cc :3 0 7cc
0 7cc 7cb 7c9
7ca :6 0 7ce c
:3 0 3eb 7d0 3ed
7cf 7ce :2 0 7d1
3ef :2 0 7d3 0
7d3 7d2 789 7d1
:6 0 840 1 :3 0
10 :3 0 96 :3 0
7d5 7d6 0 10
:3 0 a2 :2 0 a3
:3 0 7d8 7da 0
3f3 7d9 7dc :3 0
7dd :2 0 e5 :3 0
f6 :3 0 b6 :3 0
9f :3 0 25 :3 0
e5 :3 0 f8 :3 0
25 :3 0 100 :4 0
108 1 :8 0 7ee
10 :3 0 96 :3 0
7e9 7ea 0 97
:3 0 7eb 7ec 0
7ee 3f6 838 98
:3 0 10 :3 0 96
:3 0 7f1 7f2 0
97 :3 0 7f3 7f4
0 82e 71 :3 0
72 :3 0 7f6 7f7
0 71 :3 0 84
:3 0 7f9 7fa 0
99 :2 0 2 :4 0
109 :2 0 86 :2 0
2c :2 0 3f9 7ff
801 :3 0 3fc 7fb
803 7f8 805 804
:2 0 74 :3 0 87
:3 0 807 808 0
76 :4 0 10a :4 0
79 :2 0 7a :3 0
400 80c 80e :3 0
79 :2 0 9c :4 0
403 810 812 :3 0
79 :2 0 9d :4 0
406 814 816 :3 0
79 :2 0 97 :3 0
409 818 81a :3 0
79 :2 0 9e :4 0
40c 81c 81e :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 40f 821
825 413 820 827
:3 0 416 809 829
:2 0 82b 419 82c
806 82b 0 82d
41b 0 82e 41d
831 :3 0 831 0
831 830 82e 82f
:6 0 833 e :3 0
420 835 422 834
833 :2 0 836 424
:2 0 838 0 838
837 7ee 836 :6 0
83a 1 :3 0 426
83b 7de 83a 0
83c 428 0 840
4f :3 0 2f :2 0
83d 83e 0 840
42a 842 695 772
0 843 0 840
0 843 42e 0
93d 7e :3 0 4d
:3 0 2f :2 0 431
844 847 dd :3 0
a2 :2 0 10b :3 0
849 84b 0 436
84a 84d :3 0 d6
:3 0 10c :3 0 24
:3 0 10d :3 0 25
:3 0 10e :3 0 4f
:3 0 8d :3 0 1c
:4 0 10f 1 :8 0
86e 110 :4 0 859
:3 0 e4 :3 0 a2
:2 0 43b 85c 85d
:3 0 10 :3 0 96
:3 0 85f 860 0
2f :2 0 861 862
0 864 43e 86b
10 :3 0 96 :3 0
865 866 0 111
:2 0 867 868 0
86a 440 86c 85e
864 0 86d 0
86a 0 86d 442
0 86e 445 8b8
98 :3 0 10 :3 0
96 :3 0 871 872
0 97 :3 0 873
874 0 8ae 71
:3 0 72 :3 0 876
877 0 71 :3 0
84 :3 0 879 87a
0 99 :2 0 2
:4 0 112 :2 0 86
:2 0 2c :2 0 448
87f 881 :3 0 44b
87b 883 878 885
884 :2 0 74 :3 0
87 :3 0 887 888
0 76 :4 0 113
:4 0 79 :2 0 7a
:3 0 44f 88c 88e
:3 0 79 :2 0 9c
:4 0 452 890 892
:3 0 79 :2 0 9d
:4 0 455 894 896
:3 0 79 :2 0 97
:3 0 458 898 89a
:3 0 79 :2 0 9e
:4 0 45b 89c 89e
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 45e
8a1 8a5 462 8a0
8a7 :3 0 465 889
8a9 :2 0 8ab 468
8ac 886 8ab 0
8ad 46a 0 8ae
46c 8b1 :3 0 8b1
0 8b1 8b0 8ae
8af :6 0 8b3 10
:3 0 46f 8b5 471
8b4 8b3 :2 0 8b6
473 :2 0 8b8 0
8b8 8b7 86e 8b6
:6 0 8ba 1 :3 0
475 927 d6 :3 0
114 :3 0 24 :3 0
115 :3 0 25 :3 0
116 :3 0 4f :3 0
8d :3 0 1c :4 0
117 1 :8 0 8da
110 :4 0 8c5 :3 0
e4 :3 0 a2 :2 0
479 8c8 8c9 :3 0
10 :3 0 96 :3 0
8cb 8cc 0 2f
:2 0 8cd 8ce 0
8d0 47c 8d7 10
:3 0 96 :3 0 8d1
8d2 0 111 :2 0
8d3 8d4 0 8d6
47e 8d8 8ca 8d0
0 8d9 0 8d6
0 8d9 480 0
8da 483 924 98
:3 0 10 :3 0 96
:3 0 8dd 8de 0
97 :3 0 8df 8e0
0 91a 71 :3 0
72 :3 0 8e2 8e3
0 71 :3 0 84
:3 0 8e5 8e6 0
99 :2 0 2 :4 0
118 :2 0 86 :2 0
2c :2 0 486 8eb
8ed :3 0 489 8e7
8ef 8e4 8f1 8f0
:2 0 74 :3 0 87
:3 0 8f3 8f4 0
76 :4 0 119 :4 0
79 :2 0 7a :3 0
48d 8f8 8fa :3 0
79 :2 0 9c :4 0
490 8fc 8fe :3 0
79 :2 0 9d :4 0
493 900 902 :3 0
79 :2 0 97 :3 0
496 904 906 :3 0
79 :2 0 9e :4 0
499 908 90a :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 49c 90d
911 4a0 90c 913
:3 0 4a3 8f5 915
:2 0 917 4a6 918
8f2 917 0 919
4a8 0 91a 4aa
91d :3 0 91d 0
91d 91c 91a 91b
:6 0 91f 12 :3 0
4ad 921 4af 920
91f :2 0 922 4b1
:2 0 924 0 924
923 8da 922 :6 0
926 1 :3 0 4b3
928 84e 8ba 0
929 0 926 0
929 4b5 0 93d
10 :3 0 96 :3 0
92a 92b 0 10
:3 0 a2 :2 0 11a
:3 0 92d 92f 0
4ba 92e 931 :3 0
932 :2 0 60 :3 0
11b :3 0 1f :3 0
4bd 935 937 934
938 0 93a 4bf
93b 933 93a 0
93c 4c1 0 93d
4c3 c4c 11c :3 0
60 :3 0 100 :3 0
c4 :3 0 92 :3 0
1f :3 0 c2 :3 0
1c :3 0 ae :4 0
11d 1 :8 0 94d
10 :3 0 96 :3 0
948 949 0 97
:3 0 94a 94b 0
94d 4c7 997 98
:3 0 10 :3 0 96
:3 0 950 951 0
97 :3 0 952 953
0 98d 71 :3 0
72 :3 0 955 956
0 71 :3 0 84
:3 0 958 959 0
99 :2 0 2 :4 0
11e :2 0 86 :2 0
2c :2 0 4ca 95e
960 :3 0 4cd 95a
962 957 964 963
:2 0 74 :3 0 87
:3 0 966 967 0
76 :4 0 11f :4 0
79 :2 0 7a :3 0
4d1 96b 96d :3 0
79 :2 0 9c :4 0
4d4 96f 971 :3 0
79 :2 0 9d :4 0
4d7 973 975 :3 0
79 :2 0 97 :3 0
4da 977 979 :3 0
79 :2 0 9e :4 0
4dd 97b 97d :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 4e0 980
984 4e4 97f 986
:3 0 4e7 968 988
:2 0 98a 4ea 98b
965 98a 0 98c
4ec 0 98d 4ee
990 :3 0 990 0
990 98f 98d 98e
:6 0 992 14 :3 0
4f1 994 4f3 993
992 :2 0 995 4f5
:2 0 997 0 997
996 94d 995 :6 0
c4b 1 :3 0 7e
:3 0 60 :3 0 2f
:2 0 4f7 999 99c
e8 :2 0 2f :2 0
4fc 99e 9a0 :3 0
71 :3 0 72 :3 0
9a2 9a3 0 71
:3 0 84 :3 0 9a5
9a6 0 13 :2 0
2 :4 0 120 :2 0
86 :2 0 2c :2 0
4ff 9ab 9ad :3 0
502 9a7 9af 9a4
9b1 9b0 :2 0 74
:3 0 87 :3 0 9b3
9b4 0 76 :4 0
121 :4 0 79 :2 0
7a :3 0 506 9b8
9ba :3 0 79 :2 0
9c :4 0 509 9bc
9be :3 0 79 :2 0
dc :4 0 50c 9c0
9c2 :3 0 79 :2 0
7e :3 0 82 :3 0
dd :3 0 122 :3 0
9c7 9c8 0 50f
9c6 9ca 81 :4 0
511 9c5 9cd 514
9c4 9cf :3 0 79
:2 0 df :4 0 517
9d1 9d3 :3 0 79
:2 0 7c :4 0 51a
9d5 9d7 :3 0 79
:2 0 1c :3 0 51d
9d9 9db :3 0 79
:2 0 7c :4 0 520
9dd 9df :3 0 523
9b5 9e1 :2 0 9e3
526 9e4 9b2 9e3
0 9e5 528 0
a0f 71 :3 0 72
:3 0 9e6 9e7 0
71 :3 0 84 :3 0
9e9 9ea 0 2c
:2 0 2 :4 0 123
:2 0 86 :2 0 2c
:2 0 52a 9ef 9f1
:3 0 52d 9eb 9f3
9e8 9f5 9f4 :2 0
74 :3 0 87 :3 0
9f7 9f8 0 76
:4 0 124 :4 0 79
:2 0 7a :3 0 531
9fc 9fe :3 0 534
9f9 a00 :2 0 a02
537 a03 9f6 a02
0 a04 539 0
a0f e2 :3 0 e3
:3 0 a05 a06 0
dd :3 0 122 :3 0
a08 a09 0 1c
:3 0 e4 :3 0 53b
a07 a0d :2 0 a0f
53f a10 9a1 a0f
0 a11 543 0
c4b e5 :3 0 e6
:3 0 a12 a13 0
24 :3 0 22 :3 0
e7 :2 0 545 a14
a18 e9 :2 0 2f
:2 0 54b a1a a1c
:3 0 e5 :3 0 f6
:3 0 f7 :3 0 e5
:3 0 f8 :3 0 f9
:3 0 fa :3 0 fb
:3 0 24 :3 0 fc
:3 0 8d :3 0 1f
:3 0 f7 :3 0 b6
:3 0 9f :3 0 24
:4 0 fd 1 :8 0
a34 10 :3 0 96
:3 0 a2f a30 0
97 :3 0 a31 a32
0 a34 54e a7e
98 :3 0 10 :3 0
96 :3 0 a37 a38
0 97 :3 0 a39
a3a 0 a74 71
:3 0 72 :3 0 a3c
a3d 0 71 :3 0
84 :3 0 a3f a40
0 99 :2 0 2
:4 0 125 :2 0 86
:2 0 2c :2 0 551
a45 a47 :3 0 554
a41 a49 a3e a4b
a4a :2 0 74 :3 0
87 :3 0 a4d a4e
0 76 :4 0 126
:4 0 79 :2 0 7a
:3 0 558 a52 a54
:3 0 79 :2 0 9c
:4 0 55b a56 a58
:3 0 79 :2 0 9d
:4 0 55e a5a a5c
:3 0 79 :2 0 97
:3 0 561 a5e a60
:3 0 79 :2 0 9e
:4 0 564 a62 a64
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 567
a67 a6b 56b a66
a6d :3 0 56e a4f
a6f :2 0 a71 571
a72 a4c a71 0
a73 573 0 a74
575 a77 :3 0 a77
0 a77 a76 a74
a75 :6 0 a79 16
:3 0 578 a7b 57a
a7a a79 :2 0 a7c
57c :2 0 a7e 0
a7e a7d a34 a7c
:6 0 ae8 1 :3 0
10 :3 0 96 :3 0
a80 a81 0 10
:3 0 a2 :2 0 a3
:3 0 a83 a85 0
580 a84 a87 :3 0
a88 :2 0 e5 :3 0
f6 :3 0 b6 :3 0
9f :3 0 24 :3 0
e5 :3 0 f8 :3 0
24 :3 0 100 :4 0
101 1 :8 0 a99
10 :3 0 96 :3 0
a94 a95 0 97
:3 0 a96 a97 0
a99 583 ae3 98
:3 0 10 :3 0 96
:3 0 a9c a9d 0
97 :3 0 a9e a9f
0 ad9 71 :3 0
72 :3 0 aa1 aa2
0 71 :3 0 84
:3 0 aa4 aa5 0
99 :2 0 2 :4 0
127 :2 0 86 :2 0
2c :2 0 586 aaa
aac :3 0 589 aa6
aae aa3 ab0 aaf
:2 0 74 :3 0 87
:3 0 ab2 ab3 0
76 :4 0 128 :4 0
79 :2 0 7a :3 0
58d ab7 ab9 :3 0
79 :2 0 9c :4 0
590 abb abd :3 0
79 :2 0 9d :4 0
593 abf ac1 :3 0
79 :2 0 97 :3 0
596 ac3 ac5 :3 0
79 :2 0 9e :4 0
599 ac7 ac9 :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 59c acc
ad0 5a0 acb ad2
:3 0 5a3 ab4 ad4
:2 0 ad6 5a6 ad7
ab1 ad6 0 ad8
5a8 0 ad9 5aa
adc :3 0 adc 0
adc adb ad9 ada
:6 0 ade 18 :3 0
5ad ae0 5af adf
ade :2 0 ae1 5b1
:2 0 ae3 0 ae3
ae2 a99 ae1 :6 0
ae5 1 :3 0 5b3
ae6 a89 ae5 0
ae7 5b5 0 ae8
5b7 bb4 e5 :3 0
f6 :3 0 f7 :3 0
e5 :3 0 f8 :3 0
f9 :3 0 104 :3 0
fb :3 0 25 :3 0
fc :3 0 8d :3 0
1f :3 0 f7 :3 0
b6 :3 0 9f :3 0
25 :4 0 105 1
:8 0 aff 10 :3 0
96 :3 0 afa afb
0 97 :3 0 afc
afd 0 aff 5ba
b49 98 :3 0 10
:3 0 96 :3 0 b02
b03 0 97 :3 0
b04 b05 0 b3f
71 :3 0 72 :3 0
b07 b08 0 71
:3 0 84 :3 0 b0a
b0b 0 99 :2 0
2 :4 0 129 :2 0
86 :2 0 2c :2 0
5bd b10 b12 :3 0
5c0 b0c b14 b09
b16 b15 :2 0 74
:3 0 87 :3 0 b18
b19 0 76 :4 0
12a :4 0 79 :2 0
7a :3 0 5c4 b1d
b1f :3 0 79 :2 0
9c :4 0 5c7 b21
b23 :3 0 79 :2 0
9d :4 0 5ca b25
b27 :3 0 79 :2 0
97 :3 0 5cd b29
b2b :3 0 79 :2 0
9e :4 0 5d0 b2d
b2f :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
5d3 b32 b36 5d7
b31 b38 :3 0 5da
b1a b3a :2 0 b3c
5dd b3d b17 b3c
0 b3e 5df 0
b3f 5e1 b42 :3 0
b42 0 b42 b41
b3f b40 :6 0 b44
1a :3 0 5e4 b46
5e6 b45 b44 :2 0
b47 5e8 :2 0 b49
0 b49 b48 aff
b47 :6 0 bb3 1
:3 0 10 :3 0 96
:3 0 b4b b4c 0
10 :3 0 a2 :2 0
a3 :3 0 b4e b50
0 5ec b4f b52
:3 0 b53 :2 0 e5
:3 0 f6 :3 0 b6
:3 0 9f :3 0 25
:3 0 e5 :3 0 f8
:3 0 25 :3 0 100
:4 0 108 1 :8 0
b64 10 :3 0 96
:3 0 b5f b60 0
97 :3 0 b61 b62
0 b64 5ef bae
98 :3 0 10 :3 0
96 :3 0 b67 b68
0 97 :3 0 b69
b6a 0 ba4 71
:3 0 72 :3 0 b6c
b6d 0 71 :3 0
84 :3 0 b6f b70
0 99 :2 0 2
:4 0 12b :2 0 86
:2 0 2c :2 0 5f2
b75 b77 :3 0 5f5
b71 b79 b6e b7b
b7a :2 0 74 :3 0
87 :3 0 b7d b7e
0 76 :4 0 12c
:4 0 79 :2 0 7a
:3 0 5f9 b82 b84
:3 0 79 :2 0 9c
:4 0 5fc b86 b88
:3 0 79 :2 0 9d
:4 0 5ff b8a b8c
:3 0 79 :2 0 97
:3 0 602 b8e b90
:3 0 79 :2 0 9e
:4 0 605 b92 b94
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 608
b97 b9b 60c b96
b9d :3 0 60f b7f
b9f :2 0 ba1 612
ba2 b7c ba1 0
ba3 614 0 ba4
616 ba7 :3 0 ba7
0 ba7 ba6 ba4
ba5 :6 0 ba9 1c
:3 0 619 bab 61b
baa ba9 :2 0 bac
61d :2 0 bae 0
bae bad b64 bac
:6 0 bb0 1 :3 0
61f bb1 b54 bb0
0 bb2 621 0
bb3 623 bb5 a1d
ae8 0 bb6 0
bb3 0 bb6 626
0 c4b 60 :3 0
12d :3 0 1f :3 0
1c :3 0 22 :3 0
23 :3 0 24 :3 0
25 :3 0 4c :3 0
40 :3 0 7e :3 0
4b :3 0 2f :2 0
629 bc1 bc4 2f
:2 0 62c bb8 bc7
bb7 bc8 0 c4b
7e :3 0 60 :3 0
2f :2 0 637 bca
bcd a2 :2 0 2f
:2 0 63c bcf bd1
:3 0 60 :3 0 11b
:3 0 1f :3 0 63f
bd4 bd6 bd3 bd7
0 bd9 641 c48
71 :3 0 72 :3 0
bda bdb 0 71
:3 0 84 :3 0 bdd
bde 0 13 :2 0
2 :4 0 12e :2 0
86 :2 0 2c :2 0
643 be3 be5 :3 0
646 bdf be7 bdc
be9 be8 :2 0 74
:3 0 87 :3 0 beb
bec 0 76 :4 0
12f :4 0 79 :2 0
7a :3 0 64a bf0
bf2 :3 0 79 :2 0
9c :4 0 64d bf4
bf6 :3 0 79 :2 0
dc :4 0 650 bf8
bfa :3 0 79 :2 0
7e :3 0 82 :3 0
60 :3 0 653 bfe
c00 81 :4 0 655
bfd c03 658 bfc
c05 :3 0 79 :2 0
df :4 0 65b c07
c09 :3 0 79 :2 0
7c :4 0 65e c0b
c0d :3 0 79 :2 0
1c :3 0 661 c0f
c11 :3 0 79 :2 0
7c :4 0 664 c13
c15 :3 0 667 bed
c17 :2 0 c19 66a
c1a bea c19 0
c1b 66c 0 c47
71 :3 0 72 :3 0
c1c c1d 0 71
:3 0 84 :3 0 c1f
c20 0 2c :2 0
2 :4 0 130 :2 0
86 :2 0 2c :2 0
66e c25 c27 :3 0
671 c21 c29 c1e
c2b c2a :2 0 74
:3 0 87 :3 0 c2d
c2e 0 76 :4 0
131 :4 0 79 :2 0
7a :3 0 675 c32
c34 :3 0 678 c2f
c36 :2 0 c38 67b
c39 c2c c38 0
c3a 67d 0 c47
e2 :3 0 e3 :3 0
c3b c3c 0 7e
:3 0 60 :3 0 2f
:2 0 67f c3e c41
1c :3 0 e4 :3 0
682 c3d c45 :2 0
c47 686 c49 bd2
bd9 0 c4a 0
c47 0 c4a 68a
0 c4b 68d c4d
689 93d 0 c4e
0 c4b 0 c4e
693 0 c50 132
:3 0 696 ecd 7e
:3 0 d :3 0 2f
:2 0 698 c51 c54
7e :3 0 e9 :2 0
46 :3 0 2f :2 0
69b c56 c5a 6a0
c57 c5c :3 0 c5d
:2 0 7e :3 0 41
:3 0 2f :2 0 6a3
c5f c62 e8 :2 0
2f :2 0 6a8 c64
c66 :3 0 c67 :2 0
c5e c69 c68 :2 0
57 :3 0 2f :2 0
c6b c6c 0 ecb
7e :3 0 d :3 0
2f :2 0 6ab c6e
c71 7e :3 0 e8
:2 0 41 :3 0 2f
:2 0 6ae c73 c77
6b3 c74 c79 :3 0
71 :3 0 72 :3 0
c7b c7c 0 71
:3 0 84 :3 0 c7e
c7f 0 133 :2 0
2 :4 0 134 :2 0
86 :2 0 2c :2 0
6b6 c84 c86 :3 0
6b9 c80 c88 c7d
c8a c89 :2 0 74
:3 0 87 :3 0 c8c
c8d 0 76 :4 0
135 :4 0 79 :2 0
7a :3 0 6bd c91
c93 :3 0 79 :2 0
9c :4 0 6c0 c95
c97 :3 0 79 :2 0
dc :4 0 6c3 c99
c9b :3 0 79 :2 0
7e :3 0 82 :3 0
dd :3 0 136 :3 0
ca0 ca1 0 6c6
c9f ca3 81 :4 0
6c8 c9e ca6 6cb
c9d ca8 :3 0 6ce
c8e caa :2 0 cac
6d1 cad c8b cac
0 cae 6d3 0
cd8 71 :3 0 72
:3 0 caf cb0 0
71 :3 0 84 :3 0
cb2 cb3 0 2c
:2 0 2 :4 0 137
:2 0 86 :2 0 2c
:2 0 6d5 cb8 cba
:3 0 6d8 cb4 cbc
cb1 cbe cbd :2 0
74 :3 0 87 :3 0
cc0 cc1 0 76
:4 0 138 :4 0 79
:2 0 7a :3 0 6dc
cc5 cc7 :3 0 6df
cc2 cc9 :2 0 ccb
6e2 ccc cbf ccb
0 ccd 6e4 0
cd8 e2 :3 0 139
:3 0 cce ccf 0
dd :3 0 136 :3 0
cd1 cd2 0 e4
:3 0 6e6 cd0 cd5
:2 0 cd8 132 :3 0
6e9 ceb 7e :3 0
d :3 0 2f :2 0
6ed cd9 cdc 7e
:3 0 a2 :2 0 41
:3 0 2f :2 0 6f0
cde ce2 6f5 cdf
ce4 :3 0 57 :3 0
2c :2 0 ce6 ce7
0 ce9 6f8 cea
ce5 ce9 0 cec
c7a cd8 0 cec
6fa 0 ecb 60
:3 0 2f :2 0 ced
cee 0 ecb 11c
:3 0 60 :3 0 100
:3 0 13a :3 0 8d
:3 0 c4 :3 0 13b
:3 0 13c :3 0 13a
:3 0 13b :3 0 c2
:3 0 1c :3 0 13b
:3 0 c5 :3 0 13a
:3 0 c5 :3 0 13a
:3 0 c5 :3 0 13a
:3 0 8d :3 0 13a
:3 0 13d :3 0 dd
:3 0 13e :4 0 13f
1 :8 0 d0e 10
:3 0 96 :3 0 d09
d0a 0 97 :3 0
d0b d0c 0 d0e
6fd d58 98 :3 0
10 :3 0 96 :3 0
d11 d12 0 97
:3 0 d13 d14 0
d4e 71 :3 0 72
:3 0 d16 d17 0
71 :3 0 84 :3 0
d19 d1a 0 99
:2 0 2 :4 0 140
:2 0 86 :2 0 2c
:2 0 700 d1f d21
:3 0 703 d1b d23
d18 d25 d24 :2 0
74 :3 0 87 :3 0
d27 d28 0 76
:4 0 141 :4 0 79
:2 0 7a :3 0 707
d2c d2e :3 0 79
:2 0 9c :4 0 70a
d30 d32 :3 0 79
:2 0 9d :4 0 70d
d34 d36 :3 0 79
:2 0 97 :3 0 710
d38 d3a :3 0 79
:2 0 9e :4 0 713
d3c d3e :3 0 79
:2 0 9f :3 0 a0
:3 0 2c :2 0 a1
:2 0 716 d41 d45
71a d40 d47 :3 0
71d d29 d49 :2 0
d4b 720 d4c d26
d4b 0 d4d 722
0 d4e 724 d51
:3 0 d51 0 d51
d50 d4e d4f :6 0
d53 1e :3 0 727
d55 729 d54 d53
:2 0 d56 72b :2 0
d58 0 d58 d57
d0e d56 :6 0 ecb
1 :3 0 7e :3 0
60 :3 0 2f :2 0
72d d5a d5d e8
:2 0 2f :2 0 732
d5f d61 :3 0 71
:3 0 72 :3 0 d63
d64 0 71 :3 0
84 :3 0 d66 d67
0 13 :2 0 2
:4 0 142 :2 0 86
:2 0 2c :2 0 735
d6c d6e :3 0 738
d68 d70 d65 d72
d71 :2 0 74 :3 0
87 :3 0 d74 d75
0 76 :4 0 143
:4 0 79 :2 0 7a
:3 0 73c d79 d7b
:3 0 79 :2 0 9c
:4 0 73f d7d d7f
:3 0 79 :2 0 dc
:4 0 742 d81 d83
:3 0 79 :2 0 7e
:3 0 82 :3 0 dd
:3 0 144 :3 0 d88
d89 0 745 d87
d8b 81 :4 0 747
d86 d8e 74a d85
d90 :3 0 79 :2 0
df :4 0 74d d92
d94 :3 0 79 :2 0
7c :4 0 750 d96
d98 :3 0 79 :2 0
1c :3 0 753 d9a
d9c :3 0 79 :2 0
7c :4 0 756 d9e
da0 :3 0 759 d76
da2 :2 0 da4 75c
da5 d73 da4 0
da6 75e 0 dd0
71 :3 0 72 :3 0
da7 da8 0 71
:3 0 84 :3 0 daa
dab 0 2c :2 0
2 :4 0 145 :2 0
86 :2 0 2c :2 0
760 db0 db2 :3 0
763 dac db4 da9
db6 db5 :2 0 74
:3 0 87 :3 0 db8
db9 0 76 :4 0
146 :4 0 79 :2 0
7a :3 0 767 dbd
dbf :3 0 76a dba
dc1 :2 0 dc3 76d
dc4 db7 dc3 0
dc5 76f 0 dd0
e2 :3 0 e3 :3 0
dc6 dc7 0 dd
:3 0 144 :3 0 dc9
dca 0 1c :3 0
e4 :3 0 771 dc8
dce :2 0 dd0 775
dd1 d62 dd0 0
dd2 779 0 ecb
11c :3 0 60 :3 0
100 :3 0 c4 :3 0
13b :3 0 147 :3 0
148 :3 0 149 :3 0
149 :3 0 8d :3 0
13b :3 0 92 :3 0
149 :3 0 91 :3 0
13b :3 0 91 :3 0
13b :3 0 92 :3 0
1f :3 0 13b :3 0
c2 :3 0 1c :3 0
b6 :3 0 9f :3 0
13b :3 0 ae :3 0
149 :3 0 14a :4 0
14b 1 :8 0 df5
10 :3 0 96 :3 0
df0 df1 0 97
:3 0 df2 df3 0
df5 77b e3f 98
:3 0 10 :3 0 96
:3 0 df8 df9 0
97 :3 0 dfa dfb
0 e35 71 :3 0
72 :3 0 dfd dfe
0 71 :3 0 84
:3 0 e00 e01 0
99 :2 0 2 :4 0
14c :2 0 86 :2 0
2c :2 0 77e e06
e08 :3 0 781 e02
e0a dff e0c e0b
:2 0 74 :3 0 87
:3 0 e0e e0f 0
76 :4 0 14d :4 0
79 :2 0 7a :3 0
785 e13 e15 :3 0
79 :2 0 9c :4 0
788 e17 e19 :3 0
79 :2 0 9d :4 0
78b e1b e1d :3 0
79 :2 0 97 :3 0
78e e1f e21 :3 0
79 :2 0 9e :4 0
791 e23 e25 :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 794 e28
e2c 798 e27 e2e
:3 0 79b e10 e30
:2 0 e32 79e e33
e0d e32 0 e34
7a0 0 e35 7a2
e38 :3 0 e38 0
e38 e37 e35 e36
:6 0 e3a 20 :3 0
7a5 e3c 7a7 e3b
e3a :2 0 e3d 7a9
:2 0 e3f 0 e3f
e3e df5 e3d :6 0
ecb 1 :3 0 7e
:3 0 60 :3 0 2f
:2 0 7ab e41 e44
e8 :2 0 2f :2 0
7b0 e46 e48 :3 0
71 :3 0 72 :3 0
e4a e4b 0 71
:3 0 84 :3 0 e4d
e4e 0 13 :2 0
2 :4 0 14e :2 0
86 :2 0 2c :2 0
7b3 e53 e55 :3 0
7b6 e4f e57 e4c
e59 e58 :2 0 74
:3 0 87 :3 0 e5b
e5c 0 76 :4 0
14f :4 0 79 :2 0
7a :3 0 7ba e60
e62 :3 0 79 :2 0
9c :4 0 7bd e64
e66 :3 0 79 :2 0
dc :4 0 7c0 e68
e6a :3 0 79 :2 0
7e :3 0 82 :3 0
dd :3 0 150 :3 0
e6f e70 0 7c3
e6e e72 81 :4 0
7c5 e6d e75 7c8
e6c e77 :3 0 79
:2 0 df :4 0 7cb
e79 e7b :3 0 79
:2 0 7c :4 0 7ce
e7d e7f :3 0 79
:2 0 1c :3 0 7d1
e81 e83 :3 0 79
:2 0 7c :4 0 7d4
e85 e87 :3 0 7d7
e5d e89 :2 0 e8b
7da e8c e5a e8b
0 e8d 7dc 0
eb7 71 :3 0 72
:3 0 e8e e8f 0
71 :3 0 84 :3 0
e91 e92 0 2c
:2 0 2 :4 0 151
:2 0 86 :2 0 2c
:2 0 7de e97 e99
:3 0 7e1 e93 e9b
e90 e9d e9c :2 0
74 :3 0 87 :3 0
e9f ea0 0 76
:4 0 152 :4 0 79
:2 0 7a :3 0 7e5
ea4 ea6 :3 0 7e8
ea1 ea8 :2 0 eaa
7eb eab e9e eaa
0 eac 7ed 0
eb7 e2 :3 0 e3
:3 0 ead eae 0
dd :3 0 150 :3 0
eb0 eb1 0 1c
:3 0 e4 :3 0 7ef
eaf eb5 :2 0 eb7
7f3 eb8 e49 eb7
0 eb9 7f7 0
ecb 47 :3 0 d
:3 0 eba ebb 0
ecb 60 :3 0 153
:3 0 1f :3 0 1c
:3 0 47 :3 0 40
:3 0 7e :3 0 57
:3 0 2f :2 0 7f9
ec3 ec6 7fc ebe
ec8 ebd ec9 0
ecb 802 ecc c6a
ecb 0 ece 680
c50 0 ece 80c
0 f4f 7e :3 0
60 :3 0 2f :2 0
80f ecf ed2 a2
:2 0 2f :2 0 814
ed4 ed6 :3 0 60
:3 0 11b :3 0 1f
:3 0 817 ed9 edb
ed8 edc 0 ede
819 edf ed7 ede
0 ee0 81b 0
f4f 71 :3 0 72
:3 0 ee1 ee2 0
71 :3 0 84 :3 0
ee4 ee5 0 13
:2 0 2 :4 0 154
:2 0 86 :2 0 2c
:2 0 81d eea eec
:3 0 820 ee6 eee
ee3 ef0 eef :2 0
74 :3 0 87 :3 0
ef2 ef3 0 76
:4 0 155 :4 0 79
:2 0 7a :3 0 824
ef7 ef9 :3 0 79
:2 0 9c :4 0 827
efb efd :3 0 79
:2 0 dc :4 0 82a
eff f01 :3 0 79
:2 0 7e :3 0 82
:3 0 60 :3 0 82d
f05 f07 81 :4 0
82f f04 f0a 832
f03 f0c :3 0 79
:2 0 df :4 0 835
f0e f10 :3 0 79
:2 0 7c :4 0 838
f12 f14 :3 0 79
:2 0 1c :3 0 83b
f16 f18 :3 0 79
:2 0 7c :4 0 83e
f1a f1c :3 0 841
ef4 f1e :2 0 f20
844 f21 ef1 f20
0 f22 846 0
f4f 71 :3 0 72
:3 0 f23 f24 0
71 :3 0 84 :3 0
f26 f27 0 2c
:2 0 2 :4 0 156
:2 0 86 :2 0 2c
:2 0 848 f2c f2e
:3 0 84b f28 f30
f25 f32 f31 :2 0
74 :3 0 87 :3 0
f34 f35 0 76
:4 0 157 :4 0 79
:2 0 7a :3 0 84f
f39 f3b :3 0 852
f36 f3d :2 0 f3f
855 f40 f33 f3f
0 f41 857 0
f4f e2 :3 0 e3
:3 0 f42 f43 0
7e :3 0 60 :3 0
2f :2 0 859 f45
f48 1c :3 0 e4
:3 0 85c f44 f4c
:2 0 f4f 132 :3 0
860 23b3 6 :3 0
ef :2 0 86c f51
f52 :3 0 f53 :2 0
8 :3 0 ef :2 0
86e f56 f57 :3 0
f58 :2 0 f54 f5a
f59 :2 0 24 :3 0
6 :3 0 f5c f5d
0 2241 25 :3 0
8 :3 0 f5f f60
0 2241 e5 :3 0
e6 :3 0 f62 f63
0 24 :3 0 25
:3 0 e7 :2 0 870
f64 f68 e8 :2 0
2f :2 0 876 f6a
f6c :3 0 f6d :2 0
e5 :3 0 e6 :3 0
f6f f70 0 25
:3 0 23 :3 0 e7
:2 0 879 f71 f75
e9 :2 0 2f :2 0
87f f77 f79 :3 0
f7a :2 0 f6e f7c
f7b :2 0 71 :3 0
72 :3 0 f7e f7f
0 71 :3 0 84
:3 0 f81 f82 0
13 :2 0 2 :4 0
158 :2 0 86 :2 0
2c :2 0 882 f87
f89 :3 0 885 f83
f8b f80 f8d f8c
:2 0 74 :3 0 87
:3 0 f8f f90 0
76 :4 0 159 :4 0
79 :2 0 7a :3 0
889 f94 f96 :3 0
79 :2 0 9c :4 0
88c f98 f9a :3 0
79 :2 0 dc :4 0
88f f9c f9e :3 0
79 :2 0 7e :3 0
82 :3 0 dd :3 0
ec :3 0 fa3 fa4
0 892 fa2 fa6
81 :4 0 894 fa1
fa9 897 fa0 fab
:3 0 79 :2 0 df
:4 0 89a fad faf
:3 0 79 :2 0 7c
:4 0 89d fb1 fb3
:3 0 79 :2 0 1c
:3 0 8a0 fb5 fb7
:3 0 79 :2 0 7c
:4 0 8a3 fb9 fbb
:3 0 8a6 f91 fbd
:2 0 fbf 8a9 fc0
f8e fbf 0 fc1
8ab 0 feb 71
:3 0 72 :3 0 fc2
fc3 0 71 :3 0
84 :3 0 fc5 fc6
0 2c :2 0 2
:4 0 15a :2 0 86
:2 0 2c :2 0 8ad
fcb fcd :3 0 8b0
fc7 fcf fc4 fd1
fd0 :2 0 74 :3 0
87 :3 0 fd3 fd4
0 76 :4 0 15b
:4 0 79 :2 0 7a
:3 0 8b4 fd8 fda
:3 0 8b7 fd5 fdc
:2 0 fde 8ba fdf
fd2 fde 0 fe0
8bc 0 feb e2
:3 0 e3 :3 0 fe1
fe2 0 dd :3 0
ec :3 0 fe4 fe5
0 1c :3 0 e4
:3 0 8be fe3 fe9
:2 0 feb 8c2 fec
f7d feb 0 fed
8c6 0 2241 92
:3 0 c9 :3 0 ca
:3 0 1f :3 0 4b
:3 0 4c :3 0 d6
:3 0 92 :3 0 1f
:3 0 8d :3 0 3e
:4 0 15c 1 :8 0
fff 10 :3 0 96
:3 0 ffa ffb 0
97 :3 0 ffc ffd
0 fff 8c8 1049
98 :3 0 10 :3 0
96 :3 0 1002 1003
0 97 :3 0 1004
1005 0 103f 71
:3 0 72 :3 0 1007
1008 0 71 :3 0
84 :3 0 100a 100b
0 99 :2 0 2
:4 0 15d :2 0 86
:2 0 2c :2 0 8cb
1010 1012 :3 0 8ce
100c 1014 1009 1016
1015 :2 0 74 :3 0
87 :3 0 1018 1019
0 76 :4 0 15e
:4 0 79 :2 0 7a
:3 0 8d2 101d 101f
:3 0 79 :2 0 9c
:4 0 8d5 1021 1023
:3 0 79 :2 0 9d
:4 0 8d8 1025 1027
:3 0 79 :2 0 97
:3 0 8db 1029 102b
:3 0 79 :2 0 9e
:4 0 8de 102d 102f
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 8e1
1032 1036 8e5 1031
1038 :3 0 8e8 101a
103a :2 0 103c 8eb
103d 1017 103c 0
103e 8ed 0 103f
8ef 1042 :3 0 1042
0 1042 1041 103f
1040 :6 0 1044 22
:3 0 8f2 1046 8f4
1045 1044 :2 0 1047
8f6 :2 0 1049 0
1049 1048 fff 1047
:6 0 2241 1 :3 0
9f :3 0 2d :3 0
2c :2 0 2c :2 0
8f8 104b 104f a2
:2 0 2c :4 0 8fe
1051 1053 :3 0 38
:3 0 2c :2 0 1055
1056 0 1058 901
105d 38 :3 0 2f
:2 0 1059 105a 0
105c 903 105e 1054
1058 0 105f 0
105c 0 105f 905
0 2241 6c :3 0
2f :2 0 1060 1061
0 2241 6d :3 0
2f :2 0 1063 1064
0 2241 e5 :3 0
e6 :3 0 1066 1067
0 24 :3 0 22
:3 0 e7 :2 0 908
1068 106c e9 :2 0
2f :2 0 90e 106e
1070 :3 0 1071 :2 0
e5 :3 0 e6 :3 0
1073 1074 0 25
:3 0 23 :3 0 e7
:2 0 911 1075 1079
e9 :2 0 2f :2 0
917 107b 107d :3 0
107e :2 0 1072 1080
107f :2 0 7e :3 0
9 :3 0 2f :2 0
91a 1082 1085 7e
:3 0 e9 :2 0 43
:3 0 2f :2 0 91d
1087 108b 922 1088
108d :3 0 108e :2 0
1081 1090 108f :2 0
e5 :3 0 e6 :3 0
1092 1093 0 24
:3 0 22 :3 0 e7
:2 0 925 1094 1098
e9 :2 0 2f :2 0
92b 109a 109c :3 0
c9 :3 0 ca :3 0
4b :3 0 4c :3 0
d6 :3 0 92 :3 0
1f :3 0 8d :3 0
3e :4 0 15f 1
:8 0 10ad 10 :3 0
96 :3 0 10a8 10a9
0 97 :3 0 10aa
10ab 0 10ad 92e
10f7 98 :3 0 10
:3 0 96 :3 0 10b0
10b1 0 97 :3 0
10b2 10b3 0 10ed
71 :3 0 72 :3 0
10b5 10b6 0 71
:3 0 84 :3 0 10b8
10b9 0 99 :2 0
2 :4 0 160 :2 0
86 :2 0 2c :2 0
931 10be 10c0 :3 0
934 10ba 10c2 10b7
10c4 10c3 :2 0 74
:3 0 87 :3 0 10c6
10c7 0 76 :4 0
161 :4 0 79 :2 0
7a :3 0 938 10cb
10cd :3 0 79 :2 0
9c :4 0 93b 10cf
10d1 :3 0 79 :2 0
9d :4 0 93e 10d3
10d5 :3 0 79 :2 0
97 :3 0 941 10d7
10d9 :3 0 79 :2 0
9e :4 0 944 10db
10dd :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
947 10e0 10e4 94b
10df 10e6 :3 0 94e
10c8 10e8 :2 0 10ea
951 10eb 10c5 10ea
0 10ec 953 0
10ed 955 10f0 :3 0
10f0 0 10f0 10ef
10ed 10ee :6 0 10f2
24 :3 0 958 10f4
95a 10f3 10f2 :2 0
10f5 95c :2 0 10f7
0 10f7 10f6 10ad
10f5 :6 0 1103 1
:3 0 22 :3 0 24
:3 0 10f9 10fa 0
1103 43 :3 0 2f
:2 0 10fc 10fd 0
1103 6c :3 0 2c
:2 0 10ff 1100 0
1103 132 :3 0 95e
1673 e5 :3 0 e6
:3 0 1104 1105 0
25 :3 0 23 :3 0
e7 :2 0 963 1106
110a e9 :2 0 2f
:2 0 969 110c 110e
:3 0 e5 :3 0 f6
:3 0 b6 :3 0 9f
:3 0 25 :3 0 e5
:3 0 f8 :3 0 23
:3 0 25 :3 0 100
:4 0 162 1 :8 0
1120 10 :3 0 96
:3 0 111b 111c 0
97 :3 0 111d 111e
0 1120 96c 116a
98 :3 0 10 :3 0
96 :3 0 1123 1124
0 97 :3 0 1125
1126 0 1160 71
:3 0 72 :3 0 1128
1129 0 71 :3 0
84 :3 0 112b 112c
0 99 :2 0 2
:4 0 163 :2 0 86
:2 0 2c :2 0 96f
1131 1133 :3 0 972
112d 1135 112a 1137
1136 :2 0 74 :3 0
87 :3 0 1139 113a
0 76 :4 0 164
:4 0 79 :2 0 7a
:3 0 976 113e 1140
:3 0 79 :2 0 9c
:4 0 979 1142 1144
:3 0 79 :2 0 9d
:4 0 97c 1146 1148
:3 0 79 :2 0 97
:3 0 97f 114a 114c
:3 0 79 :2 0 9e
:4 0 982 114e 1150
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 985
1153 1157 989 1152
1159 :3 0 98c 113b
115b :2 0 115d 98f
115e 1138 115d 0
115f 991 0 1160
993 1163 :3 0 1163
0 1163 1162 1160
1161 :6 0 1165 26
:3 0 996 1167 998
1166 1165 :2 0 1168
99a :2 0 116a 0
116a 1169 1120 1168
:6 0 1307 1 :3 0
6d :3 0 e5 :3 0
165 :3 0 116d 116e
0 25 :3 0 23
:3 0 99c 116f 1172
116c 1173 0 1307
31 :3 0 f0 :2 0
2c :2 0 99f 1176
1178 :3 0 1175 1179
0 1307 60 :3 0
166 :3 0 1f :3 0
3e :3 0 1c :3 0
27 :3 0 29 :3 0
61 :3 0 63 :3 0
31 :3 0 30 :3 0
2e :3 0 9a1 117c
1187 117b 1188 0
1307 7e :3 0 49
:3 0 2f :2 0 9ac
118a 118d e8 :2 0
2f :2 0 9b1 118f
1191 :3 0 1192 :2 0
33 :3 0 ef :2 0
9b4 1195 1196 :3 0
1197 :2 0 1198 :2 0
1193 119a 1199 :2 0
167 :3 0 168 :3 0
169 :3 0 92 :3 0
1f :3 0 c5 :3 0
1c :3 0 f7 :3 0
b6 :3 0 9f :3 0
33 :4 0 16a 1
:8 0 11bd 110 :4 0
11a8 :3 0 e4 :3 0
a2 :2 0 9b8 11ab
11ac :3 0 10 :3 0
96 :3 0 11ae 11af
0 2f :2 0 11b0
11b1 0 11b3 9bb
11ba 10 :3 0 96
:3 0 11b4 11b5 0
111 :2 0 11b6 11b7
0 11b9 9bd 11bb
11ad 11b3 0 11bc
0 11b9 0 11bc
9bf 0 11bd 9c2
1207 98 :3 0 10
:3 0 96 :3 0 11c0
11c1 0 97 :3 0
11c2 11c3 0 11fd
71 :3 0 72 :3 0
11c5 11c6 0 71
:3 0 84 :3 0 11c8
11c9 0 99 :2 0
2 :4 0 16b :2 0
86 :2 0 2c :2 0
9c5 11ce 11d0 :3 0
9c8 11ca 11d2 11c7
11d4 11d3 :2 0 74
:3 0 87 :3 0 11d6
11d7 0 76 :4 0
16c :4 0 79 :2 0
7a :3 0 9cc 11db
11dd :3 0 79 :2 0
9c :4 0 9cf 11df
11e1 :3 0 79 :2 0
9d :4 0 9d2 11e3
11e5 :3 0 79 :2 0
97 :3 0 9d5 11e7
11e9 :3 0 79 :2 0
9e :4 0 9d8 11eb
11ed :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
9db 11f0 11f4 9df
11ef 11f6 :3 0 9e2
11d8 11f8 :2 0 11fa
9e5 11fb 11d5 11fa
0 11fc 9e7 0
11fd 9e9 1200 :3 0
1200 0 1200 11ff
11fd 11fe :6 0 1202
28 :3 0 9ec 1204
9ee 1203 1202 :2 0
1205 9f0 :2 0 1207
0 1207 1206 11bd
1205 :6 0 1209 1
:3 0 9f2 120a 119b
1209 0 120b 9f4
0 1307 9f :3 0
2b :3 0 2c :2 0
2c :2 0 9f6 120c
1210 a2 :2 0 16d
:4 0 9fc 1212 1214
:3 0 4d :3 0 16d
:2 0 1216 1217 0
1219 9ff 121e 4d
:3 0 2f :2 0 121a
121b 0 121d a01
121f 1215 1219 0
1220 0 121d 0
1220 a03 0 1307
60 :3 0 16e :3 0
1f :3 0 3e :3 0
1c :3 0 3f :3 0
2d :3 0 27 :3 0
29 :3 0 22 :3 0
25 :3 0 4d :3 0
4c :3 0 44 :3 0
40 :3 0 16d :2 0
6d :3 0 2f :2 0
a06 1222 1233 1221
1234 0 1307 b6
:3 0 9f :3 0 22
:3 0 b6 :3 0 9f
:3 0 25 :3 0 b7
:3 0 b8 :3 0 b9
:3 0 bb :3 0 27
:3 0 29 :3 0 2e
:3 0 30 :3 0 61
:3 0 63 :3 0 c4
:3 0 c5 :3 0 1c
:4 0 16f 1 :8 0
124f 10 :3 0 96
:3 0 124a 124b 0
97 :3 0 124c 124d
0 124f a17 1299
98 :3 0 10 :3 0
96 :3 0 1252 1253
0 97 :3 0 1254
1255 0 128f 71
:3 0 72 :3 0 1257
1258 0 71 :3 0
84 :3 0 125a 125b
0 99 :2 0 2
:4 0 170 :2 0 86
:2 0 2c :2 0 a1a
1260 1262 :3 0 a1d
125c 1264 1259 1266
1265 :2 0 74 :3 0
87 :3 0 1268 1269
0 76 :4 0 171
:4 0 79 :2 0 7a
:3 0 a21 126d 126f
:3 0 79 :2 0 9c
:4 0 a24 1271 1273
:3 0 79 :2 0 9d
:4 0 a27 1275 1277
:3 0 79 :2 0 97
:3 0 a2a 1279 127b
:3 0 79 :2 0 9e
:4 0 a2d 127d 127f
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 a30
1282 1286 a34 1281
1288 :3 0 a37 126a
128a :2 0 128c a3a
128d 1267 128c 0
128e a3c 0 128f
a3e 1292 :3 0 1292
0 1292 1291 128f
1290 :6 0 1294 2a
:3 0 a41 1296 a43
1295 1294 :2 0 1297
a45 :2 0 1299 0
1299 1298 124f 1297
:6 0 1307 1 :3 0
31 :3 0 2f :2 0
129b 129c 0 1307
60 :3 0 166 :3 0
1f :3 0 3e :3 0
1c :3 0 27 :3 0
29 :3 0 61 :3 0
63 :3 0 31 :3 0
30 :3 0 2e :3 0
a47 129f 12aa 129e
12ab 0 1307 60
:3 0 11b :3 0 1f
:3 0 a52 12ae 12b0
12ad 12b1 0 1307
10 :3 0 96 :3 0
12b3 12b4 0 2f
:2 0 12b5 12b6 0
1307 71 :3 0 72
:3 0 12b8 12b9 0
71 :3 0 84 :3 0
12bb 12bc 0 172
:2 0 2 :4 0 173
:2 0 86 :2 0 2c
:2 0 a54 12c1 12c3
:3 0 a57 12bd 12c5
12ba 12c7 12c6 :2 0
74 :3 0 87 :3 0
12c9 12ca 0 76
:4 0 174 :4 0 79
:2 0 7a :3 0 a5b
12ce 12d0 :3 0 79
:2 0 9c :4 0 a5e
12d2 12d4 :3 0 79
:2 0 dc :4 0 a61
12d6 12d8 :3 0 79
:2 0 7e :3 0 82
:3 0 10 :3 0 96
:3 0 12dd 12de 0
a64 12dc 12e0 81
:4 0 a66 12db 12e3
a69 12da 12e5 :3 0
79 :2 0 df :4 0
a6c 12e7 12e9 :3 0
79 :2 0 7c :4 0
a6f 12eb 12ed :3 0
79 :2 0 1a :3 0
a72 12ef 12f1 :3 0
79 :2 0 7c :4 0
a75 12f3 12f5 :3 0
a78 12cb 12f7 :2 0
12f9 a7b 12fa 12c8
12f9 0 12fb a7d
0 1307 e2 :3 0
175 :3 0 12fc 12fd
0 10 :3 0 96
:3 0 12ff 1300 0
1a :3 0 e4 :3 0
a7f 12fe 1304 :2 0
1307 132 :3 0 a83
1308 110f 1307 0
1674 7e :3 0 43
:3 0 2f :2 0 a92
1309 130c 7e :3 0
176 :2 0 9 :3 0
2f :2 0 a95 130e
1312 a9a 130f 1314
:3 0 43 :3 0 7e
:3 0 9 :3 0 2f
:2 0 a9d 1317 131a
f0 :2 0 7e :3 0
43 :3 0 2f :2 0
aa0 131d 1320 aa3
131c 1322 :3 0 1316
1323 0 1329 6c
:3 0 2c :2 0 1325
1326 0 1329 132
:3 0 aa6 132a 1315
1329 0 1674 7e
:3 0 9 :3 0 2f
:2 0 aa9 132b 132e
a2 :2 0 2f :2 0
aae 1330 1332 :3 0
43 :3 0 2f :2 0
1334 1335 0 1392
6c :3 0 2c :2 0
1337 1338 0 1392
cb :3 0 22 :3 0
d6 :3 0 8d :3 0
3e :4 0 177 1
:8 0 1345 10 :3 0
96 :3 0 1340 1341
0 97 :3 0 1342
1343 0 1345 ab1
138f 98 :3 0 10
:3 0 96 :3 0 1348
1349 0 97 :3 0
134a 134b 0 1385
71 :3 0 72 :3 0
134d 134e 0 71
:3 0 84 :3 0 1350
1351 0 99 :2 0
2 :4 0 178 :2 0
86 :2 0 2c :2 0
ab4 1356 1358 :3 0
ab7 1352 135a 134f
135c 135b :2 0 74
:3 0 87 :3 0 135e
135f 0 76 :4 0
179 :4 0 79 :2 0
7a :3 0 abb 1363
1365 :3 0 79 :2 0
9c :4 0 abe 1367
1369 :3 0 79 :2 0
9d :4 0 ac1 136b
136d :3 0 79 :2 0
97 :3 0 ac4 136f
1371 :3 0 79 :2 0
9e :4 0 ac7 1373
1375 :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
aca 1378 137c ace
1377 137e :3 0 ad1
1360 1380 :2 0 1382
ad4 1383 135d 1382
0 1384 ad6 0
1385 ad8 1388 :3 0
1388 0 1388 1387
1385 1386 :6 0 138a
2c :3 0 adb 138c
add 138b 138a :2 0
138d adf :2 0 138f
0 138f 138e 1345
138d :6 0 1392 1
:3 0 132 :3 0 ae1
1393 1333 1392 0
1674 7e :3 0 43
:3 0 2f :2 0 ae5
1394 1397 7e :3 0
e8 :2 0 9 :3 0
2f :2 0 ae8 1399
139d aed 139a 139f
:3 0 43 :3 0 7e
:3 0 43 :3 0 2f
:2 0 af0 13a2 13a5
f0 :2 0 7e :3 0
9 :3 0 2f :2 0
af3 13a8 13ab af6
13a7 13ad :3 0 13a1
13ae 0 1671 32
:4 0 13b0 13b1 0
1671 6a :3 0 89
:4 0 13b3 13b4 0
1671 7e :3 0 38
:3 0 2f :2 0 af9
13b6 13b9 a2 :2 0
2c :2 0 afe 13bb
13bd :3 0 6a :3 0
17a :4 0 79 :2 0
17b :4 0 b01 13c1
13c3 :3 0 79 :2 0
1f :3 0 b04 13c5
13c7 :3 0 79 :2 0
17c :4 0 b07 13c9
13cb :3 0 79 :2 0
22 :3 0 b0a 13cd
13cf :3 0 79 :2 0
17d :4 0 b0d 13d1
13d3 :3 0 79 :2 0
17e :4 0 b10 13d5
13d7 :3 0 79 :2 0
82 :3 0 7e :3 0
43 :3 0 2f :2 0
b13 13db 13de b16
13da 13e0 b18 13d9
13e2 :3 0 13bf 13e3
0 13ea 17f :3 0
6e :3 0 6a :3 0
13e6 13e7 0 13e8
:2 0 13ea b1b 1417
6a :3 0 17a :4 0
79 :2 0 17b :4 0
b1e 13ed 13ef :3 0
79 :2 0 3f :3 0
b21 13f1 13f3 :3 0
79 :2 0 17c :4 0
b24 13f5 13f7 :3 0
79 :2 0 22 :3 0
b27 13f9 13fb :3 0
79 :2 0 17d :4 0
b2a 13fd 13ff :3 0
79 :2 0 17e :4 0
b2d 1401 1403 :3 0
79 :2 0 82 :3 0
7e :3 0 43 :3 0
2f :2 0 b30 1407
140a b33 1406 140c
b35 1405 140e :3 0
13eb 140f 0 1416
17f :3 0 6f :3 0
6a :3 0 1412 1413
0 1414 :2 0 1416
b38 1418 13be 13ea
0 1419 0 1416
0 1419 b3b 0
1671 180 :3 0 7e
:3 0 38 :3 0 2f
:2 0 b3e 141b 141e
a2 :2 0 2c :2 0
b43 1420 1422 :3 0
6e :3 0 32 :4 0
1427 :2 0 143a 1424
1425 :3 0 6e :3 0
110 :3 0 1428 1429
:3 0 10 :3 0 96
:3 0 142b 142c 0
2f :2 0 142d 142e
0 1430 b46 1437
10 :3 0 96 :3 0
1431 1432 0 111
:2 0 1433 1434 0
1436 b48 1438 142a
1430 0 1439 0
1436 0 1439 b4a
0 143a b4d 1452
6f :3 0 32 :4 0
143e :2 0 1451 143b
143c :3 0 6f :3 0
110 :3 0 143f 1440
:3 0 10 :3 0 96
:3 0 1442 1443 0
2f :2 0 1444 1445
0 1447 b50 144e
10 :3 0 96 :3 0
1448 1449 0 111
:2 0 144a 144b 0
144d b52 144f 1441
1447 0 1450 0
144d 0 1450 b54
0 1451 b57 1453
1423 143a 0 1454
0 1451 0 1454
b5a 0 1464 10
:3 0 96 :3 0 1455
1456 0 10 :3 0
e9 :2 0 11a :3 0
1458 145a 0 b5f
1459 145c :3 0 145d
:2 0 181 :8 0 1461
b62 1462 145e 1461
0 1463 b64 0
1464 b66 1466 180
:4 0 1464 :4 0 1671
7e :3 0 38 :3 0
2f :2 0 b69 1467
146a a2 :2 0 2c
:2 0 b6e 146c 146e
:3 0 182 :3 0 6e
:4 0 1473 :2 0 1479
1471 0 10 :3 0
96 :3 0 1474 1475
0 97 :3 0 1476
1477 0 1479 b71
14c3 98 :3 0 10
:3 0 96 :3 0 147c
147d 0 97 :3 0
147e 147f 0 14b9
71 :3 0 72 :3 0
1481 1482 0 71
:3 0 84 :3 0 1484
1485 0 99 :2 0
2 :4 0 183 :2 0
86 :2 0 2c :2 0
b74 148a 148c :3 0
b77 1486 148e 1483
1490 148f :2 0 74
:3 0 87 :3 0 1492
1493 0 76 :4 0
184 :4 0 79 :2 0
7a :3 0 b7b 1497
1499 :3 0 79 :2 0
9c :4 0 b7e 149b
149d :3 0 79 :2 0
9d :4 0 b81 149f
14a1 :3 0 79 :2 0
97 :3 0 b84 14a3
14a5 :3 0 79 :2 0
9e :4 0 b87 14a7
14a9 :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
b8a 14ac 14b0 b8e
14ab 14b2 :3 0 b91
1494 14b4 :2 0 14b6
b94 14b7 1491 14b6
0 14b8 b96 0
14b9 b98 14bc :3 0
14bc 0 14bc 14bb
14b9 14ba :6 0 14be
2f :3 0 b9b 14c0
b9d 14bf 14be :2 0
14c1 b9f :2 0 14c3
0 14c3 14c2 1479
14c1 :6 0 14c5 1
:3 0 ba1 151c 182
:3 0 6f :4 0 14c9
:2 0 14cf 14c7 0
10 :3 0 96 :3 0
14ca 14cb 0 97
:3 0 14cc 14cd 0
14cf ba3 1519 98
:3 0 10 :3 0 96
:3 0 14d2 14d3 0
97 :3 0 14d4 14d5
0 150f 71 :3 0
72 :3 0 14d7 14d8
0 71 :3 0 84
:3 0 14da 14db 0
99 :2 0 2 :4 0
185 :2 0 86 :2 0
2c :2 0 ba6 14e0
14e2 :3 0 ba9 14dc
14e4 14d9 14e6 14e5
:2 0 74 :3 0 87
:3 0 14e8 14e9 0
76 :4 0 186 :4 0
79 :2 0 7a :3 0
bad 14ed 14ef :3 0
79 :2 0 9c :4 0
bb0 14f1 14f3 :3 0
79 :2 0 9d :4 0
bb3 14f5 14f7 :3 0
79 :2 0 97 :3 0
bb6 14f9 14fb :3 0
79 :2 0 9e :4 0
bb9 14fd 14ff :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 bbc 1502
1506 bc0 1501 1508
:3 0 bc3 14ea 150a
:2 0 150c bc6 150d
14e7 150c 0 150e
bc8 0 150f bca
1512 :3 0 1512 0
1512 1511 150f 1510
:6 0 1514 31 :3 0
bcd 1516 bcf 1515
1514 :2 0 1517 bd1
:2 0 1519 0 1519
1518 14cf 1517 :6 0
151b 1 :3 0 bd3
151d 146f 14c5 0
151e 0 151b 0
151e bd5 0 1671
32 :3 0 187 :2 0
bd8 1520 1521 :3 0
1522 :2 0 7e :3 0
38 :3 0 2f :2 0
bda 1524 1527 a2
:2 0 2c :2 0 bdf
1529 152b :3 0 71
:3 0 72 :3 0 152d
152e 0 71 :3 0
84 :3 0 1530 1531
0 13 :2 0 2
:4 0 188 :2 0 86
:2 0 2c :2 0 be2
1536 1538 :3 0 be5
1532 153a 152f 153c
153b :2 0 74 :3 0
87 :3 0 153e 153f
0 76 :4 0 189
:4 0 79 :2 0 7a
:3 0 be9 1543 1545
:3 0 79 :2 0 9c
:4 0 bec 1547 1549
:3 0 79 :2 0 dc
:4 0 bef 154b 154d
:3 0 79 :2 0 7e
:3 0 82 :3 0 dd
:3 0 de :3 0 1552
1553 0 bf2 1551
1555 81 :4 0 bf4
1550 1558 bf7 154f
155a :3 0 79 :2 0
df :4 0 bfa 155c
155e :3 0 79 :2 0
7c :4 0 bfd 1560
1562 :3 0 79 :2 0
1f :3 0 c00 1564
1566 :3 0 79 :2 0
7c :4 0 c03 1568
156a :3 0 c06 1540
156c :2 0 156e c09
156f 153d 156e 0
1570 c0b 0 159a
71 :3 0 72 :3 0
1571 1572 0 71
:3 0 84 :3 0 1574
1575 0 2c :2 0
2 :4 0 18a :2 0
86 :2 0 2c :2 0
c0d 157a 157c :3 0
c10 1576 157e 1573
1580 157f :2 0 74
:3 0 87 :3 0 1582
1583 0 76 :4 0
18b :4 0 79 :2 0
7a :3 0 c14 1587
1589 :3 0 c17 1584
158b :2 0 158d c1a
158e 1581 158d 0
158f c1c 0 159a
e2 :3 0 e3 :3 0
1590 1591 0 dd
:3 0 de :3 0 1593
1594 0 1f :3 0
e4 :3 0 c1e 1592
1598 :2 0 159a c22
1609 71 :3 0 72
:3 0 159b 159c 0
71 :3 0 84 :3 0
159e 159f 0 13
:2 0 2 :4 0 18c
:2 0 86 :2 0 2c
:2 0 c26 15a4 15a6
:3 0 c29 15a0 15a8
159d 15aa 15a9 :2 0
74 :3 0 87 :3 0
15ac 15ad 0 76
:4 0 18d :4 0 79
:2 0 7a :3 0 c2d
15b1 15b3 :3 0 79
:2 0 9c :4 0 c30
15b5 15b7 :3 0 79
:2 0 dc :4 0 c33
15b9 15bb :3 0 79
:2 0 7e :3 0 82
:3 0 dd :3 0 de
:3 0 15c0 15c1 0
c36 15bf 15c3 81
:4 0 c38 15be 15c6
c3b 15bd 15c8 :3 0
79 :2 0 df :4 0
c3e 15ca 15cc :3 0
79 :2 0 7c :4 0
c41 15ce 15d0 :3 0
79 :2 0 3f :3 0
c44 15d2 15d4 :3 0
79 :2 0 7c :4 0
c47 15d6 15d8 :3 0
c4a 15ae 15da :2 0
15dc c4d 15dd 15ab
15dc 0 15de c4f
0 1608 71 :3 0
72 :3 0 15df 15e0
0 71 :3 0 84
:3 0 15e2 15e3 0
2c :2 0 2 :4 0
18e :2 0 86 :2 0
2c :2 0 c51 15e8
15ea :3 0 c54 15e4
15ec 15e1 15ee 15ed
:2 0 74 :3 0 87
:3 0 15f0 15f1 0
76 :4 0 18f :4 0
79 :2 0 7a :3 0
c58 15f5 15f7 :3 0
c5b 15f2 15f9 :2 0
15fb c5e 15fc 15ef
15fb 0 15fd c60
0 1608 e2 :3 0
e3 :3 0 15fe 15ff
0 dd :3 0 de
:3 0 1601 1602 0
3f :3 0 e4 :3 0
c62 1600 1606 :2 0
1608 c66 160a 152c
159a 0 160b 0
1608 0 160b c6a
0 160c c6d 160d
1523 160c 0 160e
c6f 0 1671 e5
:3 0 f6 :3 0 b6
:3 0 9f :3 0 32
:3 0 e5 :3 0 f8
:3 0 22 :3 0 22
:3 0 100 :4 0 190
1 :8 0 161f 10
:3 0 96 :3 0 161a
161b 0 97 :3 0
161c 161d 0 161f
c71 1669 98 :3 0
10 :3 0 96 :3 0
1622 1623 0 97
:3 0 1624 1625 0
165f 71 :3 0 72
:3 0 1627 1628 0
71 :3 0 84 :3 0
162a 162b 0 99
:2 0 2 :4 0 191
:2 0 86 :2 0 2c
:2 0 c74 1630 1632
:3 0 c77 162c 1634
1629 1636 1635 :2 0
74 :3 0 87 :3 0
1638 1639 0 76
:4 0 192 :4 0 79
:2 0 7a :3 0 c7b
163d 163f :3 0 79
:2 0 9c :4 0 c7e
1641 1643 :3 0 79
:2 0 9d :4 0 c81
1645 1647 :3 0 79
:2 0 97 :3 0 c84
1649 164b :3 0 79
:2 0 9e :4 0 c87
164d 164f :3 0 79
:2 0 9f :3 0 a0
:3 0 2c :2 0 a1
:2 0 c8a 1652 1656
c8e 1651 1658 :3 0
c91 163a 165a :2 0
165c c94 165d 1637
165c 0 165e c96
0 165f c98 1662
:3 0 1662 0 1662
1661 165f 1660 :6 0
1664 33 :3 0 c9b
1666 c9d 1665 1664
:2 0 1667 c9f :2 0
1669 0 1669 1668
161f 1667 :6 0 1671
1 :3 0 43 :3 0
2f :2 0 166b 166c
0 1671 6c :3 0
2c :2 0 166e 166f
0 1671 ca1 1672
13a0 1671 0 1674
109d 1103 0 1674
cac 0 1676 132
:3 0 cb2 190d 7e
:3 0 b :3 0 2f
:2 0 cb4 1677 167a
7e :3 0 e9 :2 0
44 :3 0 2f :2 0
cb7 167c 1680 cbc
167d 1682 :3 0 7e
:3 0 46 :3 0 2f
:2 0 cbf 1684 1687
7e :3 0 a2 :2 0
41 :3 0 2f :2 0
cc2 1689 168d cc7
168a 168f :3 0 71
:3 0 72 :3 0 1691
1692 0 71 :3 0
84 :3 0 1694 1695
0 13 :2 0 2
:4 0 193 :2 0 86
:2 0 2c :2 0 cca
169a 169c :3 0 ccd
1696 169e 1693 16a0
169f :2 0 74 :3 0
87 :3 0 16a2 16a3
0 76 :4 0 194
:4 0 79 :2 0 7a
:3 0 cd1 16a7 16a9
:3 0 79 :2 0 9c
:4 0 cd4 16ab 16ad
:3 0 79 :2 0 dc
:4 0 cd7 16af 16b1
:3 0 79 :2 0 7e
:3 0 82 :3 0 10
:3 0 96 :3 0 16b6
16b7 0 cda 16b5
16b9 81 :4 0 cdc
16b4 16bc cdf 16b3
16be :3 0 79 :2 0
df :4 0 ce2 16c0
16c2 :3 0 79 :2 0
7c :4 0 ce5 16c4
16c6 :3 0 79 :2 0
1c :3 0 ce8 16c8
16ca :3 0 79 :2 0
7c :4 0 ceb 16cc
16ce :3 0 cee 16a4
16d0 :2 0 16d2 cf1
16d3 16a1 16d2 0
16d4 cf3 0 16fe
71 :3 0 72 :3 0
16d5 16d6 0 71
:3 0 84 :3 0 16d8
16d9 0 2c :2 0
2 :4 0 195 :2 0
86 :2 0 2c :2 0
cf5 16de 16e0 :3 0
cf8 16da 16e2 16d7
16e4 16e3 :2 0 74
:3 0 87 :3 0 16e6
16e7 0 76 :4 0
196 :4 0 79 :2 0
7a :3 0 cfc 16eb
16ed :3 0 cff 16e8
16ef :2 0 16f1 d02
16f2 16e5 16f1 0
16f3 d04 0 16fe
e2 :3 0 e3 :3 0
16f4 16f5 0 10
:3 0 96 :3 0 16f7
16f8 0 1c :3 0
e4 :3 0 d06 16f6
16fc :2 0 16fe d0a
16ff 1690 16fe 0
1700 d0e 0 190b
7e :3 0 b :3 0
2f :2 0 d10 1701
1704 a2 :2 0 2f
:2 0 d15 1706 1708
:3 0 44 :3 0 111
:2 0 170a 170b 0
170d d18 1787 7e
:3 0 b :3 0 2f
:2 0 d1a 170e 1711
176 :2 0 2c :2 0
d1f 1713 1715 :3 0
1716 :2 0 7e :3 0
b :3 0 2f :2 0
d22 1718 171b e8
:2 0 197 :2 0 d27
171d 171f :3 0 1720
:2 0 1717 1722 1721
:2 0 71 :3 0 72
:3 0 1724 1725 0
71 :3 0 84 :3 0
1727 1728 0 133
:2 0 2 :4 0 198
:2 0 86 :2 0 2c
:2 0 d2a 172d 172f
:3 0 d2d 1729 1731
1726 1733 1732 :2 0
74 :3 0 87 :3 0
1735 1736 0 76
:4 0 199 :4 0 79
:2 0 7a :3 0 d31
173a 173c :3 0 79
:2 0 9c :4 0 d34
173e 1740 :3 0 79
:2 0 dc :4 0 d37
1742 1744 :3 0 79
:2 0 7e :3 0 82
:3 0 dd :3 0 19a
:3 0 1749 174a 0
d3a 1748 174c 81
:4 0 d3c 1747 174f
d3f 1746 1751 :3 0
d42 1737 1753 :2 0
1755 d45 1756 1734
1755 0 1757 d47
0 1780 71 :3 0
72 :3 0 1758 1759
0 71 :3 0 84
:3 0 175b 175c 0
2c :2 0 2 :4 0
19b :2 0 86 :2 0
2c :2 0 d49 1761
1763 :3 0 d4c 175d
1765 175a 1767 1766
:2 0 74 :3 0 87
:3 0 1769 176a 0
76 :4 0 19c :4 0
79 :2 0 7a :3 0
d50 176e 1770 :3 0
d53 176b 1772 :2 0
1774 d56 1775 1768
1774 0 1776 d58
0 1780 e2 :3 0
139 :3 0 1777 1778
0 dd :3 0 19a
:3 0 177a 177b 0
e4 :3 0 d5a 1779
177e :2 0 1780 d5d
1781 1723 1780 0
1782 d61 0 1786
44 :3 0 b :3 0
1783 1784 0 1786
d63 1788 1709 170d
0 1789 0 1786
0 1789 d66 0
190b 1d :3 0 ef
:2 0 d69 178b 178c
:3 0 178d :2 0 ad
:3 0 60 :3 0 c4
:3 0 c5 :3 0 1d
:4 0 19d 1 :8 0
179a 10 :3 0 96
:3 0 1795 1796 0
97 :3 0 1797 1798
0 179a d6b 17e4
98 :3 0 10 :3 0
96 :3 0 179d 179e
0 97 :3 0 179f
17a0 0 17da 71
:3 0 72 :3 0 17a2
17a3 0 71 :3 0
84 :3 0 17a5 17a6
0 99 :2 0 2
:4 0 19e :2 0 86
:2 0 2c :2 0 d6e
17ab 17ad :3 0 d71
17a7 17af 17a4 17b1
17b0 :2 0 74 :3 0
87 :3 0 17b3 17b4
0 76 :4 0 19f
:4 0 79 :2 0 7a
:3 0 d75 17b8 17ba
:3 0 79 :2 0 9c
:4 0 d78 17bc 17be
:3 0 79 :2 0 9d
:4 0 d7b 17c0 17c2
:3 0 79 :2 0 97
:3 0 d7e 17c4 17c6
:3 0 79 :2 0 9e
:4 0 d81 17c8 17ca
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 d84
17cd 17d1 d88 17cc
17d3 :3 0 d8b 17b5
17d5 :2 0 17d7 d8e
17d8 17b2 17d7 0
17d9 d90 0 17da
d92 17dd :3 0 17dd
0 17dd 17dc 17da
17db :6 0 17df 35
:3 0 d95 17e1 d97
17e0 17df :2 0 17e2
d99 :2 0 17e4 0
17e4 17e3 179a 17e2
:6 0 1870 1 :3 0
10 :3 0 96 :3 0
17e6 17e7 0 10
:3 0 a2 :2 0 11a
:3 0 17e9 17eb 0
d9d 17ea 17ed :3 0
17ee :2 0 7e :3 0
44 :3 0 2f :2 0
da0 17f0 17f3 7e
:3 0 e8 :2 0 60
:3 0 2f :2 0 da3
17f5 17f9 da8 17f6
17fb :3 0 17fc :2 0
17ef 17fe 17fd :2 0
71 :3 0 72 :3 0
1800 1801 0 71
:3 0 84 :3 0 1803
1804 0 13 :2 0
2 :4 0 1a0 :2 0
86 :2 0 2c :2 0
dab 1809 180b :3 0
dae 1805 180d 1802
180f 180e :2 0 74
:3 0 87 :3 0 1811
1812 0 76 :4 0
1a1 :4 0 79 :2 0
7a :3 0 db2 1816
1818 :3 0 79 :2 0
9c :4 0 db5 181a
181c :3 0 79 :2 0
dc :4 0 db8 181e
1820 :3 0 79 :2 0
7e :3 0 82 :3 0
dd :3 0 1a2 :3 0
1825 1826 0 dbb
1824 1828 81 :4 0
dbd 1823 182b dc0
1822 182d :3 0 79
:2 0 df :4 0 dc3
182f 1831 :3 0 79
:2 0 7c :4 0 dc6
1833 1835 :3 0 79
:2 0 1d :3 0 dc9
1837 1839 :3 0 79
:2 0 7c :4 0 dcc
183b 183d :3 0 dcf
1813 183f :2 0 1841
dd2 1842 1810 1841
0 1843 dd4 0
186d 71 :3 0 72
:3 0 1844 1845 0
71 :3 0 84 :3 0
1847 1848 0 2c
:2 0 2 :4 0 1a3
:2 0 86 :2 0 2c
:2 0 dd6 184d 184f
:3 0 dd9 1849 1851
1846 1853 1852 :2 0
74 :3 0 87 :3 0
1855 1856 0 76
:4 0 1a4 :4 0 79
:2 0 7a :3 0 ddd
185a 185c :3 0 de0
1857 185e :2 0 1860
de3 1861 1854 1860
0 1862 de5 0
186d e2 :3 0 e3
:3 0 1863 1864 0
dd :3 0 1a2 :3 0
1866 1867 0 1d
:3 0 e4 :3 0 de7
1865 186b :2 0 186d
deb 186e 17ff 186d
0 186f def 0
1870 df1 1871 178e
1870 0 1872 df4
0 190b 43 :3 0
2f :2 0 1873 1874
0 190b 6c :3 0
16d :2 0 1876 1877
0 190b 7e :3 0
50 :3 0 2f :2 0
df6 1879 187c 176
:2 0 1a5 :2 0 dfb
187e 1880 :3 0 50
:3 0 2c :2 0 1882
1883 0 1885 dfe
1886 1881 1885 0
1887 e00 0 190b
c4 :3 0 1a6 :3 0
ad :3 0 44 :3 0
a8 :3 0 aa :3 0
a7 :3 0 ab :3 0
c3 :3 0 f9 :3 0
1a7 :3 0 c3 :3 0
dd :3 0 1a8 :3 0
dd :3 0 1a9 :3 0
c5 :3 0 1c :4 0
1aa 1 :8 0 18b0
110 :4 0 189b :3 0
e4 :3 0 a2 :2 0
e04 189e 189f :3 0
10 :3 0 96 :3 0
18a1 18a2 0 2f
:2 0 18a3 18a4 0
18a6 e07 18ad 10
:3 0 96 :3 0 18a7
18a8 0 111 :2 0
18a9 18aa 0 18ac
e09 18ae 18a0 18a6
0 18af 0 18ac
0 18af e0b 0
18b0 e0e 18fa 98
:3 0 10 :3 0 96
:3 0 18b3 18b4 0
97 :3 0 18b5 18b6
0 18f0 71 :3 0
72 :3 0 18b8 18b9
0 71 :3 0 84
:3 0 18bb 18bc 0
99 :2 0 2 :4 0
1ab :2 0 86 :2 0
2c :2 0 e11 18c1
18c3 :3 0 e14 18bd
18c5 18ba 18c7 18c6
:2 0 74 :3 0 87
:3 0 18c9 18ca 0
76 :4 0 1ac :4 0
79 :2 0 7a :3 0
e18 18ce 18d0 :3 0
79 :2 0 9c :4 0
e1b 18d2 18d4 :3 0
79 :2 0 9d :4 0
e1e 18d6 18d8 :3 0
79 :2 0 97 :3 0
e21 18da 18dc :3 0
79 :2 0 9e :4 0
e24 18de 18e0 :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 e27 18e3
18e7 e2b 18e2 18e9
:3 0 e2e 18cb 18eb
:2 0 18ed e31 18ee
18c8 18ed 0 18ef
e33 0 18f0 e35
18f3 :3 0 18f3 0
18f3 18f2 18f0 18f1
:6 0 18f5 37 :3 0
e38 18f7 e3a 18f6
18f5 :2 0 18f8 e3c
:2 0 18fa 0 18fa
18f9 18b0 18f8 :6 0
190b 1 :3 0 7e
:3 0 42 :3 0 2f
:2 0 e3e 18fc 18ff
e9 :2 0 2f :2 0
e43 1901 1903 :3 0
42 :3 0 2f :2 0
1905 1906 0 1908
e46 1909 1904 1908
0 190a e48 0
190b e4a 190c 1683
190b 0 190e 1091
1676 0 190e e53
0 2241 6c :3 0
e8 :2 0 2f :2 0
e58 1910 1912 :3 0
31 :3 0 f0 :2 0
2c :2 0 e5b 1915
1917 :3 0 1914 1918
0 1bed 5f :3 0
166 :3 0 1f :3 0
3e :3 0 1c :3 0
27 :3 0 29 :3 0
61 :3 0 63 :3 0
31 :3 0 30 :3 0
2e :3 0 e5d 191b
1926 191a 1927 0
1bed 7e :3 0 49
:3 0 2f :2 0 e68
1929 192c e8 :2 0
2f :2 0 e6d 192e
1930 :3 0 1931 :2 0
33 :3 0 ef :2 0
e70 1934 1935 :3 0
1936 :2 0 1937 :2 0
1932 1939 1938 :2 0
60 :3 0 1ad :3 0
1f :3 0 3e :3 0
3f :3 0 1d :3 0
1c :3 0 33 :3 0
49 :3 0 2f :2 0
e72 193c 1945 193b
1946 0 1948 e7b
1949 193a 1948 0
194a e7d 0 1bed
1d :3 0 ef :2 0
e7f 194c 194d :3 0
194e :2 0 5f :3 0
1ae :3 0 1f :3 0
1c :3 0 16d :2 0
e81 1951 1955 1950
1956 0 1958 e85
1979 9f :3 0 2b
:3 0 2c :2 0 2c
:2 0 e87 1959 195d
a2 :2 0 16d :4 0
e8d 195f 1961 :3 0
5f :3 0 1ae :3 0
1f :3 0 1c :3 0
2f :2 0 e90 1964
1968 1963 1969 0
196b e94 1975 5f
:3 0 1ae :3 0 1f
:3 0 1c :3 0 2c
:2 0 e96 196d 1971
196c 1972 0 1974
e9a 1976 1962 196b
0 1977 0 1974
0 1977 e9c 0
1978 e9f 197a 194f
1958 0 197b 0
1978 0 197b ea1
0 1bed 33 :3 0
ef :2 0 ea4 197d
197e :3 0 197f :2 0
7e :3 0 42 :3 0
2f :2 0 ea6 1981
1984 e8 :2 0 2f
:2 0 eab 1986 1988
:3 0 42 :3 0 1af
:3 0 1a7 :3 0 198b
198c 0 7e :3 0
42 :3 0 2f :2 0
eae 198e 1991 dd
:3 0 1b0 :3 0 1993
1994 0 eb1 198d
1996 1997 :2 0 198a
1998 0 19f6 e5
:3 0 f6 :3 0 b6
:3 0 9f :3 0 33
:3 0 e5 :3 0 f8
:3 0 22 :3 0 22
:3 0 100 :4 0 1b1
1 :8 0 19aa 10
:3 0 96 :3 0 19a5
19a6 0 97 :3 0
19a7 19a8 0 19aa
eb4 19f4 98 :3 0
10 :3 0 96 :3 0
19ad 19ae 0 97
:3 0 19af 19b0 0
19ea 71 :3 0 72
:3 0 19b2 19b3 0
71 :3 0 84 :3 0
19b5 19b6 0 99
:2 0 2 :4 0 1b2
:2 0 86 :2 0 2c
:2 0 eb7 19bb 19bd
:3 0 eba 19b7 19bf
19b4 19c1 19c0 :2 0
74 :3 0 87 :3 0
19c3 19c4 0 76
:4 0 1b3 :4 0 79
:2 0 7a :3 0 ebe
19c8 19ca :3 0 79
:2 0 9c :4 0 ec1
19cc 19ce :3 0 79
:2 0 9d :4 0 ec4
19d0 19d2 :3 0 79
:2 0 97 :3 0 ec7
19d4 19d6 :3 0 79
:2 0 9e :4 0 eca
19d8 19da :3 0 79
:2 0 9f :3 0 a0
:3 0 2c :2 0 a1
:2 0 ecd 19dd 19e1
ed1 19dc 19e3 :3 0
ed4 19c5 19e5 :2 0
19e7 ed7 19e8 19c2
19e7 0 19e9 ed9
0 19ea edb 19ed
:3 0 19ed 0 19ed
19ec 19ea 19eb :6 0
19ef 39 :3 0 ede
19f1 ee0 19f0 19ef
:2 0 19f2 ee2 :2 0
19f4 0 19f4 19f3
19aa 19f2 :6 0 19f6
1 :3 0 ee4 1a54
e5 :3 0 f6 :3 0
b6 :3 0 9f :3 0
33 :3 0 e5 :3 0
f8 :3 0 22 :3 0
22 :3 0 100 :4 0
1b4 1 :8 0 1a07
10 :3 0 96 :3 0
1a02 1a03 0 97
:3 0 1a04 1a05 0
1a07 ee7 1a51 98
:3 0 10 :3 0 96
:3 0 1a0a 1a0b 0
97 :3 0 1a0c 1a0d
0 1a47 71 :3 0
72 :3 0 1a0f 1a10
0 71 :3 0 84
:3 0 1a12 1a13 0
99 :2 0 2 :4 0
1b5 :2 0 86 :2 0
2c :2 0 eea 1a18
1a1a :3 0 eed 1a14
1a1c 1a11 1a1e 1a1d
:2 0 74 :3 0 87
:3 0 1a20 1a21 0
76 :4 0 1b6 :4 0
79 :2 0 7a :3 0
ef1 1a25 1a27 :3 0
79 :2 0 9c :4 0
ef4 1a29 1a2b :3 0
79 :2 0 9d :4 0
ef7 1a2d 1a2f :3 0
79 :2 0 97 :3 0
efa 1a31 1a33 :3 0
79 :2 0 9e :4 0
efd 1a35 1a37 :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 f00 1a3a
1a3e f04 1a39 1a40
:3 0 f07 1a22 1a42
:2 0 1a44 f0a 1a45
1a1f 1a44 0 1a46
f0c 0 1a47 f0e
1a4a :3 0 1a4a 0
1a4a 1a49 1a47 1a48
:6 0 1a4c 3b :3 0
f11 1a4e f13 1a4d
1a4c :2 0 1a4f f15
:2 0 1a51 0 1a51
1a50 1a07 1a4f :6 0
1a53 1 :3 0 f17
1a55 1989 19f6 0
1a56 0 1a53 0
1a56 f19 0 1a66
41 :3 0 7e :3 0
41 :3 0 2f :2 0
f1c 1a58 1a5b f0
:2 0 7e :3 0 46
:3 0 2f :2 0 f1f
1a5e 1a61 f22 1a5d
1a63 :3 0 1a57 1a64
0 1a66 f25 1a67
1980 1a66 0 1a68
f28 0 1bed 5e
:3 0 16d :2 0 1a69
1a6a 0 1bed 5f
:3 0 1b7 :3 0 1c
:3 0 22 :3 0 41
:3 0 5e :3 0 42
:3 0 40 :3 0 7e
:3 0 43 :3 0 2f
:2 0 f2a 1a74 1a77
7e :3 0 44 :3 0
2f :2 0 f2d 1a79
1a7c f30 1a6d 1a7e
1a6c 1a7f 0 1bed
7e :3 0 5f :3 0
2f :2 0 f39 1a81
1a84 e9 :2 0 2f
:2 0 f3e 1a86 1a88
:3 0 71 :3 0 72
:3 0 1a8a 1a8b 0
71 :3 0 84 :3 0
1a8d 1a8e 0 13
:2 0 2 :4 0 1b8
:2 0 86 :2 0 2c
:2 0 f41 1a93 1a95
:3 0 f44 1a8f 1a97
1a8c 1a99 1a98 :2 0
74 :3 0 87 :3 0
1a9b 1a9c 0 76
:4 0 1b9 :4 0 79
:2 0 7a :3 0 f48
1aa0 1aa2 :3 0 79
:2 0 9c :4 0 f4b
1aa4 1aa6 :3 0 79
:2 0 dc :4 0 f4e
1aa8 1aaa :3 0 79
:2 0 7e :3 0 82
:3 0 dd :3 0 1a2
:3 0 1aaf 1ab0 0
f51 1aae 1ab2 81
:4 0 f53 1aad 1ab5
f56 1aac 1ab7 :3 0
79 :2 0 df :4 0
f59 1ab9 1abb :3 0
79 :2 0 7c :4 0
f5c 1abd 1abf :3 0
79 :2 0 1c :3 0
f5f 1ac1 1ac3 :3 0
79 :2 0 7c :4 0
f62 1ac5 1ac7 :3 0
f65 1a9d 1ac9 :2 0
1acb f68 1acc 1a9a
1acb 0 1acd f6a
0 1af8 71 :3 0
72 :3 0 1ace 1acf
0 71 :3 0 84
:3 0 1ad1 1ad2 0
2c :2 0 2 :4 0
1ba :2 0 86 :2 0
2c :2 0 f6c 1ad7
1ad9 :3 0 f6f 1ad3
1adb 1ad0 1add 1adc
:2 0 74 :3 0 87
:3 0 1adf 1ae0 0
76 :4 0 1bb :4 0
79 :2 0 7a :3 0
f73 1ae4 1ae6 :3 0
f76 1ae1 1ae8 :2 0
1aea f79 1aeb 1ade
1aea 0 1aec f7b
0 1af8 e2 :3 0
e3 :3 0 1aed 1aee
0 dd :3 0 1a2
:3 0 1af0 1af1 0
1c :3 0 e4 :3 0
f7d 1aef 1af5 :2 0
1af8 132 :3 0 f81
1b78 6c :3 0 a2
:2 0 2c :2 0 f87
1afa 1afc :3 0 c4
:3 0 1a6 :3 0 c3
:3 0 f9 :3 0 1a7
:3 0 c3 :3 0 dd
:3 0 1a8 :3 0 dd
:3 0 1a9 :3 0 1bc
:3 0 7e :3 0 10c
:3 0 114 :3 0 1bd
:3 0 7e :3 0 10d
:3 0 115 :3 0 1be
:3 0 1bf :3 0 c5
:3 0 1c :4 0 1c0
1 :8 0 1b2a 110
:4 0 1b15 :3 0 e4
:3 0 a2 :2 0 f8c
1b18 1b19 :3 0 10
:3 0 96 :3 0 1b1b
1b1c 0 2f :2 0
1b1d 1b1e 0 1b20
f8f 1b27 10 :3 0
96 :3 0 1b21 1b22
0 111 :2 0 1b23
1b24 0 1b26 f91
1b28 1b1a 1b20 0
1b29 0 1b26 0
1b29 f93 0 1b2a
f96 1b74 98 :3 0
10 :3 0 96 :3 0
1b2d 1b2e 0 97
:3 0 1b2f 1b30 0
1b6a 71 :3 0 72
:3 0 1b32 1b33 0
71 :3 0 84 :3 0
1b35 1b36 0 99
:2 0 2 :4 0 1c1
:2 0 86 :2 0 2c
:2 0 f99 1b3b 1b3d
:3 0 f9c 1b37 1b3f
1b34 1b41 1b40 :2 0
74 :3 0 87 :3 0
1b43 1b44 0 76
:4 0 1c2 :4 0 79
:2 0 7a :3 0 fa0
1b48 1b4a :3 0 79
:2 0 9c :4 0 fa3
1b4c 1b4e :3 0 79
:2 0 9d :4 0 fa6
1b50 1b52 :3 0 79
:2 0 97 :3 0 fa9
1b54 1b56 :3 0 79
:2 0 9e :4 0 fac
1b58 1b5a :3 0 79
:2 0 9f :3 0 a0
:3 0 2c :2 0 a1
:2 0 faf 1b5d 1b61
fb3 1b5c 1b63 :3 0
fb6 1b45 1b65 :2 0
1b67 fb9 1b68 1b42
1b67 0 1b69 fbb
0 1b6a fbd 1b6d
:3 0 1b6d 0 1b6d
1b6c 1b6a 1b6b :6 0
1b6f 3d :3 0 fc0
1b71 fc2 1b70 1b6f
:2 0 1b72 fc4 :2 0
1b74 0 1b74 1b73
1b2a 1b72 :6 0 1b76
1 :3 0 fc6 1b77
1afd 1b76 0 1b79
1a89 1af8 0 1b79
fc8 0 1bed 60
:3 0 11b :3 0 1f
:3 0 fcb 1b7b 1b7d
1b7a 1b7e 0 1bed
71 :3 0 72 :3 0
1b80 1b81 0 71
:3 0 84 :3 0 1b83
1b84 0 13 :2 0
2 :4 0 1c3 :2 0
86 :2 0 2c :2 0
fcd 1b89 1b8b :3 0
fd0 1b85 1b8d 1b82
1b8f 1b8e :2 0 74
:3 0 87 :3 0 1b91
1b92 0 76 :4 0
1c4 :4 0 79 :2 0
7a :3 0 fd4 1b96
1b98 :3 0 79 :2 0
9c :4 0 fd7 1b9a
1b9c :3 0 79 :2 0
dc :4 0 fda 1b9e
1ba0 :3 0 79 :2 0
7e :3 0 82 :3 0
60 :3 0 fdd 1ba4
1ba6 81 :4 0 fdf
1ba3 1ba9 fe2 1ba2
1bab :3 0 79 :2 0
df :4 0 fe5 1bad
1baf :3 0 79 :2 0
7c :4 0 fe8 1bb1
1bb3 :3 0 79 :2 0
1c :3 0 feb 1bb5
1bb7 :3 0 79 :2 0
7c :4 0 fee 1bb9
1bbb :3 0 ff1 1b93
1bbd :2 0 1bbf ff4
1bc0 1b90 1bbf 0
1bc1 ff6 0 1bed
71 :3 0 72 :3 0
1bc2 1bc3 0 71
:3 0 84 :3 0 1bc5
1bc6 0 2c :2 0
2 :4 0 1c5 :2 0
86 :2 0 2c :2 0
ff8 1bcb 1bcd :3 0
ffb 1bc7 1bcf 1bc4
1bd1 1bd0 :2 0 74
:3 0 87 :3 0 1bd3
1bd4 0 76 :4 0
1c6 :4 0 79 :2 0
7a :3 0 fff 1bd8
1bda :3 0 1002 1bd5
1bdc :2 0 1bde 1005
1bdf 1bd2 1bde 0
1be0 1007 0 1bed
e2 :3 0 e3 :3 0
1be1 1be2 0 7e
:3 0 60 :3 0 2f
:2 0 1009 1be4 1be7
1c :3 0 e4 :3 0
100c 1be3 1beb :2 0
1bed 1010 1bee 1913
1bed 0 1bef 101d
0 2241 7e :3 0
d :3 0 2f :2 0
101f 1bf0 1bf3 7e
:3 0 e9 :2 0 46
:3 0 2f :2 0 1022
1bf5 1bf9 1027 1bf6
1bfb :3 0 11c :3 0
60 :3 0 100 :3 0
8d :3 0 13c :3 0
c5 :3 0 1c :3 0
c5 :3 0 8d :3 0
13d :3 0 dd :3 0
13e :4 0 1c7 1
:8 0 1c0f 10 :3 0
96 :3 0 1c0a 1c0b
0 97 :3 0 1c0c
1c0d 0 1c0f 102a
1c59 98 :3 0 10
:3 0 96 :3 0 1c12
1c13 0 97 :3 0
1c14 1c15 0 1c4f
71 :3 0 72 :3 0
1c17 1c18 0 71
:3 0 84 :3 0 1c1a
1c1b 0 99 :2 0
2 :4 0 1c8 :2 0
86 :2 0 2c :2 0
102d 1c20 1c22 :3 0
1030 1c1c 1c24 1c19
1c26 1c25 :2 0 74
:3 0 87 :3 0 1c28
1c29 0 76 :4 0
1c9 :4 0 79 :2 0
7a :3 0 1034 1c2d
1c2f :3 0 79 :2 0
9c :4 0 1037 1c31
1c33 :3 0 79 :2 0
9d :4 0 103a 1c35
1c37 :3 0 79 :2 0
97 :3 0 103d 1c39
1c3b :3 0 79 :2 0
9e :4 0 1040 1c3d
1c3f :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
1043 1c42 1c46 1047
1c41 1c48 :3 0 104a
1c2a 1c4a :2 0 1c4c
104d 1c4d 1c27 1c4c
0 1c4e 104f 0
1c4f 1051 1c52 :3 0
1c52 0 1c52 1c51
1c4f 1c50 :6 0 1c54
3f :3 0 1054 1c56
1056 1c55 1c54 :2 0
1c57 1058 :2 0 1c59
0 1c59 1c58 1c0f
1c57 :6 0 205c 1
:3 0 7e :3 0 60
:3 0 2f :2 0 105a
1c5b 1c5e e8 :2 0
2f :2 0 105f 1c60
1c62 :3 0 71 :3 0
72 :3 0 1c64 1c65
0 71 :3 0 84
:3 0 1c67 1c68 0
13 :2 0 2 :4 0
1ca :2 0 86 :2 0
2c :2 0 1062 1c6d
1c6f :3 0 1065 1c69
1c71 1c66 1c73 1c72
:2 0 74 :3 0 87
:3 0 1c75 1c76 0
76 :4 0 1cb :4 0
79 :2 0 7a :3 0
1069 1c7a 1c7c :3 0
79 :2 0 9c :4 0
106c 1c7e 1c80 :3 0
79 :2 0 dc :4 0
106f 1c82 1c84 :3 0
79 :2 0 7e :3 0
82 :3 0 dd :3 0
144 :3 0 1c89 1c8a
0 1072 1c88 1c8c
81 :4 0 1074 1c87
1c8f 1077 1c86 1c91
:3 0 79 :2 0 df
:4 0 107a 1c93 1c95
:3 0 79 :2 0 7c
:4 0 107d 1c97 1c99
:3 0 79 :2 0 1c
:3 0 1080 1c9b 1c9d
:3 0 79 :2 0 7c
:4 0 1083 1c9f 1ca1
:3 0 1086 1c77 1ca3
:2 0 1ca5 1089 1ca6
1c74 1ca5 0 1ca7
108b 0 1cd1 71
:3 0 72 :3 0 1ca8
1ca9 0 71 :3 0
84 :3 0 1cab 1cac
0 2c :2 0 2
:4 0 1cc :2 0 86
:2 0 2c :2 0 108d
1cb1 1cb3 :3 0 1090
1cad 1cb5 1caa 1cb7
1cb6 :2 0 74 :3 0
87 :3 0 1cb9 1cba
0 76 :4 0 1cd
:4 0 79 :2 0 7a
:3 0 1094 1cbe 1cc0
:3 0 1097 1cbb 1cc2
:2 0 1cc4 109a 1cc5
1cb8 1cc4 0 1cc6
109c 0 1cd1 e2
:3 0 e3 :3 0 1cc7
1cc8 0 dd :3 0
144 :3 0 1cca 1ccb
0 1c :3 0 e4
:3 0 109e 1cc9 1ccf
:2 0 1cd1 10a2 1cd2
1c63 1cd1 0 1cd3
10a6 0 205c 47
:3 0 d :3 0 1cd4
1cd5 0 205c 54
:3 0 7e :3 0 41
:3 0 2f :2 0 10a8
1cd8 1cdb 1cd7 1cdc
0 205c 7e :3 0
47 :3 0 2f :2 0
10ab 1cde 1ce1 7e
:3 0 e8 :2 0 41
:3 0 2f :2 0 10ae
1ce3 1ce7 10b3 1ce4
1ce9 :3 0 31 :3 0
f0 :2 0 2c :2 0
10b6 1cec 1cee :3 0
1ceb 1cef 0 1fac
5f :3 0 166 :3 0
1f :3 0 3e :3 0
1c :3 0 27 :3 0
29 :3 0 61 :3 0
63 :3 0 31 :3 0
30 :3 0 2e :3 0
10b8 1cf2 1cfd 1cf1
1cfe 0 1fac 1d
:3 0 ef :2 0 10c3
1d01 1d02 :3 0 1d03
:2 0 5f :3 0 1ae
:3 0 1f :3 0 1c
:3 0 16d :2 0 10c5
1d06 1d0a 1d05 1d0b
0 1d0d 10c9 1d2e
9f :3 0 2b :3 0
2c :2 0 2c :2 0
10cb 1d0e 1d12 a2
:2 0 16d :4 0 10d1
1d14 1d16 :3 0 5f
:3 0 1ae :3 0 1f
:3 0 1c :3 0 2f
:2 0 10d4 1d19 1d1d
1d18 1d1e 0 1d20
10d8 1d2a 5f :3 0
1ae :3 0 1f :3 0
1c :3 0 2c :2 0
10da 1d22 1d26 1d21
1d27 0 1d29 10de
1d2b 1d17 1d20 0
1d2c 0 1d29 0
1d2c 10e0 0 1d2d
10e3 1d2f 1d04 1d0d
0 1d30 0 1d2d
0 1d30 10e5 0
1fac 4a :3 0 2f
:2 0 1d31 1d32 0
1fac 33 :3 0 ef
:2 0 10e8 1d35 1d36
:3 0 1d37 :2 0 7e
:3 0 42 :3 0 2f
:2 0 10ea 1d39 1d3c
e8 :2 0 2f :2 0
10ef 1d3e 1d40 :3 0
42 :3 0 1af :3 0
1a7 :3 0 1d43 1d44
0 7e :3 0 42
:3 0 2f :2 0 10f2
1d46 1d49 dd :3 0
1b0 :3 0 1d4b 1d4c
0 10f5 1d45 1d4e
1d4f :2 0 1d42 1d50
0 1dae e5 :3 0
f6 :3 0 b6 :3 0
9f :3 0 33 :3 0
e5 :3 0 f8 :3 0
22 :3 0 22 :3 0
100 :4 0 1ce 1
:8 0 1d62 10 :3 0
96 :3 0 1d5d 1d5e
0 97 :3 0 1d5f
1d60 0 1d62 10f8
1dac 98 :3 0 10
:3 0 96 :3 0 1d65
1d66 0 97 :3 0
1d67 1d68 0 1da2
71 :3 0 72 :3 0
1d6a 1d6b 0 71
:3 0 84 :3 0 1d6d
1d6e 0 99 :2 0
2 :4 0 1cf :2 0
86 :2 0 2c :2 0
10fb 1d73 1d75 :3 0
10fe 1d6f 1d77 1d6c
1d79 1d78 :2 0 74
:3 0 87 :3 0 1d7b
1d7c 0 76 :4 0
1d0 :4 0 79 :2 0
7a :3 0 1102 1d80
1d82 :3 0 79 :2 0
9c :4 0 1105 1d84
1d86 :3 0 79 :2 0
9d :4 0 1108 1d88
1d8a :3 0 79 :2 0
97 :3 0 110b 1d8c
1d8e :3 0 79 :2 0
9e :4 0 110e 1d90
1d92 :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
1111 1d95 1d99 1115
1d94 1d9b :3 0 1118
1d7d 1d9d :2 0 1d9f
111b 1da0 1d7a 1d9f
0 1da1 111d 0
1da2 111f 1da5 :3 0
1da5 0 1da5 1da4
1da2 1da3 :6 0 1da7
41 :3 0 1122 1da9
1124 1da8 1da7 :2 0
1daa 1126 :2 0 1dac
0 1dac 1dab 1d62
1daa :6 0 1dae 1
:3 0 1128 1e0c e5
:3 0 f6 :3 0 b6
:3 0 9f :3 0 33
:3 0 e5 :3 0 f8
:3 0 22 :3 0 22
:3 0 100 :4 0 1d1
1 :8 0 1dbf 10
:3 0 96 :3 0 1dba
1dbb 0 97 :3 0
1dbc 1dbd 0 1dbf
112b 1e09 98 :3 0
10 :3 0 96 :3 0
1dc2 1dc3 0 97
:3 0 1dc4 1dc5 0
1dff 71 :3 0 72
:3 0 1dc7 1dc8 0
71 :3 0 84 :3 0
1dca 1dcb 0 99
:2 0 2 :4 0 1d2
:2 0 86 :2 0 2c
:2 0 112e 1dd0 1dd2
:3 0 1131 1dcc 1dd4
1dc9 1dd6 1dd5 :2 0
74 :3 0 87 :3 0
1dd8 1dd9 0 76
:4 0 1d3 :4 0 79
:2 0 7a :3 0 1135
1ddd 1ddf :3 0 79
:2 0 9c :4 0 1138
1de1 1de3 :3 0 79
:2 0 9d :4 0 113b
1de5 1de7 :3 0 79
:2 0 97 :3 0 113e
1de9 1deb :3 0 79
:2 0 9e :4 0 1141
1ded 1def :3 0 79
:2 0 9f :3 0 a0
:3 0 2c :2 0 a1
:2 0 1144 1df2 1df6
1148 1df1 1df8 :3 0
114b 1dda 1dfa :2 0
1dfc 114e 1dfd 1dd7
1dfc 0 1dfe 1150
0 1dff 1152 1e02
:3 0 1e02 0 1e02
1e01 1dff 1e00 :6 0
1e04 43 :3 0 1155
1e06 1157 1e05 1e04
:2 0 1e07 1159 :2 0
1e09 0 1e09 1e08
1dbf 1e07 :6 0 1e0b
1 :3 0 115b 1e0d
1d41 1dae 0 1e0e
0 1e0b 0 1e0e
115d 0 1e79 7e
:3 0 49 :3 0 2f
:2 0 1160 1e0f 1e12
e8 :2 0 2f :2 0
1165 1e14 1e16 :3 0
168 :3 0 169 :3 0
4a :3 0 167 :3 0
92 :3 0 1f :3 0
c5 :3 0 1c :3 0
f7 :3 0 b6 :3 0
9f :3 0 33 :4 0
1d4 1 :8 0 1e2a
10 :3 0 96 :3 0
1e25 1e26 0 97
:3 0 1e27 1e28 0
1e2a 1168 1e74 98
:3 0 10 :3 0 96
:3 0 1e2d 1e2e 0
97 :3 0 1e2f 1e30
0 1e6a 71 :3 0
72 :3 0 1e32 1e33
0 71 :3 0 84
:3 0 1e35 1e36 0
99 :2 0 2 :4 0
1d5 :2 0 86 :2 0
2c :2 0 116b 1e3b
1e3d :3 0 116e 1e37
1e3f 1e34 1e41 1e40
:2 0 74 :3 0 87
:3 0 1e43 1e44 0
76 :4 0 1d6 :4 0
79 :2 0 7a :3 0
1172 1e48 1e4a :3 0
79 :2 0 9c :4 0
1175 1e4c 1e4e :3 0
79 :2 0 9d :4 0
1178 1e50 1e52 :3 0
79 :2 0 97 :3 0
117b 1e54 1e56 :3 0
79 :2 0 9e :4 0
117e 1e58 1e5a :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 1181 1e5d
1e61 1185 1e5c 1e63
:3 0 1188 1e45 1e65
:2 0 1e67 118b 1e68
1e42 1e67 0 1e69
118d 0 1e6a 118f
1e6d :3 0 1e6d 0
1e6d 1e6c 1e6a 1e6b
:6 0 1e6f 45 :3 0
1192 1e71 1194 1e70
1e6f :2 0 1e72 1196
:2 0 1e74 0 1e74
1e73 1e2a 1e72 :6 0
1e76 1 :3 0 1198
1e77 1e17 1e76 0
1e78 119a 0 1e79
119c 1e7a 1d38 1e79
0 1e7b 119f 0
1fac 41 :3 0 7e
:3 0 47 :3 0 2f
:2 0 11a1 1e7d 1e80
f0 :2 0 7e :3 0
46 :3 0 2f :2 0
11a4 1e83 1e86 11a7
1e82 1e88 :3 0 f0
:2 0 7e :3 0 4a
:3 0 2f :2 0 11aa
1e8b 1e8e 11ad 1e8a
1e90 :3 0 1e7c 1e91
0 1fac 45 :3 0
1d7 :2 0 1e93 1e94
0 1fac c4 :3 0
1a6 :3 0 c3 :3 0
f9 :3 0 1a7 :3 0
c3 :3 0 dd :3 0
1a8 :3 0 b3 :3 0
47 :3 0 af :3 0
47 :3 0 d3 :3 0
c1 :3 0 d4 :3 0
d5 :3 0 1d8 :3 0
c5 :3 0 1c :4 0
1d9 1 :8 0 1ebf
110 :4 0 1eaa :3 0
e4 :3 0 a2 :2 0
11b2 1ead 1eae :3 0
10 :3 0 96 :3 0
1eb0 1eb1 0 2f
:2 0 1eb2 1eb3 0
1eb5 11b5 1ebc 10
:3 0 96 :3 0 1eb6
1eb7 0 111 :2 0
1eb8 1eb9 0 1ebb
11b7 1ebd 1eaf 1eb5
0 1ebe 0 1ebb
0 1ebe 11b9 0
1ebf 11bc 1f09 98
:3 0 10 :3 0 96
:3 0 1ec2 1ec3 0
97 :3 0 1ec4 1ec5
0 1eff 71 :3 0
72 :3 0 1ec7 1ec8
0 71 :3 0 84
:3 0 1eca 1ecb 0
99 :2 0 2 :4 0
1da :2 0 86 :2 0
2c :2 0 11bf 1ed0
1ed2 :3 0 11c2 1ecc
1ed4 1ec9 1ed6 1ed5
:2 0 74 :3 0 87
:3 0 1ed8 1ed9 0
76 :4 0 1db :4 0
79 :2 0 7a :3 0
11c6 1edd 1edf :3 0
79 :2 0 9c :4 0
11c9 1ee1 1ee3 :3 0
79 :2 0 9d :4 0
11cc 1ee5 1ee7 :3 0
79 :2 0 97 :3 0
11cf 1ee9 1eeb :3 0
79 :2 0 9e :4 0
11d2 1eed 1eef :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 11d5 1ef2
1ef6 11d9 1ef1 1ef8
:3 0 11dc 1eda 1efa
:2 0 1efc 11df 1efd
1ed7 1efc 0 1efe
11e1 0 1eff 11e3
1f02 :3 0 1f02 0
1f02 1f01 1eff 1f00
:6 0 1f04 47 :3 0
11e6 1f06 11e8 1f05
1f04 :2 0 1f07 11ea
:2 0 1f09 0 1f09
1f08 1ebf 1f07 :6 0
1fac 1 :3 0 10
:3 0 96 :3 0 1f0b
1f0c 0 10 :3 0
a2 :2 0 11a :3 0
1f0e 1f10 0 11ee
1f0f 1f12 :3 0 1f13
:2 0 5e :3 0 16d
:2 0 1f15 1f16 0
1fa2 60 :3 0 1b7
:3 0 1c :3 0 22
:3 0 41 :3 0 5e
:3 0 42 :3 0 40
:3 0 2f :2 0 7e
:3 0 44 :3 0 2f
:2 0 11f1 1f21 1f24
11f4 1f19 1f26 1f18
1f27 0 1fa2 7e
:3 0 60 :3 0 2f
:2 0 11fd 1f29 1f2c
e9 :2 0 2f :2 0
1202 1f2e 1f30 :3 0
71 :3 0 72 :3 0
1f32 1f33 0 71
:3 0 84 :3 0 1f35
1f36 0 13 :2 0
2 :4 0 1dc :2 0
86 :2 0 2c :2 0
1205 1f3b 1f3d :3 0
1208 1f37 1f3f 1f34
1f41 1f40 :2 0 74
:3 0 87 :3 0 1f43
1f44 0 76 :4 0
1dd :4 0 79 :2 0
7a :3 0 120c 1f48
1f4a :3 0 79 :2 0
9c :4 0 120f 1f4c
1f4e :3 0 79 :2 0
dc :4 0 1212 1f50
1f52 :3 0 79 :2 0
7e :3 0 82 :3 0
60 :3 0 1215 1f56
1f58 81 :4 0 1217
1f55 1f5b 121a 1f54
1f5d :3 0 79 :2 0
df :4 0 121d 1f5f
1f61 :3 0 79 :2 0
7c :4 0 1220 1f63
1f65 :3 0 79 :2 0
1c :3 0 1223 1f67
1f69 :3 0 79 :2 0
7c :4 0 1226 1f6b
1f6d :3 0 1229 1f45
1f6f :2 0 1f71 122c
1f72 1f42 1f71 0
1f73 122e 0 1f9f
71 :3 0 72 :3 0
1f74 1f75 0 71
:3 0 84 :3 0 1f77
1f78 0 2c :2 0
2 :4 0 1de :2 0
86 :2 0 2c :2 0
1230 1f7d 1f7f :3 0
1233 1f79 1f81 1f76
1f83 1f82 :2 0 74
:3 0 87 :3 0 1f85
1f86 0 76 :4 0
1df :4 0 79 :2 0
7a :3 0 1237 1f8a
1f8c :3 0 123a 1f87
1f8e :2 0 1f90 123d
1f91 1f84 1f90 0
1f92 123f 0 1f9f
e2 :3 0 e3 :3 0
1f93 1f94 0 7e
:3 0 60 :3 0 2f
:2 0 1241 1f96 1f99
1c :3 0 e4 :3 0
1244 1f95 1f9d :2 0
1f9f 1248 1fa0 1f31
1f9f 0 1fa1 124c
0 1fa2 124e 1fa3
1f14 1fa2 0 1fa4
1252 0 1fac 41
:3 0 7e :3 0 47
:3 0 2f :2 0 1254
1fa6 1fa9 1fa5 1faa
0 1fac 1257 1fca
45 :3 0 1e0 :3 0
7e :3 0 47 :3 0
2f :2 0 1262 1faf
1fb2 1e1 :2 0 7e
:3 0 41 :3 0 2f
:2 0 1265 1fb5 1fb8
1268 1fb4 1fba :3 0
1fbb :2 0 1e2 :2 0
1e3 :2 0 126b 1fbd
1fbf :3 0 1fc0 :2 0
86 :2 0 1e4 :2 0
126e 1fc2 1fc4 :3 0
1271 1fae 1fc6 1fad
1fc7 0 1fc9 1273
1fcb 1cea 1fac 0
1fcc 0 1fc9 0
1fcc 1275 0 205c
60 :3 0 1e5 :3 0
1f :3 0 3e :3 0
3f :3 0 1c :3 0
33 :3 0 2b :3 0
41 :3 0 47 :3 0
54 :3 0 46 :3 0
45 :3 0 61 :3 0
64 :3 0 63 :3 0
65 :3 0 66 :3 0
68 :3 0 67 :3 0
69 :3 0 30 :3 0
2e :3 0 49 :3 0
40 :3 0 7e :3 0
4c :3 0 2f :2 0
1278 1fe6 1fe9 127b
1fce 1feb 1fcd 1fec
0 205c 71 :3 0
72 :3 0 1fee 1fef
0 71 :3 0 84
:3 0 1ff1 1ff2 0
13 :2 0 2 :4 0
1e6 :2 0 86 :2 0
2c :2 0 1294 1ff7
1ff9 :3 0 1297 1ff3
1ffb 1ff0 1ffd 1ffc
:2 0 74 :3 0 87
:3 0 1fff 2000 0
76 :4 0 1e7 :4 0
79 :2 0 7a :3 0
129b 2004 2006 :3 0
79 :2 0 9c :4 0
129e 2008 200a :3 0
79 :2 0 dc :4 0
12a1 200c 200e :3 0
79 :2 0 7e :3 0
82 :3 0 60 :3 0
12a4 2012 2014 81
:4 0 12a6 2011 2017
12a9 2010 2019 :3 0
79 :2 0 df :4 0
12ac 201b 201d :3 0
79 :2 0 7c :4 0
12af 201f 2021 :3 0
79 :2 0 1c :3 0
12b2 2023 2025 :3 0
79 :2 0 7c :4 0
12b5 2027 2029 :3 0
12b8 2001 202b :2 0
202d 12bb 202e 1ffe
202d 0 202f 12bd
0 205c 71 :3 0
72 :3 0 2030 2031
0 71 :3 0 84
:3 0 2033 2034 0
2c :2 0 2 :4 0
1e8 :2 0 86 :2 0
2c :2 0 12bf 2039
203b :3 0 12c2 2035
203d 2032 203f 203e
:2 0 74 :3 0 87
:3 0 2041 2042 0
76 :4 0 1e9 :4 0
79 :2 0 7a :3 0
12c6 2046 2048 :3 0
12c9 2043 204a :2 0
204c 12cc 204d 2040
204c 0 204e 12ce
0 205c e2 :3 0
e3 :3 0 204f 2050
0 7e :3 0 60
:3 0 2f :2 0 12d0
2052 2055 1c :3 0
e4 :3 0 12d3 2051
2059 :2 0 205c 132
:3 0 12d7 21cc 7e
:3 0 c :3 0 2f
:2 0 12e1 205d 2060
7e :3 0 e9 :2 0
45 :3 0 2f :2 0
12e4 2062 2066 12e9
2063 2068 :3 0 7e
:3 0 46 :3 0 2f
:2 0 12ec 206a 206d
e8 :2 0 2f :2 0
12f1 206f 2071 :3 0
2072 :2 0 7e :3 0
c :3 0 2f :2 0
12f4 2074 2077 a2
:2 0 2f :2 0 12f9
2079 207b :3 0 207c
:2 0 2073 207e 207d
:2 0 71 :3 0 72
:3 0 2080 2081 0
71 :3 0 84 :3 0
2083 2084 0 13
:2 0 2 :4 0 1ea
:2 0 86 :2 0 2c
:2 0 12fc 2089 208b
:3 0 12ff 2085 208d
2082 208f 208e :2 0
74 :3 0 87 :3 0
2091 2092 0 76
:4 0 1eb :4 0 79
:2 0 7a :3 0 1303
2096 2098 :3 0 79
:2 0 9c :4 0 1306
209a 209c :3 0 79
:2 0 dc :4 0 1309
209e 20a0 :3 0 79
:2 0 7e :3 0 82
:3 0 10 :3 0 96
:3 0 20a5 20a6 0
130c 20a4 20a8 81
:4 0 130e 20a3 20ab
1311 20a2 20ad :3 0
79 :2 0 df :4 0
1314 20af 20b1 :3 0
79 :2 0 7c :4 0
1317 20b3 20b5 :3 0
79 :2 0 1c :3 0
131a 20b7 20b9 :3 0
79 :2 0 7c :4 0
131d 20bb 20bd :3 0
1320 2093 20bf :2 0
20c1 1323 20c2 2090
20c1 0 20c3 1325
0 20ed 71 :3 0
72 :3 0 20c4 20c5
0 71 :3 0 84
:3 0 20c7 20c8 0
2c :2 0 2 :4 0
1ec :2 0 86 :2 0
2c :2 0 1327 20cd
20cf :3 0 132a 20c9
20d1 20c6 20d3 20d2
:2 0 74 :3 0 87
:3 0 20d5 20d6 0
76 :4 0 1ed :4 0
79 :2 0 7a :3 0
132e 20da 20dc :3 0
1331 20d7 20de :2 0
20e0 1334 20e1 20d4
20e0 0 20e2 1336
0 20ed e2 :3 0
e3 :3 0 20e3 20e4
0 10 :3 0 96
:3 0 20e6 20e7 0
1c :3 0 e4 :3 0
1338 20e5 20eb :2 0
20ed 133c 20ee 207f
20ed 0 20ef 1340
0 21ca c4 :3 0
c1 :3 0 c :3 0
c3 :3 0 f9 :3 0
1a7 :3 0 c3 :3 0
dd :3 0 1ee :3 0
c5 :3 0 1c :4 0
1ef 1 :8 0 2111
110 :4 0 20fc :3 0
e4 :3 0 a2 :2 0
1344 20ff 2100 :3 0
10 :3 0 96 :3 0
2102 2103 0 2f
:2 0 2104 2105 0
2107 1347 210e 10
:3 0 96 :3 0 2108
2109 0 111 :2 0
210a 210b 0 210d
1349 210f 2101 2107
0 2110 0 210d
0 2110 134b 0
2111 134e 215b 98
:3 0 10 :3 0 96
:3 0 2114 2115 0
97 :3 0 2116 2117
0 2151 71 :3 0
72 :3 0 2119 211a
0 71 :3 0 84
:3 0 211c 211d 0
99 :2 0 2 :4 0
1f0 :2 0 86 :2 0
2c :2 0 1351 2122
2124 :3 0 1354 211e
2126 211b 2128 2127
:2 0 74 :3 0 87
:3 0 212a 212b 0
76 :4 0 1f1 :4 0
79 :2 0 7a :3 0
1358 212f 2131 :3 0
79 :2 0 9c :4 0
135b 2133 2135 :3 0
79 :2 0 9d :4 0
135e 2137 2139 :3 0
79 :2 0 97 :3 0
1361 213b 213d :3 0
79 :2 0 9e :4 0
1364 213f 2141 :3 0
79 :2 0 9f :3 0
a0 :3 0 2c :2 0
a1 :2 0 1367 2144
2148 136b 2143 214a
:3 0 136e 212c 214c
:2 0 214e 1371 214f
2129 214e 0 2150
1373 0 2151 1375
2154 :3 0 2154 0
2154 2153 2151 2152
:6 0 2156 49 :3 0
1378 2158 137a 2157
2156 :2 0 2159 137c
:2 0 215b 0 215b
215a 2111 2159 :6 0
21ca 1 :3 0 d6
:3 0 c3 :3 0 f9
:3 0 1a7 :3 0 c3
:3 0 dd :3 0 1ee
:3 0 92 :3 0 1f
:3 0 8d :3 0 3e
:4 0 1f2 1 :8 0
217e 110 :4 0 2169
:3 0 e4 :3 0 a2
:2 0 1380 216c 216d
:3 0 10 :3 0 96
:3 0 216f 2170 0
2f :2 0 2171 2172
0 2174 1383 217b
10 :3 0 96 :3 0
2175 2176 0 111
:2 0 2177 2178 0
217a 1385 217c 216e
2174 0 217d 0
217a 0 217d 1387
0 217e 138a 21c8
98 :3 0 10 :3 0
96 :3 0 2181 2182
0 97 :3 0 2183
2184 0 21be 71
:3 0 72 :3 0 2186
2187 0 71 :3 0
84 :3 0 2189 218a
0 99 :2 0 2
:4 0 1f3 :2 0 86
:2 0 2c :2 0 138d
218f 2191 :3 0 1390
218b 2193 2188 2195
2194 :2 0 74 :3 0
87 :3 0 2197 2198
0 76 :4 0 1f4
:4 0 79 :2 0 7a
:3 0 1394 219c 219e
:3 0 79 :2 0 9c
:4 0 1397 21a0 21a2
:3 0 79 :2 0 9d
:4 0 139a 21a4 21a6
:3 0 79 :2 0 97
:3 0 139d 21a8 21aa
:3 0 79 :2 0 9e
:4 0 13a0 21ac 21ae
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 13a3
21b1 21b5 13a7 21b0
21b7 :3 0 13aa 2199
21b9 :2 0 21bb 13ad
21bc 2196 21bb 0
21bd 13af 0 21be
13b1 21c1 :3 0 21c1
0 21c1 21c0 21be
21bf :6 0 21c3 4b
:3 0 13b4 21c5 13b6
21c4 21c3 :2 0 21c6
13b8 :2 0 21c8 0
21c8 21c7 217e 21c6
:6 0 21ca 1 :3 0
13ba 21cb 2069 21ca
0 21cd 1bfc 205c
0 21cd 13be 0
2241 60 :3 0 11b
:3 0 1f :3 0 13c1
21cf 21d1 21ce 21d2
0 2241 71 :3 0
72 :3 0 21d4 21d5
0 71 :3 0 84
:3 0 21d7 21d8 0
13 :2 0 2 :4 0
1f5 :2 0 86 :2 0
2c :2 0 13c3 21dd
21df :3 0 13c6 21d9
21e1 21d6 21e3 21e2
:2 0 74 :3 0 87
:3 0 21e5 21e6 0
76 :4 0 1f6 :4 0
79 :2 0 7a :3 0
13ca 21ea 21ec :3 0
79 :2 0 9c :4 0
13cd 21ee 21f0 :3 0
79 :2 0 dc :4 0
13d0 21f2 21f4 :3 0
79 :2 0 7e :3 0
82 :3 0 60 :3 0
13d3 21f8 21fa 81
:4 0 13d5 21f7 21fd
13d8 21f6 21ff :3 0
79 :2 0 df :4 0
13db 2201 2203 :3 0
79 :2 0 7c :4 0
13de 2205 2207 :3 0
79 :2 0 1c :3 0
13e1 2209 220b :3 0
79 :2 0 7c :4 0
13e4 220d 220f :3 0
13e7 21e7 2211 :2 0
2213 13ea 2214 21e4
2213 0 2215 13ec
0 2241 71 :3 0
72 :3 0 2216 2217
0 71 :3 0 84
:3 0 2219 221a 0
2c :2 0 2 :4 0
1f7 :2 0 86 :2 0
2c :2 0 13ee 221f
2221 :3 0 13f1 221b
2223 2218 2225 2224
:2 0 74 :3 0 87
:3 0 2227 2228 0
76 :4 0 1f8 :4 0
79 :2 0 7a :3 0
13f5 222c 222e :3 0
13f8 2229 2230 :2 0
2232 13fb 2233 2226
2232 0 2234 13fd
0 2241 e2 :3 0
e3 :3 0 2235 2236
0 7e :3 0 60
:3 0 2f :2 0 13ff
2238 223b 1c :3 0
e4 :3 0 1402 2237
223f :2 0 2241 1406
2242 f5b 2241 0
23b5 8a :3 0 1f9
:3 0 8a :3 0 8c
:3 0 8a :3 0 8d
:3 0 8a :3 0 8e
:3 0 8a :3 0 8f
:3 0 8a :3 0 90
:3 0 8a :3 0 91
:3 0 8a :3 0 92
:3 0 8a :3 0 93
:3 0 12 :3 0 37
:3 0 14 :3 0 35
:3 0 38 :3 0 3d
:3 0 15 :3 0 1f
:3 0 3c :3 0 94
:3 0 8a :3 0 8a
:3 0 8b :3 0 1a
:4 0 1fa 1 :8 0
2269 10 :3 0 96
:3 0 2264 2265 0
97 :3 0 2266 2267
0 2269 1415 22b3
98 :3 0 10 :3 0
96 :3 0 226c 226d
0 97 :3 0 226e
226f 0 22a9 71
:3 0 72 :3 0 2271
2272 0 71 :3 0
84 :3 0 2274 2275
0 99 :2 0 2
:4 0 1fb :2 0 86
:2 0 2c :2 0 1418
227a 227c :3 0 141b
2276 227e 2273 2280
227f :2 0 74 :3 0
87 :3 0 2282 2283
0 76 :4 0 1fc
:4 0 79 :2 0 7a
:3 0 141f 2287 2289
:3 0 79 :2 0 9c
:4 0 1422 228b 228d
:3 0 79 :2 0 9d
:4 0 1425 228f 2291
:3 0 79 :2 0 97
:3 0 1428 2293 2295
:3 0 79 :2 0 9e
:4 0 142b 2297 2299
:3 0 79 :2 0 9f
:3 0 a0 :3 0 2c
:2 0 a1 :2 0 142e
229c 22a0 1432 229b
22a2 :3 0 1435 2284
22a4 :2 0 22a6 1438
22a7 2281 22a6 0
22a8 143a 0 22a9
143c 22ac :3 0 22ac
0 22ac 22ab 22a9
22aa :6 0 22ae 4d
:3 0 143f 22b0 1441
22af 22ae :2 0 22b1
1443 :2 0 22b3 0
22b3 22b2 2269 22b1
:6 0 23b2 1 :3 0
10 :3 0 96 :3 0
22b5 22b6 0 10
:3 0 a2 :2 0 11a
:3 0 22b8 22ba 0
1447 22b9 22bc :3 0
22bd :2 0 1fd :2 0
144a 22bf 22c0 :3 0
71 :3 0 72 :3 0
22c2 22c3 0 71
:3 0 84 :3 0 22c5
22c6 0 13 :2 0
2 :4 0 1fe :2 0
86 :2 0 2c :2 0
144c 22cb 22cd :3 0
144f 22c7 22cf 22c4
22d1 22d0 :2 0 74
:3 0 87 :3 0 22d3
22d4 0 76 :4 0
1ff :4 0 79 :2 0
7a :3 0 1453 22d8
22da :3 0 79 :2 0
9c :4 0 1456 22dc
22de :3 0 79 :2 0
dc :4 0 1459 22e0
22e2 :3 0 79 :2 0
7e :3 0 82 :3 0
dd :3 0 de :3 0
22e7 22e8 0 145c
22e6 22ea 81 :4 0
145e 22e5 22ed 1461
22e4 22ef :3 0 79
:2 0 df :4 0 1464
22f1 22f3 :3 0 79
:2 0 7c :4 0 1467
22f5 22f7 :3 0 79
:2 0 1a :3 0 146a
22f9 22fb :3 0 79
:2 0 7c :4 0 146d
22fd 22ff :3 0 1470
22d5 2301 :2 0 2303
1473 2304 22d2 2303
0 2305 1475 0
232f 71 :3 0 72
:3 0 2306 2307 0
71 :3 0 84 :3 0
2309 230a 0 2c
:2 0 2 :4 0 200
:2 0 86 :2 0 2c
:2 0 1477 230f 2311
:3 0 147a 230b 2313
2308 2315 2314 :2 0
74 :3 0 87 :3 0
2317 2318 0 76
:4 0 201 :4 0 79
:2 0 7a :3 0 147e
231c 231e :3 0 1481
2319 2320 :2 0 2322
1484 2323 2316 2322
0 2324 1486 0
232f e2 :3 0 e3
:3 0 2325 2326 0
dd :3 0 de :3 0
2328 2329 0 1a
:3 0 e4 :3 0 1488
2327 232d :2 0 232f
148c 2330 22c1 232f
0 2331 1490 0
23b2 e5 :3 0 165
:3 0 2332 2333 0
1b :3 0 12 :3 0
1492 2334 2337 a2
:2 0 2f :2 0 1497
2339 233b :3 0 10
:3 0 96 :3 0 233d
233e 0 2f :2 0
233f 2340 0 23af
71 :3 0 72 :3 0
2342 2343 0 71
:3 0 84 :3 0 2345
2346 0 13 :2 0
2 :4 0 202 :2 0
86 :2 0 2c :2 0
149a 234b 234d :3 0
149d 2347 234f 2344
2351 2350 :2 0 74
:3 0 87 :3 0 2353
2354 0 76 :4 0
203 :4 0 79 :2 0
7a :3 0 14a1 2358
235a :3 0 79 :2 0
9c :4 0 14a4 235c
235e :3 0 79 :2 0
dc :4 0 14a7 2360
2362 :3 0 79 :2 0
7e :3 0 82 :3 0
10 :3 0 96 :3 0
2367 2368 0 14aa
2366 236a 81 :4 0
14ac 2365 236d 14af
2364 236f :3 0 79
:2 0 df :4 0 14b2
2371 2373 :3 0 79
:2 0 7c :4 0 14b5
2375 2377 :3 0 79
:2 0 1a :3 0 14b8
2379 237b :3 0 79
:2 0 7c :4 0 14bb
237d 237f :3 0 14be
2355 2381 :2 0 2383
14c1 2384 2352 2383
0 2385 14c3 0
23af 71 :3 0 72
:3 0 2386 2387 0
71 :3 0 84 :3 0
2389 238a 0 2c
:2 0 2 :4 0 204
:2 0 86 :2 0 2c
:2 0 14c5 238f 2391
:3 0 14c8 238b 2393
2388 2395 2394 :2 0
74 :3 0 87 :3 0
2397 2398 0 76
:4 0 205 :4 0 79
:2 0 7a :3 0 14cc
239c 239e :3 0 14cf
2399 23a0 :2 0 23a2
14d2 23a3 2396 23a2
0 23a4 14d4 0
23af e2 :3 0 e3
:3 0 23a5 23a6 0
10 :3 0 96 :3 0
23a8 23a9 0 1a
:3 0 e4 :3 0 14d6
23a7 23ad :2 0 23af
14da 23b0 233c 23af
0 23b1 14df 0
23b2 14e1 23b4 457
f4f 0 23b5 0
23b2 0 23b5 14e5
0 23b6 14e9 23b7
3a9 23b6 0 23b8
14ec 0 2420 1c
:3 0 3 :3 0 23b9
23ba 0 2420 1b
:3 0 5 :3 0 23bc
23bd 0 2420 40
:3 0 e :3 0 23bf
23c0 0 2420 3c
:3 0 dd :3 0 206
:3 0 23c3 23c4 0
23c2 23c5 0 2420
10 :3 0 96 :3 0
23c7 23c8 0 207
:3 0 3c :3 0 1c
:3 0 1b :3 0 40
:3 0 14ee 23ca 23cf
23c9 23d0 0 2420
71 :3 0 72 :3 0
23d2 23d3 0 71
:3 0 84 :3 0 23d5
23d6 0 172 :2 0
2 :4 0 208 :2 0
86 :2 0 2c :2 0
14f3 23db 23dd :3 0
14f6 23d7 23df 23d4
23e1 23e0 :2 0 74
:3 0 87 :3 0 23e3
23e4 0 76 :4 0
209 :4 0 79 :2 0
7a :3 0 14fa 23e8
23ea :3 0 79 :2 0
9c :4 0 14fd 23ec
23ee :3 0 79 :2 0
dc :4 0 1500 23f0
23f2 :3 0 79 :2 0
7e :3 0 82 :3 0
10 :3 0 96 :3 0
23f7 23f8 0 1503
23f6 23fa 81 :4 0
1505 23f5 23fd 1508
23f4 23ff :3 0 79
:2 0 df :4 0 150b
2401 2403 :3 0 79
:2 0 7c :4 0 150e
2405 2407 :3 0 79
:2 0 1c :3 0 1511
2409 240b :3 0 79
:2 0 7c :4 0 1514
240d 240f :3 0 1517
23e5 2411 :2 0 2413
151a 2414 23e2 2413
0 2415 151c 0
2420 e2 :3 0 175
:3 0 2416 2417 0
10 :3 0 96 :3 0
2419 241a 0 1c
:3 0 e4 :3 0 151e
2418 241e :2 0 2420
1522 24c1 10 :3 0
20a :2 0 4 2421
2422 0 71 :3 0
72 :3 0 2424 2425
0 71 :3 0 84
:3 0 2427 2428 0
99 :2 0 2 :4 0
20b :2 0 86 :2 0
2c :2 0 1533 242d
242f :3 0 1536 2429
2431 2426 2433 2432
:2 0 74 :3 0 87
:3 0 2435 2436 0
76 :4 0 20c :4 0
79 :2 0 7a :3 0
153a 243a 243c :3 0
153d 2437 243e :2 0
2457 74 :3 0 87
:3 0 2440 2441 0
76 :4 0 20d :4 0
79 :2 0 10 :3 0
20e :3 0 2446 2447
0 1540 2445 2449
:3 0 79 :2 0 df
:4 0 1543 244b 244d
:3 0 79 :2 0 10
:3 0 20f :3 0 2450
2451 0 1546 244f
2453 :3 0 1549 2442
2455 :2 0 2457 154c
2458 2434 2457 0
2459 154f 0 2469
17f :3 0 70 :3 0
10 :3 0 20e :3 0
210 :3 0 10 :3 0
20f :3 0 211 :3 0
100 :4 0 212 1
:a 0 2465 :2 0 2469
245b 2463 :2 0 f
:3 0 70 :3 0 2467
:2 0 2469 1551 246b
1555 246a 2469 :2 0
24bf 98 :3 0 10
:3 0 96 :3 0 246e
246f 0 97 :3 0
2470 2471 0 24b7
71 :3 0 72 :3 0
2473 2474 0 71
:3 0 84 :3 0 2476
2477 0 99 :2 0
2 :4 0 213 :2 0
86 :2 0 2c :2 0
1557 247c 247e :3 0
155a 2478 2480 2475
2482 2481 :2 0 74
:3 0 87 :3 0 2484
2485 0 76 :4 0
214 :4 0 79 :2 0
7a :3 0 155e 2489
248b :3 0 1561 2486
248d :2 0 24a7 74
:3 0 87 :3 0 248f
2490 0 76 :4 0
9d :4 0 79 :2 0
97 :3 0 1564 2494
2496 :3 0 79 :2 0
9e :4 0 1567 2498
249a :3 0 79 :2 0
9f :3 0 a0 :3 0
2c :2 0 a1 :2 0
156a 249d 24a1 156e
249c 24a3 :3 0 1571
2491 24a5 :2 0 24a7
1574 24a8 2483 24a7
0 24a9 1577 0
24b7 17f :3 0 70
:3 0 210 :3 0 10
:3 0 20f :3 0 211
:3 0 100 :4 0 215
1 :a 0 24b3 :2 0
24b7 24ab 24b1 :2 0
f :3 0 70 :3 0
24b5 :2 0 24b7 1579
24ba :3 0 24ba 0
24ba 24b9 24b7 24b8
:6 0 24bc 1 :3 0
157e 24be 1580 24bd
24bc :2 0 24bf 1582
:2 0 24c1 1585 24c1
24c0 2420 24bf :6 0
24c2 :2 0 2 2c
24c1 24c5 :3 0 24c4
24c2 24c6 :8 0 
15dd
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 9
6 a e 12
16 1a 1e 22
26 1 30 1
2e 1 37 1
35 1 3e 1
3c 1 45 1
43 1 4c 1
4a 1 53 1
51 1 5a 1
58 1 61 1
5f 1 68 1
66 1 6f 1
6d 1 76 1
74 1 7d 1
7b 1 84 1
82 1 89 1
8e 1 93 1
98 1 9d 1
a2 1 a7 1
ac 1 b1 1
b8 1 b6 1
bf 1 bd 1
c4 1 ca 1
d0 1 d6 1
db 1 e0 1
e6 1 ec 1
f2 1 f8 1
fe 1 104 1
10a 1 110 1
116 1 11e 1
11c 1 125 1
123 1 12c 1
12a 1 131 1
137 1 13d 1
143 1 149 1
14f 1 155 1
15b 1 161 1
167 1 16d 1
173 1 179 1
17f 1 185 1
18b 1 191 1
197 1 19d 1
1a3 1 1a9 1
1af 1 1b5 1
1bb 1 1c3 1
1c1 1 1ca 1
1c8 1 1cf 1
1d7 1 1d5 1
1dc 1 1e2 1
1e8 1 1ee 1
1f4 1 1fa 1
200 1 206 1
20c 1 212 1
218 1 220 1
21e 1 225 1
22a 1 22f 1
236 1 23d 1
24a 1 256 2
259 25b 2 25e
260 2 262 264
2 266 268 2
26a 26c 2 26e
270 2 272 274
2 276 278 2
27a 27c 2 282
284 2 286 288
2 28a 28b 2
28d 28e 2 27e
290 2 292 294
2 29a 29c 2
29e 2a0 2 2a2
2a3 2 2a5 2a6
2 296 2a8 2
2aa 2ac 1 2b2
2 2b4 2b5 2
2ae 2b7 2 2b9
2bb 1 2c1 2
2c3 2c4 2 2bd
2c6 2 2c8 2ca
1 2d0 2 2d2
2d3 2 2cc 2d5
2 2d7 2d9 1
2df 2 2e1 2e2
2 2db 2e4 2
2e6 2e8 2 2ea
2ec 2 2ee 2f0
2 2f2 2f4 2
2f6 2f8 4 252
258 25d 2fa 1
2fc 1 2fe 2
308 30a 3 306
307 30c 2 315
317 2 314 319
1 31b 1 31d
2 34e 353 2
364 366 3 362
363 368 2 371
373 2 375 377
2 379 37b 2
37d 37f 2 381
383 3 388 389
38a 2 385 38c
2 370 38e 1
390 1 392 2
35b 393 1 397
1 356 1 39b
1 3a6 2 3a2
3a6 2 3fc 401
2 412 414 3
410 411 416 2
41f 421 2 423
425 2 427 429
2 42b 42d 2
42f 431 3 436
437 438 2 433
43a 2 41e 43c
1 43e 1 440
2 409 441 1
445 1 404 1
449 1 454 2
450 454 2 478
47d 2 48e 490
3 48c 48d 492
2 49b 49d 2
49f 4a1 2 4a3
4a5 2 4a7 4a9
2 4ab 4ad 3
4b2 4b3 4b4 2
4af 4b6 2 49a
4b8 1 4ba 1
4bc 2 485 4bd
1 4c1 1 480
1 4c5 1 4d0
2 4cc 4d0 2
4dc 4de 3 4da
4db 4e0 2 4e9
4eb 2 4ed 4ef
2 4f1 4f3 1
4fb 2 4fd 4fe
2 4f5 500 2
502 504 2 506
508 2 50a 50c
2 50e 510 2
4e8 512 1 514
1 516 2 520
522 3 51e 51f
524 2 52d 52f
2 52c 531 1
533 1 535 3
53c 53d 53e 3
517 536 540 1
542 3 54d 54e
54f 1 553 2
551 553 3 55a
55b 55c 1 560
2 55e 560 2
56e 570 3 56c
56d 572 2 57b
57d 2 57f 581
2 583 585 1
58d 2 58f 590
2 587 592 2
594 596 2 598
59a 2 59c 59e
2 5a0 5a2 2
57a 5a4 1 5a6
1 5a8 2 5b2
5b4 3 5b0 5b1
5b6 2 5bf 5c1
2 5be 5c3 1
5c5 1 5c7 3
5ce 5cf 5d0 3
5a9 5c8 5d2 1
5d4 1 5d6 2
5dd 5de 2 5e3
5e4 2 5e0 5e6
2 5ec 5ed 1
5ef 2 5e9 5ef
2 5fd 5ff 3
5fb 5fc 601 2
60a 60c 2 60e
610 2 612 614
1 61c 2 61e
61f 2 616 621
2 623 625 2
627 629 2 62b
62d 2 62f 631
2 609 633 1
635 1 637 2
641 643 3 63f
640 645 2 64e
650 2 64d 652
1 654 1 656
3 65d 65e 65f
3 638 657 661
1 663 3 668
669 66a 1 66e
2 66c 66e 3
675 676 677 1
67b 2 679 67b
2 682 683 1
687 2 685 687
3 68d 68e 68f
1 693 2 691
693 2 6a6 6ab
2 6bc 6be 3
6ba 6bb 6c0 2
6c9 6cb 2 6cd
6cf 2 6d1 6d3
2 6d5 6d7 2
6d9 6db 3 6e0
6e1 6e2 2 6dd
6e4 2 6c8 6e6
1 6e8 1 6ea
2 6b3 6eb 1
6ef 1 6ae 1
6f3 1 6fe 2
6fa 6fe 2 70b
710 2 721 723
3 71f 720 725
2 72e 730 2
732 734 2 736
738 2 73a 73c
2 73e 740 3
745 746 747 2
742 749 2 72d
74b 1 74d 1
74f 2 718 750
1 754 1 713
1 758 1 75b
1 75e 3 763
764 765 1 769
2 767 769 1
76e 1 770 3
6f6 75f 771 2
783 788 2 799
79b 3 797 798
79d 2 7a6 7a8
2 7aa 7ac 2
7ae 7b0 2 7b2
7b4 2 7b6 7b8
3 7bd 7be 7bf
2 7ba 7c1 2
7a5 7c3 1 7c5
1 7c7 2 790
7c8 1 7cc 1
78b 1 7d0 1
7db 2 7d7 7db
2 7e8 7ed 2
7fe 800 3 7fc
7fd 802 2 80b
80d 2 80f 811
2 813 815 2
817 819 2 81b
81d 3 822 823
824 2 81f 826
2 80a 828 1
82a 1 82c 2
7f5 82d 1 831
1 7f0 1 835
1 838 1 83b
3 7d3 83c 83f
2 841 842 2
845 846 1 84c
2 848 84c 1
85b 2 85a 85b
1 863 1 869
2 86b 86c 2
858 86d 2 87e
880 3 87c 87d
882 2 88b 88d
2 88f 891 2
893 895 2 897
899 2 89b 89d
3 8a2 8a3 8a4
2 89f 8a6 2
88a 8a8 1 8aa
1 8ac 2 875
8ad 1 8b1 1
870 1 8b5 1
8b8 1 8c7 2
8c6 8c7 1 8cf
1 8d5 2 8d7
8d8 2 8c4 8d9
2 8ea 8ec 3
8e8 8e9 8ee 2
8f7 8f9 2 8fb
8fd 2 8ff 901
2 903 905 2
907 909 3 90e
90f 910 2 90b
912 2 8f6 914
1 916 1 918
2 8e1 919 1
91d 1 8dc 1
921 1 924 2
927 928 1 930
2 92c 930 1
936 1 939 1
93b 3 843 929
93c 2 947 94c
2 95d 95f 3
95b 95c 961 2
96a 96c 2 96e
970 2 972 974
2 976 978 2
97a 97c 3 981
982 983 2 97e
985 2 969 987
1 989 1 98b
2 954 98c 1
990 1 94f 1
994 2 99a 99b
1 99f 2 99d
99f 2 9aa 9ac
3 9a8 9a9 9ae
2 9b7 9b9 2
9bb 9bd 2 9bf
9c1 1 9c9 2
9cb 9cc 2 9c3
9ce 2 9d0 9d2
2 9d4 9d6 2
9d8 9da 2 9dc
9de 2 9b6 9e0
1 9e2 1 9e4
2 9ee 9f0 3
9ec 9ed 9f2 2
9fb 9fd 2 9fa
9ff 1 a01 1
a03 3 a0a a0b
a0c 3 9e5 a04
a0e 1 a10 3
a15 a16 a17 1
a1b 2 a19 a1b
2 a2e a33 2
a44 a46 3 a42
a43 a48 2 a51
a53 2 a55 a57
2 a59 a5b 2
a5d a5f 2 a61
a63 3 a68 a69
a6a 2 a65 a6c
2 a50 a6e 1
a70 1 a72 2
a3b a73 1 a77
1 a36 1 a7b
1 a86 2 a82
a86 2 a93 a98
2 aa9 aab 3
aa7 aa8 aad 2
ab6 ab8 2 aba
abc 2 abe ac0
2 ac2 ac4 2
ac6 ac8 3 acd
ace acf 2 aca
ad1 2 ab5 ad3
1 ad5 1 ad7
2 aa0 ad8 1
adc 1 a9b 1
ae0 1 ae3 1
ae6 2 a7e ae7
2 af9 afe 2
b0f b11 3 b0d
b0e b13 2 b1c
b1e 2 b20 b22
2 b24 b26 2
b28 b2a 2 b2c
b2e 3 b33 b34
b35 2 b30 b37
2 b1b b39 1
b3b 1 b3d 2
b06 b3e 1 b42
1 b01 1 b46
1 b51 2 b4d
b51 2 b5e b63
2 b74 b76 3
b72 b73 b78 2
b81 b83 2 b85
b87 2 b89 b8b
2 b8d b8f 2
b91 b93 3 b98
b99 b9a 2 b95
b9c 2 b80 b9e
1 ba0 1 ba2
2 b6b ba3 1
ba7 1 b66 1
bab 1 bae 1
bb1 2 b49 bb2
2 bb4 bb5 2
bc2 bc3 a bb9
bba bbb bbc bbd
bbe bbf bc0 bc5
bc6 2 bcb bcc
1 bd0 2 bce
bd0 1 bd5 1
bd8 2 be2 be4
3 be0 be1 be6
2 bef bf1 2
bf3 bf5 2 bf7
bf9 1 bff 2
c01 c02 2 bfb
c04 2 c06 c08
2 c0a c0c 2
c0e c10 2 c12
c14 2 bee c16
1 c18 1 c1a
2 c24 c26 3
c22 c23 c28 2
c31 c33 2 c30
c35 1 c37 1
c39 2 c3f c40
3 c42 c43 c44
3 c1b c3a c46
2 c48 c49 5
997 a11 bb6 bc9
c4a 2 c4c c4d
1 c4e 2 c52
c53 2 c58 c59
1 c5b 2 c55
c5b 2 c60 c61
1 c65 2 c63
c65 2 c6f c70
2 c75 c76 1
c78 2 c72 c78
2 c83 c85 3
c81 c82 c87 2
c90 c92 2 c94
c96 2 c98 c9a
1 ca2 2 ca4
ca5 2 c9c ca7
2 c8f ca9 1
cab 1 cad 2
cb7 cb9 3 cb5
cb6 cbb 2 cc4
cc6 2 cc3 cc8
1 cca 1 ccc
2 cd3 cd4 3
cae ccd cd6 2
cda cdb 2 ce0
ce1 1 ce3 2
cdd ce3 1 ce8
2 ceb cea 2
d08 d0d 2 d1e
d20 3 d1c d1d
d22 2 d2b d2d
2 d2f d31 2
d33 d35 2 d37
d39 2 d3b d3d
3 d42 d43 d44
2 d3f d46 2
d2a d48 1 d4a
1 d4c 2 d15
d4d 1 d51 1
d10 1 d55 2
d5b d5c 1 d60
2 d5e d60 2
d6b d6d 3 d69
d6a d6f 2 d78
d7a 2 d7c d7e
2 d80 d82 1
d8a 2 d8c d8d
2 d84 d8f 2
d91 d93 2 d95
d97 2 d99 d9b
2 d9d d9f 2
d77 da1 1 da3
1 da5 2 daf
db1 3 dad dae
db3 2 dbc dbe
2 dbb dc0 1
dc2 1 dc4 3
dcb dcc dcd 3
da6 dc5 dcf 1
dd1 2 def df4
2 e05 e07 3
e03 e04 e09 2
e12 e14 2 e16
e18 2 e1a e1c
2 e1e e20 2
e22 e24 3 e29
e2a e2b 2 e26
e2d 2 e11 e2f
1 e31 1 e33
2 dfc e34 1
e38 1 df7 1
e3c 2 e42 e43
1 e47 2 e45
e47 2 e52 e54
3 e50 e51 e56
2 e5f e61 2
e63 e65 2 e67
e69 1 e71 2
e73 e74 2 e6b
e76 2 e78 e7a
2 e7c e7e 2
e80 e82 2 e84
e86 2 e5e e88
1 e8a 1 e8c
2 e96 e98 3
e94 e95 e9a 2
ea3 ea5 2 ea2
ea7 1 ea9 1
eab 3 eb2 eb3
eb4 3 e8d eac
eb6 1 eb8 2
ec4 ec5 5 ebf
ec0 ec1 ec2 ec7
9 c6d cec cef
d58 dd2 e3f eb9
ebc eca 2 ecd
ecc 2 ed0 ed1
1 ed5 2 ed3
ed5 1 eda 1
edd 1 edf 2
ee9 eeb 3 ee7
ee8 eed 2 ef6
ef8 2 efa efc
2 efe f00 1
f06 2 f08 f09
2 f02 f0b 2
f0d f0f 2 f11
f13 2 f15 f17
2 f19 f1b 2
ef5 f1d 1 f1f
1 f21 2 f2b
f2d 3 f29 f2a
f2f 2 f38 f3a
2 f37 f3c 1
f3e 1 f40 2
f46 f47 3 f49
f4a f4b b 4c8
543 546 549 5d5
664 ece ee0 f22
f41 f4d 1 f50
1 f55 3 f65
f66 f67 1 f6b
2 f69 f6b 3
f72 f73 f74 1
f78 2 f76 f78
2 f86 f88 3
f84 f85 f8a 2
f93 f95 2 f97
f99 2 f9b f9d
1 fa5 2 fa7
fa8 2 f9f faa
2 fac fae 2
fb0 fb2 2 fb4
fb6 2 fb8 fba
2 f92 fbc 1
fbe 1 fc0 2
fca fcc 3 fc8
fc9 fce 2 fd7
fd9 2 fd6 fdb
1 fdd 1 fdf
3 fe6 fe7 fe8
3 fc1 fe0 fea
1 fec 2 ff9
ffe 2 100f 1011
3 100d 100e 1013
2 101c 101e 2
1020 1022 2 1024
1026 2 1028 102a
2 102c 102e 3
1033 1034 1035 2
1030 1037 2 101b
1039 1 103b 1
103d 2 1006 103e
1 1042 1 1001
1 1046 3 104c
104d 104e 1 1052
2 1050 1052 1
1057 1 105b 2
105d 105e 3 1069
106a 106b 1 106f
2 106d 106f 3
1076 1077 1078 1
107c 2 107a 107c
2 1083 1084 2
1089 108a 1 108c
2 1086 108c 3
1095 1096 1097 1
109b 2 1099 109b
2 10a7 10ac 2
10bd 10bf 3 10bb
10bc 10c1 2 10ca
10cc 2 10ce 10d0
2 10d2 10d4 2
10d6 10d8 2 10da
10dc 3 10e1 10e2
10e3 2 10de 10e5
2 10c9 10e7 1
10e9 1 10eb 2
10b4 10ec 1 10f0
1 10af 1 10f4
4 10f7 10fb 10fe
1101 3 1107 1108
1109 1 110d 2
110b 110d 2 111a
111f 2 1130 1132
3 112e 112f 1134
2 113d 113f 2
1141 1143 2 1145
1147 2 1149 114b
2 114d 114f 3
1154 1155 1156 2
1151 1158 2 113c
115a 1 115c 1
115e 2 1127 115f
1 1163 1 1122
1 1167 2 1170
1171 1 1177 a
117d 117e 117f 1180
1181 1182 1183 1184
1185 1186 2 118b
118c 1 1190 2
118e 1190 1 1194
1 11aa 2 11a9
11aa 1 11b2 1
11b8 2 11ba 11bb
2 11a7 11bc 2
11cd 11cf 3 11cb
11cc 11d1 2 11da
11dc 2 11de 11e0
2 11e2 11e4 2
11e6 11e8 2 11ea
11ec 3 11f1 11f2
11f3 2 11ee 11f5
2 11d9 11f7 1
11f9 1 11fb 2
11c4 11fc 1 1200
1 11bf 1 1204
1 1207 1 120a
3 120d 120e 120f
1 1213 2 1211
1213 1 1218 1
121c 2 121e 121f
10 1223 1224 1225
1226 1227 1228 1229
122a 122b 122c 122d
122e 122f 1230 1231
1232 2 1249 124e
2 125f 1261 3
125d 125e 1263 2
126c 126e 2 1270
1272 2 1274 1276
2 1278 127a 2
127c 127e 3 1283
1284 1285 2 1280
1287 2 126b 1289
1 128b 1 128d
2 1256 128e 1
1292 1 1251 1
1296 a 12a0 12a1
12a2 12a3 12a4 12a5
12a6 12a7 12a8 12a9
1 12af 2 12c0
12c2 3 12be 12bf
12c4 2 12cd 12cf
2 12d1 12d3 2
12d5 12d7 1 12df
2 12e1 12e2 2
12d9 12e4 2 12e6
12e8 2 12ea 12ec
2 12ee 12f0 2
12f2 12f4 2 12cc
12f6 1 12f8 1
12fa 3 1301 1302
1303 e 116a 1174
117a 1189 120b 1220
1235 1299 129d 12ac
12b2 12b7 12fb 1305
2 130a 130b 2
1310 1311 1 1313
2 130d 1313 2
1318 1319 2 131e
131f 2 131b 1321
2 1324 1327 2
132c 132d 1 1331
2 132f 1331 2
133f 1344 2 1355
1357 3 1353 1354
1359 2 1362 1364
2 1366 1368 2
136a 136c 2 136e
1370 2 1372 1374
3 1379 137a 137b
2 1376 137d 2
1361 137f 1 1381
1 1383 2 134c
1384 1 1388 1
1347 1 138c 3
1336 1339 138f 2
1395 1396 2 139b
139c 1 139e 2
1398 139e 2 13a3
13a4 2 13a9 13aa
2 13a6 13ac 2
13b7 13b8 1 13bc
2 13ba 13bc 2
13c0 13c2 2 13c4
13c6 2 13c8 13ca
2 13cc 13ce 2
13d0 13d2 2 13d4
13d6 2 13dc 13dd
1 13df 2 13d8
13e1 2 13e4 13e9
2 13ec 13ee 2
13f0 13f2 2 13f4
13f6 2 13f8 13fa
2 13fc 13fe 2
1400 1402 2 1408
1409 1 140b 2
1404 140d 2 1410
1415 2 1417 1418
2 141c 141d 1
1421 2 141f 1421
1 142f 1 1435
2 1437 1438 2
1426 1439 1 1446
1 144c 2 144e
144f 2 143d 1450
2 1452 1453 1
145b 2 1457 145b
1 1460 1 1462
2 1454 1463 2
1468 1469 1 146d
2 146b 146d 2
1472 1478 2 1489
148b 3 1487 1488
148d 2 1496 1498
2 149a 149c 2
149e 14a0 2 14a2
14a4 2 14a6 14a8
3 14ad 14ae 14af
2 14aa 14b1 2
1495 14b3 1 14b5
1 14b7 2 1480
14b8 1 14bc 1
147b 1 14c0 1
14c3 2 14c8 14ce
2 14df 14e1 3
14dd 14de 14e3 2
14ec 14ee 2 14f0
14f2 2 14f4 14f6
2 14f8 14fa 2
14fc 14fe 3 1503
1504 1505 2 1500
1507 2 14eb 1509
1 150b 1 150d
2 14d6 150e 1
1512 1 14d1 1
1516 1 1519 2
151c 151d 1 151f
2 1525 1526 1
152a 2 1528 152a
2 1535 1537 3
1533 1534 1539 2
1542 1544 2 1546
1548 2 154a 154c
1 1554 2 1556
1557 2 154e 1559
2 155b 155d 2
155f 1561 2 1563
1565 2 1567 1569
2 1541 156b 1
156d 1 156f 2
1579 157b 3 1577
1578 157d 2 1586
1588 2 1585 158a
1 158c 1 158e
3 1595 1596 1597
3 1570 158f 1599
2 15a3 15a5 3
15a1 15a2 15a7 2
15b0 15b2 2 15b4
15b6 2 15b8 15ba
1 15c2 2 15c4
15c5 2 15bc 15c7
2 15c9 15cb 2
15cd 15cf 2 15d1
15d3 2 15d5 15d7
2 15af 15d9 1
15db 1 15dd 2
15e7 15e9 3 15e5
15e6 15eb 2 15f4
15f6 2 15f3 15f8
1 15fa 1 15fc
3 1603 1604 1605
3 15de 15fd 1607
2 1609 160a 1
160b 1 160d 2
1619 161e 2 162f
1631 3 162d 162e
1633 2 163c 163e
2 1640 1642 2
1644 1646 2 1648
164a 2 164c 164e
3 1653 1654 1655
2 1650 1657 2
163b 1659 1 165b
1 165d 2 1626
165e 1 1662 1
1621 1 1666 a
13af 13b2 13b5 1419
1466 151e 160e 1669
166d 1670 5 1673
1308 132a 1393 1672
1 1674 2 1678
1679 2 167e 167f
1 1681 2 167b
1681 2 1685 1686
2 168b 168c 1
168e 2 1688 168e
2 1699 169b 3
1697 1698 169d 2
16a6 16a8 2 16aa
16ac 2 16ae 16b0
1 16b8 2 16ba
16bb 2 16b2 16bd
2 16bf 16c1 2
16c3 16c5 2 16c7
16c9 2 16cb 16cd
2 16a5 16cf 1
16d1 1 16d3 2
16dd 16df 3 16db
16dc 16e1 2 16ea
16ec 2 16e9 16ee
1 16f0 1 16f2
3 16f9 16fa 16fb
3 16d4 16f3 16fd
1 16ff 2 1702
1703 1 1707 2
1705 1707 1 170c
2 170f 1710 1
1714 2 1712 1714
2 1719 171a 1
171e 2 171c 171e
2 172c 172e 3
172a 172b 1730 2
1739 173b 2 173d
173f 2 1741 1743
1 174b 2 174d
174e 2 1745 1750
2 1738 1752 1
1754 1 1756 2
1760 1762 3 175e
175f 1764 2 176d
176f 2 176c 1771
1 1773 1 1775
2 177c 177d 3
1757 1776 177f 1
1781 2 1782 1785
2 1787 1788 1
178a 2 1794 1799
2 17aa 17ac 3
17a8 17a9 17ae 2
17b7 17b9 2 17bb
17bd 2 17bf 17c1
2 17c3 17c5 2
17c7 17c9 3 17ce
17cf 17d0 2 17cb
17d2 2 17b6 17d4
1 17d6 1 17d8
2 17a1 17d9 1
17dd 1 179c 1
17e1 1 17ec 2
17e8 17ec 2 17f1
17f2 2 17f7 17f8
1 17fa 2 17f4
17fa 2 1808 180a
3 1806 1807 180c
2 1815 1817 2
1819 181b 2 181d
181f 1 1827 2
1829 182a 2 1821
182c 2 182e 1830
2 1832 1834 2
1836 1838 2 183a
183c 2 1814 183e
1 1840 1 1842
2 184c 184e 3
184a 184b 1850 2
1859 185b 2 1858
185d 1 185f 1
1861 3 1868 1869
186a 3 1843 1862
186c 1 186e 2
17e4 186f 1 1871
2 187a 187b 1
187f 2 187d 187f
1 1884 1 1886
1 189d 2 189c
189d 1 18a5 1
18ab 2 18ad 18ae
2 189a 18af 2
18c0 18c2 3 18be
18bf 18c4 2 18cd
18cf 2 18d1 18d3
2 18d5 18d7 2
18d9 18db 2 18dd
18df 3 18e4 18e5
18e6 2 18e1 18e8
2 18cc 18ea 1
18ec 1 18ee 2
18b7 18ef 1 18f3
1 18b2 1 18f7
2 18fd 18fe 1
1902 2 1900 1902
1 1907 1 1909
8 1700 1789 1872
1875 1878 1887 18fa
190a 2 190d 190c
1 1911 2 190f
1911 1 1916 a
191c 191d 191e 191f
1920 1921 1922 1923
1924 1925 2 192a
192b 1 192f 2
192d 192f 1 1933
8 193d 193e 193f
1940 1941 1942 1943
1944 1 1947 1
1949 1 194b 3
1952 1953 1954 1
1957 3 195a 195b
195c 1 1960 2
195e 1960 3 1965
1966 1967 1 196a
3 196e 196f 1970
1 1973 2 1975
1976 1 1977 2
1979 197a 1 197c
2 1982 1983 1
1987 2 1985 1987
2 198f 1990 2
1992 1995 2 19a4
19a9 2 19ba 19bc
3 19b8 19b9 19be
2 19c7 19c9 2
19cb 19cd 2 19cf
19d1 2 19d3 19d5
2 19d7 19d9 3
19de 19df 19e0 2
19db 19e2 2 19c6
19e4 1 19e6 1
19e8 2 19b1 19e9
1 19ed 1 19ac
1 19f1 2 1999
19f4 2 1a01 1a06
2 1a17 1a19 3
1a15 1a16 1a1b 2
1a24 1a26 2 1a28
1a2a 2 1a2c 1a2e
2 1a30 1a32 2
1a34 1a36 3 1a3b
1a3c 1a3d 2 1a38
1a3f 2 1a23 1a41
1 1a43 1 1a45
2 1a0e 1a46 1
1a4a 1 1a09 1
1a4e 1 1a51 2
1a54 1a55 2 1a59
1a5a 2 1a5f 1a60
2 1a5c 1a62 2
1a56 1a65 1 1a67
2 1a75 1a76 2
1a7a 1a7b 8 1a6e
1a6f 1a70 1a71 1a72
1a73 1a78 1a7d 2
1a82 1a83 1 1a87
2 1a85 1a87 2
1a92 1a94 3 1a90
1a91 1a96 2 1a9f
1aa1 2 1aa3 1aa5
2 1aa7 1aa9 1
1ab1 2 1ab3 1ab4
2 1aab 1ab6 2
1ab8 1aba 2 1abc
1abe 2 1ac0 1ac2
2 1ac4 1ac6 2
1a9e 1ac8 1 1aca
1 1acc 2 1ad6
1ad8 3 1ad4 1ad5
1ada 2 1ae3 1ae5
2 1ae2 1ae7 1
1ae9 1 1aeb 3
1af2 1af3 1af4 3
1acd 1aec 1af6 1
1afb 2 1af9 1afb
1 1b17 2 1b16
1b17 1 1b1f 1
1b25 2 1b27 1b28
2 1b14 1b29 2
1b3a 1b3c 3 1b38
1b39 1b3e 2 1b47
1b49 2 1b4b 1b4d
2 1b4f 1b51 2
1b53 1b55 2 1b57
1b59 3 1b5e 1b5f
1b60 2 1b5b 1b62
2 1b46 1b64 1
1b66 1 1b68 2
1b31 1b69 1 1b6d
1 1b2c 1 1b71
1 1b74 2 1b78
1b77 1 1b7c 2
1b88 1b8a 3 1b86
1b87 1b8c 2 1b95
1b97 2 1b99 1b9b
2 1b9d 1b9f 1
1ba5 2 1ba7 1ba8
2 1ba1 1baa 2
1bac 1bae 2 1bb0
1bb2 2 1bb4 1bb6
2 1bb8 1bba 2
1b94 1bbc 1 1bbe
1 1bc0 2 1bca
1bcc 3 1bc8 1bc9
1bce 2 1bd7 1bd9
2 1bd6 1bdb 1
1bdd 1 1bdf 2
1be5 1be6 3 1be8
1be9 1bea c 1919
1928 194a 197b 1a68
1a6b 1a80 1b79 1b7f
1bc1 1be0 1bec 1
1bee 2 1bf1 1bf2
2 1bf7 1bf8 1
1bfa 2 1bf4 1bfa
2 1c09 1c0e 2
1c1f 1c21 3 1c1d
1c1e 1c23 2 1c2c
1c2e 2 1c30 1c32
2 1c34 1c36 2
1c38 1c3a 2 1c3c
1c3e 3 1c43 1c44
1c45 2 1c40 1c47
2 1c2b 1c49 1
1c4b 1 1c4d 2
1c16 1c4e 1 1c52
1 1c11 1 1c56
2 1c5c 1c5d 1
1c61 2 1c5f 1c61
2 1c6c 1c6e 3
1c6a 1c6b 1c70 2
1c79 1c7b 2 1c7d
1c7f 2 1c81 1c83
1 1c8b 2 1c8d
1c8e 2 1c85 1c90
2 1c92 1c94 2
1c96 1c98 2 1c9a
1c9c 2 1c9e 1ca0
2 1c78 1ca2 1
1ca4 1 1ca6 2
1cb0 1cb2 3 1cae
1caf 1cb4 2 1cbd
1cbf 2 1cbc 1cc1
1 1cc3 1 1cc5
3 1ccc 1ccd 1cce
3 1ca7 1cc6 1cd0
1 1cd2 2 1cd9
1cda 2 1cdf 1ce0
2 1ce5 1ce6 1
1ce8 2 1ce2 1ce8
1 1ced a 1cf3
1cf4 1cf5 1cf6 1cf7
1cf8 1cf9 1cfa 1cfb
1cfc 1 1d00 3
1d07 1d08 1d09 1
1d0c 3 1d0f 1d10
1d11 1 1d15 2
1d13 1d15 3 1d1a
1d1b 1d1c 1 1d1f
3 1d23 1d24 1d25
1 1d28 2 1d2a
1d2b 1 1d2c 2
1d2e 1d2f 1 1d34
2 1d3a 1d3b 1
1d3f 2 1d3d 1d3f
2 1d47 1d48 2
1d4a 1d4d 2 1d5c
1d61 2 1d72 1d74
3 1d70 1d71 1d76
2 1d7f 1d81 2
1d83 1d85 2 1d87
1d89 2 1d8b 1d8d
2 1d8f 1d91 3
1d96 1d97 1d98 2
1d93 1d9a 2 1d7e
1d9c 1 1d9e 1
1da0 2 1d69 1da1
1 1da5 1 1d64
1 1da9 2 1d51
1dac 2 1db9 1dbe
2 1dcf 1dd1 3
1dcd 1dce 1dd3 2
1ddc 1dde 2 1de0
1de2 2 1de4 1de6
2 1de8 1dea 2
1dec 1dee 3 1df3
1df4 1df5 2 1df0
1df7 2 1ddb 1df9
1 1dfb 1 1dfd
2 1dc6 1dfe 1
1e02 1 1dc1 1
1e06 1 1e09 2
1e0c 1e0d 2 1e10
1e11 1 1e15 2
1e13 1e15 2 1e24
1e29 2 1e3a 1e3c
3 1e38 1e39 1e3e
2 1e47 1e49 2
1e4b 1e4d 2 1e4f
1e51 2 1e53 1e55
2 1e57 1e59 3
1e5e 1e5f 1e60 2
1e5b 1e62 2 1e46
1e64 1 1e66 1
1e68 2 1e31 1e69
1 1e6d 1 1e2c
1 1e71 1 1e74
1 1e77 2 1e0e
1e78 1 1e7a 2
1e7e 1e7f 2 1e84
1e85 2 1e81 1e87
2 1e8c 1e8d 2
1e89 1e8f 1 1eac
2 1eab 1eac 1
1eb4 1 1eba 2
1ebc 1ebd 2 1ea9
1ebe 2 1ecf 1ed1
3 1ecd 1ece 1ed3
2 1edc 1ede 2
1ee0 1ee2 2 1ee4
1ee6 2 1ee8 1eea
2 1eec 1eee 3
1ef3 1ef4 1ef5 2
1ef0 1ef7 2 1edb
1ef9 1 1efb 1
1efd 2 1ec6 1efe
1 1f02 1 1ec1
1 1f06 1 1f11
2 1f0d 1f11 2
1f22 1f23 8 1f1a
1f1b 1f1c 1f1d 1f1e
1f1f 1f20 1f25 2
1f2a 1f2b 1 1f2f
2 1f2d 1f2f 2
1f3a 1f3c 3 1f38
1f39 1f3e 2 1f47
1f49 2 1f4b 1f4d
2 1f4f 1f51 1
1f57 2 1f59 1f5a
2 1f53 1f5c 2
1f5e 1f60 2 1f62
1f64 2 1f66 1f68
2 1f6a 1f6c 2
1f46 1f6e 1 1f70
1 1f72 2 1f7c
1f7e 3 1f7a 1f7b
1f80 2 1f89 1f8b
2 1f88 1f8d 1
1f8f 1 1f91 2
1f97 1f98 3 1f9a
1f9b 1f9c 3 1f73
1f92 1f9e 1 1fa0
3 1f17 1f28 1fa1
1 1fa3 2 1fa7
1fa8 a 1cf0 1cff
1d30 1d33 1e7b 1e92
1e95 1f09 1fa4 1fab
2 1fb0 1fb1 2
1fb6 1fb7 2 1fb3
1fb9 2 1fbc 1fbe
2 1fc1 1fc3 1
1fc5 1 1fc8 2
1fca 1fcb 2 1fe7
1fe8 18 1fcf 1fd0
1fd1 1fd2 1fd3 1fd4
1fd5 1fd6 1fd7 1fd8
1fd9 1fda 1fdb 1fdc
1fdd 1fde 1fdf 1fe0
1fe1 1fe2 1fe3 1fe4
1fe5 1fea 2 1ff6
1ff8 3 1ff4 1ff5
1ffa 2 2003 2005
2 2007 2009 2
200b 200d 1 2013
2 2015 2016 2
200f 2018 2 201a
201c 2 201e 2020
2 2022 2024 2
2026 2028 2 2002
202a 1 202c 1
202e 2 2038 203a
3 2036 2037 203c
2 2045 2047 2
2044 2049 1 204b
1 204d 2 2053
2054 3 2056 2057
2058 9 1c59 1cd3
1cd6 1cdd 1fcc 1fed
202f 204e 205a 2
205e 205f 2 2064
2065 1 2067 2
2061 2067 2 206b
206c 1 2070 2
206e 2070 2 2075
2076 1 207a 2
2078 207a 2 2088
208a 3 2086 2087
208c 2 2095 2097
2 2099 209b 2
209d 209f 1 20a7
2 20a9 20aa 2
20a1 20ac 2 20ae
20b0 2 20b2 20b4
2 20b6 20b8 2
20ba 20bc 2 2094
20be 1 20c0 1
20c2 2 20cc 20ce
3 20ca 20cb 20d0
2 20d9 20db 2
20d8 20dd 1 20df
1 20e1 3 20e8
20e9 20ea 3 20c3
20e2 20ec 1 20ee
1 20fe 2 20fd
20fe 1 2106 1
210c 2 210e 210f
2 20fb 2110 2
2121 2123 3 211f
2120 2125 2 212e
2130 2 2132 2134
2 2136 2138 2
213a 213c 2 213e
2140 3 2145 2146
2147 2 2142 2149
2 212d 214b 1
214d 1 214f 2
2118 2150 1 2154
1 2113 1 2158
1 216b 2 216a
216b 1 2173 1
2179 2 217b 217c
2 2168 217d 2
218e 2190 3 218c
218d 2192 2 219b
219d 2 219f 21a1
2 21a3 21a5 2
21a7 21a9 2 21ab
21ad 3 21b2 21b3
21b4 2 21af 21b6
2 219a 21b8 1
21ba 1 21bc 2
2185 21bd 1 21c1
1 2180 1 21c5
3 20ef 215b 21c8
2 21cc 21cb 1
21d0 2 21dc 21de
3 21da 21db 21e0
2 21e9 21eb 2
21ed 21ef 2 21f1
21f3 1 21f9 2
21fb 21fc 2 21f5
21fe 2 2200 2202
2 2204 2206 2
2208 220a 2 220c
220e 2 21e8 2210
1 2212 1 2214
2 221e 2220 3
221c 221d 2222 2
222b 222d 2 222a
222f 1 2231 1
2233 2 2239 223a
3 223c 223d 223e
e f5e f61 fed
1049 105f 1062 1065
190e 1bef 21cd 21d3
2215 2234 2240 2
2263 2268 2 2279
227b 3 2277 2278
227d 2 2286 2288
2 228a 228c 2
228e 2290 2 2292
2294 2 2296 2298
3 229d 229e 229f
2 229a 22a1 2
2285 22a3 1 22a5
1 22a7 2 2270
22a8 1 22ac 1
226b 1 22b0 1
22bb 2 22b7 22bb
1 22be 2 22ca
22cc 3 22c8 22c9
22ce 2 22d7 22d9
2 22db 22dd 2
22df 22e1 1 22e9
2 22eb 22ec 2
22e3 22ee 2 22f0
22f2 2 22f4 22f6
2 22f8 22fa 2
22fc 22fe 2 22d6
2300 1 2302 1
2304 2 230e 2310
3 230c 230d 2312
2 231b 231d 2
231a 231f 1 2321
1 2323 3 232a
232b 232c 3 2305
2324 232e 1 2330
2 2335 2336 1
233a 2 2338 233a
2 234a 234c 3
2348 2349 234e 2
2357 2359 2 235b
235d 2 235f 2361
1 2369 2 236b
236c 2 2363 236e
2 2370 2372 2
2374 2376 2 2378
237a 2 237c 237e
2 2356 2380 1
2382 1 2384 2
238e 2390 3 238c
238d 2392 2 239b
239d 2 239a 239f
1 23a1 1 23a3
3 23aa 23ab 23ac
4 2341 2385 23a4
23ae 1 23b0 3
22b3 2331 23b1 3
23b3 2242 23b4 2
44c 23b5 1 23b7
4 23cb 23cc 23cd
23ce 2 23da 23dc
3 23d8 23d9 23de
2 23e7 23e9 2
23eb 23ed 2 23ef
23f1 1 23f9 2
23fb 23fc 2 23f3
23fe 2 2400 2402
2 2404 2406 2
2408 240a 2 240c
240e 2 23e6 2410
1 2412 1 2414
3 241b 241c 241d
10 2ff 31e 321
324 327 32a 32d
39e 23b8 23bb 23be
23c1 23c6 23d1 2415
241f 2 242c 242e
3 242a 242b 2430
2 2439 243b 2
2438 243d 2 2444
2448 2 244a 244c
2 244e 2452 2
2443 2454 2 243f
2456 1 2458 3
2459 2464 2468 1
2423 2 247b 247d
3 2479 247a 247f
2 2488 248a 2
2487 248c 2 2493
2495 2 2497 2499
3 249e 249f 24a0
2 249b 24a2 2
2492 24a4 2 248e
24a6 1 24a8 4
2472 24a9 24b2 24b6
1 24ba 1 246d
2 246b 24be 57
33 3a 41 48
4f 56 5d 64
6b 72 79 80
87 8c 91 96
9b a0 a5 aa
af b4 bb c2
c8 ce d4 d9
de e4 ea f0
f6 fc 102 108
10e 114 11a 121
128 12f 135 13b
141 147 14d 153
159 15f 165 16b
171 177 17d 183
189 18f 195 19b
1a1 1a7 1ad 1b3
1b9 1bf 1c6 1cd
1d3 1da 1e0 1e6
1ec 1f2 1f8 1fe
204 20a 210 216
21c 223 228 22d
234 23b 242 
1
4
0 
24c5
0
1
50
4f
61
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 1 2f
1 31 1 33 1 35 1 37
1 39 1 3b 1 3d 1 3f
1 41 1 43 1 45 1 47
1 49 1 4b 1 4d 1 0

1a3 1 0
43 1 0
1cf 1 0
ec 1 0
218 1 0
9d 1 0
13d 1 0
1e8 1 0
f 1 0
fe 1 0
191 1 0
22a 1 0
93 1 0
1b5 1 0
d0 1 0
1d5 1 0
155 1 0
1a9 1 0
161 1 0
13 1 0
23 1 0
7 1 0
bd 1 0
98 1 0
1f4 1 0
22f 1 0
1c8 1 0
10a 1 0
21e 1 0
1fa 1 0
3c 1 0
1bb 1 0
104 1 0
d6 1 0
1e2 1 0
167 1 0
143 1 0
17f 1 0
19d 1 0
db 1 0
131 1 0
a2 1 0
66 1 0
149 1 0
f8 1 0
8e 1 0
206 1 0
116 1 0
c4 1 0
58 1 0
2e 1 0
18b 1 0
74 1 0
225 1 0
236 1 0
1af 1 0
ac 1 0
1dc 1 0
e6 1 0
212 1 0
35 1 0
3 1 0
ca 1 0
f2 1 0
11c 1 0
89 1 0
14f 1 0
197 1 0
15b 1 0
179 1 0
b6 1 0
82 1 0
b1 1 0
200 1 0
16d 1 0
110 1 0
123 1 0
7b 1 0
173 1 0
b 1 0
6d 1 0
5f 1 0
17 1 0
e0 1 0
1b 1 0
1ee 1 0
a7 1 0
1f 1 0
51 1 0
185 1 0
12a 1 0
2 0 1
1c1 1 0
4a 1 0
137 1 0
20c 1 0
23d 1 0
0

/
SHOW ERRORS FUNCTION SP_U_PARTICIPANT;
ALTER FUNCTION SP_U_PARTICIPANT COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_CRI_SECURITY ==
CREATE OR REPLACE FUNCTION SP_U_CRI_SECURITY wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
71
2 :e:
1FUNCTION:
1SP_U_CRI_SECURITY:
1ASSIGN_ID:
1VARCHAR2:
1SECURITY_ID001:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1P_DELAY:
1PLS_INTEGER:
1P_UNITS:
1P_WORK_PERCENT:
1P_ACTUAL:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1A_ELEMENT_ID:
132:
1A_PARTICIPANT_ID:
1255:
1A_PARTICIPANT_NAME:
1A_SECURITY_NAME:
1H_FULL_NAME:
1A_RES_ASSIGNMENT_ID:
1A_SECURITY_ID:
1A_TEMP_ID:
1H_CREATED_BY:
1H_PROJECT_ID:
1A_ASSIGNMENT_COUNT:
10:
1A_ELEMENT_TYPE:
1H_RESPONSIBLE:
1A_PARTICIPANT:
1A_RESOURCE_TYPE:
1A_SECURITY_VALUE:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_ASSIGN_STRING:
18192:
1H_TEMP_RES_TYPE:
11:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_WBS_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TRANSFED_CRI:
1H_CRI_TABLE:
1H_CRI_ELEMENT_TYPE:
1H_REC_USER:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_CRI_SECURITY(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_U_CRI_SECURITY(61) :: cplan.sql(16879) :: :
1:
1PMO_CNST:
1SC_TABLE_CRI:
1SC_STATE:
1FC_U_ASSIGNED_SECURITY:
14:
176:
1       RETURN_STATUS:: SP_U_CRI_SECURITY(77) :: cplan.sql(16895) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
183:
1           EXCEPTION:: SP_U_CRI_SECURITY(84) :: cplan.sql(16902) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
195:
1           EXCEPTION:: SP_U_CRI_SECURITY(96) :: cplan.sql(16914) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2e4
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :2 a0 6e 7e
a0 b4 2e 7e 6e b4 2e 6e
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :2 a0 6e 7e a0
b4 2e 7e 6e b4 2e 6e a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 6e
d :2 a0 d :2 a0 d :2 a0 d :3 a0
6b d :2 a0 6b :5 a0 a5 b d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
2e4
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 a2
c8 cc d0 d4 d7 db f8 e3
e7 ea eb f3 e2 115 103 df
107 108 110 102 132 120 ff 124
125 12d 11f 14f 13d 11c 141 142
14a 13c 16c 15a 139 15e 15f 167
159 189 177 156 17b 17c 184 176
1a6 194 173 198 199 1a1 193 1c3
1b1 190 1b5 1b6 1be 1b0 1e0 1ce
1ad 1d2 1d3 1db 1cd 1fd 1eb 1ca
1ef 1f0 1f8 1ea 219 208 20c 1e7
214 207 235 224 228 204 230 223
251 240 244 220 24c 23f 26d 25c
260 23c 268 25b 289 278 27c 258
284 277 2a5 294 298 274 2a0 293
2c1 2b0 2b4 290 2bc 2af 2dd 2cc
2d0 2ac 2d8 2cb 2f9 2e8 2ec 2c8
2f4 2e7 316 304 2e4 308 309 311
303 333 321 300 325 326 32e 320
34f 33e 342 31d 34a 33d 36c 35a
33a 35e 35f 367 359 389 377 356
37b 37c 384 376 3a5 394 398 373
3a0 393 3c1 3b0 3b4 390 3bc 3af
3dd 3cc 3d0 3ac 3d8 3cb 3f9 3e8
3ec 3c8 3f4 3e7 415 404 408 3e4
410 403 432 420 400 424 425 42d
41f 452 43d 441 41c 445 44d 43c
459 45d 439 461 465 469 46c 471
472 1 474 479 47d 481 484 489
48d 491 494 499 49a 49c 4a1 4a4
4a8 4a9 4ae 4b3 4b6 4bb 4bc 4c1
4c4 4c8 4c9 4ce 4d1 4d6 4d7 4dc
4df 4e4 4e5 4ea 4ed 4f2 4f3 4f8
4fb 4ff 500 505 508 50d 50e 513
516 51b 51c 521 524 528 52c 531
534 538 539 53e 541 546 547 54c
551 552 554 559 55a 55c 55d 562
565 56a 56b 570 573 577 57b 580
583 587 588 58d 590 595 596 59b
5a0 5a1 5a3 5a8 5a9 5ab 5ac 5b1
5b4 5b9 5ba 5bf 5c2 5c6 5ca 5ce
5cf 5d1 5d6 5d7 5d9 5da 5df 5e2
5e7 5e8 5ed 5f0 5f4 5f8 5fc 5fd
5ff 604 605 607 608 60d 610 615
616 61b 61e 622 626 62a 62b 62d
632 633 635 636 63b 63e 643 644
649 64c 650 654 658 659 65b 660
661 663 664 669 66c 671 672 677
67a 67f 680 685 688 68c 68d 692
695 69a 69b 6a0 6a3 6a8 6a9 6ae
6af 6b4 6b6 6ba 6bd 6c1 6c5 6c8
6cc 6d0 6d3 6d6 6db 6de 6e1 6e4
6e5 6ea 6eb 1 6ed 6f2 6f6 6fa
6fd 702 707 70a 70e 70f 714 715
71a 71c 720 723 727 72c 730 734
738 73c 740 744 748 74c 750 754
758 75c 760 763 767 76b 76f 772
776 77a 77e 782 786 787 789 78d
791 795 798 79c 7a0 7a3 7a6 7ab
7ae 7b1 7b4 7b5 7ba 7bb 1 7bd
7c2 7c6 7ca 7cd 7d2 7d7 7da 7de
7df 7e4 7e7 7ec 7ed 7f2 7f5 7fa
7fb 800 803 807 80b 80f 813 816
817 819 81e 81f 821 822 827 82a
82f 830 835 838 83d 83e 843 846
84a 84b 850 853 858 859 85e 85f
864 866 86a 86d 871 875 878 87c
880 883 887 88b 88c 891 893 897
89b 89e 8a2 8a6 8a9 8ad 8b1 8b4
8b7 8bc 8bf 8c2 8c5 8c6 8cb 8cc
1 8ce 8d3 8d7 8db 8de 8e3 8e8
8eb 8ef 8f0 8f5 8f6 8fb 8ff 903
906 90b 910 913 917 91b 91e 91f
924 927 92c 92d 932 935 939 93d
940 941 946 947 94c 94e 952 955
959 95d 961 965 969 96d 971 975
979 985 98a 98e 992 996 99a 99c
99d 9a2 1 9a6 9aa 9ae 9b1 9b5
9b9 9bd 9c1 9c4 9c8 9cc 9cf 9d2
9d7 9da 9dd 9e0 9e1 9e6 9e7 1
9e9 9ee 9f2 9f6 9f9 9fe a03 a06
a0a a0b a10 a11 a16 a1a a1e a21
a26 a2b a2e a32 a33 a38 a3b a40
a41 a46 a49 a4d a51 a54 a57 a58
a5a a5b a60 a61 a66 a68 a6c a6f
a73 a77 a7b a7f a83 a87 a8b a97
a9c aa0 aa4 aa8 aac aae ab2 ab4
ac0 ac2 ac4 ac5 aca ace ad0 adc
ae0 ae2 ae3 aec 
2e4
2
0 1 a 6 10 :3 6 15 :3 6
16 :3 6 17 :3 6 e :3 6 e :3 6
15 :3 6 f :3 6 10 :2 6 1 3
a 13 a :2 1 4 11 1a 19
:2 11 :2 4 15 1e 1d :2 15 :2 4 17
20 1f :2 17 :2 4 14 1d 1c :2 14
:2 4 10 19 18 :2 10 :2 4 18 21
20 :2 18 :2 4 12 1b 1a :2 12 :2 4
e 17 16 :2 e :2 4 11 1a 19
:2 11 :2 4 11 1a 19 :2 11 :2 4 :2 17
26 17 :2 4 :2 13 22 13 :2 4 :2 12
21 12 :2 4 :2 12 21 12 :2 4 :2 14
23 14 :2 4 :2 15 24 15 :2 4 :2 12
21 12 :2 4 :2 d 1c d :2 4 :2 11
20 11 :2 4 14 1d 1c :2 14 :2 4
14 1d 1c :2 14 :2 4 :2 17 26 17
:2 4 17 20 1f :2 17 :2 4 16 1f
1e :2 16 :2 4 :2 13 22 13 :2 4 :2 14
23 14 :2 4 :2 13 22 13 :2 4 :2 10
1f 10 :2 4 :2 17 26 17 :2 4 f
18 17 :2 f :2 4 e 17 :3 e 4
7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 59 5f 62
:2 59 70 8b 8 :2 70 d 10 :2 70
1a 1d :2 70 b e :2 70 13 16
:2 70 1b 1e :2 70 2d 30 :2 70 b
e :2 70 13 16 1f 26 2b 2e
:2 26 3e 41 :2 26 46 :2 1f 4f :2 16
:2 70 b e :2 70 13 16 1f 26
2b 2e :2 26 3f 42 :2 26 47 :2 1f
50 :2 16 :2 70 b e :2 70 13 16
1f 27 :2 1f 31 :2 16 :2 70 b e
:2 70 13 16 1f 27 :2 1f 31 :2 16
:2 70 b e :2 70 13 16 1f 27
:2 1f 38 :2 16 :2 70 b e :2 70 13
16 1f 27 :2 1f 32 :2 16 :2 70 b
e :2 70 13 16 :2 70 1b 1e :2 70
28 2b :2 70 30 33 :2 70 :2 7 4f
:2 4 7 :2 11 23 :2 2d 39 3c 51
53 54 :2 51 :2 23 :3 7 :2 d 12 1e
62 65 :2 1e :2 7 57 :3 4 14 :2 4
11 :2 4 15 :2 4 12 :2 4 14 :2 1d
:2 4 :2 d 19 30 3e 49 58 :2 19
4 7 :2 11 23 :2 2d 39 3c 51
53 54 :2 51 :2 23 :3 7 :2 d 12 1e
62 65 :2 1e 72 75 :2 1e 79 7c
:2 1e 86 89 92 9a :2 a3 :2 92 ae
:2 89 :2 1e b6 b9 :2 1e c1 c4 :2 1e
c9 cc :2 1e d6 d9 :2 1e :2 7 57
:3 4 :2 f 21 :2 2a 34 3f :2 4 1
9 12 9 a :2 14 26 :2 30 3c
40 55 57 58 :2 55 :2 26 :3 a :2 10
15 21 65 68 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 5b :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 52 54 55 :2 52 :2 23 :3 7 :2 d
12 1e 62 65 :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 58
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
2e4
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b 2
:4 c :2 1 :7 e :7 f
:7 10 :7 11 :7 12 :7 13
:7 14 :7 15 :7 16 :7 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :7 21 :7 22 :6 23
:7 24 :7 25 :6 26 :6 27
:6 28 :6 29 :6 2a :7 2b
:7 2d :b 2f :11 30 31
:2 30 :2 31 :2 30 :2 31
:2 30 :2 32 :2 30 :2 32
:2 30 :2 32 :2 30 :2 32
:2 30 :2 33 :2 30 :12 33
:2 30 :2 34 :2 30 :12 34
:2 30 :2 35 :2 30 :9 35
:2 30 :2 36 :2 30 :9 36
:2 30 :2 37 :2 30 :9 37
:2 30 :2 38 :2 30 :9 38
:2 30 :2 39 :2 30 :2 39
:2 30 :2 39 :2 30 :2 39
:2 30 :2 39 :4 30 :3 2f
:11 3c :b 3d :3 3c :3 42
:3 45 :3 46 :3 47 :5 49
:b 4a :11 4c :30 4d :3 4c
:a 4f 2e :3 52 :11 53
:b 54 :17 55 :3 53 :2 57
:3 58 :3 59 5a 58
57 58 :3 5b :3 52
:2 5c :5 5e :11 5f :b 60
:18 61 :3 5f :2 63 64
:3 65 66 64 63
64 :3 67 :2 5d :6 5c
51 :7 1 
aee
4
:3 0 1 :3 0 2
:a 0 2df 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 7 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 7 :3 0 8
:7 0 11 10 :3 0
a :3 0 9 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 b :7 0 19
18 :3 0 a :3 0
c :7 0 1d 1c
:3 0 15 :2 0 13
a :3 0 d :7 0
21 20 :3 0 4
:3 0 e :7 0 25
24 :3 0 f :3 0
10 :3 0 11 :2 0
4 29 2a 0
27 2b 0 2df
2 2c :2 0 15
:2 0 21 4 :3 0
13 :2 0 1f 2f
31 :6 0 34 32
0 2dd 0 12
:6 0 15 :2 0 25
4 :3 0 23 36
38 :6 0 3b 39
0 2dd 0 14
:6 0 13 :2 0 29
4 :3 0 27 3d
3f :6 0 42 40
0 2dd 0 16
:6 0 15 :2 0 2d
4 :3 0 2b 44
46 :6 0 49 47
0 2dd 0 17
:6 0 13 :2 0 31
4 :3 0 2f 4b
4d :6 0 50 4e
0 2dd 0 18
:6 0 13 :2 0 35
4 :3 0 33 52
54 :6 0 57 55
0 2dd 0 19
:6 0 13 :2 0 39
4 :3 0 37 59
5b :6 0 5e 5c
0 2dd 0 1a
:6 0 13 :2 0 3d
4 :3 0 3b 60
62 :6 0 65 63
0 2dd 0 1b
:6 0 13 :2 0 41
4 :3 0 3f 67
69 :6 0 6c 6a
0 2dd 0 1c
:6 0 1f :2 0 45
4 :3 0 43 6e
70 :6 0 73 71
0 2dd 0 1d
:6 0 1f :2 0 47
a :3 0 75 :7 0
79 76 77 2dd
0 1e :6 0 1f
:2 0 49 a :3 0
7b :7 0 7f 7c
7d 2dd 0 20
:6 0 1f :2 0 4b
a :3 0 81 :7 0
85 82 83 2dd
0 21 :6 0 1f
:2 0 4d a :3 0
87 :7 0 8b 88
89 2dd 0 22
:6 0 1f :2 0 4f
a :3 0 8d :7 0
91 8e 8f 2dd
0 23 :6 0 1f
:2 0 51 a :3 0
93 :7 0 97 94
95 2dd 0 24
:6 0 1f :2 0 53
a :3 0 99 :7 0
9d 9a 9b 2dd
0 25 :6 0 1f
:2 0 55 a :3 0
9f :7 0 a3 a0
a1 2dd 0 26
:6 0 29 :2 0 57
a :3 0 a5 :7 0
a9 a6 a7 2dd
0 27 :6 0 2b
:2 0 5b 4 :3 0
59 ab ad :6 0
b0 ae 0 2dd
0 28 :6 0 1f
:2 0 5f 4 :3 0
5d b2 b4 :6 0
b7 b5 0 2dd
0 2a :6 0 13
:2 0 61 a :3 0
b9 :7 0 bd ba
bb 2dd 0 2c
:6 0 13 :2 0 65
4 :3 0 63 bf
c1 :6 0 c4 c2
0 2dd 0 2d
:6 0 1f :2 0 69
4 :3 0 67 c6
c8 :6 0 cb c9
0 2dd 0 2e
:6 0 1f :2 0 6b
a :3 0 cd :7 0
d1 ce cf 2dd
0 2f :6 0 1f
:2 0 6d a :3 0
d3 :7 0 d7 d4
d5 2dd 0 30
:6 0 1f :2 0 6f
a :3 0 d9 :7 0
dd da db 2dd
0 31 :6 0 1f
:2 0 71 a :3 0
df :7 0 e3 e0
e1 2dd 0 32
:6 0 13 :2 0 73
a :3 0 e5 :7 0
e9 e6 e7 2dd
0 33 :6 0 f2
f3 0 77 4
:3 0 75 eb ed
:6 0 f0 ee 0
2dd 0 34 :6 0
f8 f9 0 79
10 :3 0 11 :2 0
4 f4 :7 0 f7
f5 0 2dd 0
35 :6 0 36 :3 0
37 :3 0 36 :3 0
38 :3 0 fb fc
0 2 :4 0 7b
fd ff fa 101
100 :2 0 39 :3 0
3a :3 0 103 104
0 3b :4 0 36
:3 0 3c :3 0 107
108 0 2 :4 0
7d 109 10b 3d
:4 0 3e :2 0 3f
:3 0 7f 10e 110
:3 0 40 :4 0 3e
:2 0 41 :4 0 82
113 115 :3 0 3e
:2 0 3 :3 0 85
117 119 :3 0 3e
:2 0 41 :4 0 88
11b 11d :3 0 3e
:2 0 42 :4 0 8b
11f 121 :3 0 3e
:2 0 41 :4 0 8e
123 125 :3 0 3e
:2 0 5 :3 0 91
127 129 :3 0 3e
:2 0 41 :4 0 94
12b 12d :3 0 3e
:2 0 42 :4 0 97
12f 131 :3 0 3e
:2 0 43 :3 0 44
:3 0 41 :4 0 3e
:2 0 6 :3 0 9a
137 139 :3 0 3e
:2 0 41 :4 0 9d
13b 13d :3 0 45
:4 0 a0 135 140
46 :4 0 a3 134
143 a6 133 145
:3 0 3e :2 0 42
:4 0 a9 147 149
:3 0 3e :2 0 43
:3 0 44 :3 0 41
:4 0 3e :2 0 8
:3 0 ac 14f 151
:3 0 3e :2 0 41
:4 0 af 153 155
:3 0 45 :4 0 b2
14d 158 46 :4 0
b5 14c 15b b8
14b 15d :3 0 3e
:2 0 42 :4 0 bb
15f 161 :3 0 3e
:2 0 43 :3 0 47
:3 0 9 :3 0 be
165 167 46 :4 0
c0 164 16a c3
163 16c :3 0 3e
:2 0 42 :4 0 c6
16e 170 :3 0 3e
:2 0 43 :3 0 47
:3 0 b :3 0 c9
174 176 46 :4 0
cb 173 179 ce
172 17b :3 0 3e
:2 0 42 :4 0 d1
17d 17f :3 0 3e
:2 0 43 :3 0 47
:3 0 c :3 0 d4
183 185 46 :4 0
d6 182 188 d9
181 18a :3 0 3e
:2 0 42 :4 0 dc
18c 18e :3 0 3e
:2 0 43 :3 0 47
:3 0 d :3 0 df
192 194 46 :4 0
e1 191 197 e4
190 199 :3 0 3e
:2 0 42 :4 0 e7
19b 19d :3 0 3e
:2 0 41 :4 0 ea
19f 1a1 :3 0 3e
:2 0 e :3 0 ed
1a3 1a5 :3 0 3e
:2 0 41 :4 0 f0
1a7 1a9 :3 0 3e
:2 0 48 :4 0 f3
1ab 1ad :3 0 f6
105 1af :2 0 1b1
fb 1b2 102 1b1
0 1b3 fd 0
23d 36 :3 0 37
:3 0 1b4 1b5 0
36 :3 0 49 :3 0
1b7 1b8 0 2b
:2 0 2 :4 0 4a
:2 0 4b :2 0 2b
:2 0 ff 1bd 1bf
:3 0 102 1b9 1c1
1b6 1c3 1c2 :2 0
39 :3 0 4c :3 0
1c5 1c6 0 3b
:4 0 4d :4 0 3e
:2 0 3f :3 0 106
1ca 1cc :3 0 109
1c7 1ce :2 0 1d0
10c 1d1 1c4 1d0
0 1d2 10e 0
23d 1c :3 0 4e
:4 0 1d3 1d4 0
23d 1b :3 0 3
:3 0 1d6 1d7 0
23d 1a :3 0 5
:3 0 1d9 1da 0
23d 34 :3 0 e
:3 0 1dc 1dd 0
23d 27 :3 0 4f
:3 0 50 :3 0 1e0
1e1 0 1df 1e2
0 23d 10 :3 0
51 :3 0 1e4 1e5
0 52 :3 0 27
:3 0 1b :3 0 1a
:3 0 34 :3 0 110
1e7 1ec 1e6 1ed
0 23d 36 :3 0
37 :3 0 1ef 1f0
0 36 :3 0 49
:3 0 1f2 1f3 0
53 :2 0 2 :4 0
54 :2 0 4b :2 0
2b :2 0 115 1f8
1fa :3 0 118 1f4
1fc 1f1 1fe 1fd
:2 0 39 :3 0 4c
:3 0 200 201 0
3b :4 0 55 :4 0
3e :2 0 3f :3 0
11c 205 207 :3 0
3e :2 0 56 :4 0
11f 209 20b :3 0
3e :2 0 57 :4 0
122 20d 20f :3 0
3e :2 0 43 :3 0
47 :3 0 10 :3 0
51 :3 0 214 215
0 125 213 217
46 :4 0 127 212
21a 12a 211 21c
:3 0 3e :2 0 58
:4 0 12d 21e 220
:3 0 3e :2 0 41
:4 0 130 222 224
:3 0 3e :2 0 1b
:3 0 133 226 228
:3 0 3e :2 0 41
:4 0 136 22a 22c
:3 0 139 202 22e
:2 0 230 13c 231
1ff 230 0 232
13e 0 23d 59
:3 0 5a :3 0 233
234 0 10 :3 0
51 :3 0 236 237
0 1b :3 0 5b
:3 0 140 235 23b
:2 0 23d 144 2de
10 :3 0 5c :2 0
4 23e 23f 0
36 :3 0 37 :3 0
241 242 0 36
:3 0 49 :3 0 244
245 0 5d :2 0
2 :4 0 5e :2 0
4b :2 0 2b :2 0
14f 24a 24c :3 0
152 246 24e 243
250 24f :2 0 39
:3 0 4c :3 0 252
253 0 3b :4 0
5f :4 0 3e :2 0
3f :3 0 156 257
259 :3 0 159 254
25b :2 0 274 39
:3 0 4c :3 0 25d
25e 0 3b :4 0
60 :4 0 3e :2 0
10 :3 0 61 :3 0
263 264 0 15c
262 266 :3 0 3e
:2 0 58 :4 0 15f
268 26a :3 0 3e
:2 0 10 :3 0 62
:3 0 26d 26e 0
162 26c 270 :3 0
165 25f 272 :2 0
274 168 275 251
274 0 276 16b
0 286 63 :3 0
35 :3 0 10 :3 0
61 :3 0 64 :3 0
10 :3 0 62 :3 0
65 :3 0 66 :4 0
67 1 :a 0 282
:2 0 286 278 280
:2 0 f :3 0 35
:3 0 284 :2 0 286
16d 288 171 287
286 :2 0 2dc 68
:3 0 10 :3 0 51
:3 0 28b 28c 0
69 :3 0 28d 28e
0 2d4 36 :3 0
37 :3 0 290 291
0 36 :3 0 49
:3 0 293 294 0
5d :2 0 2 :4 0
6a :2 0 4b :2 0
2b :2 0 173 299
29b :3 0 176 295
29d 292 29f 29e
:2 0 39 :3 0 4c
:3 0 2a1 2a2 0
3b :4 0 6b :4 0
3e :2 0 3f :3 0
17a 2a6 2a8 :3 0
17d 2a3 2aa :2 0
2c4 39 :3 0 4c
:3 0 2ac 2ad 0
3b :4 0 6c :4 0
3e :2 0 69 :3 0
180 2b1 2b3 :3 0
3e :2 0 6d :4 0
183 2b5 2b7 :3 0
3e :2 0 6e :3 0
6f :3 0 2b :2 0
70 :2 0 186 2ba
2be 18a 2b9 2c0
:3 0 18d 2ae 2c2
:2 0 2c4 190 2c5
2a0 2c4 0 2c6
193 0 2d4 63
:3 0 35 :3 0 64
:3 0 10 :3 0 62
:3 0 65 :3 0 66
:4 0 71 1 :a 0
2d0 :2 0 2d4 2c8
2ce :2 0 f :3 0
35 :3 0 2d2 :2 0
2d4 195 2d7 :3 0
2d7 0 2d7 2d6
2d4 2d5 :6 0 2d9
1 :3 0 19a 2db
19c 2da 2d9 :2 0
2dc 19e :2 0 2de
1a1 2de 2dd 23d
2dc :6 0 2df :2 0
2 2c 2de 2e2
:3 0 2e1 2df 2e3
:8 0 
1c1
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 9
6 a e 12
16 1a 1e 22
26 1 30 1
2e 1 37 1
35 1 3e 1
3c 1 45 1
43 1 4c 1
4a 1 53 1
51 1 5a 1
58 1 61 1
5f 1 68 1
66 1 6f 1
6d 1 74 1
7a 1 80 1
86 1 8c 1
92 1 98 1
9e 1 a4 1
ac 1 aa 1
b3 1 b1 1
b8 1 c0 1
be 1 c7 1
c5 1 cc 1
d2 1 d8 1
de 1 e4 1
ec 1 ea 1
f1 1 fe 1
10a 2 10d 10f
2 112 114 2
116 118 2 11a
11c 2 11e 120
2 122 124 2
126 128 2 12a
12c 2 12e 130
2 136 138 2
13a 13c 2 13e
13f 2 141 142
2 132 144 2
146 148 2 14e
150 2 152 154
2 156 157 2
159 15a 2 14a
15c 2 15e 160
1 166 2 168
169 2 162 16b
2 16d 16f 1
175 2 177 178
2 171 17a 2
17c 17e 1 184
2 186 187 2
180 189 2 18b
18d 1 193 2
195 196 2 18f
198 2 19a 19c
2 19e 1a0 2
1a2 1a4 2 1a6
1a8 2 1aa 1ac
4 106 10c 111
1ae 1 1b0 1
1b2 2 1bc 1be
3 1ba 1bb 1c0
2 1c9 1cb 2
1c8 1cd 1 1cf
1 1d1 4 1e8
1e9 1ea 1eb 2
1f7 1f9 3 1f5
1f6 1fb 2 204
206 2 208 20a
2 20c 20e 1
216 2 218 219
2 210 21b 2
21d 21f 2 221
223 2 225 227
2 229 22b 2
203 22d 1 22f
1 231 3 238
239 23a a 1b3
1d2 1d5 1d8 1db
1de 1e3 1ee 232
23c 2 249 24b
3 247 248 24d
2 256 258 2
255 25a 2 261
265 2 267 269
2 26b 26f 2
260 271 2 25c
273 1 275 3
276 281 285 1
240 2 298 29a
3 296 297 29c
2 2a5 2a7 2
2a4 2a9 2 2b0
2b2 2 2b4 2b6
3 2bb 2bc 2bd
2 2b8 2bf 2
2af 2c1 2 2ab
2c3 1 2c5 4
28f 2c6 2cf 2d3
1 2d7 1 28a
2 288 2db 1f
33 3a 41 48
4f 56 5d 64
6b 72 78 7e
84 8a 90 96
9c a2 a8 af
b6 bc c3 ca
d0 d6 dc e2
e8 ef f6 
1
4
0 
2e2
0
1
14
2
29
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
3c 1 0
b8 1 0
80 1 0
f 1 0
92 1 0
be 1 0
13 1 0
23 1 0
7 1 0
b1 1 0
9e 1 0
35 1 0
98 1 0
d2 1 0
c5 1 0
e4 1 0
5f 1 0
8c 1 0
d8 1 0
51 1 0
66 1 0
cc 1 0
7a 1 0
2e 1 0
3 1 0
86 1 0
de 1 0
2 0 1
a4 1 0
6d 1 0
b 1 0
58 1 0
17 1 0
74 1 0
1b 1 0
1f 1 0
4a 1 0
ea 1 0
aa 1 0
43 1 0
f1 1 0
0

/
SHOW ERRORS FUNCTION SP_U_CRI_SECURITY;
ALTER FUNCTION SP_U_CRI_SECURITY COMPILE DEBUG;
/****************************************************************************************
 id = TSK_ASSIGN_ID
 bitflag:
        1 = Copy Schedule to Baseline (includes budgets)
        2 = Copy Planned to Schedule
        3 = Copy Proposed to Schedule
        4 = Copy Forecast to Schedule (includes budgets)
        5 = Copy Forecast  Scheduled to Planned
        6 = Move Planned to Schedule
        7 = Append Planned to Schedule
 bussiness rules:
    1. Do not copy date for completed tasks (MILESTONE_PERCENT = 100)
    2. If the task has ACTUAL do not change ETC, WORK_TODATE, SD, FD
    3. When copy Forecast Date to ..., ETC is Forecast Effort, and clear Forcast dates after copy
    4. If both Forcast dates exists ignor forcast start, consider only forcast finish and ETC
    5. Calculated Forecast Start should not be in the past (is >= NOW)
    6. When copy Forcast to and assignments exists forcast rollup wins, and clear Forcast dates after copy
    7. Actual Finish date does not rollup from Assignments to Task
    8. When copy Planned to Schedule clear Planned Dates, Duration  Effort
****************************************************************************************/
Prompt == FUNCTION SP_COMMIT_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_COMMIT_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
191
2 :e:
1FUNCTION:
1SP_COMMIT_ASSIGN:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_BITID:
1RAW:
136:
1PMO_CNST:
1SC_ZERO_BIT:
1H_BITID1:
1H_PROJECT_ID:
132:
1H_DAYOFYEAR:
1DATE:
1H_RES_ID:
1H_TASK_ID:
1H_ID:
1H_TSK_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_SCHED_WORK:
10:
1H_BILLABLE:
1H_TOTAL:
1H_DAY_MIN:
1H_BITFLAG:
1H_MIN_PER_DAY:
1H_CHANGE_FLAG:
1H_TYPE_ID:
1H_FROM_PRJ:
1H_TSK_PRJ:
1H_WORK:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1STMT:
17999:
1CURSOR:
1C270:
1TA:
1TSK_ASSIGNMENT_ID:
1RESOURCE_ID:
1TASK_ASSIGNMENTS:
1JOIN:
1TMT_WBS:
1W:
1PROJECT_ID:
1ELEMENT_ID:
1TASK_ID:
1BIT_FLAG:
1RESOURCE_TYPE:
1PROJECT_ASSIGNMENT_ID:
1SELECT TA.TSK_ASSIGNMENT_ID, TA.RESOURCE_ID:n         FROM TASK_ASSIGNMENTS T+
1A JOIN TMT_WBS W:n         ON W.PROJECT_ID = TA.PROJECT_ID AND W.ELEMENT_ID =+
1 TA.TASK_ID:n         WHERE W.PROJECT_ID = h_project_id AND TA.BIT_FLAG = '0'+
1:n         AND TA.RESOURCE_TYPE = '0' AND TA.PROJECT_ASSIGNMENT_ID IS Null:
1CMM1:
1C27:
1DAY_YEAR:
1SCHED_MIN:
1BIT_SCHED:
1TASK_DAY_OF_YEAR:
1SELECT DAY_YEAR, SCHED_MIN, BIT_SCHED FROM TASK_DAY_OF_YEAR:n         WHERE P+
1ROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_id AND BIT_FLAG = '0':
1C54:
1SELECT TASK_ID, TSK_ASSIGNMENT_ID:n         FROM TASK_ASSIGNMENTS:n         W+
1HERE BIT_FLAG = '0' AND PROJECT_ASSIGNMENT_ID = h_id:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_COMMIT_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
162:
1+:
1FPUT:
1               ENTER:: SP_COMMIT_ASSIGN(63) :: cplan.sql(17014) :: :
1MINUTE_PER_DAY:
1SELECT COALESCE(MINUTE_PER_DAY, 480) INTO h_min_per_day FROM TMT_WBS WHERE EL+
1EMENT_ID = h_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
179:
1           EXCEPTION:: SP_COMMIT_ASSIGN(80) :: cplan.sql(17031) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1MILESTONE_PERCENT:
1SELECT PROJECT_ID, CASE WHEN PROJECT_ID = TASK_ID THEN 1 ELSE 0 END, CASE WHE+
1N PROJECT_ASSIGNMENT_ID IS NuLL THEN 0 ELSE 1 END:n         INTO h_project_id+
1,h_tsk_prj,h_from_prj:n         FROM TASK_ASSIGNMENTS WHERE MILESTONE_PERCENT+
1 < 10000 AND RESOURCE_TYPE='0' AND TSK_ASSIGNMENT_ID = h_id:
196:
1           EXCEPTION:: SP_COMMIT_ASSIGN(97) :: cplan.sql(17048) :: :
18:
1103:
1      RETURN_INVALID:: SP_COMMIT_ASSIGN(104) :: cplan.sql(17055) :: :
1STATE:: :
1RECORD_NOT_FOUND:
1106:
1                EXIT:: SP_COMMIT_ASSIGN(107) :: cplan.sql(17058) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1ELSIF:
1111:
1        RETURN_ERROR:: SP_COMMIT_ASSIGN(112) :: cplan.sql(17063) :: :
1PROJECT_ASSIGNMENT_EXISTS:
1 ID:: :
1114:
1                EXIT:: SP_COMMIT_ASSIGN(115) :: cplan.sql(17066) :: :
1PMO_RETURN_ERROR_SP:
1SELECT COALESCE(MINUTE_PER_DAY, 480) INTO h_min_per_day FROM TMT_WBS WHERE EL+
1EMENT_ID = h_project_id:
1127:
1           EXCEPTION:: SP_COMMIT_ASSIGN(128) :: cplan.sql(17079) :: :
1SELECT TSK_ASSIGNMENT_ID, RESOURCE_ID, TASK_ID, C_EFFORT FROM TASK_ASSIGNMENT+
1S :
1WHERE TSK_ASSIGNMENT_ID = ':
1' AND MILESTONE_PERCENT < 10000 AND RESOURCE_TYPE='0' AND BIT_FLAG = '0' :
13:
1TYPE_ID:
1SC_PROPOSAL:
1SC_PROJECT:
1SCHED_START:
1PLANNED_START:
1SCHED_FINISH:
1PLANNED_FINISH:
1SCHED_DURATION:
1PLANNED_DURATION:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1FORECAST_FINISH:
1FORECAST_EFFORT:
1ETC:
1FORECAST_DURATION:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1ASSIGN_COUNT:
1WORK_TODATE:
1UPDATE TMT_WBS SET:n            TYPE_ID         = CASE WHEN TYPE_ID = PMO_CNS+
1T.SC_PROPOSAL THEN PMO_CNST.SC_PROJECT ELSE TYPE_ID END,:n            SCHED_S+
1TART     = COALESCE(PLANNED_START, SCHED_START),:n            SCHED_FINISH   +
1 = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n            SCHED_DURATION  = CAS+
1E WHEN PLANNED_DURATION = 0 THEN SCHED_DURATION ELSE PLANNED_DURATION END,:n +
1           SCHED_EFFORT    = PLANNED_EFFORT,:n            PLANNED_START   = N+
1ull,:n            PLANNED_FINISH  = Null,:n            PLANNED_DURATION = 0,+
1:n            FORECAST_START  = Null,:n            FORECAST_FINISH = Null,:n +
1           FORECAST_EFFORT = PLANNED_EFFORT,:n            ETC             = P+
1LANNED_EFFORT,:n            FORECAST_DURATION = 0:n            WHERE PROJECT_+
1ID = h_project_id AND TYPE_ID IN (PMO_CNST.SC_TASK,PMO_CNST.SC_TASK_TYPE1,PMO+
1_CNST.SC_TASK_TYPE2,PMO_CNST.SC_TASK_TYPE3,PMO_CNST.SC_MILESTONE,PMO_CNST.SC_+
1PERSONAL_TASK,PMO_CNST.SC_ACTIVE_ADM_TASK,PMO_CNST.SC_INACTIVE_ADM_TASK,PMO_C+
1NST.SC_WBS_CHANGE_REQUEST_TASK,PMO_CNST.SC_WBS_ACTION_ITEM_TASK,PMO_CNST.SC_W+
1BS_RISK_TASK,PMO_CNST.SC_WBS_ISSUE_TASK,PMO_CNST.SC_WBS_REQUIREMENT_TASK,PMO_+
1CNST.SC_WBS_DEFECT_TASK,PMO_CNST.SC_WBS_SERVICE_REQUEST_TASK) AND ASSIGN_COUN+
1T = 0 AND WORK_TODATE = 0 AND SCHED_EFFORT = 0:
1FOUND:
1100:
1167:
1           EXCEPTION:: SP_COMMIT_ASSIGN(168) :: cplan.sql(17119) :: :
1OPEN:
1LOOP:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
1SCHED_WORK:
1PLANNED_WORK:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1SCHED_LABOR_COST:
1PLANNED_LABOR_COST:
1SCHED_LABOR_REVENUE:
1PLANNED_LABOR_REVENUE:
1FORECAST_LABOR_COST:
1BILLABLE:
1REGULAR_COST:
1ACTUAL_LABOR_COST:
1FORECAST_LABOR_REVENUE:
1REGULAR_RATE:
1ACTUAL_LABOR_REVENUE:
1UPDATE TASK_ASSIGNMENTS SET:n               BIT_FLAG = '2',:n               S+
1CHED_START = COALESCE(PLANNED_START, SCHED_START),:n               SCHED_FINI+
1SH = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n               SCHED_DURATION =+
1 CASE WHEN PLANNED_DURATION > 0 THEN PLANNED_DURATION ELSE SCHED_DURATION END+
1,:n               SCHED_WORK = PLANNED_WORK,:n               ETC = PLANNED_WO+
1RK,:n               BAK_START_DT = COALESCE(PLANNED_START, SCHED_START),:n   +
1            BAK_FINISH_DT = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n        +
1       BAK_WORK = PLANNED_WORK,:n               SCHED_LABOR_COST = CASE WHEN +
1PLANNED_LABOR_COST > 0.00 THEN PLANNED_LABOR_COST ELSE SCHED_LABOR_COST END,+
1:n               SCHED_LABOR_REVENUE = CASE WHEN PLANNED_LABOR_REVENUE > 0.00+
1 THEN PLANNED_LABOR_REVENUE ELSE SCHED_LABOR_REVENUE END,:n               FOR+
1ECAST_LABOR_COST = CASE WHEN BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/6+
10.00) * REGULAR_COST) + ACTUAL_LABOR_COST END,:n               FORECAST_LABOR+
1_REVENUE = CASE WHEN BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * +
1REGULAR_RATE) + ACTUAL_LABOR_REVENUE END,:n               PLANNED_START = Nul+
1l, PLANNED_FINISH = Null, PLANNED_DURATION = 0, PLANNED_WORK = 0,:n          +
1     FORECAST_START = Null, FORECAST_FINISH = Null, FORECAST_DURATION = 0:n  +
1             WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1213:
1           EXCEPTION:: SP_COMMIT_ASSIGN(214) :: cplan.sql(17165) :: :
1UPDATE TASK_DAY_OF_YEAR SET BIT_FLAG = '2':n               WHERE PROJECT_ID =+
1 h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1231:
1           EXCEPTION:: SP_COMMIT_ASSIGN(232) :: cplan.sql(17183) :: :
1CLOSE:
1246:
1           EXCEPTION:: SP_COMMIT_ASSIGN(247) :: cplan.sql(17198) :: :
1ROLLUP_BITS:
1SC_ASSIGNMENT_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_CNST.SC_ASSIGNMENT_BIT:n         WHERE P+
1ROJECT_ID = h_project_id AND ASSIGN_COUNT > 0 AND WORK_TODATE = 0 AND SCHED_E+
1FFORT = 0:
1265:
1           EXCEPTION:: SP_COMMIT_ASSIGN(266) :: cplan.sql(17217) :: :
12:
1SELECT TSK_ASSIGNMENT_ID, RESOURCE_ID, TASK_ID, C_EFFORT FROM TASK_ASSIGNMENT+
1S WHERE PROJECT_ID = TASK_ID AND :
1PROJECT_ID = ':
1BUDGETS:
1B:
1ESTIMATED_BASELINE3:
1ESTIMATED_BASELINE2:
1ESTIMATED_BASELINE1:
1ESTIMATED_BUDGET:
1BUDGET_BASELINE3:
1BUDGET_BASELINE2:
1BUDGET_BASELINE1:
1BUDGET:
1UPDATE BUDGETS B SET:n               B.ESTIMATED_BASELINE3 = B.ESTIMATED_BASE+
1LINE2,:n               B.ESTIMATED_BASELINE2 = B.ESTIMATED_BASELINE1,:n      +
1         B.ESTIMATED_BASELINE1 = B.ESTIMATED_BUDGET,:n               B.BUDGET+
1_BASELINE3 = B.BUDGET_BASELINE2,:n               B.BUDGET_BASELINE2 = B.BUDGE+
1T_BASELINE1,:n               B.BUDGET_BASELINE1 = B.BUDGET:n               WH+
1ERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1323:
1           EXCEPTION:: SP_COMMIT_ASSIGN(324) :: cplan.sql(17275) :: :
1BASELINE3_START:
1BASELINE2_START:
1BASELINE3_FINISH:
1BASELINE2_FINISH:
1BASELINE3_DURATION:
1BASELINE2_DURATION:
1BASELINE3_WORK:
1BASELINE2_WORK:
1BASELINE3_LABOR_COST:
1BASELINE2_LABOR_COST:
1BASELINE3_LABOR_REVENUE:
1BASELINE2_LABOR_REVENUE:
1BASELINE1_START:
1BASELINE1_FINISH:
1BASELINE1_DURATION:
1BASELINE1_WORK:
1BASELINE1_LABOR_COST:
1BASELINE1_LABOR_REVENUE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1UNRESOLVED_DURATION:
1B_REGULAR_COST:
1B_REGULAR_RATE:
1B_SPECIAL_COST:
1SPECIAL_COST:
1B_SPECIAL_RATE:
1SPECIAL_RATE:
1UPDATE TASK_ASSIGNMENTS TA SET:n               TA.BASELINE3_START = TA.BASELI+
1NE2_START, TA.BASELINE3_FINISH = TA.BASELINE2_FINISH, TA.BASELINE3_DURATION =+
1 TA.BASELINE2_DURATION, TA.BASELINE3_WORK = TA.BASELINE2_WORK,:n             +
1  TA.BASELINE3_LABOR_COST = TA.BASELINE2_LABOR_COST, TA.BASELINE3_LABOR_REVEN+
1UE = TA.BASELINE2_LABOR_REVENUE,:n               TA.BASELINE2_START = TA.BASE+
1LINE1_START, TA.BASELINE2_FINISH = TA.BASELINE1_FINISH, TA.BASELINE2_DURATION+
1 = TA.BASELINE1_DURATION, TA.BASELINE2_WORK = TA.BASELINE1_WORK,:n           +
1    TA.BASELINE2_LABOR_COST = TA.BASELINE1_LABOR_COST, TA.BASELINE2_LABOR_REV+
1ENUE = TA.BASELINE1_LABOR_REVENUE,:n               TA.BASELINE1_START = TA.UN+
1RESOLVED_START, TA.BASELINE1_FINISH = TA.UNRESOLVED_FINISH, TA.BASELINE1_DURA+
1TION = TA.UNRESOLVED_DURATION, TA.BASELINE1_WORK = TA.SCHED_WORK + TA.PLANNED+
1_WORK,:n               TA.BASELINE1_LABOR_COST = TA.SCHED_LABOR_COST + TA.PLA+
1NNED_LABOR_COST, TA.BASELINE1_LABOR_REVENUE = TA.SCHED_LABOR_REVENUE + TA.PLA+
1NNED_LABOR_REVENUE,:n               TA.B_REGULAR_COST = TA.REGULAR_COST, TA.B+
1_REGULAR_RATE = TA.REGULAR_RATE, TA.B_SPECIAL_COST = TA.SPECIAL_COST, TA.B_SP+
1ECIAL_RATE = TA.SPECIAL_RATE:n               WHERE TSK_ASSIGNMENT_ID = h_id:
1349:
1           EXCEPTION:: SP_COMMIT_ASSIGN(350) :: cplan.sql(17301) :: :
1PROJECT_ASSIGNMENTS:
1ESTIMATED_BASELINE3_START:
1ESTIMATED_BASELINE2_START:
1ESTIMATED_BASELINE1_START:
1ESTIMATED_SCHED_START:
1ESTIMATED_PLANNED_START:
1ESTIMATED_BASELINE3_FINISH:
1ESTIMATED_BASELINE2_FINISH:
1ESTIMATED_BASELINE1_FINISH:
1ESTIMATED_SCHED_FINISH:
1ESTIMATED_PLANNED_FINISH:
1ESTIMATED_BASELINE3_EFFORT:
1ESTIMATED_BASELINE2_EFFORT:
1ESTIMATED_BASELINE1_EFFORT:
1ESTIMATED_SCHED_EFFORT:
1ESTIMATED_PLANNED_EFFORT:
1ESTIMATED_BASELINE3_COST:
1ESTIMATED_BASELINE2_COST:
1ESTIMATED_BASELINE1_COST:
1ESTIMATED_SCHED_COST:
1ESTIMATED_PLANNED_COST:
1ESTIMATED_BASELINE3_REVENUE:
1ESTIMATED_BASELINE2_REVENUE:
1ESTIMATED_BASELINE1_REVENUE:
1ESTIMATED_SCHED_REVENUE:
1ESTIMATED_PLANNED_REVENUE:
1BASELINE_START:
1BASELINE_FINISH:
1BASELINE_DURATION:
1BASELINE_WORK:
1BASELINE_LABOR_COST:
1BASELINE_LABOR_REVENUE:
1UPDATE PROJECT_ASSIGNMENTS SET:n               ESTIMATED_BASELINE3_START = ES+
1TIMATED_BASELINE2_START,:n               ESTIMATED_BASELINE2_START = ESTIMATE+
1D_BASELINE1_START,:n               ESTIMATED_BASELINE1_START = CASE WHEN ESTI+
1MATED_SCHED_START IS NOT NULL THEN ESTIMATED_SCHED_START ELSE ESTIMATED_PLANN+
1ED_START END,:n               ESTIMATED_BASELINE3_FINISH = ESTIMATED_BASELINE+
12_FINISH,:n               ESTIMATED_BASELINE2_FINISH = ESTIMATED_BASELINE1_FI+
1NISH,:n               ESTIMATED_BASELINE1_FINISH = CASE WHEN ESTIMATED_SCHED_+
1FINISH IS NOT NULL THEN ESTIMATED_SCHED_FINISH ELSE ESTIMATED_PLANNED_FINISH +
1END,:n               ESTIMATED_BASELINE3_EFFORT = ESTIMATED_BASELINE2_EFFORT,+
1:n               ESTIMATED_BASELINE2_EFFORT = ESTIMATED_BASELINE1_EFFORT,:n  +
1             ESTIMATED_BASELINE1_EFFORT = CASE WHEN ESTIMATED_SCHED_EFFORT > +
10 THEN ESTIMATED_SCHED_EFFORT ELSE ESTIMATED_PLANNED_EFFORT END,:n           +
1    ESTIMATED_BASELINE3_COST = ESTIMATED_BASELINE2_COST,:n               ESTI+
1MATED_BASELINE2_COST = ESTIMATED_BASELINE1_COST,:n               ESTIMATED_BA+
1SELINE1_COST = CASE WHEN ESTIMATED_SCHED_COST > 0.00 THEN ESTIMATED_SCHED_COS+
1T ELSE ESTIMATED_PLANNED_COST END,:n               ESTIMATED_BASELINE3_REVENU+
1E = ESTIMATED_BASELINE2_REVENUE,:n               ESTIMATED_BASELINE2_REVENUE +
1= ESTIMATED_BASELINE1_REVENUE,:n               ESTIMATED_BASELINE1_REVENUE = +
1CASE WHEN ESTIMATED_SCHED_REVENUE > 0.00 THEN ESTIMATED_SCHED_REVENUE ELSE ES+
1TIMATED_PLANNED_REVENUE END,:n               BASELINE_START = UNRESOLVED_STAR+
1T,:n               BASELINE_FINISH = UNRESOLVED_FINISH,:n               BASEL+
1INE_DURATION = UNRESOLVED_DURATION,:n               BASELINE_WORK = SCHED_WOR+
1K + PLANNED_WORK,:n               BASELINE_LABOR_COST = SCHED_LABOR_COST + PL+
1ANNED_LABOR_COST,:n               BASELINE_LABOR_REVENUE = SCHED_LABOR_REVENU+
1E + PLANNED_LABOR_REVENUE:n               WHERE PROJECT_ID = h_project_id:
1388:
1           EXCEPTION:: SP_COMMIT_ASSIGN(389) :: cplan.sql(17340) :: :
1SELECT PLANNED_WORK INTO h_day_min FROM TASK_ASSIGNMENTS WHERE BIT_FLAG = '0'+
1 AND TSK_ASSIGNMENT_ID = h_id:
1407:
1           EXCEPTION:: SP_COMMIT_ASSIGN(408) :: cplan.sql(17359) :: :
1IS NULL:
1CASEEND0000:
1C_EFFORT:
1SELECT TSK_ASSIGNMENT_ID, CASE WHEN C_EFFORT = 0 THEN 0 ELSE C_EFFORT + h_wor+
1k END:n               INTO h_prj_assignment_id, h_work:n               FROM T+
1ASK_ASSIGNMENTS WHERE BIT_FLAG = '2' AND TASK_ID = h_project_id AND RESOURCE_+
1ID = h_res_id:
1426:
1           EXCEPTION:: SP_COMMIT_ASSIGN(427) :: cplan.sql(17378) :: :
1IS NOT NULL:
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_id:
1449:
1           EXCEPTION:: SP_COMMIT_ASSIGN(450) :: cplan.sql(17401) :: :
1EFFORT_WEEK:
1DELETE FROM EFFORT_WEEK WHERE TSK_ASSIGNMENT_ID = h_id:
1466:
1           EXCEPTION:: SP_COMMIT_ASSIGN(467) :: cplan.sql(17418) :: :
1RESOURCE_ASSIGN_ROLES:
1RES_ASSIGNMENT_ID:
1DELETE FROM RESOURCE_ASSIGN_ROLES WHERE RES_ASSIGNMENT_ID = h_id:
1483:
1           EXCEPTION:: SP_COMMIT_ASSIGN(484) :: cplan.sql(17435) :: :
1RESOURCE_ASSIGN_SKILLS:
1DELETE FROM RESOURCE_ASSIGN_SKILLS WHERE RES_ASSIGNMENT_ID = h_id:
1           EXCEPTION:: SP_COMMIT_ASSIGN(501) :: cplan.sql(17452) :: :
1UTL_RAW:
1BIT_OR:
1UPDATE TASK_DAY_OF_YEAR SET SCHED_MIN = SCHED_MIN + h_day_min,:n             +
1        BIT_SCHED = UTL_RAW.BIT_OR(BIT_SCHED, h_bitID):n                     +
1WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_prj_assignment_id A+
1ND DAY_YEAR = h_dayofyear:
1547:
1           EXCEPTION:: SP_COMMIT_ASSIGN(548) :: cplan.sql(17499) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_id AND DAY_YEAR = h_dayofyear:
1566:
1           EXCEPTION:: SP_COMMIT_ASSIGN(567) :: cplan.sql(17518) :: :
1UPDATE TASK_DAY_OF_YEAR SET TSK_ASSIGNMENT_ID = h_prj_assignment_id WHERE PRO+
1JECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_id AND DAY_YEAR = h_dayofyea+
1r:
1583:
1           EXCEPTION:: SP_COMMIT_ASSIGN(584) :: cplan.sql(17535) :: :
1601:
1           EXCEPTION:: SP_COMMIT_ASSIGN(602) :: cplan.sql(17553) :: :
1615:
1           EXCEPTION:: SP_COMMIT_ASSIGN(616) :: cplan.sql(17567) :: :
1PARENT_ID:
1UPDATE TASK_DAY_OF_YEAR SET BIT_FLAG = '2', PARENT_ID = h_prj_assignment_id:n+
1               WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_id:
1633:
1           EXCEPTION:: SP_COMMIT_ASSIGN(634) :: cplan.sql(17585) :: :
1SD:
1SC_SS:
1FD:
1SC_SF:
1UPDATE TASK_ASSIGNMENTS SET:n                  BIT_FLAG = '2',:n             +
1     SD = PMO_CNST.SC_SS, FD = PMO_CNST.SC_SF,:n                  SCHED_START+
1 = PLANNED_START,:n                  SCHED_FINISH = PLANNED_FINISH,:n        +
1          SCHED_DURATION = PLANNED_DURATION,:n                  SCHED_WORK = +
1PLANNED_WORK,:n                  BAK_START_DT = PLANNED_START,:n             +
1     BAK_FINISH_DT = PLANNED_FINISH,:n                  BAK_WORK = PLANNED_WO+
1RK,:n                  SCHED_LABOR_COST = CASE WHEN PLANNED_LABOR_COST > 0.00+
1 THEN PLANNED_LABOR_COST ELSE SCHED_LABOR_COST END,:n                  SCHED_+
1LABOR_REVENUE = CASE WHEN PLANNED_LABOR_REVENUE > 0.00 THEN PLANNED_LABOR_REV+
1ENUE ELSE SCHED_LABOR_REVENUE END,:n                  ETC = PLANNED_WORK,:n  +
1                FORECAST_LABOR_COST = ((ETC+PLANNED_WORK/60.00) * REGULAR_COS+
1T) + ACTUAL_LABOR_COST,:n                  FORECAST_LABOR_REVENUE = CASE WHEN+
1 BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * REGULAR_RATE) + ACTU+
1AL_LABOR_REVENUE END,:n                  PLANNED_START = NuLL, PLANNED_FINISH+
1 = NuLL, PLANNED_DURATION = 0, PLANNED_WORK = 0,:n                  FORECAST_+
1START = NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION = 0,:n               +
1   PROJECT_ASSIGNMENT_ID = NuLL:n                  WHERE TSK_ASSIGNMENT_ID = +
1h_id AND SCHED_WORK = 0 AND PLANNED_WORK > 0:
1669:
1           EXCEPTION:: SP_COMMIT_ASSIGN(670) :: cplan.sql(17621) :: :
1U_ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET:n                     BIT_FLAG = '2',:n          +
1           SD = PMO_CNST.SC_SS,:n                     FD = PMO_CNST.SC_SF,:n +
1                    SCHED_START = PLANNED_START,:n                     SCHED_+
1FINISH = PLANNED_FINISH,:n                     SCHED_DURATION = PLANNED_DURAT+
1ION,:n                     SCHED_WORK = PLANNED_WORK,:n                     B+
1AK_START_DT = PLANNED_START,:n                     BAK_FINISH_DT = PLANNED_FI+
1NISH,:n                     BAK_WORK = PLANNED_WORK,:n                     SC+
1HED_LABOR_COST = CASE WHEN PLANNED_LABOR_COST > 0.00 THEN PLANNED_LABOR_COST +
1ELSE SCHED_LABOR_COST END,:n                     SCHED_LABOR_REVENUE = CASE W+
1HEN PLANNED_LABOR_REVENUE > 0.00 THEN PLANNED_LABOR_REVENUE ELSE SCHED_LABOR_+
1REVENUE END,:n                     ETC = PLANNED_WORK,:n                     +
1FORECAST_LABOR_COST = ((ETC+PLANNED_WORK/60.00) * REGULAR_COST) + ACTUAL_LABO+
1R_COST,:n                     FORECAST_LABOR_REVENUE = CASE WHEN BILLABLE = 0+
1 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * REGULAR_RATE) + ACTUAL_LABOR_REVE+
1NUE END,:n                     PLANNED_START = NuLL, PLANNED_FINISH = NuLL, P+
1LANNED_DURATION = 0, PLANNED_WORK = 0,:n                     FORECAST_START =+
1 NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION = 0,:n                     P+
1ROJECT_ASSIGNMENT_ID = h_prj_assignment_id:n                     WHERE TSK_AS+
1SIGNMENT_ID = h_tsk_assignment_id:
1726:
1           EXCEPTION:: SP_COMMIT_ASSIGN(727) :: cplan.sql(17678) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_CNST.SC_ASSIGNMENT_BIT WHERE ELEMENT_ID +
1= h_task_id:
1745:
1           EXCEPTION:: SP_COMMIT_ASSIGN(746) :: cplan.sql(17697) :: :
1759:
1           EXCEPTION:: SP_COMMIT_ASSIGN(760) :: cplan.sql(17711) :: :
1>:
1UPDATE TASK_ASSIGNMENTS SET C_EFFORT = h_work WHERE TSK_ASSIGNMENT_ID = h_prj+
1_assignment_id:
1777:
1           EXCEPTION:: SP_COMMIT_ASSIGN(778) :: cplan.sql(17729) :: :
1BEST:
1SELECT PROJECT_ASSIGNMENT_ID, BEST, SCHED_START, SCHED_FINISH, BILLABLE, REGU+
1LAR_COST, REGULAR_RATE:n                  INTO h_prj_assignment_id, h_sched_w+
1ork, h_start_date, h_finish_date, h_billable, h_reg_cost, h_reg_sale:n       +
1           FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID   = h_prj_assignment+
1_id:
1797:
1           EXCEPTION:: SP_COMMIT_ASSIGN(798) :: cplan.sql(17749) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n                     ESTIMATED_PLANNED_START +
1= NuLL,:n                     ESTIMATED_PLANNED_FINISH = NuLL,:n             +
1        ESTIMATED_PLANNED_EFFORT = 0,:n                     ESTIMATED_PLANNED+
1_COST = 0.00,:n                     ESTIMATED_PLANNED_REVENUE = 0.00,:n      +
1               ESTIMATED_SCHED_START = h_start_date,:n                     ES+
1TIMATED_SCHED_FINISH = h_finish_date,:n                     ESTIMATED_SCHED_E+
1FFORT = h_sched_work,:n                     ESTIMATED_SCHED_COST = (h_sched_w+
1ork / 60.0) * h_reg_cost,:n                     ESTIMATED_SCHED_REVENUE = 0.0+
10:n                     WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h_r+
1es_id:
1827:
1           EXCEPTION:: SP_COMMIT_ASSIGN(828) :: cplan.sql(17779) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n                     ESTIMATED_PLANNED_START +
1= NuLL,:n                     ESTIMATED_PLANNED_FINISH = NuLL,:n             +
1        ESTIMATED_PLANNED_EFFORT = 0,:n                     ESTIMATED_PLANNED+
1_COST = 0.00,:n                     ESTIMATED_PLANNED_REVENUE = 0.00,:n      +
1               ESTIMATED_SCHED_START = h_start_date,:n                     ES+
1TIMATED_SCHED_FINISH = h_finish_date,:n                     ESTIMATED_SCHED_E+
1FFORT = h_sched_work,:n                     ESTIMATED_SCHED_COST = (h_sched_w+
1ork / 60.0) * h_reg_cost,:n                     ESTIMATED_SCHED_REVENUE = (h_+
1sched_work / 60.0) * h_reg_sale:n                     WHERE PROJECT_ID = h_pr+
1oject_id AND RESOURCE_ID = h_res_id:
1855:
1           EXCEPTION:: SP_COMMIT_ASSIGN(856) :: cplan.sql(17807) :: :
1882:
1           EXCEPTION:: SP_COMMIT_ASSIGN(883) :: cplan.sql(17834) :: :
1898:
1           EXCEPTION:: SP_COMMIT_ASSIGN(899) :: cplan.sql(17850) :: :
1FC_ROLLUP:
1SC_NS:
1SC_NF:
1SELECT CASE WHEN (SD <> PMO_CNST.SC_NS) AND (FD <> PMO_CNST.SC_NF) AND (TYPE_+
1ID = PMO_CNST.SC_PROPOSAL) THEN 1 ELSE 0 END:n      INTO h_change_flag:n     +
1 FROM TMT_WBS WHERE ELEMENT_ID = h_project_id:
1916:
1           EXCEPTION:: SP_COMMIT_ASSIGN(917) :: cplan.sql(17868) :: :
1FC_CHANGE_PROJ_TYPE:
1RESOURCE_ASSIGNMENTS:
1ELEMENT_TYPE:
1UPDATE RESOURCE_ASSIGNMENTS SET:n      ELEMENT_TYPE  = (SELECT TYPE_ID FROM T+
1MT_WBS WHERE ELEMENT_ID = h_project_id):n      WHERE ELEMENT_ID = h_project_i+
1d:
1940:
1           EXCEPTION:: SP_COMMIT_ASSIGN(941) :: cplan.sql(17892) :: :
14:
1950:
1       RETURN_STATUS:: SP_COMMIT_ASSIGN(951) :: cplan.sql(17902) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1957:
1           EXCEPTION:: SP_COMMIT_ASSIGN(958) :: cplan.sql(17909) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1969:
1           EXCEPTION:: SP_COMMIT_ASSIGN(970) :: cplan.sql(17921) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
14b0
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c :2 a0 6b 81
b0 a3 a0 51 a5 1c :2 a0 6b
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a0 f4 b4 bf
c8 :1a a0 12a bd b7 11 a4 b1
a3 :2 a0 6b 1c 81 b0 a0 f4
b4 bf c8 :9 a0 12a bd b7 11
a4 b1 a0 f4 b4 bf c8 :6 a0
12a bd b7 11 a4 b1 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 d :2 a0 d :6 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:c a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 a0 b7 :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c :6 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e d b7 :2 a0 d
:2 a0 51 a5 b 7e 51 b4 2e
:44 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 e9 dd b3 :4 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c :39 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :6 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
a0 47 :2 a0 e9 c1 :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 51 d a0 51 d
a0 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d b7
:2 19 3c :3 a0 11c 11d :6 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c a0 51 :1e a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:62 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3a a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a6 9 51 :6 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a a0 7e b4 2e :2 5a 52
10 a0 3b b7 19 3c :c a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a a0 7e b4 2e :2 5a a
10 :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 51 d b7 :2 19 3c b7
:2 a0 d a0 51 d b7 :2 19 3c
a0 51 d :2 a0 e9 dd b3 :5 a0
e9 d3 5 :2 a0 f :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a a0 2b b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e :f a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :7 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :9 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :8 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :37 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e a0 51
d :5 a0 :2 51 a5 b d b7 19
3c b7 :2 a0 e9 dd b3 :4 a0 e9
d3 5 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 2b b7 19 3c :36 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :6 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :5 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c a0
51 d :5 a0 :2 51 a5 b d :11 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :14 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :16 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :2 19 3c 93 4f b0 46 b7
a6 9 4f b7 9 a4 14 :6 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
a5 b d :d a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
d :2 a0 6b :4 a0 a5 b d b7
19 3c :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b 7e 51 b4
2e :2 a0 6b 51 d b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
14b0
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 7d 5d 61 64 65 6d
71 75 78 5c a5 88 59 8c
8d 95 99 9d a0 87 c2 b0
84 b4 b5 bd af de cd d1
d9 ac fa e5 e9 ec ed f5
cc 117 105 c9 109 10a 112 104
134 122 101 126 127 12f 121 151
13f 11e 143 144 14c 13e 16e 15c
13b 160 161 169 15b 18a 179 17d
185 158 1a2 191 195 19d 178 1be
1ad 1b1 175 1b9 1ac 1da 1c9 1cd
1a9 1d5 1c8 1f6 1e5 1e9 1c5 1f1
1e4 212 201 205 1e1 20d 200 22e
21d 221 1fd 229 21c 24a 239 23d
219 245 238 266 255 259 235 261
254 282 271 275 251 27d 270 29e
28d 291 26d 299 28c 2ba 2a9 2ad
289 2b5 2a8 2d6 2c5 2c9 2a5 2d1
2c4 2f2 2e1 2e5 2c1 2ed 2e0 30e
2fd 301 2dd 309 2fc 32a 319 31d
2f9 325 318 346 335 339 315 341
334 363 351 331 355 356 35e 350
36a 36e 34d 37f 382 386 38a 38e
392 396 39a 39e 3a2 3a6 3aa 3ae
3b2 3b6 3ba 3be 3c2 3c6 3ca 3ce
3d2 3d6 3da 3de 3e2 3e6 3ea 3ee
3fa 3ff 401 40d 411 42f 417 41b
41f 422 42a 416 436 43a 413 44b
44e 452 456 45a 45e 462 466 46a
46e 472 476 482 487 489 495 499
49b 49f 4b0 4b1 4b4 4b8 4bc 4c0
4c4 4c8 4cc 4d0 4dc 4e1 4e3 4ef
4f3 511 4f9 4fd 501 504 50c 4f8
518 51c 4f5 520 524 528 52b 530
531 1 533 538 53c 540 543 548
54c 550 553 558 559 55b 560 563
567 568 56d 572 575 57a 57b 580
583 587 588 58d 590 595 596 59b
59e 5a3 5a4 5a9 5ac 5b0 5b4 5b8
5b9 5bb 5c0 5c1 5c3 5c4 5c9 5cc
5d1 5d2 5d7 5d8 5dd 5df 5e3 5e6
5ea 5ee 5f1 5f5 5f9 5fc 5ff 604
607 60a 60d 60e 613 614 1 616
61b 61f 623 626 62b 630 633 637
638 63d 63e 643 645 649 64c 650
654 658 65c 660 664 668 66c 670
674 678 67c 688 68c 690 693 697
69b 69d 1 6a1 6a5 6a9 6ac 6b0
6b4 6b8 6bc 6bf 6c3 6c7 6ca 6cd
6d2 6d5 6d8 6db 6dc 6e1 6e2 1
6e4 6e9 6ed 6f1 6f4 6f9 6fe 701
705 706 70b 70e 713 714 719 71c
721 722 727 72a 72e 72f 734 737
73c 73d 742 745 749 74d 750 753
754 756 757 75c 75d 762 764 768
76b 76d 771 773 77f 781 783 784
789 78d 78f 79b 79d 7a1 7a5 7a8
7ac 7af 7b3 7b6 7b7 7bc 7bf 7c3
7c7 7cb 7cf 7d3 7d7 7db 7df 7e3
7e7 7eb 7ef 7fb 7ff 803 806 80a
80e 810 1 814 818 81c 81f 823
827 82b 82f 832 836 83a 83d 840
845 848 84b 84e 84f 854 855 1
857 85c 860 864 867 86c 871 874
878 879 87e 881 886 887 88c 88f
894 895 89a 89d 8a1 8a2 8a7 8aa
8af 8b0 8b5 8b8 8bc 8c0 8c3 8c6
8c7 8c9 8ca 8cf 8d0 8d5 8d7 8db
8de 8e0 8e4 8e6 8f2 8f4 8f6 8f7
8fc 900 902 90e 910 914 918 91b
91f 922 926 929 92a 92f 932 936
93a 93d 941 945 948 94b 950 953
956 959 95a 95f 960 1 962 967
96b 96f 972 977 97c 97f 983 984
989 98c 991 992 997 99a 99f 9a0
9a5 9a8 9ac 9b0 9b4 9b8 9bb 9bc
9be 9c3 9c4 9c6 9c7 9cc 9cd 9d2
9d4 9d8 9db 9df 9e3 9e6 9ea 9ee
9f1 9f4 9f9 9fc 9ff a02 a03 a08
a09 1 a0b a10 a14 a18 a1b a20
a25 a28 a2c a2d a32 a33 a38 a3a
a3e a41 a45 a49 a4c a50 a54 a57
a5b a5c a61 a65 a67 a6b a6f a72
a73 a75 a78 a7b a7c a81 a84 a88
a8c a8f a90 a92 a95 a98 a99 a9e
1 aa1 aa6 aaa aae ab1 ab5 ab9
abc abf ac4 ac7 aca acd ace ad3
ad4 1 ad6 adb adf ae3 ae6 aeb
af0 af3 af7 af8 afd b00 b05 b06
b0b b0e b13 b14 b19 b1c b20 b24
b28 b2c b2f b30 b32 b37 b38 b3a
b3b b40 b43 b48 b49 b4e b51 b56
b57 b5c b5f b63 b64 b69 b6c b71
b72 b77 b78 b7d b7f b83 b86 b8a
b8e b91 b95 b99 b9c b9f ba4 ba7
baa bad bae bb3 bb4 1 bb6 bbb
bbf bc3 bc6 bcb bd0 bd3 bd7 bd8
bdd bde be3 be5 be9 bec bf0 bf4
bf7 bfb bff c02 c06 c0a c0b c10
c12 c16 c1a c1d c21 c25 c29 c2d
c31 c35 c41 c45 c49 c4c c50 c54
c56 1 c5a c5e c62 c65 c69 c6d
c71 c75 c78 c7c c80 c83 c86 c8b
c8e c91 c94 c95 c9a c9b 1 c9d
ca2 ca6 caa cad cb2 cb7 cba cbe
cbf cc4 cc7 ccc ccd cd2 cd5 cda
cdb ce0 ce3 ce7 ce8 ced cf0 cf5
cf6 cfb cfe d02 d06 d09 d0c d0d
d0f d10 d15 d16 d1b d1d d21 d24
d26 d2a d2c d38 d3a d3c d3d d42
d46 d48 d54 d56 d5a d5f d62 d67
d68 d6d d70 d74 d75 d7a d7d d82
d83 d88 d8c d8e d92 d96 d9a d9e
da2 da5 da6 da8 dab dae daf db4
db8 dbc dc0 dc4 dc8 dcc dd0 dd4
dd8 ddc de0 de4 de8 dec df0 df4
df8 dfc e00 e04 e08 e0c e10 e14
e18 e1c e20 e24 e28 e2c e30 e34
e38 e3c e40 e44 e48 e4c e50 e54
e58 e5c e60 e64 e68 e6c e70 e74
e78 e7c e80 e84 e88 e8c e90 e94
e98 e9c ea0 ea4 ea8 eac eb0 eb4
eb8 ebc ec0 ec4 ed0 ed4 ed9 edd
ee0 ee1 ee6 eea eee ef1 ef4 ef8
efa efe f02 f05 f08 f0c f0e f12
f16 f19 f1b 1 f1f f23 f27 f2a
f2e f32 f36 f3a f3d f41 f45 f48
f4b f50 f53 f56 f59 f5a f5f f60
1 f62 f67 f6b f6f f72 f77 f7c
f7f f83 f84 f89 f8c f91 f92 f97
f9a f9f fa0 fa5 fa8 fac fad fb2
fb5 fba fbb fc0 fc3 fc7 fcb fce
fd1 fd2 fd4 fd5 fda fdb fe0 fe2
fe6 fe9 feb fef ff1 ffd fff 1001
1002 1007 100b 100d 1019 101b 101f 1023
1028 102c 102d 1031 1035 1039 103d 1042
1047 104b 104f 1053 1058 105c 1060 1063
1066 106a 106c 1070 1074 1077 107a 107e
1080 1084 1088 108b 108f 1093 1096 109a
109d 10a1 10a4 10a5 10aa 10ad 10b1 10b7
10b9 10bd 10c0 10c4 10c8 10cc 10d0 10d4
10d8 10dc 10e0 10e4 10e8 10ec 10f0 10f4
10f8 10fc 1100 1104 1108 110c 1110 1114
1118 111c 1120 1124 1128 112c 1130 1134
1138 113c 1140 1144 1148 114c 1150 1154
1158 115c 1160 1164 1168 116c 1170 1174
1178 117c 1180 1184 1188 118c 1190 1194
1198 119c 11a0 11a4 11b0 11b4 11b9 11bd
11c0 11c1 11c6 11ca 11ce 11d1 11d4 11d8
11da 11de 11e2 11e5 11e8 11ec 11ee 11f2
11f6 11f9 11fb 1 11ff 1203 1207 120a
120e 1212 1216 121a 121d 1221 1225 1228
122b 1230 1233 1236 1239 123a 123f 1240
1 1242 1247 124b 124f 1252 1257 125c
125f 1263 1264 1269 126c 1271 1272 1277
127a 127f 1280 1285 1288 128c 128d 1292
1295 129a 129b 12a0 12a3 12a7 12ab 12ae
12b1 12b2 12b4 12b5 12ba 12bb 12c0 12c2
12c6 12c9 12cb 12cf 12d1 12dd 12df 12e1
12e2 12e7 12eb 12ed 12f9 12fb 12ff 1303
1307 130b 130f 1313 131f 1323 1328 132c
132f 1330 1335 1339 133d 1340 1343 1347
1349 134d 1351 1354 1357 135b 135d 1361
1365 1368 136a 1 136e 1372 1376 1379
137d 1381 1385 1389 138c 1390 1394 1397
139a 139f 13a2 13a5 13a8 13a9 13ae 13af
1 13b1 13b6 13ba 13be 13c1 13c6 13cb
13ce 13d2 13d3 13d8 13db 13e0 13e1 13e6
13e9 13ee 13ef 13f4 13f7 13fb 13fc 1401
1404 1409 140a 140f 1412 1416 141a 141d
1420 1421 1423 1424 1429 142a 142f 1431
1435 1438 143a 143e 1440 144c 144e 1450
1451 1456 145a 145c 1468 146a 146c 1470
1477 147b 147f 1484 1486 148a 148e 1491
1495 1499 149b 1 149f 14a3 14a7 14aa
14ae 14b2 14b6 14ba 14bd 14c1 14c5 14c8
14cb 14d0 14d3 14d6 14d9 14da 14df 14e0
1 14e2 14e7 14eb 14ef 14f2 14f7 14fc
14ff 1503 1504 1509 150c 1511 1512 1517
151a 151f 1520 1525 1528 152c 152d 1532
1535 153a 153b 1540 1543 1547 154b 154e
1551 1552 1554 1555 155a 155b 1560 1562
1566 1569 156b 156f 1571 157d 157f 1581
1582 1587 158b 158d 1599 159b 159d 15a1
15a4 15a8 15ac 15b0 15b4 15b8 15bc 15c0
15c4 15c8 15d4 15d8 15dd 15e1 15e4 15e5
15ea 15ee 15f2 15f5 15f8 15fc 15fe 1602
1606 1609 160c 1610 1612 1616 161a 161d
161f 1 1623 1627 162b 162e 1632 1636
163a 163e 1641 1645 1649 164c 164f 1654
1657 165a 165d 165e 1663 1664 1 1666
166b 166f 1673 1676 167b 1680 1683 1687
1688 168d 1690 1695 1696 169b 169e 16a3
16a4 16a9 16ac 16b0 16b1 16b6 16b9 16be
16bf 16c4 16c7 16cb 16cf 16d2 16d5 16d6
16d8 16d9 16de 16df 16e4 16e6 16ea 16ed
16ef 16f3 16f5 1701 1703 1705 1706 170b
170f 1711 171d 171f 1723 1726 172a 172e
1731 1735 1739 173e 1741 1746 1747 174c
174f 1753 1754 1759 175c 1761 1762 1767
176b 176d 1771 1775 1778 177c 1780 1784
1787 178b 178f 1793 1797 179b 179f 17a3
17a8 17ad 17b1 17b5 17b9 17be 17c2 17c6
17c9 17cc 17d0 17d2 17d6 17da 17dd 17e0
17e4 17e6 17ea 17ee 17f1 17f5 17f9 17fc
1800 1803 1807 180a 180b 1810 1813 1817
181d 181f 1823 1826 182a 182d 1831 1835
1839 183d 1841 1845 1849 184d 1851 1855
1859 185d 1861 1865 1869 186d 1871 1875
1879 187d 1881 1885 1889 188d 1891 1895
1899 189d 18a1 18a5 18b1 18b5 18ba 18be
18c1 18c2 18c7 18cb 18cf 18d2 18d5 18d9
18db 18df 18e3 18e6 18e9 18ed 18ef 18f3
18f7 18fa 18fc 1 1900 1904 1908 190b
190f 1913 1917 191b 191e 1922 1926 1929
192c 1931 1934 1937 193a 193b 1940 1941
1 1943 1948 194c 1950 1953 1958 195d
1960 1964 1965 196a 196d 1972 1973 1978
197b 1980 1981 1986 1989 198d 198e 1993
1996 199b 199c 19a1 19a4 19a8 19ac 19af
19b2 19b3 19b5 19b6 19bb 19bc 19c1 19c3
19c7 19ca 19cc 19d0 19d2 19de 19e0 19e2
19e3 19e8 19ec 19ee 19fa 19fc 1a00 1a04
1a08 1a0c 1a10 1a14 1a18 1a1c 1a20 1a24
1a28 1a2c 1a30 1a34 1a38 1a3c 1a40 1a44
1a48 1a4c 1a50 1a54 1a58 1a5c 1a60 1a64
1a68 1a6c 1a70 1a74 1a78 1a7c 1a80 1a84
1a88 1a8c 1a90 1a94 1a98 1a9c 1aa0 1aa4
1aa8 1aac 1ab0 1ab4 1ab8 1abc 1ac0 1ac4
1ac8 1acc 1ad0 1ad4 1ad8 1adc 1ae0 1ae4
1ae8 1aec 1af0 1af4 1af8 1afc 1b00 1b04
1b08 1b0c 1b10 1b14 1b18 1b1c 1b20 1b24
1b28 1b2c 1b30 1b34 1b38 1b3c 1b40 1b44
1b48 1b4c 1b50 1b54 1b58 1b5c 1b60 1b64
1b68 1b6c 1b70 1b74 1b78 1b7c 1b80 1b84
1b90 1b94 1b99 1b9d 1ba0 1ba1 1ba6 1baa
1bae 1bb1 1bb4 1bb8 1bba 1bbe 1bc2 1bc5
1bc8 1bcc 1bce 1bd2 1bd6 1bd9 1bdb 1
1bdf 1be3 1be7 1bea 1bee 1bf2 1bf6 1bfa
1bfd 1c01 1c05 1c08 1c0b 1c10 1c13 1c16
1c19 1c1a 1c1f 1c20 1 1c22 1c27 1c2b
1c2f 1c32 1c37 1c3c 1c3f 1c43 1c44 1c49
1c4c 1c51 1c52 1c57 1c5a 1c5f 1c60 1c65
1c68 1c6c 1c6d 1c72 1c75 1c7a 1c7b 1c80
1c83 1c87 1c8b 1c8e 1c91 1c92 1c94 1c95
1c9a 1c9b 1ca0 1ca2 1ca6 1ca9 1cab 1caf
1cb1 1cbd 1cbf 1cc1 1cc2 1cc7 1ccb 1ccd
1cd9 1cdb 1cdf 1ce3 1ce7 1ceb 1cef 1cf3
1cf7 1cfb 1cff 1d03 1d07 1d0b 1d0f 1d13
1d17 1d1b 1d1f 1d23 1d27 1d2b 1d2f 1d33
1d37 1d3b 1d3f 1d43 1d47 1d4b 1d4f 1d53
1d57 1d5b 1d5f 1d63 1d67 1d6b 1d6f 1d73
1d77 1d7b 1d7f 1d83 1d87 1d8b 1d8f 1d93
1d97 1d9b 1d9f 1da3 1da7 1dab 1daf 1db3
1db7 1dbb 1dbf 1dc3 1dcf 1dd3 1dd8 1ddc
1ddf 1de0 1de5 1de9 1ded 1df0 1df3 1df7
1df9 1dfd 1e01 1e04 1e07 1e0b 1e0d 1e11
1e15 1e18 1e1a 1 1e1e 1e22 1e26 1e29
1e2d 1e31 1e35 1e39 1e3c 1e40 1e44 1e47
1e4a 1e4f 1e52 1e55 1e58 1e59 1e5e 1e5f
1 1e61 1e66 1e6a 1e6e 1e71 1e76 1e7b
1e7e 1e82 1e83 1e88 1e8b 1e90 1e91 1e96
1e99 1e9e 1e9f 1ea4 1ea7 1eab 1eac 1eb1
1eb4 1eb9 1eba 1ebf 1ec2 1ec6 1eca 1ecd
1ed0 1ed1 1ed3 1ed4 1ed9 1eda 1edf 1ee1
1ee5 1ee8 1eea 1eee 1ef0 1efc 1efe 1f00
1f01 1f06 1f0a 1f0c 1f18 1f1a 1f1c 1f1d
1f22 1f25 1f29 1f2d 1f31 1f35 1f39 1f3d
1f49 1f4d 1f51 1f54 1f58 1f5c 1f5e 1
1f62 1f66 1f6a 1f6d 1f71 1f75 1f79 1f7d
1f80 1f84 1f88 1f8b 1f8e 1f93 1f96 1f99
1f9c 1f9d 1fa2 1fa3 1 1fa5 1faa 1fae
1fb2 1fb5 1fba 1fbf 1fc2 1fc6 1fc7 1fcc
1fcf 1fd4 1fd5 1fda 1fdd 1fe2 1fe3 1fe8
1feb 1fef 1ff0 1ff5 1ff8 1ffd 1ffe 2003
2006 200a 200e 2011 2014 2015 2017 2018
201d 201e 2023 2025 2029 202c 202e 2032
2034 2040 2042 2044 2045 204a 204e 2050
205c 205e 2062 2066 2069 206d 2070 2074
2077 2078 207d 2080 2084 2087 2088 208d
2090 1 2093 2098 209c 20a2 20a4 20a8
20ab 20af 20b3 20b7 20bb 20bf 20c3 20c7
20cb 20cf 20d3 20d7 20db 20e7 20eb 20ef
20f2 20f6 20fa 20fc 1 2100 2104 2108
210b 210f 2113 2117 211b 211e 2122 2126
2129 212c 2131 2134 2137 213a 213b 2140
2141 1 2143 2148 214c 2150 2153 2158
215d 2160 2164 2165 216a 216d 2172 2173
2178 217b 2180 2181 2186 2189 218d 218e
2193 2196 219b 219c 21a1 21a4 21a8 21ac
21af 21b2 21b3 21b5 21b6 21bb 21bc 21c1
21c3 21c7 21ca 21cc 21d0 21d2 21de 21e0
21e2 21e3 21e8 21ec 21ee 21fa 21fc 2200
2204 2207 220b 220e 2212 2215 2216 221b
221e 2222 2225 2226 222b 222e 1 2231
2236 223a 223e 2241 2242 2244 2247 224a
224b 2250 2254 2257 225b 225d 2261 2265
2269 2275 2279 227e 2282 2285 2286 228b
228f 2293 2296 2299 229d 229f 22a3 22a7
22aa 22ad 22b1 22b3 22b7 22bb 22be 22c0
1 22c4 22c8 22cc 22cf 22d3 22d7 22db
22df 22e2 22e6 22ea 22ed 22f0 22f5 22f8
22fb 22fe 22ff 2304 2305 1 2307 230c
2310 2314 2317 231c 2321 2324 2328 2329
232e 2331 2336 2337 233c 233f 2344 2345
234a 234d 2351 2352 2357 235a 235f 2360
2365 2368 236c 2370 2373 2376 2377 2379
237a 237f 2380 2385 2387 238b 238e 2390
2394 2396 23a2 23a4 23a6 23a7 23ac 23b0
23b2 23be 23c0 23c4 23c8 23cc 23d8 23dc
23e1 23e5 23e8 23e9 23ee 23f2 23f6 23f9
23fc 2400 2402 2406 240a 240d 2410 2414
2416 241a 241e 2421 2423 1 2427 242b
242f 2432 2436 243a 243e 2442 2445 2449
244d 2450 2453 2458 245b 245e 2461 2462
2467 2468 1 246a 246f 2473 2477 247a
247f 2484 2487 248b 248c 2491 2494 2499
249a 249f 24a2 24a7 24a8 24ad 24b0 24b4
24b5 24ba 24bd 24c2 24c3 24c8 24cb 24cf
24d3 24d6 24d9 24da 24dc 24dd 24e2 24e3
24e8 24ea 24ee 24f1 24f3 24f7 24f9 2505
2507 2509 250a 250f 2513 2515 2521 2523
2527 252b 252f 253b 253f 2544 2548 254b
254c 2551 2555 2559 255c 255f 2563 2565
2569 256d 2570 2573 2577 2579 257d 2581
2584 2586 1 258a 258e 2592 2595 2599
259d 25a1 25a5 25a8 25ac 25b0 25b3 25b6
25bb 25be 25c1 25c4 25c5 25ca 25cb 1
25cd 25d2 25d6 25da 25dd 25e2 25e7 25ea
25ee 25ef 25f4 25f7 25fc 25fd 2602 2605
260a 260b 2610 2613 2617 2618 261d 2620
2625 2626 262b 262e 2632 2636 2639 263c
263d 263f 2640 2645 2646 264b 264d 2651
2654 2656 265a 265c 2668 266a 266c 266d
2672 2676 2678 2684 2686 268a 268e 2692
269e 26a2 26a7 26ab 26ae 26af 26b4 26b8
26bc 26bf 26c2 26c6 26c8 26cc 26d0 26d3
26d6 26da 26dc 26e0 26e4 26e7 26e9 1
26ed 26f1 26f5 26f8 26fc 2700 2704 2708
270b 270f 2713 2716 2719 271e 2721 2724
2727 2728 272d 272e 1 2730 2735 2739
273d 2740 2745 274a 274d 2751 2752 2757
275a 275f 2760 2765 2768 276d 276e 2773
2776 277a 277b 2780 2783 2788 2789 278e
2791 2795 2799 279c 279f 27a0 27a2 27a3
27a8 27a9 27ae 27b0 27b4 27b7 27b9 27bd
27bf 27cb 27cd 27cf 27d0 27d5 27d9 27db
27e7 27e9 27ed 27f0 27f4 27f6 27fa 27fe
2801 2803 2807 280b 280f 2813 2816 281a
281c 2820 2824 2827 282b 282e 2832 2836
283a 283f 2843 2844 2848 284c 2850 2854
2858 285d 2862 2866 286a 286e 2873 2877
287b 287e 2881 2885 2887 288b 288f 2892
2895 2899 289b 289f 28a3 28a6 28aa 28ae
28b1 28b5 28b8 28bc 28bf 28c0 28c5 28c8
28cc 28d2 28d4 28d8 28db 28df 28e3 28e6
28e7 28e9 28ec 28ef 28f0 28f5 28f9 28fd
2901 2905 2909 290d 2911 2915 2919 291d
2921 2925 2929 292d 2931 293d 2941 2946
294a 294d 294e 2953 2957 295b 295e 2961
2965 2967 296b 296f 2972 2975 2979 297b
297f 2983 2986 2988 1 298c 2990 2994
2997 299b 299f 29a3 29a7 29aa 29ae 29b2
29b5 29b8 29bd 29c0 29c3 29c6 29c7 29cc
29cd 1 29cf 29d4 29d8 29dc 29df 29e4
29e9 29ec 29f0 29f1 29f6 29f9 29fe 29ff
2a04 2a07 2a0c 2a0d 2a12 2a15 2a19 2a1a
2a1f 2a22 2a27 2a28 2a2d 2a30 2a34 2a38
2a3b 2a3e 2a3f 2a41 2a42 2a47 2a48 2a4d
2a4f 2a53 2a56 2a58 2a5c 2a5e 2a6a 2a6c
2a6e 2a6f 2a74 2a78 2a7a 2a86 2a88 2a8c
2a90 2a93 2a97 2a9a 2a9e 2aa1 2aa2 2aa7
2aaa 2aae 2ab2 2ab6 2aba 2abe 2ac2 2ac6
2ad2 2ad6 2adb 2adf 2ae2 2ae3 2ae8 2aec
2af0 2af3 2af6 2afa 2afc 2b00 2b04 2b07
2b0a 2b0e 2b10 2b14 2b18 2b1b 2b1d 1
2b21 2b25 2b29 2b2c 2b30 2b34 2b38 2b3c
2b3f 2b43 2b47 2b4a 2b4d 2b52 2b55 2b58
2b5b 2b5c 2b61 2b62 1 2b64 2b69 2b6d
2b71 2b74 2b79 2b7e 2b81 2b85 2b86 2b8b
2b8e 2b93 2b94 2b99 2b9c 2ba1 2ba2 2ba7
2baa 2bae 2baf 2bb4 2bb7 2bbc 2bbd 2bc2
2bc5 2bc9 2bcd 2bd0 2bd3 2bd4 2bd6 2bd7
2bdc 2bdd 2be2 2be4 2be8 2beb 2bed 2bf1
2bf3 2bff 2c01 2c03 2c04 2c09 2c0d 2c0f
2c1b 2c1d 2c1f 2c23 2c27 2c2b 2c2f 2c33
2c37 2c3b 2c3f 2c43 2c4f 2c53 2c58 2c5c
2c5f 2c60 2c65 2c69 2c6d 2c70 2c73 2c77
2c79 2c7d 2c81 2c84 2c87 2c8b 2c8d 2c91
2c95 2c98 2c9a 1 2c9e 2ca2 2ca6 2ca9
2cad 2cb1 2cb5 2cb9 2cbc 2cc0 2cc4 2cc7
2cca 2ccf 2cd2 2cd5 2cd8 2cd9 2cde 2cdf
1 2ce1 2ce6 2cea 2cee 2cf1 2cf6 2cfb
2cfe 2d02 2d03 2d08 2d0b 2d10 2d11 2d16
2d19 2d1e 2d1f 2d24 2d27 2d2b 2d2c 2d31
2d34 2d39 2d3a 2d3f 2d42 2d46 2d4a 2d4d
2d50 2d51 2d53 2d54 2d59 2d5a 2d5f 2d61
2d65 2d68 2d6a 2d6e 2d70 2d7c 2d7e 2d80
2d81 2d86 2d8a 2d8c 2d98 2d9a 2d9c 2da0
2da4 2da7 2dab 2dad 2db1 2db5 2db8 2db9
2dbb 2dbe 2dc1 2dc2 2dc7 2dcb 2dcf 2dd3
2dd7 2ddb 2ddf 2de3 2de7 2deb 2df7 2dfb
2e00 2e04 2e07 2e08 2e0d 2e11 2e15 2e18
2e1b 2e1f 2e21 2e25 2e29 2e2c 2e2f 2e33
2e35 2e39 2e3d 2e40 2e42 1 2e46 2e4a
2e4e 2e51 2e55 2e59 2e5d 2e61 2e64 2e68
2e6c 2e6f 2e72 2e77 2e7a 2e7d 2e80 2e81
2e86 2e87 1 2e89 2e8e 2e92 2e96 2e99
2e9e 2ea3 2ea6 2eaa 2eab 2eb0 2eb3 2eb8
2eb9 2ebe 2ec1 2ec6 2ec7 2ecc 2ecf 2ed3
2ed4 2ed9 2edc 2ee1 2ee2 2ee7 2eea 2eee
2ef2 2ef5 2ef8 2ef9 2efb 2efc 2f01 2f02
2f07 2f09 2f0d 2f10 2f12 2f16 2f18 2f24
2f26 2f28 2f29 2f2e 2f32 2f34 2f40 2f42
2f44 2f48 2f4c 2f4f 2f51 2f55 2f5c 2f60
2f64 2f69 2f6b 2f6f 2f73 2f76 2f7a 2f7e
2f80 1 2f84 2f88 2f8c 2f8f 2f93 2f97
2f9b 2f9f 2fa2 2fa6 2faa 2fad 2fb0 2fb5
2fb8 2fbb 2fbe 2fbf 2fc4 2fc5 1 2fc7
2fcc 2fd0 2fd4 2fd7 2fdc 2fe1 2fe4 2fe8
2fe9 2fee 2ff1 2ff6 2ff7 2ffc 2fff 3004
3005 300a 300d 3011 3012 3017 301a 301f
3020 3025 3028 302c 3030 3033 3036 3037
3039 303a 303f 3040 3045 3047 304b 304e
3050 3054 3056 3062 3064 3066 3067 306c
3070 3072 307e 3080 3084 3088 308c 3090
3094 3098 309c 30a0 30ac 30b0 30b5 30b9
30bc 30bd 30c2 30c6 30ca 30cd 30d0 30d4
30d6 30da 30de 30e1 30e4 30e8 30ea 30ee
30f2 30f5 30f7 1 30fb 30ff 3103 3106
310a 310e 3112 3116 3119 311d 3121 3124
3127 312c 312f 3132 3135 3136 313b 313c
1 313e 3143 3147 314b 314e 3153 3158
315b 315f 3160 3165 3168 316d 316e 3173
3176 317b 317c 3181 3184 3188 3189 318e
3191 3196 3197 319c 319f 31a3 31a7 31aa
31ad 31ae 31b0 31b1 31b6 31b7 31bc 31be
31c2 31c5 31c7 31cb 31cd 31d9 31db 31dd
31de 31e3 31e7 31e9 31f5 31f7 31fb 31ff
3202 3203 3205 3208 320b 320c 3211 3215
3219 321d 3221 3225 3229 322d 3231 3235
3239 323d 3241 3245 3249 324d 3251 3255
3259 325d 3261 3265 3269 326d 3271 3275
3279 327d 3281 3285 3289 328d 3291 3295
3299 329d 32a1 32a5 32a9 32ad 32b1 32b5
32b9 32bd 32c1 32c5 32c9 32cd 32d1 32d5
32d9 32dd 32e1 32e5 32e9 32ed 32f9 32fd
3302 3306 3309 330a 330f 3313 3317 331a
331d 3321 3323 3327 332b 332e 3331 3335
3337 333b 333f 3342 3344 1 3348 334c
3350 3353 3357 335b 335f 3363 3366 336a
336e 3371 3374 3379 337c 337f 3382 3383
3388 3389 1 338b 3390 3394 3398 339b
33a0 33a5 33a8 33ac 33ad 33b2 33b5 33ba
33bb 33c0 33c3 33c8 33c9 33ce 33d1 33d5
33d6 33db 33de 33e3 33e4 33e9 33ec 33f0
33f4 33f7 33fa 33fb 33fd 33fe 3403 3404
3409 340b 340f 3412 3414 3418 341a 3426
3428 342a 342b 3430 3434 3436 3442 3444
3448 344c 344f 3450 3452 3455 3458 3459
345e 3462 3465 3469 346d 3471 3475 3479
347d 3480 3483 3484 3486 348a 348c 3490
3493 3495 3499 349d 34a2 34a6 34a7 34ab
34af 34b3 34b7 34bc 34c1 34c5 34c9 34cd
34d2 34d6 34da 34dd 34e0 34e4 34e6 34ea
34ee 34f1 34f4 34f8 34fa 34fe 3502 3505
3509 350d 3510 3514 3517 351b 351e 351f
3524 3527 352b 3531 3533 3537 353a 353e
3542 3546 354a 354e 3552 3556 355a 355e
3562 3566 356a 356e 3572 3576 357a 357e
3582 3586 358a 358e 3592 3596 359a 359e
35a2 35a6 35aa 35ae 35b2 35b6 35ba 35be
35c2 35c6 35ca 35ce 35d2 35d6 35da 35de
35e2 35e6 35ea 35ee 35f2 35f6 35fa 35fe
3602 3606 360a 360e 3612 361e 3622 3627
362b 362e 362f 3634 3638 363c 363f 3642
3646 3648 364c 3650 3653 3656 365a 365c
3660 3664 3667 3669 1 366d 3671 3675
3678 367c 3680 3684 3688 368b 368f 3693
3696 3699 369e 36a1 36a4 36a7 36a8 36ad
36ae 1 36b0 36b5 36b9 36bd 36c0 36c5
36ca 36cd 36d1 36d2 36d7 36da 36df 36e0
36e5 36e8 36ed 36ee 36f3 36f6 36fa 36fb
3700 3703 3708 3709 370e 3711 3715 3719
371c 371f 3720 3722 3723 3728 3729 372e
3730 3734 3737 3739 373d 373f 374b 374d
374f 3750 3755 3759 375b 3767 3769 376d
3771 3775 3779 377d 3781 378d 3791 3796
379a 379d 379e 37a3 37a7 37ab 37ae 37b1
37b5 37b7 37bb 37bf 37c2 37c5 37c9 37cb
37cf 37d3 37d6 37d8 1 37dc 37e0 37e4
37e7 37eb 37ef 37f3 37f7 37fa 37fe 3802
3805 3808 380d 3810 3813 3816 3817 381c
381d 1 381f 3824 3828 382c 382f 3834
3839 383c 3840 3841 3846 3849 384e 384f
3854 3857 385c 385d 3862 3865 3869 386a
386f 3872 3877 3878 387d 3880 3884 3888
388b 388e 388f 3891 3892 3897 3898 389d
389f 38a3 38a6 38a8 38ac 38ae 38ba 38bc
38be 38bf 38c4 38c8 38ca 38d6 38d8 38da
38de 38e5 38e9 38ed 38f2 38f4 38f8 38fc
38ff 3903 3907 3909 1 390d 3911 3915
3918 391c 3920 3924 3928 392b 392f 3933
3936 3939 393e 3941 3944 3947 3948 394d
394e 1 3950 3955 3959 395d 3960 3965
396a 396d 3971 3972 3977 397a 397f 3980
3985 3988 398d 398e 3993 3996 399a 399b
39a0 39a3 39a8 39a9 39ae 39b1 39b5 39b9
39bc 39bf 39c0 39c2 39c3 39c8 39c9 39ce
39d0 39d4 39d7 39d9 39dd 39df 39eb 39ed
39ef 39f0 39f5 39f9 39fb 3a07 3a09 3a0d
3a11 3a14 3a15 3a17 3a1a 3a1d 3a1e 3a23
3a26 3a2a 3a2e 3a31 3a32 3a34 3a37 3a3a
3a3b 3a40 1 3a43 3a48 3a4c 3a50 3a54
3a58 3a5c 3a68 3a6c 3a71 3a75 3a78 3a79
3a7e 3a82 3a86 3a89 3a8c 3a90 3a92 3a96
3a9a 3a9d 3aa0 3aa4 3aa6 3aaa 3aae 3ab1
3ab3 1 3ab7 3abb 3abf 3ac2 3ac6 3aca
3ace 3ad2 3ad5 3ad9 3add 3ae0 3ae3 3ae8
3aeb 3aee 3af1 3af2 3af7 3af8 1 3afa
3aff 3b03 3b07 3b0a 3b0f 3b14 3b17 3b1b
3b1c 3b21 3b24 3b29 3b2a 3b2f 3b32 3b37
3b38 3b3d 3b40 3b44 3b45 3b4a 3b4d 3b52
3b53 3b58 3b5b 3b5f 3b63 3b66 3b69 3b6a
3b6c 3b6d 3b72 3b73 3b78 3b7a 3b7e 3b81
3b83 3b87 3b89 3b95 3b97 3b99 3b9a 3b9f
3ba3 3ba5 3bb1 3bb3 3bb5 3bb9 3bbc 3bc0
3bc3 3bc7 3bcb 3bcf 3bd3 3bd7 3bdb 3bde
3be1 3be2 3be4 3be8 3bec 3bf0 3bf4 3bf8
3bfc 3c00 3c04 3c08 3c0c 3c10 3c14 3c18
3c1c 3c20 3c24 3c28 3c2c 3c38 3c3c 3c40
3c43 3c47 3c4b 3c4d 1 3c51 3c55 3c59
3c5c 3c60 3c64 3c68 3c6c 3c6f 3c73 3c77
3c7a 3c7d 3c82 3c85 3c88 3c8b 3c8c 3c91
3c92 1 3c94 3c99 3c9d 3ca1 3ca4 3ca9
3cae 3cb1 3cb5 3cb6 3cbb 3cbe 3cc3 3cc4
3cc9 3ccc 3cd1 3cd2 3cd7 3cda 3cde 3cdf
3ce4 3ce7 3cec 3ced 3cf2 3cf5 3cf9 3cfd
3d00 3d03 3d04 3d06 3d07 3d0c 3d0d 3d12
3d14 3d18 3d1b 3d1d 3d21 3d23 3d2f 3d31
3d33 3d34 3d39 3d3d 3d3f 3d4b 3d4d 3d51
3d55 3d58 3d59 3d5b 3d5e 3d61 3d62 3d67
3d6b 3d6f 3d73 3d77 3d7b 3d7f 3d83 3d87
3d8b 3d8f 3d93 3d97 3d9b 3d9f 3da3 3da7
3dab 3daf 3db3 3db7 3dc3 3dc7 3dcc 3dd0
3dd3 3dd4 3dd9 3ddd 3de1 3de4 3de7 3deb
3ded 3df1 3df5 3df8 3dfb 3dff 3e01 3e05
3e09 3e0c 3e0e 1 3e12 3e16 3e1a 3e1d
3e21 3e25 3e29 3e2d 3e30 3e34 3e38 3e3b
3e3e 3e43 3e46 3e49 3e4c 3e4d 3e52 3e53
1 3e55 3e5a 3e5e 3e62 3e65 3e6a 3e6f
3e72 3e76 3e77 3e7c 3e7f 3e84 3e85 3e8a
3e8d 3e92 3e93 3e98 3e9b 3e9f 3ea0 3ea5
3ea8 3ead 3eae 3eb3 3eb6 3eba 3ebe 3ec1
3ec4 3ec5 3ec7 3ec8 3ecd 3ece 3ed3 3ed5
3ed9 3edc 3ede 3ee2 3ee4 3ef0 3ef2 3ef4
3ef5 3efa 3efe 3f00 3f0c 3f0e 3f10 3f14
3f18 3f1c 3f20 3f24 3f28 3f2c 3f30 3f34
3f38 3f3c 3f40 3f44 3f48 3f4c 3f50 3f54
3f58 3f5c 3f60 3f64 3f68 3f74 3f78 3f7d
3f81 3f84 3f85 3f8a 3f8e 3f92 3f95 3f98
3f9c 3f9e 3fa2 3fa6 3fa9 3fac 3fb0 3fb2
3fb6 3fba 3fbd 3fbf 1 3fc3 3fc7 3fcb
3fce 3fd2 3fd6 3fda 3fde 3fe1 3fe5 3fe9
3fec 3fef 3ff4 3ff7 3ffa 3ffd 3ffe 4003
4004 1 4006 400b 400f 4013 4016 401b
4020 4023 4027 4028 402d 4030 4035 4036
403b 403e 4043 4044 4049 404c 4050 4051
4056 4059 405e 405f 4064 4067 406b 406f
4072 4075 4076 4078 4079 407e 407f 4084
4086 408a 408d 408f 4093 4095 40a1 40a3
40a5 40a6 40ab 40af 40b1 40bd 40bf 40c1
40c5 40c9 40cc 40ce 40d2 40d6 40d9 40e1
40e3 40e4 40e7 40e9 40ea 40ef 40f1 40f3
40f8 40fc 4101 4105 4109 410d 4111 4115
4119 4125 4129 412e 4132 4135 4136 413b
413f 4143 4146 4149 414d 414f 4153 4157
415a 415d 4161 4163 4167 416b 416e 4170
1 4174 4178 417c 417f 4183 4187 418b
418f 4192 4196 419a 419d 41a0 41a5 41a8
41ab 41ae 41af 41b4 41b5 1 41b7 41bc
41c0 41c4 41c7 41cc 41d1 41d4 41d8 41d9
41de 41e1 41e6 41e7 41ec 41ef 41f4 41f5
41fa 41fd 4201 4202 4207 420a 420f 4210
4215 4218 421c 4220 4223 4226 4227 4229
422a 422f 4230 4235 4237 423b 423e 4240
4244 4246 4252 4254 4256 4257 425c 4260
4262 426e 4270 4272 4276 427d 4281 4285
428a 428c 4290 4294 4297 429b 429f 42a1
1 42a5 42a9 42ad 42b0 42b4 42b8 42bc
42c0 42c3 42c7 42cb 42ce 42d1 42d6 42d9
42dc 42df 42e0 42e5 42e6 1 42e8 42ed
42f1 42f5 42f8 42fd 4302 4305 4309 430a
430f 4312 4317 4318 431d 4320 4325 4326
432b 432e 4332 4333 4338 433b 4340 4341
4346 4349 434d 4351 4354 4357 4358 435a
435b 4360 4361 4366 4368 436c 436f 4371
4375 4377 4383 4385 4387 4388 438d 4391
4393 439f 43a1 43a5 43a9 43ad 43ae 43b0
43b4 43b8 43bc 43c0 43c4 43c8 43cc 43d0
43d4 43d8 43dc 43e0 43e4 43e8 43f4 43f8
43fc 43ff 4403 4407 4409 1 440d 4411
4415 4418 441c 4420 4424 4428 442b 442f
4433 4436 4439 443e 4441 4444 4447 4448
444d 444e 1 4450 4455 4459 445d 4460
4465 446a 446d 4471 4472 4477 447a 447f
4480 4485 4488 448d 448e 4493 4496 449a
449b 44a0 44a3 44a8 44a9 44ae 44b1 44b5
44b9 44bc 44bf 44c0 44c2 44c3 44c8 44c9
44ce 44d0 44d4 44d7 44d9 44dd 44df 44eb
44ed 44ef 44f0 44f5 44f9 44fb 4507 4509
450d 4511 4514 4515 4517 451a 451d 451e
4523 4527 452b 452f 4532 4536 453a 453e
4541 4545 4549 454d 4551 4552 4554 4558
455a 455e 4561 4565 4569 456d 4571 4575
4579 457d 4581 458d 4591 4596 459a 459d
459e 45a3 45a7 45ab 45ae 45b1 45b5 45b7
45bb 45bf 45c2 45c5 45c9 45cb 45cf 45d3
45d6 45d8 1 45dc 45e0 45e4 45e7 45eb
45ef 45f3 45f7 45fa 45fe 4602 4605 4608
460d 4610 4613 4616 4617 461c 461d 1
461f 4624 4628 462c 462f 4634 4639 463c
4640 4641 4646 4649 464e 464f 4654 4657
465c 465d 4662 4665 4669 466a 466f 4672
4677 4678 467d 4680 4684 4688 468b 468e
468f 4691 4692 4697 4698 469d 469f 46a3
46a6 46a8 46ac 46ae 46ba 46bc 46be 46bf
46c4 46c8 46ca 46d6 46d8 46dc 46e0 46e3
46e6 46e9 46ea 46ef 46f3 46f7 46fa 46fd
4701 4703 4707 470a 470e 4712 4715 4719
471d 4720 4723 4728 472b 472e 4731 4732
4737 4738 1 473a 473f 4743 4747 474a
474f 4754 4757 475b 475c 4761 4764 4769
476a 476f 4772 4777 4778 477d 4780 4784
4788 478c 4790 4793 4794 4796 479b 479c
479e 479f 47a4 47a7 47ac 47ad 47b2 47b5
47ba 47bb 47c0 47c3 47c7 47c8 47cd 47d0
47d5 47d6 47db 47dc 47e1 47e3 47e7 47ea
47ee 47f2 47f5 47f9 47fd 4800 4804 4808
4809 480e 4810 4814 4818 481b 481f 4823
4826 482a 482e 4831 4834 4839 483c 483f
4842 4843 4848 4849 1 484b 4850 4854
4858 485b 4860 4865 4868 486c 486d 4872
4873 4878 487c 4880 4883 4888 488d 4890
4894 4898 489b 489c 48a1 48a4 48a9 48aa
48af 48b2 48b6 48ba 48bd 48be 48c3 48c4
48c9 48cb 48cf 48d2 48d6 48da 48de 48e2
48e6 48ea 48ee 48f2 48f6 4902 4907 490b
490f 4913 4917 4919 491a 491f 1 4923
4927 492b 492e 4932 4936 493a 493e 4941
4945 4949 494c 494f 4954 4957 495a 495d
495e 4963 4964 1 4966 496b 496f 4973
4976 497b 4980 4983 4987 4988 498d 498e
4993 4997 499b 499e 49a3 49a8 49ab 49af
49b0 49b5 49b8 49bd 49be 49c3 49c6 49ca
49ce 49d1 49d4 49d5 49d7 49d8 49dd 49de
49e3 49e5 49e9 49ec 49f0 49f4 49f8 49fc
4a00 4a04 4a08 4a14 4a19 4a1d 4a21 4a25
4a29 4a2b 4a2f 4a31 4a3d 4a3f 4a41 4a42
4a47 4a4b 4a4d 4a59 4a5d 4a5f 4a60 4a69 
14b0
2
0 1 a 6 9 :3 6 11 :2 6
1 3 a 13 a :2 1 4 c
10 f c 20 :2 29 c :2 4 d
11 10 d 21 :2 2a d :2 4 11
1a 19 :2 11 :2 4 :3 10 :2 4 d 16
15 :2 d :2 4 e 17 16 :2 e :2 4
9 12 11 :2 9 :2 4 18 21 20
:2 18 :2 4 18 21 20 :2 18 :2 4 :3 11
:2 4 :3 12 :2 4 :2 11 20 11 :2 4 :2 f
1e f :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 e 1d e :2 4 :2 12
21 12 :2 4 :2 12 21 12 :2 4 :2 e
1d e :2 4 :2 f 1e f :2 4 :2 e
1d e :2 4 :2 b 1a b :2 4 :2 f
1e f :2 4 :2 14 23 14 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 9
12 11 :2 9 4 7 e 0 :2 7
11 14 27 2a f 20 23 28
30 d f 1c 1f 2e 30 3d
40 10 12 1f 30 33 e 11
29 2c a :6 7 c 15 :3 c :2 7
e 0 :2 7 11 1b 26 35 10
1d 2e 42 4b a :6 7 e 0
:2 7 11 1a f 10 23 3b a
:5 7 4 e 17 :3 e 4 7 :2 11
23 :2 2d 3a :2 23 :3 7 :2 d 19 25
:2 2f 43 :2 25 58 5e 61 :2 58 6f
89 8 :2 6f d 10 :2 6f 13 16
:2 6f b e :2 6f 13 16 1f 27
:2 1f 34 :2 16 :2 6f 3c 3f :2 6f :2 7
4e :2 4 7 :2 11 23 :2 2d 39 3c
50 52 53 :2 50 :2 23 :3 7 :2 d 12
1e 61 64 :2 1e :2 7 56 :3 4 11
:2 4 c 4 e 17 31 44 52
5f :2 7 :2 10 1c 7 4 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 57 59 5a :2 57 :2 29 :3 d :2 13
18 24 67 6a :2 24 77 7a :2 24
7e 81 :2 24 8d 90 :2 24 98 9b
:2 24 a7 aa b1 ba bd :2 aa :2 24
:2 d 5d :2 a :2 7 :4 13 :2 7 4 :3 1
8 :2 11 1c 1a :2 25 :2 1a 7 11
27 34 59 f 1c 26 f 26
44 5a 6e :2 a :2 13 1f a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 5a 5c 5d :2 5a :2 2c
:3 10 :2 16 1b 27 6a 6d :2 27 7a
7d :2 27 81 84 :2 27 90 93 :2 27
9b 9e :2 27 aa ad b4 bd c0
:2 ad :2 27 :2 10 60 :2 d :2 a :4 16 :2 a
7 :3 35 b :2 14 1f 1d :2 28 :2 1d
a d :2 17 29 :2 33 3f 42 56
59 5a :2 56 :2 29 :3 d :2 13 18 24
68 6b :2 24 78 7b :2 24 7f 82
:2 24 8c 8f 98 a0 :2 a9 :2 98 bc
:2 8f :2 24 :2 d 5d :2 a d :2 17 29
:2 33 3f 42 56 59 5a :2 56 :2 29
:3 d :2 13 18 24 68 6b :2 24 :2 d
5d :3 a :2 15 2b :2 34 46 :2 a 7
38 e 17 22 :2 e 25 27 :2 25
d 2f 38 44 :2 2f 47 49 :2 47
2e :3 d :2 17 29 :2 33 3f 43 57
5a 5b :2 57 :2 29 :3 d :2 13 18 24
68 6b :2 24 78 7b :2 24 7f 82
:2 24 8c 8f 98 a0 :2 a9 :2 98 c5
:2 8f :2 24 cd d0 :2 24 d8 db :2 24
e0 e3 :2 24 e8 eb :2 24 :2 d 5e
:2 a d :2 17 29 :2 33 3f 42 56
59 5a :2 56 :2 29 :3 d :2 13 18 24
68 6b :2 24 :2 d 5d :3 a :2 15 29
:2 32 4d 53 :2 a 4c 38 :2 7 11
1a 34 47 55 62 :2 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 5a 5d 5e
:2 5a :2 2c :3 10 :2 16 1b 27 6b 6e
:2 27 7b 7e :2 27 82 85 :2 27 91
94 :2 27 9c 9f :2 27 ab ae b5
be c1 :2 ae :2 27 :2 10 61 :2 d :2 a
:4 16 :2 a 7 :3 35 7 f e 11
:2 f 30 33 :2 f 13 16 :2 f 7
35 7 17 7 a 13 1e :2 a
21 23 :2 21 14 d 29 33 3c
4d 56 66 d 1f 28 37 d
1f 28 38 d 29 43 57 d
1f :6 d 1f d 1f d 13 20
31 3d 46 4e 57 65 6e 7c
85 93 9c a9 b2 c3 cc df
e8 fd 106 121 12a 142 14b 15c
165 177 180 198 1a1 1b4 1bd 1de
1f3 207 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5d 60 61
:2 5d :2 2f :3 13 :2 19 1e 2a 6e 71
:2 2a 7e 81 :2 2a 85 88 :2 2a 94
97 :2 2a 9f a2 :2 2a ae b1 b8
c1 c4 :2 b1 :2 2a :2 13 64 :2 10 :2 d
:4 19 :2 d a :3 25 a f :4 a 13
1d 32 :3 d 10 15 :2 10 :2 19 25
10 1b 10 :2 19 25 10 :4 d 11
:2 1a 26 23 :2 2f :2 23 :3 10 3f :2 d
17 :2 10 1e 27 36 10 1f 28
38 10 2b 45 5b 10 1d 10
16 10 1f 28 37 10 20 29
39 10 1b 10 2d 4c 64 10
30 52 6d 10 30 4e 52 68
78 10 33 51 55 6b 7b 10
26 3d 53 10 27 3f 16 2a
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :3 a 17 2c 16 23 34 48
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :4 a e 25 d 13 :3 d :2 16
22 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5d 60
61 :2 5d :2 2f :3 13 :2 19 1e 2a 6e
71 :2 2a 7e 81 :2 2a 85 88 :2 2a
94 97 :2 2a 9f a2 :2 2a ae b1
b8 c1 c4 :2 b1 :2 2a :2 13 64 :2 10
:2 d :4 19 :2 d a :4 25 :2 7 11 1d
2b 34 10 1d 2e 43 57 a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 5a 5d 5e :2 5a :2 2c :3 10
:2 16 1b 27 6b 6e :2 27 7b 7e
:2 27 82 85 :2 27 91 94 :2 27 9c
9f :2 27 ab ae b5 be c1 :2 ae
:2 27 :2 10 61 :2 d :2 a :4 16 :2 a 7
:3 4 7 14 :2 7 14 :2 7 d e
11 :2 d 23 26 :2 d 13 16 :2 d
7 :5 4 9 :2 12 :2 4 d 17 1d
27 32 :3 7 a f :2 a :2 13 1f
a 15 a :2 13 1f a :4 7 b
:2 14 20 1d :2 29 :2 1d :3 a 39 :2 7
c f 17 1f 10 12 28 2a
10 12 28 2a 10 12 28 2a
10 12 25 27 10 12 25 27
10 12 25 27 16 23 34 41
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :3 11 17 28 10 13 25 28
39 3c 4f 52 64 67 7c 7f
93 96 a7 aa 10 13 2a 2d
43 46 60 63 10 13 25 28
39 3c 4f 52 64 67 7c 7f
93 96 a7 aa 10 13 2a 2d
43 46 60 63 10 13 25 28
3a 3d 50 53 66 69 7e 81
96 99 aa ad ba bd 10 13
2a 2d 40 43 57 5a 74 77
8d 90 10 13 24 27 35 38
49 4c 5a 5d 6e 71 7f 82
93 96 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 60
63 64 :2 60 :2 32 :3 16 :2 1c 21 2d
71 74 :2 2d 81 84 :2 2d 88 8b
:2 2d 97 9a :2 2d a2 a5 :2 2d b1
b4 bb c4 c7 :2 b4 :2 2d :2 16 67
:2 13 :2 10 :4 1c :2 10 d :3 11 17 10
2c 10 2c 10 36 5d 78 10
2d 10 2d 10 37 5f 7b 10
2d 10 2d 10 37 57 73 10
2b 10 2b 10 35 56 70 10
2e 10 2e 10 38 5c 79 10
21 10 22 10 24 10 20 2d
10 26 39 10 29 3f 16 23
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :4 11 :2 a f 17 29 38 4f
62 76 :2 10 :2 19 25 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 60 63 64 :2 60 :2 32 :3 16
:2 1c 21 2d 71 74 :2 2d 81 84
:2 2d 88 8b :2 2d 97 9a :2 2d a2
a5 :2 2d b1 b4 bb c4 c7 :2 b4
:2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10 d
:4 11 :2 1a 26 23 :2 2f :2 23 10 :4 44
43 42 :2 10 15 10 58 :2 d 17
34 4d 58 15 2a 15 2c 3f
49 5a 68 :2 10 :2 19 25 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :4 11 :2 1a 25 23 :2 2e :2 23 10
:4 44 43 42 :2 10 13 1c 27 :2 13
2a 2c :2 2a 13 1e 13 2e 22
39 4d 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :3 10 22 34 48 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:3 10 22 3e 52 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :3 10 22 3f
53 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :3 10 13 1e 13 :4 10 66
10 27 :2 10 1b 10 :5 d 1a :2 d
12 :4 d 16 1f 2c 37 :3 10 13
17 :2 13 :2 1c 28 13 1d 13 :2 1c
28 13 :4 10 14 :2 1d 29 26 :2 32
:2 26 :3 13 42 :2 10 13 1c 25 :2 13
28 2a :2 28 1d 32 3e 4a 16
22 2a 31 3c 1c 29 3a 4e
66 71 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :3 2c 17 :2 20 2b 29
:2 34 :2 29 16 25 3c 49 5a 6e
77 82 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 69 6c 6d
:2 69 :2 3b :3 1f :2 25 2a 36 7a 7d
:2 36 8a 8d :2 36 91 94 :2 36 a0
a3 :2 36 ab ae :2 36 ba bd c4
cd d0 :2 bd :2 36 :2 1f 70 :2 1c :2 19
:4 25 :2 19 16 :4 44 20 35 49 63
70 81 95 9e a9 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
69 6c 6d :2 69 :2 3b :3 1f :2 25 2a
36 7a 7d :2 36 8a 8d :2 36 91
94 :2 36 a0 a3 :2 36 ab ae :2 36
ba bd c4 cd d0 :2 bd :2 36 :2 1f
70 :2 1c :2 19 :4 25 :2 19 16 :7 13 10
2c 16 1f 28 :2 16 2b 2d :2 2b
1d 32 46 60 6d 7e 92 9b
a6 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :4 2f 2c :2 10 d :2 11 10
16 :3 10 :2 19 25 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 60 63 64 :2 60 :2 32 :3 16 :2 1c
21 2d 71 74 :2 2d 81 84 :2 2d
88 8b :2 2d 97 9a :2 2d a2 a5
:2 2d b1 b4 bb c4 c7 :2 b4 :2 2d
:2 16 67 :2 13 :2 10 :4 1c :2 10 d :3 11
17 2c 3c 48 16 23 34 40
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :3 11 10 19 24 :2 10 27 29
:2 27 1a :2 13 18 21 28 2d 36
13 21 13 22 13 24 13 20
13 22 13 23 13 1e 13 30
4f 67 13 33 55 70 13 19
13 2b 2f 45 55 13 36 54
58 6e 7e 13 29 40 56 13
2a 42 13 19 2d 36 49 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 63 66 67 :2 63 :2 35 :3 19
:2 1f 24 30 74 77 :2 30 84 87
:2 30 8b 8e :2 30 9a 9d :2 30 a5
a8 :2 30 b4 b7 be c7 ca :2 b7
:2 30 :2 19 6a :2 16 :2 13 :4 1f :2 13 10
:3 2b 13 1c 25 :2 13 28 2a :2 28
13 21 :2 13 26 36 44 59 65
68 :2 26 13 2c :2 10 2b 10 15
:4 10 19 22 2d :3 13 16 1a :2 16
:2 1f 2b 16 20 16 :2 1f 2b 16
:4 13 17 :2 20 2c 29 :2 35 :2 29 :3 16
45 :2 13 1d :2 16 1b 24 16 1b
24 16 24 16 25 16 27 16
23 16 25 16 26 16 21 16
33 52 6a 16 36 58 73 16
1c 16 2e 32 48 58 16 39
57 5b 71 81 16 2c 43 59
16 2d 45 16 2e 1c 30 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:3 10 1d 29 37 40 58 65 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:4 10 14 d 13 19 :3 13 :2 1c 28
13 10 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 63 66 67
:2 63 :2 35 :3 19 :2 1f 24 30 74 77
:2 30 84 87 :2 30 8b 8e :2 30 9a
9d :2 30 a5 a8 :2 30 b4 b7 be
c7 ca :2 b7 :2 30 :2 19 6a :2 16 :2 13
:4 1f :2 13 10 :3 d 14 1d 28 :2 14
2b 2d :2 2b 13 35 3e 46 :2 35
49 4b :2 49 34 :2 13 1d 32 3d
4a 5e 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :4 4e :3 10 1e :2 10 23
33 41 56 62 65 :2 23 10 1a
31 37 44 52 5c 6a 18 2d
3b 49 58 64 70 18 2f 45
:2 13 :2 1c 28 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 66 67 :2 63 :2 35 :3 19 :2 1f 24
30 74 77 :2 30 84 87 :2 30 8b
8e :2 30 9a 9d :2 30 a5 a8 :2 30
b4 b7 be c7 ca :2 b7 :2 30 :2 19
6a :2 16 :2 13 :4 1f :2 13 10 :3 d 13
1c 28 :2 13 2b 2d :2 2b 1d :6 16
2e 16 2f 16 2f 16 2e 45
16 1c 29 3a 48 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 69 6a :2 66 :2 38 :3 1c :2 22 27
33 77 7a :2 33 87 8a :2 33 8e
91 :2 33 9d a0 :2 33 a8 ab :2 33
b7 ba c1 ca cd :2 ba :2 33 :2 1c
6d :2 19 :2 16 :4 22 :2 16 13 :4 2f 1d
:6 16 2e 16 2f 16 2f 16 2e
45 16 31 48 1c 29 3a 48
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9d a0 :2 33
a8 ab :2 33 b7 ba c1 ca cd
:2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16
13 :7 10 :4 d f d :3 11 :2 a d
a :3 7 11 1d 2b 34 4c 59
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 5a 5d 5e :2 5a :2 2c
:3 10 :2 16 1b 27 6b 6e :2 27 7b
7e :2 27 82 85 :2 27 91 94 :2 27
9c 9f :2 27 ab ae b5 be c1
:2 ae :2 27 :2 10 61 :2 d :2 a :4 16 :2 a
7 :4 4 8 1 7 d :3 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 57 5a
5b :2 57 :2 29 :3 d :2 13 18 24 68
6b :2 24 78 7b :2 24 7f 82 :2 24
8e 91 :2 24 99 9c :2 24 a8 ab
b2 bb be :2 ab :2 24 :2 d 5e :2 a
:2 7 :4 13 :2 7 4 :3 1 4 17 21
:2 17 4 19 1f 28 34 3a 43
4f 59 62 :2 c 1a 27 :2 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 57 5a
5b :2 57 :2 29 :3 d :2 13 18 24 68
6b :2 24 78 7b :2 24 7f 82 :2 24
8e 91 :2 24 99 9c :2 24 a8 ab
b2 bb be :2 ab :2 24 :2 d 5e :2 a
:2 7 :4 13 :2 7 4 :3 1 7 10 1f
:2 7 22 24 :2 22 7 14 :2 1d :2 7
:2 10 1c 30 3e 4d :2 1c 7 26
:2 4 e 7 1f 2c 3a 47 d
1a 7 e a 16 :3 14 a :2 13
1f a 1b a :2 13 1f a :4 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 57 5a 5b :2 57
:2 29 :3 d :2 13 18 24 68 6b :2 24
78 7b :2 24 7f 82 :2 24 8e 91
:2 24 99 9c :2 24 a8 ab b2 bb
be :2 ab :2 24 :2 d 5e :2 a :2 7 :4 13
:2 7 4 :3 1 7 :2 10 19 1b :2 19
7 :2 10 1c 7 1f :2 4 7 :2 11
23 :2 2d 39 3c 50 53 54 :2 50
:2 23 :3 7 :2 d 12 1e 62 65 :2 1e
72 75 :2 1e 79 7c :2 1e 86 89
92 9a :2 a3 :2 92 ae :2 89 :2 1e b6
b9 :2 1e c1 c4 :2 1e c9 cc :2 1e
cf d2 :2 1e :2 7 57 :3 4 :2 f 21
:2 2a 34 38 :2 4 1 9 12 9
a :2 14 26 :2 30 3c 40 54 57
58 :2 54 :2 26 :3 a :2 10 15 21 65
68 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 5b :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 51 54
55 :2 51 :2 23 :3 7 :2 d 12 1e 62
65 :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 58 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
14b0
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :a 7
:a 8 :7 9 :5 a :7 b
:7 c :7 d :7 e :7 f
:5 10 :5 11 :6 12 :6 13
:6 14 :6 15 :6 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :7 21 :2 23 0
:2 23 :4 24 :5 25 :8 26
:5 27 :4 28 24 :5 23
:7 2b :2 2d 0 :2 2d
:4 2e :5 2f 2e :5 2d
:2 31 0 :2 31 :2 32
33 :3 34 32 :5 31
:7 36 :b 38 :11 39 3a
:2 39 :2 3a :2 39 :2 3a
:2 39 :2 3b :2 39 :9 3b
:2 39 :2 3b :4 39 :3 38
:11 3e :b 3f :3 3e :3 45
:3 46 :7 49 :5 4a 48
:2 4c :5 4e :11 4f :24 50
:3 4f :2 4d :6 4c 4b
:3 37 :a 56 :4 58 :3 59
:5 5a 58 :5 5b 57
:2 5d :5 5f :11 60 :24 61
:3 60 :2 5e :6 5d 5c
:3 56 :a 66 :11 67 :20 68
:3 67 :11 6a :b 6b :3 6a
:9 6d 6e 66 :16 6e
:11 6f :30 70 :3 6f :11 72
:b 73 :3 72 :a 75 6e
:3 66 :7 79 :5 7a 78
:2 7c :5 7e :11 7f :24 80
:3 7f :2 7d :6 7c 7b
:3 56 :2 85 :2 86 :2 85
:2 86 :2 85 :2 87 :3 85
56 :3 89 :9 8c 8f
:7 90 :4 91 :4 92 :4 93
:2 94 95 96 97
98 99 :2 9a :2 9b
9c :24 9d 8f :6 9e
:5 9f 9e :5 a1 a0
:3 9e 8e :2 a4 :5 a6
:11 a7 :24 a8 :3 a7 :2 a5
:6 a4 a3 :3 8c :5 ad
af :6 b0 :3 b1 :5 b2
b1 :5 b4 b3 :3 b1
:a b6 :2 b7 :3 b6 bb
bc :4 bd :4 be :4 bf
:2 c0 :2 c1 :4 c2 :4 c3
:2 c4 :4 c5 :4 c6 :6 c7
:6 c8 :4 c9 :3 ca :2 cb
bb :6 cc :5 cd cc
:5 cf ce :3 cc ba
:2 d2 :5 d4 :11 d5 :24 d6
:3 d5 :2 d3 :6 d2 d1
:3 af :2 dc :4 dd dc
:6 de :5 df de :5 e1
e0 :3 de db :2 e4
:5 e6 :11 e7 :24 e8 :3 e7
:2 e5 :6 e4 e3 :4 af
ec 8c :4 f0 :5 f1
ef :2 f3 :5 f5 :11 f6
:24 f7 :3 f6 :2 f4 :6 f3
f2 :6 8c :4 fe :5 ff
fe :6 100 :5 101 100
:5 103 102 :3 100 fd
:2 106 :5 108 :11 109 :24 10a
:3 109 :2 107 :6 106 105
:3 88 :3 10f :3 110 112
113 :2 114 :2 113 :2 114
:2 113 :2 115 :2 113 112
88 :3 56 :5 11c 11e
:8 11f :3 120 :5 121 120
:5 123 122 :3 120 :a 126
:2 127 :3 126 12b 12d
:2 132 :4 133 :4 134 :4 135
:4 136 :4 137 :4 138 :4 139
132 :6 13a :5 13b 13a
:5 13d 13c :3 13a 131
:2 140 :5 142 :11 143 :24 144
:3 143 :2 141 :6 140 13f
:3 12d :2 14b :10 14c :8 14d
:10 14e :8 14f :12 150 :c 151
:10 152 :2 153 14b :6 154
:5 155 154 :5 157 156
:3 154 14a :2 15a :5 15c
:11 15d :24 15e :3 15d :2 15b
:6 15a 159 :3 12d 164
:2 165 :2 166 :4 167 :2 168
:2 169 :4 16a :2 16b :2 16c
:4 16d :2 16e :2 16f :4 170
:2 171 :2 172 :4 173 :2 174
:2 175 :2 176 :3 177 :3 178
:3 179 :2 17a 164 :6 17b
:5 17c 17b :5 17e 17d
:3 17b 163 :2 181 :5 183
:11 184 :24 185 :3 184 :2 182
:6 181 180 :6 12d 18c
:7 191 :5 192 190 :2 194
:5 196 :11 197 :24 198 :3 197
:2 195 :6 194 193 :3 18c
:12 19d :2 19e :3 19d :4 1a2
:2 1a3 :6 1a4 1a2 :5 1a5
1a1 :2 1a7 :5 1a9 :11 1aa
:24 1ab :3 1aa :2 1a8 :6 1a7
1a6 :3 18c :12 1b1 :9 1b2
:3 1b3 1b2 :4 1b7 :6 1b8
:5 1b9 1b8 :5 1bb 1ba
:3 1b8 1b6 :2 1be :5 1c0
:11 1c1 :24 1c2 :3 1c1 :2 1bf
:6 1be 1bd :3 1b4 :4 1c8
:6 1c9 :5 1ca 1c9 :5 1cc
1cb :3 1c9 1c7 :2 1cf
:5 1d1 :11 1d2 :24 1d3 :3 1d2
:2 1d0 :6 1cf 1ce :3 1b4
:4 1d9 :6 1da :5 1db 1da
:5 1dd 1dc :3 1da 1d8
:2 1e0 :5 1e2 :11 1e3 :24 1e4
:3 1e3 :2 1e1 :6 1e0 1df
:3 1b4 :4 1ea :6 1eb :5 1ec
1eb :5 1ee 1ed :3 1eb
1e9 :2 1f1 :5 1f3 :11 1f4
:24 1f5 :3 1f4 :2 1f2 :6 1f1
1f0 :3 1b4 :3 1fa 1b4
:3 1b2 1b1 :3 1fd :3 1fe
1fc :3 1b1 :3 201 :5 206
208 :7 209 :3 20a :5 20b
20a :5 20d 20c :3 20a
:a 210 :2 211 :3 210 :9 215
:4 217 :5 218 :6 219 217
:6 21a :5 21b 21a :5 21d
21c :3 21a 216 :2 220
:5 222 :11 223 :24 224 :3 223
:2 221 :6 220 21f :3 215
:a 22a :8 22c :6 22d :5 22e
22d :5 230 22f :3 22d
22b :2 233 :5 235 :11 236
:24 237 :3 236 :2 234 :6 233
232 :4 22a :a 23d :6 23e
:5 23f 23e :5 241 240
:3 23e 23c :2 244 :5 246
:11 247 :24 248 :3 247 :2 245
:6 244 243 :4 23b :3 22a
24d 215 :9 24d :a 24f
:6 250 :5 251 250 :5 253
252 :3 250 24e :2 256
:5 258 :11 259 :24 25a :3 259
:2 257 :6 256 255 :4 24d
:3 215 208 25f 18c
:4 261 :5 262 260 :2 264
:5 266 :11 267 :24 268 :3 267
:2 265 :6 264 263 :3 18c
:4 26e :4 26f 26e :6 270
:5 271 270 :5 273 272
:3 270 26d :2 276 :5 278
:11 279 :24 27a :3 279 :2 277
:6 276 275 :3 18c :9 27f
281 282 :6 283 :2 284
:2 285 :2 286 :2 287 :2 288
:2 289 :2 28a :4 28b :4 28c
:2 28d :5 28e :6 28f :4 290
:3 291 292 :4 293 281
:6 294 :5 295 294 :5 297
296 :3 294 280 :2 29a
:5 29c :11 29d :24 29e :3 29d
:2 29b :6 29a 299 :3 27f
:9 2a3 :3 2a5 :a 2a6 :3 2a3
27f :5 2ab 2ad :6 2ae
:3 2af :5 2b0 2af :5 2b2
2b1 :3 2af :a 2b4 :2 2b5
:3 2b4 2b9 2ba :3 2bb
:3 2bc :2 2bd :2 2be :2 2bf
:2 2c0 :2 2c1 :2 2c2 :2 2c3
:4 2c4 :4 2c5 :2 2c6 :5 2c7
:6 2c8 :4 2c9 :3 2ca :2 2cb
:2 2cc 2b9 :6 2cd :5 2ce
2cd :5 2d0 2cf :3 2cd
2b8 :2 2d3 :5 2d5 :11 2d6
:24 2d7 :3 2d6 :2 2d4 :6 2d3
2d2 :3 2ad :7 2df :6 2e0
:5 2e1 2e0 :5 2e3 2e2
:3 2e0 2de :2 2e6 :5 2e8
:11 2e9 :24 2ea :3 2e9 :2 2e7
:6 2e6 2e5 :4 2ad 2ee
2a8 :4 2f1 :5 2f2 2f0
:2 2f4 :5 2f6 :11 2f7 :24 2f8
:3 2f7 :2 2f5 :6 2f4 2f3
:3 2a8 :16 2fd :6 2ff :6 300
:5 301 300 :5 303 302
:3 300 2fe :2 306 :5 308
:11 309 :24 30a :3 309 :2 307
:6 306 305 :6 2fd :3 311
:a 312 :7 315 :7 316 :3 317
315 :5 318 314 :2 31a
:5 31c :11 31d :24 31e :3 31d
:2 31b :6 31a 319 :3 2a8
:9 324 326 327 328
329 32a 32b :2 32c
:2 32d :2 32e :3 32f 330
:4 331 326 :6 332 :5 333
332 :5 335 334 :3 332
325 :2 338 :5 33a :11 33b
:24 33c :3 33b :2 339 :6 338
337 :4 324 342 343
344 345 346 347
:2 348 :2 349 :2 34a :3 34b
:3 34c :4 34d 342 :6 34e
:5 34f 34e :5 351 350
:3 34e 341 :2 354 :5 356
:11 357 :24 358 :3 357 :2 355
:6 354 353 :4 340 :3 324
2a8 :3 27f 360 361
:5 18c 363 362 :3 12b
:7 368 :6 369 :5 36a 369
:5 36c 36b :3 369 367
:2 36f :5 371 :11 372 :24 373
:3 372 :2 370 :6 36f 36e
:4 11e 378 37 :4 37c
:5 37d 37b :2 37f :5 381
:11 382 :24 383 :3 382 :2 380
:6 37f 37e :3 37 :6 388
:9 38c 38d :3 38e 38c
:5 38f 38b :2 391 :5 393
:11 394 :24 395 :3 394 :2 392
:6 391 390 :3 37 :9 39a
:5 39b :a 39c :3 39a 3a0
:5 3a1 :2 3a2 3a0 :6 3a3
:5 3a4 3a3 :5 3a6 3a5
:3 3a3 39f :2 3a9 :5 3ab
:11 3ac :24 3ad :3 3ac :2 3aa
:6 3a9 3a8 :3 37 :7 3b2
:5 3b3 :3 3b2 :11 3b6 :30 3b7
:3 3b6 :a 3b9 37 :3 3bc
:11 3bd :b 3be :17 3bf :3 3bd
:2 3c1 :3 3c2 :3 3c3 3c4
3c2 3c1 3c2 :3 3c5
:3 3bc :2 3c6 :5 3c8 :11 3c9
:b 3ca :18 3cb :3 3c9 :2 3cd
3ce :3 3cf 3d0 3ce
3cd 3ce :3 3d1 :2 3c7
:6 3c6 3bb :7 1 
4a6b
4
:3 0 1 :3 0 2
:a 0 14ab 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 6
:3 0 5 :7 0 9
8 :3 0 7 :3 0
8 :3 0 9 :2 0
4 b f 0
14ab 2 10 :2 0
c :2 0 c b
:3 0 c :2 0 a
13 15 2 :5 0
d :3 0 e :3 0
17 18 0 1b
16 19 14a9 0
a :6 0 11 :2 0
10 b :3 0 e
1d 1f 2 :5 0
d :3 0 e :3 0
21 22 0 25
20 23 14a9 0
f :6 0 16 c9
0 14 4 :3 0
12 27 29 :6 0
2c 2a 0 14a9
0 10 :6 0 11
:2 0 1a 13 :3 0
2e :7 0 31 2f
0 14a9 0 12
:6 0 4 :3 0 11
:2 0 18 33 35
:6 0 38 36 0
14a9 0 14 :6 0
11 :2 0 1e 4
:3 0 1c 3a 3c
:6 0 3f 3d 0
14a9 0 15 :6 0
11 :2 0 22 4
:3 0 20 41 43
:6 0 46 44 0
14a9 0 16 :6 0
11 :2 0 26 4
:3 0 24 48 4a
:6 0 4d 4b 0
14a9 0 17 :6 0
2c 175 0 2a
4 :3 0 28 4f
51 :6 0 54 52
0 14a9 0 18
:6 0 1d :2 0 2e
1a :3 0 56 :7 0
59 57 0 14a9
0 19 :6 0 1a
:3 0 5b :7 0 5e
5c 0 14a9 0
1b :6 0 1d :2 0
30 6 :3 0 60
:7 0 64 61 62
14a9 0 1c :6 0
1d :2 0 32 6
:3 0 66 :7 0 6a
67 68 14a9 0
1e :6 0 1d :2 0
34 6 :3 0 6c
:7 0 70 6d 6e
14a9 0 1f :6 0
1d :2 0 36 6
:3 0 72 :7 0 76
73 74 14a9 0
20 :6 0 1d :2 0
38 6 :3 0 78
:7 0 7c 79 7a
14a9 0 21 :6 0
1d :2 0 3a 6
:3 0 7e :7 0 82
7f 80 14a9 0
22 :6 0 1d :2 0
3c 6 :3 0 84
:7 0 88 85 86
14a9 0 23 :6 0
1d :2 0 3e 6
:3 0 8a :7 0 8e
8b 8c 14a9 0
24 :6 0 1d :2 0
40 6 :3 0 90
:7 0 94 91 92
14a9 0 25 :6 0
1d :2 0 42 6
:3 0 96 :7 0 9a
97 98 14a9 0
26 :6 0 1d :2 0
44 6 :3 0 9c
:7 0 a0 9d 9e
14a9 0 27 :6 0
1d :2 0 46 6
:3 0 a2 :7 0 a6
a3 a4 14a9 0
28 :6 0 2c :2 0
48 6 :3 0 a8
:7 0 ac a9 aa
14a9 0 29 :6 0
2c :2 0 4a 2b
:3 0 ae :7 0 b2
af b0 14a9 0
2a :6 0 2f :2 0
4c 2b :3 0 b4
:7 0 b8 b5 b6
14a9 0 2d :9 0
50 4 :3 0 4e
ba bc :6 0 bf
bd 0 14a9 0
2e :6 0 30 :3 0
31 :a 0 2 e0
:4 0 c1 c4 0
c2 :3 0 32 :3 0
33 :3 0 32 :3 0
34 :3 0 35 :3 0
32 :3 0 36 :3 0
37 :3 0 38 :3 0
38 :3 0 39 :3 0
32 :3 0 39 :3 0
38 :3 0 3a :3 0
32 :3 0 3b :3 0
38 :3 0 39 :3 0
10 :3 0 32 :3 0
3c :3 0 32 :3 0
3d :3 0 32 :3 0
3e :4 0 3f 1
:8 0 e1 c1 c4
e2 0 14a9 52
e2 e4 e1 e3
:6 0 e0 :7 0 e2
:3 0 54 8 :3 0
9 :2 0 4 e6
e7 0 e8 :7 0
eb e9 0 14a9
0 40 :6 0 30
:3 0 41 :a 0 3
fb :4 0 ed f0
0 ee :3 0 42
:3 0 43 :3 0 44
:3 0 45 :3 0 39
:3 0 10 :3 0 33
:3 0 16 :3 0 3c
:4 0 46 1 :8 0
fc ed f0 fd
0 14a9 56 fd
ff fc fe :6 0
fb :7 0 fd 30
:3 0 47 :a 0 4
10c :5 0 101 104
0 102 :3 0 3b
:3 0 33 :3 0 35
:3 0 3c :3 0 3e
:3 0 16 :4 0 48
1 :8 0 10d 101
104 10e 0 14a9
58 10e 110 10d
10f :6 0 10c :7 0
10e 118 119 0
5a 8 :3 0 9
:2 0 4 112 113
0 114 :7 0 117
115 0 14a9 0
49 :6 0 4a :3 0
4b :3 0 4a :3 0
4c :3 0 11b 11c
0 2 :4 0 5c
11d 11f 11a 121
120 :2 0 4d :3 0
4e :3 0 123 124
0 4f :4 0 4a
:3 0 50 :3 0 127
128 0 2 :4 0
5e 129 12b 51
:4 0 52 :2 0 53
:3 0 60 12e 130
:3 0 54 :4 0 52
:2 0 55 :4 0 63
133 135 :3 0 52
:2 0 3 :3 0 66
137 139 :3 0 52
:2 0 55 :4 0 69
13b 13d :3 0 52
:2 0 56 :4 0 6c
13f 141 :3 0 52
:2 0 57 :3 0 58
:3 0 5 :3 0 6f
145 147 59 :4 0
71 144 14a 74
143 14c :3 0 52
:2 0 5a :4 0 77
14e 150 :3 0 7a
125 152 :2 0 154
7f 155 122 154
0 156 81 0
1409 4a :3 0 4b
:3 0 157 158 0
4a :3 0 5b :3 0
15a 15b 0 5c
:2 0 2 :4 0 5d
:2 0 5e :2 0 5c
:2 0 83 160 162
:3 0 86 15c 164
159 166 165 :2 0
4d :3 0 5f :3 0
168 169 0 4f
:4 0 60 :4 0 52
:2 0 53 :3 0 8a
16d 16f :3 0 8d
16a 171 :2 0 173
90 174 167 173
0 175 92 0
1409 21 :3 0 5
:3 0 176 177 0
1409 16 :3 0 3
:3 0 179 17a 0
1409 57 :3 0 61
:3 0 22 :3 0 37
:3 0 3a :3 0 16
:4 0 62 1 :8 0
188 8 :3 0 63
:3 0 183 184 0
64 :3 0 185 186
0 188 94 1d2
65 :3 0 8 :3 0
63 :3 0 18b 18c
0 64 :3 0 18d
18e 0 1c8 4a
:3 0 4b :3 0 190
191 0 4a :3 0
5b :3 0 193 194
0 66 :2 0 2
:4 0 67 :2 0 5e
:2 0 5c :2 0 97
199 19b :3 0 9a
195 19d 192 19f
19e :2 0 4d :3 0
5f :3 0 1a1 1a2
0 4f :4 0 68
:4 0 52 :2 0 53
:3 0 9e 1a6 1a8
:3 0 52 :2 0 69
:4 0 a1 1aa 1ac
:3 0 52 :2 0 6a
:4 0 a4 1ae 1b0
:3 0 52 :2 0 64
:3 0 a7 1b2 1b4
:3 0 52 :2 0 6b
:4 0 aa 1b6 1b8
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 ad
1bb 1bf b1 1ba
1c1 :3 0 b4 1a3
1c3 :2 0 1c5 b7
1c6 1a0 1c5 0
1c7 b9 0 1c8
bb 1cb :3 0 1cb
0 1cb 1ca 1c8
1c9 :6 0 1cd 5
:3 0 be 1cf c0
1ce 1cd :2 0 1d0
c2 :2 0 1d2 0
1d2 1d1 188 1d0
:6 0 1409 1 :3 0
8 :3 0 63 :3 0
1d4 1d5 0 8
:3 0 6f :2 0 70
:3 0 1d7 1d9 0
c6 1d8 1db :3 0
1dc :2 0 39 :3 0
39 :3 0 3b :3 0
3e :3 0 10 :3 0
26 :3 0 25 :3 0
35 :3 0 71 :3 0
3d :3 0 33 :3 0
16 :4 0 72 1
:8 0 1f0 8 :3 0
63 :3 0 1eb 1ec
0 64 :3 0 1ed
1ee 0 1f0 c9
23a 65 :3 0 8
:3 0 63 :3 0 1f3
1f4 0 64 :3 0
1f5 1f6 0 230
4a :3 0 4b :3 0
1f8 1f9 0 4a
:3 0 5b :3 0 1fb
1fc 0 66 :2 0
2 :4 0 73 :2 0
5e :2 0 5c :2 0
cc 201 203 :3 0
cf 1fd 205 1fa
207 206 :2 0 4d
:3 0 5f :3 0 209
20a 0 4f :4 0
74 :4 0 52 :2 0
53 :3 0 d3 20e
210 :3 0 52 :2 0
69 :4 0 d6 212
214 :3 0 52 :2 0
6a :4 0 d9 216
218 :3 0 52 :2 0
64 :3 0 dc 21a
21c :3 0 52 :2 0
6b :4 0 df 21e
220 :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
e2 223 227 e6
222 229 :3 0 e9
20b 22b :2 0 22d
ec 22e 208 22d
0 22f ee 0
230 f0 233 :3 0
233 0 233 232
230 231 :6 0 235
7 :3 0 f3 237
f5 236 235 :2 0
238 f7 :2 0 23a
0 23a 239 1f0
238 :6 0 392 1
:3 0 8 :3 0 63
:3 0 23c 23d 0
8 :3 0 6f :2 0
70 :3 0 23f 241
0 fb 240 243
:3 0 244 :2 0 4a
:3 0 4b :3 0 246
247 0 4a :3 0
5b :3 0 249 24a
0 75 :2 0 2
:4 0 76 :2 0 5e
:2 0 5c :2 0 fe
24f 251 :3 0 101
24b 253 248 255
254 :2 0 4d :3 0
5f :3 0 257 258
0 4f :4 0 77
:4 0 52 :2 0 53
:3 0 105 25c 25e
:3 0 52 :2 0 69
:4 0 108 260 262
:3 0 52 :2 0 78
:4 0 10b 264 266
:3 0 52 :2 0 57
:3 0 58 :3 0 d
:3 0 79 :3 0 26b
26c 0 10e 26a
26e 59 :4 0 110
269 271 113 268
273 :3 0 116 259
275 :2 0 277 119
278 256 277 0
279 11b 0 2a3
4a :3 0 4b :3 0
27a 27b 0 4a
:3 0 5b :3 0 27d
27e 0 5c :2 0
2 :4 0 7a :2 0
5e :2 0 5c :2 0
11d 283 285 :3 0
120 27f 287 27c
289 288 :2 0 4d
:3 0 5f :3 0 28b
28c 0 4f :4 0
7b :4 0 52 :2 0
53 :3 0 124 290
292 :3 0 127 28d
294 :2 0 296 12a
297 28a 296 0
298 12c 0 2a3
7c :3 0 7d :3 0
299 29a 0 d
:3 0 79 :3 0 29c
29d 0 7e :3 0
12e 29b 2a0 :2 0
2a3 7f :3 0 131
329 57 :3 0 26
:3 0 1d :2 0 135
2a4 2a7 6f :2 0
1d :2 0 13a 2a9
2ab :3 0 2ac :2 0
57 :3 0 25 :3 0
1d :2 0 13d 2ae
2b1 6f :2 0 5c
:2 0 142 2b3 2b5
:3 0 2b6 :2 0 2ad
2b8 2b7 :2 0 4a
:3 0 4b :3 0 2ba
2bb 0 4a :3 0
5b :3 0 2bd 2be
0 11 :2 0 2
:4 0 80 :2 0 5e
:2 0 5c :2 0 145
2c3 2c5 :3 0 148
2bf 2c7 2bc 2c9
2c8 :2 0 4d :3 0
5f :3 0 2cb 2cc
0 4f :4 0 81
:4 0 52 :2 0 53
:3 0 14c 2d0 2d2
:3 0 52 :2 0 69
:4 0 14f 2d4 2d6
:3 0 52 :2 0 78
:4 0 152 2d8 2da
:3 0 52 :2 0 57
:3 0 58 :3 0 d
:3 0 82 :3 0 2df
2e0 0 155 2de
2e2 59 :4 0 157
2dd 2e5 15a 2dc
2e7 :3 0 52 :2 0
83 :4 0 15d 2e9
2eb :3 0 52 :2 0
55 :4 0 160 2ed
2ef :3 0 52 :2 0
16 :3 0 163 2f1
2f3 :3 0 52 :2 0
55 :4 0 166 2f5
2f7 :3 0 169 2cd
2f9 :2 0 2fb 16c
2fc 2ca 2fb 0
2fd 16e 0 327
4a :3 0 4b :3 0
2fe 2ff 0 4a
:3 0 5b :3 0 301
302 0 5c :2 0
2 :4 0 84 :2 0
5e :2 0 5c :2 0
170 307 309 :3 0
173 303 30b 300
30d 30c :2 0 4d
:3 0 5f :3 0 30f
310 0 4f :4 0
85 :4 0 52 :2 0
53 :3 0 177 314
316 :3 0 17a 311
318 :2 0 31a 17d
31b 30e 31a 0
31c 17f 0 327
7c :3 0 86 :3 0
31d 31e 0 d
:3 0 82 :3 0 320
321 0 16 :3 0
7e :3 0 181 31f
325 :2 0 327 185
328 2b9 327 0
32a 245 2a3 0
32a 189 0 392
57 :3 0 61 :3 0
22 :3 0 37 :3 0
3a :3 0 10 :4 0
87 1 :8 0 337
8 :3 0 63 :3 0
332 333 0 64
:3 0 334 335 0
337 18c 381 65
:3 0 8 :3 0 63
:3 0 33a 33b 0
64 :3 0 33c 33d
0 377 4a :3 0
4b :3 0 33f 340
0 4a :3 0 5b
:3 0 342 343 0
66 :2 0 2 :4 0
88 :2 0 5e :2 0
5c :2 0 18f 348
34a :3 0 192 344
34c 341 34e 34d
:2 0 4d :3 0 5f
:3 0 350 351 0
4f :4 0 89 :4 0
52 :2 0 53 :3 0
196 355 357 :3 0
52 :2 0 69 :4 0
199 359 35b :3 0
52 :2 0 6a :4 0
19c 35d 35f :3 0
52 :2 0 64 :3 0
19f 361 363 :3 0
52 :2 0 6b :4 0
1a2 365 367 :3 0
52 :2 0 6c :3 0
6d :3 0 5c :2 0
6e :2 0 1a5 36a
36e 1a9 369 370
:3 0 1ac 352 372
:2 0 374 1af 375
34f 374 0 376
1b1 0 377 1b3
37a :3 0 37a 0
37a 379 377 378
:6 0 37c 9 :3 0
1b6 37e 1b8 37d
37c :2 0 37f 1ba
:2 0 381 0 381
380 337 37f :6 0
392 1 :3 0 2e
:3 0 8a :4 0 52
:2 0 8b :4 0 1bc
385 387 :3 0 52
:2 0 16 :3 0 1bf
389 38b :3 0 52
:2 0 8c :4 0 1c2
38d 38f :3 0 383
390 0 392 1c5
651 10 :3 0 16
:3 0 393 394 0
650 57 :3 0 21
:3 0 1d :2 0 1ca
396 399 6f :2 0
8d :2 0 1cf 39b
39d :3 0 37 :3 0
8e :3 0 8e :3 0
d :3 0 8f :3 0
d :3 0 90 :3 0
8e :3 0 91 :3 0
57 :3 0 92 :3 0
91 :3 0 93 :3 0
57 :3 0 94 :3 0
93 :3 0 95 :3 0
96 :3 0 95 :3 0
96 :3 0 97 :3 0
98 :3 0 92 :3 0
94 :3 0 96 :3 0
99 :3 0 9a :3 0
9b :3 0 98 :3 0
9c :3 0 98 :3 0
9d :3 0 39 :3 0
10 :3 0 8e :3 0
d :3 0 9e :3 0
d :3 0 9f :3 0
d :3 0 a0 :3 0
d :3 0 a1 :3 0
d :3 0 a2 :3 0
d :3 0 a3 :3 0
d :3 0 a4 :3 0
d :3 0 a5 :3 0
d :3 0 a6 :3 0
d :3 0 a7 :3 0
d :3 0 a8 :3 0
d :3 0 a9 :3 0
d :3 0 aa :3 0
d :3 0 ab :3 0
d :3 0 ac :3 0
ad :3 0 ae :3 0
97 :4 0 af 1
:8 0 3f9 b0 :4 0
3e4 :3 0 7e :3 0
6f :2 0 1d4 3e7
3e8 :3 0 8 :3 0
63 :3 0 3ea 3eb
0 1d :2 0 3ec
3ed 0 3ef 1d7
3f6 8 :3 0 63
:3 0 3f0 3f1 0
b1 :2 0 3f2 3f3
0 3f5 1d9 3f7
3e9 3ef 0 3f8
0 3f5 0 3f8
1db 0 3f9 1de
443 65 :3 0 8
:3 0 63 :3 0 3fc
3fd 0 64 :3 0
3fe 3ff 0 439
4a :3 0 4b :3 0
401 402 0 4a
:3 0 5b :3 0 404
405 0 66 :2 0
2 :4 0 b2 :2 0
5e :2 0 5c :2 0
1e1 40a 40c :3 0
1e4 406 40e 403
410 40f :2 0 4d
:3 0 5f :3 0 412
413 0 4f :4 0
b3 :4 0 52 :2 0
53 :3 0 1e8 417
419 :3 0 52 :2 0
69 :4 0 1eb 41b
41d :3 0 52 :2 0
6a :4 0 1ee 41f
421 :3 0 52 :2 0
64 :3 0 1f1 423
425 :3 0 52 :2 0
6b :4 0 1f4 427
429 :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
1f7 42c 430 1fb
42b 432 :3 0 1fe
414 434 :2 0 436
201 437 411 436
0 438 203 0
439 205 43c :3 0
43c 0 43c 43b
439 43a :6 0 43e
b :3 0 208 440
20a 43f 43e :2 0
441 20c :2 0 443
0 443 442 3f9
441 :6 0 5cd 1
:3 0 b4 :3 0 31
:4 0 448 :2 0 5cd
446 449 :3 0 b5
:3 0 31 :3 0 17
:3 0 14 :4 0 44f
:2 0 575 44b 450
:3 0 20e :3 0 31
:3 0 b0 :3 0 451
452 :3 0 8 :3 0
63 :3 0 454 455
0 1d :2 0 456
457 0 459 211
460 8 :3 0 63
:3 0 45a 45b 0
b1 :2 0 45c 45d
0 45f 213 461
453 459 0 462
0 45f 0 462
215 0 575 8
:3 0 63 :3 0 463
464 0 8 :3 0
b6 :2 0 b7 :3 0
466 468 0 21a
467 46a :3 0 46b
:2 0 b8 :8 0 46f
21d 470 46c 46f
0 471 21f 0
575 35 :3 0 3c
:3 0 91 :3 0 57
:3 0 92 :3 0 91
:3 0 93 :3 0 57
:3 0 94 :3 0 93
:3 0 95 :3 0 96
:3 0 96 :3 0 95
:3 0 b9 :3 0 ba
:3 0 9c :3 0 ba
:3 0 bb :3 0 57
:3 0 92 :3 0 91
:3 0 bc :3 0 57
:3 0 94 :3 0 93
:3 0 bd :3 0 ba
:3 0 be :3 0 bf
:3 0 bf :3 0 be
:3 0 c0 :3 0 c1
:3 0 c1 :3 0 c0
:3 0 c2 :3 0 c3
:3 0 9c :3 0 ba
:3 0 c4 :3 0 c5
:3 0 c6 :3 0 c3
:3 0 9c :3 0 ba
:3 0 c7 :3 0 c8
:3 0 92 :3 0 94
:3 0 96 :3 0 ba
:3 0 99 :3 0 9a
:3 0 9d :3 0 33
:3 0 17 :4 0 c9
1 :8 0 4c1 b0
:4 0 4ac :3 0 7e
:3 0 6f :2 0 223
4af 4b0 :3 0 8
:3 0 63 :3 0 4b2
4b3 0 1d :2 0
4b4 4b5 0 4b7
226 4be 8 :3 0
63 :3 0 4b8 4b9
0 b1 :2 0 4ba
4bb 0 4bd 228
4bf 4b1 4b7 0
4c0 0 4bd 0
4c0 22a 0 4c1
22d 50b 65 :3 0
8 :3 0 63 :3 0
4c4 4c5 0 64
:3 0 4c6 4c7 0
501 4a :3 0 4b
:3 0 4c9 4ca 0
4a :3 0 5b :3 0
4cc 4cd 0 66
:2 0 2 :4 0 ca
:2 0 5e :2 0 5c
:2 0 230 4d2 4d4
:3 0 233 4ce 4d6
4cb 4d8 4d7 :2 0
4d :3 0 5f :3 0
4da 4db 0 4f
:4 0 cb :4 0 52
:2 0 53 :3 0 237
4df 4e1 :3 0 52
:2 0 69 :4 0 23a
4e3 4e5 :3 0 52
:2 0 6a :4 0 23d
4e7 4e9 :3 0 52
:2 0 64 :3 0 240
4eb 4ed :3 0 52
:2 0 6b :4 0 243
4ef 4f1 :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 246 4f4 4f8
24a 4f3 4fa :3 0
24d 4dc 4fc :2 0
4fe 250 4ff 4d9
4fe 0 500 252
0 501 254 504
:3 0 504 0 504
503 501 502 :6 0
506 e :3 0 257
508 259 507 506
:2 0 509 25b :2 0
50b 0 50b 50a
4c1 509 :6 0 575
d :3 0 45 :3 0
3c :3 0 39 :3 0
10 :3 0 33 :3 0
17 :4 0 cc 1
:8 0 529 b0 :4 0
514 :3 0 7e :3 0
6f :2 0 25f 517
518 :3 0 8 :3 0
63 :3 0 51a 51b
0 1d :2 0 51c
51d 0 51f 262
526 8 :3 0 63
:3 0 520 521 0
b1 :2 0 522 523
0 525 264 527
519 51f 0 528
0 525 0 528
266 0 529 269
573 65 :3 0 8
:3 0 63 :3 0 52c
52d 0 64 :3 0
52e 52f 0 569
4a :3 0 4b :3 0
531 532 0 4a
:3 0 5b :3 0 534
535 0 66 :2 0
2 :4 0 cd :2 0
5e :2 0 5c :2 0
26c 53a 53c :3 0
26f 536 53e 533
540 53f :2 0 4d
:3 0 5f :3 0 542
543 0 4f :4 0
ce :4 0 52 :2 0
53 :3 0 273 547
549 :3 0 52 :2 0
69 :4 0 276 54b
54d :3 0 52 :2 0
6a :4 0 279 54f
551 :3 0 52 :2 0
64 :3 0 27c 553
555 :3 0 52 :2 0
6b :4 0 27f 557
559 :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
282 55c 560 286
55b 562 :3 0 289
544 564 :2 0 566
28c 567 541 566
0 568 28e 0
569 290 56c :3 0
56c 0 56c 56b
569 56a :6 0 56e
10 :3 0 293 570
295 56f 56e :2 0
571 297 :2 0 573
0 573 572 529
571 :6 0 575 d
:3 0 299 577 b5
:4 0 575 :4 0 5cd
cf :3 0 31 :4 0
57b :2 0 581 579
0 8 :3 0 63
:3 0 57c 57d 0
64 :3 0 57e 57f
0 581 29f 5cb
65 :3 0 8 :3 0
63 :3 0 584 585
0 64 :3 0 586
587 0 5c1 4a
:3 0 4b :3 0 589
58a 0 4a :3 0
5b :3 0 58c 58d
0 66 :2 0 2
:4 0 d0 :2 0 5e
:2 0 5c :2 0 2a2
592 594 :3 0 2a5
58e 596 58b 598
597 :2 0 4d :3 0
5f :3 0 59a 59b
0 4f :4 0 d1
:4 0 52 :2 0 53
:3 0 2a9 59f 5a1
:3 0 52 :2 0 69
:4 0 2ac 5a3 5a5
:3 0 52 :2 0 6a
:4 0 2af 5a7 5a9
:3 0 52 :2 0 64
:3 0 2b2 5ab 5ad
:3 0 52 :2 0 6b
:4 0 2b5 5af 5b1
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 2b8
5b4 5b8 2bc 5b3
5ba :3 0 2bf 59c
5bc :2 0 5be 2c2
5bf 599 5be 0
5c0 2c4 0 5c1
2c6 5c4 :3 0 5c4
0 5c4 5c3 5c1
5c2 :6 0 5c6 12
:3 0 2c9 5c8 2cb
5c7 5c6 :2 0 5c9
2cd :2 0 5cb 0
5cb 5ca 581 5c9
:6 0 5cd 1 :3 0
2cf 5ce 39e 5cd
0 5cf 2d4 0
650 37 :3 0 d2
:3 0 d :3 0 d3
:3 0 39 :3 0 10
:3 0 ad :3 0 ae
:3 0 97 :4 0 d4
1 :8 0 5ef b0
:4 0 5da :3 0 7e
:3 0 6f :2 0 2d8
5dd 5de :3 0 8
:3 0 63 :3 0 5e0
5e1 0 1d :2 0
5e2 5e3 0 5e5
2db 5ec 8 :3 0
63 :3 0 5e6 5e7
0 b1 :2 0 5e8
5e9 0 5eb 2dd
5ed 5df 5e5 0
5ee 0 5eb 0
5ee 2df 0 5ef
2e2 639 65 :3 0
8 :3 0 63 :3 0
5f2 5f3 0 64
:3 0 5f4 5f5 0
62f 4a :3 0 4b
:3 0 5f7 5f8 0
4a :3 0 5b :3 0
5fa 5fb 0 66
:2 0 2 :4 0 d5
:2 0 5e :2 0 5c
:2 0 2e5 600 602
:3 0 2e8 5fc 604
5f9 606 605 :2 0
4d :3 0 5f :3 0
608 609 0 4f
:4 0 d6 :4 0 52
:2 0 53 :3 0 2ec
60d 60f :3 0 52
:2 0 69 :4 0 2ef
611 613 :3 0 52
:2 0 6a :4 0 2f2
615 617 :3 0 52
:2 0 64 :3 0 2f5
619 61b :3 0 52
:2 0 6b :4 0 2f8
61d 61f :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 2fb 622 626
2ff 621 628 :3 0
302 60a 62a :2 0
62c 305 62d 607
62c 0 62e 307
0 62f 309 632
:3 0 632 0 632
631 62f 630 :6 0
634 14 :3 0 30c
636 30e 635 634
:2 0 637 310 :2 0
639 0 639 638
5ef 637 :6 0 650
1 :3 0 26 :3 0
5c :2 0 63b 63c
0 650 21 :3 0
d7 :2 0 63e 63f
0 650 2e :3 0
d8 :4 0 52 :2 0
d9 :4 0 312 643
645 :3 0 52 :2 0
16 :3 0 315 647
649 :3 0 52 :2 0
8c :4 0 318 64b
64d :3 0 641 64e
0 650 31b 652
1dd 392 0 653
0 650 0 653
322 0 1409 b4
:3 0 40 :3 0 2e
:3 0 655 656 0
657 :2 0 1409 b5
:3 0 40 :3 0 16
:3 0 14 :3 0 15
:3 0 27 :4 0 660
:2 0 126a 65a 661
:3 0 325 :3 0 40
:3 0 b0 :3 0 662
663 :3 0 8 :3 0
63 :3 0 665 666
0 1d :2 0 667
668 0 66a 32a
671 8 :3 0 63
:3 0 66b 66c 0
b1 :2 0 66d 66e
0 670 32c 672
664 66a 0 673
0 670 0 673
32e 0 126a 8
:3 0 63 :3 0 674
675 0 8 :3 0
b6 :2 0 b7 :3 0
677 679 0 333
678 67b :3 0 67c
:2 0 b8 :8 0 680
336 681 67d 680
0 682 338 0
126a 21 :3 0 5c
:2 0 da :3 0 db
:3 0 db :3 0 dc
:3 0 db :3 0 dd
:3 0 db :3 0 dd
:3 0 db :3 0 de
:3 0 db :3 0 de
:3 0 db :3 0 df
:3 0 db :3 0 e0
:3 0 db :3 0 e1
:3 0 db :3 0 e1
:3 0 db :3 0 e2
:3 0 db :3 0 e2
:3 0 db :3 0 e3
:3 0 39 :3 0 10
:3 0 3a :3 0 15
:4 0 e4 1 :8 0
6b9 b0 :4 0 6a4
:3 0 7e :3 0 6f
:2 0 33c 6a7 6a8
:3 0 8 :3 0 63
:3 0 6aa 6ab 0
1d :2 0 6ac 6ad
0 6af 33f 6b6
8 :3 0 63 :3 0
6b0 6b1 0 b1
:2 0 6b2 6b3 0
6b5 341 6b7 6a9
6af 0 6b8 0
6b5 0 6b8 343
0 6b9 346 703
65 :3 0 8 :3 0
63 :3 0 6bc 6bd
0 64 :3 0 6be
6bf 0 6f9 4a
:3 0 4b :3 0 6c1
6c2 0 4a :3 0
5b :3 0 6c4 6c5
0 66 :2 0 2
:4 0 e5 :2 0 5e
:2 0 5c :2 0 349
6ca 6cc :3 0 34c
6c6 6ce 6c3 6d0
6cf :2 0 4d :3 0
5f :3 0 6d2 6d3
0 4f :4 0 e6
:4 0 52 :2 0 53
:3 0 350 6d7 6d9
:3 0 52 :2 0 69
:4 0 353 6db 6dd
:3 0 52 :2 0 6a
:4 0 356 6df 6e1
:3 0 52 :2 0 64
:3 0 359 6e3 6e5
:3 0 52 :2 0 6b
:4 0 35c 6e7 6e9
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 35f
6ec 6f0 363 6eb
6f2 :3 0 366 6d4
6f4 :2 0 6f6 369
6f7 6d1 6f6 0
6f8 36b 0 6f9
36d 6fc :3 0 6fc
0 6fc 6fb 6f9
6fa :6 0 6fe 17
:3 0 370 700 372
6ff 6fe :2 0 701
374 :2 0 703 0
703 702 6b9 701
:6 0 865 16 :3 0
35 :3 0 32 :3 0
32 :3 0 e7 :3 0
32 :3 0 e8 :3 0
32 :3 0 e9 :3 0
32 :3 0 ea :3 0
32 :3 0 eb :3 0
32 :3 0 ec :3 0
32 :3 0 ed :3 0
32 :3 0 ee :3 0
32 :3 0 ef :3 0
32 :3 0 f0 :3 0
32 :3 0 f1 :3 0
32 :3 0 f2 :3 0
32 :3 0 e8 :3 0
32 :3 0 f3 :3 0
32 :3 0 ea :3 0
32 :3 0 f4 :3 0
32 :3 0 ec :3 0
32 :3 0 f5 :3 0
32 :3 0 ee :3 0
32 :3 0 f6 :3 0
32 :3 0 f0 :3 0
32 :3 0 f7 :3 0
32 :3 0 f2 :3 0
32 :3 0 f8 :3 0
32 :3 0 f3 :3 0
32 :3 0 f9 :3 0
32 :3 0 f4 :3 0
32 :3 0 fa :3 0
32 :3 0 f5 :3 0
32 :3 0 fb :3 0
32 :3 0 f6 :3 0
32 :3 0 b9 :3 0
32 :3 0 ba :3 0
32 :3 0 f7 :3 0
32 :3 0 be :3 0
32 :3 0 bf :3 0
32 :3 0 f8 :3 0
32 :3 0 c0 :3 0
32 :3 0 c1 :3 0
32 :3 0 fc :3 0
32 :3 0 c4 :3 0
32 :3 0 fd :3 0
32 :3 0 c7 :3 0
32 :3 0 fe :3 0
32 :3 0 ff :3 0
32 :3 0 100 :3 0
32 :3 0 101 :3 0
33 :3 0 16 :4 0
102 1 :8 0 77d
b0 :4 0 768 :3 0
7e :3 0 6f :2 0
378 76b 76c :3 0
8 :3 0 63 :3 0
76e 76f 0 1d
:2 0 770 771 0
773 37b 77a 8
:3 0 63 :3 0 774
775 0 b1 :2 0
776 777 0 779
37d 77b 76d 773
0 77c 0 779
0 77c 37f 0
77d 382 7c7 65
:3 0 8 :3 0 63
:3 0 780 781 0
64 :3 0 782 783
0 7bd 4a :3 0
4b :3 0 785 786
0 4a :3 0 5b
:3 0 788 789 0
66 :2 0 2 :4 0
103 :2 0 5e :2 0
5c :2 0 385 78e
790 :3 0 388 78a
792 787 794 793
:2 0 4d :3 0 5f
:3 0 796 797 0
4f :4 0 104 :4 0
52 :2 0 53 :3 0
38c 79b 79d :3 0
52 :2 0 69 :4 0
38f 79f 7a1 :3 0
52 :2 0 6a :4 0
392 7a3 7a5 :3 0
52 :2 0 64 :3 0
395 7a7 7a9 :3 0
52 :2 0 6b :4 0
398 7ab 7ad :3 0
52 :2 0 6c :3 0
6d :3 0 5c :2 0
6e :2 0 39b 7b0
7b4 39f 7af 7b6
:3 0 3a2 798 7b8
:2 0 7ba 3a5 7bb
795 7ba 0 7bc
3a7 0 7bd 3a9
7c0 :3 0 7c0 0
7c0 7bf 7bd 7be
:6 0 7c2 19 :3 0
3ac 7c4 3ae 7c3
7c2 :2 0 7c5 3b0
:2 0 7c7 0 7c7
7c6 77d 7c5 :6 0
865 16 :3 0 105
:3 0 106 :3 0 107
:3 0 107 :3 0 108
:3 0 108 :3 0 109
:3 0 109 :3 0 10a
:3 0 10b :3 0 10c
:3 0 10c :3 0 10d
:3 0 10d :3 0 10e
:3 0 10e :3 0 10f
:3 0 110 :3 0 111
:3 0 111 :3 0 112
:3 0 112 :3 0 113
:3 0 113 :3 0 114
:3 0 115 :3 0 116
:3 0 116 :3 0 117
:3 0 117 :3 0 118
:3 0 118 :3 0 119
:3 0 11a :3 0 11b
:3 0 11b :3 0 11c
:3 0 11c :3 0 11d
:3 0 11d :3 0 11e
:3 0 11f :3 0 f9
:3 0 120 :3 0 fa
:3 0 121 :3 0 fb
:3 0 122 :3 0 b9
:3 0 ba :3 0 123
:3 0 be :3 0 bf
:3 0 124 :3 0 c0
:3 0 c1 :3 0 39
:3 0 10 :4 0 125
1 :8 0 819 b0
:4 0 804 :3 0 7e
:3 0 6f :2 0 3b4
807 808 :3 0 8
:3 0 63 :3 0 80a
80b 0 1d :2 0
80c 80d 0 80f
3b7 816 8 :3 0
63 :3 0 810 811
0 b1 :2 0 812
813 0 815 3b9
817 809 80f 0
818 0 815 0
818 3bb 0 819
3be 863 65 :3 0
8 :3 0 63 :3 0
81c 81d 0 64
:3 0 81e 81f 0
859 4a :3 0 4b
:3 0 821 822 0
4a :3 0 5b :3 0
824 825 0 66
:2 0 2 :4 0 126
:2 0 5e :2 0 5c
:2 0 3c1 82a 82c
:3 0 3c4 826 82e
823 830 82f :2 0
4d :3 0 5f :3 0
832 833 0 4f
:4 0 127 :4 0 52
:2 0 53 :3 0 3c8
837 839 :3 0 52
:2 0 69 :4 0 3cb
83b 83d :3 0 52
:2 0 6a :4 0 3ce
83f 841 :3 0 52
:2 0 64 :3 0 3d1
843 845 :3 0 52
:2 0 6b :4 0 3d4
847 849 :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 3d7 84c 850
3db 84b 852 :3 0
3de 834 854 :2 0
856 3e1 857 831
856 0 858 3e3
0 859 3e5 85c
:3 0 85c 0 85c
85b 859 85a :6 0
85e 1b :3 0 3e8
860 3ea 85f 85e
:2 0 861 3ec :2 0
863 0 863 862
819 861 :6 0 865
16 :3 0 3ee 867
3f2 866 865 :2 0
1200 d7 :2 0 ba
:3 0 20 :3 0 35
:3 0 3c :3 0 33
:3 0 16 :4 0 128
1 :8 0 875 8
:3 0 63 :3 0 870
871 0 64 :3 0
872 873 0 875
3f4 8bf 65 :3 0
8 :3 0 63 :3 0
878 879 0 64
:3 0 87a 87b 0
8b5 4a :3 0 4b
:3 0 87d 87e 0
4a :3 0 5b :3 0
880 881 0 66
:2 0 2 :4 0 129
:2 0 5e :2 0 5c
:2 0 3f7 886 888
:3 0 3fa 882 88a
87f 88c 88b :2 0
4d :3 0 5f :3 0
88e 88f 0 4f
:4 0 12a :4 0 52
:2 0 53 :3 0 3fe
893 895 :3 0 52
:2 0 69 :4 0 401
897 899 :3 0 52
:2 0 6a :4 0 404
89b 89d :3 0 52
:2 0 64 :3 0 407
89f 8a1 :3 0 52
:2 0 6b :4 0 40a
8a3 8a5 :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 40d 8a8 8ac
411 8a7 8ae :3 0
414 890 8b0 :2 0
8b2 417 8b3 88d
8b2 0 8b4 419
0 8b5 41b 8b8
:3 0 8b8 0 8b8
8b7 8b5 8b6 :6 0
8ba 1d :3 0 41e
8bc 420 8bb 8ba
:2 0 8bd 422 :2 0
8bf 0 8bf 8be
875 8bd :6 0 11fa
16 :3 0 8 :3 0
63 :3 0 8c1 8c2
0 8 :3 0 b6
:2 0 b7 :3 0 8c4
8c6 0 426 8c5
8c8 :3 0 8c9 :2 0
20 :3 0 12b :2 0
429 8cc 8cd :3 0
8ce :2 0 8cf :2 0
8ca 8d1 8d0 :2 0
12c :3 0 8d3 :4 0
8d5 42b 8d6 8d2
8d5 0 8d7 42d
0 11fa 33 :3 0
12d :3 0 12d :3 0
27 :3 0 18 :3 0
27 :3 0 35 :3 0
3c :3 0 3b :3 0
10 :3 0 34 :3 0
14 :4 0 12e 1
:8 0 8ea 8 :3 0
63 :3 0 8e5 8e6
0 64 :3 0 8e7
8e8 0 8ea 42f
934 65 :3 0 8
:3 0 63 :3 0 8ed
8ee 0 64 :3 0
8ef 8f0 0 92a
4a :3 0 4b :3 0
8f2 8f3 0 4a
:3 0 5b :3 0 8f5
8f6 0 66 :2 0
2 :4 0 12f :2 0
5e :2 0 5c :2 0
432 8fb 8fd :3 0
435 8f7 8ff 8f4
901 900 :2 0 4d
:3 0 5f :3 0 903
904 0 4f :4 0
130 :4 0 52 :2 0
53 :3 0 439 908
90a :3 0 52 :2 0
69 :4 0 43c 90c
90e :3 0 52 :2 0
6a :4 0 43f 910
912 :3 0 52 :2 0
64 :3 0 442 914
916 :3 0 52 :2 0
6b :4 0 445 918
91a :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
448 91d 921 44c
91c 923 :3 0 44f
905 925 :2 0 927
452 928 902 927
0 929 454 0
92a 456 92d :3 0
92d 0 92d 92c
92a 92b :6 0 92f
1f :3 0 459 931
45b 930 92f :2 0
932 45d :2 0 934
0 934 933 8ea
932 :6 0 11fa 16
:3 0 8 :3 0 63
:3 0 936 937 0
8 :3 0 6f :2 0
b7 :3 0 939 93b
0 461 93a 93d
:3 0 93e :2 0 18
:3 0 131 :2 0 464
941 942 :3 0 943
:2 0 944 :2 0 93f
946 945 :2 0 57
:3 0 26 :3 0 1d
:2 0 466 948 94b
6f :2 0 1d :2 0
46b 94d 94f :3 0
1f :3 0 d7 :2 0
951 952 0 954
46e aed 35 :3 0
33 :3 0 16 :4 0
132 1 :8 0 96e
b0 :4 0 959 :3 0
7e :3 0 6f :2 0
472 95c 95d :3 0
8 :3 0 63 :3 0
95f 960 0 1d
:2 0 961 962 0
964 475 96b 8
:3 0 63 :3 0 965
966 0 b1 :2 0
967 968 0 96a
477 96c 95e 964
0 96d 0 96a
0 96d 479 0
96e 47c 9b8 65
:3 0 8 :3 0 63
:3 0 971 972 0
64 :3 0 973 974
0 9ae 4a :3 0
4b :3 0 976 977
0 4a :3 0 5b
:3 0 979 97a 0
66 :2 0 2 :4 0
133 :2 0 5e :2 0
5c :2 0 47f 97f
981 :3 0 482 97b
983 978 985 984
:2 0 4d :3 0 5f
:3 0 987 988 0
4f :4 0 134 :4 0
52 :2 0 53 :3 0
486 98c 98e :3 0
52 :2 0 69 :4 0
489 990 992 :3 0
52 :2 0 6a :4 0
48c 994 996 :3 0
52 :2 0 64 :3 0
48f 998 99a :3 0
52 :2 0 6b :4 0
492 99c 99e :3 0
52 :2 0 6c :3 0
6d :3 0 5c :2 0
6e :2 0 495 9a1
9a5 499 9a0 9a7
:3 0 49c 989 9a9
:2 0 9ab 49f 9ac
986 9ab 0 9ad
4a1 0 9ae 4a3
9b1 :3 0 9b1 0
9b1 9b0 9ae 9af
:6 0 9b3 21 :3 0
4a6 9b5 4a8 9b4
9b3 :2 0 9b6 4aa
:2 0 9b8 0 9b8
9b7 96e 9b6 :6 0
aec 16 :3 0 135
:3 0 33 :3 0 16
:4 0 136 1 :8 0
9d3 b0 :4 0 9be
:3 0 7e :3 0 6f
:2 0 4ae 9c1 9c2
:3 0 8 :3 0 63
:3 0 9c4 9c5 0
1d :2 0 9c6 9c7
0 9c9 4b1 9d0
8 :3 0 63 :3 0
9ca 9cb 0 b1
:2 0 9cc 9cd 0
9cf 4b3 9d1 9c3
9c9 0 9d2 0
9cf 0 9d2 4b5
0 9d3 4b8 a1d
65 :3 0 8 :3 0
63 :3 0 9d6 9d7
0 64 :3 0 9d8
9d9 0 a13 4a
:3 0 4b :3 0 9db
9dc 0 4a :3 0
5b :3 0 9de 9df
0 66 :2 0 2
:4 0 137 :2 0 5e
:2 0 5c :2 0 4bb
9e4 9e6 :3 0 4be
9e0 9e8 9dd 9ea
9e9 :2 0 4d :3 0
5f :3 0 9ec 9ed
0 4f :4 0 138
:4 0 52 :2 0 53
:3 0 4c2 9f1 9f3
:3 0 52 :2 0 69
:4 0 4c5 9f5 9f7
:3 0 52 :2 0 6a
:4 0 4c8 9f9 9fb
:3 0 52 :2 0 64
:3 0 4cb 9fd 9ff
:3 0 52 :2 0 6b
:4 0 4ce a01 a03
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 4d1
a06 a0a 4d5 a05
a0c :3 0 4d8 9ee
a0e :2 0 a10 4db
a11 9eb a10 0
a12 4dd 0 a13
4df a16 :3 0 a16
0 a16 a15 a13
a14 :6 0 a18 23
:3 0 4e2 a1a 4e4
a19 a18 :2 0 a1b
4e6 :2 0 a1d 0
a1d a1c 9d3 a1b
:6 0 aec 16 :3 0
139 :3 0 13a :3 0
16 :4 0 13b 1
:8 0 a38 b0 :4 0
a23 :3 0 7e :3 0
6f :2 0 4ea a26
a27 :3 0 8 :3 0
63 :3 0 a29 a2a
0 1d :2 0 a2b
a2c 0 a2e 4ed
a35 8 :3 0 63
:3 0 a2f a30 0
b1 :2 0 a31 a32
0 a34 4ef a36
a28 a2e 0 a37
0 a34 0 a37
4f1 0 a38 4f4
a82 65 :3 0 8
:3 0 63 :3 0 a3b
a3c 0 64 :3 0
a3d a3e 0 a78
4a :3 0 4b :3 0
a40 a41 0 4a
:3 0 5b :3 0 a43
a44 0 66 :2 0
2 :4 0 13c :2 0
5e :2 0 5c :2 0
4f7 a49 a4b :3 0
4fa a45 a4d a42
a4f a4e :2 0 4d
:3 0 5f :3 0 a51
a52 0 4f :4 0
13d :4 0 52 :2 0
53 :3 0 4fe a56
a58 :3 0 52 :2 0
69 :4 0 501 a5a
a5c :3 0 52 :2 0
6a :4 0 504 a5e
a60 :3 0 52 :2 0
64 :3 0 507 a62
a64 :3 0 52 :2 0
6b :4 0 50a a66
a68 :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
50d a6b a6f 511
a6a a71 :3 0 514
a53 a73 :2 0 a75
517 a76 a50 a75
0 a77 519 0
a78 51b a7b :3 0
a7b 0 a7b a7a
a78 a79 :6 0 a7d
25 :3 0 51e a7f
520 a7e a7d :2 0
a80 522 :2 0 a82
0 a82 a81 a38
a80 :6 0 aec 16
:3 0 13e :3 0 13a
:3 0 16 :4 0 13f
1 :8 0 a9d b0
:4 0 a88 :3 0 7e
:3 0 6f :2 0 526
a8b a8c :3 0 8
:3 0 63 :3 0 a8e
a8f 0 1d :2 0
a90 a91 0 a93
529 a9a 8 :3 0
63 :3 0 a94 a95
0 b1 :2 0 a96
a97 0 a99 52b
a9b a8d a93 0
a9c 0 a99 0
a9c 52d 0 a9d
530 ae7 65 :3 0
8 :3 0 63 :3 0
aa0 aa1 0 64
:3 0 aa2 aa3 0
add 4a :3 0 4b
:3 0 aa5 aa6 0
4a :3 0 5b :3 0
aa8 aa9 0 66
:2 0 2 :4 0 6e
:2 0 5e :2 0 5c
:2 0 533 aae ab0
:3 0 536 aaa ab2
aa7 ab4 ab3 :2 0
4d :3 0 5f :3 0
ab6 ab7 0 4f
:4 0 140 :4 0 52
:2 0 53 :3 0 53a
abb abd :3 0 52
:2 0 69 :4 0 53d
abf ac1 :3 0 52
:2 0 6a :4 0 540
ac3 ac5 :3 0 52
:2 0 64 :3 0 543
ac7 ac9 :3 0 52
:2 0 6b :4 0 546
acb acd :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 549 ad0 ad4
54d acf ad6 :3 0
550 ab8 ad8 :2 0
ada 553 adb ab5
ada 0 adc 555
0 add 557 ae0
:3 0 ae0 0 ae0
adf add ade :6 0
ae2 27 :3 0 55a
ae4 55c ae3 ae2
:2 0 ae5 55e :2 0
ae7 0 ae7 ae6
a9d ae5 :6 0 aec
16 :3 0 1f :3 0
5c :2 0 ae9 aea
0 aec 560 aee
950 954 0 aef
0 aec 0 aef
566 0 af0 569
af8 18 :3 0 16
:3 0 af1 af2 0
af7 1f :3 0 1d
:2 0 af4 af5 0
af7 56b af9 947
af0 0 afa 0
af7 0 afa 56e
0 11fa 20 :3 0
1d :2 0 afb afc
0 11fa b4 :3 0
41 :4 0 b01 :2 0
11fa aff b02 :3 0
b5 :3 0 41 :3 0
12 :3 0 20 :3 0
a :4 0 b09 :2 0
d03 b04 b0a :3 0
571 :3 0 41 :3 0
b0 :3 0 b0b b0c
:3 0 8 :3 0 63
:3 0 b0e b0f 0
1d :2 0 b10 b11
0 b13 575 b1a
8 :3 0 63 :3 0
b14 b15 0 b1
:2 0 b16 b17 0
b19 577 b1b b0d
b13 0 b1c 0
b19 0 b1c 579
0 d03 8 :3 0
63 :3 0 b1d b1e
0 8 :3 0 b6
:2 0 b7 :3 0 b20
b22 0 57e b21
b24 :3 0 b25 :2 0
b8 :8 0 b29 581
b2a b26 b29 0
b2b 583 0 d03
57 :3 0 1f :3 0
1d :2 0 585 b2c
b2f 6f :2 0 5c
:2 0 58a b31 b33
:3 0 45 :3 0 43
:3 0 43 :3 0 20
:3 0 44 :3 0 141
:3 0 142 :3 0 44
:3 0 a :3 0 39
:3 0 10 :3 0 33
:3 0 18 :3 0 42
:3 0 12 :4 0 143
1 :8 0 b5a b0
:4 0 b45 :3 0 7e
:3 0 6f :2 0 58f
b48 b49 :3 0 8
:3 0 63 :3 0 b4b
b4c 0 1d :2 0
b4d b4e 0 b50
592 b57 8 :3 0
63 :3 0 b51 b52
0 b1 :2 0 b53
b54 0 b56 594
b58 b4a b50 0
b59 0 b56 0
b59 596 0 b5a
599 ba4 65 :3 0
8 :3 0 63 :3 0
b5d b5e 0 64
:3 0 b5f b60 0
b9a 4a :3 0 4b
:3 0 b62 b63 0
4a :3 0 5b :3 0
b65 b66 0 66
:2 0 2 :4 0 144
:2 0 5e :2 0 5c
:2 0 59c b6b b6d
:3 0 59f b67 b6f
b64 b71 b70 :2 0
4d :3 0 5f :3 0
b73 b74 0 4f
:4 0 145 :4 0 52
:2 0 53 :3 0 5a3
b78 b7a :3 0 52
:2 0 69 :4 0 5a6
b7c b7e :3 0 52
:2 0 6a :4 0 5a9
b80 b82 :3 0 52
:2 0 64 :3 0 5ac
b84 b86 :3 0 52
:2 0 6b :4 0 5af
b88 b8a :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 5b2 b8d b91
5b6 b8c b93 :3 0
5b9 b75 b95 :2 0
b97 5bc b98 b72
b97 0 b99 5be
0 b9a 5c0 b9d
:3 0 b9d 0 b9d
b9c b9a b9b :6 0
b9f 2a :3 0 5c3
ba1 5c5 ba0 b9f
:2 0 ba2 5c7 :2 0
ba4 0 ba4 ba3
b5a ba2 :6 0 c8a
29 :3 0 8 :3 0
63 :3 0 ba6 ba7
0 8 :3 0 6f
:2 0 b7 :3 0 ba9
bab 0 5cb baa
bad :3 0 bae :2 0
45 :3 0 39 :3 0
10 :3 0 33 :3 0
16 :3 0 42 :3 0
12 :4 0 146 1
:8 0 bcd b0 :4 0
bb8 :3 0 7e :3 0
6f :2 0 5d0 bbb
bbc :3 0 8 :3 0
63 :3 0 bbe bbf
0 1d :2 0 bc0
bc1 0 bc3 5d3
bca 8 :3 0 63
:3 0 bc4 bc5 0
b1 :2 0 bc6 bc7
0 bc9 5d5 bcb
bbd bc3 0 bcc
0 bc9 0 bcc
5d7 0 bcd 5da
c17 65 :3 0 8
:3 0 63 :3 0 bd0
bd1 0 64 :3 0
bd2 bd3 0 c0d
4a :3 0 4b :3 0
bd5 bd6 0 4a
:3 0 5b :3 0 bd8
bd9 0 66 :2 0
2 :4 0 147 :2 0
5e :2 0 5c :2 0
5dd bde be0 :3 0
5e0 bda be2 bd7
be4 be3 :2 0 4d
:3 0 5f :3 0 be6
be7 0 4f :4 0
148 :4 0 52 :2 0
53 :3 0 5e4 beb
bed :3 0 52 :2 0
69 :4 0 5e7 bef
bf1 :3 0 52 :2 0
6a :4 0 5ea bf3
bf5 :3 0 52 :2 0
64 :3 0 5ed bf7
bf9 :3 0 52 :2 0
6b :4 0 5f0 bfb
bfd :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
5f3 c00 c04 5f7
bff c06 :3 0 5fa
be8 c08 :2 0 c0a
5fd c0b be5 c0a
0 c0c 5ff 0
c0d 601 c10 :3 0
c10 0 c10 c0f
c0d c0e :6 0 c12
2c :3 0 604 c14
606 c13 c12 :2 0
c15 608 :2 0 c17
0 c17 c16 bcd
c15 :6 0 c19 29
:3 0 60a c86 45
:3 0 33 :3 0 18
:3 0 39 :3 0 10
:3 0 33 :3 0 16
:3 0 42 :3 0 12
:4 0 149 1 :8 0
c39 b0 :4 0 c24
:3 0 7e :3 0 6f
:2 0 60e c27 c28
:3 0 8 :3 0 63
:3 0 c2a c2b 0
1d :2 0 c2c c2d
0 c2f 611 c36
8 :3 0 63 :3 0
c30 c31 0 b1
:2 0 c32 c33 0
c35 613 c37 c29
c2f 0 c38 0
c35 0 c38 615
0 c39 618 c83
65 :3 0 8 :3 0
63 :3 0 c3c c3d
0 64 :3 0 c3e
c3f 0 c79 4a
:3 0 4b :3 0 c41
c42 0 4a :3 0
5b :3 0 c44 c45
0 66 :2 0 2
:4 0 14a :2 0 5e
:2 0 5c :2 0 61b
c4a c4c :3 0 61e
c46 c4e c43 c50
c4f :2 0 4d :3 0
5f :3 0 c52 c53
0 4f :4 0 14b
:4 0 52 :2 0 53
:3 0 622 c57 c59
:3 0 52 :2 0 69
:4 0 625 c5b c5d
:3 0 52 :2 0 6a
:4 0 628 c5f c61
:3 0 52 :2 0 64
:3 0 62b c63 c65
:3 0 52 :2 0 6b
:4 0 62e c67 c69
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 631
c6c c70 635 c6b
c72 :3 0 638 c54
c74 :2 0 c76 63b
c77 c51 c76 0
c78 63d 0 c79
63f c7c :3 0 c7c
0 c7c c7b c79
c7a :6 0 c7e 2e
:3 0 642 c80 644
c7f c7e :2 0 c81
646 :2 0 c83 0
c83 c82 c39 c81
:6 0 c85 29 :3 0
648 c87 baf c19
0 c88 0 c85
0 c88 64a 0
c8a 7f :3 0 64d
d01 57 :3 0 1f
:3 0 1d :2 0 650
c8b c8e 6f :2 0
d7 :2 0 655 c90
c92 :3 0 45 :3 0
33 :3 0 18 :3 0
39 :3 0 10 :3 0
33 :3 0 16 :3 0
42 :3 0 12 :4 0
149 1 :8 0 cb3
b0 :4 0 c9e :3 0
7e :3 0 6f :2 0
65a ca1 ca2 :3 0
8 :3 0 63 :3 0
ca4 ca5 0 1d
:2 0 ca6 ca7 0
ca9 65d cb0 8
:3 0 63 :3 0 caa
cab 0 b1 :2 0
cac cad 0 caf
65f cb1 ca3 ca9
0 cb2 0 caf
0 cb2 661 0
cb3 664 cfd 65
:3 0 8 :3 0 63
:3 0 cb6 cb7 0
64 :3 0 cb8 cb9
0 cf3 4a :3 0
4b :3 0 cbb cbc
0 4a :3 0 5b
:3 0 cbe cbf 0
66 :2 0 2 :4 0
14c :2 0 5e :2 0
5c :2 0 667 cc4
cc6 :3 0 66a cc0
cc8 cbd cca cc9
:2 0 4d :3 0 5f
:3 0 ccc ccd 0
4f :4 0 14d :4 0
52 :2 0 53 :3 0
66e cd1 cd3 :3 0
52 :2 0 69 :4 0
671 cd5 cd7 :3 0
52 :2 0 6a :4 0
674 cd9 cdb :3 0
52 :2 0 64 :3 0
677 cdd cdf :3 0
52 :2 0 6b :4 0
67a ce1 ce3 :3 0
52 :2 0 6c :3 0
6d :3 0 5c :2 0
6e :2 0 67d ce6
cea 681 ce5 cec
:3 0 684 cce cee
:2 0 cf0 687 cf1
ccb cf0 0 cf2
689 0 cf3 68b
cf6 :3 0 cf6 0
cf6 cf5 cf3 cf4
:6 0 cf8 30 :3 0
68e cfa 690 cf9
cf8 :2 0 cfb 692
:2 0 cfd 0 cfd
cfc cb3 cfb :6 0
cff 29 :3 0 694
d00 c93 cff 0
d02 b34 c8a 0
d02 696 0 d03
699 d05 b5 :4 0
d03 :4 0 11fa cf
:3 0 41 :4 0 d09
:2 0 d0f d07 0
8 :3 0 63 :3 0
d0a d0b 0 64
:3 0 d0c d0d 0
d0f 69e d59 65
:3 0 8 :3 0 63
:3 0 d12 d13 0
64 :3 0 d14 d15
0 d4f 4a :3 0
4b :3 0 d17 d18
0 4a :3 0 5b
:3 0 d1a d1b 0
66 :2 0 2 :4 0
14e :2 0 5e :2 0
5c :2 0 6a1 d20
d22 :3 0 6a4 d1c
d24 d19 d26 d25
:2 0 4d :3 0 5f
:3 0 d28 d29 0
4f :4 0 14f :4 0
52 :2 0 53 :3 0
6a8 d2d d2f :3 0
52 :2 0 69 :4 0
6ab d31 d33 :3 0
52 :2 0 6a :4 0
6ae d35 d37 :3 0
52 :2 0 64 :3 0
6b1 d39 d3b :3 0
52 :2 0 6b :4 0
6b4 d3d d3f :3 0
52 :2 0 6c :3 0
6d :3 0 5c :2 0
6e :2 0 6b7 d42
d46 6bb d41 d48
:3 0 6be d2a d4a
:2 0 d4c 6c1 d4d
d27 d4c 0 d4e
6c3 0 d4f 6c5
d52 :3 0 d52 0
d52 d51 d4f d50
:6 0 d54 32 :3 0
6c8 d56 6ca d55
d54 :2 0 d57 6cc
:2 0 d59 0 d59
d58 d0f d57 :6 0
11fa 16 :3 0 45
:3 0 3c :3 0 150
:3 0 18 :3 0 39
:3 0 10 :3 0 150
:3 0 16 :4 0 151
1 :8 0 d79 b0
:4 0 d64 :3 0 7e
:3 0 6f :2 0 6d0
d67 d68 :3 0 8
:3 0 63 :3 0 d6a
d6b 0 1d :2 0
d6c d6d 0 d6f
6d3 d76 8 :3 0
63 :3 0 d70 d71
0 b1 :2 0 d72
d73 0 d75 6d5
d77 d69 d6f 0
d78 0 d75 0
d78 6d7 0 d79
6da dc3 65 :3 0
8 :3 0 63 :3 0
d7c d7d 0 64
:3 0 d7e d7f 0
db9 4a :3 0 4b
:3 0 d81 d82 0
4a :3 0 5b :3 0
d84 d85 0 66
:2 0 2 :4 0 152
:2 0 5e :2 0 5c
:2 0 6dd d8a d8c
:3 0 6e0 d86 d8e
d83 d90 d8f :2 0
4d :3 0 5f :3 0
d92 d93 0 4f
:4 0 153 :4 0 52
:2 0 53 :3 0 6e4
d97 d99 :3 0 52
:2 0 69 :4 0 6e7
d9b d9d :3 0 52
:2 0 6a :4 0 6ea
d9f da1 :3 0 52
:2 0 64 :3 0 6ed
da3 da5 :3 0 52
:2 0 6b :4 0 6f0
da7 da9 :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 6f3 dac db0
6f7 dab db2 :3 0
6fa d94 db4 :2 0
db6 6fd db7 d91
db6 0 db8 6ff
0 db9 701 dbc
:3 0 dbc 0 dbc
dbb db9 dba :6 0
dbe 34 :3 0 704
dc0 706 dbf dbe
:2 0 dc1 708 :2 0
dc3 0 dc3 dc2
d79 dc1 :6 0 11fa
16 :3 0 57 :3 0
26 :3 0 1d :2 0
70a dc5 dc8 6f
:2 0 1d :2 0 70f
dca dcc :3 0 35
:3 0 3c :3 0 154
:3 0 d :3 0 155
:3 0 156 :3 0 d
:3 0 157 :3 0 91
:3 0 92 :3 0 93
:3 0 94 :3 0 95
:3 0 96 :3 0 b9
:3 0 ba :3 0 bb
:3 0 92 :3 0 bc
:3 0 94 :3 0 bd
:3 0 ba :3 0 be
:3 0 bf :3 0 bf
:3 0 be :3 0 c0
:3 0 c1 :3 0 c1
:3 0 c0 :3 0 9c
:3 0 ba :3 0 c2
:3 0 9c :3 0 ba
:3 0 c4 :3 0 c5
:3 0 c6 :3 0 c3
:3 0 9c :3 0 ba
:3 0 c7 :3 0 c8
:3 0 92 :3 0 94
:3 0 96 :3 0 ba
:3 0 99 :3 0 9a
:3 0 9d :3 0 3e
:3 0 33 :3 0 16
:3 0 b9 :3 0 ba
:4 0 158 1 :8 0
e1b b0 :4 0 e06
:3 0 7e :3 0 6f
:2 0 714 e09 e0a
:3 0 8 :3 0 63
:3 0 e0c e0d 0
1d :2 0 e0e e0f
0 e11 717 e18
8 :3 0 63 :3 0
e12 e13 0 b1
:2 0 e14 e15 0
e17 719 e19 e0b
e11 0 e1a 0
e17 0 e1a 71b
0 e1b 71e e65
65 :3 0 8 :3 0
63 :3 0 e1e e1f
0 64 :3 0 e20
e21 0 e5b 4a
:3 0 4b :3 0 e23
e24 0 4a :3 0
5b :3 0 e26 e27
0 66 :2 0 2
:4 0 159 :2 0 5e
:2 0 5c :2 0 721
e2c e2e :3 0 724
e28 e30 e25 e32
e31 :2 0 4d :3 0
5f :3 0 e34 e35
0 4f :4 0 15a
:4 0 52 :2 0 53
:3 0 728 e39 e3b
:3 0 52 :2 0 69
:4 0 72b e3d e3f
:3 0 52 :2 0 6a
:4 0 72e e41 e43
:3 0 52 :2 0 64
:3 0 731 e45 e47
:3 0 52 :2 0 6b
:4 0 734 e49 e4b
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 737
e4e e52 73b e4d
e54 :3 0 73e e36
e56 :2 0 e58 741
e59 e33 e58 0
e5a 743 0 e5b
745 e5e :3 0 e5e
0 e5e e5d e5b
e5c :6 0 e60 36
:3 0 748 e62 74a
e61 e60 :2 0 e63
74c :2 0 e65 0
e65 e64 e1b e63
:6 0 e80 16 :3 0
57 :3 0 1f :3 0
1d :2 0 74e e67
e6a 6f :2 0 d7
:2 0 753 e6c e6e
:3 0 28 :3 0 8d
:2 0 e70 e71 0
e7d 29 :3 0 15b
:3 0 10 :3 0 18
:3 0 28 :3 0 1d
:2 0 1d :2 0 756
e74 e7a e73 e7b
0 e7d 75c e7e
e6f e7d 0 e7f
75f 0 e80 761
11f3 b4 :3 0 47
:4 0 e84 :2 0 11f2
e82 e85 :3 0 b5
:3 0 47 :3 0 15
:3 0 17 :4 0 e8b
:2 0 fae e87 e8c
:3 0 764 :3 0 47
:3 0 b0 :3 0 e8d
e8e :3 0 8 :3 0
63 :3 0 e90 e91
0 1d :2 0 e92
e93 0 e95 767
e9c 8 :3 0 63
:3 0 e96 e97 0
b1 :2 0 e98 e99
0 e9b 769 e9d
e8f e95 0 e9e
0 e9b 0 e9e
76b 0 fae 8
:3 0 63 :3 0 e9f
ea0 0 8 :3 0
b6 :2 0 b7 :3 0
ea2 ea4 0 770
ea3 ea6 :3 0 ea7
:2 0 b8 :8 0 eab
773 eac ea8 eab
0 ead 775 0
fae 35 :3 0 3c
:3 0 154 :3 0 d
:3 0 155 :3 0 156
:3 0 d :3 0 157
:3 0 91 :3 0 92
:3 0 93 :3 0 94
:3 0 95 :3 0 96
:3 0 b9 :3 0 ba
:3 0 bb :3 0 92
:3 0 bc :3 0 94
:3 0 bd :3 0 ba
:3 0 be :3 0 bf
:3 0 bf :3 0 be
:3 0 c0 :3 0 c1
:3 0 c1 :3 0 c0
:3 0 9c :3 0 ba
:3 0 c2 :3 0 9c
:3 0 ba :3 0 c4
:3 0 c5 :3 0 c6
:3 0 c3 :3 0 9c
:3 0 ba :3 0 c7
:3 0 c8 :3 0 92
:3 0 94 :3 0 96
:3 0 ba :3 0 99
:3 0 9a :3 0 9d
:3 0 3e :3 0 18
:3 0 33 :3 0 17
:4 0 15c 1 :8 0
efa b0 :4 0 ee5
:3 0 7e :3 0 6f
:2 0 779 ee8 ee9
:3 0 8 :3 0 63
:3 0 eeb eec 0
1d :2 0 eed eee
0 ef0 77c ef7
8 :3 0 63 :3 0
ef1 ef2 0 b1
:2 0 ef3 ef4 0
ef6 77e ef8 eea
ef0 0 ef9 0
ef6 0 ef9 780
0 efa 783 f44
65 :3 0 8 :3 0
63 :3 0 efd efe
0 64 :3 0 eff
f00 0 f3a 4a
:3 0 4b :3 0 f02
f03 0 4a :3 0
5b :3 0 f05 f06
0 66 :2 0 2
:4 0 15d :2 0 5e
:2 0 5c :2 0 786
f0b f0d :3 0 789
f07 f0f f04 f11
f10 :2 0 4d :3 0
5f :3 0 f13 f14
0 4f :4 0 15e
:4 0 52 :2 0 53
:3 0 78d f18 f1a
:3 0 52 :2 0 69
:4 0 790 f1c f1e
:3 0 52 :2 0 6a
:4 0 793 f20 f22
:3 0 52 :2 0 64
:3 0 796 f24 f26
:3 0 52 :2 0 6b
:4 0 799 f28 f2a
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 79c
f2d f31 7a0 f2c
f33 :3 0 7a3 f15
f35 :2 0 f37 7a6
f38 f12 f37 0
f39 7a8 0 f3a
7aa f3d :3 0 f3d
0 f3d f3c f3a
f3b :6 0 f3f 39
:3 0 7ad f41 7af
f40 f3f :2 0 f42
7b1 :2 0 f44 0
f44 f43 efa f42
:6 0 fae 38 :3 0
37 :3 0 d2 :3 0
d :3 0 d3 :3 0
3a :3 0 15 :4 0
15f 1 :8 0 f62
b0 :4 0 f4d :3 0
7e :3 0 6f :2 0
7b5 f50 f51 :3 0
8 :3 0 63 :3 0
f53 f54 0 1d
:2 0 f55 f56 0
f58 7b8 f5f 8
:3 0 63 :3 0 f59
f5a 0 b1 :2 0
f5b f5c 0 f5e
7ba f60 f52 f58
0 f61 0 f5e
0 f61 7bc 0
f62 7bf fac 65
:3 0 8 :3 0 63
:3 0 f65 f66 0
64 :3 0 f67 f68
0 fa2 4a :3 0
4b :3 0 f6a f6b
0 4a :3 0 5b
:3 0 f6d f6e 0
66 :2 0 2 :4 0
160 :2 0 5e :2 0
5c :2 0 7c2 f73
f75 :3 0 7c5 f6f
f77 f6c f79 f78
:2 0 4d :3 0 5f
:3 0 f7b f7c 0
4f :4 0 161 :4 0
52 :2 0 53 :3 0
7c9 f80 f82 :3 0
52 :2 0 69 :4 0
7cc f84 f86 :3 0
52 :2 0 6a :4 0
7cf f88 f8a :3 0
52 :2 0 64 :3 0
7d2 f8c f8e :3 0
52 :2 0 6b :4 0
7d5 f90 f92 :3 0
52 :2 0 6c :3 0
6d :3 0 5c :2 0
6e :2 0 7d8 f95
f99 7dc f94 f9b
:3 0 7df f7d f9d
:2 0 f9f 7e2 fa0
f7a f9f 0 fa1
7e4 0 fa2 7e6
fa5 :3 0 fa5 0
fa5 fa4 fa2 fa3
:6 0 fa7 3b :3 0
7e9 fa9 7eb fa8
fa7 :2 0 faa 7ed
:2 0 fac 0 fac
fab f62 faa :6 0
fae 38 :3 0 7ef
fb0 b5 :4 0 fae
:4 0 11f2 cf :3 0
47 :4 0 fb4 :2 0
fba fb2 0 8
:3 0 63 :3 0 fb5
fb6 0 64 :3 0
fb7 fb8 0 fba
7f5 1004 65 :3 0
8 :3 0 63 :3 0
fbd fbe 0 64
:3 0 fbf fc0 0
ffa 4a :3 0 4b
:3 0 fc2 fc3 0
4a :3 0 5b :3 0
fc5 fc6 0 66
:2 0 2 :4 0 162
:2 0 5e :2 0 5c
:2 0 7f8 fcb fcd
:3 0 7fb fc7 fcf
fc4 fd1 fd0 :2 0
4d :3 0 5f :3 0
fd3 fd4 0 4f
:4 0 163 :4 0 52
:2 0 53 :3 0 7ff
fd8 fda :3 0 52
:2 0 69 :4 0 802
fdc fde :3 0 52
:2 0 6a :4 0 805
fe0 fe2 :3 0 52
:2 0 64 :3 0 808
fe4 fe6 :3 0 52
:2 0 6b :4 0 80b
fe8 fea :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 80e fed ff1
812 fec ff3 :3 0
815 fd5 ff5 :2 0
ff7 818 ff8 fd2
ff7 0 ff9 81a
0 ffa 81c ffd
:3 0 ffd 0 ffd
ffc ffa ffb :6 0
fff 3d :3 0 81f
1001 821 1000 fff
:2 0 1002 823 :2 0
1004 0 1004 1003
fba 1002 :6 0 11f2
16 :3 0 57 :3 0
26 :3 0 1d :2 0
825 1006 1009 6f
:2 0 5c :2 0 82a
100b 100d :3 0 100e
:2 0 57 :3 0 27
:3 0 1d :2 0 82d
1010 1013 164 :2 0
1d :2 0 832 1015
1017 :3 0 1018 :2 0
100f 101a 1019 :2 0
35 :3 0 12d :3 0
27 :3 0 33 :3 0
18 :4 0 165 1
:8 0 1037 b0 :4 0
1022 :3 0 7e :3 0
6f :2 0 837 1025
1026 :3 0 8 :3 0
63 :3 0 1028 1029
0 1d :2 0 102a
102b 0 102d 83a
1034 8 :3 0 63
:3 0 102e 102f 0
b1 :2 0 1030 1031
0 1033 83c 1035
1027 102d 0 1036
0 1033 0 1036
83e 0 1037 841
1081 65 :3 0 8
:3 0 63 :3 0 103a
103b 0 64 :3 0
103c 103d 0 1077
4a :3 0 4b :3 0
103f 1040 0 4a
:3 0 5b :3 0 1042
1043 0 66 :2 0
2 :4 0 166 :2 0
5e :2 0 5c :2 0
844 1048 104a :3 0
847 1044 104c 1041
104e 104d :2 0 4d
:3 0 5f :3 0 1050
1051 0 4f :4 0
167 :4 0 52 :2 0
53 :3 0 84b 1055
1057 :3 0 52 :2 0
69 :4 0 84e 1059
105b :3 0 52 :2 0
6a :4 0 851 105d
105f :3 0 52 :2 0
64 :3 0 854 1061
1063 :3 0 52 :2 0
6b :4 0 857 1065
1067 :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
85a 106a 106e 85e
1069 1070 :3 0 861
1052 1072 :2 0 1074
864 1075 104f 1074
0 1076 866 0
1077 868 107a :3 0
107a 0 107a 1079
1077 1078 :6 0 107c
3f :3 0 86b 107e
86d 107d 107c :2 0
107f 86f :2 0 1081
0 1081 1080 1037
107f :6 0 1083 16
:3 0 871 1084 101b
1083 0 1085 873
0 11f2 28 :3 0
8d :2 0 1086 1087
0 11f2 29 :3 0
15b :3 0 10 :3 0
18 :3 0 28 :3 0
1d :2 0 1d :2 0
875 108a 1090 1089
1091 0 11f2 3e
:3 0 168 :3 0 91
:3 0 93 :3 0 c3
:3 0 c4 :3 0 c7
:3 0 18 :3 0 1c
:3 0 19 :3 0 1b
:3 0 1e :3 0 2a
:3 0 2d :3 0 35
:3 0 33 :3 0 18
:4 0 169 1 :8 0
10aa 8 :3 0 63
:3 0 10a5 10a6 0
64 :3 0 10a7 10a8
0 10aa 87b 10f4
65 :3 0 8 :3 0
63 :3 0 10ad 10ae
0 64 :3 0 10af
10b0 0 10ea 4a
:3 0 4b :3 0 10b2
10b3 0 4a :3 0
5b :3 0 10b5 10b6
0 66 :2 0 2
:4 0 16a :2 0 5e
:2 0 5c :2 0 87e
10bb 10bd :3 0 881
10b7 10bf 10b4 10c1
10c0 :2 0 4d :3 0
5f :3 0 10c3 10c4
0 4f :4 0 16b
:4 0 52 :2 0 53
:3 0 885 10c8 10ca
:3 0 52 :2 0 69
:4 0 888 10cc 10ce
:3 0 52 :2 0 6a
:4 0 88b 10d0 10d2
:3 0 52 :2 0 64
:3 0 88e 10d4 10d6
:3 0 52 :2 0 6b
:4 0 891 10d8 10da
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 894
10dd 10e1 898 10dc
10e3 :3 0 89b 10c5
10e5 :2 0 10e7 89e
10e8 10c2 10e7 0
10e9 8a0 0 10ea
8a2 10ed :3 0 10ed
0 10ed 10ec 10ea
10eb :6 0 10ef 41
:3 0 8a5 10f1 8a7
10f0 10ef :2 0 10f2
8a9 :2 0 10f4 0
10f4 10f3 10aa 10f2
:6 0 11f2 16 :3 0
57 :3 0 1e :3 0
1d :2 0 8ab 10f6
10f9 6f :2 0 1d
:2 0 8b0 10fb 10fd
:3 0 105 :3 0 10a
:3 0 10f :3 0 114
:3 0 119 :3 0 11e
:3 0 109 :3 0 19
:3 0 10e :3 0 1b
:3 0 113 :3 0 1c
:3 0 118 :3 0 1c
:3 0 2a :3 0 11d
:3 0 39 :3 0 10
:3 0 34 :3 0 14
:4 0 16c 1 :8 0
1129 b0 :4 0 1114
:3 0 7e :3 0 6f
:2 0 8b5 1117 1118
:3 0 8 :3 0 63
:3 0 111a 111b 0
1d :2 0 111c 111d
0 111f 8b8 1126
8 :3 0 63 :3 0
1120 1121 0 b1
:2 0 1122 1123 0
1125 8ba 1127 1119
111f 0 1128 0
1125 0 1128 8bc
0 1129 8bf 1173
65 :3 0 8 :3 0
63 :3 0 112c 112d
0 64 :3 0 112e
112f 0 1169 4a
:3 0 4b :3 0 1131
1132 0 4a :3 0
5b :3 0 1134 1135
0 66 :2 0 2
:4 0 16d :2 0 5e
:2 0 5c :2 0 8c2
113a 113c :3 0 8c5
1136 113e 1133 1140
113f :2 0 4d :3 0
5f :3 0 1142 1143
0 4f :4 0 16e
:4 0 52 :2 0 53
:3 0 8c9 1147 1149
:3 0 52 :2 0 69
:4 0 8cc 114b 114d
:3 0 52 :2 0 6a
:4 0 8cf 114f 1151
:3 0 52 :2 0 64
:3 0 8d2 1153 1155
:3 0 52 :2 0 6b
:4 0 8d5 1157 1159
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 8d8
115c 1160 8dc 115b
1162 :3 0 8df 1144
1164 :2 0 1166 8e2
1167 1141 1166 0
1168 8e4 0 1169
8e6 116c :3 0 116c
0 116c 116b 1169
116a :6 0 116e 43
:3 0 8e9 1170 8eb
116f 116e :2 0 1171
8ed :2 0 1173 0
1173 1172 1129 1171
:6 0 1175 16 :3 0
8ef 11ef 105 :3 0
10a :3 0 10f :3 0
114 :3 0 119 :3 0
11e :3 0 109 :3 0
19 :3 0 10e :3 0
1b :3 0 113 :3 0
1c :3 0 118 :3 0
1c :3 0 2a :3 0
11d :3 0 1c :3 0
2d :3 0 39 :3 0
10 :3 0 34 :3 0
14 :4 0 16f 1
:8 0 11a2 b0 :4 0
118d :3 0 7e :3 0
6f :2 0 8f3 1190
1191 :3 0 8 :3 0
63 :3 0 1193 1194
0 1d :2 0 1195
1196 0 1198 8f6
119f 8 :3 0 63
:3 0 1199 119a 0
b1 :2 0 119b 119c
0 119e 8f8 11a0
1192 1198 0 11a1
0 119e 0 11a1
8fa 0 11a2 8fd
11ec 65 :3 0 8
:3 0 63 :3 0 11a5
11a6 0 64 :3 0
11a7 11a8 0 11e2
4a :3 0 4b :3 0
11aa 11ab 0 4a
:3 0 5b :3 0 11ad
11ae 0 66 :2 0
2 :4 0 170 :2 0
5e :2 0 5c :2 0
900 11b3 11b5 :3 0
903 11af 11b7 11ac
11b9 11b8 :2 0 4d
:3 0 5f :3 0 11bb
11bc 0 4f :4 0
171 :4 0 52 :2 0
53 :3 0 907 11c0
11c2 :3 0 52 :2 0
69 :4 0 90a 11c4
11c6 :3 0 52 :2 0
6a :4 0 90d 11c8
11ca :3 0 52 :2 0
64 :3 0 910 11cc
11ce :3 0 52 :2 0
6b :4 0 913 11d0
11d2 :3 0 52 :2 0
6c :3 0 6d :3 0
5c :2 0 6e :2 0
916 11d5 11d9 91a
11d4 11db :3 0 91d
11bd 11dd :2 0 11df
920 11e0 11ba 11df
0 11e1 922 0
11e2 924 11e5 :3 0
11e5 0 11e5 11e4
11e2 11e3 :6 0 11e7
45 :3 0 927 11e9
929 11e8 11e7 :2 0
11ea 92b :2 0 11ec
0 11ec 11eb 11a2
11ea :6 0 11ee 16
:3 0 92d 11f0 10fe
1175 0 11f1 0
11ee 0 11f1 92f
0 11f2 932 11f4
dcd e80 0 11f5
0 11f2 0 11f5
93b 0 11fa 12c
:5 0 11f8 47 0
11f9 93e 11f8 11f7
11fa 940 11fc 94c
11fb 11fa :2 0 1200
0 11fe 94e 11ff
0 11fe :2 0 1200
950 :2 0 1201 683
1200 0 126a 0
37 :3 0 d2 :3 0
d :3 0 d3 :3 0
3a :3 0 15 :4 0
15f 1 :8 0 121e
b0 :4 0 1209 :3 0
7e :3 0 6f :2 0
956 120c 120d :3 0
8 :3 0 63 :3 0
120f 1210 0 1d
:2 0 1211 1212 0
1214 959 121b 8
:3 0 63 :3 0 1215
1216 0 b1 :2 0
1217 1218 0 121a
95b 121c 120e 1214
0 121d 0 121a
0 121d 95d 0
121e 960 1268 65
:3 0 8 :3 0 63
:3 0 1221 1222 0
64 :3 0 1223 1224
0 125e 4a :3 0
4b :3 0 1226 1227
0 4a :3 0 5b
:3 0 1229 122a 0
66 :2 0 2 :4 0
172 :2 0 5e :2 0
5c :2 0 963 122f
1231 :3 0 966 122b
1233 1228 1235 1234
:2 0 4d :3 0 5f
:3 0 1237 1238 0
4f :4 0 173 :4 0
52 :2 0 53 :3 0
96a 123c 123e :3 0
52 :2 0 69 :4 0
96d 1240 1242 :3 0
52 :2 0 6a :4 0
970 1244 1246 :3 0
52 :2 0 64 :3 0
973 1248 124a :3 0
52 :2 0 6b :4 0
976 124c 124e :3 0
52 :2 0 6c :3 0
6d :3 0 5c :2 0
6e :2 0 979 1251
1255 97d 1250 1257
:3 0 980 1239 1259
:2 0 125b 983 125c
1236 125b 0 125d
985 0 125e 987
1261 :3 0 1261 0
1261 1260 125e 125f
:6 0 1263 47 :3 0
98a 1265 98c 1264
1263 :2 0 1266 98e
:2 0 1268 0 1268
1267 121e 1266 :6 0
126a 16 :3 0 990
126c b5 :4 0 126a
:4 0 1409 cf :3 0
40 :4 0 1270 :2 0
1276 126e 0 8
:3 0 63 :3 0 1271
1272 0 64 :3 0
1273 1274 0 1276
996 12c0 65 :3 0
8 :3 0 63 :3 0
1279 127a 0 64
:3 0 127b 127c 0
12b6 4a :3 0 4b
:3 0 127e 127f 0
4a :3 0 5b :3 0
1281 1282 0 66
:2 0 2 :4 0 174
:2 0 5e :2 0 5c
:2 0 999 1287 1289
:3 0 99c 1283 128b
1280 128d 128c :2 0
4d :3 0 5f :3 0
128f 1290 0 4f
:4 0 175 :4 0 52
:2 0 53 :3 0 9a0
1294 1296 :3 0 52
:2 0 69 :4 0 9a3
1298 129a :3 0 52
:2 0 6a :4 0 9a6
129c 129e :3 0 52
:2 0 64 :3 0 9a9
12a0 12a2 :3 0 52
:2 0 6b :4 0 9ac
12a4 12a6 :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 9af 12a9 12ad
9b3 12a8 12af :3 0
9b6 1291 12b1 :2 0
12b3 9b9 12b4 128e
12b3 0 12b5 9bb
0 12b6 9bd 12b9
:3 0 12b9 0 12b9
12b8 12b6 12b7 :6 0
12bb 49 :3 0 9c0
12bd 9c2 12bc 12bb
:2 0 12be 9c4 :2 0
12c0 0 12c0 12bf
1276 12be :6 0 1409
1 :3 0 29 :3 0
176 :3 0 10 :3 0
9c6 12c3 12c5 12c2
12c6 0 1409 154
:3 0 d :3 0 177
:3 0 156 :3 0 d
:3 0 178 :3 0 8e
:3 0 d :3 0 8f
:3 0 23 :3 0 37
:3 0 3a :3 0 10
:4 0 179 1 :8 0
12db 8 :3 0 63
:3 0 12d6 12d7 0
64 :3 0 12d8 12d9
0 12db 9c8 1325
65 :3 0 8 :3 0
63 :3 0 12de 12df
0 64 :3 0 12e0
12e1 0 131b 4a
:3 0 4b :3 0 12e3
12e4 0 4a :3 0
5b :3 0 12e6 12e7
0 66 :2 0 2
:4 0 17a :2 0 5e
:2 0 5c :2 0 9cb
12ec 12ee :3 0 9ce
12e8 12f0 12e5 12f2
12f1 :2 0 4d :3 0
5f :3 0 12f4 12f5
0 4f :4 0 17b
:4 0 52 :2 0 53
:3 0 9d2 12f9 12fb
:3 0 52 :2 0 69
:4 0 9d5 12fd 12ff
:3 0 52 :2 0 6a
:4 0 9d8 1301 1303
:3 0 52 :2 0 64
:3 0 9db 1305 1307
:3 0 52 :2 0 6b
:4 0 9de 1309 130b
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 9e1
130e 1312 9e5 130d
1314 :3 0 9e8 12f6
1316 :2 0 1318 9eb
1319 12f3 1318 0
131a 9ed 0 131b
9ef 131e :3 0 131e
0 131e 131d 131b
131c :6 0 1320 4b
:3 0 9f2 1322 9f4
1321 1320 :2 0 1323
9f6 :2 0 1325 0
1325 1324 12db 1323
:6 0 1409 1 :3 0
57 :3 0 23 :3 0
1d :2 0 9f8 1327
132a 6f :2 0 5c
:2 0 9fd 132c 132e
:3 0 24 :3 0 d
:3 0 8f :3 0 1331
1332 0 1330 1333
0 133f 8 :3 0
63 :3 0 1335 1336
0 17c :3 0 10
:3 0 23 :3 0 24
:3 0 a00 1338 133c
1337 133d 0 133f
a04 1340 132f 133f
0 1341 a07 0
1409 17d :3 0 17e
:3 0 8e :3 0 37
:3 0 3a :3 0 10
:3 0 3a :3 0 10
:4 0 17f 1 :8 0
1360 b0 :4 0 134b
:3 0 7e :3 0 6f
:2 0 a0b 134e 134f
:3 0 8 :3 0 63
:3 0 1351 1352 0
1d :2 0 1353 1354
0 1356 a0e 135d
8 :3 0 63 :3 0
1357 1358 0 b1
:2 0 1359 135a 0
135c a10 135e 1350
1356 0 135f 0
135c 0 135f a12
0 1360 a15 13aa
65 :3 0 8 :3 0
63 :3 0 1363 1364
0 64 :3 0 1365
1366 0 13a0 4a
:3 0 4b :3 0 1368
1369 0 4a :3 0
5b :3 0 136b 136c
0 66 :2 0 2
:4 0 180 :2 0 5e
:2 0 5c :2 0 a18
1371 1373 :3 0 a1b
136d 1375 136a 1377
1376 :2 0 4d :3 0
5f :3 0 1379 137a
0 4f :4 0 181
:4 0 52 :2 0 53
:3 0 a1f 137e 1380
:3 0 52 :2 0 69
:4 0 a22 1382 1384
:3 0 52 :2 0 6a
:4 0 a25 1386 1388
:3 0 52 :2 0 64
:3 0 a28 138a 138c
:3 0 52 :2 0 6b
:4 0 a2b 138e 1390
:3 0 52 :2 0 6c
:3 0 6d :3 0 5c
:2 0 6e :2 0 a2e
1393 1397 a32 1392
1399 :3 0 a35 137b
139b :2 0 139d a38
139e 1378 139d 0
139f a3a 0 13a0
a3c 13a3 :3 0 13a3
0 13a3 13a2 13a0
13a1 :6 0 13a5 4d
:3 0 a3f 13a7 a41
13a6 13a5 :2 0 13a8
a43 :2 0 13aa 0
13aa 13a9 1360 13a8
:6 0 1409 1 :3 0
8 :3 0 63 :3 0
13ac 13ad 0 6f
:2 0 b1 :2 0 a47
13af 13b1 :3 0 8
:3 0 63 :3 0 13b3
13b4 0 1d :2 0
13b5 13b6 0 13b8
a4a 13b9 13b2 13b8
0 13ba a4c 0
1409 4a :3 0 4b
:3 0 13bb 13bc 0
4a :3 0 5b :3 0
13be 13bf 0 182
:2 0 2 :4 0 183
:2 0 5e :2 0 5c
:2 0 a4e 13c4 13c6
:3 0 a51 13c0 13c8
13bd 13ca 13c9 :2 0
4d :3 0 5f :3 0
13cc 13cd 0 4f
:4 0 184 :4 0 52
:2 0 53 :3 0 a55
13d1 13d3 :3 0 52
:2 0 69 :4 0 a58
13d5 13d7 :3 0 52
:2 0 78 :4 0 a5b
13d9 13db :3 0 52
:2 0 57 :3 0 58
:3 0 8 :3 0 63
:3 0 13e0 13e1 0
a5e 13df 13e3 59
:4 0 a60 13de 13e6
a63 13dd 13e8 :3 0
52 :2 0 83 :4 0
a66 13ea 13ec :3 0
52 :2 0 55 :4 0
a69 13ee 13f0 :3 0
52 :2 0 3 :3 0
a6c 13f2 13f4 :3 0
52 :2 0 55 :4 0
a6f 13f6 13f8 :3 0
a72 13ce 13fa :2 0
13fc a75 13fd 13cb
13fc 0 13fe a77
0 1409 7c :3 0
185 :3 0 13ff 1400
0 8 :3 0 63
:3 0 1402 1403 0
3 :3 0 7e :3 0
a79 1401 1407 :2 0
1409 a7d 14aa 8
:3 0 186 :2 0 4
140a 140b 0 4a
:3 0 4b :3 0 140d
140e 0 4a :3 0
5b :3 0 1410 1411
0 66 :2 0 2
:4 0 187 :2 0 5e
:2 0 5c :2 0 a8e
1416 1418 :3 0 a91
1412 141a 140f 141c
141b :2 0 4d :3 0
5f :3 0 141e 141f
0 4f :4 0 188
:4 0 52 :2 0 53
:3 0 a95 1423 1425
:3 0 a98 1420 1427
:2 0 1440 4d :3 0
5f :3 0 1429 142a
0 4f :4 0 189
:4 0 52 :2 0 8
:3 0 18a :3 0 142f
1430 0 a9b 142e
1432 :3 0 52 :2 0
83 :4 0 a9e 1434
1436 :3 0 52 :2 0
8 :3 0 18b :3 0
1439 143a 0 aa1
1438 143c :3 0 aa4
142b 143e :2 0 1440
aa7 1441 141d 1440
0 1442 aaa 0
1452 b4 :3 0 49
:3 0 8 :3 0 18a
:3 0 18c :3 0 8
:3 0 18b :3 0 3
:3 0 18d :4 0 18e
1 :a 0 144e :2 0
1452 1444 144c :2 0
7 :3 0 49 :3 0
1450 :2 0 1452 aac
1454 ab0 1453 1452
:2 0 14a8 65 :3 0
8 :3 0 63 :3 0
1457 1458 0 64
:3 0 1459 145a 0
14a0 4a :3 0 4b
:3 0 145c 145d 0
4a :3 0 5b :3 0
145f 1460 0 66
:2 0 2 :4 0 18f
:2 0 5e :2 0 5c
:2 0 ab2 1465 1467
:3 0 ab5 1461 1469
145e 146b 146a :2 0
4d :3 0 5f :3 0
146d 146e 0 4f
:4 0 190 :4 0 52
:2 0 53 :3 0 ab9
1472 1474 :3 0 abc
146f 1476 :2 0 1490
4d :3 0 5f :3 0
1478 1479 0 4f
:4 0 6a :4 0 52
:2 0 64 :3 0 abf
147d 147f :3 0 52
:2 0 6b :4 0 ac2
1481 1483 :3 0 52
:2 0 6c :3 0 6d
:3 0 5c :2 0 6e
:2 0 ac5 1486 148a
ac9 1485 148c :3 0
acc 147a 148e :2 0
1490 acf 1491 146c
1490 0 1492 ad2
0 14a0 b4 :3 0
49 :3 0 18c :3 0
8 :3 0 18b :3 0
3 :3 0 18d :4 0
191 1 :a 0 149c
:2 0 14a0 1494 149a
:2 0 7 :3 0 49
:3 0 149e :2 0 14a0
ad4 14a3 :3 0 14a3
0 14a3 14a2 14a0
14a1 :6 0 14a5 1
:3 0 ad9 14a7 adb
14a6 14a5 :2 0 14a8
add :2 0 14aa ae0
14aa 14a9 1409 14a8
:6 0 14ab :2 0 2
10 14aa 14ae :3 0
14ad 14ab 14af :8 0

b01
4
:3 0 1 3 1
7 2 6 a
1 14 1 12
1 1e 1 1c
1 28 1 26
1 2d 1 34
1 32 1 3b
1 39 1 42
1 40 1 49
1 47 1 50
1 4e 1 55
1 5a 1 5f
1 65 1 6b
1 71 1 77
1 7d 1 83
1 89 1 8f
1 95 1 9b
1 a1 1 a7
1 ad 1 b3
1 bb 1 b9
1 df 1 e5
1 fa 1 10b
1 111 1 11e
1 12a 2 12d
12f 2 132 134
2 136 138 2
13a 13c 2 13e
140 1 146 2
148 149 2 142
14b 2 14d 14f
4 126 12c 131
151 1 153 1
155 2 15f 161
3 15d 15e 163
2 16c 16e 2
16b 170 1 172
1 174 2 182
187 2 198 19a
3 196 197 19c
2 1a5 1a7 2
1a9 1ab 2 1ad
1af 2 1b1 1b3
2 1b5 1b7 3
1bc 1bd 1be 2
1b9 1c0 2 1a4
1c2 1 1c4 1
1c6 2 18f 1c7
1 1cb 1 18a
1 1cf 1 1da
2 1d6 1da 2
1ea 1ef 2 200
202 3 1fe 1ff
204 2 20d 20f
2 211 213 2
215 217 2 219
21b 2 21d 21f
3 224 225 226
2 221 228 2
20c 22a 1 22c
1 22e 2 1f7
22f 1 233 1
1f2 1 237 1
242 2 23e 242
2 24e 250 3
24c 24d 252 2
25b 25d 2 25f
261 2 263 265
1 26d 2 26f
270 2 267 272
2 25a 274 1
276 1 278 2
282 284 3 280
281 286 2 28f
291 2 28e 293
1 295 1 297
2 29e 29f 3
279 298 2a1 2
2a5 2a6 1 2aa
2 2a8 2aa 2
2af 2b0 1 2b4
2 2b2 2b4 2
2c2 2c4 3 2c0
2c1 2c6 2 2cf
2d1 2 2d3 2d5
2 2d7 2d9 1
2e1 2 2e3 2e4
2 2db 2e6 2
2e8 2ea 2 2ec
2ee 2 2f0 2f2
2 2f4 2f6 2
2ce 2f8 1 2fa
1 2fc 2 306
308 3 304 305
30a 2 313 315
2 312 317 1
319 1 31b 3
322 323 324 3
2fd 31c 326 2
329 328 2 331
336 2 347 349
3 345 346 34b
2 354 356 2
358 35a 2 35c
35e 2 360 362
2 364 366 3
36b 36c 36d 2
368 36f 2 353
371 1 373 1
375 2 33e 376
1 37a 1 339
1 37e 2 384
386 2 388 38a
2 38c 38e 4
23a 32a 381 391
2 397 398 1
39c 2 39a 39c
1 3e6 2 3e5
3e6 1 3ee 1
3f4 2 3f6 3f7
2 3e3 3f8 2
409 40b 3 407
408 40d 2 416
418 2 41a 41c
2 41e 420 2
422 424 2 426
428 3 42d 42e
42f 2 42a 431
2 415 433 1
435 1 437 2
400 438 1 43c
1 3fb 1 440
2 44c 44d 1
458 1 45e 2
460 461 1 469
2 465 469 1
46e 1 470 1
4ae 2 4ad 4ae
1 4b6 1 4bc
2 4be 4bf 2
4ab 4c0 2 4d1
4d3 3 4cf 4d0
4d5 2 4de 4e0
2 4e2 4e4 2
4e6 4e8 2 4ea
4ec 2 4ee 4f0
3 4f5 4f6 4f7
2 4f2 4f9 2
4dd 4fb 1 4fd
1 4ff 2 4c8
500 1 504 1
4c3 1 508 1
516 2 515 516
1 51e 1 524
2 526 527 2
513 528 2 539
53b 3 537 538
53d 2 546 548
2 54a 54c 2
54e 550 2 552
554 2 556 558
3 55d 55e 55f
2 55a 561 2
545 563 1 565
1 567 2 530
568 1 56c 1
52b 1 570 5
44e 462 471 50b
573 2 57a 580
2 591 593 3
58f 590 595 2
59e 5a0 2 5a2
5a4 2 5a6 5a8
2 5aa 5ac 2
5ae 5b0 3 5b5
5b6 5b7 2 5b2
5b9 2 59d 5bb
1 5bd 1 5bf
2 588 5c0 1
5c4 1 583 1
5c8 4 443 447
577 5cb 1 5ce
1 5dc 2 5db
5dc 1 5e4 1
5ea 2 5ec 5ed
2 5d9 5ee 2
5ff 601 3 5fd
5fe 603 2 60c
60e 2 610 612
2 614 616 2
618 61a 2 61c
61e 3 623 624
625 2 620 627
2 60b 629 1
62b 1 62d 2
5f6 62e 1 632
1 5f1 1 636
2 642 644 2
646 648 2 64a
64c 6 395 5cf
639 63d 640 64f
2 651 652 4
65b 65c 65d 65e
1 669 1 66f
2 671 672 1
67a 2 676 67a
1 67f 1 681
1 6a6 2 6a5
6a6 1 6ae 1
6b4 2 6b6 6b7
2 6a3 6b8 2
6c9 6cb 3 6c7
6c8 6cd 2 6d6
6d8 2 6da 6dc
2 6de 6e0 2
6e2 6e4 2 6e6
6e8 3 6ed 6ee
6ef 2 6ea 6f1
2 6d5 6f3 1
6f5 1 6f7 2
6c0 6f8 1 6fc
1 6bb 1 700
1 76a 2 769
76a 1 772 1
778 2 77a 77b
2 767 77c 2
78d 78f 3 78b
78c 791 2 79a
79c 2 79e 7a0
2 7a2 7a4 2
7a6 7a8 2 7aa
7ac 3 7b1 7b2
7b3 2 7ae 7b5
2 799 7b7 1
7b9 1 7bb 2
784 7bc 1 7c0
1 77f 1 7c4
1 806 2 805
806 1 80e 1
814 2 816 817
2 803 818 2
829 82b 3 827
828 82d 2 836
838 2 83a 83c
2 83e 840 2
842 844 2 846
848 3 84d 84e
84f 2 84a 851
2 835 853 1
855 1 857 2
820 858 1 85c
1 81b 1 860
3 703 7c7 863
1 684 2 86f
874 2 885 887
3 883 884 889
2 892 894 2
896 898 2 89a
89c 2 89e 8a0
2 8a2 8a4 3
8a9 8aa 8ab 2
8a6 8ad 2 891
8af 1 8b1 1
8b3 2 87c 8b4
1 8b8 1 877
1 8bc 1 8c7
2 8c3 8c7 1
8cb 1 8d4 1
8d6 2 8e4 8e9
2 8fa 8fc 3
8f8 8f9 8fe 2
907 909 2 90b
90d 2 90f 911
2 913 915 2
917 919 3 91e
91f 920 2 91b
922 2 906 924
1 926 1 928
2 8f1 929 1
92d 1 8ec 1
931 1 93c 2
938 93c 1 940
2 949 94a 1
94e 2 94c 94e
1 953 1 95b
2 95a 95b 1
963 1 969 2
96b 96c 2 958
96d 2 97e 980
3 97c 97d 982
2 98b 98d 2
98f 991 2 993
995 2 997 999
2 99b 99d 3
9a2 9a3 9a4 2
99f 9a6 2 98a
9a8 1 9aa 1
9ac 2 975 9ad
1 9b1 1 970
1 9b5 1 9c0
2 9bf 9c0 1
9c8 1 9ce 2
9d0 9d1 2 9bd
9d2 2 9e3 9e5
3 9e1 9e2 9e7
2 9f0 9f2 2
9f4 9f6 2 9f8
9fa 2 9fc 9fe
2 a00 a02 3
a07 a08 a09 2
a04 a0b 2 9ef
a0d 1 a0f 1
a11 2 9da a12
1 a16 1 9d5
1 a1a 1 a25
2 a24 a25 1
a2d 1 a33 2
a35 a36 2 a22
a37 2 a48 a4a
3 a46 a47 a4c
2 a55 a57 2
a59 a5b 2 a5d
a5f 2 a61 a63
2 a65 a67 3
a6c a6d a6e 2
a69 a70 2 a54
a72 1 a74 1
a76 2 a3f a77
1 a7b 1 a3a
1 a7f 1 a8a
2 a89 a8a 1
a92 1 a98 2
a9a a9b 2 a87
a9c 2 aad aaf
3 aab aac ab1
2 aba abc 2
abe ac0 2 ac2
ac4 2 ac6 ac8
2 aca acc 3
ad1 ad2 ad3 2
ace ad5 2 ab9
ad7 1 ad9 1
adb 2 aa4 adc
1 ae0 1 a9f
1 ae4 5 9b8
a1d a82 ae7 aeb
2 aed aee 1
aef 2 af3 af6
2 af8 af9 3
b05 b06 b07 1
b12 1 b18 2
b1a b1b 1 b23
2 b1f b23 1
b28 1 b2a 2
b2d b2e 1 b32
2 b30 b32 1
b47 2 b46 b47
1 b4f 1 b55
2 b57 b58 2
b44 b59 2 b6a
b6c 3 b68 b69
b6e 2 b77 b79
2 b7b b7d 2
b7f b81 2 b83
b85 2 b87 b89
3 b8e b8f b90
2 b8b b92 2
b76 b94 1 b96
1 b98 2 b61
b99 1 b9d 1
b5c 1 ba1 1
bac 2 ba8 bac
1 bba 2 bb9
bba 1 bc2 1
bc8 2 bca bcb
2 bb7 bcc 2
bdd bdf 3 bdb
bdc be1 2 bea
bec 2 bee bf0
2 bf2 bf4 2
bf6 bf8 2 bfa
bfc 3 c01 c02
c03 2 bfe c05
2 be9 c07 1
c09 1 c0b 2
bd4 c0c 1 c10
1 bcf 1 c14
1 c17 1 c26
2 c25 c26 1
c2e 1 c34 2
c36 c37 2 c23
c38 2 c49 c4b
3 c47 c48 c4d
2 c56 c58 2
c5a c5c 2 c5e
c60 2 c62 c64
2 c66 c68 3
c6d c6e c6f 2
c6a c71 2 c55
c73 1 c75 1
c77 2 c40 c78
1 c7c 1 c3b
1 c80 1 c83
2 c86 c87 2
ba4 c88 2 c8c
c8d 1 c91 2
c8f c91 1 ca0
2 c9f ca0 1
ca8 1 cae 2
cb0 cb1 2 c9d
cb2 2 cc3 cc5
3 cc1 cc2 cc7
2 cd0 cd2 2
cd4 cd6 2 cd8
cda 2 cdc cde
2 ce0 ce2 3
ce7 ce8 ce9 2
ce4 ceb 2 ccf
ced 1 cef 1
cf1 2 cba cf2
1 cf6 1 cb5
1 cfa 1 cfd
2 d01 d00 4
b08 b1c b2b d02
2 d08 d0e 2
d1f d21 3 d1d
d1e d23 2 d2c
d2e 2 d30 d32
2 d34 d36 2
d38 d3a 2 d3c
d3e 3 d43 d44
d45 2 d40 d47
2 d2b d49 1
d4b 1 d4d 2
d16 d4e 1 d52
1 d11 1 d56
1 d66 2 d65
d66 1 d6e 1
d74 2 d76 d77
2 d63 d78 2
d89 d8b 3 d87
d88 d8d 2 d96
d98 2 d9a d9c
2 d9e da0 2
da2 da4 2 da6
da8 3 dad dae
daf 2 daa db1
2 d95 db3 1
db5 1 db7 2
d80 db8 1 dbc
1 d7b 1 dc0
2 dc6 dc7 1
dcb 2 dc9 dcb
1 e08 2 e07
e08 1 e10 1
e16 2 e18 e19
2 e05 e1a 2
e2b e2d 3 e29
e2a e2f 2 e38
e3a 2 e3c e3e
2 e40 e42 2
e44 e46 2 e48
e4a 3 e4f e50
e51 2 e4c e53
2 e37 e55 1
e57 1 e59 2
e22 e5a 1 e5e
1 e1d 1 e62
2 e68 e69 1
e6d 2 e6b e6d
5 e75 e76 e77
e78 e79 2 e72
e7c 1 e7e 2
e65 e7f 2 e88
e89 1 e94 1
e9a 2 e9c e9d
1 ea5 2 ea1
ea5 1 eaa 1
eac 1 ee7 2
ee6 ee7 1 eef
1 ef5 2 ef7
ef8 2 ee4 ef9
2 f0a f0c 3
f08 f09 f0e 2
f17 f19 2 f1b
f1d 2 f1f f21
2 f23 f25 2
f27 f29 3 f2e
f2f f30 2 f2b
f32 2 f16 f34
1 f36 1 f38
2 f01 f39 1
f3d 1 efc 1
f41 1 f4f 2
f4e f4f 1 f57
1 f5d 2 f5f
f60 2 f4c f61
2 f72 f74 3
f70 f71 f76 2
f7f f81 2 f83
f85 2 f87 f89
2 f8b f8d 2
f8f f91 3 f96
f97 f98 2 f93
f9a 2 f7e f9c
1 f9e 1 fa0
2 f69 fa1 1
fa5 1 f64 1
fa9 5 e8a e9e
ead f44 fac 2
fb3 fb9 2 fca
fcc 3 fc8 fc9
fce 2 fd7 fd9
2 fdb fdd 2
fdf fe1 2 fe3
fe5 2 fe7 fe9
3 fee fef ff0
2 feb ff2 2
fd6 ff4 1 ff6
1 ff8 2 fc1
ff9 1 ffd 1
fbc 1 1001 2
1007 1008 1 100c
2 100a 100c 2
1011 1012 1 1016
2 1014 1016 1
1024 2 1023 1024
1 102c 1 1032
2 1034 1035 2
1021 1036 2 1047
1049 3 1045 1046
104b 2 1054 1056
2 1058 105a 2
105c 105e 2 1060
1062 2 1064 1066
3 106b 106c 106d
2 1068 106f 2
1053 1071 1 1073
1 1075 2 103e
1076 1 107a 1
1039 1 107e 1
1081 1 1084 5
108b 108c 108d 108e
108f 2 10a4 10a9
2 10ba 10bc 3
10b8 10b9 10be 2
10c7 10c9 2 10cb
10cd 2 10cf 10d1
2 10d3 10d5 2
10d7 10d9 3 10de
10df 10e0 2 10db
10e2 2 10c6 10e4
1 10e6 1 10e8
2 10b1 10e9 1
10ed 1 10ac 1
10f1 2 10f7 10f8
1 10fc 2 10fa
10fc 1 1116 2
1115 1116 1 111e
1 1124 2 1126
1127 2 1113 1128
2 1139 113b 3
1137 1138 113d 2
1146 1148 2 114a
114c 2 114e 1150
2 1152 1154 2
1156 1158 3 115d
115e 115f 2 115a
1161 2 1145 1163
1 1165 1 1167
2 1130 1168 1
116c 1 112b 1
1170 1 1173 1
118f 2 118e 118f
1 1197 1 119d
2 119f 11a0 2
118c 11a1 2 11b2
11b4 3 11b0 11b1
11b6 2 11bf 11c1
2 11c3 11c5 2
11c7 11c9 2 11cb
11cd 2 11cf 11d1
3 11d6 11d7 11d8
2 11d3 11da 2
11be 11dc 1 11de
1 11e0 2 11a9
11e1 1 11e5 1
11a4 1 11e9 1
11ec 2 11ef 11f0
8 e83 fb0 1004
1085 1088 1092 10f4
11f1 2 11f3 11f4
1 11f6 b 8bf
8d7 934 afa afd
b00 d05 d59 dc3
11f5 11f9 1 868
1 11fd 3 867
11fc 11ff 1 120b
2 120a 120b 1
1213 1 1219 2
121b 121c 2 1208
121d 2 122e 1230
3 122c 122d 1232
2 123b 123d 2
123f 1241 2 1243
1245 2 1247 1249
2 124b 124d 3
1252 1253 1254 2
124f 1256 2 123a
1258 1 125a 1
125c 2 1225 125d
1 1261 1 1220
1 1265 5 65f
673 682 1201 1268
2 126f 1275 2
1286 1288 3 1284
1285 128a 2 1293
1295 2 1297 1299
2 129b 129d 2
129f 12a1 2 12a3
12a5 3 12aa 12ab
12ac 2 12a7 12ae
2 1292 12b0 1
12b2 1 12b4 2
127d 12b5 1 12b9
1 1278 1 12bd
1 12c4 2 12d5
12da 2 12eb 12ed
3 12e9 12ea 12ef
2 12f8 12fa 2
12fc 12fe 2 1300
1302 2 1304 1306
2 1308 130a 3
130f 1310 1311 2
130c 1313 2 12f7
1315 1 1317 1
1319 2 12e2 131a
1 131e 1 12dd
1 1322 2 1328
1329 1 132d 2
132b 132d 3 1339
133a 133b 2 1334
133e 1 1340 1
134d 2 134c 134d
1 1355 1 135b
2 135d 135e 2
134a 135f 2 1370
1372 3 136e 136f
1374 2 137d 137f
2 1381 1383 2
1385 1387 2 1389
138b 2 138d 138f
3 1394 1395 1396
2 1391 1398 2
137c 139a 1 139c
1 139e 2 1367
139f 1 13a3 1
1362 1 13a7 1
13b0 2 13ae 13b0
1 13b7 1 13b9
2 13c3 13c5 3
13c1 13c2 13c7 2
13d0 13d2 2 13d4
13d6 2 13d8 13da
1 13e2 2 13e4
13e5 2 13dc 13e7
2 13e9 13eb 2
13ed 13ef 2 13f1
13f3 2 13f5 13f7
2 13cf 13f9 1
13fb 1 13fd 3
1404 1405 1406 10
156 175 178 17b
1d2 653 658 126c
12c0 12c7 1325 1341
13aa 13ba 13fe 1408
2 1415 1417 3
1413 1414 1419 2
1422 1424 2 1421
1426 2 142d 1431
2 1433 1435 2
1437 143b 2 142c
143d 2 1428 143f
1 1441 3 1442
144d 1451 1 140c
2 1464 1466 3
1462 1463 1468 2
1471 1473 2 1470
1475 2 147c 147e
2 1480 1482 3
1487 1488 1489 2
1484 148b 2 147b
148d 2 1477 148f
1 1491 4 145b
1492 149b 149f 1
14a3 1 1456 2
1454 14a7 20 1a
24 2b 30 37
3e 45 4c 53
58 5d 63 69
6f 75 7b 81
87 8d 93 99
9f a5 ab b1
b7 be e0 ea
fb 10c 116 
1
4
0 
14ae
0
1
50
4f
24
0 1 1 1 1 5 1 7
1 9 1 b 1 d e d
10 1 12 1 14 1 16 17
16 19 16 1b 16 1d 16 1f
16 21 16 23 16 25 16 27
16 29 2a 29 2c 29 2e 29
30 16 32 16 34 16 36 16
38 39 38 3b 16 3d 16 3f
16 41 16 43 16 45 16 47
1 49 1 4b 1 4d 1 0

2 0 1
83 1 0
a1 1 0
3 1 0
7d 1 0
5a 1 0
47 1 0
4e 1 0
ed 1 3
1c 1 0
101 1 4
b3 1 0
b9 1 0
12 1 0
71 1 0
2d 1 0
a7 1 0
95 1 0
89 1 0
e5 1 0
55 1 0
65 1 0
77 1 0
5f 1 0
6b 1 0
8f 1 0
40 1 0
39 1 0
9b 1 0
32 1 0
26 1 0
11f6 16 47
7 1 0
ad 1 0
c1 1 2
111 1 0
0

/
SHOW ERRORS FUNCTION SP_COMMIT_ASSIGN;
ALTER FUNCTION SP_COMMIT_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Accept ETC and/or FORECAST_START, Assign level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_ACPT_ETC_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_ACPT_ETC_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
aa
2 :e:
1FUNCTION:
1SP_ACPT_ETC_ASSIGN:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PRJ_ASSIGNMENT_ID:
1H_REC_USER:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_TA_START_DT:
1TIMESTAMP:
1H_TA_FINISH_DT:
1H_START_DATE:
1H_FINISH_DATE:
1H_FINISH_D:
1DATE:
1H_LAST_SUBMITTED:
1H_WEEK_OF:
1H_BIT_FLAG:
1H_EFFORT:
10:
1H_CONTOUR:
1H_BITFLAG:
1H_REMAINING:
1H_TOTAL:
1H_CONSTR_DT:
1H_DAYOFYEAR:
1H_FINISH_TIME:
18:
1H_MINUTE:
1H_CONSTR_TYPE:
1H_FF_FLAG:
1H_ETC:
1H_SCHED_WORK:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_SD:
1H_FD:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_MLST_PERCENT:
1H_PROJAFFECTED_START:
1H_WORK_TODATE:
1H_PASSED:
1H_NOT_EFFORT_PA:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ACPT_ETC_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_ACPT_ETC_ASSIGN(61) :: cplan.sql(18004) :: :
1PROJECT_ID:
1TASK_ID:
1PROJECT_ASSIGNMENT_ID:
1SCHED_WORK:
1PLANNED_WORK:
1FORECAST_START:
1FORECAST_FINISH:
1ETC:
1WORK_TODATE:
1C_CONTOUR:
1LAST_SUBMITTED:
1PLANNED_START:
1SCHED_START:
1PLANNED_FINISH:
1SCHED_FINISH:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1BIT_FLAG:
1MILESTONE_PERCENT:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT:n      PROJECT_ID,:n      TASK_ID,:n      PROJECT_ASSIGNMENT_ID,:n    +
1  SCHED_WORK+PLANNED_WORK,:n      FORECAST_START,:n      FORECAST_FINISH,:n  +
1    CASE WHEN h_bitflag = 2 AND FORECAST_START IS NuLL THEN 0 ELSE ETC END,:n+
1      SCHED_WORK+PLANNED_WORK - WORK_TODATE,:n      ETC,:n      C_CONTOUR,:n +
1     LAST_SUBMITTED,:n      CASE WHEN FORECAST_FINISH IS NOT NuLL AND FORECAS+
1T_START IS NuLL AND FORECAST_FINISH BETWEEN COALESCE(PLANNED_START, SCHED_STA+
1RT) AND COALESCE(PLANNED_FINISH, SCHED_FINISH) THEN 1 ELSE 0 END,:n      UNRE+
1SOLVED_START,:n      UNRESOLVED_FINISH,:n      BILLABLE,:n      CAPITAL_EXPEN+
1SE,:n      REGULAR_COST,:n      REGULAR_RATE,:n      BIT_FLAG,:n      MILESTO+
1NE_PERCENT,:n      RESOURCE_ID,:n      RESOURCE_TYPE,:n      WORK_TODATE:n   +
1   INTO:n      h_project_id,:n      h_task_id,:n      h_prj_assignment_id,:n +
1     h_sched_work,:n      h_start_date,:n      h_finish_date,:n      h_effort+
1,:n      h_remaining,:n      h_etc,:n      h_contour,:n      h_last_submitted+
1,:n      h_FF_flag,:n      h_ta_start_DT,:n      h_ta_finish_DT,:n      h_bil+
1lable,:n      h_capital_expense,:n      h_reg_cost,:n      h_reg_sale,:n     +
1 h_bit_flag,:n      h_mlst_percent,:n      h_res_id,:n      h_res_type,:n    +
1  h_work_todate:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID =+
1 h_tsk_assignment_id:n      AND (((SCHED_WORK+PLANNED_WORK) > 0:n      AND (S+
1CHED_WORK+PLANNED_WORK - WORK_TODATE) <> ETC):n      OR FORECAST_START IS NOT+
1 NULL OR FORECAST_FINISH IS NOT NULL):
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1138:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(139) :: cplan.sql(18082) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1145:
1        RETURN_ERROR:: SP_ACPT_ETC_ASSIGN(146) :: cplan.sql(18089) :: :
1STATE:: :
1PMO_CNST:
1RECORD_NOT_FOUND:
1 ID:: :
1148:
1                EXIT:: SP_ACPT_ETC_ASSIGN(149) :: cplan.sql(18092) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1FC_ACPT_EFFORT:
1>:
1200000:
1167:
1        RETURN_ERROR:: SP_ACPT_ETC_ASSIGN(168) :: cplan.sql(18111) :: :
1170:
1                EXIT:: SP_ACPT_ETC_ASSIGN(171) :: cplan.sql(18114) :: :
1!=:
1SELECT ETC INTO h_total:n            FROM TASK_ASSIGNMENTS:n            WHERE+
1 TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1189:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(190) :: cplan.sql(18133) :: :
1UPDATE TASK_ASSIGNMENTS:n               SET ETC  = h_etc:n               WHER+
1E TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1FOUND:
1100:
1209:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(210) :: cplan.sql(18153) :: :
1FC_ROLLUP:
14:
1220:
1       RETURN_STATUS:: SP_ACPT_ETC_ASSIGN(221) :: cplan.sql(18164) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1227:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(228) :: cplan.sql(18171) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1239:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(240) :: cplan.sql(18183) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
517
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d :2 a0 d :2 a0 d a0 4d d
a0 4d d :46 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :1c a0 a5 b d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 b7 a0 51
d :2 a0 51 a5 b 7e 51 b4
2e :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:5 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 19 3c :3 a0
a5 b d b7 :2 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :2 a0 6b :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e :2 a0 6b b4 2e 7e 6e b4
2e 7e :2 a0 6b b4 2e a5 57
b7 19 3c :9 a0 12a e9 dd :2 a0
65 b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c :7 a0 12a e9 dd :2 a0 65 b7
a4 b1 11 4f b7 a6 9 a4
b1 11 68 4f 1d 17 b5 
517
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
134 122 101 126 127 12f 121 150
13f 143 14b 11e 168 157 15b 163
13e 184 173 177 17f 13b 19c 18b
18f 197 172 1b8 1a7 1ab 1b3 16f
1d0 1bf 1c3 1cb 1a6 1ec 1db 1df
1e7 1a3 208 1f3 1f7 1fa 1fb 203
1da 224 213 217 1d7 21f 212 240
22f 233 20f 23b 22e 25c 24b 24f
22b 257 24a 278 267 26b 247 273
266 294 283 287 263 28f 282 2b0
29f 2a3 2ab 27f 2c8 2b7 2bb 2c3
29e 2e5 2d3 29b 2d7 2d8 2e0 2d2
301 2f0 2f4 2cf 2fc 2ef 31d 30c
310 2ec 318 30b 339 328 32c 308
334 327 355 344 348 324 350 343
371 360 364 340 36c 35f 38d 37c
380 35c 388 37b 3a9 398 39c 378
3a4 397 3c5 3b4 3b8 394 3c0 3b3
3e1 3d0 3d4 3b0 3dc 3cf 3fd 3ec
3f0 3f8 3cc 415 404 408 410 3eb
431 420 424 3e8 42c 41f 44d 43c
440 41c 448 43b 469 458 45c 438
464 457 485 474 478 454 480 473
4a1 490 494 49c 470 4bc 4a8 4ac
4b4 4b7 48f 4d8 4c7 4cb 48c 4d3
4c6 4f4 4e3 4e7 4c3 4ef 4e2 514
4ff 503 4df 507 50f 4fe 51b 51f
4fb 523 527 52b 52e 533 534 1
536 53b 53f 543 546 54b 54f 553
556 55b 55c 55e 563 566 56a 56b
570 575 578 57d 57e 583 586 58a
58b 590 593 598 599 59e 5a1 5a6
5a7 5ac 5af 5b3 5b7 5bb 5bc 5be
5c3 5c4 5c6 5c7 5cc 5cf 5d4 5d5
5da 5dd 5e2 5e3 5e8 5eb 5ef 5f0
5f5 5f8 5fd 5fe 603 606 60b 60c
611 612 617 619 61d 620 624 628
62b 62f 633 636 639 63e 641 644
647 648 64d 64e 1 650 655 659
65d 660 665 66a 66d 671 672 677
678 67d 67f 683 686 68a 68e 692
696 69a 69e 6a2 6a6 6aa 6ae 6af
6b3 6b7 6b8 6bc 6c0 6c4 6c8 6cc
6d0 6d4 6d8 6dc 6e0 6e4 6e8 6ec
6f0 6f4 6f8 6fc 700 704 708 70c
710 714 718 71c 720 724 728 72c
730 734 738 73c 740 744 748 74c
750 754 758 75c 760 764 768 76c
770 774 778 77c 780 784 788 78c
790 794 798 79c 7a0 7a4 7a8 7ac
7b0 7b4 7b8 7bc 7c0 7c4 7c8 7cc
7d0 7d4 7e0 7e4 7e8 7eb 7ef 7f3
7f5 1 7f9 7fd 801 804 808 80c
810 814 817 81b 81f 822 825 82a
82d 830 833 834 839 83a 1 83c
841 845 849 84c 851 856 859 85d
85e 863 866 86b 86c 871 874 879
87a 87f 882 886 887 88c 88f 894
895 89a 89d 8a1 8a5 8a8 8ab 8ac
8ae 8af 8b4 8b5 8ba 8bc 8c0 8c3
8c5 8c9 8cb 8d7 8d9 8db 8dc 8e1
8e5 8e7 8f3 8f5 8f9 8fd 900 904
907 90b 90e 90f 914 917 91b 91f
922 926 92a 92d 930 935 938 93b
93e 93f 944 945 1 947 94c 950
954 957 95c 961 964 968 969 96e
971 976 977 97c 97f 984 985 98a
98d 991 995 999 99d 9a0 9a1 9a3
9a8 9a9 9ab 9ac 9b1 9b4 9b9 9ba
9bf 9c2 9c7 9c8 9cd 9d0 9d4 9d5
9da 9dd 9e2 9e3 9e8 9e9 9ee 9f0
9f4 9f7 9fb 9ff a02 a06 a0a a0d
a10 a15 a18 a1b a1e a1f a24 a25
1 a27 a2c a30 a34 a37 a3c a41
a44 a48 a49 a4e a4f a54 a56 a5a
a5d a61 a65 a68 a6c a70 a73 a77
a7b a7c a81 a83 a87 a8a a8e a92
a96 a9a a9e aa2 aa6 aaa aae ab2
ab6 aba abe ac2 ac6 aca ace ad2
ad6 ada ade ae2 ae6 aea aee af2
af6 afa afb afd b01 b05 b09 b0c
b0d b0f b12 b15 b16 b1b b1f b23
b26 b2a b2e b31 b34 b39 b3c b3f
b42 b43 b48 b49 1 b4b b50 b54
b58 b5b b60 b65 b68 b6c b6d b72
b75 b7a b7b b80 b83 b88 b89 b8e
b91 b95 b99 b9d b9e ba0 ba5 ba6
ba8 ba9 bae bb1 bb6 bb7 bbc bbf
bc4 bc5 bca bcd bd1 bd2 bd7 bda
bdf be0 be5 be6 beb bed bf1 bf4
bf8 bfc bff c03 c07 c0a c0d c12
c15 c18 c1b c1c c21 c22 1 c24
c29 c2d c31 c34 c39 c3e c41 c45
c46 c4b c4c c51 c53 c57 c5a c5e
c62 c65 c69 c6d c70 c71 c73 c77
c7b c7c c81 c83 c87 c8a c8e c92
c96 c99 c9a c9c c9f ca2 ca3 ca8
cac cb0 cb4 cb8 cbc cc8 ccc cd0
cd3 cd7 cdb cdd 1 ce1 ce5 ce9
cec cf0 cf4 cf8 cfc cff d03 d07
d0a d0d d12 d15 d18 d1b d1c d21
d22 1 d24 d29 d2d d31 d34 d39
d3e d41 d45 d46 d4b d4e d53 d54
d59 d5c d61 d62 d67 d6a d6e d6f
d74 d77 d7c d7d d82 d85 d89 d8d
d90 d93 d94 d96 d97 d9c d9d da2
da4 da8 dab dad db1 db3 dbf dc1
dc3 dc4 dc9 dcd dcf ddb ddd de1
de5 de8 de9 deb def df2 df6 df9
dfa dfc dfd e02 e06 e0a e0e e12
e16 e22 e26 e2b e2f e32 e33 e38
e3c e40 e43 e46 e4a e4c e50 e54
e57 e5a e5e e60 e64 e68 e6b e6d
1 e71 e75 e79 e7c e80 e84 e88
e8c e8f e93 e97 e9a e9d ea2 ea5
ea8 eab eac eb1 eb2 1 eb4 eb9
ebd ec1 ec4 ec9 ece ed1 ed5 ed6
edb ede ee3 ee4 ee9 eec ef1 ef2
ef7 efa efe eff f04 f07 f0c f0d
f12 f15 f19 f1d f20 f23 f24 f26
f27 f2c f2d f32 f34 f38 f3b f3d
f41 f43 f4f f51 f53 f54 f59 f5d
f5f f6b f6d f6f f73 f76 f78 f7c
f7f f83 f87 f8b f8c f8e f92 f94
f98 f9c f9f fa3 fa7 faa fae fb2
fb5 fb8 fbd fc0 fc3 fc6 fc7 fcc
fcd 1 fcf fd4 fd8 fdc fdf fe4
fe9 fec ff0 ff1 ff6 ff9 ffe fff
1004 1007 100c 100d 1012 1015 1019 101d
1021 1025 1028 1029 102b 1030 1031 1033
1034 1039 103c 1041 1042 1047 104a 104f
1050 1055 1058 105c 105d 1062 1065 106a
106b 1070 1071 1076 1078 107c 107f 1083
1087 108a 108e 1092 1095 1099 109d 109e
10a3 10a5 10a9 10ad 10b0 10b4 10b8 10bb
10bf 10c3 10c6 10c9 10ce 10d1 10d4 10d7
10d8 10dd 10de 1 10e0 10e5 10e9 10ed
10f0 10f5 10fa 10fd 1101 1102 1107 1108
110d 1111 1115 1118 111d 1122 1125 1129
112d 1130 1131 1136 1139 113e 113f 1144
1147 114b 114f 1152 1153 1158 1159 115e
1160 1164 1167 116b 116f 1173 1177 117b
117f 1183 1187 118b 1197 119c 11a0 11a4
11a8 11ac 11ae 11af 11b4 1 11b8 11bc
11c0 11c3 11c7 11cb 11cf 11d3 11d6 11da
11de 11e1 11e4 11e9 11ec 11ef 11f2 11f3
11f8 11f9 1 11fb 1200 1204 1208 120b
1210 1215 1218 121c 121d 1222 1223 1228
122c 1230 1233 1238 123d 1240 1244 1245
124a 124d 1252 1253 1258 125b 125f 1263
1266 1269 126a 126c 126d 1272 1273 1278
127a 127e 1281 1285 1289 128d 1291 1295
1299 129d 12a9 12ae 12b2 12b6 12ba 12be
12c0 12c4 12c6 12d2 12d4 12d6 12d7 12dc
12e0 12e2 12ee 12f2 12f4 12f5 12fe 
517
2
0 1 a 6 9 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 18 21
20 :2 18 :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 e 17 16
:2 e :2 4 d 16 15 :2 d :2 4 f
18 17 :2 f :2 4 :3 12 :2 4 :3 13 :2 4
:3 11 :2 4 :3 12 :2 4 :3 f :2 4 :3 15 :2 4
:3 e :2 4 f 18 17 :2 f :2 4 :2 d
1c d :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 10 1f 10 :2 4 :2 c
1b c :2 4 :3 10 :2 4 :3 10 :2 4 12
1b 1a :2 12 :2 4 :2 d 1c d :2 4
:2 12 21 12 :2 4 :2 e 1d e :2 4
:2 a 19 a :2 4 :2 11 20 11 :2 4
:2 f 1e f :2 4 :2 14 23 14 :2 4
:2 f 19 f :2 4 :2 f 19 f :2 4
:3 9 :2 4 :3 9 :2 4 :2 f 1e f :2 4
:2 16 25 16 :2 4 :2 11 20 11 :2 4
:2 13 22 13 :2 4 :3 19 :2 4 :2 12 21
12 :2 4 :2 d 1c d :2 4 :2 14 23
14 :2 4 e 17 :3 e 4 7 :2 11
23 :2 2d 3a :2 23 :3 7 :2 d 19 25
:2 2f 43 :2 25 5a 60 63 :2 5a 71
8d 8 :2 71 d 10 :2 71 13 16
:2 71 b e :2 71 13 16 1f 27
:2 1f 34 :2 16 :2 71 b e :2 71 13
16 :2 71 1b 1e :2 71 2a 2d :2 71
32 35 :2 71 :2 7 50 :2 4 7 :2 11
23 :2 2d 39 3c 52 54 55 :2 52
:2 23 :3 7 :2 d 12 1e 63 66 :2 1e
:2 7 58 :3 4 11 :2 4 1b :2 4 12
:2 4 14 :2 4 15 4 :4 7 12 :2 7
11 23 46 7 12 21 :3 7 11
31 4c 64 6d 7c 8d 96 a6
:22 7 c d 21 e 19 c 17
26 36 a 28 fffa 7 :2 10 1c
7 4 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 59 5c 5d
:2 59 :2 29 :3 d :2 13 18 24 6a 6d
:2 24 7a 7d :2 24 81 84 :2 24 90
93 :2 24 9b 9e :2 24 aa ad b4
bd c0 :2 ad :2 24 :2 d 60 :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1c 1a
:2 25 :2 1a 7 a :2 14 26 :2 30 3c
40 56 59 5a :2 56 :2 26 :3 a :2 10
15 21 67 6a :2 21 77 7a :2 21
7e 81 :2 21 8b 8e 97 9f :2 a8
:2 97 bb :2 8e :2 21 c3 c6 :2 21 ce
d1 :2 21 d6 d9 :2 21 ed f0 :2 21
:2 a 5d :2 7 a :2 14 26 :2 30 3c
3f 55 58 59 :2 55 :2 26 :3 a :2 10
15 21 67 6a :2 21 :2 a 5c :3 7
:2 12 26 :2 2f 41 f :2 7 35 :3 4
17 26 34 3f 54 25 33 41
50 5a 25 2c 37 49 54 25
35 41 54 25 31 3d 4d 57
25 34 3f :2 17 4 7 10 21
:2 7 24 26 :2 24 a :2 14 26 :2 30
3c 40 56 59 5a :2 56 :2 26 :3 a
:2 10 15 21 67 6a :2 21 77 7a
:2 21 7e 81 :2 21 8b 8e 97 9f
:2 97 b1 :2 8e :2 21 b9 bc :2 21 c4
c7 :2 21 cc cf :2 21 e3 e6 :2 21
:2 a 5d :2 7 a :2 14 26 :2 30 3c
3f 55 58 59 :2 55 :2 26 :3 a :2 10
15 21 67 6a :2 21 :2 a 5c :3 7
:2 12 26 2f 40 :2 26 44 f :2 7
2d 7 12 7 a 13 1e :2 a
21 24 :2 21 14 1d 12 13 27
:2 d :2 16 22 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5f 62 63 :2 5f :2 2f :3 13 :2 19 1e
2a 70 73 :2 2a 80 83 :2 2a 87
8a :2 2a 96 99 :2 2a a1 a4 :2 2a
b0 b3 ba c3 c6 :2 b3 :2 2a :2 13
66 :2 10 :2 d :4 19 :2 d a :3 26 d
16 1d :2 d 22 20 2b 34 :2 22
:2 20 17 14 1b 16 2a 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 62 65 66 :2 62 :2 32 :3 16 :2 1c
21 2d 73 76 :2 2d 83 86 :2 2d
8a 8d :2 2d 99 9c :2 2d a4 a7
:2 2d b3 b6 bd c6 c9 :2 b6 :2 2d
:2 16 69 :2 13 :2 10 :4 1c :2 10 d :4 37
:2 a 26 :3 7 1a 24 :2 1a 7 :4 4
7 :2 11 23 :2 2d 39 3c 52 55
56 :2 52 :2 23 :3 7 :2 d 12 1e 64
67 :2 1e 74 77 :2 1e 7b 7e :2 1e
88 8b 94 9c :2 a5 :2 94 b0 :2 8b
:2 1e b8 bb :2 1e c3 c6 :2 1e cb
ce :2 1e d1 d4 :2 1e :2 7 59 :3 4
:2 f 21 :2 2a 34 38 :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
56 59 5a :2 56 :2 26 :3 a :2 10 15
21 67 6a :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 5d :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
53 56 57 :2 53 :2 23 :3 7 :2 d 12
1e 64 67 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 5a :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
517
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :7 e :5 f
:5 10 :5 11 :5 12 :5 13
:5 14 :5 15 :7 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:5 1c :5 1d :7 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:5 28 :5 29 :6 2a :6 2b
:6 2c :6 2d :5 2e :6 2f
:6 30 :6 31 :7 33 :b 35
:11 36 37 :2 36 :2 37
:2 36 :2 37 :2 36 :2 38
:2 36 :9 38 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:4 36 :3 35 :11 3c :b 3d
:3 3c :3 44 :3 45 :3 46
:3 4a :3 4c 51 52
53 :2 54 55 56
:3 57 :3 58 59 5a
5b :9 5c 5d 5e
5f 60 61 62
63 64 65 66
67 69 6a 6b
6c 6d 6e 6f
70 71 72 73
74 75 76 77
78 79 7a 7b
7c 7d 7e 7f
80 :2 81 :2 82 :4 83
:2 84 51 :5 85 4f
:2 87 :5 89 :11 8a :24 8b
:3 8a :2 88 :6 87 86
:3 34 :a 90 :11 91 :30 92
:3 91 :11 94 :b 95 :3 94
:7 97 98 :2 97 :3 90
:6 9b :5 9c :5 9d :4 9e
:5 9f :3 a0 :3 9b :9 a4
:11 a7 :2e a8 :3 a7 :11 aa
:b ab :3 aa :9 ad ae
:2 ad a4 :3 b0 :9 b3
:2 b5 b6 :2 b7 b5
:5 b8 b4 :2 ba :5 bc
:11 bd :24 be :3 bd :2 bb
:6 ba b9 :3 b3 :d c3
c5 :2 c6 :2 c7 c5
:6 c8 :5 c9 c8 :5 cb
ca :3 c8 c4 :2 ce
:5 d0 :11 d1 :24 d2 :3 d1
:2 cf :6 ce cd :6 c3
:3 b3 :6 d9 af :3 a4
:11 dc :30 dd :3 dc :a df
34 :3 e2 :11 e3 :b e4
:17 e5 :3 e3 :2 e7 :3 e8
:3 e9 ea e8 e7
e8 :3 eb :3 e2 :2 ec
:5 ee :11 ef :b f0 :18 f1
:3 ef :2 f3 f4 :3 f5
f6 f4 f3 f4
:3 f7 :2 ed :6 ec e1
:7 1 
1300
4
:3 0 1 :3 0 2
:a 0 512 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 512 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 510
0 b :6 0 c
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 510
0 d :6 0 c
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 510
0 e :6 0 c
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 510
0 f :6 0 c
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 510
0 10 :6 0 13
:2 0 23 4 :3 0
21 3a 3c :6 0
3f 3d 0 510
0 11 :6 0 29
13b 0 27 4
:3 0 25 41 43
:6 0 46 44 0
510 0 12 :6 0
2d 16f 0 2b
15 :3 0 48 :7 0
4b 49 0 510
0 14 :6 0 15
:3 0 4d :7 0 50
4e 0 510 0
16 :6 0 31 1a3
0 2f 15 :3 0
52 :7 0 55 53
0 510 0 17
:6 0 15 :3 0 57
:7 0 5a 58 0
510 0 18 :6 0
35 1d7 0 33
1a :3 0 5c :7 0
5f 5d 0 510
0 19 :6 0 1a
:3 0 61 :7 0 64
62 0 510 0
1b :6 0 1f :2 0
39 1a :3 0 66
:7 0 69 67 0
510 0 1c :6 0
4 :3 0 13 :2 0
37 6b 6d :6 0
70 6e 0 510
0 1d :6 0 1f
:2 0 3b 6 :3 0
72 :7 0 76 73
74 510 0 1e
:6 0 1f :2 0 3d
6 :3 0 78 :7 0
7c 79 7a 510
0 20 :6 0 1f
:2 0 3f 6 :3 0
7e :7 0 82 7f
80 510 0 21
:6 0 1f :2 0 41
6 :3 0 84 :7 0
88 85 86 510
0 22 :6 0 45
29b 0 43 6
:3 0 8a :7 0 8e
8b 8c 510 0
23 :6 0 27 :2 0
47 15 :3 0 90
:7 0 93 91 0
510 0 24 :6 0
1a :3 0 95 :7 0
98 96 0 510
0 25 :6 0 1f
:2 0 4b 4 :3 0
49 9a 9c :6 0
9f 9d 0 510
0 26 :6 0 1f
:2 0 4d 6 :3 0
a1 :7 0 a5 a2
a3 510 0 28
:6 0 1f :2 0 4f
6 :3 0 a7 :7 0
ab a8 a9 510
0 29 :6 0 1f
:2 0 51 6 :3 0
ad :7 0 b1 ae
af 510 0 2a
:6 0 1f :2 0 53
6 :3 0 b3 :7 0
b7 b4 b5 510
0 2b :6 0 1f
:2 0 55 6 :3 0
b9 :7 0 bd ba
bb 510 0 2c
:6 0 1f :2 0 57
6 :3 0 bf :7 0
c3 c0 c1 510
0 2d :6 0 31
:2 0 59 6 :3 0
c5 :7 0 c9 c6
c7 510 0 2e
:6 0 31 :2 0 5b
30 :3 0 cb :7 0
cf cc cd 510
0 2f :6 0 5f
3e8 0 5d 30
:3 0 d1 :7 0 d5
d2 d3 510 0
32 :6 0 1f :2 0
61 1a :3 0 d7
:7 0 da d8 0
510 0 33 :6 0
1a :3 0 dc :7 0
df dd 0 510
0 34 :6 0 1f
:2 0 63 6 :3 0
e1 :7 0 e5 e2
e3 510 0 35
:6 0 1f :2 0 65
6 :3 0 e7 :7 0
eb e8 e9 510
0 36 :6 0 1f
:2 0 67 6 :3 0
ed :7 0 f1 ee
ef 510 0 37
:6 0 6b 48c 0
69 6 :3 0 f3
:7 0 f7 f4 f5
510 0 38 :6 0
1f :2 0 6d 1a
:3 0 f9 :7 0 fc
fa 0 510 0
39 :6 0 6 :3 0
fe :7 0 1f :2 0
102 ff 100 510
0 3a :6 0 1f
:2 0 6f 6 :3 0
104 :7 0 108 105
106 510 0 3b
:6 0 110 111 0
71 6 :3 0 10a
:7 0 10e 10b 10c
510 0 3c :6 0
116 117 0 73
9 :3 0 a :2 0
4 112 :7 0 115
113 0 510 0
3d :6 0 3e :3 0
3f :3 0 3e :3 0
40 :3 0 119 11a
0 2 :4 0 75
11b 11d 118 11f
11e :2 0 41 :3 0
42 :3 0 121 122
0 43 :4 0 3e
:3 0 44 :3 0 125
126 0 2 :4 0
77 127 129 45
:4 0 46 :2 0 47
:3 0 79 12c 12e
:3 0 48 :4 0 46
:2 0 49 :4 0 7c
131 133 :3 0 46
:2 0 3 :3 0 7f
135 137 :3 0 46
:2 0 49 :4 0 82
139 13b :3 0 46
:2 0 4a :4 0 85
13d 13f :3 0 46
:2 0 4b :3 0 4c
:3 0 5 :3 0 88
143 145 4d :4 0
8a 142 148 8d
141 14a :3 0 46
:2 0 4a :4 0 90
14c 14e :3 0 46
:2 0 49 :4 0 93
150 152 :3 0 46
:2 0 7 :3 0 96
154 156 :3 0 46
:2 0 49 :4 0 99
158 15a :3 0 46
:2 0 4e :4 0 9c
15c 15e :3 0 9f
123 160 :2 0 162
a4 163 120 162
0 164 a6 0
470 3e :3 0 3f
:3 0 165 166 0
3e :3 0 4f :3 0
168 169 0 13
:2 0 2 :4 0 50
:2 0 51 :2 0 13
:2 0 a8 16e 170
:3 0 ab 16a 172
167 174 173 :2 0
41 :3 0 52 :3 0
176 177 0 43
:4 0 53 :4 0 46
:2 0 47 :3 0 af
17b 17d :3 0 b2
178 17f :2 0 181
b5 182 175 181
0 183 b7 0
470 21 :3 0 5
:3 0 184 185 0
470 b :3 0 3
:3 0 187 188 0
470 e :3 0 7
:3 0 18a 18b 0
470 17 :4 0 18d
18e 0 470 18
:4 0 190 191 0
470 54 :3 0 55
:3 0 56 :3 0 57
:3 0 58 :3 0 59
:3 0 5a :3 0 21
:3 0 59 :3 0 5b
:3 0 57 :3 0 58
:3 0 5c :3 0 5b
:3 0 5d :3 0 5e
:3 0 5a :3 0 59
:3 0 5a :3 0 4b
:3 0 5f :3 0 60
:3 0 4b :3 0 61
:3 0 62 :3 0 63
:3 0 64 :3 0 65
:3 0 66 :3 0 67
:3 0 68 :3 0 69
:3 0 6a :3 0 6b
:3 0 6c :3 0 5c
:3 0 f :3 0 10
:3 0 d :3 0 2c
:3 0 17 :3 0 18
:3 0 1e :3 0 22
:3 0 2b :3 0 20
:3 0 1b :3 0 2a
:3 0 14 :3 0 16
:3 0 35 :3 0 36
:3 0 2f :3 0 32
:3 0 1d :3 0 38
:3 0 11 :3 0 12
:3 0 3a :3 0 6d
:3 0 6e :3 0 b
:3 0 57 :3 0 58
:3 0 57 :3 0 58
:3 0 5c :3 0 5b
:3 0 59 :3 0 5a
:4 0 6f 1 :8 0
1df 9 :3 0 70
:3 0 1da 1db 0
71 :3 0 1dc 1dd
0 1df b9 229
72 :3 0 9 :3 0
70 :3 0 1e2 1e3
0 71 :3 0 1e4
1e5 0 21f 3e
:3 0 3f :3 0 1e7
1e8 0 3e :3 0
4f :3 0 1ea 1eb
0 73 :2 0 2
:4 0 74 :2 0 51
:2 0 13 :2 0 bc
1f0 1f2 :3 0 bf
1ec 1f4 1e9 1f6
1f5 :2 0 41 :3 0
52 :3 0 1f8 1f9
0 43 :4 0 75
:4 0 46 :2 0 47
:3 0 c3 1fd 1ff
:3 0 46 :2 0 76
:4 0 c6 201 203
:3 0 46 :2 0 77
:4 0 c9 205 207
:3 0 46 :2 0 71
:3 0 cc 209 20b
:3 0 46 :2 0 78
:4 0 cf 20d 20f
:3 0 46 :2 0 79
:3 0 7a :3 0 13
:2 0 7b :2 0 d2
212 216 d6 211
218 :3 0 d9 1fa
21a :2 0 21c dc
21d 1f7 21c 0
21e de 0 21f
e0 222 :3 0 222
0 222 221 21f
220 :6 0 224 2
:3 0 e3 226 e5
225 224 :2 0 227
e7 :2 0 229 0
229 228 1df 227
:6 0 470 1 :3 0
9 :3 0 70 :3 0
22b 22c 0 9
:3 0 7c :2 0 7d
:3 0 22e 230 0
eb 22f 232 :3 0
233 :2 0 3e :3 0
3f :3 0 235 236
0 3e :3 0 4f
:3 0 238 239 0
c :2 0 2 :4 0
7e :2 0 51 :2 0
13 :2 0 ee 23e
240 :3 0 f1 23a
242 237 244 243
:2 0 41 :3 0 52
:3 0 246 247 0
43 :4 0 7f :4 0
46 :2 0 47 :3 0
f5 24b 24d :3 0
46 :2 0 76 :4 0
f8 24f 251 :3 0
46 :2 0 80 :4 0
fb 253 255 :3 0
46 :2 0 4b :3 0
4c :3 0 81 :3 0
82 :3 0 25a 25b
0 fe 259 25d
4d :4 0 100 258
260 103 257 262
:3 0 46 :2 0 83
:4 0 106 264 266
:3 0 46 :2 0 49
:4 0 109 268 26a
:3 0 46 :2 0 b
:3 0 10c 26c 26e
:3 0 46 :2 0 49
:4 0 10f 270 272
:3 0 112 248 274
:2 0 276 115 277
245 276 0 278
117 0 2a2 3e
:3 0 3f :3 0 279
27a 0 3e :3 0
4f :3 0 27c 27d
0 13 :2 0 2
:4 0 84 :2 0 51
:2 0 13 :2 0 119
282 284 :3 0 11c
27e 286 27b 288
287 :2 0 41 :3 0
52 :3 0 28a 28b
0 43 :4 0 85
:4 0 46 :2 0 47
:3 0 120 28f 291
:3 0 123 28c 293
:2 0 295 126 296
289 295 0 297
128 0 2a2 86
:3 0 87 :3 0 298
299 0 81 :3 0
82 :3 0 29b 29c
0 b :3 0 88
:3 0 12a 29a 2a0
:2 0 2a2 12e 2a3
234 2a2 0 2a4
132 0 470 2e
:3 0 89 :3 0 f
:3 0 10 :3 0 b
:3 0 d :3 0 2c
:3 0 17 :3 0 18
:3 0 1e :3 0 22
:3 0 2b :3 0 20
:3 0 1b :3 0 2a
:3 0 14 :3 0 16
:3 0 35 :3 0 36
:3 0 2f :3 0 32
:3 0 1d :3 0 38
:3 0 11 :3 0 12
:3 0 3a :3 0 21
:3 0 e :3 0 134
2a6 2c1 2a5 2c2
0 470 4b :3 0
2e :3 0 1f :2 0
14f 2c4 2c7 8a
:2 0 8b :2 0 154
2c9 2cb :3 0 3e
:3 0 3f :3 0 2cd
2ce 0 3e :3 0
4f :3 0 2d0 2d1
0 c :2 0 2
:4 0 8c :2 0 51
:2 0 13 :2 0 157
2d6 2d8 :3 0 15a
2d2 2da 2cf 2dc
2db :2 0 41 :3 0
52 :3 0 2de 2df
0 43 :4 0 8d
:4 0 46 :2 0 47
:3 0 15e 2e3 2e5
:3 0 46 :2 0 76
:4 0 161 2e7 2e9
:3 0 46 :2 0 80
:4 0 164 2eb 2ed
:3 0 46 :2 0 4b
:3 0 4c :3 0 2e
:3 0 167 2f1 2f3
4d :4 0 169 2f0
2f6 16c 2ef 2f8
:3 0 46 :2 0 83
:4 0 16f 2fa 2fc
:3 0 46 :2 0 49
:4 0 172 2fe 300
:3 0 46 :2 0 b
:3 0 175 302 304
:3 0 46 :2 0 49
:4 0 178 306 308
:3 0 17b 2e0 30a
:2 0 30c 17e 30d
2dd 30c 0 30e
180 0 33a 3e
:3 0 3f :3 0 30f
310 0 3e :3 0
4f :3 0 312 313
0 13 :2 0 2
:4 0 8e :2 0 51
:2 0 13 :2 0 182
318 31a :3 0 185
314 31c 311 31e
31d :2 0 41 :3 0
52 :3 0 320 321
0 43 :4 0 8f
:4 0 46 :2 0 47
:3 0 189 325 327
:3 0 18c 322 329
:2 0 32b 18f 32c
31f 32b 0 32d
191 0 33a 86
:3 0 87 :3 0 32e
32f 0 4b :3 0
2e :3 0 1f :2 0
193 331 334 b
:3 0 88 :3 0 196
330 338 :2 0 33a
19a 41f 23 :3 0
1f :2 0 33b 33c
0 41e 4b :3 0
2a :3 0 1f :2 0
19e 33e 341 90
:2 0 13 :2 0 1a3
343 345 :3 0 5b
:3 0 23 :3 0 6d
:3 0 6e :3 0 b
:4 0 91 1 :8 0
352 9 :3 0 70
:3 0 34d 34e 0
71 :3 0 34f 350
0 352 1a6 39c
72 :3 0 9 :3 0
70 :3 0 355 356
0 71 :3 0 357
358 0 392 3e
:3 0 3f :3 0 35a
35b 0 3e :3 0
4f :3 0 35d 35e
0 73 :2 0 2
:4 0 92 :2 0 51
:2 0 13 :2 0 1a9
363 365 :3 0 1ac
35f 367 35c 369
368 :2 0 41 :3 0
52 :3 0 36b 36c
0 43 :4 0 93
:4 0 46 :2 0 47
:3 0 1b0 370 372
:3 0 46 :2 0 76
:4 0 1b3 374 376
:3 0 46 :2 0 77
:4 0 1b6 378 37a
:3 0 46 :2 0 71
:3 0 1b9 37c 37e
:3 0 46 :2 0 78
:4 0 1bc 380 382
:3 0 46 :2 0 79
:3 0 7a :3 0 13
:2 0 7b :2 0 1bf
385 389 1c3 384
38b :3 0 1c6 36d
38d :2 0 38f 1c9
390 36a 38f 0
391 1cb 0 392
1cd 395 :3 0 395
0 395 394 392
393 :6 0 397 4
:3 0 1d0 399 1d2
398 397 :2 0 39a
1d4 :2 0 39c 0
39c 39b 352 39a
:6 0 415 1 :3 0
4b :3 0 2b :3 0
1f :2 0 1d6 39e
3a1 4b :3 0 8a
:2 0 23 :3 0 1f
:2 0 1d9 3a3 3a7
1de 3a4 3a9 :3 0
6d :3 0 5b :3 0
2b :3 0 6e :3 0
b :4 0 94 1
:8 0 3c6 95 :4 0
3b1 :3 0 88 :3 0
7c :2 0 1e3 3b4
3b5 :3 0 9 :3 0
70 :3 0 3b7 3b8
0 1f :2 0 3b9
3ba 0 3bc 1e6
3c3 9 :3 0 70
:3 0 3bd 3be 0
96 :2 0 3bf 3c0
0 3c2 1e8 3c4
3b6 3bc 0 3c5
0 3c2 0 3c5
1ea 0 3c6 1ed
410 72 :3 0 9
:3 0 70 :3 0 3c9
3ca 0 71 :3 0
3cb 3cc 0 406
3e :3 0 3f :3 0
3ce 3cf 0 3e
:3 0 4f :3 0 3d1
3d2 0 73 :2 0
2 :4 0 97 :2 0
51 :2 0 13 :2 0
1f0 3d7 3d9 :3 0
1f3 3d3 3db 3d0
3dd 3dc :2 0 41
:3 0 52 :3 0 3df
3e0 0 43 :4 0
98 :4 0 46 :2 0
47 :3 0 1f7 3e4
3e6 :3 0 46 :2 0
76 :4 0 1fa 3e8
3ea :3 0 46 :2 0
77 :4 0 1fd 3ec
3ee :3 0 46 :2 0
71 :3 0 200 3f0
3f2 :3 0 46 :2 0
78 :4 0 203 3f4
3f6 :3 0 46 :2 0
79 :3 0 7a :3 0
13 :2 0 7b :2 0
206 3f9 3fd 20a
3f8 3ff :3 0 20d
3e1 401 :2 0 403
210 404 3de 403
0 405 212 0
406 214 409 :3 0
409 0 409 408
406 407 :6 0 40b
6 :3 0 217 40d
219 40c 40b :2 0
40e 21b :2 0 410
0 410 40f 3c6
40e :6 0 412 1
:3 0 21d 413 3aa
412 0 414 21f
0 415 221 416
346 415 0 417
224 0 41e 2e
:3 0 99 :3 0 f
:3 0 226 419 41b
418 41c 0 41e
228 420 2cc 33a
0 421 0 41e
0 421 22c 0
470 3e :3 0 3f
:3 0 422 423 0
3e :3 0 4f :3 0
425 426 0 9a
:2 0 2 :4 0 9b
:2 0 51 :2 0 13
:2 0 22f 42b 42d
:3 0 232 427 42f
424 431 430 :2 0
41 :3 0 52 :3 0
433 434 0 43
:4 0 9c :4 0 46
:2 0 47 :3 0 236
438 43a :3 0 46
:2 0 76 :4 0 239
43c 43e :3 0 46
:2 0 80 :4 0 23c
440 442 :3 0 46
:2 0 4b :3 0 4c
:3 0 9 :3 0 70
:3 0 447 448 0
23f 446 44a 4d
:4 0 241 445 44d
244 444 44f :3 0
46 :2 0 83 :4 0
247 451 453 :3 0
46 :2 0 49 :4 0
24a 455 457 :3 0
46 :2 0 3 :3 0
24d 459 45b :3 0
46 :2 0 49 :4 0
250 45d 45f :3 0
253 435 461 :2 0
463 256 464 432
463 0 465 258
0 470 86 :3 0
9d :3 0 466 467
0 9 :3 0 70
:3 0 469 46a 0
3 :3 0 88 :3 0
25a 468 46e :2 0
470 25e 511 9
:3 0 9e :2 0 4
471 472 0 3e
:3 0 3f :3 0 474
475 0 3e :3 0
4f :3 0 477 478
0 73 :2 0 2
:4 0 9f :2 0 51
:2 0 13 :2 0 26c
47d 47f :3 0 26f
479 481 476 483
482 :2 0 41 :3 0
52 :3 0 485 486
0 43 :4 0 a0
:4 0 46 :2 0 47
:3 0 273 48a 48c
:3 0 276 487 48e
:2 0 4a7 41 :3 0
52 :3 0 490 491
0 43 :4 0 a1
:4 0 46 :2 0 9
:3 0 a2 :3 0 496
497 0 279 495
499 :3 0 46 :2 0
83 :4 0 27c 49b
49d :3 0 46 :2 0
9 :3 0 a3 :3 0
4a0 4a1 0 27f
49f 4a3 :3 0 282
492 4a5 :2 0 4a7
285 4a8 484 4a7
0 4a9 288 0
4b9 a4 :3 0 3d
:3 0 9 :3 0 a2
:3 0 a5 :3 0 9
:3 0 a3 :3 0 3
:3 0 a6 :4 0 a7
1 :a 0 4b5 :2 0
4b9 4ab 4b3 :2 0
8 :3 0 3d :3 0
4b7 :2 0 4b9 28a
4bb 28e 4ba 4b9
:2 0 50f 72 :3 0
9 :3 0 70 :3 0
4be 4bf 0 71
:3 0 4c0 4c1 0
507 3e :3 0 3f
:3 0 4c3 4c4 0
3e :3 0 4f :3 0
4c6 4c7 0 73
:2 0 2 :4 0 a8
:2 0 51 :2 0 13
:2 0 290 4cc 4ce
:3 0 293 4c8 4d0
4c5 4d2 4d1 :2 0
41 :3 0 52 :3 0
4d4 4d5 0 43
:4 0 a9 :4 0 46
:2 0 47 :3 0 297
4d9 4db :3 0 29a
4d6 4dd :2 0 4f7
41 :3 0 52 :3 0
4df 4e0 0 43
:4 0 77 :4 0 46
:2 0 71 :3 0 29d
4e4 4e6 :3 0 46
:2 0 78 :4 0 2a0
4e8 4ea :3 0 46
:2 0 79 :3 0 7a
:3 0 13 :2 0 7b
:2 0 2a3 4ed 4f1
2a7 4ec 4f3 :3 0
2aa 4e1 4f5 :2 0
4f7 2ad 4f8 4d3
4f7 0 4f9 2b0
0 507 a4 :3 0
3d :3 0 a5 :3 0
9 :3 0 a3 :3 0
3 :3 0 a6 :4 0
aa 1 :a 0 503
:2 0 507 4fb 501
:2 0 8 :3 0 3d
:3 0 505 :2 0 507
2b2 50a :3 0 50a
0 50a 509 507
508 :6 0 50c 1
:3 0 2b7 50e 2b9
50d 50c :2 0 50f
2bb :2 0 511 2be
511 510 470 50f
:6 0 512 :2 0 2
14 511 515 :3 0
514 512 516 :8 0

2ea
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
42 1 40 1
47 1 4c 1
51 1 56 1
5b 1 60 1
65 1 6c 1
6a 1 71 1
77 1 7d 1
83 1 89 1
8f 1 94 1
9b 1 99 1
a0 1 a6 1
ac 1 b2 1
b8 1 be 1
c4 1 ca 1
d0 1 d6 1
db 1 e0 1
e6 1 ec 1
f2 1 f8 1
fd 1 103 1
109 1 10f 1
11c 1 128 2
12b 12d 2 130
132 2 134 136
2 138 13a 2
13c 13e 1 144
2 146 147 2
140 149 2 14b
14d 2 14f 151
2 153 155 2
157 159 2 15b
15d 4 124 12a
12f 15f 1 161
1 163 2 16d
16f 3 16b 16c
171 2 17a 17c
2 179 17e 1
180 1 182 2
1d9 1de 2 1ef
1f1 3 1ed 1ee
1f3 2 1fc 1fe
2 200 202 2
204 206 2 208
20a 2 20c 20e
3 213 214 215
2 210 217 2
1fb 219 1 21b
1 21d 2 1e6
21e 1 222 1
1e1 1 226 1
231 2 22d 231
2 23d 23f 3
23b 23c 241 2
24a 24c 2 24e
250 2 252 254
1 25c 2 25e
25f 2 256 261
2 263 265 2
267 269 2 26b
26d 2 26f 271
2 249 273 1
275 1 277 2
281 283 3 27f
280 285 2 28e
290 2 28d 292
1 294 1 296
3 29d 29e 29f
3 278 297 2a1
1 2a3 1a 2a7
2a8 2a9 2aa 2ab
2ac 2ad 2ae 2af
2b0 2b1 2b2 2b3
2b4 2b5 2b6 2b7
2b8 2b9 2ba 2bb
2bc 2bd 2be 2bf
2c0 2 2c5 2c6
1 2ca 2 2c8
2ca 2 2d5 2d7
3 2d3 2d4 2d9
2 2e2 2e4 2
2e6 2e8 2 2ea
2ec 1 2f2 2
2f4 2f5 2 2ee
2f7 2 2f9 2fb
2 2fd 2ff 2
301 303 2 305
307 2 2e1 309
1 30b 1 30d
2 317 319 3
315 316 31b 2
324 326 2 323
328 1 32a 1
32c 2 332 333
3 335 336 337
3 30e 32d 339
2 33f 340 1
344 2 342 344
2 34c 351 2
362 364 3 360
361 366 2 36f
371 2 373 375
2 377 379 2
37b 37d 2 37f
381 3 386 387
388 2 383 38a
2 36e 38c 1
38e 1 390 2
359 391 1 395
1 354 1 399
2 39f 3a0 2
3a5 3a6 1 3a8
2 3a2 3a8 1
3b3 2 3b2 3b3
1 3bb 1 3c1
2 3c3 3c4 2
3b0 3c5 2 3d6
3d8 3 3d4 3d5
3da 2 3e3 3e5
2 3e7 3e9 2
3eb 3ed 2 3ef
3f1 2 3f3 3f5
3 3fa 3fb 3fc
2 3f7 3fe 2
3e2 400 1 402
1 404 2 3cd
405 1 409 1
3c8 1 40d 1
410 1 413 2
39c 414 1 416
1 41a 3 33d
417 41d 2 41f
420 2 42a 42c
3 428 429 42e
2 437 439 2
43b 43d 2 43f
441 1 449 2
44b 44c 2 443
44e 2 450 452
2 454 456 2
458 45a 2 45c
45e 2 436 460
1 462 1 464
3 46b 46c 46d
d 164 183 186
189 18c 18f 192
229 2a4 2c3 421
465 46f 2 47c
47e 3 47a 47b
480 2 489 48b
2 488 48d 2
494 498 2 49a
49c 2 49e 4a2
2 493 4a4 2
48f 4a6 1 4a8
3 4a9 4b4 4b8
1 473 2 4cb
4cd 3 4c9 4ca
4cf 2 4d8 4da
2 4d7 4dc 2
4e3 4e5 2 4e7
4e9 3 4ee 4ef
4f0 2 4eb 4f2
2 4e2 4f4 2
4de 4f6 1 4f8
4 4c2 4f9 502
506 1 50a 1
4bd 2 4bb 50e
2b 1b 22 29
30 37 3e 45
4a 4f 54 59
5e 63 68 6f
75 7b 81 87
8d 92 97 9e
a4 aa b0 b6
bc c2 c8 ce
d4 d9 de e4
ea f0 f6 fb
101 107 10d 114

1
4
0 
515
0
1
14
8
2f
0 1 2 1 4 1 6 1
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
2 0 1
83 1 0
be 1 0
3 1 0
f2 1 0
56 1 0
16 1 0
ec 1 0
1d 1 0
b2 1 0
a0 1 0
40 1 0
d0 1 0
94 1 0
c4 1 0
109 1 0
60 1 0
71 1 0
47 1 0
51 1 0
e0 1 0
7d 1 0
b8 1 0
99 1 0
db 1 0
89 1 0
e6 1 0
32 1 0
f8 1 0
4c 1 0
fd 1 0
6a 1 0
8f 1 0
65 1 0
39 1 0
2b 1 0
7 1 0
d6 1 0
ca 1 0
5b 1 0
24 1 0
77 1 0
ac 1 0
a6 1 0
10f 1 0
103 1 0
0

/
SHOW ERRORS FUNCTION SP_ACPT_ETC_ASSIGN;
ALTER FUNCTION SP_ACPT_ETC_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Accept ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST DATES
    3 - ETC + FORECAST DATES
****************************************************************************************/
Prompt == FUNCTION SP_ACPT_ETC_WBS ==
CREATE OR REPLACE FUNCTION SP_ACPT_ETC_WBS wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
eb
2 :e:
1FUNCTION:
1SP_ACPT_ETC_WBS:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PRJ_ASSIGNMENT_ID:
132:
1H_PROJECT_ID:
1H_RANK:
1200:
1H_REC_USER:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_TA_START_DT:
1TIMESTAMP:
1H_TA_FINISH_DT:
1H_START_DATE:
1H_FINISH_DATE:
1H_START_DT:
1H_FINISH_DT:
1H_FINISH_D:
1DATE:
1H_WEEK_OF:
1H_LAST_SUBMITTED:
1H_TASK_ID:
1H_TSK_ASSIGNMENT_ID:
1H_BIT_FLAG:
1H_BITFLAG:
10:
1H_CONTOUR:
1H_EFFORT:
1H_REMAINING:
1H_TOTAL:
1H_TYPE:
1H_PASSED:
1H_CONSTR_DT:
1H_DAYOFYEAR:
1H_FINISH_TIME:
18:
1H_MINUTE:
1H_CONSTR_TYPE:
1H_ETC:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_SD:
1H_FD:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_NOT_EFFORT_PA:
1H_FF_FLAG:
1NULL_RETURN:
1LONG:
1ORA_TEMP_SC_STATE:
1CURSOR:
1CAWTSK:
1PROJECT_ID:
1ELEMENT_ID:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1COALESCE:
1PLANNED_START:
1SCHED_START:
1FORECAST_FINISH:
1PLANNED_FINISH:
1SCHED_FINISH:
1TMT_WBS:
1RANK:
1TYPE_ID:
1PMO_CNST:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1WORK_TODATE:
1ETC:
1SELECT PROJECT_ID, ELEMENT_ID, SCHED_EFFORT+PLANNED_EFFORT,:n         CASE WH+
1EN FORECAST_START IS NULL THEN COALESCE(PLANNED_START, SCHED_START) ELSE FORE+
1CAST_START END,:n         CASE WHEN FORECAST_FINISH IS NULL THEN COALESCE(PLA+
1NNED_FINISH, SCHED_FINISH) ELSE FORECAST_FINISH END:n         FROM TMT_WBS WH+
1ERE RANK LIKE h_rank AND TYPE_ID IN (PMO_CNST.SC_TASK,PMO_CNST.SC_TASK_TYPE1,+
1PMO_CNST.SC_TASK_TYPE2,PMO_CNST.SC_TASK_TYPE3,PMO_CNST.SC_MILESTONE,PMO_CNST.+
1SC_PERSONAL_TASK,PMO_CNST.SC_ACTIVE_ADM_TASK,PMO_CNST.SC_INACTIVE_ADM_TASK,PM+
1O_CNST.SC_WBS_CHANGE_REQUEST_TASK,PMO_CNST.SC_WBS_ACTION_ITEM_TASK,PMO_CNST.S+
1C_WBS_RISK_TASK,PMO_CNST.SC_WBS_ISSUE_TASK,PMO_CNST.SC_WBS_REQUIREMENT_TASK,P+
1MO_CNST.SC_WBS_DEFECT_TASK,PMO_CNST.SC_WBS_SERVICE_REQUEST_TASK):n         AN+
1D (((SCHED_EFFORT+PLANNED_EFFORT) > 0 AND ((SCHED_EFFORT+PLANNED_EFFORT-WORK_+
1TODATE) <> ETC)) OR:n         (FORECAST_START IS NOT NULL OR FORECAST_FINISH +
1IS NOT NULL)) ORDER BY COALESCE(PLANNED_START, SCHED_START):
1CAWASS:
1TSK_ASSIGNMENT_ID:
1PROJECT_ASSIGNMENT_ID:
1SCHED_WORK:
1PLANNED_WORK:
1C_CONTOUR:
1LAST_SUBMITTED:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1BIT_FLAG:
1MILESTONE_PERCENT:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1TASK_ID:
1SELECT:n         TSK_ASSIGNMENT_ID,:n         PROJECT_ASSIGNMENT_ID,:n       +
1  SCHED_WORK+PLANNED_WORK,:n         FORECAST_START,:n         FORECAST_FINIS+
1H,:n         CASE WHEN h_bitflag = 2 AND FORECAST_START IS NuLL THEN 0 ELSE E+
1TC END,:n         SCHED_WORK+PLANNED_WORK - WORK_TODATE,:n         ETC,:n    +
1     C_CONTOUR,:n         LAST_SUBMITTED,:n         CASE WHEN FORECAST_FINISH+
1 IS NOT NuLL AND FORECAST_START IS NuLL AND FORECAST_FINISH BETWEEN COALESCE(+
1PLANNED_START, SCHED_START) AND COALESCE(PLANNED_FINISH, SCHED_FINISH) THEN 1+
1 ELSE 0 END,:n         UNRESOLVED_START,:n         UNRESOLVED_FINISH,:n      +
1   BILLABLE,:n         CAPITAL_EXPENSE,:n         REGULAR_COST,:n         REG+
1ULAR_RATE,:n         BIT_FLAG,:n         MILESTONE_PERCENT,:n         RESOURC+
1E_ID,:n         RESOURCE_TYPE,:n         WORK_TODATE:n         FROM TASK_ASSI+
1GNMENTS:n         WHERE PROJECT_ID = h_project_id:n         AND TASK_ID = h_t+
1ask_id:n         AND (((SCHED_WORK+PLANNED_WORK) > 0:n         AND ((SCHED_WO+
1RK + PLANNED_WORK - WORK_TODATE) <> ETC)):n         OR (FORECAST_START IS NOT+
1 NULL OR FORECAST_FINISH IS NOT NULL)):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ACPT_ETC_WBS(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1106:
1+:
1FPUT:
1               ENTER:: SP_ACPT_ETC_WBS(107) :: cplan.sql(18312) :: :
1RTRIM:
1SELECT RTRIM(RANK), TYPE_ID INTO h_rank, h_type:n      FROM TMT_WBS WHERE ELE+
1MENT_ID = id/*HOST(h_id)*/:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1123:
1           EXCEPTION:: SP_ACPT_ETC_WBS(124) :: cplan.sql(18329) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_SUCCESS:
1IS NOT NULL:
1%:
1-:
1OPEN:
1LOOP:
1FOUND:
1100:
1!=:
1EXIT:
12:
1FC_ACPT_DURATION:
1FC_ACPT_EFFORT:
1ELSIF:
1CANNOT_ACCEPT_FROM_PROJECT_AFF:
1CLOSE:
1228:
1           EXCEPTION:: SP_ACPT_ETC_WBS(229) :: cplan.sql(18434) :: :
1>:
1CONSTRAINT_DT:
1CONSTRAINT_TYPE:
1SELECT CONSTRAINT_DT, CONSTRAINT_TYPE, FORECAST_START, FORECAST_FINISH:n     +
1             INTO h_constr_DT, h_constr_type, h_start_DT, h_finish_DT:n      +
1            FROM TMT_WBS WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_t+
1ask_id:
1250:
1           EXCEPTION:: SP_ACPT_ETC_WBS(251) :: cplan.sql(18456) :: :
1TO_DATE:
1UPDATE TMT_WBS SET:n                        CONSTRAINT_DT =:n                +
1        CASE:n                        WHEN h_constr_type IN (1,2,3,4) AND TO_+
1DATE(SubStr(h_constr_DT, 1, 10)) < TO_DATE(SubStr(h_finish_DT, 1, 10)) THEN h+
1_finish_DT:n                        WHEN h_constr_type IN (0,5,6,7) THEN h_fi+
1nish_DT:n                        ELSE h_constr_DT:n                        EN+
1D,:n                        CONSTRAINT_TYPE =:n                        CASE:n+
1                        WHEN h_constr_type IN (1,2,3,4) AND TO_DATE(SubStr(h_+
1constr_DT, 1, 10)) < TO_DATE(SubStr(h_finish_DT, 1, 10)) THEN 2:n            +
1            WHEN h_constr_type IN (0,5,6,7) THEN 2:n                        E+
1LSE h_constr_type:n                        END:n                        WHERE+
1 PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1TRUE:
1284:
1           EXCEPTION:: SP_ACPT_ETC_WBS(285) :: cplan.sql(18490) :: :
1UPDATE TMT_WBS SET CONSTRAINT_DT = h_finish_DT, CONSTRAINT_TYPE = 2:n        +
1                WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1302:
1           EXCEPTION:: SP_ACPT_ETC_WBS(303) :: cplan.sql(18508) :: :
1IS NULL:
1UPDATE TMT_WBS SET:n                        CONSTRAINT_DT =:n                +
1        CASE:n                        WHEN h_constr_type IN (0,5,6,7) AND TO_+
1DATE(SubStr(h_constr_DT, 1, 10)) > TO_DATE(SubStr(h_start_DT, 1, 10)) THEN h_+
1start_DT:n                        WHEN h_constr_type IN (1,2,3,4) THEN h_star+
1t_DT:n                        ELSE h_constr_DT:n                        END,+
1:n                        CONSTRAINT_TYPE =:n                        CASE:n  +
1                      WHEN h_constr_type IN (0,5,6,7) AND TO_DATE(SubStr(h_co+
1nstr_DT, 1, 10)) > TO_DATE(SubStr(h_start_DT, 1, 10)) THEN 6:n               +
1         WHEN h_constr_type IN (1,2,3,4) THEN 6:n                        ELSE+
1 h_constr_type:n                        END:n                        WHERE PR+
1OJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1335:
1           EXCEPTION:: SP_ACPT_ETC_WBS(336) :: cplan.sql(18541) :: :
1UPDATE TMT_WBS SET CONSTRAINT_DT = h_start_DT, CONSTRAINT_TYPE = 6:n         +
1               WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1353:
1           EXCEPTION:: SP_ACPT_ETC_WBS(354) :: cplan.sql(18559) :: :
1372:
1           EXCEPTION:: SP_ACPT_ETC_WBS(373) :: cplan.sql(18578) :: :
1NLEN:
1LENGTH:
1NOT:
1MOD:
14:
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1INVALID_RANK_LIKE:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_PROPOSED_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_PROP+
1OSED_BIT):n            WHERE PROJECT_ID = h_project_id AND RANK LIKE h_rank:
1407:
1           EXCEPTION:: SP_ACPT_ETC_WBS(408) :: cplan.sql(18613) :: :
1FC_ROLLUP:
1424:
1       RETURN_STATUS:: SP_ACPT_ETC_WBS(425) :: cplan.sql(18630) :: :
1STATE:: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1431:
1           EXCEPTION:: SP_ACPT_ETC_WBS(432) :: cplan.sql(18637) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1443:
1           EXCEPTION:: SP_ACPT_ETC_WBS(444) :: cplan.sql(18649) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
8df
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a0 f4 b4 bf
c8 :3b a0 12a bd b7 11 a4 b1
a0 f4 b4 bf c8 :30 a0 12a bd
b7 11 a4 b1 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:2 a0 d a0 51 d :8 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 7e b4 2e :2 5a a 10
:3 a0 7e 6e b4 2e :2 51 a5 b
d a0 7e 51 b4 2e d :2 a0
e9 dd b3 :7 a0 e9 d3 5 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a a0 2b
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e :3 a0 6b d :7 a0 a5
b d :2 a0 6b a0 d :3 a0 51
a5 b 7e 51 b4 2e d b7
19 3c b7 a0 4d d a0 4d
d :2 a0 e9 dd b3 :18 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c :1c a0 a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :3 a0 51 a5 b 7e 51 b4
2e d a0 b7 :2 a0 51 a5 b
a0 7e a0 6b b4 2e :3 a0 51
a5 b 7e 51 b4 2e d b7
:2 19 3c b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 a0 4d d
a0 4d d :d a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 7e
b4 2e 5a a0 7e b4 2e 5a
:1b a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c a0 b7
a0 7e b4 2e :2 5a a0 7e b4
2e :2 5a a 10 a0 7e b4 2e
5a :1b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :8 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:2 19 3c b7 19 3c b7 :2 19 3c
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b :2 7e 51 b4 2e
b4 2e 5a a 10 a3 a0 1c
51 81 b0 a0 7e b4 2e 5a
:4 a0 a5 b 51 a5 b d 51
7e 51 b4 2e a0 7e 51 b4
2e a 10 :2 a0 7e 51 b4 2e
d b7 19 3c b7 19 3c a0
7e 51 b4 2e 7e b4 2e :2 a0
7e 51 b4 2e 5a 7e 51 b4
2e 52 10 :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 a4 b1
11 4f :b a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 a5 b d b7
19 3c b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b d a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 51
a5 b d b7 :2 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :2 a0 6b :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e :2 a0 6b b4 2e 7e 6e b4
2e 7e :2 a0 6b b4 2e a5 57
b7 19 3c :9 a0 12a e9 dd :2 a0
65 b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c :7 a0 12a e9 dd :2 a0 65 b7
a4 b1 11 4f b7 a6 9 a4
b1 11 68 4f 1d 17 b5 
8df
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
133 122 126 12e 101 14b 13a 13e
146 121 167 156 15a 162 11e 17f
16e 172 17a 155 19b 18a 18e 196
152 1b3 1a2 1a6 1ae 189 1cf 1be
1c2 1ca 186 1e7 1d6 1da 1e2 1bd
203 1f2 1f6 1fe 1ba 21f 20a 20e
211 212 21a 1f1 23c 22a 1ee 22e
22f 237 229 259 247 226 24b 24c
254 246 275 264 268 243 270 263
291 280 284 260 28c 27f 2ad 29c
2a0 27c 2a8 29b 2c9 2b8 2bc 298
2c4 2b7 2e5 2d4 2d8 2b4 2e0 2d3
301 2f0 2f4 2d0 2fc 2ef 31d 30c
310 2ec 318 30b 339 328 32c 334
308 351 340 344 34c 327 36e 35c
324 360 361 369 35b 38a 379 37d
358 385 378 3a6 395 399 375 3a1
394 3c2 3b1 3b5 391 3bd 3b0 3de
3cd 3d1 3ad 3d9 3cc 3fa 3e9 3ed
3c9 3f5 3e8 416 405 409 411 3e5
42e 41d 421 429 404 44a 439 43d
401 445 438 466 455 459 435 461
454 482 471 475 451 47d 470 49e
48d 491 46d 499 48c 4ba 4a9 4ad
489 4b5 4a8 4d6 4c5 4c9 4d1 4a5
4ee 4dd 4e1 4e9 4c4 50a 4f9 4fd
4c1 505 4f8 526 515 519 4f5 521
514 542 531 535 511 53d 530 55e
54d 551 52d 559 54c 57a 569 56d
549 575 568 596 585 589 591 565
5b1 59d 5a1 5a9 5ac 584 5b8 5bc
581 5cd 5d0 5d4 5d8 5dc 5e0 5e4
5e8 5ec 5f0 5f4 5f8 5fc 600 604
608 60c 610 614 618 61c 620 624
628 62c 630 634 638 63c 640 644
648 64c 650 654 658 65c 660 664
668 66c 670 674 678 67c 680 684
688 68c 690 694 698 69c 6a0 6a4
6a8 6ac 6b0 6b4 6b8 6bc 6c0 6cc
6d1 6d3 6df 6e3 6e5 6e9 6fa 6fb
6fe 702 706 70a 70e 712 716 71a
71e 722 726 72a 72e 732 736 73a
73e 742 746 74a 74e 752 756 75a
75e 762 766 76a 76e 772 776 77a
77e 782 786 78a 78e 792 796 79a
79e 7a2 7a6 7aa 7ae 7b2 7b6 7ba
7be 7c2 7ce 7d3 7d5 7e1 7e5 803
7eb 7ef 7f3 7f6 7fe 7ea 80a 80e
7e7 812 816 81a 81d 822 823 1
825 82a 82e 832 835 83a 83e 842
845 84a 84b 84d 852 855 859 85a
85f 864 867 86c 86d 872 875 879
87a 87f 882 887 888 88d 890 895
896 89b 89e 8a2 8a6 8aa 8ab 8ad
8b2 8b3 8b5 8b6 8bb 8be 8c3 8c4
8c9 8cc 8d1 8d2 8d7 8da 8de 8df
8e4 8e7 8ec 8ed 8f2 8f5 8fa 8fb
900 901 906 908 90c 90f 913 917
91a 91e 922 925 928 92d 930 933
936 937 93c 93d 1 93f 944 948
94c 94f 954 959 95c 960 961 966
967 96c 96e 972 975 979 97d 981
985 989 98d 991 994 998 99c 9a0
9a4 9a8 9ac 9b0 9b4 9b8 9c4 9c8
9cc 9cf 9d3 9d7 9d9 1 9dd 9e1
9e5 9e8 9ec 9f0 9f4 9f8 9fb 9ff
a03 a06 a09 a0e a11 a14 a17 a18
a1d a1e 1 a20 a25 a29 a2d a30
a35 a3a a3d a41 a42 a47 a4a a4f
a50 a55 a58 a5d a5e a63 a66 a6a
a6b a70 a73 a78 a79 a7e a81 a85
a89 a8c a8f a90 a92 a93 a98 a99
a9e aa0 aa4 aa7 aa9 aad aaf abb
abd abf ac0 ac5 ac9 acb ad7 ad9
add ae1 ae4 ae8 aeb aef af2 af3
af8 afb aff b02 b03 b08 b0b 1
b0e b13 b17 b1b b1f b22 b27 b28
b2d b30 b33 b34 b36 b3a b3e b41
b44 b45 b4a b4e b52 b56 b5b b5f
b60 b64 b68 b6c b70 b74 b78 b7c
b81 b86 b8a b8e b92 b97 b9b b9f
ba2 ba5 ba9 bab baf bb3 bb6 bb9
bbd bbf bc3 bc7 bca bce bd2 bd5
bd9 bdc be0 be3 be4 be9 bec bf0
bf6 bf8 bfc bff c03 c07 c0a c0b
c0d c10 c13 c14 c19 c1d c21 c24
c25 c27 c2a c2d c2e c33 c37 c3b
c3f c42 c46 c4a c4e c52 c56 c5a
c5e c62 c63 c65 c69 c6d c71 c74
c78 c7c c80 c84 c88 c8b c8c c8e
c91 c94 c95 c9a c9e ca0 ca4 ca7
ca9 cad cae cb2 cb6 cb7 cbb cbf
cc3 cc8 ccc ccd cd1 cd5 cd9 cdd
ce1 ce5 ce9 ced cf1 cf5 cf9 cfd
d01 d05 d09 d0d d11 d15 d19 d1d
d21 d25 d29 d2d d32 d37 d3b d3f
d43 d48 d4c d50 d53 d56 d5a d5c
d60 d64 d67 d6a d6e d70 d74 d78
d7b d7f d83 d86 d8a d8d d91 d94
d95 d9a d9d da1 da7 da9 dad db0
db4 db8 dbc dc0 dc4 dc8 dcc dd0
dd4 dd8 ddc de0 de4 de8 dec df0
df4 df8 dfc e00 e04 e08 e0c e10
e14 e18 e1c e20 e21 e23 e27 e2b
e2f e32 e33 e35 e38 e3b e3c e41
e45 e49 e4d e50 e51 e53 e56 e59
e5a e5f e63 e67 e69 e6d e71 e74
e75 e77 e7b e7e e82 e85 e86 e8b
e8f e93 e97 e9a e9b e9d ea0 ea3
ea4 ea9 ead eaf eb3 eb7 eba ebc
ec0 ec7 ecb ecf ed4 ed6 eda ede
ee1 ee5 ee9 eeb 1 eef ef3 ef7
efa efe f02 f06 f0a f0d f11 f15
f18 f1b f20 f23 f26 f29 f2a f2f
f30 1 f32 f37 f3b f3f f42 f47
f4c f4f f53 f54 f59 f5c f61 f62
f67 f6a f6f f70 f75 f78 f7c f7d
f82 f85 f8a f8b f90 f93 f97 f9b
f9e fa1 fa2 fa4 fa5 faa fab fb0
fb2 fb6 fb9 fbb fbf fc1 fcd fcf
fd1 fd2 fd7 fdb fdd fe9 feb fef
ff3 ff6 ff7 ff9 ffc fff 1000 1005
1008 100c 1010 1013 1014 1016 1019 101c
101d 1022 1 1025 102a 102e 102f 1033
1037 1038 103c 1040 1044 1048 104c 1050
1054 1058 105c 1060 1064 1068 106c 1070
107c 1080 1084 1087 108b 108f 1091 1
1095 1099 109d 10a0 10a4 10a8 10ac 10b0
10b3 10b7 10bb 10be 10c1 10c6 10c9 10cc
10cf 10d0 10d5 10d6 1 10d8 10dd 10e1
10e5 10e8 10ed 10f2 10f5 10f9 10fa 10ff
1102 1107 1108 110d 1110 1115 1116 111b
111e 1122 1123 1128 112b 1130 1131 1136
1139 113d 1141 1144 1147 1148 114a 114b
1150 1151 1156 1158 115c 115f 1161 1165
1167 1173 1175 1177 1178 117d 1181 1183
118f 1191 1195 1198 1199 119e 11a1 11a5
11a8 11a9 11ae 11b1 11b5 11b9 11bd 11c1
11c5 11c9 11cd 11d1 11d5 11d9 11dd 11e1
11e5 11e9 11ed 11f1 11f5 11f9 11fd 1201
1205 1209 120d 1211 1215 1219 121d 1229
122d 1232 1236 1239 123a 123f 1243 1247
124a 124d 1251 1253 1257 125b 125e 1261
1265 1267 126b 126f 1272 1274 1 1278
127c 1280 1283 1287 128b 128f 1293 1296
129a 129e 12a1 12a4 12a9 12ac 12af 12b2
12b3 12b8 12b9 1 12bb 12c0 12c4 12c8
12cb 12d0 12d5 12d8 12dc 12dd 12e2 12e5
12ea 12eb 12f0 12f3 12f8 12f9 12fe 1301
1305 1306 130b 130e 1313 1314 1319 131c
1320 1324 1327 132a 132b 132d 132e 1333
1334 1339 133b 133f 1342 1344 1348 134a
1356 1358 135a 135b 1360 1364 1366 1372
1374 1376 137a 137e 1382 1386 138a 138e
1392 1396 13a2 13a6 13ab 13af 13b2 13b3
13b8 13bc 13c0 13c3 13c6 13ca 13cc 13d0
13d4 13d7 13da 13de 13e0 13e4 13e8 13eb
13ed 1 13f1 13f5 13f9 13fc 1400 1404
1408 140c 140f 1413 1417 141a 141d 1422
1425 1428 142b 142c 1431 1432 1 1434
1439 143d 1441 1444 1449 144e 1451 1455
1456 145b 145e 1463 1464 1469 146c 1471
1472 1477 147a 147e 147f 1484 1487 148c
148d 1492 1495 1499 149d 14a0 14a3 14a4
14a6 14a7 14ac 14ad 14b2 14b4 14b8 14bb
14bd 14c1 14c3 14cf 14d1 14d3 14d4 14d9
14dd 14df 14eb 14ed 14ef 14f3 14f7 14fa
14fe 1500 1504 1507 1508 150d 1510 1513
1517 151a 151b 1520 1523 1 1526 152b
152f 1532 1533 1538 153b 153f 1543 1547
154b 154f 1553 1557 155b 155f 1563 1567
156b 156f 1573 1577 157b 157f 1583 1587
158b 158f 1593 1597 159b 159f 15a3 15a7
15b3 15b7 15bc 15c0 15c3 15c4 15c9 15cd
15d1 15d4 15d7 15db 15dd 15e1 15e5 15e8
15eb 15ef 15f1 15f5 15f9 15fc 15fe 1
1602 1606 160a 160d 1611 1615 1619 161d
1620 1624 1628 162b 162e 1633 1636 1639
163c 163d 1642 1643 1 1645 164a 164e
1652 1655 165a 165f 1662 1666 1667 166c
166f 1674 1675 167a 167d 1682 1683 1688
168b 168f 1690 1695 1698 169d 169e 16a3
16a6 16aa 16ae 16b1 16b4 16b5 16b7 16b8
16bd 16be 16c3 16c5 16c9 16cc 16ce 16d2
16d4 16e0 16e2 16e4 16e5 16ea 16ee 16f0
16fc 16fe 1700 1704 1708 170c 1710 1714
1718 171c 1720 172c 1730 1735 1739 173c
173d 1742 1746 174a 174d 1750 1754 1756
175a 175e 1761 1764 1768 176a 176e 1772
1775 1777 1 177b 177f 1783 1786 178a
178e 1792 1796 1799 179d 17a1 17a4 17a7
17ac 17af 17b2 17b5 17b6 17bb 17bc 1
17be 17c3 17c7 17cb 17ce 17d3 17d8 17db
17df 17e0 17e5 17e8 17ed 17ee 17f3 17f6
17fb 17fc 1801 1804 1808 1809 180e 1811
1816 1817 181c 181f 1823 1827 182a 182d
182e 1830 1831 1836 1837 183c 183e 1842
1845 1847 184b 184d 1859 185b 185d 185e
1863 1867 1869 1875 1877 1879 187d 1881
1884 1886 188a 188e 1891 1893 1897 189a
189c 18a0 18a4 18a7 18a9 18ad 18b4 18b8
18bc 18c1 18c3 18c7 18cb 18ce 18d2 18d6
18d8 1 18dc 18e0 18e4 18e7 18eb 18ef
18f3 18f7 18fa 18fe 1902 1905 1908 190d
1910 1913 1916 1917 191c 191d 1 191f
1924 1928 192c 192f 1934 1939 193c 1940
1941 1946 1949 194e 194f 1954 1957 195c
195d 1962 1965 1969 196a 196f 1972 1977
1978 197d 1980 1984 1988 198b 198e 198f
1991 1992 1997 1998 199d 199f 19a3 19a6
19a8 19ac 19ae 19ba 19bc 19be 19bf 19c4
19c8 19ca 19d6 19d8 19dc 19e0 19e3 19e4
19e6 19e9 19ec 19ed 19f2 19f5 19f9 19fd
1a00 1a01 1a03 1a06 1a09 1a0c 1a0d 1a12
1a13 1a18 1 1a1b 1a38 1a24 1a28 1a30
1a33 1a23 1a3f 1a20 1a43 1a44 1a49 1a4c
1a50 1a54 1a58 1a5c 1a5d 1a5f 1a62 1a63
1a65 1a69 1a6c 1a6f 1a72 1a73 1a78 1a7c
1a7f 1a82 1a83 1 1a88 1a8d 1a91 1a95
1a98 1a9b 1a9c 1aa1 1aa5 1aa7 1aab 1aae
1ab0 1ab4 1ab7 1abb 1abe 1ac1 1ac2 1ac7
1aca 1acb 1ad0 1ad4 1ad8 1adb 1ade 1adf
1ae4 1ae7 1aea 1aed 1aee 1 1af3 1af8
1afc 1b00 1b03 1b07 1b0b 1b0e 1b12 1b16
1b17 1b1c 1b1e 1b22 1b25 1b27 1b2b 1b2d
1b39 1b3b 1b3f 1b43 1b47 1b4b 1b4f 1b53
1b57 1b5b 1b5f 1b63 1b67 1b73 1b77 1b7c
1b80 1b83 1b84 1b89 1b8d 1b91 1b94 1b97
1b9b 1b9d 1ba1 1ba5 1ba8 1bab 1baf 1bb1
1bb5 1bb9 1bbc 1bbe 1 1bc2 1bc6 1bca
1bcd 1bd1 1bd5 1bd9 1bdd 1be0 1be4 1be8
1beb 1bee 1bf3 1bf6 1bf9 1bfc 1bfd 1c02
1c03 1 1c05 1c0a 1c0e 1c12 1c15 1c1a
1c1f 1c22 1c26 1c27 1c2c 1c2f 1c34 1c35
1c3a 1c3d 1c42 1c43 1c48 1c4b 1c4f 1c50
1c55 1c58 1c5d 1c5e 1c63 1c66 1c6a 1c6e
1c71 1c74 1c75 1c77 1c78 1c7d 1c7e 1c83
1c85 1c89 1c8c 1c8e 1c92 1c94 1ca0 1ca2
1ca4 1ca5 1caa 1cae 1cb0 1cbc 1cbe 1cc2
1cc6 1cca 1ccb 1ccd 1cd1 1cd3 1cd7 1cda
1cdc 1ce0 1ce3 1ce7 1ceb 1cee 1cef 1cf1
1cf4 1cf7 1cf8 1cfd 1d01 1d05 1d08 1d0c
1d10 1d13 1d17 1d1b 1d1d 1d21 1d25 1d28
1d29 1d2b 1d2e 1d31 1d32 1d37 1d3b 1d3f
1d42 1d46 1d4a 1d4d 1d4e 1d50 1d54 1d56
1d5a 1d5e 1d61 1d65 1d69 1d6c 1d70 1d74
1d77 1d7a 1d7f 1d82 1d85 1d88 1d89 1d8e
1d8f 1 1d91 1d96 1d9a 1d9e 1da1 1da6
1dab 1dae 1db2 1db3 1db8 1dbb 1dc0 1dc1
1dc6 1dc9 1dce 1dcf 1dd4 1dd7 1ddb 1ddf
1de3 1de7 1dea 1deb 1ded 1df2 1df3 1df5
1df6 1dfb 1dfe 1e03 1e04 1e09 1e0c 1e11
1e12 1e17 1e1a 1e1e 1e1f 1e24 1e27 1e2c
1e2d 1e32 1e33 1e38 1e3a 1e3e 1e41 1e45
1e49 1e4c 1e50 1e54 1e57 1e5b 1e5f 1e60
1e65 1e67 1e6b 1e6f 1e72 1e76 1e7a 1e7d
1e81 1e85 1e88 1e8b 1e90 1e93 1e96 1e99
1e9a 1e9f 1ea0 1 1ea2 1ea7 1eab 1eaf
1eb2 1eb7 1ebc 1ebf 1ec3 1ec4 1ec9 1eca
1ecf 1ed3 1ed7 1eda 1edf 1ee4 1ee7 1eeb
1eef 1ef2 1ef3 1ef8 1efb 1f00 1f01 1f06
1f09 1f0d 1f11 1f14 1f15 1f1a 1f1b 1f20
1f22 1f26 1f29 1f2d 1f31 1f35 1f39 1f3d
1f41 1f45 1f49 1f4d 1f59 1f5e 1f62 1f66
1f6a 1f6e 1f70 1f71 1f76 1 1f7a 1f7e
1f82 1f85 1f89 1f8d 1f91 1f95 1f98 1f9c
1fa0 1fa3 1fa6 1fab 1fae 1fb1 1fb4 1fb5
1fba 1fbb 1 1fbd 1fc2 1fc6 1fca 1fcd
1fd2 1fd7 1fda 1fde 1fdf 1fe4 1fe5 1fea
1fee 1ff2 1ff5 1ffa 1fff 2002 2006 2007
200c 200f 2014 2015 201a 201d 2021 2025
2028 202b 202c 202e 202f 2034 2035 203a
203c 2040 2043 2047 204b 204f 2053 2057
205b 205f 206b 2070 2074 2078 207c 2080
2082 2086 2088 2094 2096 2098 2099 209e
20a2 20a4 20b0 20b4 20b6 20b7 20c0 
8df
2
0 1 a 6 9 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 b 14 13 :2 b :2 4
f 18 17 :2 f :2 4 d 16 15
:2 d :2 4 f 18 17 :2 f :2 4 :3 12
:2 4 :3 13 :2 4 :3 11 :2 4 :3 12 :2 4 :3 f
:2 4 :3 10 :2 4 :3 f :2 4 :3 e :2 4 :3 15
:2 4 e 17 16 :2 e :2 4 18 21
20 :2 18 :2 4 f 18 17 :2 f :2 4
:2 e 1d e :2 4 :2 e 1d e :2 4
:2 d 1c d :2 4 :2 10 1f 10 :2 4
:2 c 1b c :2 4 :2 b 1a b :2 4
:2 d 1c d :2 4 :3 10 :2 4 :3 10 :2 4
12 1b 1a :2 12 :2 4 :2 d 1c d
:2 4 :2 12 21 12 :2 4 :2 a 19 a
:2 4 :2 f 1e f :2 4 :2 14 23 14
:2 4 :3 12 :2 4 :3 13 :2 4 :2 11 20 11
:2 4 :2 12 21 12 :2 4 :2 13 22 13
:2 4 :2 f 19 f :2 4 :2 f 19 f
:2 4 :3 9 :2 4 :3 9 :2 4 :2 f 1e f
:2 4 :2 16 25 16 :2 4 :2 11 20 11
:2 4 :2 14 23 14 :2 4 :2 e 1d e
:2 4 :3 10 :2 4 :2 16 2e 16 4 7
e 0 :2 7 11 1d 29 36 14
30 39 48 5a 14 31 3a 4a
5d f 1d 27 32 3e 47 4f
58 66 6f 7d 86 94 9d aa
b3 c4 cd e0 e9 fe 107 122
12b 143 14c 15d 166 178 181 199
1a2 1b5 1be 11 1e 38 45 54
64 b 29 50 59 68 a :6 7
e 0 :2 7 :3 a 15 :2 a 14 26
49 a 15 24 :3 a 14 34 4f
67 70 7f 90 99 a9 :b a f
10 1d e 18 11 1c 10 1d
2c 3c e 2c fffa :5 7 4 e
17 :3 e 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
57 5d 60 :2 57 6e 87 8 :2 6e
d 10 :2 6e 13 16 :2 6e b e
:2 6e 13 16 1f 27 :2 1f 34 :2 16
:2 6e b e :2 6e 13 16 :2 6e 1b
1e :2 6e 2a 2d :2 6e 32 35 :2 6e
:2 7 4d :2 4 7 :2 11 23 :2 2d 39
3c 4f 52 53 :2 4f :2 23 :3 7 :2 d
12 1e 61 64 :2 1e :2 7 56 :3 4
11 :2 4 12 :2 4 17 4 e 14
1b 28 30 c 1a 27 :2 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 56 59
5a :2 56 :2 29 :3 d :2 13 18 24 67
6a :2 24 77 7a :2 24 7e 81 :2 24
8d 90 :2 24 98 9b :2 24 a7 aa
b1 ba bd :2 aa :2 24 :2 d 5d :2 a
:2 7 :4 13 :2 7 4 :3 1 8 :2 11 1c
1a :2 25 :2 1a 7 :4 3b 3a 39 :3 7
11 18 1f 22 :2 18 27 2a :2 11
:2 7 13 14 :2 13 :2 7 c :4 7 10
1c 2a 35 3f 4d :3 a d 14
:2 d :2 16 22 d 1a d :2 16 22
d :4 a e :2 17 23 20 :2 2c :2 20
:3 d 3c :2 a d 16 20 :2 d 23
25 :2 23 10 19 24 :2 10 27 29
:2 27 10 25 :2 2e :2 10 1f 30 3e
49 57 66 :2 1f :2 10 :2 19 25 :2 10
1c 25 2f :2 1c 32 34 :2 1c 10
2b :2 d 27 d 1d :2 d 1e :2 d
12 :4 d 16 :19 10 13 1a :2 13 :2 1c
28 13 20 13 :2 1c 28 13 :4 10
14 :2 1d 29 26 :2 32 :2 26 :3 13 42
:3 10 23 32 40 4b 60 25 33
41 50 5a 25 2c 37 49 54
25 35 41 54 25 31 3d 4d
57 25 34 3f :2 23 10 13 1c
2d :2 13 30 32 :2 30 13 1f 28
32 :2 1f 35 37 :2 1f 13 10 34
16 1f 30 :2 16 35 33 :2 3e :2 33
13 26 2f 40 :2 26 43 45 :2 26
13 5d 34 :2 10 d 11 a 10
16 :3 10 :2 19 25 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5f 62 63 :2 5f :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 96 99 :2 2d a1 a4
:2 2d b0 b3 ba c3 c6 :2 b3 :2 2d
:2 16 66 :2 13 :2 10 :4 1c :2 10 d :3 a
11 1a 25 :2 11 28 2b :2 28 10
33 3c 46 :2 33 49 4b :2 49 32
:3 10 1e :2 10 1f 10 1a 29 3a
4a 18 25 34 40 18 26 33
44 51 :2 13 :2 1c 28 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 62 65 66 :2 62 :2 35 :3 19
:2 1f 24 30 73 76 :2 30 83 86
:2 30 8a 8d :2 30 99 9c :2 30 a4
a7 :2 30 b3 b6 bd c6 c9 :2 b6
:2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13 10
:3 4e :4 14 13 :4 17 16 20 19 1e
3d 45 4c 63 6b 72 8c 1e
3e 1e 19 1e 3d 45 4c 63
6b 72 :2 1e 1f 2c 3d 4a 19
20 1c 28 :3 26 1c :2 25 31 1c
2d 1c :2 25 31 1c :4 19 16 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 68 6b 6c :2 68 :2 3b :3 1f
:2 25 2a 36 79 7c :2 36 89 8c
:2 36 90 93 :2 36 9f a2 :2 36 aa
ad :2 36 b9 bc c3 cc cf :2 bc
:2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19 16
:4 30 20 2c 3c 49 1f 2c 3d
4a 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 68 6b 6c :2 68
:2 3b :3 1f :2 25 2a 36 79 7c :2 36
89 8c :2 36 90 93 :2 36 9f a2
:2 36 aa ad :2 36 b9 bc c3 cc
cf :2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25
:2 19 16 :7 13 10 2d :4 18 17 16
:4 37 36 35 :2 16 :4 17 16 20 19
1e 3d 45 4c 63 6b 72 8b
1e 3e 1e 19 1e 3d 45 4c
63 6b 72 :2 1e 1f 2c 3d 4a
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 68 6b 6c :2 68 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :4 30 20 2c 3c 48 1f 2c
3d 4a 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 68 6b 6c
:2 68 :2 3b :3 1f :2 25 2a 36 79 7c
:2 36 89 8c :2 36 90 93 :2 36 9f
a2 :2 36 aa ad :2 36 b9 bc c3
cc cf :2 bc :2 36 :2 1f 6f :2 1c :2 19
:4 25 :2 19 16 :7 13 4d 2d :2 10 4e
:2 d :4 a 7 b 50 a 10 :3 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6a 6d :2 27 7a 7d :2 27 81 84
:2 27 90 93 :2 27 9b 9e :2 27 aa
ad b4 bd c0 :2 ad :2 27 :2 10 60
:2 d :2 a :4 16 :2 a 7 :3 50 b 14
1e :2 b 21 23 :2 21 a 2b 34
3e :2 2b 41 43 44 :2 43 :2 41 2a
:2 a b :2 10 1e 10 b :4 f e
c 14 1d 24 :2 1d 2d :2 14 c
f 11 14 :2 11 1a 1f 22 :2 1f
:2 f c 14 19 1b :2 14 c 24
:2 c 23 :2 b 12 17 1a :2 17 :3 e
20 :2 25 29 :2 20 1f 2c 2f :2 2c
:2 e c :2 17 2b :2 34 47 4f :2 c
31 :2 b :2 a :3 47 14 20 2e 37
3e 4a 53 13 20 31 3b d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5c 5f 60 :2 5c :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a 7d 80
:2 2a 84 87 :2 2a 93 96 :2 2a 9e
a1 :2 2a ad b0 b7 c0 c3 :2 b0
:2 2a :2 13 63 :2 10 :2 d :4 19 :2 d a
:3 47 a 1d 27 :2 1d a 47 :2 7
50 :2 4 7 10 21 :2 7 24 26
:2 24 7 :2 10 1c :2 25 7 4 28
a 13 24 :2 a 27 29 :2 27 7
:2 10 1c 25 36 :2 1c 7 2d 28
:2 4 7 :2 11 23 :2 2d 39 3c 4f
52 53 :2 4f :2 23 :3 7 :2 d 12 1e
61 64 :2 1e 71 74 :2 1e 78 7b
:2 1e 85 88 91 99 :2 a2 :2 91 ad
:2 88 :2 1e b5 b8 :2 1e c0 c3 :2 1e
c8 cb :2 1e ce d1 :2 1e :2 7 56
:3 4 :2 f 21 :2 2a 34 38 :2 4 1
9 12 9 a :2 14 26 :2 30 3c
40 53 56 57 :2 53 :2 26 :3 a :2 10
15 21 64 67 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 5a :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 50 53 54 :2 50 :2 23 :3 7 :2 d
12 1e 61 64 :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 57
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
8df
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :5 e :5 f
:5 10 :5 11 :5 12 :5 13
:5 14 :5 15 :5 16 :7 17
:7 18 :7 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :5 21 :5 22 :7 23
:6 24 :6 25 :6 26 :6 27
:6 28 :5 29 :5 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:5 30 :5 31 :6 32 :6 33
:6 34 :6 35 :6 36 :5 37
:6 38 :2 3a 0 :2 3a
:4 3b :5 3c :5 3d :22 3e
:6 3f :5 40 3b :5 3a
:2 42 0 :2 42 44
45 :2 46 47 48
:3 49 :3 4a 4b 4c
4d :9 4e 4f 50
51 52 53 54
55 56 57 58
59 5a :2 5b :2 5c
:2 5d :4 5e :2 5f 44
:5 42 :7 61 :b 63 :11 64
65 :2 64 :2 65 :2 64
:2 65 :2 64 :2 66 :2 64
:9 66 :2 64 :2 67 :2 64
:2 67 :2 64 :2 67 :2 64
:2 67 :2 64 :2 67 :4 64
:3 63 :11 6a :b 6b :3 6a
:3 6f :3 70 :3 71 :5 74
:3 75 74 :5 76 73
:2 78 :5 7a :11 7b :24 7c
:3 7b :2 79 :6 78 77
:3 62 :12 81 :c 82 :6 83
:5 87 89 :9 8a :3 8b
:5 8c 8b :5 8e 8d
:3 8b :a 91 :2 92 :3 91
:9 97 :9 99 :5 9b :a 9c
:5 9d :b 9f :3 99 97
:3 a3 :3 a5 :5 a8 aa
ab ac ad ae
af b0 b1 b2
b3 b4 b5 b6
b7 b8 b9 ba
bb bc bd be
bf c0 c1 :3 ab
:3 c2 :5 c3 c2 :5 c5
c4 :3 c2 :a c8 :2 c9
:3 c8 :6 ce :5 cf :5 d0
:4 d1 :5 d2 :3 d3 :3 ce
:9 d5 :b d6 d7 d5
:b d7 :b d8 d7 :3 d5
aa da a1 :4 de
:5 df dd :2 e1 :5 e3
:11 e4 :24 e5 :3 e4 :2 e2
:6 e1 e0 :3 a1 :16 ed
:3 ee :3 ef :4 f2 :4 f3
:5 f4 f2 :5 f5 f1
:2 f7 :5 f9 :11 fa :24 fb
:3 fa :2 f8 :6 f7 f6
:3 ed :5 101 :5 103 105
106 :8 108 :2 109 10a
10c :7 10e 10f 110
:4 112 105 :6 113 :5 114
113 :5 116 115 :3 113
104 :2 119 :5 11b :11 11c
:24 11d :3 11c :2 11a :6 119
118 :4 103 :4 123 :4 124
123 :6 125 :5 126 125
:5 128 127 :3 125 122
:2 12b :5 12d :11 12e :24 12f
:3 12e :2 12c :6 12b 12a
:4 121 :3 103 134 101
:e 134 :5 136 138 139
:8 13b :2 13c 13d 13f
:7 141 142 143 :4 145
138 :6 146 :5 147 146
:5 149 148 :3 146 137
:2 14c :5 14e :11 14f :24 150
:3 14f :2 14d :6 14c 14b
:4 136 :4 156 :4 157 156
:6 158 :5 159 158 :5 15b
15a :3 158 155 :2 15e
:5 160 :11 161 :24 162 :3 161
:2 15f :6 15e 15d :4 154
:3 136 134 :3 101 :3 ed
a1 :3 97 89 16a
81 :4 16e :5 16f 16d
:2 171 :5 173 :11 174 :24 175
:3 174 :2 172 :6 171 170
:3 81 :19 17c :6 17e :5 180
:a 181 :c 182 :7 183 :3 182
:3 180 :15 186 :a 187 :3 186
:2 17f :3 17c :7 18c :4 18d
18c :6 18e :5 18f 18e
:5 191 190 :3 18e 18b
:2 194 :5 196 :11 197 :24 198
:3 197 :2 195 :6 194 193
:3 17c :6 19d :3 17c :3 81
:9 1a2 :7 1a3 1a4 1a2
:9 1a4 :9 1a5 1a4 :3 1a2
:11 1a8 :30 1a9 :3 1a8 :a 1ab
62 :3 1ae :11 1af :b 1b0
:17 1b1 :3 1af :2 1b3 :3 1b4
:3 1b5 1b6 1b4 1b3
1b4 :3 1b7 :3 1ae :2 1b8
:5 1ba :11 1bb :b 1bc :18 1bd
:3 1bb :2 1bf 1c0 :3 1c1
1c2 1c0 1bf 1c0
:3 1c3 :2 1b9 :6 1b8 1ad
:7 1 
20c2
4
:3 0 1 :3 0 2
:a 0 8da 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 8da 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 8d8
0 b :6 0 f
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 8d8
0 d :6 0 c
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 8d8
0 e :6 0 c
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 8d8
0 10 :6 0 13
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 8d8
0 11 :6 0 25
11e 0 23 4
:3 0 21 3a 3c
:6 0 3f 3d 0
8d8 0 12 :6 0
29 152 0 27
15 :3 0 41 :7 0
44 42 0 8d8
0 14 :6 0 15
:3 0 46 :7 0 49
47 0 8d8 0
16 :6 0 2d 186
0 2b 15 :3 0
4b :7 0 4e 4c
0 8d8 0 17
:6 0 15 :3 0 50
:7 0 53 51 0
8d8 0 18 :6 0
31 1ba 0 2f
15 :3 0 55 :7 0
58 56 0 8d8
0 19 :6 0 15
:3 0 5a :7 0 5d
5b 0 8d8 0
1a :6 0 35 1ee
0 33 1c :3 0
5f :7 0 62 60
0 8d8 0 1b
:6 0 1c :3 0 64
:7 0 67 65 0
8d8 0 1d :6 0
c :2 0 39 1c
:3 0 69 :7 0 6c
6a 0 8d8 0
1e :6 0 4 :3 0
c :2 0 37 6e
70 :6 0 73 71
0 8d8 0 1f
:6 0 13 :2 0 3d
4 :3 0 3b 75
77 :6 0 7a 78
0 8d8 0 20
:6 0 23 :2 0 41
4 :3 0 3f 7c
7e :6 0 81 7f
0 8d8 0 21
:6 0 23 :2 0 43
6 :3 0 83 :7 0
87 84 85 8d8
0 22 :6 0 23
:2 0 45 6 :3 0
89 :7 0 8d 8a
8b 8d8 0 24
:6 0 23 :2 0 47
6 :3 0 8f :7 0
93 90 91 8d8
0 25 :6 0 23
:2 0 49 6 :3 0
95 :7 0 99 96
97 8d8 0 26
:6 0 23 :2 0 4b
6 :3 0 9b :7 0
9f 9c 9d 8d8
0 27 :6 0 23
:2 0 4d 6 :3 0
a1 :7 0 a5 a2
a3 8d8 0 28
:6 0 51 324 0
4f 6 :3 0 a7
:7 0 ab a8 a9
8d8 0 29 :6 0
2d :2 0 53 15
:3 0 ad :7 0 b0
ae 0 8d8 0
2a :6 0 1c :3 0
b2 :7 0 b5 b3
0 8d8 0 2b
:6 0 23 :2 0 57
4 :3 0 55 b7
b9 :6 0 bc ba
0 8d8 0 2c
:6 0 23 :2 0 59
6 :3 0 be :7 0
c2 bf c0 8d8
0 2e :6 0 23
:2 0 5b 6 :3 0
c4 :7 0 c8 c5
c6 8d8 0 2f
:6 0 23 :2 0 5d
6 :3 0 ca :7 0
ce cb cc 8d8
0 30 :6 0 23
:2 0 5f 6 :3 0
d0 :7 0 d4 d1
d2 8d8 0 31
:6 0 63 401 0
61 6 :3 0 d6
:7 0 da d7 d8
8d8 0 32 :6 0
23 :2 0 65 15
:3 0 dc :7 0 df
dd 0 8d8 0
33 :6 0 15 :3 0
e1 :7 0 e4 e2
0 8d8 0 34
:6 0 23 :2 0 67
6 :3 0 e6 :7 0
ea e7 e8 8d8
0 35 :6 0 23
:2 0 69 6 :3 0
ec :7 0 f0 ed
ee 8d8 0 36
:6 0 3a :2 0 6b
6 :3 0 f2 :7 0
f6 f3 f4 8d8
0 37 :6 0 3a
:2 0 6d 39 :3 0
f8 :7 0 fc f9
fa 8d8 0 38
:6 0 71 4c1 0
6f 39 :3 0 fe
:7 0 102 ff 100
8d8 0 3b :6 0
23 :2 0 73 1c
:3 0 104 :7 0 107
105 0 8d8 0
3c :6 0 1c :3 0
109 :7 0 10c 10a
0 8d8 0 3d
:6 0 23 :2 0 75
6 :3 0 10e :7 0
112 10f 110 8d8
0 3e :6 0 23
:2 0 77 6 :3 0
114 :7 0 118 115
116 8d8 0 3f
:6 0 23 :2 0 79
6 :3 0 11a :7 0
11e 11b 11c 8d8
0 40 :6 0 23
:2 0 7b 6 :3 0
120 :7 0 124 121
122 8d8 0 41
:6 0 7f 581 0
7d 6 :3 0 126
:7 0 12a 127 128
8d8 0 42 :9 0
81 44 :3 0 12c
:7 0 12f 12d 0
8d8 0 43 :6 0
6 :3 0 131 0
2 :5 0 23 :2 0
135 132 133 8d8
0 45 :6 0 46
:3 0 47 :a 0 2
177 :4 0 137 13a
0 138 :3 0 48
:3 0 49 :3 0 4a
:3 0 4b :3 0 4c
:3 0 4d :3 0 4e
:3 0 4f :3 0 4c
:3 0 50 :3 0 4d
:3 0 51 :3 0 52
:3 0 50 :3 0 53
:3 0 54 :3 0 e
:3 0 55 :3 0 56
:3 0 57 :3 0 56
:3 0 58 :3 0 56
:3 0 59 :3 0 56
:3 0 5a :3 0 56
:3 0 5b :3 0 56
:3 0 5c :3 0 56
:3 0 5d :3 0 56
:3 0 5e :3 0 56
:3 0 5f :3 0 56
:3 0 60 :3 0 56
:3 0 61 :3 0 56
:3 0 62 :3 0 56
:3 0 63 :3 0 56
:3 0 64 :3 0 56
:3 0 65 :3 0 4a
:3 0 4b :3 0 4a
:3 0 4b :3 0 66
:3 0 67 :3 0 4c
:3 0 50 :3 0 4d
:3 0 4e :3 0 4f
:4 0 68 1 :8 0
178 137 13a 179
0 8d8 83 179
17b 178 17a :6 0
177 :7 0 179 46
:3 0 69 :a 0 3
1b2 :5 0 17d 180
0 17e :3 0 6a
:3 0 6b :3 0 6c
:3 0 6d :3 0 4c
:3 0 50 :3 0 22
:3 0 4c :3 0 67
:3 0 6c :3 0 6d
:3 0 66 :3 0 67
:3 0 6e :3 0 6f
:3 0 50 :3 0 4c
:3 0 50 :3 0 4d
:3 0 4e :3 0 4f
:3 0 4d :3 0 51
:3 0 52 :3 0 70
:3 0 71 :3 0 72
:3 0 73 :3 0 74
:3 0 75 :3 0 76
:3 0 77 :3 0 78
:3 0 79 :3 0 66
:3 0 7a :3 0 48
:3 0 d :3 0 7b
:3 0 1f :3 0 6c
:3 0 6d :3 0 6c
:3 0 6d :3 0 66
:3 0 67 :3 0 4c
:3 0 50 :4 0 7c
1 :8 0 1b3 17d
180 1b4 0 8d8
85 1b4 1b6 1b3
1b5 :6 0 1b2 :7 0
1b4 1be 1bf 0
87 9 :3 0 a
:2 0 4 1b8 1b9
0 1ba :7 0 1bd
1bb 0 8d8 0
7d :6 0 7e :3 0
7f :3 0 7e :3 0
80 :3 0 1c1 1c2
0 2 :4 0 89
1c3 1c5 1c0 1c7
1c6 :2 0 81 :3 0
82 :3 0 1c9 1ca
0 83 :4 0 7e
:3 0 84 :3 0 1cd
1ce 0 2 :4 0
8b 1cf 1d1 85
:4 0 86 :2 0 87
:3 0 8d 1d4 1d6
:3 0 88 :4 0 86
:2 0 89 :4 0 90
1d9 1db :3 0 86
:2 0 3 :3 0 93
1dd 1df :3 0 86
:2 0 89 :4 0 96
1e1 1e3 :3 0 86
:2 0 8a :4 0 99
1e5 1e7 :3 0 86
:2 0 4d :3 0 8b
:3 0 5 :3 0 9c
1eb 1ed 8c :4 0
9e 1ea 1f0 a1
1e9 1f2 :3 0 86
:2 0 8a :4 0 a4
1f4 1f6 :3 0 86
:2 0 89 :4 0 a7
1f8 1fa :3 0 86
:2 0 7 :3 0 aa
1fc 1fe :3 0 86
:2 0 89 :4 0 ad
200 202 :3 0 86
:2 0 8d :4 0 b0
204 206 :3 0 b3
1cb 208 :2 0 20a
b8 20b 1c8 20a
0 20c ba 0
838 7e :3 0 7f
:3 0 20d 20e 0
7e :3 0 8e :3 0
210 211 0 13
:2 0 2 :4 0 8f
:2 0 90 :2 0 13
:2 0 bc 216 218
:3 0 bf 212 21a
20f 21c 21b :2 0
81 :3 0 91 :3 0
21e 21f 0 83
:4 0 92 :4 0 86
:2 0 87 :3 0 c3
223 225 :3 0 c6
220 227 :2 0 229
c9 22a 21d 229
0 22b cb 0
838 22 :3 0 5
:3 0 22c 22d 0
838 10 :3 0 7
:3 0 22f 230 0
838 41 :3 0 23
:2 0 232 233 0
838 93 :3 0 54
:3 0 55 :3 0 e
:3 0 28 :3 0 53
:3 0 49 :3 0 3
:4 0 94 1 :8 0
243 9 :3 0 95
:3 0 23e 23f 0
96 :3 0 240 241
0 243 cd 28d
97 :3 0 9 :3 0
95 :3 0 246 247
0 96 :3 0 248
249 0 283 7e
:3 0 7f :3 0 24b
24c 0 7e :3 0
8e :3 0 24e 24f
0 98 :2 0 2
:4 0 99 :2 0 90
:2 0 13 :2 0 d0
254 256 :3 0 d3
250 258 24d 25a
259 :2 0 81 :3 0
91 :3 0 25c 25d
0 83 :4 0 9a
:4 0 86 :2 0 87
:3 0 d7 261 263
:3 0 86 :2 0 9b
:4 0 da 265 267
:3 0 86 :2 0 9c
:4 0 dd 269 26b
:3 0 86 :2 0 96
:3 0 e0 26d 26f
:3 0 86 :2 0 9d
:4 0 e3 271 273
:3 0 86 :2 0 9e
:3 0 9f :3 0 13
:2 0 a0 :2 0 e6
276 27a ea 275
27c :3 0 ed 25e
27e :2 0 280 f0
281 25b 280 0
282 f2 0 283
f4 286 :3 0 286
0 286 285 283
284 :6 0 288 4
:3 0 f7 28a f9
289 288 :2 0 28b
fb :2 0 28d 0
28d 28c 243 28b
:6 0 838 1 :3 0
9 :3 0 95 :3 0
28f 290 0 9
:3 0 a1 :2 0 a2
:3 0 292 294 0
ff 293 296 :3 0
297 :2 0 28 :3 0
a3 :2 0 102 29a
29b :3 0 29c :2 0
29d :2 0 298 29f
29e :2 0 e :3 0
9e :3 0 e :3 0
86 :2 0 a4 :4 0
104 2a4 2a6 :3 0
13 :2 0 f :2 0
107 2a2 2aa 2a1
2ab 0 7bf 25
:3 0 a5 :2 0 13
:2 0 10b 2ae 2b0
:3 0 2ad 2b1 0
7bf a6 :3 0 47
:4 0 2b6 :2 0 7bf
2b4 2b7 :3 0 a7
:3 0 47 :3 0 d
:3 0 1f :3 0 25
:3 0 17 :3 0 18
:4 0 2c0 :2 0 683
2b9 2c1 :3 0 10d
:3 0 47 :3 0 a8
:3 0 2c2 2c3 :3 0
9 :3 0 95 :3 0
2c5 2c6 0 23
:2 0 2c7 2c8 0
2ca 113 2d1 9
:3 0 95 :3 0 2cb
2cc 0 a9 :2 0
2cd 2ce 0 2d0
115 2d2 2c4 2ca
0 2d3 0 2d0
0 2d3 117 0
683 9 :3 0 95
:3 0 2d4 2d5 0
9 :3 0 aa :2 0
a2 :3 0 2d7 2d9
0 11c 2d8 2db
:3 0 2dc :2 0 ab
:8 0 2e0 11f 2e1
2dd 2e0 0 2e2
121 0 683 4d
:3 0 25 :3 0 23
:2 0 123 2e3 2e6
a1 :2 0 23 :2 0
128 2e8 2ea :3 0
4d :3 0 22 :3 0
23 :2 0 12b 2ec
2ef a1 :2 0 ac
:2 0 130 2f1 2f3
:3 0 45 :3 0 9
:3 0 95 :3 0 2f6
2f7 0 2f5 2f8
0 314 43 :3 0
ad :3 0 d :3 0
1f :3 0 17 :3 0
18 :3 0 10 :3 0
133 2fb 301 2fa
302 0 314 9
:3 0 95 :3 0 304
305 0 45 :3 0
306 307 0 314
29 :3 0 4d :3 0
29 :3 0 23 :2 0
139 30a 30d 90
:2 0 13 :2 0 13c
30f 311 :3 0 309
312 0 314 13f
315 2f4 314 0
316 144 0 317
146 680 17 :4 0
318 319 0 67f
18 :4 0 31b 31c
0 67f a6 :3 0
69 :4 0 321 :2 0
67f 31f 322 :3 0
a7 :3 0 69 :3 0
20 :3 0 b :3 0
35 :3 0 17 :3 0
18 :3 0 25 :3 0
26 :3 0 30 :3 0
24 :3 0 1e :3 0
42 :3 0 14 :3 0
16 :3 0 3e :3 0
3f :3 0 38 :3 0
3b :3 0 21 :3 0
37 :3 0 11 :3 0
12 :3 0 36 :4 0
33c :2 0 3ae 324
33d :3 0 148 :3 0
69 :3 0 a8 :3 0
33e 33f :3 0 9
:3 0 95 :3 0 341
342 0 23 :2 0
343 344 0 346
15f 34d 9 :3 0
95 :3 0 347 348
0 a9 :2 0 349
34a 0 34c 161
34e 340 346 0
34f 0 34c 0
34f 163 0 3ae
9 :3 0 95 :3 0
350 351 0 9
:3 0 aa :2 0 a2
:3 0 353 355 0
168 354 357 :3 0
358 :2 0 ab :8 0
35c 16b 35d 359
35c 0 35e 16d
0 3ae 32 :3 0
ae :3 0 d :3 0
1f :3 0 20 :3 0
b :3 0 35 :3 0
17 :3 0 18 :3 0
25 :3 0 26 :3 0
30 :3 0 24 :3 0
1e :3 0 42 :3 0
14 :3 0 16 :3 0
3e :3 0 3f :3 0
38 :3 0 3b :3 0
21 :3 0 37 :3 0
11 :3 0 12 :3 0
36 :3 0 22 :3 0
10 :3 0 16f 360
37b 35f 37c 0
3ae 4d :3 0 32
:3 0 23 :2 0 18a
37e 381 a1 :2 0
23 :2 0 18f 383
385 :3 0 29 :3 0
4d :3 0 29 :3 0
23 :2 0 192 388
38b 90 :2 0 13
:2 0 195 38d 38f
:3 0 387 390 0
393 af :3 0 198
3ac 4d :3 0 32
:3 0 23 :2 0 19a
394 397 56 :3 0
a1 :2 0 b0 :3 0
399 39b 0 19f
39a 39d :3 0 41
:3 0 4d :3 0 41
:3 0 23 :2 0 1a2
3a0 3a3 90 :2 0
13 :2 0 1a5 3a5
3a7 :3 0 39f 3a8
0 3aa 1a8 3ab
39e 3aa 0 3ad
386 393 0 3ad
1aa 0 3ae 1ad
3b0 a7 :4 0 3ae
:4 0 67f b1 :3 0
69 :4 0 3b4 :2 0
3ba 3b2 0 9
:3 0 95 :3 0 3b5
3b6 0 96 :3 0
3b7 3b8 0 3ba
1b3 404 97 :3 0
9 :3 0 95 :3 0
3bd 3be 0 96
:3 0 3bf 3c0 0
3fa 7e :3 0 7f
:3 0 3c2 3c3 0
7e :3 0 8e :3 0
3c5 3c6 0 98
:2 0 2 :4 0 b2
:2 0 90 :2 0 13
:2 0 1b6 3cb 3cd
:3 0 1b9 3c7 3cf
3c4 3d1 3d0 :2 0
81 :3 0 91 :3 0
3d3 3d4 0 83
:4 0 b3 :4 0 86
:2 0 87 :3 0 1bd
3d8 3da :3 0 86
:2 0 9b :4 0 1c0
3dc 3de :3 0 86
:2 0 9c :4 0 1c3
3e0 3e2 :3 0 86
:2 0 96 :3 0 1c6
3e4 3e6 :3 0 86
:2 0 9d :4 0 1c9
3e8 3ea :3 0 86
:2 0 9e :3 0 9f
:3 0 13 :2 0 a0
:2 0 1cc 3ed 3f1
1d0 3ec 3f3 :3 0
1d3 3d5 3f5 :2 0
3f7 1d6 3f8 3d2
3f7 0 3f9 1d8
0 3fa 1da 3fd
:3 0 3fd 0 3fd
3fc 3fa 3fb :6 0
3ff 8 :3 0 1dd
401 1df 400 3ff
:2 0 402 1e1 :2 0
404 0 404 403
3ba 402 :6 0 67f
6 :3 0 4d :3 0
22 :3 0 23 :2 0
1e3 406 409 aa
:2 0 13 :2 0 1e8
40b 40d :3 0 40e
:2 0 4d :3 0 29
:3 0 23 :2 0 1eb
410 413 b4 :2 0
23 :2 0 1f0 415
417 :3 0 418 :2 0
40f 41a 419 :2 0
19 :4 0 41c 41d
0 67c 1a :4 0
41f 420 0 67c
b5 :3 0 b6 :3 0
4c :3 0 50 :3 0
2a :3 0 2f :3 0
19 :3 0 1a :3 0
53 :3 0 48 :3 0
d :3 0 49 :3 0
1f :4 0 b7 1
:8 0 435 9 :3 0
95 :3 0 430 431
0 96 :3 0 432
433 0 435 1f3
47f 97 :3 0 9
:3 0 95 :3 0 438
439 0 96 :3 0
43a 43b 0 475
7e :3 0 7f :3 0
43d 43e 0 7e
:3 0 8e :3 0 440
441 0 98 :2 0
2 :4 0 b8 :2 0
90 :2 0 13 :2 0
1f6 446 448 :3 0
1f9 442 44a 43f
44c 44b :2 0 81
:3 0 91 :3 0 44e
44f 0 83 :4 0
b9 :4 0 86 :2 0
87 :3 0 1fd 453
455 :3 0 86 :2 0
9b :4 0 200 457
459 :3 0 86 :2 0
9c :4 0 203 45b
45d :3 0 86 :2 0
96 :3 0 206 45f
461 :3 0 86 :2 0
9d :4 0 209 463
465 :3 0 86 :2 0
9e :3 0 9f :3 0
13 :2 0 a0 :2 0
20c 468 46c 210
467 46e :3 0 213
450 470 :2 0 472
216 473 44d 472
0 474 218 0
475 21a 478 :3 0
478 0 478 477
475 476 :6 0 47a
a :3 0 21d 47c
21f 47b 47a :2 0
47d 221 :2 0 47f
0 47f 47e 435
47d :6 0 67c 6
:3 0 1a :3 0 a3
:2 0 223 482 483
:3 0 484 :2 0 2a
:3 0 a3 :2 0 225
487 488 :3 0 489
:2 0 53 :3 0 b5
:3 0 2f :3 0 ba
:3 0 9e :3 0 2a
:3 0 ba :3 0 9e
:3 0 1a :3 0 1a
:3 0 2f :3 0 1a
:3 0 2a :3 0 b6
:3 0 2f :3 0 ba
:3 0 9e :3 0 2a
:3 0 ba :3 0 9e
:3 0 1a :3 0 2f
:3 0 2f :3 0 48
:3 0 d :3 0 49
:3 0 1f :4 0 bb
1 :8 0 4bc a8
:4 0 4a7 :3 0 bc
:3 0 a1 :2 0 229
4aa 4ab :3 0 9
:3 0 95 :3 0 4ad
4ae 0 23 :2 0
4af 4b0 0 4b2
22c 4b9 9 :3 0
95 :3 0 4b3 4b4
0 a9 :2 0 4b5
4b6 0 4b8 22e
4ba 4ac 4b2 0
4bb 0 4b8 0
4bb 230 0 4bc
233 506 97 :3 0
9 :3 0 95 :3 0
4bf 4c0 0 96
:3 0 4c1 4c2 0
4fc 7e :3 0 7f
:3 0 4c4 4c5 0
7e :3 0 8e :3 0
4c7 4c8 0 98
:2 0 2 :4 0 bd
:2 0 90 :2 0 13
:2 0 236 4cd 4cf
:3 0 239 4c9 4d1
4c6 4d3 4d2 :2 0
81 :3 0 91 :3 0
4d5 4d6 0 83
:4 0 be :4 0 86
:2 0 87 :3 0 23d
4da 4dc :3 0 86
:2 0 9b :4 0 240
4de 4e0 :3 0 86
:2 0 9c :4 0 243
4e2 4e4 :3 0 86
:2 0 96 :3 0 246
4e6 4e8 :3 0 86
:2 0 9d :4 0 249
4ea 4ec :3 0 86
:2 0 9e :3 0 9f
:3 0 13 :2 0 a0
:2 0 24c 4ef 4f3
250 4ee 4f5 :3 0
253 4d7 4f7 :2 0
4f9 256 4fa 4d4
4f9 0 4fb 258
0 4fc 25a 4ff
:3 0 4ff 0 4ff
4fe 4fc 4fd :6 0
501 c :3 0 25d
503 25f 502 501
:2 0 504 261 :2 0
506 0 506 505
4bc 504 :6 0 508
6 :3 0 263 574
53 :3 0 b5 :3 0
1a :3 0 b6 :3 0
48 :3 0 d :3 0
49 :3 0 1f :4 0
bf 1 :8 0 527
a8 :4 0 512 :3 0
bc :3 0 a1 :2 0
267 515 516 :3 0
9 :3 0 95 :3 0
518 519 0 23
:2 0 51a 51b 0
51d 26a 524 9
:3 0 95 :3 0 51e
51f 0 a9 :2 0
520 521 0 523
26c 525 517 51d
0 526 0 523
0 526 26e 0
527 271 571 97
:3 0 9 :3 0 95
:3 0 52a 52b 0
96 :3 0 52c 52d
0 567 7e :3 0
7f :3 0 52f 530
0 7e :3 0 8e
:3 0 532 533 0
98 :2 0 2 :4 0
c0 :2 0 90 :2 0
13 :2 0 274 538
53a :3 0 277 534
53c 531 53e 53d
:2 0 81 :3 0 91
:3 0 540 541 0
83 :4 0 c1 :4 0
86 :2 0 87 :3 0
27b 545 547 :3 0
86 :2 0 9b :4 0
27e 549 54b :3 0
86 :2 0 9c :4 0
281 54d 54f :3 0
86 :2 0 96 :3 0
284 551 553 :3 0
86 :2 0 9d :4 0
287 555 557 :3 0
86 :2 0 9e :3 0
9f :3 0 13 :2 0
a0 :2 0 28a 55a
55e 28e 559 560
:3 0 291 542 562
:2 0 564 294 565
53f 564 0 566
296 0 567 298
56a :3 0 56a 0
56a 569 567 568
:6 0 56c e :3 0
29b 56e 29d 56d
56c :2 0 56f 29f
:2 0 571 0 571
570 527 56f :6 0
573 6 :3 0 2a1
575 48a 508 0
576 0 573 0
576 2a3 0 578
af :3 0 2a6 67a
19 :3 0 a3 :2 0
2a8 57a 57b :3 0
57c :2 0 57d :2 0
1a :3 0 c2 :2 0
2aa 580 581 :3 0
582 :2 0 583 :2 0
57e 585 584 :2 0
2a :3 0 a3 :2 0
2ac 588 589 :3 0
58a :2 0 53 :3 0
b5 :3 0 2f :3 0
ba :3 0 9e :3 0
2a :3 0 ba :3 0
9e :3 0 19 :3 0
19 :3 0 2f :3 0
19 :3 0 2a :3 0
b6 :3 0 2f :3 0
ba :3 0 9e :3 0
2a :3 0 ba :3 0
9e :3 0 19 :3 0
2f :3 0 2f :3 0
48 :3 0 d :3 0
49 :3 0 1f :4 0
c3 1 :8 0 5bd
a8 :4 0 5a8 :3 0
bc :3 0 a1 :2 0
2b0 5ab 5ac :3 0
9 :3 0 95 :3 0
5ae 5af 0 23
:2 0 5b0 5b1 0
5b3 2b3 5ba 9
:3 0 95 :3 0 5b4
5b5 0 a9 :2 0
5b6 5b7 0 5b9
2b5 5bb 5ad 5b3
0 5bc 0 5b9
0 5bc 2b7 0
5bd 2ba 607 97
:3 0 9 :3 0 95
:3 0 5c0 5c1 0
96 :3 0 5c2 5c3
0 5fd 7e :3 0
7f :3 0 5c5 5c6
0 7e :3 0 8e
:3 0 5c8 5c9 0
98 :2 0 2 :4 0
c4 :2 0 90 :2 0
13 :2 0 2bd 5ce
5d0 :3 0 2c0 5ca
5d2 5c7 5d4 5d3
:2 0 81 :3 0 91
:3 0 5d6 5d7 0
83 :4 0 c5 :4 0
86 :2 0 87 :3 0
2c4 5db 5dd :3 0
86 :2 0 9b :4 0
2c7 5df 5e1 :3 0
86 :2 0 9c :4 0
2ca 5e3 5e5 :3 0
86 :2 0 96 :3 0
2cd 5e7 5e9 :3 0
86 :2 0 9d :4 0
2d0 5eb 5ed :3 0
86 :2 0 9e :3 0
9f :3 0 13 :2 0
a0 :2 0 2d3 5f0
5f4 2d7 5ef 5f6
:3 0 2da 5d8 5f8
:2 0 5fa 2dd 5fb
5d5 5fa 0 5fc
2df 0 5fd 2e1
600 :3 0 600 0
600 5ff 5fd 5fe
:6 0 602 10 :3 0
2e4 604 2e6 603
602 :2 0 605 2e8
:2 0 607 0 607
606 5bd 605 :6 0
609 6 :3 0 2ea
675 53 :3 0 b5
:3 0 19 :3 0 b6
:3 0 48 :3 0 d
:3 0 49 :3 0 1f
:4 0 c6 1 :8 0
628 a8 :4 0 613
:3 0 bc :3 0 a1
:2 0 2ee 616 617
:3 0 9 :3 0 95
:3 0 619 61a 0
23 :2 0 61b 61c
0 61e 2f1 625
9 :3 0 95 :3 0
61f 620 0 a9
:2 0 621 622 0
624 2f3 626 618
61e 0 627 0
624 0 627 2f5
0 628 2f8 672
97 :3 0 9 :3 0
95 :3 0 62b 62c
0 96 :3 0 62d
62e 0 668 7e
:3 0 7f :3 0 630
631 0 7e :3 0
8e :3 0 633 634
0 98 :2 0 2
:4 0 c7 :2 0 90
:2 0 13 :2 0 2fb
639 63b :3 0 2fe
635 63d 632 63f
63e :2 0 81 :3 0
91 :3 0 641 642
0 83 :4 0 c8
:4 0 86 :2 0 87
:3 0 302 646 648
:3 0 86 :2 0 9b
:4 0 305 64a 64c
:3 0 86 :2 0 9c
:4 0 308 64e 650
:3 0 86 :2 0 96
:3 0 30b 652 654
:3 0 86 :2 0 9d
:4 0 30e 656 658
:3 0 86 :2 0 9e
:3 0 9f :3 0 13
:2 0 a0 :2 0 311
65b 65f 315 65a
661 :3 0 318 643
663 :2 0 665 31b
666 640 665 0
667 31d 0 668
31f 66b :3 0 66b
0 66b 66a 668
669 :6 0 66d 12
:3 0 322 66f 324
66e 66d :2 0 670
326 :2 0 672 0
672 671 628 670
:6 0 674 6 :3 0
328 676 58b 609
0 677 0 674
0 677 32a 0
678 32d 679 586
678 0 67b 485
578 0 67b 32f
0 67c 332 67d
41b 67c 0 67e
337 0 67f 339
681 2eb 317 0
682 0 67f 0
682 340 0 683
343 685 a7 :4 0
683 :4 0 7bf b1
:3 0 47 :4 0 689
:2 0 68f 687 0
9 :3 0 95 :3 0
68a 68b 0 96
:3 0 68c 68d 0
68f 348 6d9 97
:3 0 9 :3 0 95
:3 0 692 693 0
96 :3 0 694 695
0 6cf 7e :3 0
7f :3 0 697 698
0 7e :3 0 8e
:3 0 69a 69b 0
98 :2 0 2 :4 0
c9 :2 0 90 :2 0
13 :2 0 34b 6a0
6a2 :3 0 34e 69c
6a4 699 6a6 6a5
:2 0 81 :3 0 91
:3 0 6a8 6a9 0
83 :4 0 ca :4 0
86 :2 0 87 :3 0
352 6ad 6af :3 0
86 :2 0 9b :4 0
355 6b1 6b3 :3 0
86 :2 0 9c :4 0
358 6b5 6b7 :3 0
86 :2 0 96 :3 0
35b 6b9 6bb :3 0
86 :2 0 9d :4 0
35e 6bd 6bf :3 0
86 :2 0 9e :3 0
9f :3 0 13 :2 0
a0 :2 0 361 6c2
6c6 365 6c1 6c8
:3 0 368 6aa 6ca
:2 0 6cc 36b 6cd
6a7 6cc 0 6ce
36d 0 6cf 36f
6d2 :3 0 6d2 0
6d2 6d1 6cf 6d0
:6 0 6d4 14 :3 0
372 6d6 374 6d5
6d4 :2 0 6d7 376
:2 0 6d9 0 6d9
6d8 68f 6d7 :6 0
7bf 1 :3 0 4d
:3 0 29 :3 0 23
:2 0 378 6db 6de
b4 :2 0 23 :2 0
37d 6e0 6e2 :3 0
6e3 :2 0 4d :3 0
25 :3 0 23 :2 0
380 6e5 6e8 b4
:2 0 a5 :2 0 13
:2 0 383 6eb 6ed
:3 0 387 6ea 6ef
:3 0 6f0 :2 0 6e4
6f2 6f1 :2 0 a3
:2 0 38a 6 :3 0
6f5 :7 0 23 :2 0
6f9 6f6 6f7 746
0 cb :6 0 e
:3 0 38c 6fb 6fc
:3 0 6fd :2 0 cb
:3 0 4d :3 0 cc
:3 0 e :3 0 38e
701 703 23 :2 0
390 700 706 6ff
707 0 71f 13
:2 0 aa :2 0 23
:2 0 395 70a 70c
:3 0 cb :3 0 aa
:2 0 23 :2 0 39a
70f 711 :3 0 70d
713 712 :2 0 cb
:3 0 cb :3 0 a5
:2 0 13 :2 0 39d
717 719 :3 0 715
71a 0 71c 3a0
71d 714 71c 0
71e 3a2 0 71f
3a4 720 6fe 71f
0 721 3a7 0
744 cb :3 0 aa
:2 0 23 :2 0 3ab
723 725 :3 0 cd
:2 0 3ae 727 728
:3 0 cb :3 0 ce
:3 0 ce :2 0 cf
:2 0 3b0 72c 72e
:3 0 72f :2 0 aa
:2 0 23 :2 0 3b5
731 733 :3 0 729
735 734 :2 0 d0
:3 0 d1 :3 0 737
738 0 56 :3 0
d2 :3 0 73a 73b
0 e :3 0 bc
:3 0 3b8 739 73f
:2 0 741 3bc 742
736 741 0 743
3be 0 744 3c0
747 :3 0 747 3c3
747 746 744 745
:6 0 7bc 1 :3 0
53 :3 0 d3 :3 0
d4 :3 0 d5 :3 0
d3 :3 0 56 :3 0
d6 :3 0 48 :3 0
d :3 0 54 :3 0
e :4 0 d7 1
:8 0 76a a8 :4 0
755 :3 0 bc :3 0
a1 :2 0 3c7 758
759 :3 0 9 :3 0
95 :3 0 75b 75c
0 23 :2 0 75d
75e 0 760 3ca
767 9 :3 0 95
:3 0 761 762 0
a9 :2 0 763 764
0 766 3cc 768
75a 760 0 769
0 766 0 769
3ce 0 76a 3d1
7b4 97 :3 0 9
:3 0 95 :3 0 76d
76e 0 96 :3 0
76f 770 0 7aa
7e :3 0 7f :3 0
772 773 0 7e
:3 0 8e :3 0 775
776 0 98 :2 0
2 :4 0 d8 :2 0
90 :2 0 13 :2 0
3d4 77b 77d :3 0
3d7 777 77f 774
781 780 :2 0 81
:3 0 91 :3 0 783
784 0 83 :4 0
d9 :4 0 86 :2 0
87 :3 0 3db 788
78a :3 0 86 :2 0
9b :4 0 3de 78c
78e :3 0 86 :2 0
9c :4 0 3e1 790
792 :3 0 86 :2 0
96 :3 0 3e4 794
796 :3 0 86 :2 0
9d :4 0 3e7 798
79a :3 0 86 :2 0
9e :3 0 9f :3 0
13 :2 0 a0 :2 0
3ea 79d 7a1 3ee
79c 7a3 :3 0 3f1
785 7a5 :2 0 7a7
3f4 7a8 782 7a7
0 7a9 3f6 0
7aa 3f8 7ad :3 0
7ad 0 7ad 7ac
7aa 7ab :6 0 7af
17 :3 0 3fb 7b1
3fd 7b0 7af :2 0
7b2 3ff :2 0 7b4
0 7b4 7b3 76a
7b2 :6 0 7bc 1
:3 0 32 :3 0 da
:3 0 d :3 0 401
7b7 7b9 7b6 7ba
0 7bc 403 7bd
6f3 7bc 0 7be
407 0 7bf 409
7c0 2a0 7bf 0
7c1 410 0 838
4d :3 0 41 :3 0
23 :2 0 412 7c2
7c5 b4 :2 0 23
:2 0 417 7c7 7c9
:3 0 9 :3 0 95
:3 0 7cb 7cc 0
56 :3 0 b0 :3 0
7ce 7cf 0 7cd
7d0 0 7d3 af
:3 0 41a 7e8 4d
:3 0 32 :3 0 23
:2 0 41c 7d4 7d7
b4 :2 0 a9 :2 0
421 7d9 7db :3 0
9 :3 0 95 :3 0
7dd 7de 0 4d
:3 0 32 :3 0 23
:2 0 424 7e0 7e3
7df 7e4 0 7e6
427 7e7 7dc 7e6
0 7e9 7ca 7d3
0 7e9 429 0
838 7e :3 0 7f
:3 0 7ea 7eb 0
7e :3 0 8e :3 0
7ed 7ee 0 cf
:2 0 2 :4 0 db
:2 0 90 :2 0 13
:2 0 42c 7f3 7f5
:3 0 42f 7ef 7f7
7ec 7f9 7f8 :2 0
81 :3 0 91 :3 0
7fb 7fc 0 83
:4 0 dc :4 0 86
:2 0 87 :3 0 433
800 802 :3 0 86
:2 0 9b :4 0 436
804 806 :3 0 86
:2 0 dd :4 0 439
808 80a :3 0 86
:2 0 4d :3 0 8b
:3 0 9 :3 0 95
:3 0 80f 810 0
43c 80e 812 8c
:4 0 43e 80d 815
441 80c 817 :3 0
86 :2 0 de :4 0
444 819 81b :3 0
86 :2 0 89 :4 0
447 81d 81f :3 0
86 :2 0 3 :3 0
44a 821 823 :3 0
86 :2 0 89 :4 0
44d 825 827 :3 0
450 7fd 829 :2 0
82b 453 82c 7fa
82b 0 82d 455
0 838 d0 :3 0
df :3 0 82e 82f
0 9 :3 0 95
:3 0 831 832 0
3 :3 0 bc :3 0
457 830 836 :2 0
838 45b 8d9 9
:3 0 e0 :2 0 4
839 83a 0 7e
:3 0 7f :3 0 83c
83d 0 7e :3 0
8e :3 0 83f 840
0 98 :2 0 2
:4 0 e1 :2 0 90
:2 0 13 :2 0 466
845 847 :3 0 469
841 849 83e 84b
84a :2 0 81 :3 0
91 :3 0 84d 84e
0 83 :4 0 e2
:4 0 86 :2 0 87
:3 0 46d 852 854
:3 0 470 84f 856
:2 0 86f 81 :3 0
91 :3 0 858 859
0 83 :4 0 e3
:4 0 86 :2 0 9
:3 0 e4 :3 0 85e
85f 0 473 85d
861 :3 0 86 :2 0
de :4 0 476 863
865 :3 0 86 :2 0
9 :3 0 e5 :3 0
868 869 0 479
867 86b :3 0 47c
85a 86d :2 0 86f
47f 870 84c 86f
0 871 482 0
881 a6 :3 0 7d
:3 0 9 :3 0 e4
:3 0 e6 :3 0 9
:3 0 e5 :3 0 3
:3 0 e7 :4 0 e8
1 :a 0 87d :2 0
881 873 87b :2 0
8 :3 0 7d :3 0
87f :2 0 881 484
883 488 882 881
:2 0 8d7 97 :3 0
9 :3 0 95 :3 0
886 887 0 96
:3 0 888 889 0
8cf 7e :3 0 7f
:3 0 88b 88c 0
7e :3 0 8e :3 0
88e 88f 0 98
:2 0 2 :4 0 e9
:2 0 90 :2 0 13
:2 0 48a 894 896
:3 0 48d 890 898
88d 89a 899 :2 0
81 :3 0 91 :3 0
89c 89d 0 83
:4 0 ea :4 0 86
:2 0 87 :3 0 491
8a1 8a3 :3 0 494
89e 8a5 :2 0 8bf
81 :3 0 91 :3 0
8a7 8a8 0 83
:4 0 9c :4 0 86
:2 0 96 :3 0 497
8ac 8ae :3 0 86
:2 0 9d :4 0 49a
8b0 8b2 :3 0 86
:2 0 9e :3 0 9f
:3 0 13 :2 0 a0
:2 0 49d 8b5 8b9
4a1 8b4 8bb :3 0
4a4 8a9 8bd :2 0
8bf 4a7 8c0 89b
8bf 0 8c1 4aa
0 8cf a6 :3 0
7d :3 0 e6 :3 0
9 :3 0 e5 :3 0
3 :3 0 e7 :4 0
eb 1 :a 0 8cb
:2 0 8cf 8c3 8c9
:2 0 8 :3 0 7d
:3 0 8cd :2 0 8cf
4ac 8d2 :3 0 8d2
0 8d2 8d1 8cf
8d0 :6 0 8d4 1
:3 0 4b1 8d6 4b3
8d5 8d4 :2 0 8d7
4b5 :2 0 8d9 4b8
8d9 8d8 838 8d7
:6 0 8da :2 0 2
14 8d9 8dd :3 0
8dc 8da 8de :8 0

4ed
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
40 1 45 1
4a 1 4f 1
54 1 59 1
5e 1 63 1
68 1 6f 1
6d 1 76 1
74 1 7d 1
7b 1 82 1
88 1 8e 1
94 1 9a 1
a0 1 a6 1
ac 1 b1 1
b8 1 b6 1
bd 1 c3 1
c9 1 cf 1
d5 1 db 1
e0 1 e5 1
eb 1 f1 1
f7 1 fd 1
103 1 108 1
10d 1 113 1
119 1 11f 1
125 1 12b 1
130 1 176 1
1b1 1 1b7 1
1c4 1 1d0 2
1d3 1d5 2 1d8
1da 2 1dc 1de
2 1e0 1e2 2
1e4 1e6 1 1ec
2 1ee 1ef 2
1e8 1f1 2 1f3
1f5 2 1f7 1f9
2 1fb 1fd 2
1ff 201 2 203
205 4 1cc 1d2
1d7 207 1 209
1 20b 2 215
217 3 213 214
219 2 222 224
2 221 226 1
228 1 22a 2
23d 242 2 253
255 3 251 252
257 2 260 262
2 264 266 2
268 26a 2 26c
26e 2 270 272
3 277 278 279
2 274 27b 2
25f 27d 1 27f
1 281 2 24a
282 1 286 1
245 1 28a 1
295 2 291 295
1 299 2 2a3
2a5 3 2a7 2a8
2a9 1 2af 5
2ba 2bb 2bc 2bd
2be 1 2c9 1
2cf 2 2d1 2d2
1 2da 2 2d6
2da 1 2df 1
2e1 2 2e4 2e5
1 2e9 2 2e7
2e9 2 2ed 2ee
1 2f2 2 2f0
2f2 5 2fc 2fd
2fe 2ff 300 2
30b 30c 2 30e
310 4 2f9 303
308 313 1 315
1 316 16 325
326 327 328 329
32a 32b 32c 32d
32e 32f 330 331
332 333 334 335
336 337 338 339
33a 1 345 1
34b 2 34d 34e
1 356 2 352
356 1 35b 1
35d 1a 361 362
363 364 365 366
367 368 369 36a
36b 36c 36d 36e
36f 370 371 372
373 374 375 376
377 378 379 37a
2 37f 380 1
384 2 382 384
2 389 38a 2
38c 38e 1 391
2 395 396 1
39c 2 398 39c
2 3a1 3a2 2
3a4 3a6 1 3a9
2 3ac 3ab 5
33b 34f 35e 37d
3ad 2 3b3 3b9
2 3ca 3cc 3
3c8 3c9 3ce 2
3d7 3d9 2 3db
3dd 2 3df 3e1
2 3e3 3e5 2
3e7 3e9 3 3ee
3ef 3f0 2 3eb
3f2 2 3d6 3f4
1 3f6 1 3f8
2 3c1 3f9 1
3fd 1 3bc 1
401 2 407 408
1 40c 2 40a
40c 2 411 412
1 416 2 414
416 2 42f 434
2 445 447 3
443 444 449 2
452 454 2 456
458 2 45a 45c
2 45e 460 2
462 464 3 469
46a 46b 2 466
46d 2 451 46f
1 471 1 473
2 43c 474 1
478 1 437 1
47c 1 481 1
486 1 4a9 2
4a8 4a9 1 4b1
1 4b7 2 4b9
4ba 2 4a6 4bb
2 4cc 4ce 3
4ca 4cb 4d0 2
4d9 4db 2 4dd
4df 2 4e1 4e3
2 4e5 4e7 2
4e9 4eb 3 4f0
4f1 4f2 2 4ed
4f4 2 4d8 4f6
1 4f8 1 4fa
2 4c3 4fb 1
4ff 1 4be 1
503 1 506 1
514 2 513 514
1 51c 1 522
2 524 525 2
511 526 2 537
539 3 535 536
53b 2 544 546
2 548 54a 2
54c 54e 2 550
552 2 554 556
3 55b 55c 55d
2 558 55f 2
543 561 1 563
1 565 2 52e
566 1 56a 1
529 1 56e 1
571 2 574 575
1 576 1 579
1 57f 1 587
1 5aa 2 5a9
5aa 1 5b2 1
5b8 2 5ba 5bb
2 5a7 5bc 2
5cd 5cf 3 5cb
5cc 5d1 2 5da
5dc 2 5de 5e0
2 5e2 5e4 2
5e6 5e8 2 5ea
5ec 3 5f1 5f2
5f3 2 5ee 5f5
2 5d9 5f7 1
5f9 1 5fb 2
5c4 5fc 1 600
1 5bf 1 604
1 607 1 615
2 614 615 1
61d 1 623 2
625 626 2 612
627 2 638 63a
3 636 637 63c
2 645 647 2
649 64b 2 64d
64f 2 651 653
2 655 657 3
65c 65d 65e 2
659 660 2 644
662 1 664 1
666 2 62f 667
1 66b 1 62a
1 66f 1 672
2 675 676 1
677 2 67a 679
4 41e 421 47f
67b 1 67d 6
31a 31d 320 3b0
404 67e 2 680
681 4 2bf 2d3
2e2 682 2 688
68e 2 69f 6a1
3 69d 69e 6a3
2 6ac 6ae 2
6b0 6b2 2 6b4
6b6 2 6b8 6ba
2 6bc 6be 3
6c3 6c4 6c5 2
6c0 6c7 2 6ab
6c9 1 6cb 1
6cd 2 696 6ce
1 6d2 1 691
1 6d6 2 6dc
6dd 1 6e1 2
6df 6e1 2 6e6
6e7 1 6ec 1
6ee 2 6e9 6ee
1 6f4 1 6fa
1 702 2 704
705 1 70b 2
709 70b 1 710
2 70e 710 2
716 718 1 71b
1 71d 2 708
71e 1 720 1
724 2 722 724
1 726 2 72a
72d 1 732 2
730 732 3 73c
73d 73e 1 740
1 742 2 721
743 1 6f8 1
757 2 756 757
1 75f 1 765
2 767 768 2
754 769 2 77a
77c 3 778 779
77e 2 787 789
2 78b 78d 2
78f 791 2 793
795 2 797 799
3 79e 79f 7a0
2 79b 7a2 2
786 7a4 1 7a6
1 7a8 2 771
7a9 1 7ad 1
76c 1 7b1 1
7b8 3 747 7b4
7bb 1 7bd 6
2ac 2b2 2b5 685
6d9 7be 1 7c0
2 7c3 7c4 1
7c8 2 7c6 7c8
1 7d1 2 7d5
7d6 1 7da 2
7d8 7da 2 7e1
7e2 1 7e5 2
7e8 7e7 2 7f2
7f4 3 7f0 7f1
7f6 2 7ff 801
2 803 805 2
807 809 1 811
2 813 814 2
80b 816 2 818
81a 2 81c 81e
2 820 822 2
824 826 2 7fe
828 1 82a 1
82c 3 833 834
835 a 20c 22b
22e 231 234 28d
7c1 7e9 82d 837
2 844 846 3
842 843 848 2
851 853 2 850
855 2 85c 860
2 862 864 2
866 86a 2 85b
86c 2 857 86e
1 870 3 871
87c 880 1 83b
2 893 895 3
891 892 897 2
8a0 8a2 2 89f
8a4 2 8ab 8ad
2 8af 8b1 3
8b6 8b7 8b8 2
8b3 8ba 2 8aa
8bc 2 8a6 8be
1 8c0 4 88a
8c1 8ca 8ce 1
8d2 1 885 2
883 8d6 34 1b
22 29 30 37
3e 43 48 4d
52 57 5c 61
66 6b 72 79
80 86 8c 92
98 9e a4 aa
af b4 bb c1
c7 cd d3 d9
de e3 e9 ef
f5 fb 101 106
10b 111 117 11d
123 129 12e 134
177 1b2 1bc 
1
4
0 
8dd
0
1
28
19
39
0 1 1 1 4 1 6 6
8 6 a 6 c 6 e 6
10 6 12 1 14 1 1 17
1 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

b 1 0
2 0 1
e0 1 0
94 1 0
cf 1 0
3 1 0
f1 1 0
4f 1 0
74 1 0
119 1 0
16 1 0
c9 1 0
bd 1 0
39 1 0
db 1 0
fd 1 0
12b 1 0
b1 1 0
d5 1 0
6f4 16 0
11f 1 0
68 1 0
8e 1 0
54 1 0
40 1 0
4a 1 0
137 1 2
10d 1 0
82 1 0
e5 1 0
b6 1 0
108 1 0
59 1 0
9a 1 0
113 1 0
6d 1 0
24 1 0
45 1 0
130 1 0
eb 1 0
7b 1 0
ac 1 0
63 1 0
a0 1 0
32 1 0
1d 1 0
17d 1 3
7 1 0
103 1 0
f7 1 0
5e 1 0
2b 1 0
88 1 0
125 1 0
c3 1 0
1b7 1 0
a6 1 0
0

/
SHOW ERRORS FUNCTION SP_ACPT_ETC_WBS;
ALTER FUNCTION SP_ACPT_ETC_WBS COMPILE DEBUG;
/****************************************************************************************
Reject ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_RJCT_ETC_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_RJCT_ETC_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
a0
2 :e:
1FUNCTION:
1SP_RJCT_ETC_ASSIGN:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PROJECT_ID:
1H_TASK_ID:
1H_START_DATE:
1TIMESTAMP:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_TEMP_SC_STATE:
1H_STEPS_EXIST:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1I_PERCENT_COMPLETE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_RJCT_ETC_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
130:
1+:
1FPUT:
1               ENTER:: SP_RJCT_ETC_ASSIGN(31) :: cplan.sql(18702) :: :
1PROJECT_ID:
1TASK_ID:
1BIT_FLAG:
1SCHED_WORK:
1PLANNED_WORK:
1WORK_TODATE:
1MILESTONE_PERCENT:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, TASK_ID, BIT_FLAG, SCHED_WORK+PLANNED_WORK, WORK_TODATE, M+
1ILESTONE_PERCENT:n      INTO h_project_id, h_task_id, h_bit_flag, h_sched_wor+
1k, h_work_todate, h_mlst_percent:n      FROM TASK_ASSIGNMENTS WHERE TSK_ASSIG+
1NMENT_ID = h_tsk_assignment_id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
147:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(48) :: cplan.sql(18719) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
12:
1ETC:
1UPDATE TASK_ASSIGNMENTS SET ETC = SCHED_WORK - WORK_TODATE--, MILESTONE_PERCE+
1NT = (WORK_TODATE * 10000) / SCHED_WORK:n            WHERE TSK_ASSIGNMENT_ID +
1= h_tsk_assignment_id:
1FOUND:
1TRUE:
1100:
167:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(68) :: cplan.sql(18739) :: :
1ACTIVITIES:
1ETC_MODIFIED:
1ELEMENT_ID:
1TYPE_ID:
1PMO_CNST:
1SC_TIMESHEET_ACTIVITY:
1UPDATE ACTIVITIES:n            SET ETC_MODIFIED = 'N':n            WHERE TSK_+
1ASSIGNMENT_ID = h_tsk_assignment_id:n            AND TSK_ASSIGNMENT_ID <> ELE+
1MENT_ID:n            AND TYPE_ID = PMO_CNST.SC_TIMESHEET_ACTIVITY:
188:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(89) :: cplan.sql(18760) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = PLANNED_WORK, WORK_TODATE = 0, MILESTONE_PE+
1RCENT = 0:n            WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1106:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(107) :: cplan.sql(18778) :: :
1TMT_WBS:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_SCHED_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, PMO_CNST.SC_SCH+
1ED_BIT) WHERE ELEMENT_ID = h_task_id:
1124:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(125) :: cplan.sql(18796) :: :
1FORECAST_START:
1FORECAST_FINISH:
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_i+
1d:
1143:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(144) :: cplan.sql(18815) :: :
1160:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(161) :: cplan.sql(18832) :: :
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0,:n               ETC = SCHED_WORK - WORK_TODATE--, MILEST+
1ONE_PERCENT = (WORK_TODATE * 10000) / SCHED_WORK:n               WHERE TSK_AS+
1SIGNMENT_ID = h_tsk_assignment_id:
1180:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(181) :: cplan.sql(18852) :: :
1UPDATE ACTIVITIES:n               SET ETC_MODIFIED = 'N':n               WHER+
1E TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n               AND TSK_ASSIGNMENT_+
1ID <> ELEMENT_ID:n               AND TYPE_ID = PMO_CNST.SC_TIMESHEET_ACTIVITY:
1201:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(202) :: cplan.sql(18873) :: :
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0,:n               ETC = PLANNED_WORK, WORK_TODATE = 0, MIL+
1ESTONE_PERCENT = 0:n               WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id:
1220:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(221) :: cplan.sql(18892) :: :
1238:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(239) :: cplan.sql(18910) :: :
1BITAND:
1>:
1TRUNC:
1/:
1*:
110000.00:
1-:
1<:
1SC_PERCENT_COMPLETE_BIT:
1ACTUAL_FINISH:
1SCHED_FINISH:
1UPDATE TASK_ASSIGNMENTS SET:n            ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP+
1_BITS,PMO_CNST.SC_PERCENT_COMPLETE_BIT),:n            ACTUAL_FINISH = CASE:n +
1           WHEN ACTUAL_FINISH IS NULL AND ETC = 0 THEN SCHED_FINISH:n        +
1    ELSE ACTUAL_FINISH:n            END:n            WHERE TSK_ASSIGNMENT_ID +
1= h_tsk_assignment_id:
1267:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(268) :: cplan.sql(18939) :: :
1UPDATE TASK_ASSIGNMENTS SET:n         ACTUAL_FINISH = CASE:n         WHEN ACT+
1UAL_FINISH IS NULL AND ETC = 0 THEN SCHED_FINISH:n         ELSE ACTUAL_FINISH+
1:n         END:n         WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1290:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(291) :: cplan.sql(18962) :: :
1SC_SQL_SUCCESS:
1!=:
1FC_FIX_SUMMARY_TS:
1FC_ROLLUP:
14:
1305:
1       RETURN_STATUS:: SP_RJCT_ETC_ASSIGN(306) :: cplan.sql(18977) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1312:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(313) :: cplan.sql(18984) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1324:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(325) :: cplan.sql(18996) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
7e6
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 d :2 a0 d :10 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
:2 51 a5 b 7e 6e b4 2e :6 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :7 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 a0 51 a5 b 7e 51 b4 2e
:6 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 a0 :2 51 a5 b 7e
6e b4 2e :9 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :a a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :2 19
3c :3 a0 51 a5 b 51 a5 b
5a 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :4 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e 5a 7e 51 b4
2e 5a 7e :2 a0 51 a5 b b4
2e a5 b d a0 7e 51 b4
2e 5a a0 :2 7e 51 b4 2e b4
2e 52 10 :e a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:4 a0 a5 b d b7 19 3c :3 a0
a5 b d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
7e6
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dc cb cf d7 aa
f8 e3 e7 ea eb f3 ca 114
103 107 c7 10f 102 130 11f 123
ff 12b 11e 14c 13b 13f 11b 147
13a 168 157 15b 137 163 156 184
173 177 153 17f 172 1a0 18f 193
16f 19b 18e 1bc 1ab 1af 1b7 18b
1db 1c3 1c7 1cb 1ce 1d6 1aa 1e2
1e6 1a7 1ea 1ee 1f2 1f5 1fa 1fb
1 1fd 202 206 20a 20d 212 216
21a 21d 222 223 225 22a 22d 231
232 237 23c 23f 244 245 24a 24d
251 252 257 25a 25f 260 265 268
26d 26e 273 276 27a 27e 282 283
285 28a 28b 28d 28e 293 296 29b
29c 2a1 2a4 2a9 2aa 2af 2b2 2b6
2b7 2bc 2bf 2c4 2c5 2ca 2cd 2d2
2d3 2d8 2d9 2de 2e0 2e4 2e7 2eb
2ef 2f2 2f6 2fa 2fd 300 305 308
30b 30e 30f 314 315 1 317 31c
320 324 327 32c 331 334 338 339
33e 33f 344 346 34a 34d 351 355
359 35d 361 365 369 36d 371 375
379 37d 381 385 389 38d 391 395
399 39d 3a1 3a5 3b1 3b5 3b9 3bc
3c0 3c4 3c6 1 3ca 3ce 3d2 3d5
3d9 3dd 3e1 3e5 3e8 3ec 3f0 3f3
3f6 3fb 3fe 401 404 405 40a 40b
1 40d 412 416 41a 41d 422 427
42a 42e 42f 434 437 43c 43d 442
445 44a 44b 450 453 457 458 45d
460 465 466 46b 46e 472 476 479
47c 47d 47f 480 485 486 48b 48d
491 494 496 49a 49c 4a8 4aa 4ac
4ad 4b2 4b6 4b8 4c4 4c6 4ca 4ce
4d1 4d2 4d4 4d7 4da 4db 4e0 4e4
4e8 4eb 4ee 4ef 4f1 4f4 4f9 4fa
4ff 503 507 50b 50f 513 517 523
527 52c 530 533 534 539 53d 541
544 547 54b 54d 551 555 558 55b
55f 561 565 569 56c 56e 1 572
576 57a 57d 581 585 589 58d 590
594 598 59b 59e 5a3 5a6 5a9 5ac
5ad 5b2 5b3 1 5b5 5ba 5be 5c2
5c5 5ca 5cf 5d2 5d6 5d7 5dc 5df
5e4 5e5 5ea 5ed 5f2 5f3 5f8 5fb
5ff 600 605 608 60d 60e 613 616
61a 61e 621 624 625 627 628 62d
62e 633 635 639 63c 63e 642 644
650 652 654 655 65a 65e 660 66c
66e 672 676 67a 67e 682 686 68a
68e 692 69e 6a2 6a7 6ab 6ae 6af
6b4 6b8 6bc 6bf 6c2 6c6 6c8 6cc
6d0 6d3 6d6 6da 6dc 6e0 6e4 6e7
6e9 1 6ed 6f1 6f5 6f8 6fc 700
704 708 70b 70f 713 716 719 71e
721 724 727 728 72d 72e 1 730
735 739 73d 740 745 74a 74d 751
752 757 75a 75f 760 765 768 76d
76e 773 776 77a 77b 780 783 788
789 78e 791 795 799 79c 79f 7a0
7a2 7a3 7a8 7a9 7ae 7b0 7b4 7b7
7b9 7bd 7bf 7cb 7cd 7cf 7d0 7d5
7d9 7db 7e7 7e9 7eb 7ef 7f3 7f7
7fb 7ff 803 807 813 817 81c 820
823 824 829 82d 831 834 837 83b
83d 841 845 848 84b 84f 851 855
859 85c 85e 1 862 866 86a 86d
871 875 879 87d 880 884 888 88b
88e 893 896 899 89c 89d 8a2 8a3
1 8a5 8aa 8ae 8b2 8b5 8ba 8bf
8c2 8c6 8c7 8cc 8cf 8d4 8d5 8da
8dd 8e2 8e3 8e8 8eb 8ef 8f0 8f5
8f8 8fd 8fe 903 906 90a 90e 911
914 915 917 918 91d 91e 923 925
929 92c 92e 932 934 940 942 944
945 94a 94e 950 95c 95e 960 964
968 96b 96f 973 977 97b 97f 983
987 98b 98f 99b 99f 9a4 9a8 9ab
9ac 9b1 9b5 9b9 9bc 9bf 9c3 9c5
9c9 9cd 9d0 9d3 9d7 9d9 9dd 9e1
9e4 9e6 1 9ea 9ee 9f2 9f5 9f9
9fd a01 a05 a08 a0c a10 a13 a16
a1b a1e a21 a24 a25 a2a a2b 1
a2d a32 a36 a3a a3d a42 a47 a4a
a4e a4f a54 a57 a5c a5d a62 a65
a6a a6b a70 a73 a77 a78 a7d a80
a85 a86 a8b a8e a92 a96 a99 a9c
a9d a9f aa0 aa5 aa6 aab aad ab1
ab4 ab6 aba abc ac8 aca acc acd
ad2 ad6 ad8 ae4 ae6 ae8 aec af0
af3 af4 af6 af9 afc afd b02 b06
b0a b0e b12 b16 b1a b26 b2a b2f
b33 b36 b37 b3c b40 b44 b47 b4a
b4e b50 b54 b58 b5b b5e b62 b64
b68 b6c b6f b71 1 b75 b79 b7d
b80 b84 b88 b8c b90 b93 b97 b9b
b9e ba1 ba6 ba9 bac baf bb0 bb5
bb6 1 bb8 bbd bc1 bc5 bc8 bcd
bd2 bd5 bd9 bda bdf be2 be7 be8
bed bf0 bf5 bf6 bfb bfe c02 c03
c08 c0b c10 c11 c16 c19 c1d c21
c24 c27 c28 c2a c2b c30 c31 c36
c38 c3c c3f c41 c45 c47 c53 c55
c57 c58 c5d c61 c63 c6f c71 c75
c79 c7d c81 c85 c89 c8d c91 c95
ca1 ca5 caa cae cb1 cb2 cb7 cbb
cbf cc2 cc5 cc9 ccb ccf cd3 cd6
cd9 cdd cdf ce3 ce7 cea cec 1
cf0 cf4 cf8 cfb cff d03 d07 d0b
d0e d12 d16 d19 d1c d21 d24 d27
d2a d2b d30 d31 1 d33 d38 d3c
d40 d43 d48 d4d d50 d54 d55 d5a
d5d d62 d63 d68 d6b d70 d71 d76
d79 d7d d7e d83 d86 d8b d8c d91
d94 d98 d9c d9f da2 da3 da5 da6
dab dac db1 db3 db7 dba dbc dc0
dc2 dce dd0 dd2 dd3 dd8 ddc dde
dea dec dee df2 df6 df9 dfc dfd
dff e02 e07 e08 e0d e11 e15 e19
e1d e21 e25 e29 e2d e31 e3d e41
e46 e4a e4d e4e e53 e57 e5b e5e
e61 e65 e67 e6b e6f e72 e75 e79
e7b e7f e83 e86 e88 1 e8c e90
e94 e97 e9b e9f ea3 ea7 eaa eae
eb2 eb5 eb8 ebd ec0 ec3 ec6 ec7
ecc ecd 1 ecf ed4 ed8 edc edf
ee4 ee9 eec ef0 ef1 ef6 ef9 efe
eff f04 f07 f0c f0d f12 f15 f19
f1a f1f f22 f27 f28 f2d f30 f34
f38 f3b f3e f3f f41 f42 f47 f48
f4d f4f f53 f56 f58 f5c f5e f6a
f6c f6e f6f f74 f78 f7a f86 f88
f8c f90 f94 f98 f9c fa0 fa4 fa8
fac fb8 fbc fc1 fc5 fc8 fc9 fce
fd2 fd6 fd9 fdc fe0 fe2 fe6 fea
fed ff0 ff4 ff6 ffa ffe 1001 1003
1 1007 100b 100f 1012 1016 101a 101e
1022 1025 1029 102d 1030 1033 1038 103b
103e 1041 1042 1047 1048 1 104a 104f
1053 1057 105a 105f 1064 1067 106b 106c
1071 1074 1079 107a 107f 1082 1087 1088
108d 1090 1094 1095 109a 109d 10a2 10a3
10a8 10ab 10af 10b3 10b6 10b9 10ba 10bc
10bd 10c2 10c3 10c8 10ca 10ce 10d1 10d3
10d7 10d9 10e5 10e7 10e9 10ea 10ef 10f3
10f5 1101 1103 1105 1109 110d 1111 1115
1119 111d 1121 1125 1129 112d 1139 113d
1142 1146 1149 114a 114f 1153 1157 115a
115d 1161 1163 1167 116b 116e 1171 1175
1177 117b 117f 1182 1184 1 1188 118c
1190 1193 1197 119b 119f 11a3 11a6 11aa
11ae 11b1 11b4 11b9 11bc 11bf 11c2 11c3
11c8 11c9 1 11cb 11d0 11d4 11d8 11db
11e0 11e5 11e8 11ec 11ed 11f2 11f5 11fa
11fb 1200 1203 1208 1209 120e 1211 1215
1216 121b 121e 1223 1224 1229 122c 1230
1234 1237 123a 123b 123d 123e 1243 1244
1249 124b 124f 1252 1254 1258 125a 1266
1268 126a 126b 1270 1274 1276 1282 1284
1286 128a 128e 1291 1295 1299 129d 12a1
12a5 12a9 12ad 12b1 12b5 12c1 12c5 12ca
12ce 12d1 12d2 12d7 12db 12df 12e2 12e5
12e9 12eb 12ef 12f3 12f6 12f9 12fd 12ff
1303 1307 130a 130c 1 1310 1314 1318
131b 131f 1323 1327 132b 132e 1332 1336
1339 133c 1341 1344 1347 134a 134b 1350
1351 1 1353 1358 135c 1360 1363 1368
136d 1370 1374 1375 137a 137d 1382 1383
1388 138b 1390 1391 1396 1399 139d 139e
13a3 13a6 13ab 13ac 13b1 13b4 13b8 13bc
13bf 13c2 13c3 13c5 13c6 13cb 13cc 13d1
13d3 13d7 13da 13dc 13e0 13e2 13ee 13f0
13f2 13f3 13f8 13fc 13fe 140a 140c 140e
1412 1416 1419 141b 141f 1423 1426 142a
142e 1432 1435 1436 1438 143b 143c 143e
1441 1444 1447 1448 144d 1450 1454 1458
145b 145c 145e 1461 1464 1465 146a 1
146d 1472 1476 147a 147e 1482 1485 1486
1488 148b 148f 1493 1496 1497 1499 149a
149f 14a2 14a5 14a8 14a9 14ae 14b1 14b4
14b8 14bc 14bf 14c0 14c2 14c3 14c8 14c9
14cb 14cf 14d3 14d6 14d9 14da 14df 14e2
14e6 14e9 14ec 14ef 14f0 14f5 14f6 1
14fb 1500 1504 1508 150c 1510 1514 1518
151c 1520 1524 1528 152c 1530 1534 1538
1544 1548 154d 1551 1554 1555 155a 155e
1562 1565 1568 156c 156e 1572 1576 1579
157c 1580 1582 1586 158a 158d 158f 1
1593 1597 159b 159e 15a2 15a6 15aa 15ae
15b1 15b5 15b9 15bc 15bf 15c4 15c7 15ca
15cd 15ce 15d3 15d4 1 15d6 15db 15df
15e3 15e6 15eb 15f0 15f3 15f7 15f8 15fd
1600 1605 1606 160b 160e 1613 1614 1619
161c 1620 1621 1626 1629 162e 162f 1634
1637 163b 163f 1642 1645 1646 1648 1649
164e 164f 1654 1656 165a 165d 165f 1663
1665 1671 1673 1675 1676 167b 167f 1681
168d 168f 1691 1695 1698 169a 169e 16a2
16a6 16aa 16ae 16b2 16b6 16ba 16c6 16ca
16cf 16d3 16d6 16d7 16dc 16e0 16e4 16e7
16ea 16ee 16f0 16f4 16f8 16fb 16fe 1702
1704 1708 170c 170f 1711 1 1715 1719
171d 1720 1724 1728 172c 1730 1733 1737
173b 173e 1741 1746 1749 174c 174f 1750
1755 1756 1 1758 175d 1761 1765 1768
176d 1772 1775 1779 177a 177f 1782 1787
1788 178d 1790 1795 1796 179b 179e 17a2
17a3 17a8 17ab 17b0 17b1 17b6 17b9 17bd
17c1 17c4 17c7 17c8 17ca 17cb 17d0 17d1
17d6 17d8 17dc 17df 17e1 17e5 17e7 17f3
17f5 17f7 17f8 17fd 1801 1803 180f 1811
1813 1817 181b 181e 1822 1826 1829 182d
1830 1834 1837 1838 183d 1840 1844 1848
184b 184c 184e 1851 1854 1855 185a 1
185d 1862 1866 186a 186e 1872 1873 1875
1879 187b 187f 1882 1886 188a 188e 188f
1891 1895 1899 189d 18a0 18a4 18a8 18ab
18ae 18b3 18b6 18b9 18bc 18bd 18c2 18c3
1 18c5 18ca 18ce 18d2 18d5 18da 18df
18e2 18e6 18e7 18ec 18ef 18f4 18f5 18fa
18fd 1902 1903 1908 190b 190f 1913 1917
191b 191e 191f 1921 1926 1927 1929 192a
192f 1932 1937 1938 193d 1940 1945 1946
194b 194e 1952 1953 1958 195b 1960 1961
1966 1967 196c 196e 1972 1975 1979 197d
1980 1984 1988 198b 198f 1993 1994 1999
199b 199f 19a3 19a6 19aa 19ae 19b1 19b5
19b9 19bc 19bf 19c4 19c7 19ca 19cd 19ce
19d3 19d4 1 19d6 19db 19df 19e3 19e6
19eb 19f0 19f3 19f7 19f8 19fd 19fe 1a03
1a07 1a0b 1a0e 1a13 1a18 1a1b 1a1f 1a23
1a26 1a27 1a2c 1a2f 1a34 1a35 1a3a 1a3d
1a41 1a45 1a48 1a49 1a4e 1a4f 1a54 1a56
1a5a 1a5d 1a61 1a65 1a69 1a6d 1a71 1a75
1a79 1a7d 1a81 1a8d 1a92 1a96 1a9a 1a9e
1aa2 1aa4 1aa5 1aaa 1 1aae 1ab2 1ab6
1ab9 1abd 1ac1 1ac5 1ac9 1acc 1ad0 1ad4
1ad7 1ada 1adf 1ae2 1ae5 1ae8 1ae9 1aee
1aef 1 1af1 1af6 1afa 1afe 1b01 1b06
1b0b 1b0e 1b12 1b13 1b18 1b19 1b1e 1b22
1b26 1b29 1b2e 1b33 1b36 1b3a 1b3b 1b40
1b43 1b48 1b49 1b4e 1b51 1b55 1b59 1b5c
1b5f 1b60 1b62 1b63 1b68 1b69 1b6e 1b70
1b74 1b77 1b7b 1b7f 1b83 1b87 1b8b 1b8f
1b93 1b9f 1ba4 1ba8 1bac 1bb0 1bb4 1bb6
1bba 1bbc 1bc8 1bca 1bcc 1bcd 1bd2 1bd6
1bd8 1be4 1be8 1bea 1beb 1bf4 
7e6
2
0 1 a 6 9 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 e 17 16 :2 e :2 4
:3 11 :2 4 f 18 17 :2 f :2 4 :2 e
1d e :2 4 :2 14 23 14 :2 4 :2 12
21 12 :2 4 :2 11 20 11 :2 4 :2 12
21 12 :2 4 :2 13 22 13 :2 4 :3 17
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 5a 60 63 :2 5a 71 8d
8 :2 71 d 10 :2 71 13 16 :2 71
b e :2 71 13 16 1f 27 :2 1f
34 :2 16 :2 71 b e :2 71 13 16
:2 71 1b 1e :2 71 2a 2d :2 71 32
35 :2 71 :2 7 50 :2 4 7 :2 11 23
:2 2d 39 3c 52 54 55 :2 52 :2 23
:3 7 :2 d 12 1e 63 66 :2 1e :2 7
58 :3 4 11 :2 4 1b 4 e 1a
23 2d 38 46 53 c 1a 25
31 3f 4e c 23 37 :2 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 59 5b
5c :2 59 :2 29 :3 d :2 13 18 24 69
6c :2 24 79 7c :2 24 80 83 :2 24
8f 92 :2 24 9a 9d :2 24 a9 ac
b3 bc bf :2 ac :2 24 :2 d 5f :2 a
:2 7 :4 13 :2 7 4 :3 1 7 10 1b
:2 7 1e 20 :2 1e a 11 1d 20
:2 a 23 25 :2 23 14 29 2f 3c
13 27 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 61 62
:2 5f :2 2f :3 13 :2 19 1e 2a 6f 72
:2 2a 7f 82 :2 2a 86 89 :2 2a 95
98 :2 2a a0 a3 :2 2a af b2 b9
c2 c5 :2 b2 :2 2a :2 13 65 :2 10 :2 d
:4 19 :2 d a :3 29 14 11 13 27
11 26 11 1b 24 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5f 61 62 :2 5f :2 2f :3 13 :2 19 1e
2a 6f 72 :2 2a 7f 82 :2 2a 86
89 :2 2a 95 98 :2 2a a0 a3 :2 2a
af b2 b9 c2 c5 :2 b2 :2 2a :2 13
65 :2 10 :2 d :4 19 :2 d a :4 29 14
29 2f 3d 4e 13 27 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5f 62 63 :2 5f :2 2f :3 13 :2 19
1e 2a 70 73 :2 2a 80 83 :2 2a
87 8a :2 2a 96 99 :2 2a a1 a4
:2 2a b0 b3 ba c3 c6 :2 b3 :2 2a
:2 13 66 :2 10 :2 d :4 19 :2 d a :7 7
11 1d 2b 34 3b 48 51 65
72 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 5c 5f 60 :2 5c
:2 2c :3 10 :2 16 1b 27 6d 70 :2 27
7d 80 :2 27 84 87 :2 27 93 96
:2 27 9e a1 :2 27 ad b0 b7 c0
c3 :2 b0 :2 27 :2 10 63 :2 d :2 a :4 16
:2 a 7 :4 22 a 13 1e :2 a 21
23 :2 21 14 29 40 58 13 27
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5f 62 63 :2 5f :2 2f
:3 13 :2 19 1e 2a 70 73 :2 2a 80
83 :2 2a 87 8a :2 2a 96 99 :2 2a
a1 a4 :2 2a b0 b3 ba c3 c6
:2 b3 :2 2a :2 13 66 :2 10 :2 d :4 19 :2 d
a :3 25 14 20 2e 37 3e 4b
54 68 75 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5f 62
63 :2 5f :2 2f :3 13 :2 19 1e 2a 70
73 :2 2a 80 83 :2 2a 87 8a :2 2a
96 99 :2 2a a1 a4 :2 2a b0 b3
ba c3 c6 :2 b3 :2 2a :2 13 66 :2 10
:2 d :4 19 :2 d a :4 25 d 14 20
23 :2 d 26 28 :2 26 17 2c 43
5b 10 16 23 16 2a 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 62 65 66 :2 62 :2 32 :3 16 :2 1c
21 2d 73 76 :2 2d 83 86 :2 2d
8a 8d :2 2d 99 9c :2 2d a4 a7
:2 2d b3 b6 bd c6 c9 :2 b6 :2 2d
:2 16 69 :2 13 :2 10 :4 1c :2 10 d :3 2c
17 14 16 2a 14 29 14 1e
27 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 62 65 66 :2 62
:2 32 :3 16 :2 1c 21 2d 73 76 :2 2d
83 86 :2 2d 8a 8d :2 2d 99 9c
:2 2d a4 a7 :2 2d b3 b6 bd c6
c9 :2 b6 :2 2d :2 16 69 :2 13 :2 10 :4 1c
:2 10 d :4 2c 17 2c 43 5b 10
16 24 35 16 2a 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
62 65 66 :2 62 :2 32 :3 16 :2 1c 21
2d 73 76 :2 2d 83 86 :2 2d 8a
8d :2 2d 99 9c :2 2d a4 a7 :2 2d
b3 b6 bd c6 c9 :2 b6 :2 2d :2 16
69 :2 13 :2 10 :4 1c :2 10 d :7 a 14
20 2e 37 3e 4b 54 68 75
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5f 62 63 :2 5f :2 2f
:3 13 :2 19 1e 2a 70 73 :2 2a 80
83 :2 2a 87 8a :2 2a 96 99 :2 2a
a1 a4 :2 2a b0 b3 ba c3 c6
:2 b3 :2 2a :2 13 66 :2 10 :2 d :4 19 :2 d
a :7 7 :4 4 9 10 19 24 :2 10
28 :2 9 8 2c 2e :2 2c 7 36
3f 4f :2 36 52 54 :2 52 35 :3 7
1d 25 2e 3d :2 25 40 42 4b
59 :2 42 :2 25 24 5d 5f :2 24 23
28 2a 33 43 :2 2a :2 23 :2 1d 7
b 1e 20 :2 1e a 26 39 3b
3c :2 3b :2 39 :2 a 14 d 1b 24
2b 37 40 d 12 2c 39 12
13 27 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 62 63
:2 5f :2 2f :3 13 :2 19 1e 2a 70 73
:2 2a 80 83 :2 2a 87 8a :2 2a 96
99 :2 2a a1 a4 :2 2a b0 b3 ba
c3 c6 :2 b3 :2 2a :2 13 66 :2 10 :2 d
:4 19 :2 d a :4 3e :2 7 57 11 a
f 29 36 f 10 24 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 5c 5f 60 :2 5c :2 2c :3 10 :2 16
1b 27 6d 70 :2 27 7d 80 :2 27
84 87 :2 27 93 96 :2 27 9e a1
:2 27 ad b0 b7 c0 c3 :2 b0 :2 27
:2 10 63 :2 d :2 a :4 16 :2 a 7 :7 4
8 :2 11 1c 1a :2 25 :2 1a 7 3a
43 4e :2 3a 51 54 :2 51 39 :3 7
1a 2c 3a :2 1a 7 57 :3 4 17
21 :2 17 4 7 :2 11 23 :2 2d 39
3c 52 55 56 :2 52 :2 23 :3 7 :2 d
12 1e 64 67 :2 1e 74 77 :2 1e
7b 7e :2 1e 88 8b 94 9c :2 a5
:2 94 b0 :2 8b :2 1e b8 bb :2 1e c3
c6 :2 1e cb ce :2 1e d1 d4 :2 1e
:2 7 59 :3 4 :2 f 21 :2 2a 34 38
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 56 59 5a :2 56 :2 26
:3 a :2 10 15 21 67 6a :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 5d
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 53 56 57 :2 53 :2 23
:3 7 :2 d 12 1e 64 67 :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 5a :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
7e6
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :5 b
:7 c :6 d :6 e :6 f
:6 10 :6 11 :6 12 :5 13
:7 15 :b 17 :11 18 19
:2 18 :2 19 :2 18 :2 19
:2 18 :2 1a :2 18 :9 1a
:2 18 :2 1b :2 18 :2 1b
:2 18 :2 1b :2 18 :2 1b
:2 18 :2 1b :4 18 :3 17
:11 1e :b 1f :3 1e :3 23
:3 24 :7 27 :6 28 :3 29
27 :5 2a 26 :2 2c
:5 2e :11 2f :24 30 :3 2f
:2 2d :6 2c 2b :3 16
:9 35 :a 36 :4 38 :2 39
38 :6 3a :5 3b 3a
:5 3d 3c :3 3a 37
:2 40 :5 42 :11 43 :24 44
:3 43 :2 41 :6 40 3f
:3 36 4a 4b :2 4c
:2 4d :3 4e 4a :6 4f
:5 50 4f :5 52 51
:3 4f 49 :2 55 :5 57
:11 58 :24 59 :3 58 :2 56
:6 55 54 :4 36 :5 5f
:2 60 5f :6 61 :5 62
61 :5 64 63 :3 61
5e :2 67 :5 69 :11 6a
:24 6b :3 6a :2 68 :6 67
66 :4 5d :3 36 :a 72
:6 73 :5 74 73 :5 76
75 :3 73 71 :2 79
:5 7b :11 7c :24 7d :3 7c
:2 7a :6 79 78 :4 35
:9 82 :4 84 :2 85 84
:6 86 :5 87 86 :5 89
88 :3 86 83 :2 8c
:5 8e :11 8f :24 90 :3 8f
:2 8d :6 8c 8b :3 82
:a 96 :6 97 :5 98 97
:5 9a 99 :3 97 95
:2 9d :5 9f :11 a0 :24 a1
:3 a0 :2 9e :6 9d 9c
:4 82 :a a6 :4 a8 :3 a9
:2 aa a8 :6 ab :5 ac
ab :5 ae ad :3 ab
a7 :2 b1 :5 b3 :11 b4
:24 b5 :3 b4 :2 b2 :6 b1
b0 :3 a6 bb bc
:2 bd :2 be :3 bf bb
:6 c0 :5 c1 c0 :5 c3
c2 :3 c0 ba :2 c6
:5 c8 :11 c9 :24 ca :3 c9
:2 c7 :6 c6 c5 :4 a6
:4 d0 :4 d1 :2 d2 d0
:6 d3 :5 d4 d3 :5 d6
d5 :3 d3 cf :2 d9
:5 db :11 dc :24 dd :3 dc
:2 da :6 d9 d8 :4 ce
:3 a6 :a e4 :6 e5 :5 e6
e5 :5 e8 e7 :3 e5
e3 :2 eb :5 ed :11 ee
:24 ef :3 ee :2 ec :6 eb
ea :4 a5 :3 82 81
:3 35 :1b f6 :15 f7 :6 f8
:5 f7 :10 f9 fb :6 fc
fd :3 fe ff :2 101
fb :6 102 :5 103 102
:5 105 104 :3 102 fa
:2 108 :5 10a :11 10b :24 10c
:3 10b :2 109 :6 108 107
:6 f9 f6 113 114
:3 115 116 :2 118 113
:6 119 :5 11a 119 :5 11c
11b :3 119 112 :2 11f
:5 121 :11 122 :24 123 :3 122
:2 120 :6 11f 11e :4 111
:3 f6 :16 129 :7 12b :3 129
:6 12e :11 131 :30 132 :3 131
:a 134 16 :3 137 :11 138
:b 139 :17 13a :3 138 :2 13c
:3 13d :3 13e 13f 13d
13c 13d :3 140 :3 137
:2 141 :5 143 :11 144 :b 145
:18 146 :3 144 :2 148 149
:3 14a 14b 149 148
149 :3 14c :2 142 :6 141
136 :7 1 
1bf6
4
:3 0 1 :3 0 2
:a 0 7e1 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 7e1 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 7df
0 b :6 0 c
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 7df
0 d :6 0 19
c7 0 17 4
:3 0 15 25 27
:6 0 2a 28 0
7df 0 e :6 0
14 :2 0 1d 10
:3 0 2c :7 0 2f
2d 0 7df 0
f :6 0 4 :3 0
12 :2 0 1b 31
33 :6 0 36 34
0 7df 0 11
:6 0 14 :2 0 1f
6 :3 0 38 :7 0
3c 39 3a 7df
0 13 :6 0 14
:2 0 21 6 :3 0
3e :7 0 42 3f
40 7df 0 15
:6 0 14 :2 0 23
6 :3 0 44 :7 0
48 45 46 7df
0 16 :6 0 14
:2 0 25 6 :3 0
4a :7 0 4e 4b
4c 7df 0 17
:6 0 14 :2 0 27
6 :3 0 50 :7 0
54 51 52 7df
0 18 :6 0 2b
1a7 0 29 6
:3 0 56 :7 0 5a
57 58 7df 0
19 :6 0 67 68
0 2d 6 :3 0
5c :7 0 5f 5d
0 7df 0 1a
:6 0 9 :3 0 a
:2 0 4 61 62
0 63 :7 0 66
64 0 7df 0
1b :6 0 1c :3 0
1d :3 0 1c :3 0
1e :3 0 6a 6b
0 2 :4 0 2f
6c 6e 69 70
6f :2 0 1f :3 0
20 :3 0 72 73
0 21 :4 0 1c
:3 0 22 :3 0 76
77 0 2 :4 0
31 78 7a 23
:4 0 24 :2 0 25
:3 0 33 7d 7f
:3 0 26 :4 0 24
:2 0 27 :4 0 36
82 84 :3 0 24
:2 0 3 :3 0 39
86 88 :3 0 24
:2 0 27 :4 0 3c
8a 8c :3 0 24
:2 0 28 :4 0 3f
8e 90 :3 0 24
:2 0 29 :3 0 2a
:3 0 5 :3 0 42
94 96 2b :4 0
44 93 99 47
92 9b :3 0 24
:2 0 28 :4 0 4a
9d 9f :3 0 24
:2 0 27 :4 0 4d
a1 a3 :3 0 24
:2 0 7 :3 0 50
a5 a7 :3 0 24
:2 0 27 :4 0 53
a9 ab :3 0 24
:2 0 2c :4 0 56
ad af :3 0 59
74 b1 :2 0 b3
5e b4 71 b3
0 b5 60 0
73f 1c :3 0 1d
:3 0 b6 b7 0
1c :3 0 2d :3 0
b9 ba 0 12
:2 0 2 :4 0 2e
:2 0 2f :2 0 12
:2 0 62 bf c1
:3 0 65 bb c3
b8 c5 c4 :2 0
1f :3 0 30 :3 0
c7 c8 0 21
:4 0 31 :4 0 24
:2 0 25 :3 0 69
cc ce :3 0 6c
c9 d0 :2 0 d2
6f d3 c6 d2
0 d4 71 0
73f 13 :3 0 5
:3 0 d5 d6 0
73f b :3 0 3
:3 0 d8 d9 0
73f 32 :3 0 33
:3 0 34 :3 0 35
:3 0 36 :3 0 37
:3 0 38 :3 0 d
:3 0 e :3 0 11
:3 0 17 :3 0 18
:3 0 19 :3 0 39
:3 0 3a :3 0 b
:4 0 3b 1 :8 0
f1 9 :3 0 3c
:3 0 ec ed 0
3d :3 0 ee ef
0 f1 73 13b
3e :3 0 9 :3 0
3c :3 0 f4 f5
0 3d :3 0 f6
f7 0 131 1c
:3 0 1d :3 0 f9
fa 0 1c :3 0
2d :3 0 fc fd
0 3f :2 0 2
:4 0 40 :2 0 2f
:2 0 12 :2 0 76
102 104 :3 0 79
fe 106 fb 108
107 :2 0 1f :3 0
30 :3 0 10a 10b
0 21 :4 0 41
:4 0 24 :2 0 25
:3 0 7d 10f 111
:3 0 24 :2 0 42
:4 0 80 113 115
:3 0 24 :2 0 43
:4 0 83 117 119
:3 0 24 :2 0 3d
:3 0 86 11b 11d
:3 0 24 :2 0 44
:4 0 89 11f 121
:3 0 24 :2 0 45
:3 0 46 :3 0 12
:2 0 47 :2 0 8c
124 128 90 123
12a :3 0 93 10c
12c :2 0 12e 96
12f 109 12e 0
130 98 0 131
9a 134 :3 0 134
0 134 133 131
132 :6 0 136 2
:3 0 9d 138 9f
137 136 :2 0 139
a1 :2 0 13b 0
13b 13a f1 139
:6 0 73f 1 :3 0
29 :3 0 13 :3 0
14 :2 0 a3 13d
140 48 :2 0 12
:2 0 a8 142 144
:3 0 45 :3 0 11
:3 0 12 :2 0 12
:2 0 ab 146 14a
48 :2 0 49 :4 0
b1 14c 14e :3 0
39 :3 0 4a :3 0
35 :3 0 37 :3 0
3a :3 0 b :4 0
4b 1 :8 0 16c
4c :4 0 157 :3 0
4d :3 0 48 :2 0
b6 15a 15b :3 0
9 :3 0 3c :3 0
15d 15e 0 14
:2 0 15f 160 0
162 b9 169 9
:3 0 3c :3 0 163
164 0 4e :2 0
165 166 0 168
bb 16a 15c 162
0 16b 0 168
0 16b bd 0
16c c0 1b6 3e
:3 0 9 :3 0 3c
:3 0 16f 170 0
3d :3 0 171 172
0 1ac 1c :3 0
1d :3 0 174 175
0 1c :3 0 2d
:3 0 177 178 0
3f :2 0 2 :4 0
4f :2 0 2f :2 0
12 :2 0 c3 17d
17f :3 0 c6 179
181 176 183 182
:2 0 1f :3 0 30
:3 0 185 186 0
21 :4 0 50 :4 0
24 :2 0 25 :3 0
ca 18a 18c :3 0
24 :2 0 42 :4 0
cd 18e 190 :3 0
24 :2 0 43 :4 0
d0 192 194 :3 0
24 :2 0 3d :3 0
d3 196 198 :3 0
24 :2 0 44 :4 0
d6 19a 19c :3 0
24 :2 0 45 :3 0
46 :3 0 12 :2 0
47 :2 0 d9 19f
1a3 dd 19e 1a5
:3 0 e0 187 1a7
:2 0 1a9 e3 1aa
184 1a9 0 1ab
e5 0 1ac e7
1af :3 0 1af 0
1af 1ae 1ac 1ad
:6 0 1b1 4 :3 0
ea 1b3 ec 1b2
1b1 :2 0 1b4 ee
:2 0 1b6 0 1b6
1b5 16c 1b4 :6 0
223 1 :3 0 51
:3 0 52 :3 0 3a
:3 0 b :3 0 3a
:3 0 53 :3 0 54
:3 0 55 :3 0 56
:4 0 57 1 :8 0
1d7 4c :4 0 1c2
:3 0 4d :3 0 48
:2 0 f2 1c5 1c6
:3 0 9 :3 0 3c
:3 0 1c8 1c9 0
14 :2 0 1ca 1cb
0 1cd f5 1d4
9 :3 0 3c :3 0
1ce 1cf 0 4e
:2 0 1d0 1d1 0
1d3 f7 1d5 1c7
1cd 0 1d6 0
1d3 0 1d6 f9
0 1d7 fc 221
3e :3 0 9 :3 0
3c :3 0 1da 1db
0 3d :3 0 1dc
1dd 0 217 1c
:3 0 1d :3 0 1df
1e0 0 1c :3 0
2d :3 0 1e2 1e3
0 3f :2 0 2
:4 0 58 :2 0 2f
:2 0 12 :2 0 ff
1e8 1ea :3 0 102
1e4 1ec 1e1 1ee
1ed :2 0 1f :3 0
30 :3 0 1f0 1f1
0 21 :4 0 59
:4 0 24 :2 0 25
:3 0 106 1f5 1f7
:3 0 24 :2 0 42
:4 0 109 1f9 1fb
:3 0 24 :2 0 43
:4 0 10c 1fd 1ff
:3 0 24 :2 0 3d
:3 0 10f 201 203
:3 0 24 :2 0 44
:4 0 112 205 207
:3 0 24 :2 0 45
:3 0 46 :3 0 12
:2 0 47 :2 0 115
20a 20e 119 209
210 :3 0 11c 1f2
212 :2 0 214 11f
215 1ef 214 0
216 121 0 217
123 21a :3 0 21a
0 21a 219 217
218 :6 0 21c 6
:3 0 126 21e 128
21d 21c :2 0 21f
12a :2 0 221 0
221 220 1d7 21f
:6 0 223 1 :3 0
12c 28e 39 :3 0
4a :3 0 36 :3 0
37 :3 0 38 :3 0
3a :3 0 b :4 0
5a 1 :8 0 241
4c :4 0 22c :3 0
4d :3 0 48 :2 0
131 22f 230 :3 0
9 :3 0 3c :3 0
232 233 0 14
:2 0 234 235 0
237 134 23e 9
:3 0 3c :3 0 238
239 0 4e :2 0
23a 23b 0 23d
136 23f 231 237
0 240 0 23d
0 240 138 0
241 13b 28b 3e
:3 0 9 :3 0 3c
:3 0 244 245 0
3d :3 0 246 247
0 281 1c :3 0
1d :3 0 249 24a
0 1c :3 0 2d
:3 0 24c 24d 0
3f :2 0 2 :4 0
5b :2 0 2f :2 0
12 :2 0 13e 252
254 :3 0 141 24e
256 24b 258 257
:2 0 1f :3 0 30
:3 0 25a 25b 0
21 :4 0 5c :4 0
24 :2 0 25 :3 0
145 25f 261 :3 0
24 :2 0 42 :4 0
148 263 265 :3 0
24 :2 0 43 :4 0
14b 267 269 :3 0
24 :2 0 3d :3 0
14e 26b 26d :3 0
24 :2 0 44 :4 0
151 26f 271 :3 0
24 :2 0 45 :3 0
46 :3 0 12 :2 0
47 :2 0 154 274
278 158 273 27a
:3 0 15b 25c 27c
:2 0 27e 15e 27f
259 27e 0 280
160 0 281 162
284 :3 0 284 0
284 283 281 282
:6 0 286 8 :3 0
165 288 167 287
286 :2 0 289 169
:2 0 28b 0 28b
28a 241 289 :6 0
28d 1 :3 0 16b
28f 14f 223 0
290 0 28d 0
290 16d 0 2fc
5d :3 0 5e :3 0
5f :3 0 60 :3 0
5e :3 0 55 :3 0
61 :3 0 53 :3 0
e :4 0 62 1
:8 0 2b0 4c :4 0
29b :3 0 4d :3 0
48 :2 0 172 29e
29f :3 0 9 :3 0
3c :3 0 2a1 2a2
0 14 :2 0 2a3
2a4 0 2a6 175
2ad 9 :3 0 3c
:3 0 2a7 2a8 0
4e :2 0 2a9 2aa
0 2ac 177 2ae
2a0 2a6 0 2af
0 2ac 0 2af
179 0 2b0 17c
2fa 3e :3 0 9
:3 0 3c :3 0 2b3
2b4 0 3d :3 0
2b5 2b6 0 2f0
1c :3 0 1d :3 0
2b8 2b9 0 1c
:3 0 2d :3 0 2bb
2bc 0 3f :2 0
2 :4 0 63 :2 0
2f :2 0 12 :2 0
17f 2c1 2c3 :3 0
182 2bd 2c5 2ba
2c7 2c6 :2 0 1f
:3 0 30 :3 0 2c9
2ca 0 21 :4 0
64 :4 0 24 :2 0
25 :3 0 186 2ce
2d0 :3 0 24 :2 0
42 :4 0 189 2d2
2d4 :3 0 24 :2 0
43 :4 0 18c 2d6
2d8 :3 0 24 :2 0
3d :3 0 18f 2da
2dc :3 0 24 :2 0
44 :4 0 192 2de
2e0 :3 0 24 :2 0
45 :3 0 46 :3 0
12 :2 0 47 :2 0
195 2e3 2e7 199
2e2 2e9 :3 0 19c
2cb 2eb :2 0 2ed
19f 2ee 2c8 2ed
0 2ef 1a1 0
2f0 1a3 2f3 :3 0
2f3 0 2f3 2f2
2f0 2f1 :6 0 2f5
a :3 0 1a6 2f7
1a8 2f6 2f5 :2 0
2f8 1aa :2 0 2fa
0 2fa 2f9 2b0
2f8 :6 0 2fc 1
:3 0 1ac 59b 29
:3 0 13 :3 0 14
:2 0 1af 2fd 300
48 :2 0 49 :2 0
1b4 302 304 :3 0
39 :3 0 65 :3 0
66 :3 0 67 :3 0
3a :3 0 b :4 0
68 1 :8 0 322
4c :4 0 30d :3 0
4d :3 0 48 :2 0
1b9 310 311 :3 0
9 :3 0 3c :3 0
313 314 0 14
:2 0 315 316 0
318 1bc 31f 9
:3 0 3c :3 0 319
31a 0 4e :2 0
31b 31c 0 31e
1be 320 312 318
0 321 0 31e
0 321 1c0 0
322 1c3 36c 3e
:3 0 9 :3 0 3c
:3 0 325 326 0
3d :3 0 327 328
0 362 1c :3 0
1d :3 0 32a 32b
0 1c :3 0 2d
:3 0 32d 32e 0
3f :2 0 2 :4 0
69 :2 0 2f :2 0
12 :2 0 1c6 333
335 :3 0 1c9 32f
337 32c 339 338
:2 0 1f :3 0 30
:3 0 33b 33c 0
21 :4 0 6a :4 0
24 :2 0 25 :3 0
1cd 340 342 :3 0
24 :2 0 42 :4 0
1d0 344 346 :3 0
24 :2 0 43 :4 0
1d3 348 34a :3 0
24 :2 0 3d :3 0
1d6 34c 34e :3 0
24 :2 0 44 :4 0
1d9 350 352 :3 0
24 :2 0 45 :3 0
46 :3 0 12 :2 0
47 :2 0 1dc 355
359 1e0 354 35b
:3 0 1e3 33d 35d
:2 0 35f 1e6 360
33a 35f 0 361
1e8 0 362 1ea
365 :3 0 365 0
365 364 362 363
:6 0 367 c :3 0
1ed 369 1ef 368
367 :2 0 36a 1f1
:2 0 36c 0 36c
36b 322 36a :6 0
3d9 1 :3 0 5d
:3 0 5e :3 0 5f
:3 0 60 :3 0 5e
:3 0 55 :3 0 61
:3 0 53 :3 0 e
:4 0 62 1 :8 0
38d 4c :4 0 378
:3 0 4d :3 0 48
:2 0 1f5 37b 37c
:3 0 9 :3 0 3c
:3 0 37e 37f 0
14 :2 0 380 381
0 383 1f8 38a
9 :3 0 3c :3 0
384 385 0 4e
:2 0 386 387 0
389 1fa 38b 37d
383 0 38c 0
389 0 38c 1fc
0 38d 1ff 3d7
3e :3 0 9 :3 0
3c :3 0 390 391
0 3d :3 0 392
393 0 3cd 1c
:3 0 1d :3 0 395
396 0 1c :3 0
2d :3 0 398 399
0 3f :2 0 2
:4 0 6b :2 0 2f
:2 0 12 :2 0 202
39e 3a0 :3 0 205
39a 3a2 397 3a4
3a3 :2 0 1f :3 0
30 :3 0 3a6 3a7
0 21 :4 0 6c
:4 0 24 :2 0 25
:3 0 209 3ab 3ad
:3 0 24 :2 0 42
:4 0 20c 3af 3b1
:3 0 24 :2 0 43
:4 0 20f 3b3 3b5
:3 0 24 :2 0 3d
:3 0 212 3b7 3b9
:3 0 24 :2 0 44
:4 0 215 3bb 3bd
:3 0 24 :2 0 45
:3 0 46 :3 0 12
:2 0 47 :2 0 218
3c0 3c4 21c 3bf
3c6 :3 0 21f 3a8
3c8 :2 0 3ca 222
3cb 3a5 3ca 0
3cc 224 0 3cd
226 3d0 :3 0 3d0
0 3d0 3cf 3cd
3ce :6 0 3d2 e
:3 0 229 3d4 22b
3d3 3d2 :2 0 3d5
22d :2 0 3d7 0
3d7 3d6 38d 3d5
:6 0 3d9 1 :3 0
22f 597 45 :3 0
11 :3 0 12 :2 0
12 :2 0 232 3da
3de 48 :2 0 49
:4 0 238 3e0 3e2
:3 0 39 :3 0 65
:3 0 66 :3 0 67
:3 0 4a :3 0 35
:3 0 37 :3 0 3a
:3 0 b :4 0 6d
1 :8 0 403 4c
:4 0 3ee :3 0 4d
:3 0 48 :2 0 23d
3f1 3f2 :3 0 9
:3 0 3c :3 0 3f4
3f5 0 14 :2 0
3f6 3f7 0 3f9
240 400 9 :3 0
3c :3 0 3fa 3fb
0 4e :2 0 3fc
3fd 0 3ff 242
401 3f3 3f9 0
402 0 3ff 0
402 244 0 403
247 44d 3e :3 0
9 :3 0 3c :3 0
406 407 0 3d
:3 0 408 409 0
443 1c :3 0 1d
:3 0 40b 40c 0
1c :3 0 2d :3 0
40e 40f 0 3f
:2 0 2 :4 0 6e
:2 0 2f :2 0 12
:2 0 24a 414 416
:3 0 24d 410 418
40d 41a 419 :2 0
1f :3 0 30 :3 0
41c 41d 0 21
:4 0 6f :4 0 24
:2 0 25 :3 0 251
421 423 :3 0 24
:2 0 42 :4 0 254
425 427 :3 0 24
:2 0 43 :4 0 257
429 42b :3 0 24
:2 0 3d :3 0 25a
42d 42f :3 0 24
:2 0 44 :4 0 25d
431 433 :3 0 24
:2 0 45 :3 0 46
:3 0 12 :2 0 47
:2 0 260 436 43a
264 435 43c :3 0
267 41e 43e :2 0
440 26a 441 41b
440 0 442 26c
0 443 26e 446
:3 0 446 0 446
445 443 444 :6 0
448 10 :3 0 271
44a 273 449 448
:2 0 44b 275 :2 0
44d 0 44d 44c
403 44b :6 0 4ba
1 :3 0 51 :3 0
52 :3 0 3a :3 0
b :3 0 3a :3 0
53 :3 0 54 :3 0
55 :3 0 56 :4 0
70 1 :8 0 46e
4c :4 0 459 :3 0
4d :3 0 48 :2 0
279 45c 45d :3 0
9 :3 0 3c :3 0
45f 460 0 14
:2 0 461 462 0
464 27c 46b 9
:3 0 3c :3 0 465
466 0 4e :2 0
467 468 0 46a
27e 46c 45e 464
0 46d 0 46a
0 46d 280 0
46e 283 4b8 3e
:3 0 9 :3 0 3c
:3 0 471 472 0
3d :3 0 473 474
0 4ae 1c :3 0
1d :3 0 476 477
0 1c :3 0 2d
:3 0 479 47a 0
3f :2 0 2 :4 0
71 :2 0 2f :2 0
12 :2 0 286 47f
481 :3 0 289 47b
483 478 485 484
:2 0 1f :3 0 30
:3 0 487 488 0
21 :4 0 72 :4 0
24 :2 0 25 :3 0
28d 48c 48e :3 0
24 :2 0 42 :4 0
290 490 492 :3 0
24 :2 0 43 :4 0
293 494 496 :3 0
24 :2 0 3d :3 0
296 498 49a :3 0
24 :2 0 44 :4 0
299 49c 49e :3 0
24 :2 0 45 :3 0
46 :3 0 12 :2 0
47 :2 0 29c 4a1
4a5 2a0 4a0 4a7
:3 0 2a3 489 4a9
:2 0 4ab 2a6 4ac
486 4ab 0 4ad
2a8 0 4ae 2aa
4b1 :3 0 4b1 0
4b1 4b0 4ae 4af
:6 0 4b3 12 :3 0
2ad 4b5 2af 4b4
4b3 :2 0 4b6 2b1
:2 0 4b8 0 4b8
4b7 46e 4b6 :6 0
4ba 1 :3 0 2b3
528 39 :3 0 65
:3 0 66 :3 0 67
:3 0 4a :3 0 36
:3 0 37 :3 0 38
:3 0 3a :3 0 b
:4 0 73 1 :8 0
4db 4c :4 0 4c6
:3 0 4d :3 0 48
:2 0 2b8 4c9 4ca
:3 0 9 :3 0 3c
:3 0 4cc 4cd 0
14 :2 0 4ce 4cf
0 4d1 2bb 4d8
9 :3 0 3c :3 0
4d2 4d3 0 4e
:2 0 4d4 4d5 0
4d7 2bd 4d9 4cb
4d1 0 4da 0
4d7 0 4da 2bf
0 4db 2c2 525
3e :3 0 9 :3 0
3c :3 0 4de 4df
0 3d :3 0 4e0
4e1 0 51b 1c
:3 0 1d :3 0 4e3
4e4 0 1c :3 0
2d :3 0 4e6 4e7
0 3f :2 0 2
:4 0 74 :2 0 2f
:2 0 12 :2 0 2c5
4ec 4ee :3 0 2c8
4e8 4f0 4e5 4f2
4f1 :2 0 1f :3 0
30 :3 0 4f4 4f5
0 21 :4 0 75
:4 0 24 :2 0 25
:3 0 2cc 4f9 4fb
:3 0 24 :2 0 42
:4 0 2cf 4fd 4ff
:3 0 24 :2 0 43
:4 0 2d2 501 503
:3 0 24 :2 0 3d
:3 0 2d5 505 507
:3 0 24 :2 0 44
:4 0 2d8 509 50b
:3 0 24 :2 0 45
:3 0 46 :3 0 12
:2 0 47 :2 0 2db
50e 512 2df 50d
514 :3 0 2e2 4f6
516 :2 0 518 2e5
519 4f3 518 0
51a 2e7 0 51b
2e9 51e :3 0 51e
0 51e 51d 51b
51c :6 0 520 14
:3 0 2ec 522 2ee
521 520 :2 0 523
2f0 :2 0 525 0
525 524 4db 523
:6 0 527 1 :3 0
2f2 529 3e3 4ba
0 52a 0 527
0 52a 2f4 0
596 5d :3 0 5e
:3 0 5f :3 0 60
:3 0 5e :3 0 55
:3 0 61 :3 0 53
:3 0 e :4 0 62
1 :8 0 54a 4c
:4 0 535 :3 0 4d
:3 0 48 :2 0 2f9
538 539 :3 0 9
:3 0 3c :3 0 53b
53c 0 14 :2 0
53d 53e 0 540
2fc 547 9 :3 0
3c :3 0 541 542
0 4e :2 0 543
544 0 546 2fe
548 53a 540 0
549 0 546 0
549 300 0 54a
303 594 3e :3 0
9 :3 0 3c :3 0
54d 54e 0 3d
:3 0 54f 550 0
58a 1c :3 0 1d
:3 0 552 553 0
1c :3 0 2d :3 0
555 556 0 3f
:2 0 2 :4 0 76
:2 0 2f :2 0 12
:2 0 306 55b 55d
:3 0 309 557 55f
554 561 560 :2 0
1f :3 0 30 :3 0
563 564 0 21
:4 0 77 :4 0 24
:2 0 25 :3 0 30d
568 56a :3 0 24
:2 0 42 :4 0 310
56c 56e :3 0 24
:2 0 43 :4 0 313
570 572 :3 0 24
:2 0 3d :3 0 316
574 576 :3 0 24
:2 0 44 :4 0 319
578 57a :3 0 24
:2 0 45 :3 0 46
:3 0 12 :2 0 47
:2 0 31c 57d 581
320 57c 583 :3 0
323 565 585 :2 0
587 326 588 562
587 0 589 328
0 58a 32a 58d
:3 0 58d 0 58d
58c 58a 58b :6 0
58f 16 :3 0 32d
591 32f 590 58f
:2 0 592 331 :2 0
594 0 594 593
54a 592 :6 0 596
1 :3 0 333 598
305 3d9 0 599
0 596 0 599
336 0 59a 339
59c 145 2fc 0
59d 0 59a 0
59d 33b 0 73f
78 :3 0 29 :3 0
13 :3 0 14 :2 0
33e 59f 5a2 12
:2 0 341 59e 5a5
5a6 :2 0 48 :2 0
12 :2 0 346 5a8
5aa :3 0 5ab :2 0
29 :3 0 19 :3 0
14 :2 0 349 5ad
5b0 79 :2 0 14
:2 0 34e 5b2 5b4
:3 0 5b5 :2 0 5ac
5b7 5b6 :2 0 1a
:3 0 7a :3 0 29
:3 0 18 :3 0 14
:2 0 351 5bb 5be
7b :2 0 29 :3 0
17 :3 0 14 :2 0
354 5c1 5c4 357
5c0 5c6 :3 0 5c7
:2 0 7c :2 0 7d
:2 0 35a 5c9 5cb
:3 0 5cc :2 0 7e
:2 0 29 :3 0 19
:3 0 14 :2 0 35d
5cf 5d2 360 5ce
5d4 :3 0 363 5ba
5d6 5b9 5d7 0
65c 1a :3 0 79
:2 0 12 :2 0 367
5da 5dc :3 0 5dd
:2 0 1a :3 0 7f
:2 0 7e :2 0 12
:2 0 36a 5e1 5e3
:3 0 36e 5e0 5e5
:3 0 5de 5e7 5e6
:2 0 39 :3 0 5e
:3 0 5f :3 0 60
:3 0 5e :3 0 55
:3 0 80 :3 0 81
:3 0 81 :3 0 4a
:3 0 82 :3 0 81
:3 0 3a :3 0 b
:4 0 83 1 :8 0
60d 4c :4 0 5f8
:3 0 4d :3 0 48
:2 0 373 5fb 5fc
:3 0 9 :3 0 3c
:3 0 5fe 5ff 0
14 :2 0 600 601
0 603 376 60a
9 :3 0 3c :3 0
604 605 0 4e
:2 0 606 607 0
609 378 60b 5fd
603 0 60c 0
609 0 60c 37a
0 60d 37d 657
3e :3 0 9 :3 0
3c :3 0 610 611
0 3d :3 0 612
613 0 64d 1c
:3 0 1d :3 0 615
616 0 1c :3 0
2d :3 0 618 619
0 3f :2 0 2
:4 0 84 :2 0 2f
:2 0 12 :2 0 380
61e 620 :3 0 383
61a 622 617 624
623 :2 0 1f :3 0
30 :3 0 626 627
0 21 :4 0 85
:4 0 24 :2 0 25
:3 0 387 62b 62d
:3 0 24 :2 0 42
:4 0 38a 62f 631
:3 0 24 :2 0 43
:4 0 38d 633 635
:3 0 24 :2 0 3d
:3 0 390 637 639
:3 0 24 :2 0 44
:4 0 393 63b 63d
:3 0 24 :2 0 45
:3 0 46 :3 0 12
:2 0 47 :2 0 396
640 644 39a 63f
646 :3 0 39d 628
648 :2 0 64a 3a0
64b 625 64a 0
64c 3a2 0 64d
3a4 650 :3 0 650
0 650 64f 64d
64e :6 0 652 18
:3 0 3a7 654 3a9
653 652 :2 0 655
3ab :2 0 657 0
657 656 60d 655
:6 0 659 1 :3 0
3ad 65a 5e8 659
0 65b 3af 0
65c 3b1 6c8 39
:3 0 81 :3 0 81
:3 0 4a :3 0 82
:3 0 81 :3 0 3a
:3 0 b :4 0 86
1 :8 0 67b 4c
:4 0 666 :3 0 4d
:3 0 48 :2 0 3b6
669 66a :3 0 9
:3 0 3c :3 0 66c
66d 0 14 :2 0
66e 66f 0 671
3b9 678 9 :3 0
3c :3 0 672 673
0 4e :2 0 674
675 0 677 3bb
679 66b 671 0
67a 0 677 0
67a 3bd 0 67b
3c0 6c5 3e :3 0
9 :3 0 3c :3 0
67e 67f 0 3d
:3 0 680 681 0
6bb 1c :3 0 1d
:3 0 683 684 0
1c :3 0 2d :3 0
686 687 0 3f
:2 0 2 :4 0 87
:2 0 2f :2 0 12
:2 0 3c3 68c 68e
:3 0 3c6 688 690
685 692 691 :2 0
1f :3 0 30 :3 0
694 695 0 21
:4 0 88 :4 0 24
:2 0 25 :3 0 3ca
699 69b :3 0 24
:2 0 42 :4 0 3cd
69d 69f :3 0 24
:2 0 43 :4 0 3d0
6a1 6a3 :3 0 24
:2 0 3d :3 0 3d3
6a5 6a7 :3 0 24
:2 0 44 :4 0 3d6
6a9 6ab :3 0 24
:2 0 45 :3 0 46
:3 0 12 :2 0 47
:2 0 3d9 6ae 6b2
3dd 6ad 6b4 :3 0
3e0 696 6b6 :2 0
6b8 3e3 6b9 693
6b8 0 6ba 3e5
0 6bb 3e7 6be
:3 0 6be 0 6be
6bd 6bb 6bc :6 0
6c0 1a :3 0 3ea
6c2 3ec 6c1 6c0
:2 0 6c3 3ee :2 0
6c5 0 6c5 6c4
67b 6c3 :6 0 6c7
1 :3 0 3f0 6c9
5b8 65c 0 6ca
0 6c7 0 6ca
3f2 0 73f 9
:3 0 3c :3 0 6cb
6cc 0 9 :3 0
48 :2 0 89 :3 0
6ce 6d0 0 3f7
6cf 6d2 :3 0 6d3
:2 0 29 :3 0 13
:3 0 14 :2 0 3fa
6d5 6d8 8a :2 0
49 :2 0 3ff 6da
6dc :3 0 6dd :2 0
6d4 6df 6de :2 0
15 :3 0 8b :3 0
d :3 0 b :3 0
402 6e2 6e5 6e1
6e6 0 6e8 405
6e9 6e0 6e8 0
6ea 407 0 73f
15 :3 0 8c :3 0
d :3 0 409 6ec
6ee 6eb 6ef 0
73f 1c :3 0 1d
:3 0 6f1 6f2 0
1c :3 0 2d :3 0
6f4 6f5 0 8d
:2 0 2 :4 0 8e
:2 0 2f :2 0 12
:2 0 40b 6fa 6fc
:3 0 40e 6f6 6fe
6f3 700 6ff :2 0
1f :3 0 30 :3 0
702 703 0 21
:4 0 8f :4 0 24
:2 0 25 :3 0 412
707 709 :3 0 24
:2 0 42 :4 0 415
70b 70d :3 0 24
:2 0 90 :4 0 418
70f 711 :3 0 24
:2 0 29 :3 0 2a
:3 0 9 :3 0 3c
:3 0 716 717 0
41b 715 719 2b
:4 0 41d 714 71c
420 713 71e :3 0
24 :2 0 91 :4 0
423 720 722 :3 0
24 :2 0 27 :4 0
426 724 726 :3 0
24 :2 0 3 :3 0
429 728 72a :3 0
24 :2 0 27 :4 0
42c 72c 72e :3 0
42f 704 730 :2 0
732 432 733 701
732 0 734 434
0 73f 92 :3 0
93 :3 0 735 736
0 9 :3 0 3c
:3 0 738 739 0
3 :3 0 4d :3 0
436 737 73d :2 0
73f 43a 7e0 9
:3 0 94 :2 0 4
740 741 0 1c
:3 0 1d :3 0 743
744 0 1c :3 0
2d :3 0 746 747
0 3f :2 0 2
:4 0 95 :2 0 2f
:2 0 12 :2 0 446
74c 74e :3 0 449
748 750 745 752
751 :2 0 1f :3 0
30 :3 0 754 755
0 21 :4 0 96
:4 0 24 :2 0 25
:3 0 44d 759 75b
:3 0 450 756 75d
:2 0 776 1f :3 0
30 :3 0 75f 760
0 21 :4 0 97
:4 0 24 :2 0 9
:3 0 98 :3 0 765
766 0 453 764
768 :3 0 24 :2 0
91 :4 0 456 76a
76c :3 0 24 :2 0
9 :3 0 99 :3 0
76f 770 0 459
76e 772 :3 0 45c
761 774 :2 0 776
45f 777 753 776
0 778 462 0
788 9a :3 0 1b
:3 0 9 :3 0 98
:3 0 9b :3 0 9
:3 0 99 :3 0 3
:3 0 9c :4 0 9d
1 :a 0 784 :2 0
788 77a 782 :2 0
8 :3 0 1b :3 0
786 :2 0 788 464
78a 468 789 788
:2 0 7de 3e :3 0
9 :3 0 3c :3 0
78d 78e 0 3d
:3 0 78f 790 0
7d6 1c :3 0 1d
:3 0 792 793 0
1c :3 0 2d :3 0
795 796 0 3f
:2 0 2 :4 0 9e
:2 0 2f :2 0 12
:2 0 46a 79b 79d
:3 0 46d 797 79f
794 7a1 7a0 :2 0
1f :3 0 30 :3 0
7a3 7a4 0 21
:4 0 9f :4 0 24
:2 0 25 :3 0 471
7a8 7aa :3 0 474
7a5 7ac :2 0 7c6
1f :3 0 30 :3 0
7ae 7af 0 21
:4 0 43 :4 0 24
:2 0 3d :3 0 477
7b3 7b5 :3 0 24
:2 0 44 :4 0 47a
7b7 7b9 :3 0 24
:2 0 45 :3 0 46
:3 0 12 :2 0 47
:2 0 47d 7bc 7c0
481 7bb 7c2 :3 0
484 7b0 7c4 :2 0
7c6 487 7c7 7a2
7c6 0 7c8 48a
0 7d6 9a :3 0
1b :3 0 9b :3 0
9 :3 0 99 :3 0
3 :3 0 9c :4 0
a0 1 :a 0 7d2
:2 0 7d6 7ca 7d0
:2 0 8 :3 0 1b
:3 0 7d4 :2 0 7d6
48c 7d9 :3 0 7d9
0 7d9 7d8 7d6
7d7 :6 0 7db 1
:3 0 491 7dd 493
7dc 7db :2 0 7de
495 :2 0 7e0 498
7e0 7df 73f 7de
:6 0 7e1 :2 0 2
14 7e0 7e4 :3 0
7e3 7e1 7e5 :8 0

4a6
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2b 1 32 1
30 1 37 1
3d 1 43 1
49 1 4f 1
55 1 5b 1
60 1 6d 1
79 2 7c 7e
2 81 83 2
85 87 2 89
8b 2 8d 8f
1 95 2 97
98 2 91 9a
2 9c 9e 2
a0 a2 2 a4
a6 2 a8 aa
2 ac ae 4
75 7b 80 b0
1 b2 1 b4
2 be c0 3
bc bd c2 2
cb cd 2 ca
cf 1 d1 1
d3 2 eb f0
2 101 103 3
ff 100 105 2
10e 110 2 112
114 2 116 118
2 11a 11c 2
11e 120 3 125
126 127 2 122
129 2 10d 12b
1 12d 1 12f
2 f8 130 1
134 1 f3 1
138 2 13e 13f
1 143 2 141
143 3 147 148
149 1 14d 2
14b 14d 1 159
2 158 159 1
161 1 167 2
169 16a 2 156
16b 2 17c 17e
3 17a 17b 180
2 189 18b 2
18d 18f 2 191
193 2 195 197
2 199 19b 3
1a0 1a1 1a2 2
19d 1a4 2 188
1a6 1 1a8 1
1aa 2 173 1ab
1 1af 1 16e
1 1b3 1 1c4
2 1c3 1c4 1
1cc 1 1d2 2
1d4 1d5 2 1c1
1d6 2 1e7 1e9
3 1e5 1e6 1eb
2 1f4 1f6 2
1f8 1fa 2 1fc
1fe 2 200 202
2 204 206 3
20b 20c 20d 2
208 20f 2 1f3
211 1 213 1
215 2 1de 216
1 21a 1 1d9
1 21e 2 1b6
221 1 22e 2
22d 22e 1 236
1 23c 2 23e
23f 2 22b 240
2 251 253 3
24f 250 255 2
25e 260 2 262
264 2 266 268
2 26a 26c 2
26e 270 3 275
276 277 2 272
279 2 25d 27b
1 27d 1 27f
2 248 280 1
284 1 243 1
288 1 28b 2
28e 28f 1 29d
2 29c 29d 1
2a5 1 2ab 2
2ad 2ae 2 29a
2af 2 2c0 2c2
3 2be 2bf 2c4
2 2cd 2cf 2
2d1 2d3 2 2d5
2d7 2 2d9 2db
2 2dd 2df 3
2e4 2e5 2e6 2
2e1 2e8 2 2cc
2ea 1 2ec 1
2ee 2 2b7 2ef
1 2f3 1 2b2
1 2f7 2 290
2fa 2 2fe 2ff
1 303 2 301
303 1 30f 2
30e 30f 1 317
1 31d 2 31f
320 2 30c 321
2 332 334 3
330 331 336 2
33f 341 2 343
345 2 347 349
2 34b 34d 2
34f 351 3 356
357 358 2 353
35a 2 33e 35c
1 35e 1 360
2 329 361 1
365 1 324 1
369 1 37a 2
379 37a 1 382
1 388 2 38a
38b 2 377 38c
2 39d 39f 3
39b 39c 3a1 2
3aa 3ac 2 3ae
3b0 2 3b2 3b4
2 3b6 3b8 2
3ba 3bc 3 3c1
3c2 3c3 2 3be
3c5 2 3a9 3c7
1 3c9 1 3cb
2 394 3cc 1
3d0 1 38f 1
3d4 2 36c 3d7
3 3db 3dc 3dd
1 3e1 2 3df
3e1 1 3f0 2
3ef 3f0 1 3f8
1 3fe 2 400
401 2 3ed 402
2 413 415 3
411 412 417 2
420 422 2 424
426 2 428 42a
2 42c 42e 2
430 432 3 437
438 439 2 434
43b 2 41f 43d
1 43f 1 441
2 40a 442 1
446 1 405 1
44a 1 45b 2
45a 45b 1 463
1 469 2 46b
46c 2 458 46d
2 47e 480 3
47c 47d 482 2
48b 48d 2 48f
491 2 493 495
2 497 499 2
49b 49d 3 4a2
4a3 4a4 2 49f
4a6 2 48a 4a8
1 4aa 1 4ac
2 475 4ad 1
4b1 1 470 1
4b5 2 44d 4b8
1 4c8 2 4c7
4c8 1 4d0 1
4d6 2 4d8 4d9
2 4c5 4da 2
4eb 4ed 3 4e9
4ea 4ef 2 4f8
4fa 2 4fc 4fe
2 500 502 2
504 506 2 508
50a 3 50f 510
511 2 50c 513
2 4f7 515 1
517 1 519 2
4e2 51a 1 51e
1 4dd 1 522
1 525 2 528
529 1 537 2
536 537 1 53f
1 545 2 547
548 2 534 549
2 55a 55c 3
558 559 55e 2
567 569 2 56b
56d 2 56f 571
2 573 575 2
577 579 3 57e
57f 580 2 57b
582 2 566 584
1 586 1 588
2 551 589 1
58d 1 54c 1
591 2 52a 594
2 597 598 1
599 2 59b 59c
2 5a0 5a1 2
5a3 5a4 1 5a9
2 5a7 5a9 2
5ae 5af 1 5b3
2 5b1 5b3 2
5bc 5bd 2 5c2
5c3 2 5bf 5c5
2 5c8 5ca 2
5d0 5d1 2 5cd
5d3 1 5d5 1
5db 2 5d9 5db
1 5e2 1 5e4
2 5df 5e4 1
5fa 2 5f9 5fa
1 602 1 608
2 60a 60b 2
5f7 60c 2 61d
61f 3 61b 61c
621 2 62a 62c
2 62e 630 2
632 634 2 636
638 2 63a 63c
3 641 642 643
2 63e 645 2
629 647 1 649
1 64b 2 614
64c 1 650 1
60f 1 654 1
657 1 65a 2
5d8 65b 1 668
2 667 668 1
670 1 676 2
678 679 2 665
67a 2 68b 68d
3 689 68a 68f
2 698 69a 2
69c 69e 2 6a0
6a2 2 6a4 6a6
2 6a8 6aa 3
6af 6b0 6b1 2
6ac 6b3 2 697
6b5 1 6b7 1
6b9 2 682 6ba
1 6be 1 67d
1 6c2 1 6c5
2 6c8 6c9 1
6d1 2 6cd 6d1
2 6d6 6d7 1
6db 2 6d9 6db
2 6e3 6e4 1
6e7 1 6e9 1
6ed 2 6f9 6fb
3 6f7 6f8 6fd
2 706 708 2
70a 70c 2 70e
710 1 718 2
71a 71b 2 712
71d 2 71f 721
2 723 725 2
727 729 2 72b
72d 2 705 72f
1 731 1 733
3 73a 73b 73c
b b5 d4 d7
da 13b 59d 6ca
6ea 6f0 734 73e
2 74b 74d 3
749 74a 74f 2
758 75a 2 757
75c 2 763 767
2 769 76b 2
76d 771 2 762
773 2 75e 775
1 777 3 778
783 787 1 742
2 79a 79c 3
798 799 79e 2
7a7 7a9 2 7a6
7ab 2 7b2 7b4
2 7b6 7b8 3
7bd 7be 7bf 2
7ba 7c1 2 7b1
7c3 2 7ad 7c5
1 7c7 4 791
7c8 7d1 7d5 1
7d9 1 78c 2
78a 7dd d 1b
22 29 2e 35
3b 41 47 4d
53 59 5e 65

1
4
0 
7e4
0
1
28
1c
11
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 0 0 0 0
0 0 0 0 0 0 0 0

b 1 0
3 1 0
55 1 0
16 1 0
2 0 1
3d 1 0
2b 1 0
37 1 0
49 1 0
24 1 0
4f 1 0
30 1 0
43 1 0
1d 1 0
7 1 0
5b 1 0
60 1 0
0

/
SHOW ERRORS FUNCTION SP_RJCT_ETC_ASSIGN;
ALTER FUNCTION SP_RJCT_ETC_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Reject ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_RJCT_ETC_WBS ==
CREATE OR REPLACE FUNCTION SP_RJCT_ETC_WBS wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
e8
2 :e:
1FUNCTION:
1SP_RJCT_ETC_WBS:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_FINISH_DATE:
1TIMESTAMP:
1H_PROJECT_ID:
132:
1H_RANK:
1200:
1H_START_DATE:
1H_TASK_ID:
1H_TSK_ASSIGNMENT_ID:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_EFFORT:
1H_TYPE:
1H_START_D:
1DATE:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_TEMP_SC_NODATA:
1H_STEPS_EXIST:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1H_TEMP_SC_STATE_ALERT:
1H_ALERT_ID:
1H_REC_USER:
1H_CALLTYPE:
1H_TABLE_TYPE:
1I_STEPS_EXIST:
1I_PERCENT_COMPLETE:
1CURSOR:
1CAWTSKR:
1ELEMENT_ID:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1SCHED_START:
1FORECAST_FINISH:
1SCHED_FINISH:
1TMT_WBS:
1PROJECT_ID:
1RANK:
1TYPE_ID:
1PMO_CNST:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1WORK_TODATE:
1ETC:
1SELECT ELEMENT_ID, SCHED_EFFORT+PLANNED_EFFORT,:n         CASE WHEN FORECAST_+
1START IS NULL THEN SCHED_START ELSE FORECAST_START END,:n         CASE WHEN F+
1ORECAST_FINISH IS NULL THEN SCHED_FINISH ELSE FORECAST_FINISH END:n         F+
1ROM TMT_WBS:n         WHERE PROJECT_ID = h_project_id AND RANK LIKE h_rank AN+
1D TYPE_ID IN (PMO_CNST.SC_TASK,PMO_CNST.SC_TASK_TYPE1,PMO_CNST.SC_TASK_TYPE2,+
1PMO_CNST.SC_TASK_TYPE3,PMO_CNST.SC_MILESTONE,PMO_CNST.SC_PERSONAL_TASK,PMO_CN+
1ST.SC_ACTIVE_ADM_TASK,PMO_CNST.SC_INACTIVE_ADM_TASK,PMO_CNST.SC_WBS_CHANGE_RE+
1QUEST_TASK,PMO_CNST.SC_WBS_ACTION_ITEM_TASK,PMO_CNST.SC_WBS_RISK_TASK,PMO_CNS+
1T.SC_WBS_ISSUE_TASK,PMO_CNST.SC_WBS_REQUIREMENT_TASK,PMO_CNST.SC_WBS_DEFECT_T+
1ASK,PMO_CNST.SC_WBS_SERVICE_REQUEST_TASK):n         AND (((SCHED_EFFORT+PLANN+
1ED_EFFORT) > 0 AND ((SCHED_EFFORT+PLANNED_EFFORT-WORK_TODATE) <> ETC)):n     +
1    OR (FORECAST_START IS NOT NULL OR FORECAST_FINISH IS NOT NULL)):
1CAWASSR:
1TSK_ASSIGNMENT_ID:
1BIT_FLAG:
1BEST:
1SCHED_WORK:
1PLANNED_WORK:
1MILESTONE_PERCENT:
1TASK_ASSIGNMENTS:
1TASK_ID:
1SELECT TSK_ASSIGNMENT_ID, BIT_FLAG, BEST, SCHED_WORK+PLANNED_WORK, WORK_TODAT+
1E, MILESTONE_PERCENT:n         FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_+
1ID = h_project_id:n         AND TASK_ID = h_task_id:n         AND (((SCHED_WO+
1RK+PLANNED_WORK) > 0 AND ((SCHED_WORK+PLANNED_WORK-WORK_TODATE) <> ETC)):n   +
1      OR (FORECAST_START IS NOT NULL OR FORECAST_FINISH IS NOT NULL)):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_RJCT_ETC_WBS(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_RJCT_ETC_WBS(61) :: cplan.sql(19079) :: :
13:
1SCETCFORCASTREJECTED:
1RTRIM:
1SELECT PROJECT_ID, RTRIM(RANK), TYPE_ID:n      INTO h_project_id, h_rank, h_t+
1ype:n      FROM TMT_WBS WHERE ELEMENT_ID = id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
183:
1           EXCEPTION:: SP_RJCT_ETC_WBS(84) :: cplan.sql(19102) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_SUCCESS:
1IS NOT NULL:
1%:
1-:
1START_FINISH_DATE:
1SELECT START_FINISH_DATE INTO h_start_D FROM TMT_WBS WHERE ELEMENT_ID = h_pro+
1ject_id:
1101:
1           EXCEPTION:: SP_RJCT_ETC_WBS(102) :: cplan.sql(19120) :: :
1OPEN:
1LOOP:
1FOUND:
1100:
1!=:
1EXIT:
12:
1FORECAST_DURATION:
1UPDATE TMT_WBS SET:n                  FORECAST_START = NULL,:n               +
1   FORECAST_FINISH = NULL,:n                  FORECAST_DURATION = 0:n        +
1          WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1TRUE:
1141:
1           EXCEPTION:: SP_RJCT_ETC_WBS(142) :: cplan.sql(19160) :: :
1FC_ISSUE_ALERT:
1CONTINUE0000:
1ACTIVITIES:
1ETC_MODIFIED:
1SC_TIMESHEET_ACTIVITY:
1UPDATE ACTIVITIES:n                        SET ETC_MODIFIED = 'N':n          +
1              WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n                +
1        AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n                        AND TYPE+
1_ID = PMO_CNST.SC_TIMESHEET_ACTIVITY:
1190:
1           EXCEPTION:: SP_RJCT_ETC_WBS(191) :: cplan.sql(19209) :: :
1PROPOSED_START:
1PROPOSED_FINISH:
1PROPOSED_WORK:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1BAK_ASSIGN_STRING:
1ASSIGN_STRING:
1ACTUAL_FINISH:
1UPDATE TASK_ASSIGNMENTS SET:n                           PROPOSED_START      =+
1 SCHED_START,:n                           PROPOSED_FINISH     = SCHED_FINISH,+
1:n                           PROPOSED_WORK       = SCHED_WORK,:n             +
1              BAK_START_DT        = SCHED_START,:n                           +
1BAK_FINISH_DT       = SCHED_FINISH,:n                           BAK_WORK     +
1       = SCHED_WORK,:n                           BAK_ASSIGN_STRING   = ASSIGN+
1_STRING,:n                           BEST                = SCHED_WORK,:n     +
1                      ETC                 = SCHED_WORK - WORK_TODATE,:n      +
1                     ACTUAL_FINISH       = NULL:n                           W+
1HERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1219:
1           EXCEPTION:: SP_RJCT_ETC_WBS(220) :: cplan.sql(19238) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           SCHED_WORK	= SCHED_WO+
1RK,:n                           ETC			= SCHED_WORK - WORK_TODATE:n           +
1                WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1247:
1           EXCEPTION:: SP_RJCT_ETC_WBS(248) :: cplan.sql(19266) :: :
1ACTUAL_DURATION:
1UPDATE TASK_ASSIGNMENTS SET:n                        ETC					= PLANNED_WORK, +
1:n                        MILESTONE_PERCENT	= 0 ,:n                        AC+
1TUAL_FINISH		= NULL, :n                        ACTUAL_DURATION		= 0:n        +
1                WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1270:
1           EXCEPTION:: SP_RJCT_ETC_WBS(271) :: cplan.sql(19289) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                        FORECAST_START = NULL,:n+
1                        FORECAST_FINISH = NULL,:n                        FORE+
1CAST_DURATION = 0:n                        WHERE TSK_ASSIGNMENT_ID = h_tsk_as+
1signment_id:
1295:
1           EXCEPTION:: SP_RJCT_ETC_WBS(296) :: cplan.sql(19314) :: :
1UPDATE ACTIVITIES:n                           SET ETC_MODIFIED = 'N':n       +
1                    WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n          +
1                 AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n                       +
1    AND TYPE_ID = PMO_CNST.SC_TIMESHEET_ACTIVITY:
1318:
1           EXCEPTION:: SP_RJCT_ETC_WBS(319) :: cplan.sql(19337) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           FORECAST_START = NULL+
1,:n                           FORECAST_FINISH = NULL,:n                      +
1     FORECAST_DURATION = 0,:n                           SCHED_WORK = CASE WHE+
1N PROPOSED_WORK > WORK_TODATE THEN PROPOSED_WORK ELSE SCHED_WORK END,:n      +
1                     ETC = CASE WHEN PROPOSED_WORK > WORK_TODATE THEN PROPOSE+
1D_WORK - WORK_TODATE ELSE 0 END/*,:n                           MILESTONE_PERC+
1ENT = (WORK_TODATE * 10000) / SCHED_WORK*/:n                           WHERE +
1TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1342:
1           EXCEPTION:: SP_RJCT_ETC_WBS(343) :: cplan.sql(19361) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           FORECAST_START = NULL+
1,:n                           FORECAST_FINISH = NULL,:n                      +
1     FORECAST_DURATION = 0,:n                           ETC = PLANNED_WORK, M+
1ILESTONE_PERCENT = 0:n                           WHERE TSK_ASSIGNMENT_ID = h_+
1tsk_assignment_id:
1364:
1           EXCEPTION:: SP_RJCT_ETC_WBS(365) :: cplan.sql(19383) :: :
1SC_SQL_NO_DATA:
1BITAND:
1>:
1TRUNC:
1/:
1*:
110000.00:
1<:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS SET:n                           ROLLUP_BITS = PMO_STP+
1U.BIT_OR(ROLLUP_BITS,PMO_CNST.SC_PERCENT_COMPLETE_BIT),:n                    +
1       ACTUAL_FINISH = CASE:n                           WHEN ACTUAL_FINISH IS+
1 NULL AND ETC = 0 THEN SCHED_FINISH:n                           ELSE ACTUAL_F+
1INISH:n                           END:n                           WHERE TSK_A+
1SSIGNMENT_ID = h_tsk_assignment_id:
1405:
1           EXCEPTION:: SP_RJCT_ETC_WBS(406) :: cplan.sql(19424) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           ACTUAL_FINISH = CASE +
1WHEN (ACTUAL_FINISH IS NULL) AND ETC = 0 THEN SCHED_FINISH ELSE ACTUAL_FINISH+
1 END:n                           WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_i+
1d:
1424:
1           EXCEPTION:: SP_RJCT_ETC_WBS(425) :: cplan.sql(19443) :: :
1FC_FIX_SUMMARY_TS:
1CLOSE:
1447:
1           EXCEPTION:: SP_RJCT_ETC_WBS(448) :: cplan.sql(19466) :: :
1CONSTRAINT_TYPE:
1TO_DATE:
1CONSTRAINT_DT:
1UPDATE TMT_WBS SET:n            CONSTRAINT_TYPE =:n            CASE:n        +
1    WHEN TO_DATE(SubStr(SCHED_START, 1, 10)) <> TO_DATE(SubStr(h_start_D, 1, +
110)) THEN 6:n            ELSE 0:n            END,:n            CONSTRAINT_DT +
1=:n            CASE:n            WHEN TO_DATE(SubStr(SCHED_START, 1, 10)) <> +
1TO_DATE(SubStr(h_start_D, 1, 10)) THEN SCHED_START:n            ELSE NULL:n  +
1          END:n            WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h+
1_task_id:
1477:
1           EXCEPTION:: SP_RJCT_ETC_WBS(478) :: cplan.sql(19496) :: :
1494:
1           EXCEPTION:: SP_RJCT_ETC_WBS(495) :: cplan.sql(19513) :: :
1FC_ROLLUP:
14:
1506:
1       RETURN_STATUS:: SP_RJCT_ETC_WBS(507) :: cplan.sql(19525) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1513:
1           EXCEPTION:: SP_RJCT_ETC_WBS(514) :: cplan.sql(19532) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1525:
1           EXCEPTION:: SP_RJCT_ETC_WBS(526) :: cplan.sql(19544) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
aad
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a0 f4 b4
bf c8 :35 a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :14 a0 12a
bd b7 11 a4 b1 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d :2 a0 d a0 51 d a0 6e
d :a a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 7e b4
2e :2 5a a 10 :3 a0 7e 6e b4
2e :2 51 a5 b d a0 7e 51
b4 2e d :5 a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 e9
dd b3 :6 a0 e9 d3 5 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 2b b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 51 d :8 a0 51
a5 b a5 b d b7 a0 3b
b7 :2 19 3c b7 :2 a0 e9 dd b3
:8 a0 e9 d3 5 :2 a0 f :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 2b b7 19 3c
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 :2 51 a5 b 7e
6e b4 2e :9 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
:2 7e 51 b4 2e b4 2e :17 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :2 a0 51 a5 b 7e 51
b4 2e :6 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 a0 :2 51 a5 b
7e 6e b4 2e :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :10 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 19 3c b7 :2 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a a0 51 d b7 19 3c
a0 51 d :8 a0 51 a5 b a5
b d :2 a0 51 a5 b 7e 51
b4 2e :3 a0 51 a5 b 51 a5
b 5a 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :4 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e 5a 7e 51
b4 2e 5a 7e :2 a0 51 a5 b
b4 2e a5 b d a0 7e 51
b4 2e 5a a0 :2 7e 51 b4 2e
b4 2e 52 10 :e a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :8 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :4 a0 a5 b d b7 19
3c b7 19 3c b7 a0 47 :2 a0
e9 c1 :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :14 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f 93
4f b0 46 b7 a0 47 :2 a0 e9
c1 :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b :2 7e 51
b4 2e b4 2e :3 a0 a5 b d
b7 19 3c b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :2 a0 6b :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e :2 a0 6b b4 2e 7e 6e b4
2e 7e :2 a0 6b b4 2e a5 57
b7 19 3c :9 a0 12a e9 dd :2 a0
65 b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c :7 a0 12a e9 dd :2 a0 65 b7
a4 b1 11 4f b7 a6 9 a4
b1 11 68 4f 1d 17 b5 
aad
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 82 71
75 7d 70 9f 8d 6d 91 92
9a 8c bc aa 89 ae af b7
a9 d8 c7 cb d3 a6 f4 df
e3 e6 e7 ef c6 111 ff c3
103 104 10c fe 12e 11c fb 120
121 129 11b 14a 139 13d 118 145
138 166 155 159 135 161 154 182
171 175 151 17d 170 19e 18d 191
199 16d 1b9 1a5 1a9 1b1 1b4 18c
1d5 1c4 1c8 189 1d0 1c3 1f1 1e0
1e4 1c0 1ec 1df 20d 1fc 200 1dc
208 1fb 229 218 21c 1f8 224 217
245 234 238 214 240 233 261 250
254 230 25c 24f 27d 26c 270 24c
278 26b 29a 288 268 28c 28d 295
287 2b7 2a5 284 2a9 2aa 2b2 2a4
2d3 2c2 2c6 2a1 2ce 2c1 2ef 2de
2e2 2be 2ea 2dd 30b 2fa 2fe 2da
306 2f9 327 316 31a 322 2f6 312
32e 33f 340 343 347 34b 34f 353
357 35b 35f 363 367 36b 36f 373
377 37b 37f 383 387 38b 38f 393
397 39b 39f 3a3 3a7 3ab 3af 3b3
3b7 3bb 3bf 3c3 3c7 3cb 3cf 3d3
3d7 3db 3df 3e3 3e7 3eb 3ef 3f3
3f7 3fb 3ff 403 407 40b 40f 413
417 41b 427 42c 42e 43a 43e 440
444 455 456 459 45d 461 465 469
46d 471 475 479 47d 481 485 489
48d 491 495 499 49d 4a1 4a5 4a9
4ad 4b9 4be 4c0 4cc 4d0 4ee 4d6
4da 4de 4e1 4e9 4d5 4f5 4f9 4d2
4fd 501 505 508 50d 50e 1 510
515 519 51d 520 525 529 52d 530
535 536 538 53d 540 544 545 54a
54f 552 557 558 55d 560 564 565
56a 56d 572 573 578 57b 580 581
586 589 58d 591 595 596 598 59d
59e 5a0 5a1 5a6 5a9 5ae 5af 5b4
5b7 5bc 5bd 5c2 5c5 5c9 5ca 5cf
5d2 5d7 5d8 5dd 5e0 5e5 5e6 5eb
5ec 5f1 5f3 5f7 5fa 5fe 602 605
609 60d 610 613 618 61b 61e 621
622 627 628 1 62a 62f 633 637
63a 63f 644 647 64b 64c 651 652
657 659 65d 660 664 668 66c 670
674 678 67c 67f 683 687 68c 690
694 698 69c 6a0 6a4 6a8 6ac 6b0
6b4 6b8 6c4 6c8 6cc 6cf 6d3 6d7
6d9 1 6dd 6e1 6e5 6e8 6ec 6f0
6f4 6f8 6fb 6ff 703 706 709 70e
711 714 717 718 71d 71e 1 720
725 729 72d 730 735 73a 73d 741
742 747 74a 74f 750 755 758 75d
75e 763 766 76a 76b 770 773 778
779 77e 781 785 789 78c 78f 790
792 793 798 799 79e 7a0 7a4 7a7
7a9 7ad 7af 7bb 7bd 7bf 7c0 7c5
7c9 7cb 7d7 7d9 7dd 7e1 7e4 7e8
7eb 7ef 7f2 7f3 7f8 7fb 7ff 802
803 808 80b 1 80e 813 817 81b
81f 822 827 828 82d 830 833 834
836 83a 83e 841 844 845 84a 84e
852 856 85a 85e 862 86e 872 876
879 87d 881 883 1 887 88b 88f
892 896 89a 89e 8a2 8a5 8a9 8ad
8b0 8b3 8b8 8bb 8be 8c1 8c2 8c7
8c8 1 8ca 8cf 8d3 8d7 8da 8df
8e4 8e7 8eb 8ec 8f1 8f4 8f9 8fa
8ff 902 907 908 90d 910 914 915
91a 91d 922 923 928 92b 92f 933
936 939 93a 93c 93d 942 943 948
94a 94e 951 953 957 959 965 967
969 96a 96f 973 975 981 983 987
98b 990 994 995 999 99d 9a1 9a5
9a9 9ad 9b2 9b7 9bb 9bf 9c3 9c8
9cc 9d0 9d3 9d6 9da 9dc 9e0 9e4
9e7 9ea 9ee 9f0 9f4 9f8 9fb 9ff
a03 a06 a0a a0d a11 a14 a15 a1a
a1d a21 a27 a29 a2d a30 a34 a38
a3b a3c a3e a41 a44 a45 a4a a4e
a52 a55 a56 a58 a5b a5e a5f a64
a68 a6c a70 a74 a78 a7c a80 a84
a90 a94 a99 a9d aa0 aa1 aa6 aaa
aae ab1 ab4 ab8 aba abe ac2 ac5
ac8 acc ace ad2 ad6 ad9 adb 1
adf ae3 ae7 aea aee af2 af6 afa
afd b01 b05 b08 b0b b10 b13 b16
b19 b1a b1f b20 1 b22 b27 b2b
b2f b32 b37 b3c b3f b43 b44 b49
b4c b51 b52 b57 b5a b5f b60 b65
b68 b6c b6d b72 b75 b7a b7b b80
b83 b87 b8b b8e b91 b92 b94 b95
b9a b9b ba0 ba2 ba6 ba9 bab baf
bb1 bbd bbf bc1 bc2 bc7 bcb bcd
bd9 bdb bdf be2 be6 bea bee bf2
bf6 bfa bfe c02 c06 c09 c0a c0c
c0d c0f c13 c15 c19 c1f c21 c25
c29 c2c c2e c32 c36 c3b c3f c40
c44 c48 c4c c50 c54 c58 c5c c60
c65 c6a c6e c72 c76 c7b c7f c83
c86 c89 c8d c8f c93 c97 c9a c9d
ca1 ca3 ca7 cab cae cb2 cb6 cb9
cbd cc0 cc4 cc7 cc8 ccd cd0 cd4
cda cdc ce0 ce3 ce7 cea cee cf2
cf6 cf9 cfa cfc cff d02 d03 d08
d0c d10 d13 d16 d17 d19 d1c d21
d22 d27 d2b d2f d33 d37 d3b d3f
d43 d47 d4b d57 d5b d60 d64 d67
d68 d6d d71 d75 d78 d7b d7f d81
d85 d89 d8c d8f d93 d95 d99 d9d
da0 da2 1 da6 daa dae db1 db5
db9 dbd dc1 dc4 dc8 dcc dcf dd2
dd7 dda ddd de0 de1 de6 de7 1
de9 dee df2 df6 df9 dfe e03 e06
e0a e0b e10 e13 e18 e19 e1e e21
e26 e27 e2c e2f e33 e34 e39 e3c
e41 e42 e47 e4a e4e e52 e55 e58
e59 e5b e5c e61 e62 e67 e69 e6d
e70 e72 e76 e78 e84 e86 e88 e89
e8e e92 e94 ea0 ea2 ea6 eaa ead
eae eb0 eb3 eb6 eb9 eba ebf ec0
ec5 ec9 ecd ed1 ed5 ed9 edd ee1
ee5 ee9 eed ef1 ef5 ef9 efd f01
f05 f09 f0d f11 f15 f19 f1d f21
f2d f31 f36 f3a f3d f3e f43 f47
f4b f4e f51 f55 f57 f5b f5f f62
f65 f69 f6b f6f f73 f76 f78 1
f7c f80 f84 f87 f8b f8f f93 f97
f9a f9e fa2 fa5 fa8 fad fb0 fb3
fb6 fb7 fbc fbd 1 fbf fc4 fc8
fcc fcf fd4 fd9 fdc fe0 fe1 fe6
fe9 fee fef ff4 ff7 ffc ffd 1002
1005 1009 100a 100f 1012 1017 1018 101d
1020 1024 1028 102b 102e 102f 1031 1032
1037 1038 103d 103f 1043 1046 1048 104c
104e 105a 105c 105e 105f 1064 1068 106a
1076 1078 107a 107e 1082 1086 108a 108e
1092 1096 109a 10a6 10aa 10af 10b3 10b6
10b7 10bc 10c0 10c4 10c7 10ca 10ce 10d0
10d4 10d8 10db 10de 10e2 10e4 10e8 10ec
10ef 10f1 1 10f5 10f9 10fd 1100 1104
1108 110c 1110 1113 1117 111b 111e 1121
1126 1129 112c 112f 1130 1135 1136 1
1138 113d 1141 1145 1148 114d 1152 1155
1159 115a 115f 1162 1167 1168 116d 1170
1175 1176 117b 117e 1182 1183 1188 118b
1190 1191 1196 1199 119d 11a1 11a4 11a7
11a8 11aa 11ab 11b0 11b1 11b6 11b8 11bc
11bf 11c1 11c5 11c7 11d3 11d5 11d7 11d8
11dd 11e1 11e3 11ef 11f1 11f3 11f7 11fb
11fe 1200 1204 1208 120c 1210 1214 1218
121c 1220 122c 1230 1235 1239 123c 123d
1242 1246 124a 124d 1250 1254 1256 125a
125e 1261 1264 1268 126a 126e 1272 1275
1277 1 127b 127f 1283 1286 128a 128e
1292 1296 1299 129d 12a1 12a4 12a7 12ac
12af 12b2 12b5 12b6 12bb 12bc 1 12be
12c3 12c7 12cb 12ce 12d3 12d8 12db 12df
12e0 12e5 12e8 12ed 12ee 12f3 12f6 12fb
12fc 1301 1304 1308 1309 130e 1311 1316
1317 131c 131f 1323 1327 132a 132d 132e
1330 1331 1336 1337 133c 133e 1342 1345
1347 134b 134d 1359 135b 135d 135e 1363
1367 1369 1375 1377 1379 137d 1381 1384
1386 138a 138e 1391 1392 1394 1397 139a
139b 13a0 13a4 13a8 13ac 13b0 13b4 13b8
13c4 13c8 13cd 13d1 13d4 13d5 13da 13de
13e2 13e5 13e8 13ec 13ee 13f2 13f6 13f9
13fc 1400 1402 1406 140a 140d 140f 1
1413 1417 141b 141e 1422 1426 142a 142e
1431 1435 1439 143c 143f 1444 1447 144a
144d 144e 1453 1454 1 1456 145b 145f
1463 1466 146b 1470 1473 1477 1478 147d
1480 1485 1486 148b 148e 1493 1494 1499
149c 14a0 14a1 14a6 14a9 14ae 14af 14b4
14b7 14bb 14bf 14c2 14c5 14c6 14c8 14c9
14ce 14cf 14d4 14d6 14da 14dd 14df 14e3
14e5 14f1 14f3 14f5 14f6 14fb 14ff 1501
150d 150f 1511 1515 1519 151c 151f 1520
1522 1525 152a 152b 1530 1534 1538 153c
1540 1544 1548 154c 1550 1554 1560 1564
1569 156d 1570 1571 1576 157a 157e 1581
1584 1588 158a 158e 1592 1595 1598 159c
159e 15a2 15a6 15a9 15ab 1 15af 15b3
15b7 15ba 15be 15c2 15c6 15ca 15cd 15d1
15d5 15d8 15db 15e0 15e3 15e6 15e9 15ea
15ef 15f0 1 15f2 15f7 15fb 15ff 1602
1607 160c 160f 1613 1614 1619 161c 1621
1622 1627 162a 162f 1630 1635 1638 163c
163d 1642 1645 164a 164b 1650 1653 1657
165b 165e 1661 1662 1664 1665 166a 166b
1670 1672 1676 1679 167b 167f 1681 168d
168f 1691 1692 1697 169b 169d 16a9 16ab
16af 16b3 16b7 16bb 16bf 16c3 16c7 16cb
16cf 16d3 16d7 16db 16df 16e3 16e7 16eb
16f7 16fb 1700 1704 1707 1708 170d 1711
1715 1718 171b 171f 1721 1725 1729 172c
172f 1733 1735 1739 173d 1740 1742 1
1746 174a 174e 1751 1755 1759 175d 1761
1764 1768 176c 176f 1772 1777 177a 177d
1780 1781 1786 1787 1 1789 178e 1792
1796 1799 179e 17a3 17a6 17aa 17ab 17b0
17b3 17b8 17b9 17be 17c1 17c6 17c7 17cc
17cf 17d3 17d4 17d9 17dc 17e1 17e2 17e7
17ea 17ee 17f2 17f5 17f8 17f9 17fb 17fc
1801 1802 1807 1809 180d 1810 1812 1816
1818 1824 1826 1828 1829 182e 1832 1834
1840 1842 1844 1848 184c 1850 1854 1858
185c 1860 1864 1868 1874 1878 187d 1881
1884 1885 188a 188e 1892 1895 1898 189c
189e 18a2 18a6 18a9 18ac 18b0 18b2 18b6
18ba 18bd 18bf 1 18c3 18c7 18cb 18ce
18d2 18d6 18da 18de 18e1 18e5 18e9 18ec
18ef 18f4 18f7 18fa 18fd 18fe 1903 1904
1 1906 190b 190f 1913 1916 191b 1920
1923 1927 1928 192d 1930 1935 1936 193b
193e 1943 1944 1949 194c 1950 1951 1956
1959 195e 195f 1964 1967 196b 196f 1972
1975 1976 1978 1979 197e 197f 1984 1986
198a 198d 198f 1993 1995 19a1 19a3 19a5
19a6 19ab 19af 19b1 19bd 19bf 19c1 19c5
19c9 19cc 19ce 19d2 19d6 19d9 19db 19df
19e3 19e6 19ea 19ee 19f1 19f5 19f8 19fc
19ff 1a00 1a05 1a08 1a0c 1a0f 1a13 1a15
1a19 1a1c 1a20 1a23 1a27 1a2b 1a2f 1a33
1a37 1a3b 1a3f 1a43 1a47 1a4a 1a4b 1a4d
1a4e 1a50 1a54 1a58 1a5c 1a5f 1a60 1a62
1a65 1a68 1a69 1a6e 1a72 1a76 1a7a 1a7d
1a7e 1a80 1a83 1a84 1a86 1a89 1a8c 1a8f
1a90 1a95 1a98 1a9c 1aa0 1aa3 1aa4 1aa6
1aa9 1aac 1aad 1ab2 1 1ab5 1aba 1abe
1ac2 1ac6 1aca 1acd 1ace 1ad0 1ad3 1ad7
1adb 1ade 1adf 1ae1 1ae2 1ae7 1aea 1aed
1af0 1af1 1af6 1af9 1afc 1b00 1b04 1b07
1b08 1b0a 1b0b 1b10 1b11 1b13 1b17 1b1b
1b1e 1b21 1b22 1b27 1b2a 1b2e 1b31 1b34
1b37 1b38 1b3d 1b3e 1 1b43 1b48 1b4c
1b50 1b54 1b58 1b5c 1b60 1b64 1b68 1b6c
1b70 1b74 1b78 1b7c 1b80 1b8c 1b90 1b95
1b99 1b9c 1b9d 1ba2 1ba6 1baa 1bad 1bb0
1bb4 1bb6 1bba 1bbe 1bc1 1bc4 1bc8 1bca
1bce 1bd2 1bd5 1bd7 1 1bdb 1bdf 1be3
1be6 1bea 1bee 1bf2 1bf6 1bf9 1bfd 1c01
1c04 1c07 1c0c 1c0f 1c12 1c15 1c16 1c1b
1c1c 1 1c1e 1c23 1c27 1c2b 1c2e 1c33
1c38 1c3b 1c3f 1c40 1c45 1c48 1c4d 1c4e
1c53 1c56 1c5b 1c5c 1c61 1c64 1c68 1c69
1c6e 1c71 1c76 1c77 1c7c 1c7f 1c83 1c87
1c8a 1c8d 1c8e 1c90 1c91 1c96 1c97 1c9c
1c9e 1ca2 1ca5 1ca7 1cab 1cad 1cb9 1cbb
1cbd 1cbe 1cc3 1cc7 1cc9 1cd5 1cd7 1cd9
1cdd 1ce1 1ce5 1ce9 1ced 1cf1 1cf5 1cf9
1d05 1d09 1d0e 1d12 1d15 1d16 1d1b 1d1f
1d23 1d26 1d29 1d2d 1d2f 1d33 1d37 1d3a
1d3d 1d41 1d43 1d47 1d4b 1d4e 1d50 1
1d54 1d58 1d5c 1d5f 1d63 1d67 1d6b 1d6f
1d72 1d76 1d7a 1d7d 1d80 1d85 1d88 1d8b
1d8e 1d8f 1d94 1d95 1 1d97 1d9c 1da0
1da4 1da7 1dac 1db1 1db4 1db8 1db9 1dbe
1dc1 1dc6 1dc7 1dcc 1dcf 1dd4 1dd5 1dda
1ddd 1de1 1de2 1de7 1dea 1def 1df0 1df5
1df8 1dfc 1e00 1e03 1e06 1e07 1e09 1e0a
1e0f 1e10 1e15 1e17 1e1b 1e1e 1e20 1e24
1e26 1e32 1e34 1e36 1e37 1e3c 1e40 1e42
1e4e 1e50 1e52 1e56 1e5a 1e5d 1e61 1e65
1e69 1e6d 1e6e 1e70 1e74 1e76 1e7a 1e7d
1e7f 1e83 1e86 1e88 1e8c 1e93 1e97 1e9b
1ea0 1ea2 1ea6 1eaa 1ead 1eb1 1eb5 1eb7
1 1ebb 1ebf 1ec3 1ec6 1eca 1ece 1ed2
1ed6 1ed9 1edd 1ee1 1ee4 1ee7 1eec 1eef
1ef2 1ef5 1ef6 1efb 1efc 1 1efe 1f03
1f07 1f0b 1f0e 1f13 1f18 1f1b 1f1f 1f20
1f25 1f28 1f2d 1f2e 1f33 1f36 1f3b 1f3c
1f41 1f44 1f48 1f49 1f4e 1f51 1f56 1f57
1f5c 1f5f 1f63 1f67 1f6a 1f6d 1f6e 1f70
1f71 1f76 1f77 1f7c 1f7e 1f82 1f85 1f87
1f8b 1f8d 1f99 1f9b 1f9d 1f9e 1fa3 1fa7
1fa9 1fb5 1fb7 1fb9 1fbd 1fc1 1fc4 1fc8
1fcc 1fd0 1fd4 1fd8 1fdc 1fe0 1fe4 1fe8
1fec 1ff0 1ff4 1ff8 1ffc 2000 2004 2008
200c 2010 2014 2020 2024 2029 202d 2030
2031 2036 203a 203e 2041 2044 2048 204a
204e 2052 2055 2058 205c 205e 2062 2066
2069 206b 1 206f 2073 2077 207a 207e
2082 2086 208a 208d 2091 2095 2098 209b
20a0 20a3 20a6 20a9 20aa 20af 20b0 1
20b2 20b7 20bb 20bf 20c2 20c7 20cc 20cf
20d3 20d4 20d9 20dc 20e1 20e2 20e7 20ea
20ef 20f0 20f5 20f8 20fc 20fd 2102 2105
210a 210b 2110 2113 2117 211b 211e 2121
2122 2124 2125 212a 212b 2130 2132 2136
2139 213b 213f 2141 214d 214f 2151 2152
2157 215b 215d 2169 216b 2173 2175 2176
2179 217b 217f 2186 218a 218e 2193 2195
2199 219d 21a0 21a4 21a8 21aa 1 21ae
21b2 21b6 21b9 21bd 21c1 21c5 21c9 21cc
21d0 21d4 21d7 21da 21df 21e2 21e5 21e8
21e9 21ee 21ef 1 21f1 21f6 21fa 21fe
2201 2206 220b 220e 2212 2213 2218 221b
2220 2221 2226 2229 222e 222f 2234 2237
223b 223c 2241 2244 2249 224a 224f 2252
2256 225a 225d 2260 2261 2263 2264 2269
226a 226f 2271 2275 2278 227a 227e 2280
228c 228e 2290 2291 2296 229a 229c 22a8
22aa 22ae 22b2 22b5 22b6 22b8 22bb 22be
22c1 22c2 22c7 22c8 22cd 22d1 22d5 22d9
22da 22dc 22e0 22e2 22e6 22e9 22eb 22ef
22f2 22f6 22fa 22fd 2301 2305 2308 230b
2310 2313 2316 2319 231a 231f 2320 1
2322 2327 232b 232f 2332 2337 233c 233f
2343 2344 2349 234c 2351 2352 2357 235a
235f 2360 2365 2368 236c 2370 2374 2378
237b 237c 237e 2383 2384 2386 2387 238c
238f 2394 2395 239a 239d 23a2 23a3 23a8
23ab 23af 23b0 23b5 23b8 23bd 23be 23c3
23c4 23c9 23cb 23cf 23d2 23d6 23da 23dd
23e1 23e5 23e8 23ec 23f0 23f1 23f6 23f8
23fc 2400 2403 2407 240b 240e 2412 2416
2419 241c 2421 2424 2427 242a 242b 2430
2431 1 2433 2438 243c 2440 2443 2448
244d 2450 2454 2455 245a 245b 2460 2464
2468 246b 2470 2475 2478 247c 2480 2483
2484 2489 248c 2491 2492 2497 249a 249e
24a2 24a5 24a6 24ab 24ac 24b1 24b3 24b7
24ba 24be 24c2 24c6 24ca 24ce 24d2 24d6
24da 24de 24ea 24ef 24f3 24f7 24fb 24ff
2501 2502 2507 1 250b 250f 2513 2516
251a 251e 2522 2526 2529 252d 2531 2534
2537 253c 253f 2542 2545 2546 254b 254c
1 254e 2553 2557 255b 255e 2563 2568
256b 256f 2570 2575 2576 257b 257f 2583
2586 258b 2590 2593 2597 2598 259d 25a0
25a5 25a6 25ab 25ae 25b2 25b6 25b9 25bc
25bd 25bf 25c0 25c5 25c6 25cb 25cd 25d1
25d4 25d8 25dc 25e0 25e4 25e8 25ec 25f0
25fc 2601 2605 2609 260d 2611 2613 2617
2619 2625 2627 2629 262a 262f 2633 2635
2641 2645 2647 2648 2651 
aad
2
0 1 a 6 9 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 :3 12 :2 4 11 1a 19 :2 11 :2 4
b 14 13 :2 b :2 4 :3 11 :2 4 e
17 16 :2 e :2 4 18 21 20 :2 18
:2 4 f 18 17 :2 f :2 4 :2 e 1d
e :2 4 :2 d 1c d :2 4 :2 b 1a
b :2 4 :3 e :2 4 :2 14 23 14 :2 4
:2 f 1e f :2 4 :2 15 24 15 :2 4
:2 12 21 12 :2 4 :2 11 20 11 :2 4
:2 12 21 12 :2 4 :2 13 22 13 :2 4
:2 1a 29 1a :2 4 f 18 17 :2 f
:2 4 f 18 17 :2 f :2 4 :2 f 1e
f :2 4 :2 11 20 11 :2 4 :2 12 2a
12 :2 4 :3 17 4 7 e 0 :2 7
11 1d 2a 14 30 41 14 31
43 f 10 1d 2e 38 43 4f
58 60 69 77 80 8e 97 a5
ae bb c4 d5 de f1 fa 10f
118 133 13c 154 15d 16e 177 189
192 1aa 1b3 1c6 1cf 11 1e 38
45 54 64 e 2c a :6 7 e
0 :2 7 11 24 2e 34 3f 4d
5a f 10 1d e 18 11 1c
34 3f 4c 5c e 2c a :5 7
4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 57 5d 60 :2 57 6e 87
8 :2 6e d 10 :2 6e 13 16 :2 6e
b e :2 6e 13 16 1f 27 :2 1f
34 :2 16 :2 6e b e :2 6e 13 16
:2 6e 1b 1e :2 6e 2a 2d :2 6e 32
35 :2 6e :2 7 4d :2 4 7 :2 11 23
:2 2d 39 3c 4f 51 52 :2 4f :2 23
:3 7 :2 d 12 1e 60 63 :2 1e :2 7
55 :3 4 11 :2 4 12 :2 4 12 :2 4
12 4 e 1a 20 27 c 1a
22 c 1a 27 :2 7 :2 10 1c 7
4 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 56 58 59 :2 56
:2 29 :3 d :2 13 18 24 66 69 :2 24
76 79 :2 24 7d 80 :2 24 8c 8f
:2 24 97 9a :2 24 a6 a9 b0 b9
bc :2 a9 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 8 :2 11 1c 1a :2 25
:2 1a 7 :4 3b 3a 39 :3 7 11 18
1f 22 :2 18 27 2a :2 11 :2 7 13
14 :2 13 7 11 28 37 45 52
:2 a :2 13 1f a 7 :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
59 5c 5d :2 59 :2 2c :3 10 :2 16 1b
27 6a 6d :2 27 7a 7d :2 27 81
84 :2 27 90 93 :2 27 9b 9e :2 27
aa ad b4 bd c0 :2 ad :2 27 :2 10
60 :2 d :2 a :4 16 :2 a 7 :3 50 7
c :4 7 10 1d 28 32 40 :3 a
d 15 :2 d :2 16 22 d 1b d
:2 16 22 d :4 a e :2 17 23 20
:2 2c :2 20 :3 d 3c :2 a d 16 20
:2 d 23 25 :2 23 10 19 24 :2 10
27 29 :2 27 1a :3 13 19 26 37
44 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 62 65 66 :2 62
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
83 86 :2 30 8a 8d :2 30 99 9c
:2 30 a4 a7 :2 30 b3 b6 bd c6
c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f
:2 13 10 :3 2b 10 20 :2 10 29 38
44 4f 5b 67 29 37 :2 67 :2 29
10 2b 15 10 :4 d 27 d 12
:4 d 16 23 38 44 50 5e 6d
:3 10 13 1b :2 13 :2 1c 28 13 21
13 :2 1c 28 13 :4 10 14 :2 1d 29
26 :2 32 :2 26 :3 13 42 :3 10 24 10
13 1c 27 :2 13 2a 2c :2 2a 16
1d 29 2c :2 16 2f 31 :2 2f 20
1d 1f 33 1d 32 1d 27 30
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 68 6b 6c :2 68 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :3 35 19 22 2e :2 19 31 33
34 :2 33 :2 31 23 1c 32 1c 32
1c 32 1c 32 1c 32 1c 32
1c 32 1c 32 1c 32 3f 1c
22 36 1c 23 1f 2b :3 29 1f
:2 28 34 1f 30 1f :2 28 34 1f
:4 1c 19 :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 6b 6e 6f
:2 6b :2 3e :3 22 :2 28 2d 39 7c 7f
:2 39 8c 8f :2 39 93 96 :2 39 a2
a5 :2 39 ad b0 :2 39 bc bf c6
cf d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c
:4 28 :2 1c 19 :4 36 23 1c 29 1c
24 31 22 36 1c 23 1f 2b
:3 29 1f :2 28 34 1f 30 1f :2 28
34 1f :4 1c 19 :2 21 1f :2 28 34
1f 22 :2 2c 3e :2 48 54 58 6b
6e 6f :2 6b :2 3e :3 22 :2 28 2d 39
7c 7f :2 39 8c 8f :2 39 93 96
:2 39 a2 a5 :2 39 ad b0 :2 39 bc
bf c6 cf d2 :2 bf :2 39 :2 22 72
:2 1f :2 1c :4 28 :2 1c 19 :7 16 35 20
19 23 :3 19 1f 33 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
68 6b 6c :2 68 :2 3b :3 1f :2 25 2a
36 79 7c :2 36 89 8c :2 36 90
93 :2 36 9f a2 :2 36 aa ad :2 36
b9 bc c3 cc cf :2 bc :2 36 :2 1f
6f :2 1c :2 19 :4 25 :2 19 16 :7 13 2e
16 1f 2a :2 16 2d 2f :2 2d 20
:3 19 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 68 6b
6c :2 68 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :4 31 19 20 2c
2f :2 19 32 34 :2 32 23 20 22
36 20 35 20 2a 33 1c 23
1f 2b :3 29 1f :2 28 34 1f 30
1f :2 28 34 1f :4 1c 19 :2 21 1f
:2 28 34 1f 22 :2 2c 3e :2 48 54
58 6b 6e 6f :2 6b :2 3e :3 22 :2 28
2d 39 7c 7f :2 39 8c 8f :2 39
93 96 :2 39 a2 a5 :2 39 ad b0
:2 39 bc bf c6 cf d2 :2 bf :2 39
:2 22 72 :2 1f :2 1c :4 28 :2 1c 19 :3 38
23 :4 1c 33 43 54 67 1c 2c
3c 4d 5d 22 36 1c 23 1f
2b :3 29 1f :2 28 34 1f 30 1f
:2 28 34 1f :4 1c 19 :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
6b 6e 6f :2 6b :2 3e :3 22 :2 28 2d
39 7c 7f :2 39 8c 8f :2 39 93
96 :2 39 a2 a5 :2 39 ad b0 :2 39
bc bf c6 cf d2 :2 bf :2 39 :2 22
72 :2 1f :2 1c :4 28 :2 1c 19 :4 38 23
:4 1c 22 30 22 36 1c 23 1f
2b :3 29 1f :2 28 34 1f 30 1f
:2 28 34 1f :4 1c 19 :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
6b 6e 6f :2 6b :2 3e :3 22 :2 28 2d
39 7c 7f :2 39 8c 8f :2 39 93
96 :2 39 a2 a5 :2 39 ad b0 :2 39
bc bf c6 cf d2 :2 bf :2 39 :2 22
72 :2 1f :2 1c :4 28 :2 1c 19 :7 16 :4 13
:4 10 14 :2 1d 28 26 :2 31 :2 26 :2 13
27 13 41 :3 10 20 :2 10 29 38
44 59 65 2b 34 42 :2 2b :2 29
10 13 1c 2e :2 13 31 33 :2 31
18 1f 28 33 :2 1f 37 :2 18 17
3b 3d :2 3b 16 45 4e 5e :2 45
61 63 :2 61 44 :3 16 2c 34 3d
4c :2 34 4f 51 5a 68 :2 51 :2 34
33 6c 6e :2 33 32 28 2a 33
43 :2 2a :2 32 :2 2c 16 1a 2d 2f
:2 2d 19 35 48 4a 4b :2 4a :2 48
:2 19 23 1c 2a 33 3a 46 4f
1c 21 3b 48 21 22 36 1c
23 1f 2b :3 29 1f :2 28 34 1f
30 1f :2 28 34 1f :4 1c 19 :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6b 6e 6f :2 6b :2 3e :3 22
:2 28 2d 39 7c 7f :2 39 8c 8f
:2 39 93 96 :2 39 a2 a5 :2 39 ad
b0 :2 39 bc bf c6 cf d2 :2 bf
:2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c 19
:4 4d 23 1c 37 52 5f 71 22
36 1c 23 1f 2b :3 29 1f :2 28
34 1f 30 1f :2 28 34 1f :4 1c
19 :2 21 1f :2 28 34 1f 22 :2 2c
3e :2 48 54 58 6b 6e 6f :2 6b
:2 3e :3 22 :2 28 2d 39 7c 7f :2 39
8c 8f :2 39 93 96 :2 39 a2 a5
:2 39 ad b0 :2 39 bc bf c6 cf
d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c :4 28
:2 1c 19 :8 16 29 3b 49 :2 29 16
66 :2 13 35 :2 10 d 11 a 10
16 :3 10 :2 19 25 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5f 62 63 :2 5f :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 96 99 :2 2d a1 a4
:2 2d b0 b3 ba c3 c6 :2 b3 :2 2d
:2 16 66 :2 13 :2 10 :4 1c :2 10 d :7 a
14 d 12 1a 21 39 41 48
d 12 1a 21 39 41 48 60
13 20 31 3e d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5c
5f 60 :2 5c :2 2f :3 13 :2 19 1e 2a
6d 70 :2 2a 7d 80 :2 2a 84 87
:2 2a 93 96 :2 2a 9e a1 :2 2a ad
b0 b7 c0 c3 :2 b0 :2 2a :2 13 63
:2 10 :2 d :4 19 :2 d a :3 7 c a
:3 7 b 50 a 10 :3 a :2 13 1f
a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 59 5c 5d
:2 59 :2 2c :3 10 :2 16 1b 27 6a 6d
:2 27 7a 7d :2 27 81 84 :2 27 90
93 :2 27 9b 9e :2 27 aa ad b4
bd c0 :2 ad :2 27 :2 10 60 :2 d :2 a
:4 16 :2 a 7 :3 50 a 13 1d :2 a
20 22 23 :2 22 :2 20 a 1d 27
:2 1d a 25 :2 7 50 :2 4 7 :2 11
23 :2 2d 39 3c 4f 52 53 :2 4f
:2 23 :3 7 :2 d 12 1e 61 64 :2 1e
71 74 :2 1e 78 7b :2 1e 85 88
91 99 :2 a2 :2 91 ad :2 88 :2 1e b5
b8 :2 1e c0 c3 :2 1e c8 cb :2 1e
ce d1 :2 1e :2 7 56 :3 4 :2 f 21
:2 2a 34 38 :2 4 1 9 12 9
a :2 14 26 :2 30 3c 40 53 56
57 :2 53 :2 26 :3 a :2 10 15 21 64
67 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 5a :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 50 53
54 :2 50 :2 23 :3 7 :2 d 12 1e 61
64 :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 57 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
aad
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:5 8 :7 9 :7 a :5 b
:7 c :7 d :7 e :6 f
:6 10 :6 11 :5 12 :6 13
:6 14 :6 15 :6 16 :6 17
:6 18 :6 19 :6 1a :7 1b
:7 1c :6 1d :6 1e :6 1f
:5 20 :2 22 0 :2 22
:3 23 :3 24 :3 25 26
:23 27 :6 28 :2 29 23
:5 22 :2 2b 0 :2 2b
:7 2c 2d :2 2e :2 2f
:6 30 :2 31 2c :5 2b
:7 33 :b 35 :11 36 37
:2 36 :2 37 :2 36 :2 37
:2 36 :2 38 :2 36 :9 38
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :4 36 :3 35
:11 3c :b 3d :3 3c :3 43
:3 46 :3 47 :3 48 :4 4b
:3 4c :3 4d 4b :5 4e
4a :2 50 :5 52 :11 53
:24 54 :3 53 :2 51 :6 50
4f :3 34 :12 5a :c 5b
:6 5c :6 5f :5 60 5e
:2 62 :5 64 :11 65 :24 66
:3 65 :2 63 :6 62 61
:3 5a :5 6b 6d :8 6e
:3 6f :5 70 6f :5 72
71 :3 6f :a 75 :2 76
:3 75 :9 7a :9 7c 7f
80 81 82 :4 83
7f :6 84 :5 85 84
:5 87 86 :3 84 7e
:2 8a :5 8c :11 8d :24 8e
:3 8d :2 8b :6 8a 89
:3 7c :3 94 :7 95 :2 96
:5 95 7c :2 98 97
:3 7c 7a :5 9d 9f
:a a0 :3 a1 :5 a2 a1
:5 a4 a3 :3 a1 :a a7
:2 a8 :3 a7 :3 ac :9 ad
:a ae b0 b1 :2 b2
:2 b3 :3 b4 b0 :6 b5
:5 b6 b5 :5 b8 b7
:3 b5 af :2 bb :5 bd
:11 be :24 bf :3 be :2 bc
:6 bb ba :3 ae :c c4
c6 :2 c7 :2 c8 :2 c9
:2 ca :2 cb :2 cc :2 cd
:2 ce :3 cf d0 :2 d1
c6 :6 d2 :5 d3 d2
:5 d5 d4 :3 d2 c5
:2 d8 :5 da :11 db :24 dc
:3 db :2 d9 :6 d8 d7
:4 c4 ea :2 eb :3 ec
:2 ed ea :6 ee :5 ef
ee :5 f1 f0 :3 ee
e9 :2 f4 :5 f6 :11 f7
:24 f8 :3 f7 :2 f5 :6 f4
f3 :4 e0 :3 c4 ae
ff :2 100 101 102
103 :2 104 ff :6 105
:5 106 105 :5 108 107
:3 105 fe :2 10b :5 10d
:11 10e :24 10f :3 10e :2 10c
:6 10b 10a :4 fd :3 ae
ad :9 116 119 11a
11b 11c :2 11d 119
:6 11e :5 11f 11e :5 121
120 :3 11e 118 :2 124
:5 126 :11 127 :24 128 :3 127
:2 125 :6 124 123 :4 116
:a 12e 130 131 :2 132
:2 133 :3 134 130 :6 135
:5 136 135 :5 138 137
:3 135 12f :2 13b :5 13d
:11 13e :24 13f :3 13e :2 13c
:6 13b 13a :3 12e 145
146 147 148 :5 149
:5 14a :2 14c 145 :6 14d
:5 14e 14d :5 150 14f
:3 14d 144 :2 153 :5 155
:11 156 :24 157 :3 156 :2 154
:6 153 152 :4 12e 15d
15e 15f 160 :3 161
:2 162 15d :6 163 :5 164
163 :5 166 165 :3 163
15c :2 169 :5 16b :11 16c
:24 16d :3 16c :2 16a :6 169
168 :4 15b :3 12e 12c
:3 116 115 :3 ad :a 175
:3 176 :3 175 :3 17a :6 17b
:5 17c :3 17b :9 17f :1b 180
:15 181 :6 182 :5 181 :10 183
185 :6 186 187 :3 188
189 :2 18b 185 :6 18c
:5 18d 18c :5 18f 18e
:3 18c 184 :2 192 :5 194
:11 195 :24 196 :3 195 :2 193
:6 192 191 :4 183 19c
:5 19d :2 19e 19c :6 19f
:5 1a0 19f :5 1a2 1a1
:3 19f 19b :2 1a5 :5 1a7
:11 1a8 :24 1a9 :3 1a8 :2 1a6
:6 1a5 1a4 :4 19a :3 183
:7 1b2 :3 180 :3 17f 9f
1b5 9a :4 1b9 :5 1ba
1b8 :2 1bc :5 1be :11 1bf
:24 1c0 :3 1bf :2 1bd :6 1bc
1bb :4 9a :3 7a 1c8
1c9 :6 1cb 1ce :7 1d0
:4 1d3 1c8 :6 1d4 :5 1d5
1d4 :5 1d7 1d6 :3 1d4
1c7 :2 1da :5 1dc :11 1dd
:24 1de :3 1dd :2 1db :6 1da
1d9 :3 6d 1e2 1e3
:3 6d 1e4 5a :4 1e8
:5 1e9 1e7 :2 1eb :5 1ed
:11 1ee :24 1ef :3 1ee :2 1ec
:6 1eb 1ea :3 5a :c 1f4
:6 1f5 :3 1f4 :3 5a :11 1fa
:30 1fb :3 1fa :a 1fd 34
:3 200 :11 201 :b 202 :17 203
:3 201 :2 205 :3 206 :3 207
208 206 205 206
:3 209 :3 200 :2 20a :5 20c
:11 20d :b 20e :18 20f :3 20d
:2 211 212 :3 213 214
212 211 212 :3 215
:2 20b :6 20a 1ff :7 1

2653
4
:3 0 1 :3 0 2
:a 0 aa8 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 aa8 2 14
:2 0 e :2 0 d
c :3 0 17 :7 0
1a 18 0 aa6
0 b :6 0 10
:2 0 11 4 :3 0
f 1c 1e :6 0
21 1f 0 aa6
0 d :6 0 17
c3 0 15 4
:3 0 13 23 25
:6 0 28 26 0
aa6 0 f :6 0
e :2 0 1b c
:3 0 2a :7 0 2d
2b 0 aa6 0
11 :6 0 4 :3 0
e :2 0 19 2f
31 :6 0 34 32
0 aa6 0 12
:6 0 15 :2 0 1f
4 :3 0 1d 36
38 :6 0 3b 39
0 aa6 0 13
:6 0 17 :2 0 23
4 :3 0 21 3d
3f :6 0 42 40
0 aa6 0 14
:6 0 17 :2 0 25
6 :3 0 44 :7 0
48 45 46 aa6
0 16 :6 0 17
:2 0 27 6 :3 0
4a :7 0 4e 4b
4c aa6 0 18
:6 0 2b 189 0
29 6 :3 0 50
:7 0 54 51 52
aa6 0 19 :6 0
17 :2 0 2d 1b
:3 0 56 :7 0 59
57 0 aa6 0
1a :6 0 6 :3 0
5b :7 0 17 :2 0
5f 5c 5d aa6
0 1c :6 0 17
:2 0 2f 6 :3 0
61 :7 0 65 62
63 aa6 0 1d
:6 0 17 :2 0 31
6 :3 0 67 :7 0
6b 68 69 aa6
0 1e :6 0 17
:2 0 33 6 :3 0
6d :7 0 71 6e
6f aa6 0 1f
:6 0 17 :2 0 35
6 :3 0 73 :7 0
77 74 75 aa6
0 20 :6 0 17
:2 0 37 6 :3 0
79 :7 0 7d 7a
7b aa6 0 21
:6 0 17 :2 0 39
6 :3 0 7f :7 0
83 80 81 aa6
0 22 :6 0 e
:2 0 3b 6 :3 0
85 :7 0 89 86
87 aa6 0 23
:6 0 e :2 0 3f
4 :3 0 3d 8b
8d :6 0 90 8e
0 aa6 0 24
:6 0 17 :2 0 43
4 :3 0 41 92
94 :6 0 97 95
0 aa6 0 25
:6 0 17 :2 0 45
6 :3 0 99 :7 0
9d 9a 9b aa6
0 26 :6 0 17
:2 0 47 6 :3 0
9f :7 0 a3 a0
a1 aa6 0 27
:6 0 4b 312 0
49 6 :3 0 a5
0 2 :5 0 a9
a6 a7 aa6 0
28 :6 0 2a :3 0
6 :3 0 ab :7 0
ae ac 0 aa6
0 29 :6 0 2b
:a 0 2 ea :5 0
b0 b3 0 b1
:3 0 2c :3 0 2d
:3 0 2e :3 0 2f
:3 0 30 :3 0 2f
:3 0 31 :3 0 32
:3 0 31 :3 0 33
:3 0 34 :3 0 d
:3 0 35 :3 0 f
:3 0 36 :3 0 37
:3 0 38 :3 0 37
:3 0 39 :3 0 37
:3 0 3a :3 0 37
:3 0 3b :3 0 37
:3 0 3c :3 0 37
:3 0 3d :3 0 37
:3 0 3e :3 0 37
:3 0 3f :3 0 37
:3 0 40 :3 0 37
:3 0 41 :3 0 37
:3 0 42 :3 0 37
:3 0 43 :3 0 37
:3 0 44 :3 0 37
:3 0 45 :3 0 37
:3 0 46 :3 0 2d
:3 0 2e :3 0 2d
:3 0 2e :3 0 47
:3 0 48 :3 0 2f
:3 0 31 :4 0 49
1 :8 0 eb b0
b3 ec 0 aa6
4d ec ee eb
ed :6 0 ea :7 0
ec 2a :3 0 4a
:a 0 3 109 :5 0
f0 f3 0 f1
:3 0 4b :3 0 4c
:3 0 4d :3 0 4e
:3 0 4f :3 0 47
:3 0 50 :3 0 51
:3 0 34 :3 0 d
:3 0 52 :3 0 12
:3 0 4e :3 0 4f
:3 0 4e :3 0 4f
:3 0 47 :3 0 48
:3 0 2f :3 0 31
:4 0 53 1 :8 0
10a f0 f3 10b
0 aa6 4f 10b
10d 10a 10c :6 0
109 :7 0 10b 115
116 0 51 9
:3 0 a :2 0 4
10f 110 0 111
:7 0 114 112 0
aa6 0 54 :6 0
55 :3 0 56 :3 0
55 :3 0 57 :3 0
118 119 0 2
:4 0 53 11a 11c
117 11e 11d :2 0
58 :3 0 59 :3 0
120 121 0 5a
:4 0 55 :3 0 5b
:3 0 124 125 0
2 :4 0 55 126
128 5c :4 0 5d
:2 0 5e :3 0 57
12b 12d :3 0 5f
:4 0 5d :2 0 60
:4 0 5a 130 132
:3 0 5d :2 0 3
:3 0 5d 134 136
:3 0 5d :2 0 60
:4 0 60 138 13a
:3 0 5d :2 0 61
:4 0 63 13c 13e
:3 0 5d :2 0 62
:3 0 63 :3 0 5
:3 0 66 142 144
64 :4 0 68 141
147 6b 140 149
:3 0 5d :2 0 61
:4 0 6e 14b 14d
:3 0 5d :2 0 60
:4 0 71 14f 151
:3 0 5d :2 0 7
:3 0 74 153 155
:3 0 5d :2 0 60
:4 0 77 157 159
:3 0 5d :2 0 65
:4 0 7a 15b 15d
:3 0 7d 122 15f
:2 0 161 82 162
11f 161 0 163
84 0 a06 55
:3 0 56 :3 0 164
165 0 55 :3 0
66 :3 0 167 168
0 15 :2 0 2
:4 0 67 :2 0 68
:2 0 15 :2 0 86
16d 16f :3 0 89
169 171 166 173
172 :2 0 58 :3 0
69 :3 0 175 176
0 5a :4 0 6a
:4 0 5d :2 0 5e
:3 0 8d 17a 17c
:3 0 90 177 17e
:2 0 180 93 181
174 180 0 182
95 0 a06 16
:3 0 5 :3 0 183
184 0 a06 25
:3 0 7 :3 0 186
187 0 a06 26
:3 0 6b :2 0 189
18a 0 a06 24
:3 0 6c :4 0 18c
18d 0 a06 34
:3 0 6d :3 0 35
:3 0 36 :3 0 d
:3 0 f :3 0 19
:3 0 33 :3 0 2c
:3 0 3 :4 0 6e
1 :8 0 19f 9
:3 0 6f :3 0 19a
19b 0 70 :3 0
19c 19d 0 19f
97 1e9 71 :3 0
9 :3 0 6f :3 0
1a2 1a3 0 70
:3 0 1a4 1a5 0
1df 55 :3 0 56
:3 0 1a7 1a8 0
55 :3 0 66 :3 0
1aa 1ab 0 72
:2 0 2 :4 0 73
:2 0 68 :2 0 15
:2 0 9a 1b0 1b2
:3 0 9d 1ac 1b4
1a9 1b6 1b5 :2 0
58 :3 0 69 :3 0
1b8 1b9 0 5a
:4 0 74 :4 0 5d
:2 0 5e :3 0 a1
1bd 1bf :3 0 5d
:2 0 75 :4 0 a4
1c1 1c3 :3 0 5d
:2 0 76 :4 0 a7
1c5 1c7 :3 0 5d
:2 0 70 :3 0 aa
1c9 1cb :3 0 5d
:2 0 77 :4 0 ad
1cd 1cf :3 0 5d
:2 0 78 :3 0 79
:3 0 15 :2 0 7a
:2 0 b0 1d2 1d6
b4 1d1 1d8 :3 0
b7 1ba 1da :2 0
1dc ba 1dd 1b7
1dc 0 1de bc
0 1df be 1e2
:3 0 1e2 0 1e2
1e1 1df 1e0 :6 0
1e4 4 :3 0 c1
1e6 c3 1e5 1e4
:2 0 1e7 c5 :2 0
1e9 0 1e9 1e8
19f 1e7 :6 0 a06
1 :3 0 9 :3 0
6f :3 0 1eb 1ec
0 9 :3 0 7b
:2 0 7c :3 0 1ee
1f0 0 c9 1ef
1f2 :3 0 1f3 :2 0
19 :3 0 7d :2 0
cc 1f6 1f7 :3 0
1f8 :2 0 1f9 :2 0
1f4 1fb 1fa :2 0
f :3 0 78 :3 0
f :3 0 5d :2 0
7e :4 0 ce 200
202 :3 0 15 :2 0
10 :2 0 d1 1fe
206 1fd 207 0
9b5 18 :3 0 7f
:2 0 15 :2 0 d5
20a 20c :3 0 209
20d 0 9b5 80
:3 0 1a :3 0 33
:3 0 2c :3 0 d
:4 0 81 1 :8 0
21a 9 :3 0 6f
:3 0 215 216 0
70 :3 0 217 218
0 21a d7 264
71 :3 0 9 :3 0
6f :3 0 21d 21e
0 70 :3 0 21f
220 0 25a 55
:3 0 56 :3 0 222
223 0 55 :3 0
66 :3 0 225 226
0 72 :2 0 2
:4 0 82 :2 0 68
:2 0 15 :2 0 da
22b 22d :3 0 dd
227 22f 224 231
230 :2 0 58 :3 0
69 :3 0 233 234
0 5a :4 0 83
:4 0 5d :2 0 5e
:3 0 e1 238 23a
:3 0 5d :2 0 75
:4 0 e4 23c 23e
:3 0 5d :2 0 76
:4 0 e7 240 242
:3 0 5d :2 0 70
:3 0 ea 244 246
:3 0 5d :2 0 77
:4 0 ed 248 24a
:3 0 5d :2 0 78
:3 0 79 :3 0 15
:2 0 7a :2 0 f0
24d 251 f4 24c
253 :3 0 f7 235
255 :2 0 257 fa
258 232 257 0
259 fc 0 25a
fe 25d :3 0 25d
0 25d 25c 25a
25b :6 0 25f 6
:3 0 101 261 103
260 25f :2 0 262
105 :2 0 264 0
264 263 21a 262
:6 0 9b5 1 :3 0
84 :3 0 2b :4 0
269 :2 0 9b5 267
26a :3 0 85 :3 0
2b :3 0 12 :3 0
18 :3 0 11 :3 0
b :4 0 272 :2 0
948 26c 273 :3 0
107 :3 0 2b :3 0
86 :3 0 274 275
:3 0 9 :3 0 6f
:3 0 277 278 0
17 :2 0 279 27a
0 27c 10c 283
9 :3 0 6f :3 0
27d 27e 0 87
:2 0 27f 280 0
282 10e 284 276
27c 0 285 0
282 0 285 110
0 948 9 :3 0
6f :3 0 286 287
0 9 :3 0 88
:2 0 7c :3 0 289
28b 0 115 28a
28d :3 0 28e :2 0
89 :8 0 292 118
293 28f 292 0
294 11a 0 948
62 :3 0 18 :3 0
17 :2 0 11c 295
298 7b :2 0 17
:2 0 121 29a 29c
:3 0 62 :3 0 16
:3 0 17 :2 0 124
29e 2a1 7b :2 0
8a :2 0 129 2a3
2a5 :3 0 33 :3 0
2f :3 0 31 :3 0
8b :3 0 34 :3 0
d :3 0 2c :3 0
12 :4 0 8c 1
:8 0 2c5 86 :4 0
2b0 :3 0 8d :3 0
7b :2 0 12e 2b3
2b4 :3 0 9 :3 0
6f :3 0 2b6 2b7
0 17 :2 0 2b8
2b9 0 2bb 131
2c2 9 :3 0 6f
:3 0 2bc 2bd 0
87 :2 0 2be 2bf
0 2c1 133 2c3
2b5 2bb 0 2c4
0 2c1 0 2c4
135 0 2c5 138
30f 71 :3 0 9
:3 0 6f :3 0 2c8
2c9 0 70 :3 0
2ca 2cb 0 305
55 :3 0 56 :3 0
2cd 2ce 0 55
:3 0 66 :3 0 2d0
2d1 0 72 :2 0
2 :4 0 8e :2 0
68 :2 0 15 :2 0
13b 2d6 2d8 :3 0
13e 2d2 2da 2cf
2dc 2db :2 0 58
:3 0 69 :3 0 2de
2df 0 5a :4 0
8f :4 0 5d :2 0
5e :3 0 142 2e3
2e5 :3 0 5d :2 0
75 :4 0 145 2e7
2e9 :3 0 5d :2 0
76 :4 0 148 2eb
2ed :3 0 5d :2 0
70 :3 0 14b 2ef
2f1 :3 0 5d :2 0
77 :4 0 14e 2f3
2f5 :3 0 5d :2 0
78 :3 0 79 :3 0
15 :2 0 7a :2 0
151 2f8 2fc 155
2f7 2fe :3 0 158
2e0 300 :2 0 302
15b 303 2dd 302
0 304 15d 0
305 15f 308 :3 0
308 0 308 307
305 306 :6 0 30a
9 :3 0 162 30c
164 30b 30a :2 0
30d 166 :2 0 30f
0 30f 30e 2c5
30d :6 0 322 8
:3 0 27 :3 0 15
:2 0 311 312 0
322 23 :3 0 90
:3 0 24 :3 0 12
:3 0 25 :3 0 26
:3 0 62 :3 0 27
:3 0 17 :2 0 168
31a 31d 16b 315
31f 314 320 0
322 171 326 91
:3 0 323 :4 0 325
175 327 2a6 322
0 328 0 325
0 328 177 0
329 17a 8cb 84
:3 0 4a :4 0 32d
:2 0 8ca 32b 32e
:3 0 85 :3 0 4a
:3 0 13 :3 0 14
:3 0 1d :3 0 20
:3 0 21 :3 0 22
:4 0 338 :2 0 872
330 339 :3 0 17c
:3 0 4a :3 0 86
:3 0 33a 33b :3 0
9 :3 0 6f :3 0
33d 33e 0 17
:2 0 33f 340 0
342 183 349 9
:3 0 6f :3 0 343
344 0 87 :2 0
345 346 0 348
185 34a 33c 342
0 34b 0 348
0 34b 187 0
872 9 :3 0 6f
:3 0 34c 34d 0
9 :3 0 88 :2 0
7c :3 0 34f 351
0 18c 350 353
:3 0 354 :2 0 89
:8 0 358 18f 359
355 358 0 35a
191 0 872 1e
:3 0 17 :2 0 35b
35c 0 872 62
:3 0 16 :3 0 17
:2 0 193 35e 361
7b :2 0 15 :2 0
198 363 365 :3 0
78 :3 0 14 :3 0
15 :2 0 15 :2 0
19b 367 36b 7b
:2 0 8a :4 0 1a1
36d 36f :3 0 92
:3 0 93 :3 0 4b
:3 0 13 :3 0 4b
:3 0 2c :3 0 36
:3 0 37 :3 0 94
:4 0 95 1 :8 0
390 86 :4 0 37b
:3 0 8d :3 0 7b
:2 0 1a6 37e 37f
:3 0 9 :3 0 6f
:3 0 381 382 0
17 :2 0 383 384
0 386 1a9 38d
9 :3 0 6f :3 0
387 388 0 87
:2 0 389 38a 0
38c 1ab 38e 380
386 0 38f 0
38c 0 38f 1ad
0 390 1b0 3da
71 :3 0 9 :3 0
6f :3 0 393 394
0 70 :3 0 395
396 0 3d0 55
:3 0 56 :3 0 398
399 0 55 :3 0
66 :3 0 39b 39c
0 72 :2 0 2
:4 0 96 :2 0 68
:2 0 15 :2 0 1b3
3a1 3a3 :3 0 1b6
39d 3a5 39a 3a7
3a6 :2 0 58 :3 0
69 :3 0 3a9 3aa
0 5a :4 0 97
:4 0 5d :2 0 5e
:3 0 1ba 3ae 3b0
:3 0 5d :2 0 75
:4 0 1bd 3b2 3b4
:3 0 5d :2 0 76
:4 0 1c0 3b6 3b8
:3 0 5d :2 0 70
:3 0 1c3 3ba 3bc
:3 0 5d :2 0 77
:4 0 1c6 3be 3c0
:3 0 5d :2 0 78
:3 0 79 :3 0 15
:2 0 7a :2 0 1c9
3c3 3c7 1cd 3c2
3c9 :3 0 1d0 3ab
3cb :2 0 3cd 1d3
3ce 3a8 3cd 0
3cf 1d5 0 3d0
1d7 3d3 :3 0 3d3
0 3d3 3d2 3d0
3d1 :6 0 3d5 c
:3 0 1da 3d7 1dc
3d6 3d5 :2 0 3d8
1de :2 0 3da 0
3da 3d9 390 3d8
:6 0 4d0 b :3 0
62 :3 0 1d :3 0
17 :2 0 1e0 3dc
3df 7b :2 0 7f
:2 0 15 :2 0 1e3
3e2 3e4 :3 0 1e7
3e1 3e6 :3 0 51
:3 0 98 :3 0 30
:3 0 99 :3 0 32
:3 0 9a :3 0 4e
:3 0 9b :3 0 30
:3 0 9c :3 0 32
:3 0 9d :3 0 4e
:3 0 9e :3 0 9f
:3 0 4d :3 0 4e
:3 0 48 :3 0 4e
:3 0 47 :3 0 a0
:3 0 4b :3 0 13
:4 0 a1 1 :8 0
415 86 :4 0 400
:3 0 8d :3 0 7b
:2 0 1ec 403 404
:3 0 9 :3 0 6f
:3 0 406 407 0
17 :2 0 408 409
0 40b 1ef 412
9 :3 0 6f :3 0
40c 40d 0 87
:2 0 40e 40f 0
411 1f1 413 405
40b 0 414 0
411 0 414 1f3
0 415 1f6 45f
71 :3 0 9 :3 0
6f :3 0 418 419
0 70 :3 0 41a
41b 0 455 55
:3 0 56 :3 0 41d
41e 0 55 :3 0
66 :3 0 420 421
0 72 :2 0 2
:4 0 a2 :2 0 68
:2 0 15 :2 0 1f9
426 428 :3 0 1fc
422 42a 41f 42c
42b :2 0 58 :3 0
69 :3 0 42e 42f
0 5a :4 0 a3
:4 0 5d :2 0 5e
:3 0 200 433 435
:3 0 5d :2 0 75
:4 0 203 437 439
:3 0 5d :2 0 76
:4 0 206 43b 43d
:3 0 5d :2 0 70
:3 0 209 43f 441
:3 0 5d :2 0 77
:4 0 20c 443 445
:3 0 5d :2 0 78
:3 0 79 :3 0 15
:2 0 7a :2 0 20f
448 44c 213 447
44e :3 0 216 430
450 :2 0 452 219
453 42d 452 0
454 21b 0 455
21d 458 :3 0 458
0 458 457 455
456 :6 0 45a e
:3 0 220 45c 222
45b 45a :2 0 45d
224 :2 0 45f 0
45f 45e 415 45d
:6 0 461 b :3 0
226 4cd 51 :3 0
4e :3 0 4e :3 0
48 :3 0 4e :3 0
47 :3 0 4b :3 0
13 :4 0 a4 1
:8 0 480 86 :4 0
46b :3 0 8d :3 0
7b :2 0 22a 46e
46f :3 0 9 :3 0
6f :3 0 471 472
0 17 :2 0 473
474 0 476 22d
47d 9 :3 0 6f
:3 0 477 478 0
87 :2 0 479 47a
0 47c 22f 47e
470 476 0 47f
0 47c 0 47f
231 0 480 234
4ca 71 :3 0 9
:3 0 6f :3 0 483
484 0 70 :3 0
485 486 0 4c0
55 :3 0 56 :3 0
488 489 0 55
:3 0 66 :3 0 48b
48c 0 72 :2 0
2 :4 0 a5 :2 0
68 :2 0 15 :2 0
237 491 493 :3 0
23a 48d 495 48a
497 496 :2 0 58
:3 0 69 :3 0 499
49a 0 5a :4 0
a6 :4 0 5d :2 0
5e :3 0 23e 49e
4a0 :3 0 5d :2 0
75 :4 0 241 4a2
4a4 :3 0 5d :2 0
76 :4 0 244 4a6
4a8 :3 0 5d :2 0
70 :3 0 247 4aa
4ac :3 0 5d :2 0
77 :4 0 24a 4ae
4b0 :3 0 5d :2 0
78 :3 0 79 :3 0
15 :2 0 7a :2 0
24d 4b3 4b7 251
4b2 4b9 :3 0 254
49b 4bb :2 0 4bd
257 4be 498 4bd
0 4bf 259 0
4c0 25b 4c3 :3 0
4c3 0 4c3 4c2
4c0 4c1 :6 0 4c5
10 :3 0 25e 4c7
260 4c6 4c5 :2 0
4c8 262 :2 0 4ca
0 4ca 4c9 480
4c8 :6 0 4cc b
:3 0 264 4ce 3e7
461 0 4cf 0
4cc 0 4cf 266
0 4d0 269 53c
51 :3 0 48 :3 0
4f :3 0 50 :3 0
a0 :3 0 a7 :3 0
4b :3 0 13 :4 0
a8 1 :8 0 4ef
86 :4 0 4da :3 0
8d :3 0 7b :2 0
26e 4dd 4de :3 0
9 :3 0 6f :3 0
4e0 4e1 0 17
:2 0 4e2 4e3 0
4e5 271 4ec 9
:3 0 6f :3 0 4e6
4e7 0 87 :2 0
4e8 4e9 0 4eb
273 4ed 4df 4e5
0 4ee 0 4eb
0 4ee 275 0
4ef 278 539 71
:3 0 9 :3 0 6f
:3 0 4f2 4f3 0
70 :3 0 4f4 4f5
0 52f 55 :3 0
56 :3 0 4f7 4f8
0 55 :3 0 66
:3 0 4fa 4fb 0
72 :2 0 2 :4 0
a9 :2 0 68 :2 0
15 :2 0 27b 500
502 :3 0 27e 4fc
504 4f9 506 505
:2 0 58 :3 0 69
:3 0 508 509 0
5a :4 0 aa :4 0
5d :2 0 5e :3 0
282 50d 50f :3 0
5d :2 0 75 :4 0
285 511 513 :3 0
5d :2 0 76 :4 0
288 515 517 :3 0
5d :2 0 70 :3 0
28b 519 51b :3 0
5d :2 0 77 :4 0
28e 51d 51f :3 0
5d :2 0 78 :3 0
79 :3 0 15 :2 0
7a :2 0 291 522
526 295 521 528
:3 0 298 50a 52a
:2 0 52c 29b 52d
507 52c 0 52e
29d 0 52f 29f
532 :3 0 532 0
532 531 52f 530
:6 0 534 12 :3 0
2a2 536 2a4 535
534 :2 0 537 2a6
:2 0 539 0 539
538 4ef 537 :6 0
53b b :3 0 2a8
53d 370 4d0 0
53e 0 53b 0
53e 2aa 0 53f
2ad 70e 62 :3 0
16 :3 0 17 :2 0
2af 540 543 7b
:2 0 8a :2 0 2b4
545 547 :3 0 51
:3 0 2f :3 0 31
:3 0 8b :3 0 4b
:3 0 13 :4 0 ab
1 :8 0 565 86
:4 0 550 :3 0 8d
:3 0 7b :2 0 2b9
553 554 :3 0 9
:3 0 6f :3 0 556
557 0 17 :2 0
558 559 0 55b
2bc 562 9 :3 0
6f :3 0 55c 55d
0 87 :2 0 55e
55f 0 561 2be
563 555 55b 0
564 0 561 0
564 2c0 0 565
2c3 5af 71 :3 0
9 :3 0 6f :3 0
568 569 0 70
:3 0 56a 56b 0
5a5 55 :3 0 56
:3 0 56d 56e 0
55 :3 0 66 :3 0
570 571 0 72
:2 0 2 :4 0 ac
:2 0 68 :2 0 15
:2 0 2c6 576 578
:3 0 2c9 572 57a
56f 57c 57b :2 0
58 :3 0 69 :3 0
57e 57f 0 5a
:4 0 ad :4 0 5d
:2 0 5e :3 0 2cd
583 585 :3 0 5d
:2 0 75 :4 0 2d0
587 589 :3 0 5d
:2 0 76 :4 0 2d3
58b 58d :3 0 5d
:2 0 70 :3 0 2d6
58f 591 :3 0 5d
:2 0 77 :4 0 2d9
593 595 :3 0 5d
:2 0 78 :3 0 79
:3 0 15 :2 0 7a
:2 0 2dc 598 59c
2e0 597 59e :3 0
2e3 580 5a0 :2 0
5a2 2e6 5a3 57d
5a2 0 5a4 2e8
0 5a5 2ea 5a8
:3 0 5a8 0 5a8
5a7 5a5 5a6 :6 0
5aa 14 :3 0 2ed
5ac 2ef 5ab 5aa
:2 0 5ad 2f1 :2 0
5af 0 5af 5ae
565 5ad :6 0 5b1
b :3 0 2f3 70a
78 :3 0 14 :3 0
15 :2 0 15 :2 0
2f5 5b2 5b6 7b
:2 0 8a :4 0 2fb
5b8 5ba :3 0 92
:3 0 93 :3 0 4b
:3 0 13 :3 0 4b
:3 0 2c :3 0 36
:3 0 37 :3 0 94
:4 0 ae 1 :8 0
5db 86 :4 0 5c6
:3 0 8d :3 0 7b
:2 0 300 5c9 5ca
:3 0 9 :3 0 6f
:3 0 5cc 5cd 0
17 :2 0 5ce 5cf
0 5d1 303 5d8
9 :3 0 6f :3 0
5d2 5d3 0 87
:2 0 5d4 5d5 0
5d7 305 5d9 5cb
5d1 0 5da 0
5d7 0 5da 307
0 5db 30a 625
71 :3 0 9 :3 0
6f :3 0 5de 5df
0 70 :3 0 5e0
5e1 0 61b 55
:3 0 56 :3 0 5e3
5e4 0 55 :3 0
66 :3 0 5e6 5e7
0 72 :2 0 2
:4 0 af :2 0 68
:2 0 15 :2 0 30d
5ec 5ee :3 0 310
5e8 5f0 5e5 5f2
5f1 :2 0 58 :3 0
69 :3 0 5f4 5f5
0 5a :4 0 b0
:4 0 5d :2 0 5e
:3 0 314 5f9 5fb
:3 0 5d :2 0 75
:4 0 317 5fd 5ff
:3 0 5d :2 0 76
:4 0 31a 601 603
:3 0 5d :2 0 70
:3 0 31d 605 607
:3 0 5d :2 0 77
:4 0 320 609 60b
:3 0 5d :2 0 78
:3 0 79 :3 0 15
:2 0 7a :2 0 323
60e 612 327 60d
614 :3 0 32a 5f6
616 :2 0 618 32d
619 5f3 618 0
61a 32f 0 61b
331 61e :3 0 61e
0 61e 61d 61b
61c :6 0 620 16
:3 0 334 622 336
621 620 :2 0 623
338 :2 0 625 0
625 624 5db 623
:6 0 699 b :3 0
51 :3 0 2f :3 0
31 :3 0 8b :3 0
4e :3 0 9a :3 0
47 :3 0 9a :3 0
4e :3 0 48 :3 0
9a :3 0 47 :3 0
9a :3 0 47 :3 0
4b :3 0 13 :4 0
b1 1 :8 0 64d
86 :4 0 638 :3 0
8d :3 0 7b :2 0
33c 63b 63c :3 0
9 :3 0 6f :3 0
63e 63f 0 17
:2 0 640 641 0
643 33f 64a 9
:3 0 6f :3 0 644
645 0 87 :2 0
646 647 0 649
341 64b 63d 643
0 64c 0 649
0 64c 343 0
64d 346 697 71
:3 0 9 :3 0 6f
:3 0 650 651 0
70 :3 0 652 653
0 68d 55 :3 0
56 :3 0 655 656
0 55 :3 0 66
:3 0 658 659 0
72 :2 0 2 :4 0
b2 :2 0 68 :2 0
15 :2 0 349 65e
660 :3 0 34c 65a
662 657 664 663
:2 0 58 :3 0 69
:3 0 666 667 0
5a :4 0 b3 :4 0
5d :2 0 5e :3 0
350 66b 66d :3 0
5d :2 0 75 :4 0
353 66f 671 :3 0
5d :2 0 76 :4 0
356 673 675 :3 0
5d :2 0 70 :3 0
359 677 679 :3 0
5d :2 0 77 :4 0
35c 67b 67d :3 0
5d :2 0 78 :3 0
79 :3 0 15 :2 0
7a :2 0 35f 680
684 363 67f 686
:3 0 366 668 688
:2 0 68a 369 68b
665 68a 0 68c
36b 0 68d 36d
690 :3 0 690 0
690 68f 68d 68e
:6 0 692 18 :3 0
370 694 372 693
692 :2 0 695 374
:2 0 697 0 697
696 64d 695 :6 0
699 b :3 0 376
706 51 :3 0 2f
:3 0 31 :3 0 8b
:3 0 48 :3 0 4f
:3 0 50 :3 0 4b
:3 0 13 :4 0 b4
1 :8 0 6b9 86
:4 0 6a4 :3 0 8d
:3 0 7b :2 0 37b
6a7 6a8 :3 0 9
:3 0 6f :3 0 6aa
6ab 0 17 :2 0
6ac 6ad 0 6af
37e 6b6 9 :3 0
6f :3 0 6b0 6b1
0 87 :2 0 6b2
6b3 0 6b5 380
6b7 6a9 6af 0
6b8 0 6b5 0
6b8 382 0 6b9
385 703 71 :3 0
9 :3 0 6f :3 0
6bc 6bd 0 70
:3 0 6be 6bf 0
6f9 55 :3 0 56
:3 0 6c1 6c2 0
55 :3 0 66 :3 0
6c4 6c5 0 72
:2 0 2 :4 0 b5
:2 0 68 :2 0 15
:2 0 388 6ca 6cc
:3 0 38b 6c6 6ce
6c3 6d0 6cf :2 0
58 :3 0 69 :3 0
6d2 6d3 0 5a
:4 0 b6 :4 0 5d
:2 0 5e :3 0 38f
6d7 6d9 :3 0 5d
:2 0 75 :4 0 392
6db 6dd :3 0 5d
:2 0 76 :4 0 395
6df 6e1 :3 0 5d
:2 0 70 :3 0 398
6e3 6e5 :3 0 5d
:2 0 77 :4 0 39b
6e7 6e9 :3 0 5d
:2 0 78 :3 0 79
:3 0 15 :2 0 7a
:2 0 39e 6ec 6f0
3a2 6eb 6f2 :3 0
3a5 6d4 6f4 :2 0
6f6 3a8 6f7 6d1
6f6 0 6f8 3aa
0 6f9 3ac 6fc
:3 0 6fc 0 6fc
6fb 6f9 6fa :6 0
6fe 1a :3 0 3af
700 3b1 6ff 6fe
:2 0 701 3b3 :2 0
703 0 703 702
6b9 701 :6 0 705
b :3 0 3b5 707
5bb 699 0 708
0 705 0 708
3b7 0 709 3ba
70b 548 5b1 0
70c 0 709 0
70c 3bc 0 70d
3bf 70f 366 53f
0 710 0 70d
0 710 3c1 0
872 9 :3 0 6f
:3 0 711 712 0
9 :3 0 7b :2 0
b7 :3 0 714 716
0 3c6 715 718
:3 0 719 :2 0 1e
:3 0 15 :2 0 71b
71c 0 71e 3c9
71f 71a 71e 0
720 3cb 0 872
27 :3 0 17 :2 0
721 722 0 872
23 :3 0 90 :3 0
24 :3 0 13 :3 0
25 :3 0 26 :3 0
62 :3 0 27 :3 0
17 :2 0 3cd 72a
72d 3d0 725 72f
724 730 0 872
62 :3 0 1e :3 0
17 :2 0 3d6 732
735 7b :2 0 17
:2 0 3db 737 739
:3 0 b8 :3 0 62
:3 0 16 :3 0 17
:2 0 3de 73c 73f
15 :2 0 3e1 73b
742 743 :2 0 7b
:2 0 15 :2 0 3e6
745 747 :3 0 748
:2 0 62 :3 0 22
:3 0 17 :2 0 3e9
74a 74d b9 :2 0
17 :2 0 3ee 74f
751 :3 0 752 :2 0
749 754 753 :2 0
29 :3 0 ba :3 0
62 :3 0 21 :3 0
17 :2 0 3f1 758
75b bb :2 0 62
:3 0 20 :3 0 17
:2 0 3f4 75e 761
3f7 75d 763 :3 0
764 :2 0 bc :2 0
bd :2 0 3fa 766
768 :3 0 769 :2 0
7f :2 0 62 :3 0
22 :3 0 17 :2 0
3fd 76c 76f 400
76b 771 :3 0 403
757 773 756 774
0 86c 29 :3 0
b9 :2 0 15 :2 0
407 777 779 :3 0
77a :2 0 29 :3 0
be :2 0 7f :2 0
15 :2 0 40a 77e
780 :3 0 40e 77d
782 :3 0 77b 784
783 :2 0 51 :3 0
bf :3 0 c0 :3 0
c1 :3 0 bf :3 0
37 :3 0 c2 :3 0
a0 :3 0 a0 :3 0
48 :3 0 32 :3 0
a0 :3 0 4b :3 0
13 :4 0 c3 1
:8 0 7aa 86 :4 0
795 :3 0 8d :3 0
7b :2 0 413 798
799 :3 0 9 :3 0
6f :3 0 79b 79c
0 17 :2 0 79d
79e 0 7a0 416
7a7 9 :3 0 6f
:3 0 7a1 7a2 0
87 :2 0 7a3 7a4
0 7a6 418 7a8
79a 7a0 0 7a9
0 7a6 0 7a9
41a 0 7aa 41d
7f4 71 :3 0 9
:3 0 6f :3 0 7ad
7ae 0 70 :3 0
7af 7b0 0 7ea
55 :3 0 56 :3 0
7b2 7b3 0 55
:3 0 66 :3 0 7b5
7b6 0 72 :2 0
2 :4 0 c4 :2 0
68 :2 0 15 :2 0
420 7bb 7bd :3 0
423 7b7 7bf 7b4
7c1 7c0 :2 0 58
:3 0 69 :3 0 7c3
7c4 0 5a :4 0
c5 :4 0 5d :2 0
5e :3 0 427 7c8
7ca :3 0 5d :2 0
75 :4 0 42a 7cc
7ce :3 0 5d :2 0
76 :4 0 42d 7d0
7d2 :3 0 5d :2 0
70 :3 0 430 7d4
7d6 :3 0 5d :2 0
77 :4 0 433 7d8
7da :3 0 5d :2 0
78 :3 0 79 :3 0
15 :2 0 7a :2 0
436 7dd 7e1 43a
7dc 7e3 :3 0 43d
7c5 7e5 :2 0 7e7
440 7e8 7c2 7e7
0 7e9 442 0
7ea 444 7ed :3 0
7ed 0 7ed 7ec
7ea 7eb :6 0 7ef
1c :3 0 447 7f1
449 7f0 7ef :2 0
7f2 44b :2 0 7f4
0 7f4 7f3 7aa
7f2 :6 0 7f6 b
:3 0 44d 862 51
:3 0 a0 :3 0 a0
:3 0 48 :3 0 32
:3 0 a0 :3 0 4b
:3 0 13 :4 0 c6
1 :8 0 815 86
:4 0 800 :3 0 8d
:3 0 7b :2 0 451
803 804 :3 0 9
:3 0 6f :3 0 806
807 0 17 :2 0
808 809 0 80b
454 812 9 :3 0
6f :3 0 80c 80d
0 87 :2 0 80e
80f 0 811 456
813 805 80b 0
814 0 811 0
814 458 0 815
45b 85f 71 :3 0
9 :3 0 6f :3 0
818 819 0 70
:3 0 81a 81b 0
855 55 :3 0 56
:3 0 81d 81e 0
55 :3 0 66 :3 0
820 821 0 72
:2 0 2 :4 0 c7
:2 0 68 :2 0 15
:2 0 45e 826 828
:3 0 461 822 82a
81f 82c 82b :2 0
58 :3 0 69 :3 0
82e 82f 0 5a
:4 0 c8 :4 0 5d
:2 0 5e :3 0 465
833 835 :3 0 5d
:2 0 75 :4 0 468
837 839 :3 0 5d
:2 0 76 :4 0 46b
83b 83d :3 0 5d
:2 0 70 :3 0 46e
83f 841 :3 0 5d
:2 0 77 :4 0 471
843 845 :3 0 5d
:2 0 78 :3 0 79
:3 0 15 :2 0 7a
:2 0 474 848 84c
478 847 84e :3 0
47b 830 850 :2 0
852 47e 853 82d
852 0 854 480
0 855 482 858
:3 0 858 0 858
857 855 856 :6 0
85a 1e :3 0 485
85c 487 85b 85a
:2 0 85d 489 :2 0
85f 0 85f 85e
815 85d :6 0 861
b :3 0 48b 863
785 7f6 0 864
0 861 0 864
48d 0 86c 1c
:3 0 c9 :3 0 d
:3 0 13 :3 0 490
866 869 865 86a
0 86c 493 86d
755 86c 0 86e
497 0 86f 499
870 73a 86f 0
871 49b 0 872
49d 874 85 :4 0
872 :4 0 8ca ca
:3 0 4a :4 0 878
:2 0 87e 876 0
9 :3 0 6f :3 0
879 87a 0 70
:3 0 87b 87c 0
87e 4a7 8c8 71
:3 0 9 :3 0 6f
:3 0 881 882 0
70 :3 0 883 884
0 8be 55 :3 0
56 :3 0 886 887
0 55 :3 0 66
:3 0 889 88a 0
72 :2 0 2 :4 0
cb :2 0 68 :2 0
15 :2 0 4aa 88f
891 :3 0 4ad 88b
893 888 895 894
:2 0 58 :3 0 69
:3 0 897 898 0
5a :4 0 cc :4 0
5d :2 0 5e :3 0
4b1 89c 89e :3 0
5d :2 0 75 :4 0
4b4 8a0 8a2 :3 0
5d :2 0 76 :4 0
4b7 8a4 8a6 :3 0
5d :2 0 70 :3 0
4ba 8a8 8aa :3 0
5d :2 0 77 :4 0
4bd 8ac 8ae :3 0
5d :2 0 78 :3 0
79 :3 0 15 :2 0
7a :2 0 4c0 8b1
8b5 4c4 8b0 8b7
:3 0 4c7 899 8b9
:2 0 8bb 4ca 8bc
896 8bb 0 8bd
4cc 0 8be 4ce
8c1 :3 0 8c1 0
8c1 8c0 8be 8bf
:6 0 8c3 20 :3 0
4d1 8c5 4d3 8c4
8c3 :2 0 8c6 4d5
:2 0 8c8 0 8c8
8c7 87e 8c6 :6 0
8ca 8 :3 0 4d7
8cc 29d 329 0
8cd 0 8ca 0
8cd 4db 0 948
33 :3 0 cd :3 0
ce :3 0 78 :3 0
30 :3 0 ce :3 0
78 :3 0 1a :3 0
cf :3 0 ce :3 0
78 :3 0 30 :3 0
ce :3 0 78 :3 0
1a :3 0 30 :3 0
34 :3 0 d :3 0
2c :3 0 12 :4 0
d0 1 :8 0 8f8
86 :4 0 8e3 :3 0
8d :3 0 7b :2 0
4e0 8e6 8e7 :3 0
9 :3 0 6f :3 0
8e9 8ea 0 17
:2 0 8eb 8ec 0
8ee 4e3 8f5 9
:3 0 6f :3 0 8ef
8f0 0 87 :2 0
8f1 8f2 0 8f4
4e5 8f6 8e8 8ee
0 8f7 0 8f4
0 8f7 4e7 0
8f8 4ea 942 71
:3 0 9 :3 0 6f
:3 0 8fb 8fc 0
70 :3 0 8fd 8fe
0 938 55 :3 0
56 :3 0 900 901
0 55 :3 0 66
:3 0 903 904 0
72 :2 0 2 :4 0
d1 :2 0 68 :2 0
15 :2 0 4ed 909
90b :3 0 4f0 905
90d 902 90f 90e
:2 0 58 :3 0 69
:3 0 911 912 0
5a :4 0 d2 :4 0
5d :2 0 5e :3 0
4f4 916 918 :3 0
5d :2 0 75 :4 0
4f7 91a 91c :3 0
5d :2 0 76 :4 0
4fa 91e 920 :3 0
5d :2 0 70 :3 0
4fd 922 924 :3 0
5d :2 0 77 :4 0
500 926 928 :3 0
5d :2 0 78 :3 0
79 :3 0 15 :2 0
7a :2 0 503 92b
92f 507 92a 931
:3 0 50a 913 933
:2 0 935 50d 936
910 935 0 937
50f 0 938 511
93b :3 0 93b 0
93b 93a 938 939
:6 0 93d 22 :3 0
514 93f 516 93e
93d :2 0 940 518
:2 0 942 0 942
941 8f8 940 :6 0
948 8 :3 0 91
:5 0 946 24 0
947 51a 946 945
948 51c 94a 85
:4 0 948 :4 0 9b5
ca :3 0 2b :4 0
94e :2 0 954 94c
0 9 :3 0 6f
:3 0 94f 950 0
70 :3 0 951 952
0 954 523 99e
71 :3 0 9 :3 0
6f :3 0 957 958
0 70 :3 0 959
95a 0 994 55
:3 0 56 :3 0 95c
95d 0 55 :3 0
66 :3 0 95f 960
0 72 :2 0 2
:4 0 d3 :2 0 68
:2 0 15 :2 0 526
965 967 :3 0 529
961 969 95e 96b
96a :2 0 58 :3 0
69 :3 0 96d 96e
0 5a :4 0 d4
:4 0 5d :2 0 5e
:3 0 52d 972 974
:3 0 5d :2 0 75
:4 0 530 976 978
:3 0 5d :2 0 76
:4 0 533 97a 97c
:3 0 5d :2 0 70
:3 0 536 97e 980
:3 0 5d :2 0 77
:4 0 539 982 984
:3 0 5d :2 0 78
:3 0 79 :3 0 15
:2 0 7a :2 0 53c
987 98b 540 986
98d :3 0 543 96f
98f :2 0 991 546
992 96c 991 0
993 548 0 994
54a 997 :3 0 997
0 997 996 994
995 :6 0 999 24
:3 0 54d 99b 54f
99a 999 :2 0 99c
551 :2 0 99e 0
99e 99d 954 99c
:6 0 9b5 1 :3 0
62 :3 0 18 :3 0
17 :2 0 553 9a0
9a3 b9 :2 0 7f
:2 0 15 :2 0 556
9a6 9a8 :3 0 55a
9a5 9aa :3 0 1c
:3 0 d5 :3 0 d
:3 0 55d 9ad 9af
9ac 9b0 0 9b2
55f 9b3 9ab 9b2
0 9b4 561 0
9b5 563 9b6 1fc
9b5 0 9b7 56b
0 a06 55 :3 0
56 :3 0 9b8 9b9
0 55 :3 0 66
:3 0 9bb 9bc 0
d6 :2 0 2 :4 0
d7 :2 0 68 :2 0
15 :2 0 56d 9c1
9c3 :3 0 570 9bd
9c5 9ba 9c7 9c6
:2 0 58 :3 0 69
:3 0 9c9 9ca 0
5a :4 0 d8 :4 0
5d :2 0 5e :3 0
574 9ce 9d0 :3 0
5d :2 0 75 :4 0
577 9d2 9d4 :3 0
5d :2 0 d9 :4 0
57a 9d6 9d8 :3 0
5d :2 0 62 :3 0
63 :3 0 9 :3 0
6f :3 0 9dd 9de
0 57d 9dc 9e0
64 :4 0 57f 9db
9e3 582 9da 9e5
:3 0 5d :2 0 da
:4 0 585 9e7 9e9
:3 0 5d :2 0 60
:4 0 588 9eb 9ed
:3 0 5d :2 0 3
:3 0 58b 9ef 9f1
:3 0 5d :2 0 60
:4 0 58e 9f3 9f5
:3 0 591 9cb 9f7
:2 0 9f9 594 9fa
9c8 9f9 0 9fb
596 0 a06 db
:3 0 dc :3 0 9fc
9fd 0 9 :3 0
6f :3 0 9ff a00
0 3 :3 0 8d
:3 0 598 9fe a04
:2 0 a06 59c aa7
9 :3 0 dd :2 0
4 a07 a08 0
55 :3 0 56 :3 0
a0a a0b 0 55
:3 0 66 :3 0 a0d
a0e 0 72 :2 0
2 :4 0 de :2 0
68 :2 0 15 :2 0
5a7 a13 a15 :3 0
5aa a0f a17 a0c
a19 a18 :2 0 58
:3 0 69 :3 0 a1b
a1c 0 5a :4 0
df :4 0 5d :2 0
5e :3 0 5ae a20
a22 :3 0 5b1 a1d
a24 :2 0 a3d 58
:3 0 69 :3 0 a26
a27 0 5a :4 0
e0 :4 0 5d :2 0
9 :3 0 e1 :3 0
a2c a2d 0 5b4
a2b a2f :3 0 5d
:2 0 da :4 0 5b7
a31 a33 :3 0 5d
:2 0 9 :3 0 e2
:3 0 a36 a37 0
5ba a35 a39 :3 0
5bd a28 a3b :2 0
a3d 5c0 a3e a1a
a3d 0 a3f 5c3
0 a4f 84 :3 0
54 :3 0 9 :3 0
e1 :3 0 e3 :3 0
9 :3 0 e2 :3 0
3 :3 0 e4 :4 0
e5 1 :a 0 a4b
:2 0 a4f a41 a49
:2 0 8 :3 0 54
:3 0 a4d :2 0 a4f
5c5 a51 5c9 a50
a4f :2 0 aa5 71
:3 0 9 :3 0 6f
:3 0 a54 a55 0
70 :3 0 a56 a57
0 a9d 55 :3 0
56 :3 0 a59 a5a
0 55 :3 0 66
:3 0 a5c a5d 0
72 :2 0 2 :4 0
e6 :2 0 68 :2 0
15 :2 0 5cb a62
a64 :3 0 5ce a5e
a66 a5b a68 a67
:2 0 58 :3 0 69
:3 0 a6a a6b 0
5a :4 0 e7 :4 0
5d :2 0 5e :3 0
5d2 a6f a71 :3 0
5d5 a6c a73 :2 0
a8d 58 :3 0 69
:3 0 a75 a76 0
5a :4 0 76 :4 0
5d :2 0 70 :3 0
5d8 a7a a7c :3 0
5d :2 0 77 :4 0
5db a7e a80 :3 0
5d :2 0 78 :3 0
79 :3 0 15 :2 0
7a :2 0 5de a83
a87 5e2 a82 a89
:3 0 5e5 a77 a8b
:2 0 a8d 5e8 a8e
a69 a8d 0 a8f
5eb 0 a9d 84
:3 0 54 :3 0 e3
:3 0 9 :3 0 e2
:3 0 3 :3 0 e4
:4 0 e8 1 :a 0
a99 :2 0 a9d a91
a97 :2 0 8 :3 0
54 :3 0 a9b :2 0
a9d 5ed aa0 :3 0
aa0 0 aa0 a9f
a9d a9e :6 0 aa2
1 :3 0 5f2 aa4
5f4 aa3 aa2 :2 0
aa5 5f6 :2 0 aa7
5f9 aa7 aa6 a06
aa5 :6 0 aa8 :2 0
2 14 aa7 aab
:3 0 aaa aa8 aac
:8 0 
616
4
:3 0 1 3 1
7 1 b 3
6 a e 1
16 1 1d 1
1b 1 24 1
22 1 29 1
30 1 2e 1
37 1 35 1
3e 1 3c 1
43 1 49 1
4f 1 55 1
5a 1 60 1
66 1 6c 1
72 1 78 1
7e 1 84 1
8c 1 8a 1
93 1 91 1
98 1 9e 1
a4 1 aa 1
e9 1 108 1
10e 1 11b 1
127 2 12a 12c
2 12f 131 2
133 135 2 137
139 2 13b 13d
1 143 2 145
146 2 13f 148
2 14a 14c 2
14e 150 2 152
154 2 156 158
2 15a 15c 4
123 129 12e 15e
1 160 1 162
2 16c 16e 3
16a 16b 170 2
179 17b 2 178
17d 1 17f 1
181 2 199 19e
2 1af 1b1 3
1ad 1ae 1b3 2
1bc 1be 2 1c0
1c2 2 1c4 1c6
2 1c8 1ca 2
1cc 1ce 3 1d3
1d4 1d5 2 1d0
1d7 2 1bb 1d9
1 1db 1 1dd
2 1a6 1de 1
1e2 1 1a1 1
1e6 1 1f1 2
1ed 1f1 1 1f5
2 1ff 201 3
203 204 205 1
20b 2 214 219
2 22a 22c 3
228 229 22e 2
237 239 2 23b
23d 2 23f 241
2 243 245 2
247 249 3 24e
24f 250 2 24b
252 2 236 254
1 256 1 258
2 221 259 1
25d 1 21c 1
261 4 26d 26e
26f 270 1 27b
1 281 2 283
284 1 28c 2
288 28c 1 291
1 293 2 296
297 1 29b 2
299 29b 2 29f
2a0 1 2a4 2
2a2 2a4 1 2b2
2 2b1 2b2 1
2ba 1 2c0 2
2c2 2c3 2 2af
2c4 2 2d5 2d7
3 2d3 2d4 2d9
2 2e2 2e4 2
2e6 2e8 2 2ea
2ec 2 2ee 2f0
2 2f2 2f4 3
2f9 2fa 2fb 2
2f6 2fd 2 2e1
2ff 1 301 1
303 2 2cc 304
1 308 1 2c7
1 30c 2 31b
31c 5 316 317
318 319 31e 3
30f 313 321 1
324 2 326 327
1 328 6 331
332 333 334 335
336 1 341 1
347 2 349 34a
1 352 2 34e
352 1 357 1
359 2 35f 360
1 364 2 362
364 3 368 369
36a 1 36e 2
36c 36e 1 37d
2 37c 37d 1
385 1 38b 2
38d 38e 2 37a
38f 2 3a0 3a2
3 39e 39f 3a4
2 3ad 3af 2
3b1 3b3 2 3b5
3b7 2 3b9 3bb
2 3bd 3bf 3
3c4 3c5 3c6 2
3c1 3c8 2 3ac
3ca 1 3cc 1
3ce 2 397 3cf
1 3d3 1 392
1 3d7 2 3dd
3de 1 3e3 1
3e5 2 3e0 3e5
1 402 2 401
402 1 40a 1
410 2 412 413
2 3ff 414 2
425 427 3 423
424 429 2 432
434 2 436 438
2 43a 43c 2
43e 440 2 442
444 3 449 44a
44b 2 446 44d
2 431 44f 1
451 1 453 2
41c 454 1 458
1 417 1 45c
1 45f 1 46d
2 46c 46d 1
475 1 47b 2
47d 47e 2 46a
47f 2 490 492
3 48e 48f 494
2 49d 49f 2
4a1 4a3 2 4a5
4a7 2 4a9 4ab
2 4ad 4af 3
4b4 4b5 4b6 2
4b1 4b8 2 49c
4ba 1 4bc 1
4be 2 487 4bf
1 4c3 1 482
1 4c7 1 4ca
2 4cd 4ce 2
3da 4cf 1 4dc
2 4db 4dc 1
4e4 1 4ea 2
4ec 4ed 2 4d9
4ee 2 4ff 501
3 4fd 4fe 503
2 50c 50e 2
510 512 2 514
516 2 518 51a
2 51c 51e 3
523 524 525 2
520 527 2 50b
529 1 52b 1
52d 2 4f6 52e
1 532 1 4f1
1 536 1 539
2 53c 53d 1
53e 2 541 542
1 546 2 544
546 1 552 2
551 552 1 55a
1 560 2 562
563 2 54f 564
2 575 577 3
573 574 579 2
582 584 2 586
588 2 58a 58c
2 58e 590 2
592 594 3 599
59a 59b 2 596
59d 2 581 59f
1 5a1 1 5a3
2 56c 5a4 1
5a8 1 567 1
5ac 1 5af 3
5b3 5b4 5b5 1
5b9 2 5b7 5b9
1 5c8 2 5c7
5c8 1 5d0 1
5d6 2 5d8 5d9
2 5c5 5da 2
5eb 5ed 3 5e9
5ea 5ef 2 5f8
5fa 2 5fc 5fe
2 600 602 2
604 606 2 608
60a 3 60f 610
611 2 60c 613
2 5f7 615 1
617 1 619 2
5e2 61a 1 61e
1 5dd 1 622
1 63a 2 639
63a 1 642 1
648 2 64a 64b
2 637 64c 2
65d 65f 3 65b
65c 661 2 66a
66c 2 66e 670
2 672 674 2
676 678 2 67a
67c 3 681 682
683 2 67e 685
2 669 687 1
689 1 68b 2
654 68c 1 690
1 64f 1 694
2 625 697 1
6a6 2 6a5 6a6
1 6ae 1 6b4
2 6b6 6b7 2
6a3 6b8 2 6c9
6cb 3 6c7 6c8
6cd 2 6d6 6d8
2 6da 6dc 2
6de 6e0 2 6e2
6e4 2 6e6 6e8
3 6ed 6ee 6ef
2 6ea 6f1 2
6d5 6f3 1 6f5
1 6f7 2 6c0
6f8 1 6fc 1
6bb 1 700 1
703 2 706 707
1 708 2 70a
70b 1 70c 2
70e 70f 1 717
2 713 717 1
71d 1 71f 2
72b 72c 5 726
727 728 729 72e
2 733 734 1
738 2 736 738
2 73d 73e 2
740 741 1 746
2 744 746 2
74b 74c 1 750
2 74e 750 2
759 75a 2 75f
760 2 75c 762
2 765 767 2
76d 76e 2 76a
770 1 772 1
778 2 776 778
1 77f 1 781
2 77c 781 1
797 2 796 797
1 79f 1 7a5
2 7a7 7a8 2
794 7a9 2 7ba
7bc 3 7b8 7b9
7be 2 7c7 7c9
2 7cb 7cd 2
7cf 7d1 2 7d3
7d5 2 7d7 7d9
3 7de 7df 7e0
2 7db 7e2 2
7c6 7e4 1 7e6
1 7e8 2 7b1
7e9 1 7ed 1
7ac 1 7f1 1
7f4 1 802 2
801 802 1 80a
1 810 2 812
813 2 7ff 814
2 825 827 3
823 824 829 2
832 834 2 836
838 2 83a 83c
2 83e 840 2
842 844 3 849
84a 84b 2 846
84d 2 831 84f
1 851 1 853
2 81c 854 1
858 1 817 1
85c 1 85f 2
862 863 2 867
868 3 775 864
86b 1 86d 1
86e 1 870 9
337 34b 35a 35d
710 720 723 731
871 2 877 87d
2 88e 890 3
88c 88d 892 2
89b 89d 2 89f
8a1 2 8a3 8a5
2 8a7 8a9 2
8ab 8ad 3 8b2
8b3 8b4 2 8af
8b6 2 89a 8b8
1 8ba 1 8bc
2 885 8bd 1
8c1 1 880 1
8c5 3 32c 874
8c8 2 8cb 8cc
1 8e5 2 8e4
8e5 1 8ed 1
8f3 2 8f5 8f6
2 8e2 8f7 2
908 90a 3 906
907 90c 2 915
917 2 919 91b
2 91d 91f 2
921 923 2 925
927 3 92c 92d
92e 2 929 930
2 914 932 1
934 1 936 2
8ff 937 1 93b
1 8fa 1 93f
1 944 6 271
285 294 8cd 942
947 2 94d 953
2 964 966 3
962 963 968 2
971 973 2 975
977 2 979 97b
2 97d 97f 2
981 983 3 988
989 98a 2 985
98c 2 970 98e
1 990 1 992
2 95b 993 1
997 1 956 1
99b 2 9a1 9a2
1 9a7 1 9a9
2 9a4 9a9 1
9ae 1 9b1 1
9b3 7 208 20e
264 268 94a 99e
9b4 1 9b6 2
9c0 9c2 3 9be
9bf 9c4 2 9cd
9cf 2 9d1 9d3
2 9d5 9d7 1
9df 2 9e1 9e2
2 9d9 9e4 2
9e6 9e8 2 9ea
9ec 2 9ee 9f0
2 9f2 9f4 2
9cc 9f6 1 9f8
1 9fa 3 a01
a02 a03 a 163
182 185 188 18b
18e 1e9 9b7 9fb
a05 2 a12 a14
3 a10 a11 a16
2 a1f a21 2
a1e a23 2 a2a
a2e 2 a30 a32
2 a34 a38 2
a29 a3a 2 a25
a3c 1 a3e 3
a3f a4a a4e 1
a09 2 a61 a63
3 a5f a60 a65
2 a6e a70 2
a6d a72 2 a79
a7b 2 a7d a7f
3 a84 a85 a86
2 a81 a88 2
a78 a8a 2 a74
a8c 1 a8e 4
a58 a8f a98 a9c
1 aa0 1 a53
2 a51 aa4 1c
19 20 27 2c
33 3a 41 47
4d 53 58 5e
64 6a 70 76
7c 82 88 8f
96 9c a2 a8
ad ea 109 113

1
4
0 
aab
0
1
28
26
21
0 1 1 1 4 1 6 1
8 9 8 b c b e b
10 b 12 b 14 b 16 b
18 b 1a b 1c b 1e 8
20 8 22 1 24 1 0 0

b 1 0
60 1 0
3 1 0
7e 1 0
16 1 0
35 1 0
98 1 0
2 0 1
944 8 24
84 1 0
5a 1 0
49 1 0
29 1 0
8a 1 0
f0 1 3
43 1 0
72 1 0
2e 1 0
22 1 0
78 1 0
a4 1 0
3c 1 0
6c 1 0
9e 1 0
4f 1 0
55 1 0
1b 1 0
66 1 0
7 1 0
91 1 0
b0 1 2
aa 1 0
10e 1 0
0

/
SHOW ERRORS FUNCTION SP_RJCT_ETC_WBS;
ALTER FUNCTION SP_RJCT_ETC_WBS COMPILE DEBUG;
Prompt == FUNCTION SP_U_WP_FORECAST ==
CREATE OR REPLACE FUNCTION SP_U_WP_FORECAST wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
12b
2 :e:
1FUNCTION:
1SP_U_WP_FORECAST:
1ID:
1VARCHAR2:
1START_DATE001:
1TIMESTAMP:
1FINISH_DATE001:
1ACC_REJ_BITFLAG:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PROJECT_ID:
132:
1H_TASK_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_TSK_ASSIGNMENT_ID:
1H_RES_ASSIGNMENT_ID:
1H_RES_ID:
1H_REC_USER:
1H_SECURITY_ID:
1H_START_DATE:
1H_FINISH_DATE:
1H_START_DT:
1H_FINISH_DT:
1H_FORECAST_START:
1H_FORECAST_FINISH:
1H_ACTUAL_START:
1H_RANK:
1200:
1H_MLST_PERCENT:
10:
1H_TYPE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_TA_START_DT:
1H_TA_FINISH_DT:
1H_LAST_SUBMITTED:
1DATE:
1H_PROJAFFECTED_START:
1H_DAYOFYEAR:
1H_WEEK_OF:
1H_BIT_FLAG:
11:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_ETC:
1H_TOTAL:
1H_SCHED_WORK:
1H_CONTINUE:
1H_EFFORT:
1H_CONTOUR:
1H_BITFLAG:
1H_ACC_REJ_BITFLAG:
1H_REMAINING:
1H_FF:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_ALERT_FLAG:
1H_ALERT_ID:
1NULL_RETURN:
1LONG:
1ORA_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_FORECAST(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
167:
1+:
1FPUT:
1               ENTER:: SP_U_WP_FORECAST(68) :: cplan.sql(19628) :: :
1:
1=:
1PMO_CNST:
1SC_ACCEPT_REJECT_FORECAST:
1PROJECT_ID:
1RES_ASSIGNMENT_ID:
1PROJECT_ASSIGNMENT_ID:
1ACTUAL_START:
1MILESTONE_PERCENT:
1BIT_FLAG:
1FORECAST_START:
1SCHED_START:
1FORECAST_FINISH:
1SCHED_FINISH:
1TASK_ID:
1RESOURCE_ID:
1SCHED_WORK:
1PLANNED_WORK:
1WORK_TODATE:
1ETC:
1C_CONTOUR:
1LAST_SUBMITTED:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, RES_ASSIGNMENT_ID, PROJECT_ASSIGNMENT_ID, ACTUAL_START, MI+
1LESTONE_PERCENT, BIT_FLAG, :n      COALESCE(FORECAST_START,SCHED_START), COAL+
1ESCE(FORECAST_FINISH,SCHED_FINISH), FORECAST_START, FORECAST_FINISH, TASK_ID,+
1 RESOURCE_ID, SCHED_WORK, (PLANNED_WORK + SCHED_WORK - WORK_TODATE), ETC,:n  +
1    C_CONTOUR, LAST_SUBMITTED, UNRESOLVED_START, UNRESOLVED_FINISH, BILLABLE,+
1 CAPITAL_EXPENSE, REGULAR_COST, REGULAR_RATE:n      INTO h_project_id, h_res_+
1assignment_id, h_prj_assignment_id, h_actual_start, h_mlst_percent, h_bit_fla+
1g,:n      h_start_DT, h_finish_DT, h_forecast_start, h_forecast_finish, h_tas+
1k_id, h_res_id, h_sched_work,h_remaining, h_etc,:n      h_contour, h_last_sub+
1mitted, h_ta_start_DT, h_ta_finish_DT, h_billable, h_capital_expense, h_reg_c+
1ost, h_reg_sale:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID =+
1 id:
1SC_STATE:
1SQLCODE:
1OTHERS:
116:
1101:
1           EXCEPTION:: SP_U_WP_FORECAST(102) :: cplan.sql(19662) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1109:
1        RETURN_ERROR:: SP_U_WP_FORECAST(110) :: cplan.sql(19670) :: :
1STATE:: :
1RECORD_NOT_FOUND:
1 ID:: :
1112:
1                EXIT:: SP_U_WP_FORECAST(113) :: cplan.sql(19673) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
110000:
1119:
1        RETURN_ERROR:: SP_U_WP_FORECAST(120) :: cplan.sql(19680) :: :
1ASSIGNMENT_ALREADY_CLOSED:
1122:
1                EXIT:: SP_U_WP_FORECAST(123) :: cplan.sql(19683) :: :
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1<:
1130:
1        RETURN_ERROR:: SP_U_WP_FORECAST(131) :: cplan.sql(19691) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1133:
1                EXIT:: SP_U_WP_FORECAST(134) :: cplan.sql(19694) :: :
1MAX:
1WEEK_OF:
1TIMESHEET_APPROVAL_STATUS:
1ELEMENT_ID:
1CURRENT_STATE:
1SC_APV_STATE_RM_APPROVED:
1SC_APV_STATE_PM_APPROVED:
1SC_APV_STATE_SUBMITTED:
1SELECT MAX(WEEK_OF) + 7      INTO h_week_of FROM TIMESHEET_APPROVAL_STATUS:n +
1     WHERE ELEMENT_ID = h_project_id AND RESOURCE_ID = h_res_id:n      AND CU+
1RRENT_STATE IN (PMO_CNST.SC_APV_STATE_RM_APPROVED,PMO_CNST.SC_APV_STATE_PM_AP+
1PROVED,PMO_CNST.SC_APV_STATE_SUBMITTED):
1150:
1           EXCEPTION:: SP_U_WP_FORECAST(151) :: cplan.sql(19711) :: :
1STRCMP:
1!=:
1SCETCFORCASTCHANGED:
1FC_ISSUE_ALERT:
1SCREDUCEDETC:
1IS NULL:
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET:n         FORECAST_START  = start_date001,:n     +
1    FORECAST_FINISH = finish_date001,:n         FORECAST_DURATION = 0:n      +
1   WHERE TSK_ASSIGNMENT_ID = id:
1FOUND:
1100:
1194:
1           EXCEPTION:: SP_U_WP_FORECAST(195) :: cplan.sql(19755) :: :
1UPDATE TASK_ASSIGNMENTS SET:n            FORECAST_START  = start_date001,:n  +
1          FORECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = id:
1219:
1           EXCEPTION:: SP_U_WP_FORECAST(220) :: cplan.sql(19780) :: :
1UPDATE TASK_ASSIGNMENTS SET:n            FORECAST_FINISH = finish_date001,:n +
1           FORECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = id:
1249:
1           EXCEPTION:: SP_U_WP_FORECAST(250) :: cplan.sql(19810) :: :
1>:
1273:
1        RETURN_ERROR:: SP_U_WP_FORECAST(274) :: cplan.sql(19834) :: :
1FORECAST_APPROVAL_EXISTS:
1276:
1                EXIT:: SP_U_WP_FORECAST(277) :: cplan.sql(19837) :: :
1284:
1        RETURN_ERROR:: SP_U_WP_FORECAST(285) :: cplan.sql(19845) :: :
1CANNOT_UPDATE_HAS_ACTUAL:
1287:
1                EXIT:: SP_U_WP_FORECAST(288) :: cplan.sql(19848) :: :
1ELSIF:
1DB2TIMESTAMP:
1DAY_YEAR:
1TIME:
1PMO_STPU:
1FIRST_AVAIL_TIME:
1BIT_SCHED:
1CALENDAR_DAY_OF_YEAR:
1TO_DATE:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.FIRST_AVAIL+
1_TIME(BIT_SCHED))) INTO h_start_date:n                  FROM CALENDAR_DAY_OF_+
1YEAR:n                  WHERE ELEMENT_ID = h_project_id:n                  AN+
1D DAY_YEAR = TO_DATE(SubStr(start_date001, 1, 10)):
1308:
1           EXCEPTION:: SP_U_WP_FORECAST(309) :: cplan.sql(19869) :: :
1DUAL:
1SELECT  (PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(start_date001, 1, 10)), PMO_O+
1RASTD.TIME('08::00')))  INTO  h_start_date FROM DUAL:
1323:
1           EXCEPTION:: SP_U_WP_FORECAST(324) :: cplan.sql(19884) :: :
1330:
1        RETURN_ERROR:: SP_U_WP_FORECAST(331) :: cplan.sql(19891) :: :
1333:
1                EXIT:: SP_U_WP_FORECAST(334) :: cplan.sql(19894) :: :
1346:
1        RETURN_ERROR:: SP_U_WP_FORECAST(347) :: cplan.sql(19907) :: :
1INVALID_PARAMS:
1349:
1                EXIT:: SP_U_WP_FORECAST(350) :: cplan.sql(19910) :: :
1<=:
18:
1355:
1      RETURN_INVALID:: SP_U_WP_FORECAST(356) :: cplan.sql(19916) :: :
1358:
1                EXIT:: SP_U_WP_FORECAST(359) :: cplan.sql(19919) :: :
1PMO_RETURN_INVALID_SP:
1LAST_AVAIL_TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.LAST_AVAIL_+
1TIME(BIT_SCHED))) INTO h_finish_date:n                  FROM CALENDAR_DAY_OF_+
1YEAR:n                  WHERE ELEMENT_ID = h_project_id:n                  AN+
1D DAY_YEAR = TO_DATE(SubStr(finish_date001, 1, 10)):
1385:
1           EXCEPTION:: SP_U_WP_FORECAST(386) :: cplan.sql(19946) :: :
1SELECT  (PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(finish_date001, 1, 10)), PMO_+
1ORASTD.TIME('17::00')))  INTO  h_finish_date FROM DUAL:
1401:
1           EXCEPTION:: SP_U_WP_FORECAST(402) :: cplan.sql(19962) :: :
1409:
1        RETURN_ERROR:: SP_U_WP_FORECAST(410) :: cplan.sql(19970) :: :
1412:
1                EXIT:: SP_U_WP_FORECAST(413) :: cplan.sql(19973) :: :
1UPDATE TASK_ASSIGNMENTS SET:n               FORECAST_START  = h_start_date,:n+
1               FORECAST_FINISH = h_finish_date,:n               FORECAST_DURA+
1TION = 0:n               WHERE TSK_ASSIGNMENT_ID = id:
1441:
1           EXCEPTION:: SP_U_WP_FORECAST(442) :: cplan.sql(20002) :: :
1COUNT:
1TASK_DAY_OF_YEAR:
1SELECT COUNT('X') INTO h_temp_var:n                     FROM DUAL:n          +
1           WHERE EXISTS (SELECT DAY_YEAR FROM TASK_DAY_OF_YEAR:n             +
1        WHERE PROJECT_ID = h_project_id AND ((TSK_ASSIGNMENT_ID = h_prj_assig+
1nment_id) OR (TSK_ASSIGNMENT_ID = h_tsk_assignment_id)):n                    +
1 AND DAY_YEAR = TO_DATE(SubStr(finish_date001, 1, 10))):
1463:
1           EXCEPTION:: SP_U_WP_FORECAST(464) :: cplan.sql(20024) :: :
1471:
1        RETURN_ERROR:: SP_U_WP_FORECAST(472) :: cplan.sql(20032) :: :
1PROJECT_ASSIGNMENT_REMAINING:
1474:
1                EXIT:: SP_U_WP_FORECAST(475) :: cplan.sql(20035) :: :
1SELECT COUNT('X') INTO h_temp_var:n                     FROM DUAL:n          +
1           WHERE EXISTS (SELECT DAY_YEAR FROM TASK_DAY_OF_YEAR:n             +
1        WHERE PROJECT_ID = h_project_id AND ((TSK_ASSIGNMENT_ID = h_prj_assig+
1nment_id) OR (TSK_ASSIGNMENT_ID = h_tsk_assignment_id)):n                    +
1 AND DAY_YEAR = TO_DATE(SubStr(start_date001, 1, 10))):
1493:
1           EXCEPTION:: SP_U_WP_FORECAST(494) :: cplan.sql(20054) :: :
1501:
1        RETURN_ERROR:: SP_U_WP_FORECAST(502) :: cplan.sql(20062) :: :
1504:
1                EXIT:: SP_U_WP_FORECAST(505) :: cplan.sql(20065) :: :
1SUM:
1SCHED_MIN:
1PARENT_ID:
1SELECT SUM(SCHED_MIN) INTO h_total FROM TASK_DAY_OF_YEAR:n                   +
1     WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_prj_assignment_id AND +
1DAY_YEAR >= TO_DATE(SubStr(start_date001, 1, 10)):
1522:
1           EXCEPTION:: SP_U_WP_FORECAST(523) :: cplan.sql(20083) :: :
1528:
1        RETURN_ERROR:: SP_U_WP_FORECAST(529) :: cplan.sql(20089) :: :
1531:
1                EXIT:: SP_U_WP_FORECAST(532) :: cplan.sql(20092) :: :
1539:
1        RETURN_ERROR:: SP_U_WP_FORECAST(540) :: cplan.sql(20100) :: :
1TASK_ASSIGNMENT_ERROR:
1542:
1                EXIT:: SP_U_WP_FORECAST(543) :: cplan.sql(20103) :: :
12:
1FC_ACPT_ETC_ASSIGN:
1U_ASSIGN_STRING:
13:
1FC_ROLLUP:
14:
1593:
1       RETURN_STATUS:: SP_U_WP_FORECAST(594) :: cplan.sql(20154) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1601:
1           EXCEPTION:: SP_U_WP_FORECAST(602) :: cplan.sql(20162) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_ID:
1OPEN:
1ERROR:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1613:
1           EXCEPTION:: SP_U_WP_FORECAST(614) :: cplan.sql(20174) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
10ba
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 51 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :2 a0 6e 7e
a0 b4 2e 7e 6e b4 2e 6e
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :2 a0 6e 7e a0
b4 2e 7e 6e b4 2e 6e a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c a0
6e d a0 6e d a0 51 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 51 a5 b 7e 51 b4 2e
5a :3 a0 6b d b7 19 3c :37 a0
12a :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c a0
7e b4 2e :2 5a a0 7e b4 2e
:2 5a a 10 :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c b7
19 3c a0 4d d :f a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 d :2 a0 6b :2 a0 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
a0 7e a0 6b b4 2e 5a a
10 a0 6e d a0 51 d :3 a0
6b d :6 a0 51 a5 b d :2 a0
6b a0 d a0 6e d a0 51
d :3 a0 6b d :6 a0 51 a5 b
d :2 a0 6b a0 d b7 19 3c
a0 7e b4 2e :2 5a :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 d b7 19 3c a0
7e b4 2e :2 5a a0 7e b4 2e
:2 5a a 10 :8 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a0 7e b4
2e 5a a0 7e b4 2e 5a a
10 :6 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
19 3c b7 19 3c a0 7e b4
2e 5a a0 7e b4 2e 5a a
10 :6 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
19 3c b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e a0 7e b4
2e :2 5a :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :2 a0
d b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a a 10
:2 a0 6b :2 a0 a5 b 7e 51 b4
2e 5a a 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c a0 7e
b4 2e 5a a0 7e b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :2 a0 d :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e a0 4d
d a0 b7 :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e :10 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :9 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c a0
b7 19 a0 7e b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 51
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b 51 :2 a0 a5 57 b7 :2 19 3c
b7 a0 51 d a0 4d d b7
:2 19 3c a0 7e b4 2e 5a a0
7e b4 2e :2 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
a0 b7 a0 7e b4 2e :2 5a :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 b7 :2 19 3c a0 7e
b4 2e :2 5a :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
a0 51 d b7 a0 51 d b7
:2 19 3c :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e a0 4d d a0
b7 :2 a0 6b :2 a0 a5 b 7e 51
b4 2e :10 a0 12a :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :9 a0 12a
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c a0 b7 19 :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:2 a0 51 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b 51 :2 a0 a5 57 b7
:2 19 3c b7 a0 4d d b7 :2 19
3c :2 a0 d a0 51 d :2 a0 51
a5 b a0 7e a0 6b b4 2e
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 a0 7e b4 2e 5a a0
7e b4 2e 5a :f a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c a0 b7 a0 7e b4 2e 5a
:f a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :c a0 12a :2 a0 6b a0
d b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c b7 :2 19 3c b7
19 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c b7 19 3c a0 51
d :2 a0 d a0 7e b4 2e 5a
a0 7e b4 2e :2 5a a 10 :2 a0
d b7 19 3c :18 a0 51 a5 b
d a0 51 d :5 a0 :2 51 a5 b
d a0 7e b4 2e 5a a0 51
d :5 a0 :2 51 a5 b d b7 19
3c b7 :2 19 3c b7 19 3c b7
:2 19 3c :2 a0 6b :2 a0 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
a0 7e a0 6b b4 2e 5a a
10 a0 6e d a0 51 d :3 a0
6b d :6 a0 51 a5 b d :2 a0
6b a0 d a0 6e d a0 51
d :3 a0 6b d :6 a0 51 a5 b
d :2 a0 6b a0 d b7 19 3c
:3 a0 a5 b d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
10ba
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 56
7c 80 84 88 8b 8f ac 97
9b 9e 9f a7 96 c9 b7 93
bb bc c4 b6 e6 d4 b3 d8
d9 e1 d3 103 f1 d0 f5 f6
fe f0 120 10e ed 112 113 11b
10d 13d 12b 10a 12f 130 138 12a
15a 148 127 14c 14d 155 147 177
165 144 169 16a 172 164 193 182
186 18e 161 1ab 19a 19e 1a6 181
1c7 1b6 1ba 1c2 17e 1df 1ce 1d2
1da 1b5 1fb 1ea 1ee 1f6 1b2 213
202 206 20e 1e9 22f 21e 222 22a
1e6 24b 236 23a 23d 23e 246 21d
267 256 25a 21a 262 255 283 272
276 252 27e 271 29f 28e 292 26e
29a 28d 2bb 2aa 2ae 28a 2b6 2a9
2d7 2c6 2ca 2d2 2a6 2ef 2de 2e2
2ea 2c5 30b 2fa 2fe 306 2c2 323
312 316 31e 2f9 33f 32e 332 33a
2f6 357 346 34a 352 32d 374 362
32a 366 367 36f 361 390 37f 383
35e 38b 37e 3ac 39b 39f 37b 3a7
39a 3c8 3b7 3bb 397 3c3 3b6 3e4
3d3 3d7 3b3 3df 3d2 400 3ef 3f3
3cf 3fb 3ee 41c 40b 40f 3eb 417
40a 438 427 42b 407 433 426 454
443 447 423 44f 442 470 45f 463
43f 46b 45e 48c 47b 47f 45b 487
47a 4a8 497 49b 477 4a3 496 4c4
4b3 4b7 493 4bf 4b2 4e0 4cf 4d3
4af 4db 4ce 4fc 4eb 4ef 4cb 4f7
4ea 518 507 50b 4e7 513 506 535
523 503 527 528 530 522 551 540
544 54c 51f 56c 558 55c 564 567
53f 58c 577 57b 53c 57f 587 576
593 597 573 59b 59f 5a3 5a6 5ab
5ac 1 5ae 5b3 5b7 5bb 5be 5c3
5c7 5cb 5ce 5d3 5d4 5d6 5db 5de
5e2 5e3 5e8 5ed 5f0 5f5 5f6 5fb
5fe 602 603 608 60b 610 611 616
619 61e 61f 624 627 62b 62f 634
637 63b 63c 641 644 649 64a 64f
654 655 657 65c 65d 65f 660 665
668 66d 66e 673 676 67a 67e 683
686 68a 68b 690 693 698 699 69e
6a3 6a4 6a6 6ab 6ac 6ae 6af 6b4
6b7 6bc 6bd 6c2 6c5 6c9 6cd 6d1
6d2 6d4 6d9 6da 6dc 6dd 6e2 6e5
6ea 6eb 6f0 6f3 6f8 6f9 6fe 701
705 706 70b 70e 713 714 719 71c
721 722 727 728 72d 72f 733 736
73a 73e 741 745 749 74c 74f 754
757 75a 75d 75e 763 764 1 766
76b 76f 773 776 77b 780 783 787
788 78d 78e 793 795 799 79c 7a0
7a5 7a9 7ad 7b2 7b6 7ba 7bd 7c1
7c5 7c9 7cd 7d1 7d5 7d9 7dd 7e1
7e5 7e9 7ed 7f1 7f5 7f9 7fc 7fd
7ff 802 805 806 80b 80e 812 816
81a 81d 821 823 827 82a 82e 832
836 83a 83e 842 846 84a 84e 852
856 85a 85e 862 866 86a 86e 872
876 87a 87e 882 886 88a 88e 892
896 89a 89e 8a2 8a6 8aa 8ae 8b2
8b6 8ba 8be 8c2 8c6 8ca 8ce 8d2
8d6 8da 8de 8e2 8e6 8ea 8ee 8f2
8f6 8fa 8fe 902 906 912 916 91a
91d 921 925 927 1 92b 92f 933
936 93a 93e 942 946 949 94d 951
954 957 95c 95f 962 965 966 96b
96c 1 96e 973 977 97b 97e 983
988 98b 98f 990 995 998 99d 99e
9a3 9a6 9ab 9ac 9b1 9b4 9b8 9b9
9be 9c1 9c6 9c7 9cc 9cf 9d3 9d7
9da 9dd 9de 9e0 9e1 9e6 9e7 9ec
9ee 9f2 9f5 9f7 9fb 9fd a09 a0b
a0d a0e a13 a17 a19 a25 a27 a2b
a2f a32 a36 a39 a3d a40 a41 a46
a49 a4d a51 a54 a58 a5c a5f a62
a67 a6a a6d a70 a71 a76 a77 1
a79 a7e a82 a86 a89 a8e a93 a96
a9a a9b aa0 aa3 aa8 aa9 aae ab1
ab6 ab7 abc abf ac3 ac7 acb acf
ad2 ad3 ad5 ada adb add ade ae3
ae6 aeb aec af1 af4 af9 afa aff
b02 b06 b07 b0c b0f b14 b15 b1a
b1b b20 b22 b26 b29 b2d b31 b34
b38 b3c b3f b42 b47 b4a b4d b50
b51 b56 b57 1 b59 b5e b62 b66
b69 b6e b73 b76 b7a b7b b80 b81
b86 b88 b8c b8f b93 b97 b9a b9e
ba2 ba5 ba9 bad bae bb3 bb5 bb9
bbc bc0 bc4 bc7 bc8 bca bcd bd0
bd1 bd6 bda bde be1 be5 be9 bec
bef bf4 bf7 bfa bfd bfe c03 c04
1 c06 c0b c0f c13 c16 c1b c20
c23 c27 c28 c2d c30 c35 c36 c3b
c3e c43 c44 c49 c4c c50 c54 c58
c5c c5f c60 c62 c67 c68 c6a c6b
c70 c73 c78 c79 c7e c81 c86 c87
c8c c8f c93 c94 c99 c9c ca1 ca2
ca7 ca8 cad caf cb3 cb6 cba cbe
cc1 cc5 cc9 ccc ccf cd4 cd7 cda
cdd cde ce3 ce4 1 ce6 ceb cef
cf3 cf6 cfb d00 d03 d07 d08 d0d
d0e d13 d15 d19 d1c d20 d24 d27
d2b d2f d32 d36 d3a d3b d40 d42
d46 d49 d4d d50 d51 d56 d59 d5c
d60 d63 d64 d69 d6c 1 d6f d74
d78 d7c d7f d83 d87 d8a d8b d8d
d90 d93 d94 d99 d9d da1 da4 da8
dac daf db2 db7 dba dbd dc0 dc1
dc6 dc7 1 dc9 dce dd2 dd6 dd9
dde de3 de6 dea deb df0 df3 df8
df9 dfe e01 e06 e07 e0c e0f e13
e17 e1b e1f e22 e23 e25 e2a e2b
e2d e2e e33 e36 e3b e3c e41 e44
e49 e4a e4f e52 e56 e57 e5c e5f
e64 e65 e6a e6b e70 e72 e76 e79
e7d e81 e84 e88 e8c e8f e92 e97
e9a e9d ea0 ea1 ea6 ea7 1 ea9
eae eb2 eb6 eb9 ebe ec3 ec6 eca
ecb ed0 ed1 ed6 ed8 edc edf ee3
ee7 eea eee ef2 ef5 ef9 efd efe
f03 f05 f09 f0c f0e f12 f15 f19
f1a f1e f22 f26 f2a f2e f32 f36
f3a f3e f42 f46 f4a f4e f52 f56
f5a f66 f6a f6e f71 f75 f79 f7b
1 f7f f83 f87 f8a f8e f92 f96
f9a f9d fa1 fa5 fa8 fab fb0 fb3
fb6 fb9 fba fbf fc0 1 fc2 fc7
fcb fcf fd2 fd7 fdc fdf fe3 fe4
fe9 fec ff1 ff2 ff7 ffa fff 1000
1005 1008 100c 100d 1012 1015 101a 101b
1020 1023 1027 102b 102e 1031 1032 1034
1035 103a 103b 1040 1042 1046 1049 104b
104f 1051 105d 105f 1061 1062 1067 106b
106d 1079 107b 107f 1083 1087 108b 108f
1092 1096 109a 109b 109d 10a0 10a3 10a4
10a9 10ac 10b0 10b4 10b7 10b8 10ba 10be
10c1 10c5 10c8 10c9 10ce 1 10d1 10d6
10da 10df 10e3 10e7 10ea 10ee 10f2 10f6
10fa 10fd 1101 1105 1109 110d 1111 1115
1119 111c 111d 111f 1123 1127 112b 112e
1132 1136 113a 113f 1143 1147 114a 114e
1152 1156 115a 115d 1161 1165 1169 116d
1171 1175 1179 117c 117d 117f 1183 1187
118b 118e 1192 1196 1198 119c 119f 11a3
11a6 11a7 11ac 11af 11b2 11b6 11ba 11bd
11c1 11c5 11c8 11c9 11cb 11ce 11d1 11d2
11d7 1 11da 11df 11e3 11e7 11eb 11ed
11f1 11f4 11f8 11fb 11fc 1201 1204 1207
120b 120e 120f 1214 1217 1 121a 121f
1223 1227 122b 122f 1233 1237 123b 123f
124b 124f 1254 1258 125b 125c 1261 1265
1269 126c 126f 1273 1275 1279 127d 1280
1283 1287 1289 128d 1291 1294 1296 1
129a 129e 12a2 12a5 12a9 12ad 12b1 12b5
12b8 12bc 12c0 12c3 12c6 12cb 12ce 12d1
12d4 12d5 12da 12db 1 12dd 12e2 12e6
12ea 12ed 12f2 12f7 12fa 12fe 12ff 1304
1307 130c 130d 1312 1315 131a 131b 1320
1323 1327 1328 132d 1330 1335 1336 133b
133e 1342 1346 1349 134c 134d 134f 1350
1355 1356 135b 135d 1361 1364 1366 136a
136c 1378 137a 137c 137d 1382 1386 1388
1394 1396 1398 139c 139f 13a0 13a5 13a8
13ac 13af 13b0 13b5 1 13b8 13bd 13c1
13c5 13c9 13cd 13d1 13d5 13e1 13e5 13ea
13ee 13f1 13f2 13f7 13fb 13ff 1402 1405
1409 140b 140f 1413 1416 1419 141d 141f
1423 1427 142a 142c 1 1430 1434 1438
143b 143f 1443 1447 144b 144e 1452 1456
1459 145c 1461 1464 1467 146a 146b 1470
1471 1 1473 1478 147c 1480 1483 1488
148d 1490 1494 1495 149a 149d 14a2 14a3
14a8 14ab 14b0 14b1 14b6 14b9 14bd 14be
14c3 14c6 14cb 14cc 14d1 14d4 14d8 14dc
14df 14e2 14e3 14e5 14e6 14eb 14ec 14f1
14f3 14f7 14fa 14fc 1500 1502 150e 1510
1512 1513 1518 151c 151e 152a 152c 1530
1534 1537 153b 153f 1542 1543 1545 1548
154b 154c 1551 1555 1558 155c 155e 1562
1565 1567 156b 156e 1572 1575 1576 157b
157e 1582 1585 1586 158b 1 158e 1593
1597 159b 159f 15a3 15a7 15ab 15b7 15bb
15c0 15c4 15c7 15c8 15cd 15d1 15d5 15d8
15db 15df 15e1 15e5 15e9 15ec 15ef 15f3
15f5 15f9 15fd 1600 1602 1 1606 160a
160e 1611 1615 1619 161d 1621 1624 1628
162c 162f 1632 1637 163a 163d 1640 1641
1646 1647 1 1649 164e 1652 1656 1659
165e 1663 1666 166a 166b 1670 1673 1678
1679 167e 1681 1686 1687 168c 168f 1693
1694 1699 169c 16a1 16a2 16a7 16aa 16ae
16b2 16b5 16b8 16b9 16bb 16bc 16c1 16c2
16c7 16c9 16cd 16d0 16d2 16d6 16d8 16e4
16e6 16e8 16e9 16ee 16f2 16f4 1700 1702
1706 170a 170d 1711 1715 1718 1719 171b
171e 1721 1722 1727 172b 172e 1732 1734
1738 173b 173d 1741 1744 1748 174c 174f
1750 1752 1755 1758 1759 175e 1762 1765
1766 176b 176e 1771 1775 1779 177c 1780
1784 1787 1788 178a 178d 1790 1791 1796
1 1799 179e 17a2 17a6 17aa 17ac 17b0
17b3 17b7 17ba 17bb 17c0 17c3 17c6 17ca
17cd 17ce 17d3 17d6 1 17d9 17de 17e2
17e6 17e9 17ed 17f1 17f2 17f4 17f7 17fa
17fb 1800 1 1803 1808 180c 1810 1813
1817 181b 181e 1821 1826 1829 182c 182f
1830 1835 1836 1 1838 183d 1841 1845
1848 184d 1852 1855 1859 185a 185f 1862
1867 1868 186d 1870 1875 1876 187b 187e
1882 1886 188a 188e 1891 1892 1894 1899
189a 189c 189d 18a2 18a5 18aa 18ab 18b0
18b3 18b8 18b9 18be 18c1 18c5 18c6 18cb
18ce 18d3 18d4 18d9 18da 18df 18e1 18e5
18e8 18ec 18f0 18f3 18f7 18fb 18fe 1901
1906 1909 190c 190f 1910 1915 1916 1
1918 191d 1921 1925 1928 192d 1932 1935
1939 193a 193f 1940 1945 1947 194b 194e
1952 1956 1959 195d 1961 1964 1968 196c
196d 1972 1974 1978 197b 197f 1982 1983
1988 198b 198f 1992 1993 1998 199b 199f
19a3 19a6 19aa 19ae 19b1 19b4 19b9 19bc
19bf 19c2 19c3 19c8 19c9 1 19cb 19d0
19d4 19d8 19db 19e0 19e5 19e8 19ec 19ed
19f2 19f5 19fa 19fb 1a00 1a03 1a08 1a09
1a0e 1a11 1a15 1a19 1a1d 1a21 1a24 1a25
1a27 1a2c 1a2d 1a2f 1a30 1a35 1a38 1a3d
1a3e 1a43 1a46 1a4b 1a4c 1a51 1a54 1a58
1a59 1a5e 1a61 1a66 1a67 1a6c 1a6d 1a72
1a74 1a78 1a7b 1a7f 1a83 1a86 1a8a 1a8e
1a91 1a94 1a99 1a9c 1a9f 1aa2 1aa3 1aa8
1aa9 1 1aab 1ab0 1ab4 1ab8 1abb 1ac0
1ac5 1ac8 1acc 1acd 1ad2 1ad3 1ad8 1ada
1ade 1ae1 1ae5 1ae9 1aec 1af0 1af4 1af7
1afb 1aff 1b00 1b05 1b07 1b0b 1b0e 1b12
1b16 1b1a 1b1e 1b22 1b25 1b29 1b2d 1b30
1b31 1b33 1b36 1b39 1b3a 1b3f 1b43 1b44
1b48 1b4c 1b4e 1b52 1b56 1b59 1b5d 1b61
1b64 1b65 1b67 1b6a 1b6d 1b6e 1b73 1b77
1b7b 1b7f 1b83 1b87 1b8b 1b8f 1b93 1b97
1b9b 1b9f 1ba3 1ba7 1bab 1baf 1bb3 1bbf
1bc3 1bc7 1bca 1bce 1bd2 1bd4 1 1bd8
1bdc 1be0 1be3 1be7 1beb 1bef 1bf3 1bf6
1bfa 1bfe 1c01 1c04 1c09 1c0c 1c0f 1c12
1c13 1c18 1c19 1 1c1b 1c20 1c24 1c28
1c2b 1c30 1c35 1c38 1c3c 1c3d 1c42 1c45
1c4a 1c4b 1c50 1c53 1c58 1c59 1c5e 1c61
1c65 1c66 1c6b 1c6e 1c73 1c74 1c79 1c7c
1c80 1c84 1c87 1c8a 1c8b 1c8d 1c8e 1c93
1c94 1c99 1c9b 1c9f 1ca2 1ca4 1ca8 1caa
1cb6 1cb8 1cba 1cbb 1cc0 1cc4 1cc6 1cd2
1cd4 1cd8 1cdc 1cdf 1ce3 1ce6 1cea 1ced
1cee 1cf3 1cf6 1cfa 1cfe 1d02 1d06 1d0a
1d0e 1d12 1d16 1d1a 1d26 1d2a 1d2e 1d31
1d35 1d39 1d3b 1 1d3f 1d43 1d47 1d4a
1d4e 1d52 1d56 1d5a 1d5d 1d61 1d65 1d68
1d6b 1d70 1d73 1d76 1d79 1d7a 1d7f 1d80
1 1d82 1d87 1d8b 1d8f 1d92 1d97 1d9c
1d9f 1da3 1da4 1da9 1dac 1db1 1db2 1db7
1dba 1dbf 1dc0 1dc5 1dc8 1dcc 1dcd 1dd2
1dd5 1dda 1ddb 1de0 1de3 1de7 1deb 1dee
1df1 1df2 1df4 1df5 1dfa 1dfb 1e00 1e02
1e06 1e09 1e0b 1e0f 1e11 1e1d 1e1f 1e21
1e22 1e27 1e2b 1e2d 1e39 1e3b 1e3d 1e41
1e44 1e48 1e4a 1e4e 1e52 1e55 1e56 1e5b
1e5e 1e62 1e66 1e69 1e6d 1e71 1e74 1e77
1e7c 1e7f 1e82 1e85 1e86 1e8b 1e8c 1
1e8e 1e93 1e97 1e9b 1e9e 1ea3 1ea8 1eab
1eaf 1eb0 1eb5 1eb8 1ebd 1ebe 1ec3 1ec6
1ecb 1ecc 1ed1 1ed4 1ed8 1edc 1edf 1ee0
1ee2 1ee7 1ee8 1eea 1eeb 1ef0 1ef3 1ef8
1ef9 1efe 1f01 1f06 1f07 1f0c 1f0f 1f13
1f14 1f19 1f1c 1f21 1f22 1f27 1f28 1f2d
1f2f 1f33 1f36 1f3a 1f3e 1f41 1f45 1f49
1f4c 1f4f 1f54 1f57 1f5a 1f5d 1f5e 1f63
1f64 1 1f66 1f6b 1f6f 1f73 1f76 1f7b
1f80 1f83 1f87 1f88 1f8d 1f8e 1f93 1f95
1f99 1f9c 1fa0 1fa4 1fa7 1faa 1fae 1fb2
1fb3 1fb8 1fba 1fbe 1fc2 1fc5 1fc7 1fcb
1fce 1fd2 1fd6 1fd7 1fdb 1fdd 1fe1 1fe5
1fe8 1fec 1fef 1ff0 1ff5 1ff8 1ffc 1fff
2000 2005 2008 200b 200f 2013 2016 201a
201e 2021 2022 2024 2027 202a 202b 2030
1 2033 2038 203c 2040 2043 2047 204b
204e 2051 2056 2059 205c 205f 2060 2065
2066 1 2068 206d 2071 2075 2078 207d
2082 2085 2089 208a 208f 2092 2097 2098
209d 20a0 20a5 20a6 20ab 20ae 20b2 20b6
20ba 20be 20c1 20c2 20c4 20c9 20ca 20cc
20cd 20d2 20d5 20da 20db 20e0 20e3 20e8
20e9 20ee 20f1 20f5 20f6 20fb 20fe 2103
2104 2109 210a 210f 2111 2115 2118 211c
2120 2123 2127 212b 212e 2131 2136 2139
213c 213f 2140 2145 2146 1 2148 214d
2151 2155 2158 215d 2162 2165 2169 216a
216f 2170 2175 2177 217b 217e 2182 2186
2189 218d 2191 2194 2198 219c 219d 21a2
21a6 21a8 21ac 21af 21b0 21b5 21b8 21bb
21bf 21c3 21c6 21ca 21ce 21d1 21d2 21d4
21d7 21da 21db 21e0 1 21e3 21e8 21ec
21f0 21f3 21f7 21fb 21fe 2201 2206 2209
220c 220f 2210 2215 2216 1 2218 221d
2221 2225 2228 222d 2232 2235 2239 223a
223f 2242 2247 2248 224d 2250 2255 2256
225b 225e 2262 2266 226a 226e 2271 2272
2274 2279 227a 227c 227d 2282 2283 2288
228a 228e 2291 2295 2299 229c 22a0 22a4
22a7 22aa 22af 22b2 22b5 22b8 22b9 22be
22bf 1 22c1 22c6 22ca 22ce 22d1 22d6
22db 22de 22e2 22e3 22e8 22e9 22ee 22f0
22f4 22f7 22fb 22ff 2302 2306 230a 230d
2311 2312 2317 2319 231d 2321 2324 2328
232b 232c 2331 2334 2337 233b 233f 2342
2346 234a 234d 234e 2350 2353 2356 2357
235c 1 235f 2364 2368 236b 236f 2371
2375 2378 237c 237e 2382 2386 2389 238d
2391 2394 2398 239c 239f 23a0 23a2 23a5
23a8 23a9 23ae 23b2 23b3 23b7 23bb 23bd
23c1 23c5 23c8 23cc 23d0 23d1 23d3 23d6
23d9 23da 23df 23e3 23e7 23eb 23ef 23f3
23f7 23fb 23ff 2403 2407 240b 240f 2413
2417 241b 241f 242b 242f 2433 2436 243a
243e 2440 1 2444 2448 244c 244f 2453
2457 245b 245f 2462 2466 246a 246d 2470
2475 2478 247b 247e 247f 2484 2485 1
2487 248c 2490 2494 2497 249c 24a1 24a4
24a8 24a9 24ae 24b1 24b6 24b7 24bc 24bf
24c4 24c5 24ca 24cd 24d1 24d2 24d7 24da
24df 24e0 24e5 24e8 24ec 24f0 24f3 24f6
24f7 24f9 24fa 24ff 2500 2505 2507 250b
250e 2510 2514 2516 2522 2524 2526 2527
252c 2530 2532 253e 2540 2544 2548 254b
254f 2552 2556 2559 255a 255f 2562 2566
256a 256e 2572 2576 257a 257e 2582 2586
2592 2596 259a 259d 25a1 25a5 25a7 1
25ab 25af 25b3 25b6 25ba 25be 25c2 25c6
25c9 25cd 25d1 25d4 25d7 25dc 25df 25e2
25e5 25e6 25eb 25ec 1 25ee 25f3 25f7
25fb 25fe 2603 2608 260b 260f 2610 2615
2618 261d 261e 2623 2626 262b 262c 2631
2634 2638 2639 263e 2641 2646 2647 264c
264f 2653 2657 265a 265d 265e 2660 2661
2666 2667 266c 266e 2672 2675 2677 267b
267d 2689 268b 268d 268e 2693 2697 2699
26a5 26a7 26a9 26ad 26b0 26b4 26b6 26ba
26be 26c2 26c5 26c9 26cd 26d0 26d1 26d3
26d6 26d9 26da 26df 26e3 26e7 26ea 26ee
26f2 26f5 26f8 26fd 2700 2703 2706 2707
270c 270d 1 270f 2714 2718 271c 271f
2724 2729 272c 2730 2731 2736 2739 273e
273f 2744 2747 274c 274d 2752 2755 2759
275d 2760 2761 2763 2768 2769 276b 276c
2771 2774 2779 277a 277f 2782 2787 2788
278d 2790 2794 2795 279a 279d 27a2 27a3
27a8 27a9 27ae 27b0 27b4 27b7 27bb 27bf
27c2 27c6 27ca 27cd 27d0 27d5 27d8 27db
27de 27df 27e4 27e5 1 27e7 27ec 27f0
27f4 27f7 27fc 2801 2804 2808 2809 280e
280f 2814 2816 281a 281d 2821 2825 2828
282b 282f 2833 2834 2839 283b 283f 2843
2846 2848 284c 284d 2851 2853 2857 285b
285e 2862 2866 286a 286e 2871 2875 2879
287d 2880 2881 2883 2887 288a 288e 2891
2892 2897 289b 289f 28a3 28a7 28ab 28af
28b3 28b7 28c3 28c7 28cc 28d0 28d3 28d4
28d9 28dd 28e1 28e4 28e7 28eb 28ed 28f1
28f5 28f8 28fb 28ff 2901 2905 2909 290c
290e 1 2912 2916 291a 291d 2921 2925
2929 292d 2930 2934 2938 293b 293e 2943
2946 2949 294c 294d 2952 2953 1 2955
295a 295e 2962 2965 296a 296f 2972 2976
2977 297c 297f 2984 2985 298a 298d 2992
2993 2998 299b 299f 29a0 29a5 29a8 29ad
29ae 29b3 29b6 29ba 29be 29c1 29c4 29c5
29c7 29c8 29cd 29ce 29d3 29d5 29d9 29dc
29de 29e2 29e4 29f0 29f2 29f4 29f5 29fa
29fe 2a00 2a0c 2a0e 2a10 2a14 2a17 2a18
2a1d 2a20 2a24 2a27 2a28 2a2d 2a30 2a34
2a38 2a3c 2a40 2a44 2a48 2a4c 2a50 2a54
2a58 2a5c 2a60 2a64 2a68 2a6c 2a78 2a7c
2a80 2a83 2a87 2a8b 2a8d 1 2a91 2a95
2a99 2a9c 2aa0 2aa4 2aa8 2aac 2aaf 2ab3
2ab7 2aba 2abd 2ac2 2ac5 2ac8 2acb 2acc
2ad1 2ad2 1 2ad4 2ad9 2add 2ae1 2ae4
2ae9 2aee 2af1 2af5 2af6 2afb 2afe 2b03
2b04 2b09 2b0c 2b11 2b12 2b17 2b1a 2b1e
2b1f 2b24 2b27 2b2c 2b2d 2b32 2b35 2b39
2b3d 2b40 2b43 2b44 2b46 2b47 2b4c 2b4d
2b52 2b54 2b58 2b5b 2b5d 2b61 2b63 2b6f
2b71 2b73 2b74 2b79 2b7d 2b7f 2b8b 2b8d
2b91 2b95 2b98 2b99 2b9b 2b9e 2ba1 2ba2
2ba7 2bab 2baf 2bb2 2bb6 2bba 2bbd 2bc0
2bc5 2bc8 2bcb 2bce 2bcf 2bd4 2bd5 1
2bd7 2bdc 2be0 2be4 2be7 2bec 2bf1 2bf4
2bf8 2bf9 2bfe 2c01 2c06 2c07 2c0c 2c0f
2c14 2c15 2c1a 2c1d 2c21 2c25 2c29 2c2d
2c30 2c31 2c33 2c38 2c39 2c3b 2c3c 2c41
2c44 2c49 2c4a 2c4f 2c52 2c57 2c58 2c5d
2c60 2c64 2c65 2c6a 2c6d 2c72 2c73 2c78
2c79 2c7e 2c80 2c84 2c87 2c8b 2c8f 2c92
2c96 2c9a 2c9d 2ca0 2ca5 2ca8 2cab 2cae
2caf 2cb4 2cb5 1 2cb7 2cbc 2cc0 2cc4
2cc7 2ccc 2cd1 2cd4 2cd8 2cd9 2cde 2cdf
2ce4 2ce6 2cea 2ced 2cf1 2cf5 2cf8 2cfc
2d00 2d03 2d07 2d0b 2d0c 2d11 2d13 2d17
2d1a 2d1e 2d20 2d24 2d27 2d28 2d2d 2d30
2d34 2d38 2d3c 2d40 2d44 2d48 2d4c 2d50
2d54 2d58 2d5c 2d60 2d64 2d68 2d6c 2d78
2d7c 2d80 2d83 2d87 2d8b 2d8d 1 2d91
2d95 2d99 2d9c 2da0 2da4 2da8 2dac 2daf
2db3 2db7 2dba 2dbd 2dc2 2dc5 2dc8 2dcb
2dcc 2dd1 2dd2 1 2dd4 2dd9 2ddd 2de1
2de4 2de9 2dee 2df1 2df5 2df6 2dfb 2dfe
2e03 2e04 2e09 2e0c 2e11 2e12 2e17 2e1a
2e1e 2e1f 2e24 2e27 2e2c 2e2d 2e32 2e35
2e39 2e3d 2e40 2e43 2e44 2e46 2e47 2e4c
2e4d 2e52 2e54 2e58 2e5b 2e5d 2e61 2e63
2e6f 2e71 2e73 2e74 2e79 2e7d 2e7f 2e8b
2e8d 2e91 2e95 2e98 2e99 2e9b 2e9e 2ea1
2ea2 2ea7 2eab 2eaf 2eb2 2eb6 2eba 2ebd
2ec0 2ec5 2ec8 2ecb 2ece 2ecf 2ed4 2ed5
1 2ed7 2edc 2ee0 2ee4 2ee7 2eec 2ef1
2ef4 2ef8 2ef9 2efe 2f01 2f06 2f07 2f0c
2f0f 2f14 2f15 2f1a 2f1d 2f21 2f25 2f29
2f2d 2f30 2f31 2f33 2f38 2f39 2f3b 2f3c
2f41 2f44 2f49 2f4a 2f4f 2f52 2f57 2f58
2f5d 2f60 2f64 2f65 2f6a 2f6d 2f72 2f73
2f78 2f79 2f7e 2f80 2f84 2f87 2f8b 2f8f
2f92 2f96 2f9a 2f9d 2fa0 2fa5 2fa8 2fab
2fae 2faf 2fb4 2fb5 1 2fb7 2fbc 2fc0
2fc4 2fc7 2fcc 2fd1 2fd4 2fd8 2fd9 2fde
2fdf 2fe4 2fe6 2fea 2fed 2ff1 2ff5 2ff8
2ffc 3000 3003 3007 300b 300c 3011 3013
3017 301b 301f 3023 3027 302b 302f 3033
3037 303b 303f 3043 304f 3053 3057 305a
305e 3062 3064 1 3068 306c 3070 3073
3077 307b 307f 3083 3086 308a 308e 3091
3094 3099 309c 309f 30a2 30a3 30a8 30a9
1 30ab 30b0 30b4 30b8 30bb 30c0 30c5
30c8 30cc 30cd 30d2 30d5 30da 30db 30e0
30e3 30e8 30e9 30ee 30f1 30f5 30f6 30fb
30fe 3103 3104 3109 310c 3110 3114 3117
311a 311b 311d 311e 3123 3124 3129 312b
312f 3132 3134 3138 313a 3146 3148 314a
314b 3150 3154 3156 3162 3164 3168 316c
316f 3170 3172 3176 3179 317d 3180 3181
3183 3184 3189 318d 3191 3194 3198 319c
319f 31a2 31a7 31aa 31ad 31b0 31b1 31b6
31b7 1 31b9 31be 31c2 31c6 31c9 31ce
31d3 31d6 31da 31db 31e0 31e3 31e8 31e9
31ee 31f1 31f6 31f7 31fc 31ff 3203 3207
320b 320f 3212 3213 3215 321a 321b 321d
321e 3223 3226 322b 322c 3231 3234 3239
323a 323f 3242 3246 3247 324c 324f 3254
3255 325a 325b 3260 3262 3266 3269 326d
3271 3274 3278 327c 327f 3282 3287 328a
328d 3290 3291 3296 3297 1 3299 329e
32a2 32a6 32a9 32ae 32b3 32b6 32ba 32bb
32c0 32c1 32c6 32c8 32cc 32cf 32d3 32d7
32da 32de 32e2 32e5 32e9 32ed 32ee 32f3
32f5 32f9 32fc 32fe 3302 3306 3309 330b
330f 3313 3317 331a 331e 3322 3325 3328
332d 3330 3333 3336 3337 333c 333d 1
333f 3344 3348 334c 334f 3354 3359 335c
3360 3361 3366 3369 336e 336f 3374 3377
337c 337d 3382 3385 3389 338d 3391 3395
3398 3399 339b 33a0 33a1 33a3 33a4 33a9
33ac 33b1 33b2 33b7 33ba 33bf 33c0 33c5
33c8 33cc 33cd 33d2 33d5 33da 33db 33e0
33e1 33e6 33e8 33ec 33ef 33f3 33f7 33fa
33fe 3402 3405 3408 340d 3410 3413 3416
3417 341c 341d 1 341f 3424 3428 342c
342f 3434 3439 343c 3440 3441 3446 3447
344c 344e 3452 3455 3459 345d 3460 3464
3468 346b 346f 3473 3474 3479 347b 347f
3483 3486 3488 348c 348f 3493 3496 349a
349e 34a2 34a6 34aa 34ad 34ae 34b3 34b6
34ba 34bd 34be 34c3 34c6 1 34c9 34ce
34d2 34d6 34da 34dc 34e0 34e3 34e7 34eb
34ef 34f3 34f7 34fb 34ff 3503 3507 350b
350f 3513 3517 351b 351f 3523 3527 352b
352f 3533 3537 353b 353f 3543 3546 3547
3549 354d 3551 3554 3558 355c 3560 3564
3568 356c 356f 3572 3573 3575 3579 357d
3580 3581 3586 3589 358d 3590 3594 3598
359c 35a0 35a4 35a8 35ab 35ae 35af 35b1
35b5 35b7 35bb 35be 35c0 35c4 35c8 35cb
35cd 35d1 35d4 35d6 35da 35de 35e1 35e5
35e9 35ec 35f0 35f4 35f5 35f7 35fa 35fd
35fe 3603 3606 360a 360e 3611 3612 3614
3618 361b 361f 3622 3623 3628 1 362b
3630 3634 3639 363d 3641 3644 3648 364c
3650 3654 3657 365b 365f 3663 3667 366b
366f 3673 3676 3677 3679 367d 3681 3685
3688 368c 3690 3694 3699 369d 36a1 36a4
36a8 36ac 36b0 36b4 36b7 36bb 36bf 36c3
36c7 36cb 36cf 36d3 36d6 36d7 36d9 36dd
36e1 36e5 36e8 36ec 36f0 36f2 36f6 36f9
36fd 3701 3705 3706 3708 370c 3710 3714
3717 371b 371f 3722 3725 372a 372d 3730
3733 3734 3739 373a 1 373c 3741 3745
3749 374c 3751 3756 3759 375d 375e 3763
3766 376b 376c 3771 3774 3779 377a 377f
3782 3786 378a 378e 3792 3795 3796 3798
379d 379e 37a0 37a1 37a6 37a9 37ae 37af
37b4 37b7 37bc 37bd 37c2 37c5 37c9 37ca
37cf 37d2 37d7 37d8 37dd 37de 37e3 37e5
37e9 37ec 37f0 37f4 37f7 37fb 37ff 3802
3806 380a 380b 3810 3812 3816 381a 381d
3821 3825 3828 382c 3830 3833 3836 383b
383e 3841 3844 3845 384a 384b 1 384d
3852 3856 385a 385d 3862 3867 386a 386e
386f 3874 3875 387a 387e 3882 3885 388a
388f 3892 3896 389a 389d 389e 38a3 38a6
38ab 38ac 38b1 38b4 38b8 38bc 38bf 38c0
38c5 38c6 38cb 38cd 38d1 38d4 38d8 38dc
38e0 38e4 38e8 38ec 38f0 38f4 38f8 3904
3909 390d 3911 3915 3919 391b 391c 3921
1 3925 3929 392d 3930 3934 3938 393c
3940 3943 3947 394b 394e 3951 3956 3959
395c 395f 3960 3965 3966 1 3968 396d
3971 3975 3978 397d 3982 3985 3989 398a
398f 3990 3995 3999 399d 39a0 39a5 39aa
39ad 39b1 39b2 39b7 39ba 39bf 39c0 39c5
39c8 39cc 39d0 39d3 39d6 39d7 39d9 39da
39df 39e0 39e5 39e7 39eb 39ee 39f2 39f6
39fa 39fe 3a02 3a06 3a0a 3a16 3a1b 3a1f
3a23 3a27 3a2b 3a2d 3a31 3a33 3a3f 3a41
3a43 3a44 3a49 3a4d 3a4f 3a5b 3a5f 3a61
3a62 3a6b 
10ba
2
0 1 a 6 9 :3 6 14 :3 6
15 :3 6 16 :3 6 12 :2 6 1 3
a 13 a :2 1 4 11 1a 19
:2 11 :2 4 e 17 16 :2 e :2 4 18
21 20 :2 18 :2 4 18 21 20 :2 18
:2 4 18 21 20 :2 18 :2 4 d 16
15 :2 d :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :3 11 :2 4 :3 12
:2 4 :3 f :2 4 :3 10 :2 4 :3 15 :2 4 :3 16
:2 4 :3 13 :2 4 b 14 13 :2 b :2 4
:2 13 22 13 :2 4 :2 b 1a b :2 4
:2 f 19 f :2 4 :2 f 19 f :2 4
:3 12 :2 4 :3 13 :2 4 :3 15 :2 4 :3 19 :2 4
:3 10 :2 4 :3 e :2 4 f 18 17 :2 f
:2 4 :2 f 1e f :2 4 :2 16 25 16
:2 4 :2 a 19 a :2 4 :2 c 1b c
:2 4 :2 11 20 11 :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 e 1d e
:2 4 :2 e 1d e :2 4 :2 16 25 16
:2 4 :2 10 1f 10 :2 4 :2 9 18 9
:2 4 :2 f 1e f :2 4 :2 14 23 14
:2 4 :2 11 20 11 :2 4 f 18 17
:2 f :2 4 :3 10 :2 4 :2 16 2e 16 :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 58 5e 61 :2 58 6f 89 8
:2 6f d 10 :2 6f 13 16 :2 6f b
e :2 6f 13 16 1f 26 2b 2e
:2 26 3c 3f :2 26 44 :2 1f 4d :2 16
:2 6f b e :2 6f 13 16 1f 26
2b 2e :2 26 3d 40 :2 26 45 :2 1f
4e :2 16 :2 6f b e :2 6f 13 16
1f 27 :2 1f 39 :2 16 :2 6f b e
:2 6f 13 16 :2 6f 1b 1e :2 6f 2a
2d :2 6f 32 35 :2 6f :2 7 4e :2 4
7 :2 11 23 :2 2d 39 3c 50 52
53 :2 50 :2 23 :3 7 :2 d 12 1e 61
64 :2 1e :2 7 56 :3 4 14 :2 4 15
:2 4 12 :2 4 14 :2 4 15 :2 4 1b
:2 4 19 4 8 11 24 :2 8 27
29 :2 27 :2 7 1c :2 25 7 2c :2 4
e 1a 2d 44 52 65 7 10
1f 2d 36 46 55 65 76 7f
8c 99 a8 b5 c3 7 12 22
34 47 51 62 70 c 1a 2f
44 54 64 7 13 20 32 45
50 5a 67 74 7 12 24 33
43 4f 62 6e c d 21 :2 7
:2 10 1c 7 4 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 57
5a 5b :2 57 :2 29 :3 d :2 13 18 24
68 6b :2 24 78 7b :2 24 7f 82
:2 24 8e 91 :2 24 99 9c :2 24 a8
ab b2 bb be :2 ab :2 24 :2 d 5e
:2 a :2 7 :4 13 :2 7 4 :3 1 8 :2 11
1c 1a :2 25 :2 1a 7 a :2 14 26
:2 30 3c 40 54 57 58 :2 54 :2 26
:3 a :2 10 15 21 65 68 :2 21 75
78 :2 21 7c 7f :2 21 89 8c 95
9d :2 a6 :2 95 b9 :2 8c :2 21 c1 c4
:2 21 cc cf :2 21 d4 d7 :2 21 da
dd :2 21 :2 a 5b :2 7 a :2 14 26
:2 30 3c 3f 53 56 57 :2 53 :2 26
:3 a :2 10 15 21 65 68 :2 21 :2 a
5a :3 7 :2 12 26 :2 2f 41 45 :2 7
35 :2 4 7 10 20 :2 7 23 25
:2 23 a :2 14 26 :2 30 3c 40 54
57 58 :2 54 :2 26 :3 a :2 10 15 21
65 68 :2 21 75 78 :2 21 7c 7f
:2 21 89 8c 95 9d :2 a6 :2 95 c2
:2 8c :2 21 ca cd :2 21 d5 d8 :2 21
dd e0 :2 21 e3 e6 :2 21 :2 a 5b
:2 7 a :2 14 26 :2 30 3c 3f 53
56 57 :2 53 :2 26 :3 a :2 10 15 21
65 68 :2 21 :2 a 5a :3 7 :2 12 26
:2 2f 4a 4e :2 7 2b :2 4 :4 9 8
7 :4 2b 2a 29 :2 7 a :2 15 1d
2c 3a :2 a 3e 40 :2 3e d :2 17
29 :2 33 3f 43 57 5a 5b :2 57
:2 29 :3 d :2 13 18 24 68 6b :2 24
78 7b :2 24 7f 82 :2 24 8c 8f
98 a0 :2 a9 :2 98 c6 :2 8f :2 24 ce
d1 :2 24 d9 dc :2 24 e1 e4 :2 24
e7 ea :2 24 :2 d 5e :2 a d :2 17
29 :2 33 3f 42 56 59 5a :2 56
:2 29 :3 d :2 13 18 24 68 6b :2 24
:2 d 5d :3 a :2 15 29 :2 32 4e 52
:2 a 42 :2 7 48 :3 4 11 4 e
12 29 38 d 1a 2b 39 b
1d 26 3f 48 61 6a :2 7 :2 10
1c 7 4 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 57 5a
5b :2 57 :2 29 :3 d :2 13 18 24 68
6b :2 24 78 7b :2 24 7f 82 :2 24
8e 91 :2 24 99 9c :2 24 a8 ab
b2 bb be :2 ab :2 24 :2 d 5e :2 a
:2 7 :4 13 :2 7 4 :3 1 4 12 4
8 :2 13 1a 24 :2 8 30 32 :2 30
7 3a a 1d :2 3a 23 20 :2 2c
:2 20 39 :3 7 15 :2 7 17 :2 7 1c
:2 25 :2 7 16 25 31 46 52 60
:2 16 :2 7 :2 10 1c :2 7 15 :2 7 17
:2 7 1c :2 25 :2 7 16 25 31 46
52 60 :2 16 :2 7 :2 10 1c 7 47
:2 4 :4 9 8 7 29 :2 34 3c 4a
56 :2 29 5a 5c :2 5a 28 :3 7 17
7 5f :2 4 :4 9 8 7 :4 27 26
25 :2 7 11 a 1c a 1c a
10 24 a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 5a 5d 5e
:2 5a :2 2c :3 10 :2 16 1b 27 6b 6e
:2 27 7b 7e :2 27 82 85 :2 27 91
94 :2 27 9c 9f :2 27 ab ae b5
be c1 :2 ae :2 27 :2 10 61 :2 d :2 a
:4 16 :2 a 7 :4 40 :4 b a :4 27 26
:2 a 14 d 1f d 13 27 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5d 60 61 :2 5d :2 2f :3 13
:2 19 1e 2a 6e 71 :2 2a 7e 81
:2 2a 85 88 :2 2a 94 97 :2 2a 9f
a2 :2 2a ae b1 b8 c1 c4 :2 b1
:2 2a :2 13 64 :2 10 :2 d :4 19 :2 d a
:3 45 d :2 18 20 2f 42 :2 d 46
48 :2 46 d 1b d 4a :2 a 45
:2 7 :4 b a :4 28 27 :2 a 14 d
1f d 13 27 d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5d
60 61 :2 5d :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a 7e 81 :2 2a 85 88
:2 2a 94 97 :2 2a 9f a2 :2 2a ae
b1 b8 c1 c4 :2 b1 :2 2a :2 13 64
:2 10 :2 d :4 19 :2 d a :3 47 d :2 18
20 2e 40 :2 d 44 46 :2 44 d
1b d 48 :2 a 47 :2 7 a 13
1f :2 a 22 24 :2 22 :4 f e d
30 :2 3b 43 52 5f :2 30 63 65
:2 63 2f :3 d 1e d 68 :2 a :4 f
e d :4 2d 2c 2b :2 d 4e :2 59
60 12 :2 4e 21 23 :2 21 4d :2 d
10 :2 1a 2c :2 36 42 46 5a 5d
5e :2 5a :2 2c :3 10 :2 16 1b 27 6b
6e :2 27 7b 7e :2 27 82 85 :2 27
8f 92 9b a3 :2 ac :2 9b c7 :2 92
:2 27 cf d2 :2 27 da dd :2 27 e2
e5 :2 27 ee f1 :2 27 :2 10 61 :2 d
10 :2 1a 2c :2 36 42 45 59 5c
5d :2 59 :2 2c :3 10 :2 16 1b 27 6b
6e :2 27 :2 10 60 :3 d :2 18 2c :2 35
4f 59 :2 d 26 :2 a :4 e d :4 11
10 13 :2 1d 2f :2 39 45 49 5d
60 61 :2 5d :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a 7e 81 :2 2a 85 88
:2 2a 92 95 9e a6 :2 af :2 9e ca
:2 95 :2 2a d2 d5 :2 2a dd e0 :2 2a
e5 e8 :2 2a eb ee :2 2a :2 13 64
:2 10 13 :2 1d 2f :2 39 45 48 5c
5f 60 :2 5c :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a :2 13 63 :3 10 :2 1b 2f
:2 38 52 56 :2 10 2d :3 d 19 d
10 :2 1b 23 31 40 :2 10 44 46
:2 44 10 20 10 d 48 13 :2 1e
26 34 40 :2 13 44 47 :2 44 1a
25 32 3c 47 4c 55 66 78
18 19 26 17 22 2a 31 :2 13
:2 1c 28 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 63
66 67 :2 63 :2 35 :3 19 :2 1f 24 30
74 77 :2 30 84 87 :2 30 8b 8e
:2 30 9a 9d :2 30 a5 a8 :2 30 b4
b7 be c7 ca :2 b7 :2 30 :2 19 6a
:2 16 :2 13 :4 1f :2 13 10 :3 49 14 :2 1d
28 26 :2 31 :2 26 13 1f 2a 37
3f 46 5e 69 80 92 :2 16 :2 1f
2b 16 13 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 66 69
6a :2 66 :2 38 :3 1c :2 22 27 33 77
7a :2 33 87 8a :2 33 8e 91 :2 33
9d a0 :2 33 a8 ab :2 33 b7 ba
c1 ca cd :2 ba :2 33 :2 1c 6d :2 19
:2 16 :4 22 :2 16 13 :4 41 :2 10 d 49
48 :4 14 :2 13 :2 1d 2f :2 39 45 49
5d 60 61 :2 5d :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 92 95 9e a6 :2 9e aa
:2 95 :2 2a b2 b5 :2 2a bd c0 :2 2a
c5 c8 :2 2a cb ce :2 2a :2 13 64
:2 10 13 :2 1d 2f :2 39 45 48 5c
5f 60 :2 5c :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a :2 13 63 :3 10 :2 1b 2f
32 36 :2 10 2c 48 :2 d 29 d
19 :2 d 1d d :4 a :4 e d :4 12
11 10 2f :2 3a 42 51 60 :2 2f
64 66 :2 64 2e :2 10 13 :2 1d 2f
:2 39 45 49 5d 60 61 :2 5d :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a 7e
81 :2 2a 85 88 :2 2a 92 95 9e
a6 :2 af :2 9e c0 :2 95 :2 2a c8 cb
:2 2a d3 d6 :2 2a db de :2 2a e1
e4 :2 2a :2 13 64 :2 10 13 :2 1d 2f
:2 39 45 48 5c 5f 60 :2 5c :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a :2 13
63 :3 10 :2 1b 2f :2 38 48 4c :2 10
d 69 :4 15 14 13 39 :2 44 4c
5b 15 :2 39 19 1c :2 19 38 :3 13
:2 1d 2f :2 39 45 48 5c 5f 60
:2 5c :2 2f :3 13 :2 19 1e 2a 6e 71
:2 2a 7e 81 :2 2a 85 88 :2 2a 92
95 9e a6 :2 af :2 9e ca :2 95 :2 2a
:2 13 63 :2 10 13 :2 1d 2f :2 39 45
48 5c 5f 60 :2 5c :2 2f :3 13 :2 19
1e 2a 6e 71 :2 2a :2 13 63 :3 10
:2 1b 31 :2 3a 54 :2 10 1f 69 :2 d
:4 12 11 10 2f :2 3a 42 51 5e
:2 2f 62 64 :2 62 2e :3 10 18 10
67 10 18 10 :4 d 10 :2 1b 23
32 42 :2 10 46 48 :2 46 10 21
10 d 4a 13 :2 1e 25 34 :2 13
41 44 :2 41 1a 25 32 3c 47
4c 55 65 77 18 19 26 17
22 2a 31 :2 13 :2 1c 28 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 63 66 67 :2 63 :2 35
:3 19 :2 1f 24 30 74 77 :2 30 84
87 :2 30 8b 8e :2 30 9a 9d :2 30
a5 a8 :2 30 b4 b7 be c7 ca
:2 b7 :2 30 :2 19 6a :2 16 :2 13 :4 1f :2 13
10 :3 46 14 :2 1d 28 26 :2 31 :2 26
13 1f 2a 37 3f 46 5f 6a
81 94 :2 16 :2 1f 2b 16 13 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:4 41 :2 10 d 46 4a 13 :2 1e 26
35 44 :2 13 48 4a :2 48 13 :2 1d
2f :2 39 45 49 5d 60 61 :2 5d
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
7e 81 :2 2a 85 88 :2 2a 92 95
9e a6 :2 9e aa :2 95 :2 2a b2 b5
:2 2a bd c0 :2 2a c5 c8 :2 2a cb
ce :2 2a :2 13 64 :2 10 13 :2 1d 2f
:2 39 45 48 5c 5f 60 :2 5c :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a :2 13
63 :3 10 :2 1b 2f 32 36 :2 10 4c
4a :2 d 2a d 1e d :5 a 18
:2 a 18 a d 16 29 :2 d 2f
2c :2 38 :2 2c 17 10 22 10 22
10 16 2a 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 60 63
64 :2 60 :2 32 :3 16 :2 1c 21 2d 71
74 :2 2d 81 84 :2 2d 88 8b :2 2d
97 9a :2 2d a2 a5 :2 2d b1 b4
bb c4 c7 :2 b4 :2 2d :2 16 67 :2 13
:2 10 :4 1c :2 10 d :4 52 :4 11 10 :4 14
13 1d 2d 1b 2b 39 1c 29
3c 50 69 7d 1a 25 2d 34
:2 16 :2 1f 2b 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 69 6a :2 66 :2 38 :3 1c :2 22 27
33 77 7a :2 33 87 8a :2 33 8e
91 :2 33 9d a0 :2 33 a8 ab :2 33
b7 ba c1 ca cd :2 ba :2 33 :2 1c
6d :2 19 :2 16 :4 22 :2 16 13 :3 30 16
1f 2b :2 16 2e 30 :2 2e 19 :2 23
35 :2 3f 4b 4f 63 66 67 :2 63
:2 35 :3 19 :2 1f 24 30 74 77 :2 30
84 87 :2 30 8b 8e :2 30 98 9b
a4 ac :2 b5 :2 a4 d4 :2 9b :2 30 dc
df :2 30 e7 ea :2 30 ef f2 :2 30
106 109 :2 30 :2 19 6a :2 16 19 :2 23
35 :2 3f 4b 4e 62 65 66 :2 62
:2 35 :3 19 :2 1f 24 30 74 77 :2 30
:2 19 69 :3 16 :2 21 35 :2 3e 5c 1e
:2 16 32 :2 13 10 30 :4 17 16 1d
2d 1b 2b 39 1c 29 3c 50
69 7d 1a 25 2d 34 :2 16 :2 1f
2b 16 13 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 66 69
6a :2 66 :2 38 :3 1c :2 22 27 33 77
7a :2 33 87 8a :2 33 8e 91 :2 33
9d a0 :2 33 a8 ab :2 33 b7 ba
c1 ca cd :2 ba :2 33 :2 1c 6d :2 19
:2 16 :4 22 :2 16 13 :3 32 16 1f 2b
:2 16 2e 30 :2 2e 19 :2 23 35 :2 3f
4b 4f 63 66 67 :2 63 :2 35 :3 19
:2 1f 24 30 74 77 :2 30 84 87
:2 30 8b 8e :2 30 98 9b a4 ac
:2 b5 :2 a4 d4 :2 9b :2 30 dc df :2 30
e7 ea :2 30 ef f2 :2 30 106 109
:2 30 :2 19 6a :2 16 19 :2 23 35 :2 3f
4b 4e 62 65 66 :2 62 :2 35 :3 19
:2 1f 24 30 74 77 :2 30 :2 19 69
:3 16 :2 21 35 :2 3e 5c 1e :2 16 32
20 24 34 41 1f 2c 3d 49
61 6d 75 7c :2 19 :2 22 2e 19
16 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 69 6c 6d :2 69
:2 3b :3 1f :2 25 2a 36 7a 7d :2 36
8a 8d :2 36 91 94 :2 36 a0 a3
:2 36 ab ae :2 36 ba bd c4 cd
d0 :2 bd :2 36 :2 1f 70 :2 1c :2 19 :4 25
:2 19 16 :3 13 19 22 2b :2 19 30
2e 39 40 :2 30 :2 2e 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9b 9e a7
af :2 b8 :2 a7 d7 :2 9e :2 33 df e2
:2 33 ea ed :2 33 f2 f5 :2 33 109
10c :2 33 :2 1c 6d :2 19 1c :2 26 38
:2 42 4e 51 65 68 69 :2 65 :2 38
:3 1c :2 22 27 33 77 7a :2 33 :2 1c
6c :3 19 :2 24 38 :2 41 5f 21 :2 19
43 :2 16 :4 13 32 30 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 95 98 a1
a9 :2 b2 :2 a1 ca :2 98 :2 2d d2 d5
:2 2d dd e0 :2 2d e5 e8 :2 2d fc
ff :2 2d :2 16 67 :2 13 16 :2 20 32
:2 3c 48 4b 5f 62 63 :2 5f :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d :2 16
66 :3 13 :2 1e 32 :2 3b 52 1b :2 13
:4 10 32 :3 d 1a :2 d 24 d :4 11
10 :4 2d 2c 2b :3 10 20 10 4c
:3 d 20 33 41 4c 29 3e 4c
29 3b 47 51 29 37 3e 49
4f 29 38 48 54 29 35 48
54 :2 20 :2 d 1b :2 d 20 30 3e
53 5f 62 :2 20 d :4 11 :2 10 1e
:2 10 23 33 41 56 62 65 :2 23
10 32 :2 d :4 a 26 :2 7 :4 4 8
:2 13 1a 24 :2 8 30 32 :2 30 7
3a a 1d :2 3a 23 20 :2 2c :2 20
39 :3 7 15 :2 7 17 :2 7 1c :2 25
:2 7 16 25 31 46 52 60 :2 16
:2 7 :2 10 1c :2 7 15 :2 7 17 :2 7
1c :2 25 :2 7 16 25 31 46 52
60 :2 16 :2 7 :2 10 1c 7 47 :3 4
17 21 :2 17 4 7 :2 11 23 :2 2d
39 3c 50 53 54 :2 50 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e 72 75
:2 1e 79 7c :2 1e 86 89 92 9a
:2 a3 :2 92 ae :2 89 :2 1e b6 b9 :2 1e
c1 c4 :2 1e c9 cc :2 1e cf d2
:2 1e :2 7 57 :3 4 :2 f 21 :2 2a 34
38 :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 54 57 58 :2 54
:2 26 :3 a :2 10 15 21 65 68 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
5b :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 51 54 55 :2 51
:2 23 :3 7 :2 d 12 1e 62 65 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 58 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
10ba
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 2
:4 8 :2 1 :7 a :7 b
:7 c :7 d :7 e :7 f
:7 10 :7 11 :5 12 :5 13
:5 14 :5 15 :5 16 :5 17
:5 18 :7 19 :6 1a :6 1b
:6 1c :6 1d :5 1e :5 1f
:5 20 :5 21 :5 22 :5 23
:7 24 :6 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:7 34 :5 35 :6 36 :7 38
:b 3a :11 3b 3c :2 3b
:2 3c :2 3b :2 3c :2 3b
:2 3d :2 3b :12 3d :2 3b
:2 3e :2 3b :12 3e :2 3b
:2 3f :2 3b :9 3f :2 3b
:2 40 :2 3b :2 40 :2 3b
:2 40 :2 3b :2 40 :2 3b
:2 40 :4 3b :3 3a :11 43
:b 44 :3 43 :3 4a :3 4b
:3 4d :3 4f :3 50 :3 51
:3 52 :a 53 :5 54 :3 53
:6 58 :f 59 :8 5a :6 5b
:9 5c :8 5d 5e :2 5f
58 :5 60 57 :2 62
:5 64 :11 65 :24 66 :3 65
:2 63 :6 62 61 :3 39
:a 6c :11 6d :30 6e :3 6d
:11 70 :b 71 :3 70 :a 73
:3 6c :9 76 :11 77 :30 78
:3 77 :11 7a :b 7b :3 7a
:a 7d :3 76 :e 80 :c 81
:11 82 :30 83 :3 82 :11 85
:b 86 :3 85 :a 88 :3 81
:3 80 :3 8c :4 8e :4 8f
:7 90 8e :5 91 8d
:2 93 :5 95 :11 96 :24 97
:3 96 :2 94 :6 93 92
:3 39 :3 9d :d 9e :2 9f
:2 9e :6 9f :3 9e :3 a0
:3 a1 :5 a2 :a a3 :5 a4
:3 a6 :3 a7 :5 a8 :a a9
:5 aa 9f :2 9e :15 ae
:3 af :3 ae :e b2 b4
:2 b5 :2 b6 b7 :2 b8
b4 :6 b9 :5 ba b9
:5 bc bb :3 b9 b3
:2 bf :5 c1 :11 c2 :24 c3
:3 c2 :2 c0 :6 bf be
:4 b2 :c ca ce :2 cf
d0 :2 d1 ce :6 d2
:5 d3 d2 :5 d5 d4
:3 d2 cd :2 d8 :5 da
:11 db :24 dc :3 db :2 d9
:6 d8 d7 :3 ca :c e3
:3 e5 :3 e3 :3 ca :c e9
ec :2 ed ee :2 ef
ec :6 f0 :5 f1 f0
:5 f3 f2 :3 f0 eb
:2 f6 :5 f8 :11 f9 :24 fa
:3 f9 :2 f7 :6 f6 f5
:3 e9 :c 102 :3 104 :3 102
:3 e9 :9 108 :15 10b :3 10c
:3 10b :12 10f 110 :2 10f
:4 110 :3 10f :11 111 :30 112
:3 111 :11 114 :b 115 :3 114
:a 117 110 :2 10f :5 11a
:5 11b :11 11c :30 11d :3 11c
:11 11f :b 120 :3 11f :a 122
:3 11b :3 126 :c 127 :3 128
129 127 :c 129 :9 12b
12c :2 12d :4 12e 12b
:5 12f 12a :2 131 :5 133
:11 134 :24 135 :3 134 :2 132
:6 131 130 :3 129 :a 13a
:a 13d :5 13e 13c :2 140
:5 142 :11 143 :24 144 :3 143
:2 141 :6 140 13f :6 13a
149 129 127 :5 149
:11 14a :2e 14b :3 14a :11 14d
:b 14e :3 14d :8 150 149
:3 127 11a :3 153 :3 154
152 :3 11a :5 157 :15 159
:11 15a :30 15b :3 15a :11 15d
:b 15e :3 15d :a 160 161
159 :b 161 162 :2 161
:4 162 :3 161 :11 163 :20 164
:3 163 :11 166 :b 167 :3 166
:9 169 162 :3 159 :15 16c
:3 16d 16c :3 16f 16e
:3 16c :c 173 :3 174 175
173 :b 175 :9 178 179
:2 17a :4 17b 178 :5 17c
177 :2 17e :5 180 :11 181
:24 182 :3 181 :2 17f :6 17e
17d :3 175 :a 188 :a 18b
:5 18c 18a :2 18e :5 190
:11 191 :24 192 :3 191 :2 18f
:6 18e 18d :6 188 197
175 173 :c 197 :11 199
:2e 19a :3 199 :11 19c :b 19d
:3 19c :8 19f 197 :3 173
157 :3 1a2 1a1 :3 157
:3 1a5 :3 1a6 :b 1a9 1ab
:2 1ac :2 1ad 1ae :2 1af
1ab :6 1b0 :5 1b1 1b0
:5 1b3 1b2 :3 1b0 1aa
:2 1b6 :5 1b8 :11 1b9 :24 1ba
:3 1b9 :2 1b7 :6 1b6 1b5
:4 1a9 :5 1c1 :5 1c3 :2 1c5
1c6 :2 1c7 :6 1c8 :4 1c9
1c5 :5 1ca 1c4 :2 1cc
:5 1ce :11 1cf :24 1d0 :3 1cf
:2 1cd :6 1cc 1cb :3 1c3
:9 1d4 :11 1d7 :30 1d8 :3 1d7
:11 1da :b 1db :3 1da :7 1dd
1de :2 1dd :3 1d4 1e0
1c3 :5 1e0 :2 1e3 1e4
:2 1e5 :6 1e6 :4 1e7 1e3
:5 1e8 1e2 :2 1ea :5 1ec
:11 1ed :24 1ee :3 1ed :2 1eb
:6 1ea 1e9 :3 1e0 :9 1f3
:11 1f5 :30 1f6 :3 1f5 :11 1f8
:b 1f9 :3 1f8 :7 1fb 1fc
:2 1fb 1f3 :4 203 :8 204
203 :5 205 202 :2 207
:5 209 :11 20a :24 20b :3 20a
:2 208 :6 207 206 :3 1fd
:d 20f :11 210 :30 211 :3 210
:11 213 :b 214 :3 213 :7 216
217 :2 216 :3 20f 1fd
:3 1f3 1e0 1c3 :11 21b
:30 21c :3 21b :11 21e :b 21f
:3 21e :7 221 222 :2 221
21a :3 1c3 :3 1c1 :3 227
:3 228 :d 22a :3 22b :3 22a
:5 22e :3 22f :4 230 :5 231
:4 232 :4 233 :3 22e :3 235
:a 236 :5 238 :3 239 :a 23a
:3 238 1be :3 1a9 :3 108
c8 :3 b2 :d 240 :2 241
:2 240 :6 241 :3 240 :3 242
:3 243 :5 244 :a 245 :5 246
:3 248 :3 249 :5 24a :a 24b
:5 24c 241 :2 240 :6 24f
:11 251 :30 252 :3 251 :a 254
39 :3 258 :11 259 :b 25a
:17 25b :3 259 :2 25d :3 25e
:3 25f 260 25e 25d
25e :3 261 :3 258 :2 262
:5 264 :11 265 :b 266 :18 267
:3 265 :2 269 26a :3 26b
26c 26a 269 26a
:3 26d :2 263 :6 262 257
:7 1 
3a6d
4
:3 0 1 :3 0 2
:a 0 10b5 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d :2 0 b
9 :3 0 8 :7 0
11 10 :3 0 4
:3 0 a :7 0 15
14 :3 0 b :3 0
c :3 0 d :2 0
4 19 1a 0
17 1b 0 10b5
2 1c :2 0 f
:2 0 15 4 :3 0
f :2 0 13 1f
21 :6 0 24 22
0 10b3 0 e
:6 0 f :2 0 19
4 :3 0 17 26
28 :6 0 2b 29
0 10b3 0 10
:6 0 f :2 0 1d
4 :3 0 1b 2d
2f :6 0 32 30
0 10b3 0 11
:6 0 f :2 0 21
4 :3 0 1f 34
36 :6 0 39 37
0 10b3 0 12
:6 0 f :2 0 25
4 :3 0 23 3b
3d :6 0 40 3e
0 10b3 0 13
:6 0 f :2 0 29
4 :3 0 27 42
44 :6 0 47 45
0 10b3 0 14
:6 0 f :2 0 2d
4 :3 0 2b 49
4b :6 0 4e 4c
0 10b3 0 15
:6 0 33 17e 0
31 4 :3 0 2f
50 52 :6 0 55
53 0 10b3 0
16 :6 0 37 1b2
0 35 6 :3 0
57 :7 0 5a 58
0 10b3 0 17
:6 0 6 :3 0 5c
:7 0 5f 5d 0
10b3 0 18 :6 0
3b 1e6 0 39
6 :3 0 61 :7 0
64 62 0 10b3
0 19 :6 0 6
:3 0 66 :7 0 69
67 0 10b3 0
1a :6 0 3f 21a
0 3d 6 :3 0
6b :7 0 6e 6c
0 10b3 0 1b
:6 0 6 :3 0 70
:7 0 73 71 0
10b3 0 1c :6 0
21 :2 0 43 6
:3 0 75 :7 0 78
76 0 10b3 0
1d :6 0 4 :3 0
1f :2 0 41 7a
7c :6 0 7f 7d
0 10b3 0 1e
:6 0 21 :2 0 45
9 :3 0 81 :7 0
85 82 83 10b3
0 20 :6 0 25
:2 0 47 9 :3 0
87 :7 0 8b 88
89 10b3 0 22
:6 0 25 :2 0 49
24 :3 0 8d :7 0
91 8e 8f 10b3
0 23 :6 0 4d
2c2 0 4b 24
:3 0 93 :7 0 97
94 95 10b3 0
26 :6 0 51 2f6
0 4f 6 :3 0
99 :7 0 9c 9a
0 10b3 0 27
:6 0 6 :3 0 9e
:7 0 a1 9f 0
10b3 0 28 :6 0
55 32a 0 53
2a :3 0 a3 :7 0
a6 a4 0 10b3
0 29 :6 0 2a
:3 0 a8 :7 0 ab
a9 0 10b3 0
2b :6 0 2f :2 0
57 2a :3 0 ad
:7 0 b0 ae 0
10b3 0 2c :6 0
2a :3 0 b2 :7 0
b5 b3 0 10b3
0 2d :6 0 21
:2 0 5b 4 :3 0
59 b7 b9 :6 0
bc ba 0 10b3
0 2e :6 0 21
:2 0 5d 9 :3 0
be :7 0 c2 bf
c0 10b3 0 30
:6 0 21 :2 0 5f
9 :3 0 c4 :7 0
c8 c5 c6 10b3
0 31 :6 0 21
:2 0 61 9 :3 0
ca :7 0 ce cb
cc 10b3 0 32
:6 0 21 :2 0 63
9 :3 0 d0 :7 0
d4 d1 d2 10b3
0 33 :6 0 21
:2 0 65 9 :3 0
d6 :7 0 da d7
d8 10b3 0 34
:6 0 21 :2 0 67
9 :3 0 dc :7 0
e0 dd de 10b3
0 35 :6 0 21
:2 0 69 9 :3 0
e2 :7 0 e6 e3
e4 10b3 0 36
:6 0 21 :2 0 6b
9 :3 0 e8 :7 0
ec e9 ea 10b3
0 37 :6 0 21
:2 0 6d 9 :3 0
ee :7 0 f2 ef
f0 10b3 0 38
:6 0 21 :2 0 6f
9 :3 0 f4 :7 0
f8 f5 f6 10b3
0 39 :6 0 21
:2 0 71 9 :3 0
fa :7 0 fe fb
fc 10b3 0 3a
:6 0 21 :2 0 73
9 :3 0 100 :7 0
104 101 102 10b3
0 3b :6 0 21
:2 0 75 9 :3 0
106 :7 0 10a 107
108 10b3 0 3c
:6 0 21 :2 0 77
9 :3 0 10c :7 0
110 10d 10e 10b3
0 3d :6 0 f
:2 0 79 9 :3 0
112 :7 0 116 113
114 10b3 0 3e
:6 0 7f 53c 0
7d 4 :3 0 7b
118 11a :6 0 11d
11b 0 10b3 0
3f :6 0 12a 12b
0 81 41 :3 0
11f :7 0 122 120
0 10b3 0 40
:6 0 9 :3 0 124
0 2 :5 0 21
:2 0 128 125 126
10b3 0 42 :6 0
130 131 0 83
c :3 0 d :2 0
4 12c :7 0 12f
12d 0 10b3 0
43 :6 0 44 :3 0
45 :3 0 44 :3 0
46 :3 0 133 134
0 2 :4 0 85
135 137 132 139
138 :2 0 47 :3 0
48 :3 0 13b 13c
0 49 :4 0 44
:3 0 4a :3 0 13f
140 0 2 :4 0
87 141 143 4b
:4 0 4c :2 0 4d
:3 0 89 146 148
:3 0 4e :4 0 4c
:2 0 4f :4 0 8c
14b 14d :3 0 4c
:2 0 3 :3 0 8f
14f 151 :3 0 4c
:2 0 4f :4 0 92
153 155 :3 0 4c
:2 0 50 :4 0 95
157 159 :3 0 4c
:2 0 51 :3 0 52
:3 0 4f :4 0 4c
:2 0 5 :3 0 98
15f 161 :3 0 4c
:2 0 4f :4 0 9b
163 165 :3 0 53
:4 0 9e 15d 168
54 :4 0 a1 15c
16b a4 15b 16d
:3 0 4c :2 0 50
:4 0 a7 16f 171
:3 0 4c :2 0 51
:3 0 52 :3 0 4f
:4 0 4c :2 0 7
:3 0 aa 177 179
:3 0 4c :2 0 4f
:4 0 ad 17b 17d
:3 0 53 :4 0 b0
175 180 54 :4 0
b3 174 183 b6
173 185 :3 0 4c
:2 0 50 :4 0 b9
187 189 :3 0 4c
:2 0 51 :3 0 55
:3 0 8 :3 0 bc
18d 18f 54 :4 0
be 18c 192 c1
18b 194 :3 0 4c
:2 0 50 :4 0 c4
196 198 :3 0 4c
:2 0 4f :4 0 c7
19a 19c :3 0 4c
:2 0 a :3 0 ca
19e 1a0 :3 0 4c
:2 0 4f :4 0 cd
1a2 1a4 :3 0 4c
:2 0 56 :4 0 d0
1a6 1a8 :3 0 d3
13d 1aa :2 0 1ac
d8 1ad 13a 1ac
0 1ae da 0
1013 44 :3 0 45
:3 0 1af 1b0 0
44 :3 0 57 :3 0
1b2 1b3 0 2f
:2 0 2 :4 0 58
:2 0 59 :2 0 2f
:2 0 dc 1b8 1ba
:3 0 df 1b4 1bc
1b1 1be 1bd :2 0
47 :3 0 5a :3 0
1c0 1c1 0 49
:4 0 5b :4 0 4c
:2 0 4d :3 0 e3
1c5 1c7 :3 0 e6
1c2 1c9 :2 0 1cb
e9 1cc 1bf 1cb
0 1cd eb 0
1013 17 :3 0 5c
:4 0 1ce 1cf 0
1013 18 :3 0 5c
:4 0 1d1 1d2 0
1013 35 :3 0 2f
:2 0 1d4 1d5 0
1013 17 :3 0 5
:3 0 1d7 1d8 0
1013 18 :3 0 7
:3 0 1da 1db 0
1013 12 :3 0 3
:3 0 1dd 1de 0
1013 39 :3 0 8
:3 0 1e0 1e1 0
1013 51 :3 0 39
:3 0 21 :2 0 ed
1e3 1e6 5d :2 0
2f :2 0 f2 1e8
1ea :3 0 1eb :2 0
39 :3 0 5e :3 0
5f :3 0 1ee 1ef
0 1ed 1f0 0
1f2 f5 1f3 1ec
1f2 0 1f4 f7
0 1013 60 :3 0
61 :3 0 62 :3 0
63 :3 0 64 :3 0
65 :3 0 51 :3 0
66 :3 0 67 :3 0
51 :3 0 68 :3 0
69 :3 0 66 :3 0
68 :3 0 6a :3 0
6b :3 0 6c :3 0
6d :3 0 6c :3 0
6e :3 0 6f :3 0
70 :3 0 71 :3 0
72 :3 0 73 :3 0
74 :3 0 75 :3 0
76 :3 0 77 :3 0
e :3 0 13 :3 0
11 :3 0 1d :3 0
20 :3 0 2e :3 0
19 :3 0 1a :3 0
1b :3 0 1c :3 0
10 :3 0 14 :3 0
34 :3 0 3a :3 0
32 :3 0 37 :3 0
29 :3 0 27 :3 0
28 :3 0 30 :3 0
31 :3 0 23 :3 0
26 :3 0 78 :3 0
79 :3 0 3 :4 0
7a 1 :8 0 232
c :3 0 7b :3 0
22d 22e 0 7c
:3 0 22f 230 0
232 f9 27c 7d
:3 0 c :3 0 7b
:3 0 235 236 0
7c :3 0 237 238
0 272 44 :3 0
45 :3 0 23a 23b
0 44 :3 0 57
:3 0 23d 23e 0
7e :2 0 2 :4 0
7f :2 0 59 :2 0
2f :2 0 fc 243
245 :3 0 ff 23f
247 23c 249 248
:2 0 47 :3 0 5a
:3 0 24b 24c 0
49 :4 0 80 :4 0
4c :2 0 4d :3 0
103 250 252 :3 0
4c :2 0 81 :4 0
106 254 256 :3 0
4c :2 0 82 :4 0
109 258 25a :3 0
4c :2 0 7c :3 0
10c 25c 25e :3 0
4c :2 0 83 :4 0
10f 260 262 :3 0
4c :2 0 84 :3 0
85 :3 0 2f :2 0
86 :2 0 112 265
269 116 264 26b
:3 0 119 24d 26d
:2 0 26f 11c 270
24a 26f 0 271
11e 0 272 120
275 :3 0 275 0
275 274 272 273
:6 0 277 2 :3 0
123 279 125 278
277 :2 0 27a 127
:2 0 27c 0 27c
27b 232 27a :6 0
1013 1 :3 0 c
:3 0 7b :3 0 27e
27f 0 c :3 0
5d :2 0 87 :3 0
281 283 0 12b
282 285 :3 0 286
:2 0 44 :3 0 45
:3 0 288 289 0
44 :3 0 57 :3 0
28b 28c 0 f
:2 0 2 :4 0 88
:2 0 59 :2 0 2f
:2 0 12e 291 293
:3 0 131 28d 295
28a 297 296 :2 0
47 :3 0 5a :3 0
299 29a 0 49
:4 0 89 :4 0 4c
:2 0 4d :3 0 135
29e 2a0 :3 0 4c
:2 0 81 :4 0 138
2a2 2a4 :3 0 4c
:2 0 8a :4 0 13b
2a6 2a8 :3 0 4c
:2 0 51 :3 0 55
:3 0 5e :3 0 8b
:3 0 2ad 2ae 0
13e 2ac 2b0 54
:4 0 140 2ab 2b3
143 2aa 2b5 :3 0
4c :2 0 8c :4 0
146 2b7 2b9 :3 0
4c :2 0 4f :4 0
149 2bb 2bd :3 0
4c :2 0 3 :3 0
14c 2bf 2c1 :3 0
4c :2 0 4f :4 0
14f 2c3 2c5 :3 0
152 29b 2c7 :2 0
2c9 155 2ca 298
2c9 0 2cb 157
0 2f5 44 :3 0
45 :3 0 2cc 2cd
0 44 :3 0 57
:3 0 2cf 2d0 0
2f :2 0 2 :4 0
8d :2 0 59 :2 0
2f :2 0 159 2d5
2d7 :3 0 15c 2d1
2d9 2ce 2db 2da
:2 0 47 :3 0 5a
:3 0 2dd 2de 0
49 :4 0 8e :4 0
4c :2 0 4d :3 0
160 2e2 2e4 :3 0
163 2df 2e6 :2 0
2e8 166 2e9 2dc
2e8 0 2ea 168
0 2f5 8f :3 0
90 :3 0 2eb 2ec
0 5e :3 0 8b
:3 0 2ee 2ef 0
3 :3 0 91 :3 0
16a 2ed 2f3 :2 0
2f5 16e 2f6 287
2f5 0 2f7 172
0 1013 51 :3 0
20 :3 0 21 :2 0
174 2f8 2fb 5d
:2 0 92 :2 0 179
2fd 2ff :3 0 44
:3 0 45 :3 0 301
302 0 44 :3 0
57 :3 0 304 305
0 f :2 0 2
:4 0 93 :2 0 59
:2 0 2f :2 0 17c
30a 30c :3 0 17f
306 30e 303 310
30f :2 0 47 :3 0
5a :3 0 312 313
0 49 :4 0 94
:4 0 4c :2 0 4d
:3 0 183 317 319
:3 0 4c :2 0 81
:4 0 186 31b 31d
:3 0 4c :2 0 8a
:4 0 189 31f 321
:3 0 4c :2 0 51
:3 0 55 :3 0 5e
:3 0 95 :3 0 326
327 0 18c 325
329 54 :4 0 18e
324 32c 191 323
32e :3 0 4c :2 0
8c :4 0 194 330
332 :3 0 4c :2 0
4f :4 0 197 334
336 :3 0 4c :2 0
3 :3 0 19a 338
33a :3 0 4c :2 0
4f :4 0 19d 33c
33e :3 0 1a0 314
340 :2 0 342 1a3
343 311 342 0
344 1a5 0 36e
44 :3 0 45 :3 0
345 346 0 44
:3 0 57 :3 0 348
349 0 2f :2 0
2 :4 0 96 :2 0
59 :2 0 2f :2 0
1a7 34e 350 :3 0
1aa 34a 352 347
354 353 :2 0 47
:3 0 5a :3 0 356
357 0 49 :4 0
97 :4 0 4c :2 0
4d :3 0 1ae 35b
35d :3 0 1b1 358
35f :2 0 361 1b4
362 355 361 0
363 1b6 0 36e
8f :3 0 90 :3 0
364 365 0 5e
:3 0 95 :3 0 367
368 0 3 :3 0
91 :3 0 1b8 366
36c :2 0 36e 1bc
36f 300 36e 0
370 1c0 0 1013
5 :3 0 98 :2 0
1c2 372 373 :3 0
374 :2 0 375 :2 0
7 :3 0 98 :2 0
1c4 378 379 :3 0
37a :2 0 37b :2 0
376 37d 37c :2 0
99 :3 0 9a :3 0
37f 380 0 18
:3 0 17 :3 0 9b
:2 0 1c6 381 385
9c :2 0 21 :2 0
1cc 387 389 :3 0
44 :3 0 45 :3 0
38b 38c 0 44
:3 0 57 :3 0 38e
38f 0 f :2 0
2 :4 0 9d :2 0
59 :2 0 2f :2 0
1cf 394 396 :3 0
1d2 390 398 38d
39a 399 :2 0 47
:3 0 5a :3 0 39c
39d 0 49 :4 0
9e :4 0 4c :2 0
4d :3 0 1d6 3a1
3a3 :3 0 4c :2 0
81 :4 0 1d9 3a5
3a7 :3 0 4c :2 0
8a :4 0 1dc 3a9
3ab :3 0 4c :2 0
51 :3 0 55 :3 0
5e :3 0 9f :3 0
3b0 3b1 0 1df
3af 3b3 54 :4 0
1e1 3ae 3b6 1e4
3ad 3b8 :3 0 4c
:2 0 8c :4 0 1e7
3ba 3bc :3 0 4c
:2 0 4f :4 0 1ea
3be 3c0 :3 0 4c
:2 0 3 :3 0 1ed
3c2 3c4 :3 0 4c
:2 0 4f :4 0 1f0
3c6 3c8 :3 0 1f3
39e 3ca :2 0 3cc
1f6 3cd 39b 3cc
0 3ce 1f8 0
3f8 44 :3 0 45
:3 0 3cf 3d0 0
44 :3 0 57 :3 0
3d2 3d3 0 2f
:2 0 2 :4 0 a0
:2 0 59 :2 0 2f
:2 0 1fa 3d8 3da
:3 0 1fd 3d4 3dc
3d1 3de 3dd :2 0
47 :3 0 5a :3 0
3e0 3e1 0 49
:4 0 a1 :4 0 4c
:2 0 4d :3 0 201
3e5 3e7 :3 0 204
3e2 3e9 :2 0 3eb
207 3ec 3df 3eb
0 3ed 209 0
3f8 8f :3 0 90
:3 0 3ee 3ef 0
5e :3 0 9f :3 0
3f1 3f2 0 3
:3 0 91 :3 0 20b
3f0 3f6 :2 0 3f8
20f 3f9 38a 3f8
0 3fa 213 0
3fb 215 3fc 37e
3fb 0 3fd 217
0 1013 2d :4 0
3fe 3ff 0 1013
a2 :3 0 a3 :3 0
2d :3 0 a4 :3 0
a5 :3 0 e :3 0
6b :3 0 14 :3 0
a6 :3 0 5e :3 0
a7 :3 0 5e :3 0
a8 :3 0 5e :3 0
a9 :4 0 aa 1
:8 0 416 c :3 0
7b :3 0 411 412
0 7c :3 0 413
414 0 416 219
460 7d :3 0 c
:3 0 7b :3 0 419
41a 0 7c :3 0
41b 41c 0 456
44 :3 0 45 :3 0
41e 41f 0 44
:3 0 57 :3 0 421
422 0 7e :2 0
2 :4 0 ab :2 0
59 :2 0 2f :2 0
21c 427 429 :3 0
21f 423 42b 420
42d 42c :2 0 47
:3 0 5a :3 0 42f
430 0 49 :4 0
ac :4 0 4c :2 0
4d :3 0 223 434
436 :3 0 4c :2 0
81 :4 0 226 438
43a :3 0 4c :2 0
82 :4 0 229 43c
43e :3 0 4c :2 0
7c :3 0 22c 440
442 :3 0 4c :2 0
83 :4 0 22f 444
446 :3 0 4c :2 0
84 :3 0 85 :3 0
2f :2 0 86 :2 0
232 449 44d 236
448 44f :3 0 239
431 451 :2 0 453
23c 454 42e 453
0 455 23e 0
456 240 459 :3 0
459 0 459 458
456 457 :6 0 45b
4 :3 0 243 45d
245 45c 45b :2 0
45e 247 :2 0 460
0 460 45f 416
45e :6 0 1013 1
:3 0 15 :3 0 a
:3 0 462 463 0
1013 99 :3 0 ad
:3 0 465 466 0
14 :3 0 15 :3 0
249 467 46a 5d
:2 0 21 :2 0 24e
46c 46e :3 0 46f
:2 0 51 :3 0 39
:3 0 21 :2 0 251
471 474 5e :3 0
ae :2 0 5f :3 0
476 478 0 256
477 47a :3 0 47b
:2 0 470 47d 47c
:2 0 3f :3 0 af
:4 0 47f 480 0
4b3 3e :3 0 2f
:2 0 482 483 0
4b3 42 :3 0 c
:3 0 7b :3 0 486
487 0 485 488
0 4b3 40 :3 0
b0 :3 0 3f :3 0
12 :3 0 15 :3 0
3e :3 0 21 :2 0
259 48b 491 48a
492 0 4b3 c
:3 0 7b :3 0 494
495 0 42 :3 0
496 497 0 4b3
3f :3 0 b1 :4 0
499 49a 0 4b3
3e :3 0 21 :2 0
49c 49d 0 4b3
42 :3 0 c :3 0
7b :3 0 4a0 4a1
0 49f 4a2 0
4b3 40 :3 0 b0
:3 0 3f :3 0 12
:3 0 15 :3 0 3e
:3 0 21 :2 0 25f
4a5 4ab 4a4 4ac
0 4b3 c :3 0
7b :3 0 4ae 4af
0 42 :3 0 4b0
4b1 0 4b3 265
4b4 47e 4b3 0
4b5 270 0 1013
17 :3 0 98 :2 0
272 4b7 4b8 :3 0
4b9 :2 0 4ba :2 0
99 :3 0 9a :3 0
4bc 4bd 0 17
:3 0 19 :3 0 9b
:2 0 274 4be 4c2
5d :2 0 21 :2 0
27a 4c4 4c6 :3 0
4c7 :2 0 4bb 4c9
4c8 :2 0 17 :3 0
19 :3 0 4cb 4cc
0 4ce 27d 4cf
4ca 4ce 0 4d0
27f 0 1013 5
:3 0 b2 :2 0 281
4d2 4d3 :3 0 4d4
:2 0 4d5 :2 0 7
:3 0 b2 :2 0 283
4d8 4d9 :3 0 4da
:2 0 4db :2 0 4d6
4dd 4dc :2 0 78
:3 0 66 :3 0 5
:3 0 68 :3 0 7
:3 0 b3 :3 0 79
:3 0 3 :4 0 b4
1 :8 0 4fd b5
:4 0 4e8 :3 0 91
:3 0 5d :2 0 287
4eb 4ec :3 0 c
:3 0 7b :3 0 4ee
4ef 0 21 :2 0
4f0 4f1 0 4f3
28a 4fa c :3 0
7b :3 0 4f4 4f5
0 b6 :2 0 4f6
4f7 0 4f9 28c
4fb 4ed 4f3 0
4fc 0 4f9 0
4fc 28e 0 4fd
291 547 7d :3 0
c :3 0 7b :3 0
500 501 0 7c
:3 0 502 503 0
53d 44 :3 0 45
:3 0 505 506 0
44 :3 0 57 :3 0
508 509 0 7e
:2 0 2 :4 0 b7
:2 0 59 :2 0 2f
:2 0 294 50e 510
:3 0 297 50a 512
507 514 513 :2 0
47 :3 0 5a :3 0
516 517 0 49
:4 0 b8 :4 0 4c
:2 0 4d :3 0 29b
51b 51d :3 0 4c
:2 0 81 :4 0 29e
51f 521 :3 0 4c
:2 0 82 :4 0 2a1
523 525 :3 0 4c
:2 0 7c :3 0 2a4
527 529 :3 0 4c
:2 0 83 :4 0 2a7
52b 52d :3 0 4c
:2 0 84 :3 0 85
:3 0 2f :2 0 86
:2 0 2aa 530 534
2ae 52f 536 :3 0
2b1 518 538 :2 0
53a 2b4 53b 515
53a 0 53c 2b6
0 53d 2b8 540
:3 0 540 0 540
53f 53d 53e :6 0
542 6 :3 0 2bb
544 2bd 543 542
:2 0 545 2bf :2 0
547 0 547 546
4fd 545 :6 0 549
1 :3 0 2c1 f6b
5 :3 0 b2 :2 0
2c3 54b 54c :3 0
54d :2 0 1b :3 0
98 :2 0 2c5 550
551 :3 0 552 :2 0
54e 554 553 :2 0
78 :3 0 66 :3 0
5 :3 0 b3 :3 0
79 :3 0 3 :4 0
b9 1 :8 0 572
b5 :4 0 55d :3 0
91 :3 0 5d :2 0
2c9 560 561 :3 0
c :3 0 7b :3 0
563 564 0 21
:2 0 565 566 0
568 2cc 56f c
:3 0 7b :3 0 569
56a 0 b6 :2 0
56b 56c 0 56e
2ce 570 562 568
0 571 0 56e
0 571 2d0 0
572 2d3 5bc 7d
:3 0 c :3 0 7b
:3 0 575 576 0
7c :3 0 577 578
0 5b2 44 :3 0
45 :3 0 57a 57b
0 44 :3 0 57
:3 0 57d 57e 0
7e :2 0 2 :4 0
ba :2 0 59 :2 0
2f :2 0 2d6 583
585 :3 0 2d9 57f
587 57c 589 588
:2 0 47 :3 0 5a
:3 0 58b 58c 0
49 :4 0 bb :4 0
4c :2 0 4d :3 0
2dd 590 592 :3 0
4c :2 0 81 :4 0
2e0 594 596 :3 0
4c :2 0 82 :4 0
2e3 598 59a :3 0
4c :2 0 7c :3 0
2e6 59c 59e :3 0
4c :2 0 83 :4 0
2e9 5a0 5a2 :3 0
4c :2 0 84 :3 0
85 :3 0 2f :2 0
86 :2 0 2ec 5a5
5a9 2f0 5a4 5ab
:3 0 2f3 58d 5ad
:2 0 5af 2f6 5b0
58a 5af 0 5b1
2f8 0 5b2 2fa
5b5 :3 0 5b5 0
5b5 5b4 5b2 5b3
:6 0 5b7 8 :3 0
2fd 5b9 2ff 5b8
5b7 :2 0 5ba 301
:2 0 5bc 0 5bc
5bb 572 5ba :6 0
5d0 1 :3 0 99
:3 0 9a :3 0 5be
5bf 0 18 :3 0
1c :3 0 9b :2 0
303 5c0 5c4 5d
:2 0 21 :2 0 309
5c6 5c8 :3 0 35
:3 0 21 :2 0 5ca
5cb 0 5cd 30c
5ce 5c9 5cd 0
5cf 30e 0 5d0
310 5d1 555 5d0
0 5d2 313 0
f6a 7 :3 0 b2
:2 0 315 5d4 5d5
:3 0 5d6 :2 0 1c
:3 0 98 :2 0 317
5d9 5da :3 0 5db
:2 0 5d7 5dd 5dc
:2 0 78 :3 0 68
:3 0 7 :3 0 b3
:3 0 79 :3 0 3
:4 0 bc 1 :8 0
5fb b5 :4 0 5e6
:3 0 91 :3 0 5d
:2 0 31b 5e9 5ea
:3 0 c :3 0 7b
:3 0 5ec 5ed 0
21 :2 0 5ee 5ef
0 5f1 31e 5f8
c :3 0 7b :3 0
5f2 5f3 0 b6
:2 0 5f4 5f5 0
5f7 320 5f9 5eb
5f1 0 5fa 0
5f7 0 5fa 322
0 5fb 325 645
7d :3 0 c :3 0
7b :3 0 5fe 5ff
0 7c :3 0 600
601 0 63b 44
:3 0 45 :3 0 603
604 0 44 :3 0
57 :3 0 606 607
0 7e :2 0 2
:4 0 bd :2 0 59
:2 0 2f :2 0 328
60c 60e :3 0 32b
608 610 605 612
611 :2 0 47 :3 0
5a :3 0 614 615
0 49 :4 0 be
:4 0 4c :2 0 4d
:3 0 32f 619 61b
:3 0 4c :2 0 81
:4 0 332 61d 61f
:3 0 4c :2 0 82
:4 0 335 621 623
:3 0 4c :2 0 7c
:3 0 338 625 627
:3 0 4c :2 0 83
:4 0 33b 629 62b
:3 0 4c :2 0 84
:3 0 85 :3 0 2f
:2 0 86 :2 0 33e
62e 632 342 62d
634 :3 0 345 616
636 :2 0 638 348
639 613 638 0
63a 34a 0 63b
34c 63e :3 0 63e
0 63e 63d 63b
63c :6 0 640 a
:3 0 34f 642 351
641 640 :2 0 643
353 :2 0 645 0
645 644 5fb 643
:6 0 659 1 :3 0
99 :3 0 9a :3 0
647 648 0 17
:3 0 1b :3 0 9b
:2 0 355 649 64d
5d :2 0 21 :2 0
35b 64f 651 :3 0
35 :3 0 21 :2 0
653 654 0 656
35e 657 652 656
0 658 360 0
659 362 65a 5de
659 0 65b 365
0 f6a 51 :3 0
35 :3 0 21 :2 0
367 65c 65f 5d
:2 0 2f :2 0 36c
661 663 :3 0 18
:3 0 98 :2 0 36f
666 667 :3 0 668
:2 0 669 :2 0 99
:3 0 9a :3 0 66b
66c 0 18 :3 0
1a :3 0 9b :2 0
371 66d 671 5d
:2 0 21 :2 0 377
673 675 :3 0 676
:2 0 66a 678 677
:2 0 18 :3 0 1a
:3 0 67a 67b 0
67d 37a 67e 679
67d 0 67f 37c
0 f67 2d :3 0
98 :2 0 37e 681
682 :3 0 683 :2 0
684 :2 0 18 :3 0
98 :2 0 380 687
688 :3 0 689 :2 0
68a :2 0 685 68c
68b :2 0 99 :3 0
ad :3 0 68e 68f
0 2d :3 0 18
:3 0 382 690 693
bf :2 0 21 :2 0
387 695 697 :3 0
698 :2 0 68d 69a
699 :2 0 44 :3 0
45 :3 0 69c 69d
0 44 :3 0 57
:3 0 69f 6a0 0
f :2 0 2 :4 0
c0 :2 0 59 :2 0
2f :2 0 38a 6a5
6a7 :3 0 38d 6a1
6a9 69e 6ab 6aa
:2 0 47 :3 0 5a
:3 0 6ad 6ae 0
49 :4 0 c1 :4 0
4c :2 0 4d :3 0
391 6b2 6b4 :3 0
4c :2 0 81 :4 0
394 6b6 6b8 :3 0
4c :2 0 8a :4 0
397 6ba 6bc :3 0
4c :2 0 51 :3 0
55 :3 0 5e :3 0
c2 :3 0 6c1 6c2
0 39a 6c0 6c4
54 :4 0 39c 6bf
6c7 39f 6be 6c9
:3 0 4c :2 0 8c
:4 0 3a2 6cb 6cd
:3 0 4c :2 0 4f
:4 0 3a5 6cf 6d1
:3 0 4c :2 0 14
:3 0 3a8 6d3 6d5
:3 0 4c :2 0 4f
:4 0 3ab 6d7 6d9
:3 0 3ae 6af 6db
:2 0 6dd 3b1 6de
6ac 6dd 0 6df
3b3 0 709 44
:3 0 45 :3 0 6e0
6e1 0 44 :3 0
57 :3 0 6e3 6e4
0 2f :2 0 2
:4 0 c3 :2 0 59
:2 0 2f :2 0 3b5
6e9 6eb :3 0 3b8
6e5 6ed 6e2 6ef
6ee :2 0 47 :3 0
5a :3 0 6f1 6f2
0 49 :4 0 c4
:4 0 4c :2 0 4d
:3 0 3bc 6f6 6f8
:3 0 3bf 6f3 6fa
:2 0 6fc 3c2 6fd
6f0 6fc 0 6fe
3c4 0 709 8f
:3 0 90 :3 0 6ff
700 0 5e :3 0
c2 :3 0 702 703
0 14 :3 0 91
:3 0 3c6 701 707
:2 0 709 3ca 70a
69b 709 0 70b
3ce 0 f67 5
:3 0 98 :2 0 3d0
70d 70e :3 0 70f
:2 0 1d :3 0 98
:2 0 3d2 712 713
:3 0 714 :2 0 44
:3 0 45 :3 0 716
717 0 44 :3 0
57 :3 0 719 71a
0 f :2 0 2
:4 0 c5 :2 0 59
:2 0 2f :2 0 3d4
71f 721 :3 0 3d7
71b 723 718 725
724 :2 0 47 :3 0
5a :3 0 727 728
0 49 :4 0 c6
:4 0 4c :2 0 4d
:3 0 3db 72c 72e
:3 0 4c :2 0 81
:4 0 3de 730 732
:3 0 4c :2 0 8a
:4 0 3e1 734 736
:3 0 4c :2 0 51
:3 0 55 :3 0 5e
:3 0 c7 :3 0 73b
73c 0 3e4 73a
73e 54 :4 0 3e6
739 741 3e9 738
743 :3 0 4c :2 0
8c :4 0 3ec 745
747 :3 0 4c :2 0
4f :4 0 3ef 749
74b :3 0 4c :2 0
3 :3 0 3f2 74d
74f :3 0 4c :2 0
4f :4 0 3f5 751
753 :3 0 3f8 729
755 :2 0 757 3fb
758 726 757 0
759 3fd 0 783
44 :3 0 45 :3 0
75a 75b 0 44
:3 0 57 :3 0 75d
75e 0 2f :2 0
2 :4 0 c8 :2 0
59 :2 0 2f :2 0
3ff 763 765 :3 0
402 75f 767 75c
769 768 :2 0 47
:3 0 5a :3 0 76b
76c 0 49 :4 0
c9 :4 0 4c :2 0
4d :3 0 406 770
772 :3 0 409 76d
774 :2 0 776 40c
777 76a 776 0
778 40e 0 783
8f :3 0 90 :3 0
779 77a 0 5e
:3 0 c7 :3 0 77c
77d 0 3 :3 0
91 :3 0 410 77b
781 :2 0 783 414
784 715 783 0
785 418 0 8e5
36 :3 0 32 :3 0
786 787 0 8e5
99 :3 0 9a :3 0
789 78a 0 17
:3 0 27 :3 0 9b
:2 0 41a 78b 78f
5d :2 0 21 :2 0
420 791 793 :3 0
17 :4 0 795 796
0 799 ca :3 0
423 8e3 99 :3 0
9a :3 0 79a 79b
0 17 :3 0 19
:3 0 9b :2 0 425
79c 7a0 ae :2 0
21 :2 0 42b 7a2
7a4 :3 0 99 :3 0
cb :3 0 cc :3 0
99 :3 0 cd :3 0
ce :3 0 cf :3 0
d0 :3 0 17 :3 0
d1 :3 0 a5 :3 0
e :3 0 cc :3 0
d2 :3 0 84 :3 0
5 :4 0 d3 1
:8 0 7bc c :3 0
7b :3 0 7b7 7b8
0 7c :3 0 7b9
7ba 0 7bc 42e
806 7d :3 0 c
:3 0 7b :3 0 7bf
7c0 0 7c :3 0
7c1 7c2 0 7fc
44 :3 0 45 :3 0
7c4 7c5 0 44
:3 0 57 :3 0 7c7
7c8 0 7e :2 0
2 :4 0 d4 :2 0
59 :2 0 2f :2 0
431 7cd 7cf :3 0
434 7c9 7d1 7c6
7d3 7d2 :2 0 47
:3 0 5a :3 0 7d5
7d6 0 49 :4 0
d5 :4 0 4c :2 0
4d :3 0 438 7da
7dc :3 0 4c :2 0
81 :4 0 43b 7de
7e0 :3 0 4c :2 0
82 :4 0 43e 7e2
7e4 :3 0 4c :2 0
7c :3 0 441 7e6
7e8 :3 0 4c :2 0
83 :4 0 444 7ea
7ec :3 0 4c :2 0
84 :3 0 85 :3 0
2f :2 0 86 :2 0
447 7ef 7f3 44b
7ee 7f5 :3 0 44e
7d7 7f7 :2 0 7f9
451 7fa 7d4 7f9
0 7fb 453 0
7fc 455 7ff :3 0
7ff 0 7ff 7fe
7fc 7fd :6 0 801
c :3 0 458 803
45a 802 801 :2 0
804 45c :2 0 806
0 806 805 7bc
804 :6 0 871 1
:3 0 c :3 0 7b
:3 0 808 809 0
c :3 0 5d :2 0
87 :3 0 80b 80d
0 460 80c 80f
:3 0 810 :2 0 99
:3 0 cb :3 0 d2
:3 0 84 :3 0 5
:3 0 99 :3 0 cd
:3 0 17 :3 0 d6
:4 0 d7 1 :8 0
821 c :3 0 7b
:3 0 81c 81d 0
7c :3 0 81e 81f
0 821 463 86b
7d :3 0 c :3 0
7b :3 0 824 825
0 7c :3 0 826
827 0 861 44
:3 0 45 :3 0 829
82a 0 44 :3 0
57 :3 0 82c 82d
0 7e :2 0 2
:4 0 d8 :2 0 59
:2 0 2f :2 0 466
832 834 :3 0 469
82e 836 82b 838
837 :2 0 47 :3 0
5a :3 0 83a 83b
0 49 :4 0 d9
:4 0 4c :2 0 4d
:3 0 46d 83f 841
:3 0 4c :2 0 81
:4 0 470 843 845
:3 0 4c :2 0 82
:4 0 473 847 849
:3 0 4c :2 0 7c
:3 0 476 84b 84d
:3 0 4c :2 0 83
:4 0 479 84f 851
:3 0 4c :2 0 84
:3 0 85 :3 0 2f
:2 0 86 :2 0 47c
854 858 480 853
85a :3 0 483 83c
85c :2 0 85e 486
85f 839 85e 0
860 488 0 861
48a 864 :3 0 864
0 864 863 861
862 :6 0 866 e
:3 0 48d 868 48f
867 866 :2 0 869
491 :2 0 86b 0
86b 86a 821 869
:6 0 86d 1 :3 0
493 86e 811 86d
0 86f 495 0
871 ca :3 0 497
872 7a5 871 0
8e4 7 :3 0 b2
:2 0 49a 874 875
:3 0 876 :2 0 44
:3 0 45 :3 0 878
879 0 44 :3 0
57 :3 0 87b 87c
0 f :2 0 2
:4 0 da :2 0 59
:2 0 2f :2 0 49c
881 883 :3 0 49f
87d 885 87a 887
886 :2 0 47 :3 0
5a :3 0 889 88a
0 49 :4 0 db
:4 0 4c :2 0 4d
:3 0 4a3 88e 890
:3 0 4c :2 0 81
:4 0 4a6 892 894
:3 0 4c :2 0 8a
:4 0 4a9 896 898
:3 0 4c :2 0 51
:3 0 55 :3 0 21
:2 0 4ac 89c 89e
54 :4 0 4ae 89b
8a1 4b1 89a 8a3
:3 0 4c :2 0 8c
:4 0 4b4 8a5 8a7
:3 0 4c :2 0 4f
:4 0 4b7 8a9 8ab
:3 0 4c :2 0 3
:3 0 4ba 8ad 8af
:3 0 4c :2 0 4f
:4 0 4bd 8b1 8b3
:3 0 4c0 88b 8b5
:2 0 8b7 4c3 8b8
888 8b7 0 8b9
4c5 0 8e1 44
:3 0 45 :3 0 8ba
8bb 0 44 :3 0
57 :3 0 8bd 8be
0 2f :2 0 2
:4 0 dc :2 0 59
:2 0 2f :2 0 4c7
8c3 8c5 :3 0 4ca
8bf 8c7 8bc 8c9
8c8 :2 0 47 :3 0
5a :3 0 8cb 8cc
0 49 :4 0 dd
:4 0 4c :2 0 4d
:3 0 4ce 8d0 8d2
:3 0 4d1 8cd 8d4
:2 0 8d6 4d4 8d7
8ca 8d6 0 8d8
4d6 0 8e1 8f
:3 0 90 :3 0 8d9
8da 0 21 :2 0
3 :3 0 91 :3 0
4d8 8db 8df :2 0
8e1 4dc 8e2 877
8e1 0 8e4 794
799 0 8e4 4e0
0 8e5 4e4 8ed
36 :3 0 21 :2 0
8e6 8e7 0 8ec
17 :4 0 8e9 8ea
0 8ec 4e8 8ee
710 8e5 0 8ef
0 8ec 0 8ef
4eb 0 f67 7
:3 0 98 :2 0 4ee
8f1 8f2 :3 0 8f3
:2 0 5 :3 0 b2
:2 0 4f0 8f6 8f7
:3 0 8f8 :2 0 8f9
:2 0 99 :3 0 9a
:3 0 8fb 8fc 0
18 :3 0 27 :3 0
9b :2 0 4f2 8fd
901 9c :2 0 21
:2 0 4f8 903 905
:3 0 906 :2 0 8fa
908 907 :2 0 44
:3 0 45 :3 0 90a
90b 0 44 :3 0
57 :3 0 90d 90e
0 f :2 0 2
:4 0 de :2 0 59
:2 0 2f :2 0 4fb
913 915 :3 0 4fe
90f 917 90c 919
918 :2 0 47 :3 0
5a :3 0 91b 91c
0 49 :4 0 df
:4 0 4c :2 0 4d
:3 0 502 920 922
:3 0 4c :2 0 81
:4 0 505 924 926
:3 0 4c :2 0 8a
:4 0 508 928 92a
:3 0 4c :2 0 51
:3 0 55 :3 0 5e
:3 0 e0 :3 0 92f
930 0 50b 92e
932 54 :4 0 50d
92d 935 510 92c
937 :3 0 4c :2 0
8c :4 0 513 939
93b :3 0 4c :2 0
4f :4 0 516 93d
93f :3 0 4c :2 0
3 :3 0 519 941
943 :3 0 4c :2 0
4f :4 0 51c 945
947 :3 0 51f 91d
949 :2 0 94b 522
94c 91a 94b 0
94d 524 0 978
44 :3 0 45 :3 0
94e 94f 0 44
:3 0 57 :3 0 951
952 0 2f :2 0
2 :4 0 e1 :2 0
59 :2 0 2f :2 0
526 957 959 :3 0
529 953 95b 950
95d 95c :2 0 47
:3 0 5a :3 0 95f
960 0 49 :4 0
e2 :4 0 4c :2 0
4d :3 0 52d 964
966 :3 0 530 961
968 :2 0 96a 533
96b 95e 96a 0
96c 535 0 978
8f :3 0 90 :3 0
96d 96e 0 5e
:3 0 e0 :3 0 970
971 0 3 :3 0
91 :3 0 537 96f
975 :2 0 978 ca
:3 0 53b 9ec 29
:3 0 98 :2 0 53f
97a 97b :3 0 97c
:2 0 97d :2 0 99
:3 0 9a :3 0 97f
980 0 18 :3 0
29 :3 0 9b :2 0
541 981 985 e3
:2 0 21 :2 0 547
987 989 :3 0 98a
:2 0 97e 98c 98b
:2 0 44 :3 0 45
:3 0 98e 98f 0
44 :3 0 57 :3 0
991 992 0 e4
:2 0 2 :4 0 e5
:2 0 59 :2 0 2f
:2 0 54a 997 999
:3 0 54d 993 99b
990 99d 99c :2 0
47 :3 0 5a :3 0
99f 9a0 0 49
:4 0 e6 :4 0 4c
:2 0 4d :3 0 551
9a4 9a6 :3 0 4c
:2 0 81 :4 0 554
9a8 9aa :3 0 4c
:2 0 8a :4 0 557
9ac 9ae :3 0 4c
:2 0 51 :3 0 55
:3 0 5e :3 0 c7
:3 0 9b3 9b4 0
55a 9b2 9b6 54
:4 0 55c 9b1 9b9
55f 9b0 9bb :3 0
562 9a1 9bd :2 0
9bf 565 9c0 99e
9bf 0 9c1 567
0 9ea 44 :3 0
45 :3 0 9c2 9c3
0 44 :3 0 57
:3 0 9c5 9c6 0
2f :2 0 2 :4 0
e7 :2 0 59 :2 0
2f :2 0 569 9cb
9cd :3 0 56c 9c7
9cf 9c4 9d1 9d0
:2 0 47 :3 0 5a
:3 0 9d3 9d4 0
49 :4 0 e8 :4 0
4c :2 0 4d :3 0
570 9d8 9da :3 0
573 9d5 9dc :2 0
9de 576 9df 9d2
9de 0 9e0 578
0 9ea 8f :3 0
e9 :3 0 9e1 9e2
0 5e :3 0 c7
:3 0 9e4 9e5 0
91 :3 0 57a 9e3
9e8 :2 0 9ea 57d
9eb 98d 9ea 0
9ed 909 978 0
9ed 581 0 b70
5 :3 0 b2 :2 0
584 9ef 9f0 :3 0
9f1 :2 0 9f2 :2 0
99 :3 0 9a :3 0
9f4 9f5 0 18
:3 0 1a :3 0 9b
:2 0 586 9f6 9fa
9c :2 0 21 :2 0
58c 9fc 9fe :3 0
9ff :2 0 9f3 a01
a00 :2 0 3b :3 0
2f :2 0 a03 a04
0 a06 58f a0b
3b :3 0 21 :2 0
a07 a08 0 a0a
591 a0c a02 a06
0 a0d 0 a0a
0 a0d 593 0
b70 99 :3 0 9a
:3 0 a0e a0f 0
18 :3 0 28 :3 0
9b :2 0 596 a10
a14 5d :2 0 21
:2 0 59c a16 a18
:3 0 18 :4 0 a1a
a1b 0 a1e ca
:3 0 59f b6e 99
:3 0 ad :3 0 a1f
a20 0 18 :3 0
1a :3 0 5a1 a21
a24 ae :2 0 21
:2 0 5a6 a26 a28
:3 0 99 :3 0 cb
:3 0 cc :3 0 99
:3 0 cd :3 0 ce
:3 0 ea :3 0 d0
:3 0 18 :3 0 d1
:3 0 a5 :3 0 e
:3 0 cc :3 0 d2
:3 0 84 :3 0 7
:4 0 eb 1 :8 0
a40 c :3 0 7b
:3 0 a3b a3c 0
7c :3 0 a3d a3e
0 a40 5a9 a8a
7d :3 0 c :3 0
7b :3 0 a43 a44
0 7c :3 0 a45
a46 0 a80 44
:3 0 45 :3 0 a48
a49 0 44 :3 0
57 :3 0 a4b a4c
0 7e :2 0 2
:4 0 ec :2 0 59
:2 0 2f :2 0 5ac
a51 a53 :3 0 5af
a4d a55 a4a a57
a56 :2 0 47 :3 0
5a :3 0 a59 a5a
0 49 :4 0 ed
:4 0 4c :2 0 4d
:3 0 5b3 a5e a60
:3 0 4c :2 0 81
:4 0 5b6 a62 a64
:3 0 4c :2 0 82
:4 0 5b9 a66 a68
:3 0 4c :2 0 7c
:3 0 5bc a6a a6c
:3 0 4c :2 0 83
:4 0 5bf a6e a70
:3 0 4c :2 0 84
:3 0 85 :3 0 2f
:2 0 86 :2 0 5c2
a73 a77 5c6 a72
a79 :3 0 5c9 a5b
a7b :2 0 a7d 5cc
a7e a58 a7d 0
a7f 5ce 0 a80
5d0 a83 :3 0 a83
0 a83 a82 a80
a81 :6 0 a85 10
:3 0 5d3 a87 5d5
a86 a85 :2 0 a88
5d7 :2 0 a8a 0
a8a a89 a40 a88
:6 0 af5 1 :3 0
c :3 0 7b :3 0
a8c a8d 0 c
:3 0 5d :2 0 87
:3 0 a8f a91 0
5db a90 a93 :3 0
a94 :2 0 99 :3 0
cb :3 0 d2 :3 0
84 :3 0 7 :3 0
99 :3 0 cd :3 0
18 :3 0 d6 :4 0
ee 1 :8 0 aa5
c :3 0 7b :3 0
aa0 aa1 0 7c
:3 0 aa2 aa3 0
aa5 5de aef 7d
:3 0 c :3 0 7b
:3 0 aa8 aa9 0
7c :3 0 aaa aab
0 ae5 44 :3 0
45 :3 0 aad aae
0 44 :3 0 57
:3 0 ab0 ab1 0
7e :2 0 2 :4 0
ef :2 0 59 :2 0
2f :2 0 5e1 ab6
ab8 :3 0 5e4 ab2
aba aaf abc abb
:2 0 47 :3 0 5a
:3 0 abe abf 0
49 :4 0 f0 :4 0
4c :2 0 4d :3 0
5e8 ac3 ac5 :3 0
4c :2 0 81 :4 0
5eb ac7 ac9 :3 0
4c :2 0 82 :4 0
5ee acb acd :3 0
4c :2 0 7c :3 0
5f1 acf ad1 :3 0
4c :2 0 83 :4 0
5f4 ad3 ad5 :3 0
4c :2 0 84 :3 0
85 :3 0 2f :2 0
86 :2 0 5f7 ad8
adc 5fb ad7 ade
:3 0 5fe ac0 ae0
:2 0 ae2 601 ae3
abd ae2 0 ae4
603 0 ae5 605
ae8 :3 0 ae8 0
ae8 ae7 ae5 ae6
:6 0 aea 12 :3 0
608 aec 60a aeb
aea :2 0 aed 60c
:2 0 aef 0 aef
aee aa5 aed :6 0
af1 1 :3 0 60e
af2 a95 af1 0
af3 610 0 af5
ca :3 0 612 af6
a29 af5 0 b6f
99 :3 0 9a :3 0
af7 af8 0 18
:3 0 27 :3 0 9b
:2 0 615 af9 afd
5d :2 0 21 :2 0
61b aff b01 :3 0
44 :3 0 45 :3 0
b03 b04 0 44
:3 0 57 :3 0 b06
b07 0 f :2 0
2 :4 0 f1 :2 0
59 :2 0 2f :2 0
61e b0c b0e :3 0
621 b08 b10 b05
b12 b11 :2 0 47
:3 0 5a :3 0 b14
b15 0 49 :4 0
f2 :4 0 4c :2 0
4d :3 0 625 b19
b1b :3 0 4c :2 0
81 :4 0 628 b1d
b1f :3 0 4c :2 0
8a :4 0 62b b21
b23 :3 0 4c :2 0
51 :3 0 55 :3 0
21 :2 0 62e b27
b29 54 :4 0 630
b26 b2c 633 b25
b2e :3 0 4c :2 0
8c :4 0 636 b30
b32 :3 0 4c :2 0
4f :4 0 639 b34
b36 :3 0 4c :2 0
3 :3 0 63c b38
b3a :3 0 4c :2 0
4f :4 0 63f b3c
b3e :3 0 642 b16
b40 :2 0 b42 645
b43 b13 b42 0
b44 647 0 b6c
44 :3 0 45 :3 0
b45 b46 0 44
:3 0 57 :3 0 b48
b49 0 2f :2 0
2 :4 0 f3 :2 0
59 :2 0 2f :2 0
649 b4e b50 :3 0
64c b4a b52 b47
b54 b53 :2 0 47
:3 0 5a :3 0 b56
b57 0 49 :4 0
f4 :4 0 4c :2 0
4d :3 0 650 b5b
b5d :3 0 653 b58
b5f :2 0 b61 656
b62 b55 b61 0
b63 658 0 b6c
8f :3 0 90 :3 0
b64 b65 0 21
:2 0 3 :3 0 91
:3 0 65a b66 b6a
:2 0 b6c 65e b6d
b02 b6c 0 b6f
a19 a1e 0 b6f
662 0 b70 666
b75 18 :4 0 b71
b72 0 b74 66a
b76 8f4 b70 0
b77 0 b74 0
b77 66c 0 f67
15 :3 0 a :3 0
b78 b79 0 f67
3c :3 0 21 :2 0
b7b b7c 0 f67
51 :3 0 39 :3 0
21 :2 0 66f b7e
b81 5e :3 0 ae
:2 0 5f :3 0 b83
b85 0 674 b84
b87 :3 0 78 :3 0
66 :3 0 17 :3 0
68 :3 0 18 :3 0
b3 :3 0 79 :3 0
3 :4 0 f5 1
:8 0 ba7 b5 :4 0
b92 :3 0 91 :3 0
5d :2 0 679 b95
b96 :3 0 c :3 0
7b :3 0 b98 b99
0 21 :2 0 b9a
b9b 0 b9d 67c
ba4 c :3 0 7b
:3 0 b9e b9f 0
b6 :2 0 ba0 ba1
0 ba3 67e ba5
b97 b9d 0 ba6
0 ba3 0 ba6
680 0 ba7 683
bf1 7d :3 0 c
:3 0 7b :3 0 baa
bab 0 7c :3 0
bac bad 0 be7
44 :3 0 45 :3 0
baf bb0 0 44
:3 0 57 :3 0 bb2
bb3 0 7e :2 0
2 :4 0 f6 :2 0
59 :2 0 2f :2 0
686 bb8 bba :3 0
689 bb4 bbc bb1
bbe bbd :2 0 47
:3 0 5a :3 0 bc0
bc1 0 49 :4 0
f7 :4 0 4c :2 0
4d :3 0 68d bc5
bc7 :3 0 4c :2 0
81 :4 0 690 bc9
bcb :3 0 4c :2 0
82 :4 0 693 bcd
bcf :3 0 4c :2 0
7c :3 0 696 bd1
bd3 :3 0 4c :2 0
83 :4 0 699 bd5
bd7 :3 0 4c :2 0
84 :3 0 85 :3 0
2f :2 0 86 :2 0
69c bda bde 6a0
bd9 be0 :3 0 6a3
bc2 be2 :2 0 be4
6a6 be5 bbf be4
0 be6 6a8 0
be7 6aa bea :3 0
bea 0 bea be9
be7 be8 :6 0 bec
14 :3 0 6ad bee
6af bed bec :2 0
bef 6b1 :2 0 bf1
0 bf1 bf0 ba7
bef :6 0 bf3 1
:3 0 6b3 f64 11
:3 0 98 :2 0 6b5
bf5 bf6 :3 0 bf7
:2 0 7 :3 0 98
:2 0 6b7 bfa bfb
:3 0 bfc :2 0 f8
:3 0 3c :3 0 d6
:3 0 cc :3 0 f9
:3 0 60 :3 0 e
:3 0 79 :3 0 11
:3 0 79 :3 0 12
:3 0 cc :3 0 d2
:3 0 84 :3 0 7
:4 0 fa 1 :8 0
c13 c :3 0 7b
:3 0 c0e c0f 0
7c :3 0 c10 c11
0 c13 6b9 c5d
7d :3 0 c :3 0
7b :3 0 c16 c17
0 7c :3 0 c18
c19 0 c53 44
:3 0 45 :3 0 c1b
c1c 0 44 :3 0
57 :3 0 c1e c1f
0 7e :2 0 2
:4 0 fb :2 0 59
:2 0 2f :2 0 6bc
c24 c26 :3 0 6bf
c20 c28 c1d c2a
c29 :2 0 47 :3 0
5a :3 0 c2c c2d
0 49 :4 0 fc
:4 0 4c :2 0 4d
:3 0 6c3 c31 c33
:3 0 4c :2 0 81
:4 0 6c6 c35 c37
:3 0 4c :2 0 82
:4 0 6c9 c39 c3b
:3 0 4c :2 0 7c
:3 0 6cc c3d c3f
:3 0 4c :2 0 83
:4 0 6cf c41 c43
:3 0 4c :2 0 84
:3 0 85 :3 0 2f
:2 0 86 :2 0 6d2
c46 c4a 6d6 c45
c4c :3 0 6d9 c2e
c4e :2 0 c50 6dc
c51 c2b c50 0
c52 6de 0 c53
6e0 c56 :3 0 c56
0 c56 c55 c53
c54 :6 0 c58 16
:3 0 6e3 c5a 6e5
c59 c58 :2 0 c5b
6e7 :2 0 c5d 0
c5d c5c c13 c5b
:6 0 cd9 1 :3 0
51 :3 0 3c :3 0
21 :2 0 6e9 c5f
c62 5d :2 0 21
:2 0 6ee c64 c66
:3 0 44 :3 0 45
:3 0 c68 c69 0
44 :3 0 57 :3 0
c6b c6c 0 f
:2 0 2 :4 0 fd
:2 0 59 :2 0 2f
:2 0 6f1 c71 c73
:3 0 6f4 c6d c75
c6a c77 c76 :2 0
47 :3 0 5a :3 0
c79 c7a 0 49
:4 0 fe :4 0 4c
:2 0 4d :3 0 6f8
c7e c80 :3 0 4c
:2 0 81 :4 0 6fb
c82 c84 :3 0 4c
:2 0 8a :4 0 6fe
c86 c88 :3 0 4c
:2 0 51 :3 0 55
:3 0 5e :3 0 ff
:3 0 c8d c8e 0
701 c8c c90 54
:4 0 703 c8b c93
706 c8a c95 :3 0
4c :2 0 8c :4 0
709 c97 c99 :3 0
4c :2 0 4f :4 0
70c c9b c9d :3 0
4c :2 0 12 :3 0
70f c9f ca1 :3 0
4c :2 0 4f :4 0
712 ca3 ca5 :3 0
715 c7b ca7 :2 0
ca9 718 caa c78
ca9 0 cab 71a
0 cd5 44 :3 0
45 :3 0 cac cad
0 44 :3 0 57
:3 0 caf cb0 0
2f :2 0 2 :4 0
100 :2 0 59 :2 0
2f :2 0 71c cb5
cb7 :3 0 71f cb1
cb9 cae cbb cba
:2 0 47 :3 0 5a
:3 0 cbd cbe 0
49 :4 0 101 :4 0
4c :2 0 4d :3 0
723 cc2 cc4 :3 0
726 cbf cc6 :2 0
cc8 729 cc9 cbc
cc8 0 cca 72b
0 cd5 8f :3 0
90 :3 0 ccb ccc
0 5e :3 0 ff
:3 0 cce ccf 0
12 :3 0 91 :3 0
72d ccd cd3 :2 0
cd5 731 cd6 c67
cd5 0 cd7 735
0 cd9 ca :3 0
737 f06 5 :3 0
98 :2 0 73a cdb
cdc :3 0 cdd :2 0
f8 :3 0 3c :3 0
d6 :3 0 cc :3 0
f9 :3 0 60 :3 0
e :3 0 79 :3 0
11 :3 0 79 :3 0
12 :3 0 cc :3 0
d2 :3 0 84 :3 0
5 :4 0 102 1
:8 0 cf4 c :3 0
7b :3 0 cef cf0
0 7c :3 0 cf1
cf2 0 cf4 73c
d3e 7d :3 0 c
:3 0 7b :3 0 cf7
cf8 0 7c :3 0
cf9 cfa 0 d34
44 :3 0 45 :3 0
cfc cfd 0 44
:3 0 57 :3 0 cff
d00 0 7e :2 0
2 :4 0 103 :2 0
59 :2 0 2f :2 0
73f d05 d07 :3 0
742 d01 d09 cfe
d0b d0a :2 0 47
:3 0 5a :3 0 d0d
d0e 0 49 :4 0
104 :4 0 4c :2 0
4d :3 0 746 d12
d14 :3 0 4c :2 0
81 :4 0 749 d16
d18 :3 0 4c :2 0
82 :4 0 74c d1a
d1c :3 0 4c :2 0
7c :3 0 74f d1e
d20 :3 0 4c :2 0
83 :4 0 752 d22
d24 :3 0 4c :2 0
84 :3 0 85 :3 0
2f :2 0 86 :2 0
755 d27 d2b 759
d26 d2d :3 0 75c
d0f d2f :2 0 d31
75f d32 d0c d31
0 d33 761 0
d34 763 d37 :3 0
d37 0 d37 d36
d34 d35 :6 0 d39
18 :3 0 766 d3b
768 d3a d39 :2 0
d3c 76a :2 0 d3e
0 d3e d3d cf4
d3c :6 0 e96 1
:3 0 51 :3 0 3c
:3 0 21 :2 0 76c
d40 d43 5d :2 0
21 :2 0 771 d45
d47 :3 0 44 :3 0
45 :3 0 d49 d4a
0 44 :3 0 57
:3 0 d4c d4d 0
f :2 0 2 :4 0
105 :2 0 59 :2 0
2f :2 0 774 d52
d54 :3 0 777 d4e
d56 d4b d58 d57
:2 0 47 :3 0 5a
:3 0 d5a d5b 0
49 :4 0 106 :4 0
4c :2 0 4d :3 0
77b d5f d61 :3 0
4c :2 0 81 :4 0
77e d63 d65 :3 0
4c :2 0 8a :4 0
781 d67 d69 :3 0
4c :2 0 51 :3 0
55 :3 0 5e :3 0
ff :3 0 d6e d6f
0 784 d6d d71
54 :4 0 786 d6c
d74 789 d6b d76
:3 0 4c :2 0 8c
:4 0 78c d78 d7a
:3 0 4c :2 0 4f
:4 0 78f d7c d7e
:3 0 4c :2 0 12
:3 0 792 d80 d82
:3 0 4c :2 0 4f
:4 0 795 d84 d86
:3 0 798 d5c d88
:2 0 d8a 79b d8b
d59 d8a 0 d8c
79d 0 db6 44
:3 0 45 :3 0 d8d
d8e 0 44 :3 0
57 :3 0 d90 d91
0 2f :2 0 2
:4 0 107 :2 0 59
:2 0 2f :2 0 79f
d96 d98 :3 0 7a2
d92 d9a d8f d9c
d9b :2 0 47 :3 0
5a :3 0 d9e d9f
0 49 :4 0 108
:4 0 4c :2 0 4d
:3 0 7a6 da3 da5
:3 0 7a9 da0 da7
:2 0 da9 7ac daa
d9d da9 0 dab
7ae 0 db6 8f
:3 0 90 :3 0 dac
dad 0 5e :3 0
ff :3 0 daf db0
0 12 :3 0 91
:3 0 7b0 dae db4
:2 0 db6 7b4 e93
109 :3 0 10a :3 0
33 :3 0 f9 :3 0
60 :3 0 e :3 0
10b :3 0 11 :3 0
cc :3 0 d2 :3 0
84 :3 0 5 :4 0
10c 1 :8 0 dc9
c :3 0 7b :3 0
dc4 dc5 0 7c
:3 0 dc6 dc7 0
dc9 7b8 e13 7d
:3 0 c :3 0 7b
:3 0 dcc dcd 0
7c :3 0 dce dcf
0 e09 44 :3 0
45 :3 0 dd1 dd2
0 44 :3 0 57
:3 0 dd4 dd5 0
7e :2 0 2 :4 0
10d :2 0 59 :2 0
2f :2 0 7bb dda
ddc :3 0 7be dd6
dde dd3 de0 ddf
:2 0 47 :3 0 5a
:3 0 de2 de3 0
49 :4 0 10e :4 0
4c :2 0 4d :3 0
7c2 de7 de9 :3 0
4c :2 0 81 :4 0
7c5 deb ded :3 0
4c :2 0 82 :4 0
7c8 def df1 :3 0
4c :2 0 7c :3 0
7cb df3 df5 :3 0
4c :2 0 83 :4 0
7ce df7 df9 :3 0
4c :2 0 84 :3 0
85 :3 0 2f :2 0
86 :2 0 7d1 dfc
e00 7d5 dfb e02
:3 0 7d8 de4 e04
:2 0 e06 7db e07
de1 e06 0 e08
7dd 0 e09 7df
e0c :3 0 e0c 0
e0c e0b e09 e0a
:6 0 e0e 1a :3 0
7e2 e10 7e4 e0f
e0e :2 0 e11 7e6
:2 0 e13 0 e13
e12 dc9 e11 :6 0
e92 1 :3 0 51
:3 0 33 :3 0 21
:2 0 7e8 e15 e18
51 :3 0 9c :2 0
32 :3 0 21 :2 0
7eb e1a e1e 7f0
e1b e20 :3 0 44
:3 0 45 :3 0 e22
e23 0 44 :3 0
57 :3 0 e25 e26
0 f :2 0 2
:4 0 10f :2 0 59
:2 0 2f :2 0 7f3
e2b e2d :3 0 7f6
e27 e2f e24 e31
e30 :2 0 47 :3 0
5a :3 0 e33 e34
0 49 :4 0 110
:4 0 4c :2 0 4d
:3 0 7fa e38 e3a
:3 0 4c :2 0 81
:4 0 7fd e3c e3e
:3 0 4c :2 0 8a
:4 0 800 e40 e42
:3 0 4c :2 0 51
:3 0 55 :3 0 5e
:3 0 ff :3 0 e47
e48 0 803 e46
e4a 54 :4 0 805
e45 e4d 808 e44
e4f :3 0 4c :2 0
8c :4 0 80b e51
e53 :3 0 4c :2 0
4f :4 0 80e e55
e57 :3 0 4c :2 0
12 :3 0 811 e59
e5b :3 0 4c :2 0
4f :4 0 814 e5d
e5f :3 0 817 e35
e61 :2 0 e63 81a
e64 e32 e63 0
e65 81c 0 e8f
44 :3 0 45 :3 0
e66 e67 0 44
:3 0 57 :3 0 e69
e6a 0 2f :2 0
2 :4 0 111 :2 0
59 :2 0 2f :2 0
81e e6f e71 :3 0
821 e6b e73 e68
e75 e74 :2 0 47
:3 0 5a :3 0 e77
e78 0 49 :4 0
112 :4 0 4c :2 0
4d :3 0 825 e7c
e7e :3 0 828 e79
e80 :2 0 e82 82b
e83 e76 e82 0
e84 82d 0 e8f
8f :3 0 90 :3 0
e85 e86 0 5e
:3 0 ff :3 0 e88
e89 0 12 :3 0
91 :3 0 82f e87
e8d :2 0 e8f 833
e90 e21 e8f 0
e91 837 0 e92
839 e94 d48 db6
0 e95 0 e92
0 e95 83c 0
e96 83f e97 cde
e96 0 f08 44
:3 0 45 :3 0 e98
e99 0 44 :3 0
57 :3 0 e9b e9c
0 f :2 0 2
:4 0 113 :2 0 59
:2 0 2f :2 0 842
ea1 ea3 :3 0 845
e9d ea5 e9a ea7
ea6 :2 0 47 :3 0
5a :3 0 ea9 eaa
0 49 :4 0 114
:4 0 4c :2 0 4d
:3 0 849 eae eb0
:3 0 4c :2 0 81
:4 0 84c eb2 eb4
:3 0 4c :2 0 8a
:4 0 84f eb6 eb8
:3 0 4c :2 0 51
:3 0 55 :3 0 5e
:3 0 115 :3 0 ebd
ebe 0 852 ebc
ec0 54 :4 0 854
ebb ec3 857 eba
ec5 :3 0 4c :2 0
8c :4 0 85a ec7
ec9 :3 0 4c :2 0
4f :4 0 85d ecb
ecd :3 0 4c :2 0
12 :3 0 860 ecf
ed1 :3 0 4c :2 0
4f :4 0 863 ed3
ed5 :3 0 866 eab
ed7 :2 0 ed9 869
eda ea8 ed9 0
edb 86b 0 f05
44 :3 0 45 :3 0
edc edd 0 44
:3 0 57 :3 0 edf
ee0 0 2f :2 0
2 :4 0 116 :2 0
59 :2 0 2f :2 0
86d ee5 ee7 :3 0
870 ee1 ee9 ede
eeb eea :2 0 47
:3 0 5a :3 0 eed
eee 0 49 :4 0
117 :4 0 4c :2 0
4d :3 0 874 ef2
ef4 :3 0 877 eef
ef6 :2 0 ef8 87a
ef9 eec ef8 0
efa 87c 0 f05
8f :3 0 90 :3 0
efb efc 0 5e
:3 0 115 :3 0 efe
eff 0 12 :3 0
91 :3 0 87e efd
f03 :2 0 f05 882
f07 bfd cd9 0
f08 0 f05 0
f08 886 0 f09
88a f0a bf8 f09
0 f0b 88c 0
f63 38 :3 0 118
:2 0 f0c f0d 0
f63 12 :3 0 3
:3 0 f0f f10 0
f63 17 :3 0 b2
:2 0 88e f13 f14
:3 0 f15 :2 0 29
:3 0 98 :2 0 890
f18 f19 :3 0 f1a
:2 0 f1b :2 0 f16
f1d f1c :2 0 17
:3 0 19 :3 0 f1f
f20 0 f22 892
f23 f1e f22 0
f24 894 0 f63
3d :3 0 119 :3 0
e :3 0 10 :3 0
12 :3 0 11 :3 0
17 :3 0 18 :3 0
29 :3 0 2e :3 0
36 :3 0 3a :3 0
34 :3 0 32 :3 0
37 :3 0 3b :3 0
38 :3 0 27 :3 0
28 :3 0 23 :3 0
26 :3 0 30 :3 0
31 :3 0 15 :3 0
21 :2 0 896 f26
f3e f25 f3f 0
f63 3c :3 0 118
:2 0 f41 f42 0
f63 3d :3 0 11a
:3 0 e :3 0 12
:3 0 3c :3 0 21
:2 0 21 :2 0 8ae
f45 f4b f44 f4c
0 f63 11 :3 0
98 :2 0 8b4 f4f
f50 :3 0 f51 :2 0
3c :3 0 11b :2 0
f53 f54 0 f60
3d :3 0 11a :3 0
e :3 0 11 :3 0
3c :3 0 21 :2 0
21 :2 0 8b6 f57
f5d f56 f5e 0
f60 8bc f61 f52
f60 0 f62 8bf
0 f63 8c1 f65
b88 bf3 0 f66
0 f63 0 f66
8ca 0 f67 8cd
f68 664 f67 0
f69 8d5 0 f6a
8d7 f6c 4de 549
0 f6d 0 f6a
0 f6d 8db 0
1013 99 :3 0 ad
:3 0 f6e f6f 0
14 :3 0 15 :3 0
8de f70 f73 5d
:2 0 21 :2 0 8e3
f75 f77 :3 0 f78
:2 0 51 :3 0 39
:3 0 21 :2 0 8e6
f7a f7d 5e :3 0
ae :2 0 5f :3 0
f7f f81 0 8eb
f80 f83 :3 0 f84
:2 0 f79 f86 f85
:2 0 3f :3 0 af
:4 0 f88 f89 0
fbc 3e :3 0 118
:2 0 f8b f8c 0
fbc 42 :3 0 c
:3 0 7b :3 0 f8f
f90 0 f8e f91
0 fbc 40 :3 0
b0 :3 0 3f :3 0
12 :3 0 15 :3 0
3e :3 0 21 :2 0
8ee f94 f9a f93
f9b 0 fbc c
:3 0 7b :3 0 f9d
f9e 0 42 :3 0
f9f fa0 0 fbc
3f :3 0 b1 :4 0
fa2 fa3 0 fbc
3e :3 0 118 :2 0
fa5 fa6 0 fbc
42 :3 0 c :3 0
7b :3 0 fa9 faa
0 fa8 fab 0
fbc 40 :3 0 b0
:3 0 3f :3 0 12
:3 0 15 :3 0 3e
:3 0 21 :2 0 8f4
fae fb4 fad fb5
0 fbc c :3 0
7b :3 0 fb7 fb8
0 42 :3 0 fb9
fba 0 fbc 8fa
fbd f87 fbc 0
fbe 905 0 1013
3d :3 0 11c :3 0
e :3 0 907 fc0
fc2 fbf fc3 0
1013 44 :3 0 45
:3 0 fc5 fc6 0
44 :3 0 57 :3 0
fc8 fc9 0 11d
:2 0 2 :4 0 11e
:2 0 59 :2 0 2f
:2 0 909 fce fd0
:3 0 90c fca fd2
fc7 fd4 fd3 :2 0
47 :3 0 5a :3 0
fd6 fd7 0 49
:4 0 11f :4 0 4c
:2 0 4d :3 0 910
fdb fdd :3 0 4c
:2 0 81 :4 0 913
fdf fe1 :3 0 4c
:2 0 8a :4 0 916
fe3 fe5 :3 0 4c
:2 0 51 :3 0 55
:3 0 c :3 0 7b
:3 0 fea feb 0
919 fe9 fed 54
:4 0 91b fe8 ff0
91e fe7 ff2 :3 0
4c :2 0 8c :4 0
921 ff4 ff6 :3 0
4c :2 0 4f :4 0
924 ff8 ffa :3 0
4c :2 0 3 :3 0
927 ffc ffe :3 0
4c :2 0 4f :4 0
92a 1000 1002 :3 0
92d fd8 1004 :2 0
1006 930 1007 fd5
1006 0 1008 932
0 1013 8f :3 0
120 :3 0 1009 100a
0 c :3 0 7b
:3 0 100c 100d 0
3 :3 0 91 :3 0
934 100b 1011 :2 0
1013 938 10b4 c
:3 0 121 :2 0 4
1014 1015 0 44
:3 0 45 :3 0 1017
1018 0 44 :3 0
57 :3 0 101a 101b
0 7e :2 0 2
:4 0 122 :2 0 59
:2 0 2f :2 0 951
1020 1022 :3 0 954
101c 1024 1019 1026
1025 :2 0 47 :3 0
5a :3 0 1028 1029
0 49 :4 0 123
:4 0 4c :2 0 4d
:3 0 958 102d 102f
:3 0 95b 102a 1031
:2 0 104a 47 :3 0
5a :3 0 1033 1034
0 49 :4 0 124
:4 0 4c :2 0 c
:3 0 a6 :3 0 1039
103a 0 95e 1038
103c :3 0 4c :2 0
8c :4 0 961 103e
1040 :3 0 4c :2 0
c :3 0 125 :3 0
1043 1044 0 964
1042 1046 :3 0 967
1035 1048 :2 0 104a
96a 104b 1027 104a
0 104c 96d 0
105c 126 :3 0 43
:3 0 c :3 0 a6
:3 0 127 :3 0 c
:3 0 125 :3 0 3
:3 0 d6 :4 0 128
1 :a 0 1058 :2 0
105c 104e 1056 :2 0
b :3 0 43 :3 0
105a :2 0 105c 96f
105e 973 105d 105c
:2 0 10b2 7d :3 0
c :3 0 7b :3 0
1061 1062 0 7c
:3 0 1063 1064 0
10aa 44 :3 0 45
:3 0 1066 1067 0
44 :3 0 57 :3 0
1069 106a 0 7e
:2 0 2 :4 0 129
:2 0 59 :2 0 2f
:2 0 975 106f 1071
:3 0 978 106b 1073
1068 1075 1074 :2 0
47 :3 0 5a :3 0
1077 1078 0 49
:4 0 12a :4 0 4c
:2 0 4d :3 0 97c
107c 107e :3 0 97f
1079 1080 :2 0 109a
47 :3 0 5a :3 0
1082 1083 0 49
:4 0 82 :4 0 4c
:2 0 7c :3 0 982
1087 1089 :3 0 4c
:2 0 83 :4 0 985
108b 108d :3 0 4c
:2 0 84 :3 0 85
:3 0 2f :2 0 86
:2 0 988 1090 1094
98c 108f 1096 :3 0
98f 1084 1098 :2 0
109a 992 109b 1076
109a 0 109c 995
0 10aa 126 :3 0
43 :3 0 127 :3 0
c :3 0 125 :3 0
3 :3 0 d6 :4 0
12b 1 :a 0 10a6
:2 0 10aa 109e 10a4
:2 0 b :3 0 43
:3 0 10a8 :2 0 10aa
997 10ad :3 0 10ad
0 10ad 10ac 10aa
10ab :6 0 10af 1
:3 0 99c 10b1 99e
10b0 10af :2 0 10b2
9a0 :2 0 10b4 9a3
10b4 10b3 1013 10b2
:6 0 10b5 :2 0 2
1c 10b4 10b8 :3 0
10b7 10b5 10b9 :8 0

9d2
4
:3 0 1 3 1
7 1 b 1
f 1 13 5
6 a e 12
16 1 20 1
1e 1 27 1
25 1 2e 1
2c 1 35 1
33 1 3c 1
3a 1 43 1
41 1 4a 1
48 1 51 1
4f 1 56 1
5b 1 60 1
65 1 6a 1
6f 1 74 1
7b 1 79 1
80 1 86 1
8c 1 92 1
98 1 9d 1
a2 1 a7 1
ac 1 b1 1
b8 1 b6 1
bd 1 c3 1
c9 1 cf 1
d5 1 db 1
e1 1 e7 1
ed 1 f3 1
f9 1 ff 1
105 1 10b 1
111 1 119 1
117 1 11e 1
123 1 129 1
136 1 142 2
145 147 2 14a
14c 2 14e 150
2 152 154 2
156 158 2 15e
160 2 162 164
2 166 167 2
169 16a 2 15a
16c 2 16e 170
2 176 178 2
17a 17c 2 17e
17f 2 181 182
2 172 184 2
186 188 1 18e
2 190 191 2
18a 193 2 195
197 2 199 19b
2 19d 19f 2
1a1 1a3 2 1a5
1a7 4 13e 144
149 1a9 1 1ab
1 1ad 2 1b7
1b9 3 1b5 1b6
1bb 2 1c4 1c6
2 1c3 1c8 1
1ca 1 1cc 2
1e4 1e5 1 1e9
2 1e7 1e9 1
1f1 1 1f3 2
22c 231 2 242
244 3 240 241
246 2 24f 251
2 253 255 2
257 259 2 25b
25d 2 25f 261
3 266 267 268
2 263 26a 2
24e 26c 1 26e
1 270 2 239
271 1 275 1
234 1 279 1
284 2 280 284
2 290 292 3
28e 28f 294 2
29d 29f 2 2a1
2a3 2 2a5 2a7
1 2af 2 2b1
2b2 2 2a9 2b4
2 2b6 2b8 2
2ba 2bc 2 2be
2c0 2 2c2 2c4
2 29c 2c6 1
2c8 1 2ca 2
2d4 2d6 3 2d2
2d3 2d8 2 2e1
2e3 2 2e0 2e5
1 2e7 1 2e9
3 2f0 2f1 2f2
3 2cb 2ea 2f4
1 2f6 2 2f9
2fa 1 2fe 2
2fc 2fe 2 309
30b 3 307 308
30d 2 316 318
2 31a 31c 2
31e 320 1 328
2 32a 32b 2
322 32d 2 32f
331 2 333 335
2 337 339 2
33b 33d 2 315
33f 1 341 1
343 2 34d 34f
3 34b 34c 351
2 35a 35c 2
359 35e 1 360
1 362 3 369
36a 36b 3 344
363 36d 1 36f
1 371 1 377
3 382 383 384
1 388 2 386
388 2 393 395
3 391 392 397
2 3a0 3a2 2
3a4 3a6 2 3a8
3aa 1 3b2 2
3b4 3b5 2 3ac
3b7 2 3b9 3bb
2 3bd 3bf 2
3c1 3c3 2 3c5
3c7 2 39f 3c9
1 3cb 1 3cd
2 3d7 3d9 3
3d5 3d6 3db 2
3e4 3e6 2 3e3
3e8 1 3ea 1
3ec 3 3f3 3f4
3f5 3 3ce 3ed
3f7 1 3f9 1
3fa 1 3fc 2
410 415 2 426
428 3 424 425
42a 2 433 435
2 437 439 2
43b 43d 2 43f
441 2 443 445
3 44a 44b 44c
2 447 44e 2
432 450 1 452
1 454 2 41d
455 1 459 1
418 1 45d 2
468 469 1 46d
2 46b 46d 2
472 473 1 479
2 475 479 5
48c 48d 48e 48f
490 5 4a6 4a7
4a8 4a9 4aa a
481 484 489 493
498 49b 49e 4a3
4ad 4b2 1 4b4
1 4b6 3 4bf
4c0 4c1 1 4c5
2 4c3 4c5 1
4cd 1 4cf 1
4d1 1 4d7 1
4ea 2 4e9 4ea
1 4f2 1 4f8
2 4fa 4fb 2
4e7 4fc 2 50d
50f 3 50b 50c
511 2 51a 51c
2 51e 520 2
522 524 2 526
528 2 52a 52c
3 531 532 533
2 52e 535 2
519 537 1 539
1 53b 2 504
53c 1 540 1
4ff 1 544 1
547 1 54a 1
54f 1 55f 2
55e 55f 1 567
1 56d 2 56f
570 2 55c 571
2 582 584 3
580 581 586 2
58f 591 2 593
595 2 597 599
2 59b 59d 2
59f 5a1 3 5a6
5a7 5a8 2 5a3
5aa 2 58e 5ac
1 5ae 1 5b0
2 579 5b1 1
5b5 1 574 1
5b9 3 5c1 5c2
5c3 1 5c7 2
5c5 5c7 1 5cc
1 5ce 2 5bc
5cf 1 5d1 1
5d3 1 5d8 1
5e8 2 5e7 5e8
1 5f0 1 5f6
2 5f8 5f9 2
5e5 5fa 2 60b
60d 3 609 60a
60f 2 618 61a
2 61c 61e 2
620 622 2 624
626 2 628 62a
3 62f 630 631
2 62c 633 2
617 635 1 637
1 639 2 602
63a 1 63e 1
5fd 1 642 3
64a 64b 64c 1
650 2 64e 650
1 655 1 657
2 645 658 1
65a 2 65d 65e
1 662 2 660
662 1 665 3
66e 66f 670 1
674 2 672 674
1 67c 1 67e
1 680 1 686
2 691 692 1
696 2 694 696
2 6a4 6a6 3
6a2 6a3 6a8 2
6b1 6b3 2 6b5
6b7 2 6b9 6bb
1 6c3 2 6c5
6c6 2 6bd 6c8
2 6ca 6cc 2
6ce 6d0 2 6d2
6d4 2 6d6 6d8
2 6b0 6da 1
6dc 1 6de 2
6e8 6ea 3 6e6
6e7 6ec 2 6f5
6f7 2 6f4 6f9
1 6fb 1 6fd
3 704 705 706
3 6df 6fe 708
1 70a 1 70c
1 711 2 71e
720 3 71c 71d
722 2 72b 72d
2 72f 731 2
733 735 1 73d
2 73f 740 2
737 742 2 744
746 2 748 74a
2 74c 74e 2
750 752 2 72a
754 1 756 1
758 2 762 764
3 760 761 766
2 76f 771 2
76e 773 1 775
1 777 3 77e
77f 780 3 759
778 782 1 784
3 78c 78d 78e
1 792 2 790
792 1 797 3
79d 79e 79f 1
7a3 2 7a1 7a3
2 7b6 7bb 2
7cc 7ce 3 7ca
7cb 7d0 2 7d9
7db 2 7dd 7df
2 7e1 7e3 2
7e5 7e7 2 7e9
7eb 3 7f0 7f1
7f2 2 7ed 7f4
2 7d8 7f6 1
7f8 1 7fa 2
7c3 7fb 1 7ff
1 7be 1 803
1 80e 2 80a
80e 2 81b 820
2 831 833 3
82f 830 835 2
83e 840 2 842
844 2 846 848
2 84a 84c 2
84e 850 3 855
856 857 2 852
859 2 83d 85b
1 85d 1 85f
2 828 860 1
864 1 823 1
868 1 86b 1
86e 2 806 86f
1 873 2 880
882 3 87e 87f
884 2 88d 88f
2 891 893 2
895 897 1 89d
2 89f 8a0 2
899 8a2 2 8a4
8a6 2 8a8 8aa
2 8ac 8ae 2
8b0 8b2 2 88c
8b4 1 8b6 1
8b8 2 8c2 8c4
3 8c0 8c1 8c6
2 8cf 8d1 2
8ce 8d3 1 8d5
1 8d7 3 8dc
8dd 8de 3 8b9
8d8 8e0 3 8e3
872 8e2 3 785
788 8e4 2 8e8
8eb 2 8ed 8ee
1 8f0 1 8f5
3 8fe 8ff 900
1 904 2 902
904 2 912 914
3 910 911 916
2 91f 921 2
923 925 2 927
929 1 931 2
933 934 2 92b
936 2 938 93a
2 93c 93e 2
940 942 2 944
946 2 91e 948
1 94a 1 94c
2 956 958 3
954 955 95a 2
963 965 2 962
967 1 969 1
96b 3 972 973
974 3 94d 96c
976 1 979 3
982 983 984 1
988 2 986 988
2 996 998 3
994 995 99a 2
9a3 9a5 2 9a7
9a9 2 9ab 9ad
1 9b5 2 9b7
9b8 2 9af 9ba
2 9a2 9bc 1
9be 1 9c0 2
9ca 9cc 3 9c8
9c9 9ce 2 9d7
9d9 2 9d6 9db
1 9dd 1 9df
2 9e6 9e7 3
9c1 9e0 9e9 2
9ec 9eb 1 9ee
3 9f7 9f8 9f9
1 9fd 2 9fb
9fd 1 a05 1
a09 2 a0b a0c
3 a11 a12 a13
1 a17 2 a15
a17 1 a1c 2
a22 a23 1 a27
2 a25 a27 2
a3a a3f 2 a50
a52 3 a4e a4f
a54 2 a5d a5f
2 a61 a63 2
a65 a67 2 a69
a6b 2 a6d a6f
3 a74 a75 a76
2 a71 a78 2
a5c a7a 1 a7c
1 a7e 2 a47
a7f 1 a83 1
a42 1 a87 1
a92 2 a8e a92
2 a9f aa4 2
ab5 ab7 3 ab3
ab4 ab9 2 ac2
ac4 2 ac6 ac8
2 aca acc 2
ace ad0 2 ad2
ad4 3 ad9 ada
adb 2 ad6 add
2 ac1 adf 1
ae1 1 ae3 2
aac ae4 1 ae8
1 aa7 1 aec
1 aef 1 af2
2 a8a af3 3
afa afb afc 1
b00 2 afe b00
2 b0b b0d 3
b09 b0a b0f 2
b18 b1a 2 b1c
b1e 2 b20 b22
1 b28 2 b2a
b2b 2 b24 b2d
2 b2f b31 2
b33 b35 2 b37
b39 2 b3b b3d
2 b17 b3f 1
b41 1 b43 2
b4d b4f 3 b4b
b4c b51 2 b5a
b5c 2 b59 b5e
1 b60 1 b62
3 b67 b68 b69
3 b44 b63 b6b
3 b6e af6 b6d
3 9ed a0d b6f
1 b73 2 b75
b76 2 b7f b80
1 b86 2 b82
b86 1 b94 2
b93 b94 1 b9c
1 ba2 2 ba4
ba5 2 b91 ba6
2 bb7 bb9 3
bb5 bb6 bbb 2
bc4 bc6 2 bc8
bca 2 bcc bce
2 bd0 bd2 2
bd4 bd6 3 bdb
bdc bdd 2 bd8
bdf 2 bc3 be1
1 be3 1 be5
2 bae be6 1
bea 1 ba9 1
bee 1 bf1 1
bf4 1 bf9 2
c0d c12 2 c23
c25 3 c21 c22
c27 2 c30 c32
2 c34 c36 2
c38 c3a 2 c3c
c3e 2 c40 c42
3 c47 c48 c49
2 c44 c4b 2
c2f c4d 1 c4f
1 c51 2 c1a
c52 1 c56 1
c15 1 c5a 2
c60 c61 1 c65
2 c63 c65 2
c70 c72 3 c6e
c6f c74 2 c7d
c7f 2 c81 c83
2 c85 c87 1
c8f 2 c91 c92
2 c89 c94 2
c96 c98 2 c9a
c9c 2 c9e ca0
2 ca2 ca4 2
c7c ca6 1 ca8
1 caa 2 cb4
cb6 3 cb2 cb3
cb8 2 cc1 cc3
2 cc0 cc5 1
cc7 1 cc9 3
cd0 cd1 cd2 3
cab cca cd4 1
cd6 2 c5d cd7
1 cda 2 cee
cf3 2 d04 d06
3 d02 d03 d08
2 d11 d13 2
d15 d17 2 d19
d1b 2 d1d d1f
2 d21 d23 3
d28 d29 d2a 2
d25 d2c 2 d10
d2e 1 d30 1
d32 2 cfb d33
1 d37 1 cf6
1 d3b 2 d41
d42 1 d46 2
d44 d46 2 d51
d53 3 d4f d50
d55 2 d5e d60
2 d62 d64 2
d66 d68 1 d70
2 d72 d73 2
d6a d75 2 d77
d79 2 d7b d7d
2 d7f d81 2
d83 d85 2 d5d
d87 1 d89 1
d8b 2 d95 d97
3 d93 d94 d99
2 da2 da4 2
da1 da6 1 da8
1 daa 3 db1
db2 db3 3 d8c
dab db5 2 dc3
dc8 2 dd9 ddb
3 dd7 dd8 ddd
2 de6 de8 2
dea dec 2 dee
df0 2 df2 df4
2 df6 df8 3
dfd dfe dff 2
dfa e01 2 de5
e03 1 e05 1
e07 2 dd0 e08
1 e0c 1 dcb
1 e10 2 e16
e17 2 e1c e1d
1 e1f 2 e19
e1f 2 e2a e2c
3 e28 e29 e2e
2 e37 e39 2
e3b e3d 2 e3f
e41 1 e49 2
e4b e4c 2 e43
e4e 2 e50 e52
2 e54 e56 2
e58 e5a 2 e5c
e5e 2 e36 e60
1 e62 1 e64
2 e6e e70 3
e6c e6d e72 2
e7b e7d 2 e7a
e7f 1 e81 1
e83 3 e8a e8b
e8c 3 e65 e84
e8e 1 e90 2
e13 e91 2 e93
e94 2 d3e e95
2 ea0 ea2 3
e9e e9f ea4 2
ead eaf 2 eb1
eb3 2 eb5 eb7
1 ebf 2 ec1
ec2 2 eb9 ec4
2 ec6 ec8 2
eca ecc 2 ece
ed0 2 ed2 ed4
2 eac ed6 1
ed8 1 eda 2
ee4 ee6 3 ee2
ee3 ee8 2 ef1
ef3 2 ef0 ef5
1 ef7 1 ef9
3 f00 f01 f02
3 edb efa f04
3 f06 e97 f07
1 f08 1 f0a
1 f12 1 f17
1 f21 1 f23
17 f27 f28 f29
f2a f2b f2c f2d
f2e f2f f30 f31
f32 f33 f34 f35
f36 f37 f38 f39
f3a f3b f3c f3d
5 f46 f47 f48
f49 f4a 1 f4e
5 f58 f59 f5a
f5b f5c 2 f55
f5f 1 f61 8
f0b f0e f11 f24
f40 f43 f4d f62
2 f64 f65 7
67f 70b 8ef b77
b7a b7d f66 1
f68 3 5d2 65b
f69 2 f6b f6c
2 f71 f72 1
f76 2 f74 f76
2 f7b f7c 1
f82 2 f7e f82
5 f95 f96 f97
f98 f99 5 faf
fb0 fb1 fb2 fb3
a f8a f8d f92
f9c fa1 fa4 fa7
fac fb6 fbb 1
fbd 1 fc1 2
fcd fcf 3 fcb
fcc fd1 2 fda
fdc 2 fde fe0
2 fe2 fe4 1
fec 2 fee fef
2 fe6 ff1 2
ff3 ff5 2 ff7
ff9 2 ffb ffd
2 fff 1001 2
fd9 1003 1 1005
1 1007 3 100e
100f 1010 18 1ae
1cd 1d0 1d3 1d6
1d9 1dc 1df 1e2
1f4 27c 2f7 370
3fd 400 460 464
4b5 4d0 f6d fbe
fc4 1008 1012 2
101f 1021 3 101d
101e 1023 2 102c
102e 2 102b 1030
2 1037 103b 2
103d 103f 2 1041
1045 2 1036 1047
2 1032 1049 1
104b 3 104c 1057
105b 1 1016 2
106e 1070 3 106c
106d 1072 2 107b
107d 2 107a 107f
2 1086 1088 2
108a 108c 3 1091
1092 1093 2 108e
1095 2 1085 1097
2 1081 1099 1
109b 4 1065 109c
10a5 10a9 1 10ad
1 1060 2 105e
10b1 2e 23 2a
31 38 3f 46
4d 54 59 5e
63 68 6d 72
77 7e 84 8a
90 96 9b a0
a5 aa af b4
bb c1 c7 cd
d3 d9 df e5
eb f1 f7 fd
103 109 10f 115
11c 121 127 12e

1
4
0 
10b8
0
1
28
1c
34
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 0 0 0 0
0 0 0 0 0 0 0 0

13 1 0
f9 1 0
105 1 0
6f 1 0
3 1 0
80 1 0
5b 1 0
33 1 0
2c 1 0
c9 1 0
111 1 0
92 1 0
f3 1 0
11e 1 0
ac 1 0
10b 1 0
a2 1 0
e1 1 0
60 1 0
98 1 0
56 1 0
117 1 0
bd 1 0
4f 1 0
ed 1 0
d5 1 0
65 1 0
ff 1 0
cf 1 0
3a 1 0
c3 1 0
25 1 0
79 1 0
a7 1 0
9d 1 0
74 1 0
123 1 0
7 1 0
b6 1 0
b1 1 0
86 1 0
41 1 0
1e 1 0
2 0 1
6a 1 0
f 1 0
8c 1 0
db 1 0
48 1 0
e7 1 0
b 1 0
129 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_FORECAST;
ALTER FUNCTION SP_U_WP_FORECAST COMPILE DEBUG;
/*****************************************************************************/
Prompt == FUNCTION SP_U_ASSIGN_DESCR ==
CREATE OR REPLACE FUNCTION SP_U_ASSIGN_DESCR wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
56
2 :e:
1FUNCTION:
1SP_U_ASSIGN_DESCR:
1PRJ_ID:
1VARCHAR2:
1RES_ID001:
1DESCRIPTION001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_ASSIGN_DESCR(:
1':
1, :
1);:
1CHECK_TRACE:
11:
120:
1+:
1FPUT:
1               ENTER:: SP_U_ASSIGN_DESCR(21) :: cplan.sql(20211) :: :
1IS NULL:
132:
125:
1        RETURN_ERROR:: SP_U_ASSIGN_DESCR(26) :: cplan.sql(20216) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
1 ID:: :
128:
1                EXIT:: SP_U_ASSIGN_DESCR(29) :: cplan.sql(20219) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1PROJECT_ASSIGNMENTS:
1DESCRIPTION:
1RESOURCE_ID:
1PROJECT_ID:
1UPDATE PROJECT_ASSIGNMENTS:n      SET DESCRIPTION = description001:n      WHE+
1RE RESOURCE_ID = res_id001:n      AND PROJECT_ID = prj_id:
1FOUND:
1=:
1SC_STATE:
10:
1100:
1OTHERS:
1SQLCODE:
116:
149:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(50) :: cplan.sql(20240) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
14:
155:
1       RETURN_STATUS:: SP_U_ASSIGN_DESCR(56) :: cplan.sql(20246) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
162:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(63) :: cplan.sql(20253) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
174:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(75) :: cplan.sql(20265) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
27a
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c a0 7e b4
2e 5a a0 7e b4 2e 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :7 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
27a
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 9b 83 87 8b 8e 96
82 a2 a6 7f aa ae b2 b5
ba bb 1 bd c2 c6 ca cd
d2 d6 da dd e2 e3 e5 ea
ed f1 f2 f7 fc ff 104 105
10a 10d 111 112 117 11a 11f 120
125 128 12d 12e 133 136 13b 13c
141 144 148 149 14e 151 156 157
15c 15f 164 165 16a 16d 172 173
178 17b 17f 180 185 188 18d 18e
193 196 19b 19c 1a1 1a4 1a9 1aa
1af 1b2 1b6 1b7 1bc 1bf 1c4 1c5
1ca 1cd 1d2 1d3 1d8 1d9 1de 1e0
1e4 1e7 1eb 1ef 1f2 1f6 1fa 1fd
200 205 208 20b 20e 20f 214 215
1 217 21c 220 224 227 22c 231
234 238 239 23e 23f 244 246 24a
24d 251 254 255 25a 25d 261 264
265 26a 1 26d 272 276 27a 27d
281 285 288 28b 290 293 296 299
29a 29f 2a0 1 2a2 2a7 2ab 2af
2b2 2b7 2bc 2bf 2c3 2c4 2c9 2cc
2d1 2d2 2d7 2da 2df 2e0 2e5 2e8
2ec 2f0 2f4 2f8 2fb 2fc 2fe 303
304 306 307 30c 30f 314 315 31a
31d 322 323 328 32b 32f 330 335
338 33d 33e 343 344 349 34b 34f
352 356 35a 35d 361 365 368 36b
370 373 376 379 37a 37f 380 1
382 387 38b 38f 392 397 39c 39f
3a3 3a4 3a9 3aa 3af 3b1 3b5 3b8
3bc 3c0 3c3 3c7 3cb 3ce 3d2 3d6
3d7 3dc 3de 3e2 3e5 3e9 3ed 3f1
3f5 3f9 3fd 401 40d 411 416 41a
41d 41e 423 427 42b 42e 431 435
437 43b 43f 442 445 449 44b 44f
453 456 458 1 45c 460 464 467
46b 46f 473 477 47a 47e 482 485
488 48d 490 493 496 497 49c 49d
1 49f 4a4 4a8 4ac 4af 4b4 4b9
4bc 4c0 4c1 4c6 4c9 4ce 4cf 4d4
4d7 4dc 4dd 4e2 4e5 4e9 4ea 4ef
4f2 4f7 4f8 4fd 500 504 508 50b
50e 50f 511 512 517 518 51d 51f
523 526 528 52c 52e 53a 53c 53e
53f 544 548 54a 556 558 55c 560
563 567 56b 56e 571 576 579 57c
57f 580 585 586 1 588 58d 591
595 598 59d 5a2 5a5 5a9 5aa 5af
5b2 5b7 5b8 5bd 5c0 5c5 5c6 5cb
5ce 5d2 5d6 5da 5de 5e1 5e2 5e4
5e9 5ea 5ec 5ed 5f2 5f5 5fa 5fb
600 603 608 609 60e 611 615 616
61b 61e 623 624 629 62a 62f 631
635 638 63c 640 643 647 64b 64e
652 656 657 65c 65e 662 666 669
66d 671 674 678 67c 67f 682 687
68a 68d 690 691 696 697 1 699
69e 6a2 6a6 6a9 6ae 6b3 6b6 6ba
6bb 6c0 6c1 6c6 6ca 6ce 6d1 6d6
6db 6de 6e2 6e6 6e9 6ea 6ef 6f2
6f7 6f8 6fd 700 704 708 70b 70c
711 712 717 719 71d 720 724 728
72c 730 734 738 73c 740 744 750
755 759 75d 761 765 767 768 76d
1 771 775 779 77c 780 784 788
78c 78f 793 797 79a 79d 7a2 7a5
7a8 7ab 7ac 7b1 7b2 1 7b4 7b9
7bd 7c1 7c4 7c9 7ce 7d1 7d5 7d6
7db 7dc 7e1 7e5 7e9 7ec 7f1 7f6
7f9 7fd 7fe 803 806 80b 80c 811
814 818 81c 81f 822 823 825 826
82b 82c 831 833 837 83a 83e 842
846 84a 84e 852 856 862 867 86b
86f 873 877 879 87d 87f 88b 88d
88f 890 895 899 89b 8a7 8ab 8ad
8ae 8b7 
27a
2
0 1 a 6 d :3 6 10 :3 6
15 :3 6 12 :2 6 1 3 a 13
a :2 1 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 59 5f 62 :2 59
70 8b 8 :2 70 d 10 :2 70 17
1a :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 28 2b :2 70 b e
:2 70 13 16 :2 70 1b 1e :2 70 2d
30 :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 2a 2d :2 70 32 35
:2 70 :2 7 4f :2 4 7 :2 11 23 :2 2d
39 3c 51 53 54 :2 51 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 57
:2 4 :4 8 7 :4 1c 1b :2 7 a :2 14
26 :2 30 3c 40 55 57 58 :2 55
:2 26 :3 a :2 10 15 21 65 68 :2 21
75 78 :2 21 7c 7f :2 21 89 8c
95 9d :2 a6 :2 95 b7 :2 8c :2 21 bf
c2 :2 21 ca cd :2 21 d2 d5 :2 21
dc df :2 21 :2 a 5b :2 7 a :2 14
26 :2 30 3c 3f 54 56 57 :2 54
:2 26 :3 a :2 10 15 21 65 68 :2 21
:2 a 5a :3 7 :2 12 26 :2 2f 3f 47
:2 7 2f :2 4 e b 19 d 1b
b 18 7 e a 16 :3 14 a
:2 13 1f a 1b a :2 13 1f a
:4 7 4 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 58 5a 5b
:2 58 :2 29 :3 d :2 13 18 24 68 6b
:2 24 78 7b :2 24 7f 82 :2 24 8e
91 :2 24 99 9c :2 24 a8 ab b2
bb be :2 ab :2 24 :2 d 5e :2 a :2 7
:4 13 :2 7 4 :3 1 7 :2 11 23 :2 2d
39 3c 51 53 54 :2 51 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e 72 75
:2 1e 79 7c :2 1e 86 89 92 9a
:2 a3 :2 92 ae :2 89 :2 1e b6 b9 :2 1e
c1 c4 :2 1e c9 cc :2 1e d3 d6
:2 1e :2 7 57 :3 4 :2 f 21 :2 2a 34
3c :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 55 57 58 :2 55
:2 26 :3 a :2 10 15 21 65 68 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
5b :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 52 54 55 :2 52
:2 23 :3 7 :2 d 12 1e 62 65 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 58 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
27a
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 a :b c :11 d
e :2 d :2 e :2 d
:2 e :2 d :2 f :2 d
:2 f :2 d :2 f :2 d
:2 f :2 d :2 10 :2 d
:2 10 :2 d :2 10 :2 d
:2 10 :2 d :2 11 :2 d
:2 11 :2 d :2 11 :2 d
:2 11 :2 d :2 11 :4 d
:3 c :11 14 :b 15 :3 14
:c 18 :11 19 :30 1a :3 19
:11 1c :b 1d :3 1c :a 1f
:3 18 24 :2 25 :2 26
:2 27 24 :6 28 :5 29
28 :5 2b 2a :3 28
23 :2 2e :5 30 :11 31
:24 32 :3 31 :2 2f :6 2e
2d :3 b :11 37 :30 38
:3 37 :a 3a b :3 3d
:11 3e :b 3f :17 40 :3 3e
:2 42 :3 43 :3 44 45
43 42 43 :3 46
:3 3d :2 47 :5 49 :11 4a
:b 4b :18 4c :3 4a :2 4e
4f :3 50 51 4f
4e 4f :3 52 :2 48
:6 47 3c :7 1 
8b9
4
:3 0 1 :3 0 2
:a 0 275 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 15 16 0
b 4 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :3 0
a :2 0 4 13
17 0 275 2
18 :2 0 21 22
0 10 9 :3 0
a :2 0 4 1b
1c 0 1d :7 0
20 1e 0 273
0 b :6 0 c
:3 0 d :3 0 c
:3 0 e :3 0 24
25 0 2 :4 0
12 26 28 23
2a 29 :2 0 f
:3 0 10 :3 0 2c
2d 0 11 :4 0
c :3 0 12 :3 0
30 31 0 2
:4 0 14 32 34
13 :4 0 14 :2 0
15 :3 0 16 37
39 :3 0 16 :4 0
14 :2 0 17 :4 0
19 3c 3e :3 0
14 :2 0 3 :3 0
1c 40 42 :3 0
14 :2 0 17 :4 0
1f 44 46 :3 0
14 :2 0 18 :4 0
22 48 4a :3 0
14 :2 0 17 :4 0
25 4c 4e :3 0
14 :2 0 5 :3 0
28 50 52 :3 0
14 :2 0 17 :4 0
2b 54 56 :3 0
14 :2 0 18 :4 0
2e 58 5a :3 0
14 :2 0 17 :4 0
31 5c 5e :3 0
14 :2 0 6 :3 0
34 60 62 :3 0
14 :2 0 17 :4 0
37 64 66 :3 0
14 :2 0 18 :4 0
3a 68 6a :3 0
14 :2 0 17 :4 0
3d 6c 6e :3 0
14 :2 0 7 :3 0
40 70 72 :3 0
14 :2 0 17 :4 0
43 74 76 :3 0
14 :2 0 19 :4 0
46 78 7a :3 0
49 2e 7c :2 0
7e 4e 7f 2b
7e 0 80 50
0 1d3 c :3 0
d :3 0 81 82
0 c :3 0 1a
:3 0 84 85 0
1b :2 0 2 :4 0
1c :2 0 1d :2 0
1b :2 0 52 8a
8c :3 0 55 86
8e 83 90 8f
:2 0 f :3 0 1e
:3 0 92 93 0
11 :4 0 1f :4 0
14 :2 0 15 :3 0
59 97 99 :3 0
5c 94 9b :2 0
9d 5f 9e 91
9d 0 9f 61
0 1d3 3 :3 0
20 :2 0 63 a1
a2 :3 0 a3 :2 0
5 :3 0 20 :2 0
65 a6 a7 :3 0
a8 :2 0 a4 aa
a9 :2 0 c :3 0
d :3 0 ac ad
0 c :3 0 1a
:3 0 af b0 0
21 :2 0 2 :4 0
22 :2 0 1d :2 0
1b :2 0 67 b5
b7 :3 0 6a b1
b9 ae bb ba
:2 0 f :3 0 1e
:3 0 bd be 0
11 :4 0 23 :4 0
14 :2 0 15 :3 0
6e c2 c4 :3 0
14 :2 0 24 :4 0
71 c6 c8 :3 0
14 :2 0 25 :4 0
74 ca cc :3 0
14 :2 0 26 :3 0
27 :3 0 28 :3 0
29 :3 0 d1 d2
0 77 d0 d4
2a :4 0 79 cf
d7 7c ce d9
:3 0 14 :2 0 2b
:4 0 7f db dd
:3 0 14 :2 0 17
:4 0 82 df e1
:3 0 14 :2 0 3
:3 0 85 e3 e5
:3 0 14 :2 0 17
:4 0 88 e7 e9
:3 0 8b bf eb
:2 0 ed 8e ee
bc ed 0 ef
90 0 119 c
:3 0 d :3 0 f0
f1 0 c :3 0
1a :3 0 f3 f4
0 1b :2 0 2
:4 0 2c :2 0 1d
:2 0 1b :2 0 92
f9 fb :3 0 95
f5 fd f2 ff
fe :2 0 f :3 0
1e :3 0 101 102
0 11 :4 0 2d
:4 0 14 :2 0 15
:3 0 99 106 108
:3 0 9c 103 10a
:2 0 10c 9f 10d
100 10c 0 10e
a1 0 119 2e
:3 0 2f :3 0 10f
110 0 28 :3 0
29 :3 0 112 113
0 3 :3 0 30
:3 0 a3 111 117
:2 0 119 a7 11a
ab 119 0 11b
ab 0 1d3 31
:3 0 32 :3 0 6
:3 0 33 :3 0 5
:3 0 34 :3 0 3
:4 0 35 1 :8 0
139 36 :4 0 124
:3 0 30 :3 0 37
:2 0 af 127 128
:3 0 9 :3 0 38
:3 0 12a 12b 0
39 :2 0 12c 12d
0 12f b2 136
9 :3 0 38 :3 0
130 131 0 3a
:2 0 132 133 0
135 b4 137 129
12f 0 138 0
135 0 138 b6
0 139 b9 183
3b :3 0 9 :3 0
38 :3 0 13c 13d
0 3c :3 0 13e
13f 0 179 c
:3 0 d :3 0 141
142 0 c :3 0
1a :3 0 144 145
0 3d :2 0 2
:4 0 3e :2 0 1d
:2 0 1b :2 0 bc
14a 14c :3 0 bf
146 14e 143 150
14f :2 0 f :3 0
1e :3 0 152 153
0 11 :4 0 3f
:4 0 14 :2 0 15
:3 0 c3 157 159
:3 0 14 :2 0 24
:4 0 c6 15b 15d
:3 0 14 :2 0 40
:4 0 c9 15f 161
:3 0 14 :2 0 3c
:3 0 cc 163 165
:3 0 14 :2 0 41
:4 0 cf 167 169
:3 0 14 :2 0 42
:3 0 43 :3 0 1b
:2 0 44 :2 0 d2
16c 170 d6 16b
172 :3 0 d9 154
174 :2 0 176 dc
177 151 176 0
178 de 0 179
e0 17c :3 0 17c
0 17c 17b 179
17a :6 0 17e 2
:3 0 e3 180 e5
17f 17e :2 0 181
e7 :2 0 183 0
183 182 139 181
:6 0 1d3 1 :3 0
c :3 0 d :3 0
185 186 0 c
:3 0 1a :3 0 188
189 0 45 :2 0
2 :4 0 46 :2 0
1d :2 0 1b :2 0
e9 18e 190 :3 0
ec 18a 192 187
194 193 :2 0 f
:3 0 1e :3 0 196
197 0 11 :4 0
47 :4 0 14 :2 0
15 :3 0 f0 19b
19d :3 0 14 :2 0
24 :4 0 f3 19f
1a1 :3 0 14 :2 0
25 :4 0 f6 1a3
1a5 :3 0 14 :2 0
26 :3 0 27 :3 0
9 :3 0 38 :3 0
1aa 1ab 0 f9
1a9 1ad 2a :4 0
fb 1a8 1b0 fe
1a7 1b2 :3 0 14
:2 0 2b :4 0 101
1b4 1b6 :3 0 14
:2 0 17 :4 0 104
1b8 1ba :3 0 14
:2 0 3 :3 0 107
1bc 1be :3 0 14
:2 0 17 :4 0 10a
1c0 1c2 :3 0 10d
198 1c4 :2 0 1c6
110 1c7 195 1c6
0 1c8 112 0
1d3 2e :3 0 48
:3 0 1c9 1ca 0
9 :3 0 38 :3 0
1cc 1cd 0 3
:3 0 30 :3 0 114
1cb 1d1 :2 0 1d3
118 274 9 :3 0
49 :2 0 4 1d4
1d5 0 c :3 0
d :3 0 1d7 1d8
0 c :3 0 1a
:3 0 1da 1db 0
3d :2 0 2 :4 0
4a :2 0 1d :2 0
1b :2 0 11f 1e0
1e2 :3 0 122 1dc
1e4 1d9 1e6 1e5
:2 0 f :3 0 1e
:3 0 1e8 1e9 0
11 :4 0 4b :4 0
14 :2 0 15 :3 0
126 1ed 1ef :3 0
129 1ea 1f1 :2 0
20a f :3 0 1e
:3 0 1f3 1f4 0
11 :4 0 4c :4 0
14 :2 0 9 :3 0
4d :3 0 1f9 1fa
0 12c 1f8 1fc
:3 0 14 :2 0 2b
:4 0 12f 1fe 200
:3 0 14 :2 0 9
:3 0 4e :3 0 203
204 0 132 202
206 :3 0 135 1f5
208 :2 0 20a 138
20b 1e7 20a 0
20c 13b 0 21c
4f :3 0 b :3 0
9 :3 0 4d :3 0
50 :3 0 9 :3 0
4e :3 0 51 :3 0
52 :4 0 53 1
:a 0 218 :2 0 21c
20e 216 :2 0 8
:3 0 b :3 0 21a
:2 0 21c 13d 21e
141 21d 21c :2 0
272 3b :3 0 9
:3 0 38 :3 0 221
222 0 3c :3 0
223 224 0 26a
c :3 0 d :3 0
226 227 0 c
:3 0 1a :3 0 229
22a 0 3d :2 0
2 :4 0 54 :2 0
1d :2 0 1b :2 0
143 22f 231 :3 0
146 22b 233 228
235 234 :2 0 f
:3 0 1e :3 0 237
238 0 11 :4 0
55 :4 0 14 :2 0
15 :3 0 14a 23c
23e :3 0 14d 239
240 :2 0 25a f
:3 0 1e :3 0 242
243 0 11 :4 0
40 :4 0 14 :2 0
3c :3 0 150 247
249 :3 0 14 :2 0
41 :4 0 153 24b
24d :3 0 14 :2 0
42 :3 0 43 :3 0
1b :2 0 44 :2 0
156 250 254 15a
24f 256 :3 0 15d
244 258 :2 0 25a
160 25b 236 25a
0 25c 163 0
26a 4f :3 0 b
:3 0 50 :3 0 9
:3 0 4e :3 0 51
:3 0 52 :4 0 56
1 :a 0 266 :2 0
26a 25e 264 :2 0
8 :3 0 b :3 0
268 :2 0 26a 165
26d :3 0 26d 0
26d 26c 26a 26b
:6 0 26f 1 :3 0
16a 271 16c 270
26f :2 0 272 16e
:2 0 274 171 274
273 1d3 272 :6 0
275 :2 0 2 18
274 278 :3 0 277
275 279 :8 0 
173
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1a
1 27 1 33
2 36 38 2
3b 3d 2 3f
41 2 43 45
2 47 49 2
4b 4d 2 4f
51 2 53 55
2 57 59 2
5b 5d 2 5f
61 2 63 65
2 67 69 2
6b 6d 2 6f
71 2 73 75
2 77 79 4
2f 35 3a 7b
1 7d 1 7f
2 89 8b 3
87 88 8d 2
96 98 2 95
9a 1 9c 1
9e 1 a0 1
a5 2 b4 b6
3 b2 b3 b8
2 c1 c3 2
c5 c7 2 c9
cb 1 d3 2
d5 d6 2 cd
d8 2 da dc
2 de e0 2
e2 e4 2 e6
e8 2 c0 ea
1 ec 1 ee
2 f8 fa 3
f6 f7 fc 2
105 107 2 104
109 1 10b 1
10d 3 114 115
116 3 ef 10e
118 1 11a 1
126 2 125 126
1 12e 1 134
2 136 137 2
123 138 2 149
14b 3 147 148
14d 2 156 158
2 15a 15c 2
15e 160 2 162
164 2 166 168
3 16d 16e 16f
2 16a 171 2
155 173 1 175
1 177 2 140
178 1 17c 1
13b 1 180 2
18d 18f 3 18b
18c 191 2 19a
19c 2 19e 1a0
2 1a2 1a4 1
1ac 2 1ae 1af
2 1a6 1b1 2
1b3 1b5 2 1b7
1b9 2 1bb 1bd
2 1bf 1c1 2
199 1c3 1 1c5
1 1c7 3 1ce
1cf 1d0 6 80
9f 11b 183 1c8
1d2 2 1df 1e1
3 1dd 1de 1e3
2 1ec 1ee 2
1eb 1f0 2 1f7
1fb 2 1fd 1ff
2 201 205 2
1f6 207 2 1f2
209 1 20b 3
20c 217 21b 1
1d6 2 22e 230
3 22c 22d 232
2 23b 23d 2
23a 23f 2 246
248 2 24a 24c
3 251 252 253
2 24e 255 2
245 257 2 241
259 1 25b 4
225 25c 265 269
1 26d 1 220
2 21e 271 1
1f 
1
4
0 
278
0
1
14
4
6
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
f 1 0
b 1 0
7 1 0
2 0 1
3 1 0
1a 1 0
0

/
SHOW ERRORS FUNCTION SP_U_ASSIGN_DESCR;
ALTER FUNCTION SP_U_ASSIGN_DESCR COMPILE DEBUG;
/****************************************************************************************/
Prompt == FUNCTION SP_TEST_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_TEST_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
bb
2 :e:
1FUNCTION:
1SP_TEST_ASSIGN:
1RANK001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_RANK:
1200:
1H_FULL_NAME:
1255:
1H_PROJECT_ID:
132:
1H_RES_ASSIGNMENT_ID:
1H_TSK_ASSIGNMENT_ID:
1H_SECURITY_ID:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_PARTICIPANT:
10:
1H_BITFLAG:
1CURSOR:
1C_RPA0:
1ELEMENT_ID:
1TMT_WBS:
1TYPE_ID:
1PMO_CNST:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1RANK:
1SELECT ELEMENT_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (PMO_CNST.SC_PROJEC+
1T,PMO_CNST.SC_PROPOSAL,PMO_CNST.SC_PROJ_TYPE1,PMO_CNST.SC_PROJ_TYPE2,PMO_CNST+
1.SC_PROJ_TYPE3) AND RANK LIKE h_rank || '%':
1C_RPA1:
1RES_ASSIGNMENT_ID:
1TSK_ASSIGNMENT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1TASK_ID:
1SELECT RES_ASSIGNMENT_ID, TSK_ASSIGNMENT_ID, RESOURCE_ID, RESOURCE_TYPE:n    +
1     FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_ID = h_project_id AND TASK+
1_ID = h_project_id:
1C_FPA1:
1RA:
1PARTICIPANT:
1SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1PROJECT_ASSIGNMENTS:
1PA:
1SELECT ra.RESOURCE_ID, ra.RESOURCE_TYPE, ra.PARTICIPANT, ra.SECURITY_ID:n    +
1     FROM RESOURCE_ASSIGNMENTS ra:n         WHERE ELEMENT_ID = h_project_id A+
1ND NOT EXISTS (:n         SELECT 'X' FROM PROJECT_ASSIGNMENTS pa WHERE pa.PRO+
1JECT_ID = h_project_id AND pa.RESOURCE_ID = ra.RESOURCE_ID):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_TEST_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
141:
1+:
1FPUT:
1               ENTER:: SP_TEST_ASSIGN(42) :: cplan.sql(20323) :: :
1OPEN:
1LOOP:
1FOUND:
1SC_STATE:
1100:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
1=:
1COUNT:
1DUAL:
1PROJECT_ASSIGNMENT_ID:
1SELECT COUNT('X') INTO h_bitflag FROM DUAL WHERE EXISTS (SELECT 'X' FROM TASK+
1_ASSIGNMENTS:n               WHERE PROJECT_ASSIGNMENT_ID = h_tsk_assignment_i+
1d AND RESOURCE_ID = h_res_id):
1SQLCODE:
1OTHERS:
116:
184:
1           EXCEPTION:: SP_TEST_ASSIGN(85) :: cplan.sql(20366) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1UPDATE TASK_ASSIGNMENTS SET PROJECT_ASSIGNMENT_ID = NuLL:n                  W+
1HERE PROJECT_ASSIGNMENT_ID = h_tsk_assignment_id:
1TRUE:
1103:
1           EXCEPTION:: SP_TEST_ASSIGN(104) :: cplan.sql(20385) :: :
1TASK_DAY_OF_YEAR:
1PARENT_ID:
1UPDATE TASK_DAY_OF_YEAR SET PARENT_ID = TSK_ASSIGNMENT_ID:n                  +
1WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_tsk_assignment_id:
1121:
1           EXCEPTION:: SP_TEST_ASSIGN(122) :: cplan.sql(20403) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS:n               WHERE RES_ASSIGNMENT_ID = h_+
1res_assignment_id:n               AND SECURITY_ID = 'SCPROJECTASSIGNMENT':
1141:
1           EXCEPTION:: SP_TEST_ASSIGN(142) :: cplan.sql(20423) :: :
1DELETE FROM PROJECT_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND RESOURCE_+
1ID = h_res_id:
1159:
1           EXCEPTION:: SP_TEST_ASSIGN(160) :: cplan.sql(20441) :: :
1NICK_NAME:
1RESOURCES:
1SELECT NICK_NAME || ';' INTO h_full_name:n                     FROM RESOURCES+
1:n                     WHERE RESOURCE_ID = h_res_id:
1175:
1           EXCEPTION:: SP_TEST_ASSIGN(176) :: cplan.sql(20457) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME || ';' INTO h_full_name:n                     FROM PROFIL+
1ES:n                     WHERE PROFILE_ID = h_res_id:
1190:
1           EXCEPTION:: SP_TEST_ASSIGN(191) :: cplan.sql(20472) :: :
1ASSIGN_NAMES:
1REPLACE:
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_full_name, ''):n  +
1                WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_project_id:
1209:
1           EXCEPTION:: SP_TEST_ASSIGN(210) :: cplan.sql(20491) :: :
1PMO_STPU:
1BIT_ANDNOT:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT = PMO_STPU.BIT_ANDNOT(PARTICIPANT+
1,4096):n                  WHERE RES_ASSIGNMENT_ID = h_res_assignment_id:
1227:
1           EXCEPTION:: SP_TEST_ASSIGN(228) :: cplan.sql(20509) :: :
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1245:
1           EXCEPTION:: SP_TEST_ASSIGN(246) :: cplan.sql(20527) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_tsk_assignment_id:
1262:
1           EXCEPTION:: SP_TEST_ASSIGN(263) :: cplan.sql(20544) :: :
1CLOSE:
1276:
1           EXCEPTION:: SP_TEST_ASSIGN(277) :: cplan.sql(20558) :: :
1COMMIT:
1ELSIF:
1SELECT NICK_NAME || ';' INTO h_full_name:n                  FROM RESOURCES:n +
1                 WHERE RESOURCE_ID = h_res_id:
1307:
1           EXCEPTION:: SP_TEST_ASSIGN(308) :: cplan.sql(20589) :: :
1SELECT PROFILE_NAME || ';' INTO h_full_name:n                  FROM PROFILES+
1:n                  WHERE PROFILE_ID = h_res_id:
1322:
1           EXCEPTION:: SP_TEST_ASSIGN(323) :: cplan.sql(20604) :: :
1INSTR:
1UPDATE TMT_WBS SET ASSIGN_NAMES = CASE:n               WHEN InStr(ASSIGN_NAME+
1S, h_full_name) > 0 THEN ASSIGN_NAMES:n               ELSE ASSIGN_NAMES || h_+
1full_name END:n               WHERE PROJECT_ID = h_project_id AND ELEMENT_ID +
1= h_project_id:
1343:
1           EXCEPTION:: SP_TEST_ASSIGN(344) :: cplan.sql(20625) :: :
1ELEMENT_TYPE_BITS:
1ROLLUP_BITS:
1SC_ASSIGNMENT_BIT:
1INSERT INTO PROJECT_ASSIGNMENTS (PROJECT_ID, RESOURCE_ID, PARTICIPANT, SECURI+
1TY_ID, RESOURCE_TYPE, ELEMENT_TYPE_BITS,ROLLUP_BITS):n               VALUES(h+
1_project_id, h_res_id, h_participant, h_security_id, h_res_type, 1, PMO_CNST.+
1SC_ASSIGNMENT_BIT):
1361:
1           EXCEPTION:: SP_TEST_ASSIGN(362) :: cplan.sql(20643) :: :
1376:
1           EXCEPTION:: SP_TEST_ASSIGN(377) :: cplan.sql(20658) :: :
1393:
1           EXCEPTION:: SP_TEST_ASSIGN(394) :: cplan.sql(20675) :: :
14:
1399:
1       RETURN_STATUS:: SP_TEST_ASSIGN(400) :: cplan.sql(20681) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1406:
1           EXCEPTION:: SP_TEST_ASSIGN(407) :: cplan.sql(20688) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1418:
1           EXCEPTION:: SP_TEST_ASSIGN(419) :: cplan.sql(20700) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
9bb
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a0 f4 b4 bf
c8 :f a0 12a bd b7 11 a4 b1
a0 f4 b4 bf c8 :9 a0 12a bd
b7 11 a4 b1 a0 f4 b4 bf
c8 :15 a0 12a bd b7 11 a4 b1
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 d :2 a0 d :2 a0 e9
dd b3 :3 a0 e9 d3 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 2b b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e :2 a0 e9 dd b3 :6 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c :8 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:4 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :7 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c :4 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :5 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 :2 51 a5 b 7e 6e b4 2e
:5 a0 12a :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :5 a0 12a :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :7 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:3 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 12a a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 e9 dd
b3 :6 a0 e9 d3 5 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 2b b7 19
3c :2 a0 :2 51 a5 b 7e 6e b4
2e :5 a0 12a :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :5 a0 12a :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :c a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :f a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 12a b7 :2 19
3c b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
9bb
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 72 5d 61 64 65 6d
5c 8f 7d 59 81 82 8a 7c
ac 9a 79 9e 9f a7 99 c9
b7 96 bb bc c4 b6 e6 d4
b3 d8 d9 e1 d3 103 f1 d0
f5 f6 fe f0 120 10e ed 112
113 11b 10d 13d 12b 10a 12f 130
138 12a 159 148 14c 127 154 147
175 164 168 144 170 163 17c 180
160 191 194 198 19c 1a0 1a4 1a8
1ac 1b0 1b4 1b8 1bc 1c0 1c4 1c8
1cc 1d0 1d4 1e0 1e5 1e7 1f3 1f7
1f9 1fd 20e 20f 212 216 21a 21e
222 226 22a 22e 232 236 23a 246
24b 24d 259 25d 25f 263 274 275
278 27c 280 284 288 28c 290 294
298 29c 2a0 2a4 2a8 2ac 2b0 2b4
2b8 2bc 2c0 2c4 2c8 2cc 2d0 2dc
2e1 2e3 2ef 2f3 311 2f9 2fd 301
304 30c 2f8 318 31c 2f5 320 324
328 32b 330 331 1 333 338 33c
340 343 348 34c 350 353 358 359
35b 360 363 367 368 36d 372 375
37a 37b 380 383 387 388 38d 390
395 396 39b 39e 3a3 3a4 3a9 3ac
3b0 3b4 3b8 3b9 3bb 3c0 3c1 3c3
3c4 3c9 3cc 3d1 3d2 3d7 3d8 3dd
3df 3e3 3e6 3ea 3ee 3f1 3f5 3f9
3fc 3ff 404 407 40a 40d 40e 413
414 1 416 41b 41f 423 426 42b
430 433 437 438 43d 43e 443 445
449 44c 450 454 458 45c 460 464
468 46c 471 475 476 47a 47e 482
487 48c 490 494 499 49d 4a1 4a4
4a7 4ab 4ad 4b1 4b5 4b8 4bb 4bf
4c1 4c5 4c9 4cc 4d0 4d4 4d7 4db
4de 4e2 4e5 4e6 4eb 4ee 4f2 4f8
4fa 4fe 501 505 509 50c 50d 50f
512 515 516 51b 51f 523 528 52c
52d 531 535 539 53d 541 545 54a
54f 553 557 55b 560 564 568 56b
56e 572 574 578 57c 57f 582 586
588 58c 590 593 597 59b 59e 5a2
5a5 5a9 5ac 5ad 5b2 5b5 5b9 5bf
5c1 5c5 5c8 5cc 5d0 5d4 5d8 5dc
5e0 5e4 5e8 5f4 5f8 5fc 5ff 603
607 609 1 60d 611 615 618 61c
620 624 628 62b 62f 633 636 639
63e 641 644 647 648 64d 64e 1
650 655 659 65d 660 665 66a 66d
671 672 677 67a 67f 680 685 688
68d 68e 693 696 69a 69b 6a0 6a3
6a8 6a9 6ae 6b1 6b5 6b9 6bc 6bf
6c0 6c2 6c3 6c8 6c9 6ce 6d0 6d4
6d7 6d9 6dd 6df 6eb 6ed 6ef 6f0
6f5 6f9 6fb 707 709 70d 711 714
715 717 71a 71d 71e 723 727 72b
72f 733 73f 743 748 74c 74f 750
755 759 75d 760 763 767 769 76d
771 774 777 77b 77d 781 785 788
78a 1 78e 792 796 799 79d 7a1
7a5 7a9 7ac 7b0 7b4 7b7 7ba 7bf
7c2 7c5 7c8 7c9 7ce 7cf 1 7d1
7d6 7da 7de 7e1 7e6 7eb 7ee 7f2
7f3 7f8 7fb 800 801 806 809 80e
80f 814 817 81b 81c 821 824 829
82a 82f 832 836 83a 83d 840 841
843 844 849 84a 84f 851 855 858
85a 85e 860 86c 86e 870 871 876
87a 87c 888 88a 88e 892 896 89a
89e 8a2 8a6 8b2 8b6 8bb 8bf 8c2
8c3 8c8 8cc 8d0 8d3 8d6 8da 8dc
8e0 8e4 8e7 8ea 8ee 8f0 8f4 8f8
8fb 8fd 1 901 905 909 90c 910
914 918 91c 91f 923 927 92a 92d
932 935 938 93b 93c 941 942 1
944 949 94d 951 954 959 95e 961
965 966 96b 96e 973 974 979 97c
981 982 987 98a 98e 98f 994 997
99c 99d 9a2 9a5 9a9 9ad 9b0 9b3
9b4 9b6 9b7 9bc 9bd 9c2 9c4 9c8
9cb 9cd 9d1 9d3 9df 9e1 9e3 9e4
9e9 9ed 9ef 9fb 9fd 9ff a03 a06
a0a a0e a12 a16 a22 a26 a2b a2f
a32 a33 a38 a3c a40 a43 a46 a4a
a4c a50 a54 a57 a5a a5e a60 a64
a68 a6b a6d 1 a71 a75 a79 a7c
a80 a84 a88 a8c a8f a93 a97 a9a
a9d aa2 aa5 aa8 aab aac ab1 ab2
1 ab4 ab9 abd ac1 ac4 ac9 ace
ad1 ad5 ad6 adb ade ae3 ae4 ae9
aec af1 af2 af7 afa afe aff b04
b07 b0c b0d b12 b15 b19 b1d b20
b23 b24 b26 b27 b2c b2d b32 b34
b38 b3b b3d b41 b43 b4f b51 b53
b54 b59 b5d b5f b6b b6d b71 b75
b78 b7c b7f b83 b86 b87 b8c b8f
b93 b97 b9b b9f ba3 baf bb3 bb8
bbc bbf bc0 bc5 bc9 bcd bd0 bd3
bd7 bd9 bdd be1 be4 be7 beb bed
bf1 bf5 bf8 bfa 1 bfe c02 c06
c09 c0d c11 c15 c19 c1c c20 c24
c27 c2a c2f c32 c35 c38 c39 c3e
c3f 1 c41 c46 c4a c4e c51 c56
c5b c5e c62 c63 c68 c6b c70 c71
c76 c79 c7e c7f c84 c87 c8b c8c
c91 c94 c99 c9a c9f ca2 ca6 caa
cad cb0 cb1 cb3 cb4 cb9 cba cbf
cc1 cc5 cc8 cca cce cd0 cdc cde
ce0 ce1 ce6 cea cec cf8 cfa cfe
d02 d05 d08 d09 d0b d0e d13 d14
d19 d1d d21 d25 d29 d2d d39 d3d
d41 d44 d48 d4c d4e 1 d52 d56
d5a d5d d61 d65 d69 d6d d70 d74
d78 d7b d7e d83 d86 d89 d8c d8d
d92 d93 1 d95 d9a d9e da2 da5
daa daf db2 db6 db7 dbc dbf dc4
dc5 dca dcd dd2 dd3 dd8 ddb ddf
de0 de5 de8 ded dee df3 df6 dfa
dfe e01 e04 e05 e07 e08 e0d e0e
e13 e15 e19 e1c e1e e22 e24 e30
e32 e34 e35 e3a e3e e40 e4c e4e
e50 e54 e58 e5c e60 e64 e70 e74
e78 e7b e7f e83 e85 1 e89 e8d
e91 e94 e98 e9c ea0 ea4 ea7 eab
eaf eb2 eb5 eba ebd ec0 ec3 ec4
ec9 eca 1 ecc ed1 ed5 ed9 edc
ee1 ee6 ee9 eed eee ef3 ef6 efb
efc f01 f04 f09 f0a f0f f12 f16
f17 f1c f1f f24 f25 f2a f2d f31
f35 f38 f3b f3c f3e f3f f44 f45
f4a f4c f50 f53 f55 f59 f5b f67
f69 f6b f6c f71 f75 f77 f83 f85
f87 f8b f8f f92 f96 f9a f9e fa2
fa6 faa fae fb2 fb6 fc2 fc6 fcb
fcf fd2 fd3 fd8 fdc fe0 fe3 fe6
fea fec ff0 ff4 ff7 ffa ffe 1000
1004 1008 100b 100d 1 1011 1015 1019
101c 1020 1024 1028 102c 102f 1033 1037
103a 103d 1042 1045 1048 104b 104c 1051
1052 1 1054 1059 105d 1061 1064 1069
106e 1071 1075 1076 107b 107e 1083 1084
1089 108c 1091 1092 1097 109a 109e 109f
10a4 10a7 10ac 10ad 10b2 10b5 10b9 10bd
10c0 10c3 10c4 10c6 10c7 10cc 10cd 10d2
10d4 10d8 10db 10dd 10e1 10e3 10ef 10f1
10f3 10f4 10f9 10fd 10ff 110b 110d 110f
1113 1117 111b 111f 1123 1127 112b 1137
113b 1140 1144 1147 1148 114d 1151 1155
1158 115b 115f 1161 1165 1169 116c 116f
1173 1175 1179 117d 1180 1182 1 1186
118a 118e 1191 1195 1199 119d 11a1 11a4
11a8 11ac 11af 11b2 11b7 11ba 11bd 11c0
11c1 11c6 11c7 1 11c9 11ce 11d2 11d6
11d9 11de 11e3 11e6 11ea 11eb 11f0 11f3
11f8 11f9 11fe 1201 1206 1207 120c 120f
1213 1214 1219 121c 1221 1222 1227 122a
122e 1232 1235 1238 1239 123b 123c 1241
1242 1247 1249 124d 1250 1252 1256 1258
1264 1266 1268 1269 126e 1272 1274 1280
1282 1284 1288 128c 128f 1293 1297 129b
12a7 12ab 12b0 12b4 12b7 12b8 12bd 12c1
12c5 12c8 12cb 12cf 12d1 12d5 12d9 12dc
12df 12e3 12e5 12e9 12ed 12f0 12f2 1
12f6 12fa 12fe 1301 1305 1309 130d 1311
1314 1318 131c 131f 1322 1327 132a 132d
1330 1331 1336 1337 1 1339 133e 1342
1346 1349 134e 1353 1356 135a 135b 1360
1363 1368 1369 136e 1371 1376 1377 137c
137f 1383 1384 1389 138c 1391 1392 1397
139a 139e 13a2 13a5 13a8 13a9 13ab 13ac
13b1 13b2 13b7 13b9 13bd 13c0 13c2 13c6
13c8 13d4 13d6 13d8 13d9 13de 13e2 13e4
13f0 13f2 13f6 13fa 13fe 1402 1406 1412
1416 141b 141f 1422 1423 1428 142c 1430
1433 1436 143a 143c 1440 1444 1447 144a
144e 1450 1454 1458 145b 145d 1 1461
1465 1469 146c 1470 1474 1478 147c 147f
1483 1487 148a 148d 1492 1495 1498 149b
149c 14a1 14a2 1 14a4 14a9 14ad 14b1
14b4 14b9 14be 14c1 14c5 14c6 14cb 14ce
14d3 14d4 14d9 14dc 14e1 14e2 14e7 14ea
14ee 14ef 14f4 14f7 14fc 14fd 1502 1505
1509 150d 1510 1513 1514 1516 1517 151c
151d 1522 1524 1528 152b 152d 1531 1533
153f 1541 1543 1544 1549 154d 154f 155b
155d 155f 1563 156a 156e 1572 1577 1579
157d 1581 1584 1588 158c 158e 1 1592
1596 159a 159d 15a1 15a5 15a9 15ad 15b0
15b4 15b8 15bb 15be 15c3 15c6 15c9 15cc
15cd 15d2 15d3 1 15d5 15da 15de 15e2
15e5 15ea 15ef 15f2 15f6 15f7 15fc 15ff
1604 1605 160a 160d 1612 1613 1618 161b
161f 1620 1625 1628 162d 162e 1633 1636
163a 163e 1641 1644 1645 1647 1648 164d
164e 1653 1655 1659 165c 165e 1662 1664
1670 1672 1674 1675 167a 167e 1680 168c
168e 1692 169e 16a2 16a4 16a8 16ac 16af
16b0 16b2 16b5 16b8 16b9 16be 16c2 16c6
16cb 16cf 16d0 16d4 16d8 16dc 16e0 16e4
16e8 16ed 16f2 16f6 16fa 16fe 1703 1707
170b 170e 1711 1715 1717 171b 171f 1722
1725 1729 172b 172f 1733 1736 173a 173e
1741 1745 1748 174c 174f 1750 1755 1758
175c 1762 1764 1768 176b 176f 1773 1776
1779 177a 177c 177f 1784 1785 178a 178e
1792 1796 179a 179e 17aa 17ae 17b2 17b5
17b9 17bd 17bf 1 17c3 17c7 17cb 17ce
17d2 17d6 17da 17de 17e1 17e5 17e9 17ec
17ef 17f4 17f7 17fa 17fd 17fe 1803 1804
1 1806 180b 180f 1813 1816 181b 1820
1823 1827 1828 182d 1830 1835 1836 183b
183e 1843 1844 1849 184c 1850 1851 1856
1859 185e 185f 1864 1867 186b 186f 1872
1875 1876 1878 1879 187e 187f 1884 1886
188a 188d 188f 1893 1895 18a1 18a3 18a5
18a6 18ab 18af 18b1 18bd 18bf 18c1 18c5
18c9 18cd 18d1 18d5 18e1 18e5 18e9 18ec
18f0 18f4 18f6 1 18fa 18fe 1902 1905
1909 190d 1911 1915 1918 191c 1920 1923
1926 192b 192e 1931 1934 1935 193a 193b
1 193d 1942 1946 194a 194d 1952 1957
195a 195e 195f 1964 1967 196c 196d 1972
1975 197a 197b 1980 1983 1987 1988 198d
1990 1995 1996 199b 199e 19a2 19a6 19a9
19ac 19ad 19af 19b0 19b5 19b6 19bb 19bd
19c1 19c4 19c6 19ca 19cc 19d8 19da 19dc
19dd 19e2 19e6 19e8 19f4 19f6 19f8 19fc
1a00 1a03 1a07 1a0b 1a0f 1a13 1a17 1a1b
1a1f 1a23 1a27 1a2b 1a2f 1a33 1a3f 1a43
1a48 1a4c 1a4f 1a50 1a55 1a59 1a5d 1a60
1a63 1a67 1a69 1a6d 1a71 1a74 1a77 1a7b
1a7d 1a81 1a85 1a88 1a8a 1 1a8e 1a92
1a96 1a99 1a9d 1aa1 1aa5 1aa9 1aac 1ab0
1ab4 1ab7 1aba 1abf 1ac2 1ac5 1ac8 1ac9
1ace 1acf 1 1ad1 1ad6 1ada 1ade 1ae1
1ae6 1aeb 1aee 1af2 1af3 1af8 1afb 1b00
1b01 1b06 1b09 1b0e 1b0f 1b14 1b17 1b1b
1b1c 1b21 1b24 1b29 1b2a 1b2f 1b32 1b36
1b3a 1b3d 1b40 1b41 1b43 1b44 1b49 1b4a
1b4f 1b51 1b55 1b58 1b5a 1b5e 1b60 1b6c
1b6e 1b70 1b71 1b76 1b7a 1b7c 1b88 1b8a
1b8e 1b92 1b96 1b9a 1b9e 1ba2 1ba6 1baa
1bae 1bb2 1bb6 1bba 1bbe 1bc2 1bc6 1bd2
1bd6 1bdb 1bdf 1be2 1be3 1be8 1bec 1bf0
1bf3 1bf6 1bfa 1bfc 1c00 1c04 1c07 1c0a
1c0e 1c10 1c14 1c18 1c1b 1c1d 1 1c21
1c25 1c29 1c2c 1c30 1c34 1c38 1c3c 1c3f
1c43 1c47 1c4a 1c4d 1c52 1c55 1c58 1c5b
1c5c 1c61 1c62 1 1c64 1c69 1c6d 1c71
1c74 1c79 1c7e 1c81 1c85 1c86 1c8b 1c8e
1c93 1c94 1c99 1c9c 1ca1 1ca2 1ca7 1caa
1cae 1caf 1cb4 1cb7 1cbc 1cbd 1cc2 1cc5
1cc9 1ccd 1cd0 1cd3 1cd4 1cd6 1cd7 1cdc
1cdd 1ce2 1ce4 1ce8 1ceb 1ced 1cf1 1cf3
1cff 1d01 1d03 1d04 1d09 1d0d 1d0f 1d1b
1d1d 1d1f 1d23 1d2a 1d2e 1d32 1d37 1d39
1d3d 1d41 1d44 1d48 1d4c 1d4e 1 1d52
1d56 1d5a 1d5d 1d61 1d65 1d69 1d6d 1d70
1d74 1d78 1d7b 1d7e 1d83 1d86 1d89 1d8c
1d8d 1d92 1d93 1 1d95 1d9a 1d9e 1da2
1da5 1daa 1daf 1db2 1db6 1db7 1dbc 1dbf
1dc4 1dc5 1dca 1dcd 1dd2 1dd3 1dd8 1ddb
1ddf 1de0 1de5 1de8 1ded 1dee 1df3 1df6
1dfa 1dfe 1e01 1e04 1e05 1e07 1e08 1e0d
1e0e 1e13 1e15 1e19 1e1c 1e1e 1e22 1e24
1e30 1e32 1e34 1e35 1e3a 1e3e 1e40 1e4c
1e4e 1e52 1e5e 1e60 1e64 1e68 1e6b 1e6d
1e71 1e78 1e7c 1e80 1e85 1e87 1e8b 1e8f
1e92 1e96 1e9a 1e9c 1 1ea0 1ea4 1ea8
1eab 1eaf 1eb3 1eb7 1ebb 1ebe 1ec2 1ec6
1ec9 1ecc 1ed1 1ed4 1ed7 1eda 1edb 1ee0
1ee1 1 1ee3 1ee8 1eec 1ef0 1ef3 1ef8
1efd 1f00 1f04 1f05 1f0a 1f0d 1f12 1f13
1f18 1f1b 1f20 1f21 1f26 1f29 1f2d 1f2e
1f33 1f36 1f3b 1f3c 1f41 1f44 1f48 1f4c
1f4f 1f52 1f53 1f55 1f56 1f5b 1f5c 1f61
1f63 1f67 1f6a 1f6c 1f70 1f72 1f7e 1f80
1f82 1f83 1f88 1f8c 1f8e 1f9a 1f9c 1fa0
1fa4 1fa7 1fab 1faf 1fb2 1fb5 1fba 1fbd
1fc0 1fc3 1fc4 1fc9 1fca 1 1fcc 1fd1
1fd5 1fd9 1fdc 1fe1 1fe6 1fe9 1fed 1fee
1ff3 1ff6 1ffb 1ffc 2001 2004 2009 200a
200f 2012 2016 201a 201e 2022 2025 2026
2028 202d 202e 2030 2031 2036 2039 203e
203f 2044 2047 204c 204d 2052 2055 2059
205a 205f 2062 2067 2068 206d 206e 2073
2075 2079 207c 2080 2084 2087 208b 208f
2092 2096 209a 209b 20a0 20a2 20a6 20aa
20ad 20b1 20b5 20b8 20bc 20c0 20c3 20c6
20cb 20ce 20d1 20d4 20d5 20da 20db 1
20dd 20e2 20e6 20ea 20ed 20f2 20f7 20fa
20fe 20ff 2104 2105 210a 210e 2112 2115
211a 211f 2122 2126 212a 212d 212e 2133
2136 213b 213c 2141 2144 2148 214c 214f
2150 2155 2156 215b 215d 2161 2164 2168
216c 2170 2174 2178 217c 2180 2184 2188
2194 2199 219d 21a1 21a5 21a9 21ab 21ac
21b1 1 21b5 21b9 21bd 21c0 21c4 21c8
21cc 21d0 21d3 21d7 21db 21de 21e1 21e6
21e9 21ec 21ef 21f0 21f5 21f6 1 21f8
21fd 2201 2205 2208 220d 2212 2215 2219
221a 221f 2220 2225 2229 222d 2230 2235
223a 223d 2241 2242 2247 224a 224f 2250
2255 2258 225c 2260 2263 2266 2267 2269
226a 226f 2270 2275 2277 227b 227e 2282
2286 228a 228e 2292 2296 229a 22a6 22ab
22af 22b3 22b7 22bb 22bd 22c1 22c3 22cf
22d1 22d3 22d4 22d9 22dd 22df 22eb 22ef
22f1 22f2 22fb 
9bb
2
0 1 a 6 e :3 6 11 :2 6
1 3 a 13 a :2 1 4 b
14 13 :2 b :2 4 10 19 18 :2 10
:2 4 11 1a 19 :2 11 :2 4 18 21
20 :2 18 :2 4 18 21 20 :2 18 :2 4
12 1b 1a :2 12 :2 4 d 16 15
:2 d :2 4 f 18 17 :2 f :2 4 :2 12
21 12 :2 4 :2 e 1d e 4 7
e 0 :2 7 11 21 10 1c 25
30 39 45 4e 5c 65 73 7c
8f 99 a :6 7 e 0 :2 7 11
24 37 44 f 10 1d 2e 38
a :6 7 e 0 :2 7 11 14 21
24 33 36 43 46 f 24 10
1d 1a 2e 37 3a 47 58 5b
69 6c a :5 7 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 56 5c
5f :2 56 6d 85 8 :2 6d d 10
:2 6d 18 1b :2 6d b e :2 6d 13
16 1f 27 :2 1f 34 :2 16 :2 6d 3c
3f :2 6d :2 7 4c :2 4 7 :2 11 23
:2 2d 39 3c 4e 50 51 :2 4e :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e :2 7
54 :3 4 e :2 4 11 :2 4 9 :4 4
d 19 :2 7 a 11 :2 a :2 13 1f
a 17 a :2 13 1f a :4 7 b
:2 14 20 1d :2 29 :2 1d :3 a 39 :2 7
a 13 1e :2 a 21 23 :2 21 a
f :4 a 13 1f 34 49 53 :3 d
10 17 :2 10 :2 19 25 10 1d 10
:2 19 25 10 :4 d 11 :2 1a 26 23
:2 2f :2 23 :3 10 3f :2 d 17 27 36
59 16 2e 46 54 :2 10 :2 19 25
10 d :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 60 61
:2 5e :2 32 :3 16 :2 1c 21 2d 6e 71
:2 2d 7e 81 :2 2d 85 88 :2 2d 94
97 :2 2d 9f a2 :2 2d ae b1 b8
c1 c4 :2 b1 :2 2d :2 16 64 :2 13 :2 10
:4 1c :2 10 d :3 a 10 19 24 :2 10
27 2a :2 27 1a 2f 19 31 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 64 65 :2 61 :2 35 :3 19
:2 1f 24 30 72 75 :2 30 82 85
:2 30 89 8c :2 30 98 9b :2 30 a3
a6 :2 30 b2 b5 bc c5 c8 :2 b5
:2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13 10
:3 2c 1a 2f 3b 19 26 37 43
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 64 65 :2 61 :2 35
:3 19 :2 1f 24 30 72 75 :2 30 82
85 :2 30 89 8c :2 30 98 9b :2 30
a3 a6 :2 30 b2 b5 bc c5 c8
:2 b5 :2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13
10 :4 2c :2 d 1c 16 2a 14 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 61 62 :2 5e :2 32 :3 16
:2 1c 21 2d 6f 72 :2 2d 7f 82
:2 2d 86 89 :2 2d 95 98 :2 2d a0
a3 :2 2d af b2 b9 c2 c5 :2 b2
:2 2d :2 16 65 :2 13 :2 10 :4 1c :2 10 d
:3 a 11 :2 1a 25 23 :2 2e :2 23 10
1f 39 46 57 65 13 1a 16
22 :3 20 16 :2 1f 2b 16 27 16
:2 1f 2b 16 :4 13 10 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
61 64 65 :2 61 :2 35 :3 19 :2 1f 24
30 72 75 :2 30 82 85 :2 30 89
8c :2 30 98 9b :2 30 a3 a6 :2 30
b2 b5 bc c5 c8 :2 b5 :2 30 :2 19
68 :2 16 :2 13 :4 1f :2 13 10 :3 3e 13
1a 26 29 :2 13 2c 2e :2 2c 1d
33 1b 1c 2a :2 16 :2 1f 2b 16
13 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 67 68 :2 64
:2 38 :3 1c :2 22 27 33 75 78 :2 33
85 88 :2 33 8c 8f :2 33 9b 9e
:2 33 a6 a9 :2 33 b5 b8 bf c8
cb :2 b8 :2 33 :2 1c 6b :2 19 :2 16 :4 22
:2 16 13 :4 32 1d 36 1b 1c 29
:2 16 :2 1f 2b 16 13 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 67 68 :2 64 :2 38 :3 1c :2 22 27
33 75 78 :2 33 85 88 :2 33 8c
8f :2 33 9b 9e :2 33 a6 a9 :2 33
b5 b8 bf c8 cb :2 b8 :2 33 :2 1c
6b :2 19 :2 16 :4 22 :2 16 13 :7 10 1a
26 35 3e 4c 19 26 37 44
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 64 65 :2 61 :2 35
:3 19 :2 1f 24 30 72 75 :2 30 82
85 :2 30 89 8c :2 30 98 9b :2 30
a3 a6 :2 30 b2 b5 bc c5 c8
:2 b5 :2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13
10 :4 3e 1a 33 41 4a 55 19
2d 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 64 65 :2 61
:2 35 :3 19 :2 1f 24 30 72 75 :2 30
82 85 :2 30 89 8c :2 30 98 9b
:2 30 a3 a6 :2 30 b2 b5 bc c5
c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13 :4 1f
:2 13 10 :7 d 1c 33 47 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 61 62 :2 5e :2 32 :3 16 :2 1c
21 2d 6f 72 :2 2d 7f 82 :2 2d
86 89 :2 2d 95 98 :2 2d a0 a3
:2 2d af b2 b9 c2 c5 :2 b2 :2 2d
:2 16 65 :2 13 :2 10 :4 1c :2 10 d :3 a
1c 33 40 51 65 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 61 62 :2 5e :2 32 :3 16 :2 1c 21
2d 6f 72 :2 2d 7f 82 :2 2d 86
89 :2 2d 95 98 :2 2d a0 a3 :2 2d
af b2 b9 c2 c5 :2 b2 :2 2d :2 16
65 :2 13 :2 10 :4 1c :2 10 d :4 a e
25 d 13 :3 d :2 16 22 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5b 5e 5f :2 5b :2 2f
:3 13 :2 19 1e 2a 6c 6f :2 2a 7c
7f :2 2a 83 86 :2 2a 92 95 :2 2a
9d a0 :2 2a ac af b6 bf c2
:2 af :2 2a :2 13 62 :2 10 :2 d :4 19 :2 d
a :3 25 :2 a 7 25 d 16 21
:2 d 24 26 :2 24 a f :4 a 13
1f 29 35 44 :3 d 10 17 :2 10
:2 19 25 10 1d 10 :2 19 25 10
:4 d 11 :2 1a 26 23 :2 2f :2 23 :3 10
3f :2 d 10 17 23 26 :2 10 29
2b :2 29 1a 30 18 19 27 :2 13
:2 1c 28 13 10 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 61
64 65 :2 61 :2 35 :3 19 :2 1f 24 30
72 75 :2 30 82 85 :2 30 89 8c
:2 30 98 9b :2 30 a3 a6 :2 30 b2
b5 bc c5 c8 :2 b5 :2 30 :2 19 68
:2 16 :2 13 :4 1f :2 13 10 :4 2f 1a 33
18 19 26 :2 13 :2 1c 28 13 10
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 64 65 :2 61 :2 35
:3 19 :2 1f 24 30 72 75 :2 30 82
85 :2 30 89 8c :2 30 98 9b :2 30
a3 a6 :2 30 b2 b5 bc c5 c8
:2 b5 :2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13
10 :7 d 17 23 15 1b 29 3f
15 25 16 23 34 41 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 61 62 :2 5e :2 32 :3 16 :2 1c
21 2d 6f 72 :2 2d 7f 82 :2 2d
86 89 :2 2d 95 98 :2 2d a0 a3
:2 2d af b2 b9 c2 c5 :2 b2 :2 2d
:2 16 65 :2 13 :2 10 :4 1c :2 10 d :3 a
1c 31 3d 4a 57 64 73 85
17 25 2f 3e 4d 5c 65 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 61 62 :2 5e :2 32 :3 16
:2 1c 21 2d 6f 72 :2 2d 7f 82
:2 2d 86 89 :2 2d 95 98 :2 2d a0
a3 :2 2d af b2 b9 c2 c5 :2 b2
:2 2d :2 16 65 :2 13 :2 10 :4 1c :2 10 d
:4 a e 28 d 13 :3 d :2 16 22
d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5e 5f
:2 5b :2 2f :3 13 :2 19 1e 2a 6c 6f
:2 2a 7c 7f :2 2a 83 86 :2 2a 92
95 :2 2a 9d a0 :2 2a ac af b6
bf c2 :2 af :2 2a :2 13 62 :2 10 :2 d
:4 19 :2 d a :3 28 :2 a 28 25 :2 7
4 8 1 7 d :3 7 :2 10 1c
7 4 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 55 58 59
:2 55 :2 29 :3 d :2 13 18 24 66 69
:2 24 76 79 :2 24 7d 80 :2 24 8c
8f :2 24 97 9a :2 24 a6 a9 b0
b9 bc :2 a9 :2 24 :2 d 5c :2 a :2 7
:4 13 :2 7 4 :3 1 7 :2 11 23 :2 2d
39 3c 4e 51 52 :2 4e :2 23 :3 7
:2 d 12 1e 60 63 :2 1e 70 73
:2 1e 77 7a :2 1e 84 87 90 98
:2 a1 :2 90 ac :2 87 :2 1e b4 b7 :2 1e
bf c2 :2 1e c7 ca :2 1e d1 d4
:2 1e :2 7 55 :3 4 :2 f 21 :2 2a 34
3c :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 52 55 56 :2 52
:2 26 :3 a :2 10 15 21 63 66 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
59 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4f 52 53 :2 4f
:2 23 :3 7 :2 d 12 1e 60 63 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 56 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
9bb
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :7 7
:7 8 :7 9 :7 a :7 b
:7 c :7 d :7 e :6 f
:6 10 :2 12 0 :2 12
:2 13 :d 14 13 :5 12
:2 16 0 :2 16 :4 17
18 :4 19 17 :5 16
:2 1b 0 :2 1b :8 1c
:2 1d :2 1e :9 1f 1c
:5 1b :7 21 :b 23 :11 24
25 :2 24 :2 25 :2 24
:2 25 :2 24 :2 26 :2 24
:9 26 :2 24 :2 26 :4 24
:3 23 :11 29 :b 2a :3 29
:3 2d :3 2e :5 30 32
:4 33 :3 34 :5 35 34
:5 37 36 :3 34 :a 39
:2 3a :3 39 :9 3e :5 3f
41 :8 42 :3 43 :5 44
43 :5 46 45 :3 43
:a 48 :2 49 :3 48 :4 4d
:4 4e 4d :5 4f 4c
:2 51 :5 53 :11 54 :24 55
:3 54 :2 52 :6 51 50
:3 41 :9 5a :2 5c :2 5d
5c :6 5e :5 5f 5e
:5 61 60 :3 5e 5b
:2 64 :5 66 :11 67 :24 68
:3 67 :2 65 :6 64 63
:3 5a :3 6e :4 6f 6e
:6 70 :5 71 70 :5 73
72 :3 70 6d :2 76
:5 78 :11 79 :24 7a :3 79
:2 77 :6 76 75 :6 5a
81 :2 82 83 81
:6 84 :5 85 84 :5 87
86 :3 84 80 :2 8a
:5 8c :11 8d :24 8e :3 8d
:2 8b :6 8a 89 :3 41
:a 93 :6 95 :6 96 :5 97
96 :5 99 98 :3 96
94 :2 9c :5 9e :11 9f
:24 a0 :3 9f :2 9d :6 9c
9b :3 93 :a a5 :2 a7
a8 :2 a9 a7 :5 aa
a6 :2 ac :5 ae :11 af
:24 b0 :3 af :2 ad :6 ac
ab :4 a5 :2 b6 b7
:2 b8 b6 :5 b9 b5
:2 bb :5 bd :11 be :24 bf
:3 be :2 bc :6 bb ba
:4 b4 :3 a5 :5 c6 :4 c7
c6 :6 c8 :5 c9 c8
:5 cb ca :3 c8 c5
:2 ce :5 d0 :11 d1 :24 d2
:3 d1 :2 cf :6 ce cd
:4 93 :5 d8 :2 d9 d8
:6 da :5 db da :5 dd
dc :3 da d7 :2 e0
:5 e2 :11 e3 :24 e4 :3 e3
:2 e1 :6 e0 df :4 d6
:3 93 :4 eb :6 ec :5 ed
ec :5 ef ee :3 ec
ea :2 f2 :5 f4 :11 f5
:24 f6 :3 f5 :2 f3 :6 f2
f1 :3 41 :6 fc :6 fd
:5 fe fd :5 100 ff
:3 fd fb :2 103 :5 105
:11 106 :24 107 :3 106 :2 104
:6 103 102 :4 41 10b
3e :4 10e :5 10f 10d
:2 111 :5 113 :11 114 :24 115
:3 114 :2 112 :6 111 110
:3 3e :2 11a 11b 3e
:9 11b :5 11c 11e :8 11f
:3 120 :5 121 120 :5 123
122 :3 120 :a 125 :2 126
:3 125 :a 129 :2 12b 12c
:2 12d 12b :5 12e 12a
:2 130 :5 132 :11 133 :24 134
:3 133 :2 131 :6 130 12f
:4 129 :2 13a 13b :2 13c
13a :5 13d 139 :2 13f
:5 141 :11 142 :24 143 :3 142
:2 140 :6 13f 13e :4 138
:3 129 :2 14a :4 14b :2 14c
:4 14d 14a :6 14e :5 14f
14e :5 151 150 :3 14e
149 :2 154 :5 156 :11 157
:24 158 :3 157 :2 155 :6 154
153 :3 11e :8 15e :7 15f
15e :6 160 :5 161 160
:5 163 162 :3 160 15d
:2 166 :5 168 :11 169 :24 16a
:3 169 :2 167 :6 166 165
:4 11e 16f 11b :4 172
:5 173 171 :2 175 :5 177
:11 178 :24 179 :3 178 :2 176
:6 175 174 :3 11b :2 17e
11b :3 3e 32 180
22 :4 183 :5 184 182
:2 186 :5 188 :11 189 :24 18a
:3 189 :2 187 :6 186 185
:3 22 :11 18f :30 190 :3 18f
:a 192 22 :3 195 :11 196
:b 197 :17 198 :3 196 :2 19a
:3 19b :3 19c 19d 19b
19a 19b :3 19e :3 195
:2 19f :5 1a1 :11 1a2 :b 1a3
:18 1a4 :3 1a2 :2 1a6 1a7
:3 1a8 1a9 1a7 1a6
1a7 :3 1aa :2 1a0 :6 19f
194 :7 1 
22fd
4
:3 0 1 :3 0 2
:a 0 9b6 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 6
:3 0 5 :7 0 9
8 :3 0 7 :3 0
8 :3 0 9 :2 0
4 b f 0
9b6 2 10 :2 0
d :2 0 c 4
:3 0 b :2 0 a
13 15 :6 0 18
16 0 9b4 0
a :6 0 f :2 0
10 4 :3 0 e
1a 1c :6 0 1f
1d 0 9b4 0
c :6 0 f :2 0
14 4 :3 0 12
21 23 :6 0 26
24 0 9b4 0
e :6 0 f :2 0
18 4 :3 0 16
28 2a :6 0 2d
2b 0 9b4 0
10 :6 0 f :2 0
1c 4 :3 0 1a
2f 31 :6 0 34
32 0 9b4 0
11 :6 0 f :2 0
20 4 :3 0 1e
36 38 :6 0 3b
39 0 9b4 0
12 :6 0 15 :2 0
24 4 :3 0 22
3d 3f :6 0 42
40 0 9b4 0
13 :6 0 17 :2 0
28 4 :3 0 26
44 46 :6 0 49
47 0 9b4 0
14 :6 0 17 :2 0
2a 6 :3 0 4b
:7 0 4f 4c 4d
9b4 0 16 :9 0
2c 6 :3 0 51
:7 0 55 52 53
9b4 0 18 :6 0
19 :3 0 1a :a 0
2 6b :4 0 57
5a 0 58 :3 0
1b :3 0 1c :3 0
1d :3 0 1e :3 0
1f :3 0 1e :3 0
20 :3 0 1e :3 0
21 :3 0 1e :3 0
22 :3 0 1e :3 0
23 :3 0 24 :3 0
a :4 0 25 1
:8 0 6c 57 5a
6d 0 9b4 2e
6d 6f 6c 6e
:6 0 6b :7 0 6d
19 :3 0 26 :a 0
3 7f :5 0 71
74 0 72 :3 0
27 :3 0 28 :3 0
29 :3 0 2a :3 0
2b :3 0 2c :3 0
e :3 0 2d :3 0
e :4 0 2e 1
:8 0 80 71 74
81 0 9b4 30
81 83 80 82
:6 0 7f :7 0 81
19 :3 0 2f :a 0
4 9f :5 0 85
88 0 86 :3 0
30 :3 0 29 :3 0
30 :3 0 2a :3 0
30 :3 0 31 :3 0
30 :3 0 32 :3 0
33 :3 0 30 :3 0
1b :3 0 e :3 0
34 :3 0 35 :3 0
35 :3 0 2c :3 0
e :3 0 35 :3 0
29 :3 0 30 :3 0
29 :4 0 36 1
:8 0 a0 85 88
a1 0 9b4 32
a1 a3 a0 a2
:6 0 9f :7 0 a1
ab ac 0 34
8 :3 0 9 :2 0
4 a5 a6 0
a7 :7 0 aa a8
0 9b4 0 37
:6 0 38 :3 0 39
:3 0 38 :3 0 3a
:3 0 ae af 0
2 :4 0 36 b0
b2 ad b4 b3
:2 0 3b :3 0 3c
:3 0 b6 b7 0
3d :4 0 38 :3 0
3e :3 0 ba bb
0 2 :4 0 38
bc be 3f :4 0
40 :2 0 41 :3 0
3a c1 c3 :3 0
42 :4 0 40 :2 0
43 :4 0 3d c6
c8 :3 0 40 :2 0
3 :3 0 40 ca
cc :3 0 40 :2 0
43 :4 0 43 ce
d0 :3 0 40 :2 0
44 :4 0 46 d2
d4 :3 0 40 :2 0
45 :3 0 46 :3 0
5 :3 0 49 d8
da 47 :4 0 4b
d7 dd 4e d6
df :3 0 40 :2 0
48 :4 0 51 e1
e3 :3 0 54 b8
e5 :2 0 e7 59
e8 b5 e7 0
e9 5b 0 914
38 :3 0 39 :3 0
ea eb 0 38
:3 0 49 :3 0 ed
ee 0 15 :2 0
2 :4 0 4a :2 0
4b :2 0 15 :2 0
5d f3 f5 :3 0
60 ef f7 ec
f9 f8 :2 0 3b
:3 0 4c :3 0 fb
fc 0 3d :4 0
4d :4 0 40 :2 0
41 :3 0 64 100
102 :3 0 67 fd
104 :2 0 106 6a
107 fa 106 0
108 6c 0 914
a :3 0 3 :3 0
109 10a 0 914
18 :3 0 5 :3 0
10c 10d 0 914
4e :3 0 1a :4 0
112 :2 0 914 110
113 :3 0 4f :3 0
1a :3 0 e :4 0
118 :2 0 86e 115
116 :3 0 1a :3 0
50 :3 0 119 11a
:3 0 8 :3 0 51
:3 0 11c 11d 0
17 :2 0 11e 11f
0 121 6e 128
8 :3 0 51 :3 0
122 123 0 52
:2 0 124 125 0
127 70 129 11b
121 0 12a 0
127 0 12a 72
0 86e 8 :3 0
51 :3 0 12b 12c
0 8 :3 0 53
:2 0 54 :3 0 12e
130 0 77 12f
132 :3 0 133 :2 0
55 :8 0 137 7a
138 134 137 0
139 7c 0 86e
45 :3 0 18 :3 0
17 :2 0 7e 13a
13d 56 :2 0 17
:2 0 83 13f 141
:3 0 4e :3 0 26
:4 0 146 :2 0 63b
144 147 :3 0 4f
:3 0 26 :3 0 10
:3 0 11 :3 0 13
:3 0 14 :4 0 14f
:2 0 5e0 149 150
:3 0 86 :3 0 26
:3 0 50 :3 0 151
152 :3 0 8 :3 0
51 :3 0 154 155
0 17 :2 0 156
157 0 159 8b
160 8 :3 0 51
:3 0 15a 15b 0
52 :2 0 15c 15d
0 15f 8d 161
153 159 0 162
0 15f 0 162
8f 0 5e0 8
:3 0 51 :3 0 163
164 0 8 :3 0
53 :2 0 54 :3 0
166 168 0 94
167 16a :3 0 16b
:2 0 55 :8 0 16f
97 170 16c 16f
0 171 99 0
5e0 57 :3 0 18
:3 0 58 :3 0 2b
:3 0 59 :3 0 11
:3 0 29 :3 0 13
:4 0 5a 1 :8 0
180 8 :3 0 51
:3 0 17b 17c 0
5b :3 0 17d 17e
0 180 9b 1ca
5c :3 0 8 :3 0
51 :3 0 183 184
0 5b :3 0 185
186 0 1c0 38
:3 0 39 :3 0 188
189 0 38 :3 0
49 :3 0 18b 18c
0 5d :2 0 2
:4 0 5e :2 0 4b
:2 0 15 :2 0 9e
191 193 :3 0 a1
18d 195 18a 197
196 :2 0 3b :3 0
4c :3 0 199 19a
0 3d :4 0 5f
:4 0 40 :2 0 41
:3 0 a5 19e 1a0
:3 0 40 :2 0 60
:4 0 a8 1a2 1a4
:3 0 40 :2 0 61
:4 0 ab 1a6 1a8
:3 0 40 :2 0 5b
:3 0 ae 1aa 1ac
:3 0 40 :2 0 62
:4 0 b1 1ae 1b0
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 b4
1b3 1b7 b8 1b2
1b9 :3 0 bb 19b
1bb :2 0 1bd be
1be 198 1bd 0
1bf c0 0 1c0
c2 1c3 :3 0 1c3
0 1c3 1c2 1c0
1c1 :6 0 1c5 7
:3 0 c5 1c7 c7
1c6 1c5 :2 0 1c8
c9 :2 0 1ca 0
1ca 1c9 180 1c8
:6 0 5e0 6 :3 0
45 :3 0 18 :3 0
17 :2 0 cb 1cc
1cf 53 :2 0 17
:2 0 d0 1d1 1d3
:3 0 2b :3 0 59
:3 0 59 :3 0 11
:4 0 66 1 :8 0
1ef 50 :4 0 1da
:3 0 67 :3 0 56
:2 0 d5 1dd 1de
:3 0 8 :3 0 51
:3 0 1e0 1e1 0
17 :2 0 1e2 1e3
0 1e5 d8 1ec
8 :3 0 51 :3 0
1e6 1e7 0 52
:2 0 1e8 1e9 0
1eb da 1ed 1df
1e5 0 1ee 0
1eb 0 1ee dc
0 1ef df 239
5c :3 0 8 :3 0
51 :3 0 1f2 1f3
0 5b :3 0 1f4
1f5 0 22f 38
:3 0 39 :3 0 1f7
1f8 0 38 :3 0
49 :3 0 1fa 1fb
0 5d :2 0 2
:4 0 68 :2 0 4b
:2 0 15 :2 0 e2
200 202 :3 0 e5
1fc 204 1f9 206
205 :2 0 3b :3 0
4c :3 0 208 209
0 3d :4 0 69
:4 0 40 :2 0 41
:3 0 e9 20d 20f
:3 0 40 :2 0 60
:4 0 ec 211 213
:3 0 40 :2 0 61
:4 0 ef 215 217
:3 0 40 :2 0 5b
:3 0 f2 219 21b
:3 0 40 :2 0 62
:4 0 f5 21d 21f
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 f8
222 226 fc 221
228 :3 0 ff 20a
22a :2 0 22c 102
22d 207 22c 0
22e 104 0 22f
106 232 :3 0 232
0 232 231 22f
230 :6 0 234 9
:3 0 109 236 10b
235 234 :2 0 237
10d :2 0 239 0
239 238 1ef 237
:6 0 2a4 6 :3 0
6a :3 0 6b :3 0
28 :3 0 2c :3 0
e :3 0 6b :3 0
11 :4 0 6c 1
:8 0 258 50 :4 0
243 :3 0 67 :3 0
56 :2 0 111 246
247 :3 0 8 :3 0
51 :3 0 249 24a
0 17 :2 0 24b
24c 0 24e 114
255 8 :3 0 51
:3 0 24f 250 0
52 :2 0 251 252
0 254 116 256
248 24e 0 257
0 254 0 257
118 0 258 11b
2a2 5c :3 0 8
:3 0 51 :3 0 25b
25c 0 5b :3 0
25d 25e 0 298
38 :3 0 39 :3 0
260 261 0 38
:3 0 49 :3 0 263
264 0 5d :2 0
2 :4 0 6d :2 0
4b :2 0 15 :2 0
11e 269 26b :3 0
121 265 26d 262
26f 26e :2 0 3b
:3 0 4c :3 0 271
272 0 3d :4 0
6e :4 0 40 :2 0
41 :3 0 125 276
278 :3 0 40 :2 0
60 :4 0 128 27a
27c :3 0 40 :2 0
61 :4 0 12b 27e
280 :3 0 40 :2 0
5b :3 0 12e 282
284 :3 0 40 :2 0
62 :4 0 131 286
288 :3 0 40 :2 0
63 :3 0 64 :3 0
15 :2 0 65 :2 0
134 28b 28f 138
28a 291 :3 0 13b
273 293 :2 0 295
13e 296 270 295
0 297 140 0
298 142 29b :3 0
29b 0 29b 29a
298 299 :6 0 29d
b :3 0 145 29f
147 29e 29d :2 0
2a0 149 :2 0 2a2
0 2a2 2a1 258
2a0 :6 0 2a4 6
:3 0 14b 2a5 1d4
2a4 0 2a6 14e
0 5e0 33 :3 0
27 :3 0 10 :3 0
32 :4 0 6f 1
:8 0 2c1 50 :4 0
2ac :3 0 67 :3 0
56 :2 0 152 2af
2b0 :3 0 8 :3 0
51 :3 0 2b2 2b3
0 17 :2 0 2b4
2b5 0 2b7 155
2be 8 :3 0 51
:3 0 2b8 2b9 0
52 :2 0 2ba 2bb
0 2bd 157 2bf
2b1 2b7 0 2c0
0 2bd 0 2c0
159 0 2c1 15c
30b 5c :3 0 8
:3 0 51 :3 0 2c4
2c5 0 5b :3 0
2c6 2c7 0 301
38 :3 0 39 :3 0
2c9 2ca 0 38
:3 0 49 :3 0 2cc
2cd 0 5d :2 0
2 :4 0 70 :2 0
4b :2 0 15 :2 0
15f 2d2 2d4 :3 0
162 2ce 2d6 2cb
2d8 2d7 :2 0 3b
:3 0 4c :3 0 2da
2db 0 3d :4 0
71 :4 0 40 :2 0
41 :3 0 166 2df
2e1 :3 0 40 :2 0
60 :4 0 169 2e3
2e5 :3 0 40 :2 0
61 :4 0 16c 2e7
2e9 :3 0 40 :2 0
5b :3 0 16f 2eb
2ed :3 0 40 :2 0
62 :4 0 172 2ef
2f1 :3 0 40 :2 0
63 :3 0 64 :3 0
15 :2 0 65 :2 0
175 2f4 2f8 179
2f3 2fa :3 0 17c
2dc 2fc :2 0 2fe
17f 2ff 2d9 2fe
0 300 181 0
301 183 304 :3 0
304 0 304 303
301 302 :6 0 306
d :3 0 186 308
188 307 306 :2 0
309 18a :2 0 30b
0 30b 30a 2c1
309 :6 0 5e0 6
:3 0 8 :3 0 51
:3 0 30d 30e 0
8 :3 0 56 :2 0
54 :3 0 310 312
0 18e 311 314
:3 0 315 :2 0 34
:3 0 2c :3 0 e
:3 0 29 :3 0 13
:4 0 72 1 :8 0
332 50 :4 0 31d
:3 0 67 :3 0 56
:2 0 193 320 321
:3 0 8 :3 0 51
:3 0 323 324 0
17 :2 0 325 326
0 328 196 32f
8 :3 0 51 :3 0
329 32a 0 52
:2 0 32b 32c 0
32e 198 330 322
328 0 331 0
32e 0 331 19a
0 332 19d 37c
5c :3 0 8 :3 0
51 :3 0 335 336
0 5b :3 0 337
338 0 372 38
:3 0 39 :3 0 33a
33b 0 38 :3 0
49 :3 0 33d 33e
0 5d :2 0 2
:4 0 73 :2 0 4b
:2 0 15 :2 0 1a0
343 345 :3 0 1a3
33f 347 33c 349
348 :2 0 3b :3 0
4c :3 0 34b 34c
0 3d :4 0 74
:4 0 40 :2 0 41
:3 0 1a7 350 352
:3 0 40 :2 0 60
:4 0 1aa 354 356
:3 0 40 :2 0 61
:4 0 1ad 358 35a
:3 0 40 :2 0 5b
:3 0 1b0 35c 35e
:3 0 40 :2 0 62
:4 0 1b3 360 362
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 1b6
365 369 1ba 364
36b :3 0 1bd 34d
36d :2 0 36f 1c0
370 34a 36f 0
371 1c2 0 372
1c4 375 :3 0 375
0 375 374 372
373 :6 0 377 f
:3 0 1c7 379 1c9
378 377 :2 0 37a
1cb :2 0 37c 0
37c 37b 332 37a
:6 0 4a6 6 :3 0
63 :3 0 14 :3 0
15 :2 0 15 :2 0
1cd 37e 382 56
:2 0 17 :4 0 1d3
384 386 :3 0 75
:3 0 c :3 0 76
:3 0 29 :3 0 13
:4 0 77 1 :8 0
393 8 :3 0 51
:3 0 38e 38f 0
5b :3 0 390 391
0 393 1d6 3dd
5c :3 0 8 :3 0
51 :3 0 396 397
0 5b :3 0 398
399 0 3d3 38
:3 0 39 :3 0 39b
39c 0 38 :3 0
49 :3 0 39e 39f
0 5d :2 0 2
:4 0 78 :2 0 4b
:2 0 15 :2 0 1d9
3a4 3a6 :3 0 1dc
3a0 3a8 39d 3aa
3a9 :2 0 3b :3 0
4c :3 0 3ac 3ad
0 3d :4 0 79
:4 0 40 :2 0 41
:3 0 1e0 3b1 3b3
:3 0 40 :2 0 60
:4 0 1e3 3b5 3b7
:3 0 40 :2 0 61
:4 0 1e6 3b9 3bb
:3 0 40 :2 0 5b
:3 0 1e9 3bd 3bf
:3 0 40 :2 0 62
:4 0 1ec 3c1 3c3
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 1ef
3c6 3ca 1f3 3c5
3cc :3 0 1f6 3ae
3ce :2 0 3d0 1f9
3d1 3ab 3d0 0
3d2 1fb 0 3d3
1fd 3d6 :3 0 3d6
0 3d6 3d5 3d3
3d4 :6 0 3d8 11
:3 0 200 3da 202
3d9 3d8 :2 0 3db
204 :2 0 3dd 0
3dd 3dc 393 3db
:6 0 3df 6 :3 0
206 438 7a :3 0
c :3 0 7b :3 0
7c :3 0 13 :4 0
7d 1 :8 0 3eb
8 :3 0 51 :3 0
3e6 3e7 0 5b
:3 0 3e8 3e9 0
3eb 208 435 5c
:3 0 8 :3 0 51
:3 0 3ee 3ef 0
5b :3 0 3f0 3f1
0 42b 38 :3 0
39 :3 0 3f3 3f4
0 38 :3 0 49
:3 0 3f6 3f7 0
5d :2 0 2 :4 0
7e :2 0 4b :2 0
15 :2 0 20b 3fc
3fe :3 0 20e 3f8
400 3f5 402 401
:2 0 3b :3 0 4c
:3 0 404 405 0
3d :4 0 7f :4 0
40 :2 0 41 :3 0
212 409 40b :3 0
40 :2 0 60 :4 0
215 40d 40f :3 0
40 :2 0 61 :4 0
218 411 413 :3 0
40 :2 0 5b :3 0
21b 415 417 :3 0
40 :2 0 62 :4 0
21e 419 41b :3 0
40 :2 0 63 :3 0
64 :3 0 15 :2 0
65 :2 0 221 41e
422 225 41d 424
:3 0 228 406 426
:2 0 428 22b 429
403 428 0 42a
22d 0 42b 22f
42e :3 0 42e 0
42e 42d 42b 42c
:6 0 430 13 :3 0
232 432 234 431
430 :2 0 433 236
:2 0 435 0 435
434 3eb 433 :6 0
437 6 :3 0 238
439 387 3df 0
43a 0 437 0
43a 23a 0 4a6
1c :3 0 80 :3 0
81 :3 0 80 :3 0
c :3 0 2c :3 0
e :3 0 1b :3 0
e :4 0 82 1
:8 0 45a 50 :4 0
445 :3 0 67 :3 0
56 :2 0 23f 448
449 :3 0 8 :3 0
51 :3 0 44b 44c
0 17 :2 0 44d
44e 0 450 242
457 8 :3 0 51
:3 0 451 452 0
52 :2 0 453 454
0 456 244 458
44a 450 0 459
0 456 0 459
246 0 45a 249
4a4 5c :3 0 8
:3 0 51 :3 0 45d
45e 0 5b :3 0
45f 460 0 49a
38 :3 0 39 :3 0
462 463 0 38
:3 0 49 :3 0 465
466 0 5d :2 0
2 :4 0 83 :2 0
4b :2 0 15 :2 0
24c 46b 46d :3 0
24f 467 46f 464
471 470 :2 0 3b
:3 0 4c :3 0 473
474 0 3d :4 0
84 :4 0 40 :2 0
41 :3 0 253 478
47a :3 0 40 :2 0
60 :4 0 256 47c
47e :3 0 40 :2 0
61 :4 0 259 480
482 :3 0 40 :2 0
5b :3 0 25c 484
486 :3 0 40 :2 0
62 :4 0 25f 488
48a :3 0 40 :2 0
63 :3 0 64 :3 0
15 :2 0 65 :2 0
262 48d 491 266
48c 493 :3 0 269
475 495 :2 0 497
26c 498 472 497
0 499 26e 0
49a 270 49d :3 0
49d 0 49d 49c
49a 49b :6 0 49f
15 :3 0 273 4a1
275 4a0 49f :2 0
4a2 277 :2 0 4a4
0 4a4 4a3 45a
4a2 :6 0 4a6 6
:3 0 279 511 33
:3 0 31 :3 0 85
:3 0 86 :3 0 31
:3 0 27 :3 0 10
:4 0 87 1 :8 0
4c4 50 :4 0 4af
:3 0 67 :3 0 56
:2 0 27f 4b2 4b3
:3 0 8 :3 0 51
:3 0 4b5 4b6 0
17 :2 0 4b7 4b8
0 4ba 282 4c1
8 :3 0 51 :3 0
4bb 4bc 0 52
:2 0 4bd 4be 0
4c0 284 4c2 4b4
4ba 0 4c3 0
4c0 0 4c3 286
0 4c4 289 50e
5c :3 0 8 :3 0
51 :3 0 4c7 4c8
0 5b :3 0 4c9
4ca 0 504 38
:3 0 39 :3 0 4cc
4cd 0 38 :3 0
49 :3 0 4cf 4d0
0 5d :2 0 2
:4 0 88 :2 0 4b
:2 0 15 :2 0 28c
4d5 4d7 :3 0 28f
4d1 4d9 4ce 4db
4da :2 0 3b :3 0
4c :3 0 4dd 4de
0 3d :4 0 89
:4 0 40 :2 0 41
:3 0 293 4e2 4e4
:3 0 40 :2 0 60
:4 0 296 4e6 4e8
:3 0 40 :2 0 61
:4 0 299 4ea 4ec
:3 0 40 :2 0 5b
:3 0 29c 4ee 4f0
:3 0 40 :2 0 62
:4 0 29f 4f2 4f4
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 2a2
4f7 4fb 2a6 4f6
4fd :3 0 2a9 4df
4ff :2 0 501 2ac
502 4dc 501 0
503 2ae 0 504
2b0 507 :3 0 507
0 507 506 504
505 :6 0 509 17
:3 0 2b3 50b 2b5
50a 509 :2 0 50c
2b7 :2 0 50e 0
50e 50d 4c4 50c
:6 0 510 6 :3 0
2b9 512 316 4a6
0 513 0 510
0 513 2bb 0
5e0 2b :3 0 28
:3 0 11 :4 0 8a
1 :8 0 52d 50
:4 0 518 :3 0 67
:3 0 56 :2 0 2c0
51b 51c :3 0 8
:3 0 51 :3 0 51e
51f 0 17 :2 0
520 521 0 523
2c3 52a 8 :3 0
51 :3 0 524 525
0 52 :2 0 526
527 0 529 2c5
52b 51d 523 0
52c 0 529 0
52c 2c7 0 52d
2ca 577 5c :3 0
8 :3 0 51 :3 0
530 531 0 5b
:3 0 532 533 0
56d 38 :3 0 39
:3 0 535 536 0
38 :3 0 49 :3 0
538 539 0 5d
:2 0 2 :4 0 8b
:2 0 4b :2 0 15
:2 0 2cd 53e 540
:3 0 2d0 53a 542
537 544 543 :2 0
3b :3 0 4c :3 0
546 547 0 3d
:4 0 8c :4 0 40
:2 0 41 :3 0 2d4
54b 54d :3 0 40
:2 0 60 :4 0 2d7
54f 551 :3 0 40
:2 0 61 :4 0 2da
553 555 :3 0 40
:2 0 5b :3 0 2dd
557 559 :3 0 40
:2 0 62 :4 0 2e0
55b 55d :3 0 40
:2 0 63 :3 0 64
:3 0 15 :2 0 65
:2 0 2e3 560 564
2e7 55f 566 :3 0
2ea 548 568 :2 0
56a 2ed 56b 545
56a 0 56c 2ef
0 56d 2f1 570
:3 0 570 0 570
56f 56d 56e :6 0
572 19 :3 0 2f4
574 2f6 573 572
:2 0 575 2f8 :2 0
577 0 577 576
52d 575 :6 0 5e0
6 :3 0 6a :3 0
2c :3 0 e :3 0
28 :3 0 11 :4 0
8d 1 :8 0 594
50 :4 0 57f :3 0
67 :3 0 56 :2 0
2fc 582 583 :3 0
8 :3 0 51 :3 0
585 586 0 17
:2 0 587 588 0
58a 2ff 591 8
:3 0 51 :3 0 58b
58c 0 52 :2 0
58d 58e 0 590
301 592 584 58a
0 593 0 590
0 593 303 0
594 306 5de 5c
:3 0 8 :3 0 51
:3 0 597 598 0
5b :3 0 599 59a
0 5d4 38 :3 0
39 :3 0 59c 59d
0 38 :3 0 49
:3 0 59f 5a0 0
5d :2 0 2 :4 0
8e :2 0 4b :2 0
15 :2 0 309 5a5
5a7 :3 0 30c 5a1
5a9 59e 5ab 5aa
:2 0 3b :3 0 4c
:3 0 5ad 5ae 0
3d :4 0 8f :4 0
40 :2 0 41 :3 0
310 5b2 5b4 :3 0
40 :2 0 60 :4 0
313 5b6 5b8 :3 0
40 :2 0 61 :4 0
316 5ba 5bc :3 0
40 :2 0 5b :3 0
319 5be 5c0 :3 0
40 :2 0 62 :4 0
31c 5c2 5c4 :3 0
40 :2 0 63 :3 0
64 :3 0 15 :2 0
65 :2 0 31f 5c7
5cb 323 5c6 5cd
:3 0 326 5af 5cf
:2 0 5d1 329 5d2
5ac 5d1 0 5d3
32b 0 5d4 32d
5d7 :3 0 5d7 0
5d7 5d6 5d4 5d5
:6 0 5d9 1b :3 0
330 5db 332 5da
5d9 :2 0 5dc 334
:2 0 5de 0 5de
5dd 594 5dc :6 0
5e0 6 :3 0 336
5e2 4f :4 0 5e0
:4 0 63b 90 :3 0
26 :4 0 5e6 :2 0
5ec 5e4 0 8
:3 0 51 :3 0 5e7
5e8 0 5b :3 0
5e9 5ea 0 5ec
340 636 5c :3 0
8 :3 0 51 :3 0
5ef 5f0 0 5b
:3 0 5f1 5f2 0
62c 38 :3 0 39
:3 0 5f4 5f5 0
38 :3 0 49 :3 0
5f7 5f8 0 5d
:2 0 2 :4 0 91
:2 0 4b :2 0 15
:2 0 343 5fd 5ff
:3 0 346 5f9 601
5f6 603 602 :2 0
3b :3 0 4c :3 0
605 606 0 3d
:4 0 92 :4 0 40
:2 0 41 :3 0 34a
60a 60c :3 0 40
:2 0 60 :4 0 34d
60e 610 :3 0 40
:2 0 61 :4 0 350
612 614 :3 0 40
:2 0 5b :3 0 353
616 618 :3 0 40
:2 0 62 :4 0 356
61a 61c :3 0 40
:2 0 63 :3 0 64
:3 0 15 :2 0 65
:2 0 359 61f 623
35d 61e 625 :3 0
360 607 627 :2 0
629 363 62a 604
629 0 62b 365
0 62c 367 62f
:3 0 62f 0 62f
62e 62c 62d :6 0
631 1d :3 0 36a
633 36c 632 631
:2 0 634 36e :2 0
636 0 636 635
5ec 634 :6 0 63b
5 :3 0 93 :4 0
93 1 :8 0 63b
94 :3 0 370 86c
45 :3 0 18 :3 0
17 :2 0 375 63c
63f 56 :2 0 15
:2 0 37a 641 643
:3 0 4e :3 0 2f
:4 0 648 :2 0 86a
646 649 :3 0 4f
:3 0 2f :3 0 13
:3 0 14 :3 0 16
:3 0 12 :4 0 651
:2 0 810 64b 652
:3 0 37d :3 0 2f
:3 0 50 :3 0 653
654 :3 0 8 :3 0
51 :3 0 656 657
0 17 :2 0 658
659 0 65b 382
662 8 :3 0 51
:3 0 65c 65d 0
52 :2 0 65e 65f
0 661 384 663
655 65b 0 664
0 661 0 664
386 0 810 8
:3 0 51 :3 0 665
666 0 8 :3 0
53 :2 0 54 :3 0
668 66a 0 38b
669 66c :3 0 66d
:2 0 55 :8 0 671
38e 672 66e 671
0 673 390 0
810 63 :3 0 14
:3 0 15 :2 0 15
:2 0 392 674 678
56 :2 0 17 :4 0
398 67a 67c :3 0
75 :3 0 c :3 0
76 :3 0 29 :3 0
13 :4 0 95 1
:8 0 689 8 :3 0
51 :3 0 684 685
0 5b :3 0 686
687 0 689 39b
6d3 5c :3 0 8
:3 0 51 :3 0 68c
68d 0 5b :3 0
68e 68f 0 6c9
38 :3 0 39 :3 0
691 692 0 38
:3 0 49 :3 0 694
695 0 5d :2 0
2 :4 0 96 :2 0
4b :2 0 15 :2 0
39e 69a 69c :3 0
3a1 696 69e 693
6a0 69f :2 0 3b
:3 0 4c :3 0 6a2
6a3 0 3d :4 0
97 :4 0 40 :2 0
41 :3 0 3a5 6a7
6a9 :3 0 40 :2 0
60 :4 0 3a8 6ab
6ad :3 0 40 :2 0
61 :4 0 3ab 6af
6b1 :3 0 40 :2 0
5b :3 0 3ae 6b3
6b5 :3 0 40 :2 0
62 :4 0 3b1 6b7
6b9 :3 0 40 :2 0
63 :3 0 64 :3 0
15 :2 0 65 :2 0
3b4 6bc 6c0 3b8
6bb 6c2 :3 0 3bb
6a4 6c4 :2 0 6c6
3be 6c7 6a1 6c6
0 6c8 3c0 0
6c9 3c2 6cc :3 0
6cc 0 6cc 6cb
6c9 6ca :6 0 6ce
20 :3 0 3c5 6d0
3c7 6cf 6ce :2 0
6d1 3c9 :2 0 6d3
0 6d3 6d2 689
6d1 :6 0 6d5 1f
:3 0 3cb 72e 7a
:3 0 c :3 0 7b
:3 0 7c :3 0 13
:4 0 98 1 :8 0
6e1 8 :3 0 51
:3 0 6dc 6dd 0
5b :3 0 6de 6df
0 6e1 3cd 72b
5c :3 0 8 :3 0
51 :3 0 6e4 6e5
0 5b :3 0 6e6
6e7 0 721 38
:3 0 39 :3 0 6e9
6ea 0 38 :3 0
49 :3 0 6ec 6ed
0 5d :2 0 2
:4 0 99 :2 0 4b
:2 0 15 :2 0 3d0
6f2 6f4 :3 0 3d3
6ee 6f6 6eb 6f8
6f7 :2 0 3b :3 0
4c :3 0 6fa 6fb
0 3d :4 0 9a
:4 0 40 :2 0 41
:3 0 3d7 6ff 701
:3 0 40 :2 0 60
:4 0 3da 703 705
:3 0 40 :2 0 61
:4 0 3dd 707 709
:3 0 40 :2 0 5b
:3 0 3e0 70b 70d
:3 0 40 :2 0 62
:4 0 3e3 70f 711
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 3e6
714 718 3ea 713
71a :3 0 3ed 6fc
71c :2 0 71e 3f0
71f 6f9 71e 0
720 3f2 0 721
3f4 724 :3 0 724
0 724 723 721
722 :6 0 726 22
:3 0 3f7 728 3f9
727 726 :2 0 729
3fb :2 0 72b 0
72b 72a 6e1 729
:6 0 72d 1f :3 0
3fd 72f 67d 6d5
0 730 0 72d
0 730 3ff 0
810 1c :3 0 80
:3 0 9b :3 0 80
:3 0 c :3 0 80
:3 0 80 :3 0 c
:3 0 2c :3 0 e
:3 0 1b :3 0 e
:4 0 9c 1 :8 0
753 50 :4 0 73e
:3 0 67 :3 0 56
:2 0 404 741 742
:3 0 8 :3 0 51
:3 0 744 745 0
17 :2 0 746 747
0 749 407 750
8 :3 0 51 :3 0
74a 74b 0 52
:2 0 74c 74d 0
74f 409 751 743
749 0 752 0
74f 0 752 40b
0 753 40e 79d
5c :3 0 8 :3 0
51 :3 0 756 757
0 5b :3 0 758
759 0 793 38
:3 0 39 :3 0 75b
75c 0 38 :3 0
49 :3 0 75e 75f
0 5d :2 0 2
:4 0 9d :2 0 4b
:2 0 15 :2 0 411
764 766 :3 0 414
760 768 75d 76a
769 :2 0 3b :3 0
4c :3 0 76c 76d
0 3d :4 0 9e
:4 0 40 :2 0 41
:3 0 418 771 773
:3 0 40 :2 0 60
:4 0 41b 775 777
:3 0 40 :2 0 61
:4 0 41e 779 77b
:3 0 40 :2 0 5b
:3 0 421 77d 77f
:3 0 40 :2 0 62
:4 0 424 781 783
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 427
786 78a 42b 785
78c :3 0 42e 76e
78e :2 0 790 431
791 76b 790 0
792 433 0 793
435 796 :3 0 796
0 796 795 793
794 :6 0 798 24
:3 0 438 79a 43a
799 798 :2 0 79b
43c :2 0 79d 0
79d 79c 753 79b
:6 0 810 1f :3 0
34 :3 0 2c :3 0
29 :3 0 31 :3 0
32 :3 0 2a :3 0
9f :3 0 a0 :3 0
e :3 0 13 :3 0
16 :3 0 12 :3 0
14 :3 0 1e :3 0
a1 :4 0 a2 1
:8 0 7c4 50 :4 0
7af :3 0 67 :3 0
56 :2 0 440 7b2
7b3 :3 0 8 :3 0
51 :3 0 7b5 7b6
0 17 :2 0 7b7
7b8 0 7ba 443
7c1 8 :3 0 51
:3 0 7bb 7bc 0
52 :2 0 7bd 7be
0 7c0 445 7c2
7b4 7ba 0 7c3
0 7c0 0 7c3
447 0 7c4 44a
80e 5c :3 0 8
:3 0 51 :3 0 7c7
7c8 0 5b :3 0
7c9 7ca 0 804
38 :3 0 39 :3 0
7cc 7cd 0 38
:3 0 49 :3 0 7cf
7d0 0 5d :2 0
2 :4 0 a3 :2 0
4b :2 0 15 :2 0
44d 7d5 7d7 :3 0
450 7d1 7d9 7ce
7db 7da :2 0 3b
:3 0 4c :3 0 7dd
7de 0 3d :4 0
a4 :4 0 40 :2 0
41 :3 0 454 7e2
7e4 :3 0 40 :2 0
60 :4 0 457 7e6
7e8 :3 0 40 :2 0
61 :4 0 45a 7ea
7ec :3 0 40 :2 0
5b :3 0 45d 7ee
7f0 :3 0 40 :2 0
62 :4 0 460 7f2
7f4 :3 0 40 :2 0
63 :3 0 64 :3 0
15 :2 0 65 :2 0
463 7f7 7fb 467
7f6 7fd :3 0 46a
7df 7ff :2 0 801
46d 802 7dc 801
0 803 46f 0
804 471 807 :3 0
807 0 807 806
804 805 :6 0 809
26 :3 0 474 80b
476 80a 809 :2 0
80c 478 :2 0 80e
0 80e 80d 7c4
80c :6 0 810 1f
:3 0 47a 812 4f
:4 0 810 :4 0 86a
90 :3 0 2f :4 0
816 :2 0 81c 814
0 8 :3 0 51
:3 0 817 818 0
5b :3 0 819 81a
0 81c 481 866
5c :3 0 8 :3 0
51 :3 0 81f 820
0 5b :3 0 821
822 0 85c 38
:3 0 39 :3 0 824
825 0 38 :3 0
49 :3 0 827 828
0 5d :2 0 2
:4 0 a5 :2 0 4b
:2 0 15 :2 0 484
82d 82f :3 0 487
829 831 826 833
832 :2 0 3b :3 0
4c :3 0 835 836
0 3d :4 0 a6
:4 0 40 :2 0 41
:3 0 48b 83a 83c
:3 0 40 :2 0 60
:4 0 48e 83e 840
:3 0 40 :2 0 61
:4 0 491 842 844
:3 0 40 :2 0 5b
:3 0 494 846 848
:3 0 40 :2 0 62
:4 0 497 84a 84c
:3 0 40 :2 0 63
:3 0 64 :3 0 15
:2 0 65 :2 0 49a
84f 853 49e 84e
855 :3 0 4a1 837
857 :2 0 859 4a4
85a 834 859 0
85b 4a6 0 85c
4a8 85f :3 0 85f
0 85f 85e 85c
85d :6 0 861 28
:3 0 4ab 863 4ad
862 861 :2 0 864
4af :2 0 866 0
866 865 81c 864
:6 0 86a 5 :3 0
93 :4 0 93 1
:8 0 86a 4b1 86b
644 86a 0 86d
142 63b 0 86d
4b6 0 86e 4b9
870 4f :4 0 86e
:4 0 914 90 :3 0
1a :4 0 874 :2 0
87a 872 0 8
:3 0 51 :3 0 875
876 0 5b :3 0
877 878 0 87a
4be 8c4 5c :3 0
8 :3 0 51 :3 0
87d 87e 0 5b
:3 0 87f 880 0
8ba 38 :3 0 39
:3 0 882 883 0
38 :3 0 49 :3 0
885 886 0 5d
:2 0 2 :4 0 a7
:2 0 4b :2 0 15
:2 0 4c1 88b 88d
:3 0 4c4 887 88f
884 891 890 :2 0
3b :3 0 4c :3 0
893 894 0 3d
:4 0 a8 :4 0 40
:2 0 41 :3 0 4c8
898 89a :3 0 40
:2 0 60 :4 0 4cb
89c 89e :3 0 40
:2 0 61 :4 0 4ce
8a0 8a2 :3 0 40
:2 0 5b :3 0 4d1
8a4 8a6 :3 0 40
:2 0 62 :4 0 4d4
8a8 8aa :3 0 40
:2 0 63 :3 0 64
:3 0 15 :2 0 65
:2 0 4d7 8ad 8b1
4db 8ac 8b3 :3 0
4de 895 8b5 :2 0
8b7 4e1 8b8 892
8b7 0 8b9 4e3
0 8ba 4e5 8bd
:3 0 8bd 0 8bd
8bc 8ba 8bb :6 0
8bf 2a :3 0 4e8
8c1 4ea 8c0 8bf
:2 0 8c2 4ec :2 0
8c4 0 8c4 8c3
87a 8c2 :6 0 914
1 :3 0 38 :3 0
39 :3 0 8c6 8c7
0 38 :3 0 49
:3 0 8c9 8ca 0
a9 :2 0 2 :4 0
aa :2 0 4b :2 0
15 :2 0 4ee 8cf
8d1 :3 0 4f1 8cb
8d3 8c8 8d5 8d4
:2 0 3b :3 0 4c
:3 0 8d7 8d8 0
3d :4 0 ab :4 0
40 :2 0 41 :3 0
4f5 8dc 8de :3 0
40 :2 0 60 :4 0
4f8 8e0 8e2 :3 0
40 :2 0 ac :4 0
4fb 8e4 8e6 :3 0
40 :2 0 45 :3 0
46 :3 0 8 :3 0
51 :3 0 8eb 8ec
0 4fe 8ea 8ee
47 :4 0 500 8e9
8f1 503 8e8 8f3
:3 0 40 :2 0 ad
:4 0 506 8f5 8f7
:3 0 40 :2 0 43
:4 0 509 8f9 8fb
:3 0 40 :2 0 a
:3 0 50c 8fd 8ff
:3 0 40 :2 0 43
:4 0 50f 901 903
:3 0 512 8d9 905
:2 0 907 515 908
8d6 907 0 909
517 0 914 ae
:3 0 af :3 0 90a
90b 0 8 :3 0
51 :3 0 90d 90e
0 a :3 0 67
:3 0 519 90c 912
:2 0 914 51d 9b5
8 :3 0 b0 :2 0
4 915 916 0
38 :3 0 39 :3 0
918 919 0 38
:3 0 49 :3 0 91b
91c 0 5d :2 0
2 :4 0 b1 :2 0
4b :2 0 15 :2 0
527 921 923 :3 0
52a 91d 925 91a
927 926 :2 0 3b
:3 0 4c :3 0 929
92a 0 3d :4 0
b2 :4 0 40 :2 0
41 :3 0 52e 92e
930 :3 0 531 92b
932 :2 0 94b 3b
:3 0 4c :3 0 934
935 0 3d :4 0
b3 :4 0 40 :2 0
8 :3 0 b4 :3 0
93a 93b 0 534
939 93d :3 0 40
:2 0 ad :4 0 537
93f 941 :3 0 40
:2 0 8 :3 0 b5
:3 0 944 945 0
53a 943 947 :3 0
53d 936 949 :2 0
94b 540 94c 928
94b 0 94d 543
0 95d 4e :3 0
37 :3 0 8 :3 0
b4 :3 0 b6 :3 0
8 :3 0 b5 :3 0
b7 :3 0 58 :4 0
b8 1 :a 0 959
:2 0 95d 94f 957
:2 0 7 :3 0 37
:3 0 95b :2 0 95d
545 95f 549 95e
95d :2 0 9b3 5c
:3 0 8 :3 0 51
:3 0 962 963 0
5b :3 0 964 965
0 9ab 38 :3 0
39 :3 0 967 968
0 38 :3 0 49
:3 0 96a 96b 0
5d :2 0 2 :4 0
b9 :2 0 4b :2 0
15 :2 0 54b 970
972 :3 0 54e 96c
974 969 976 975
:2 0 3b :3 0 4c
:3 0 978 979 0
3d :4 0 ba :4 0
40 :2 0 41 :3 0
552 97d 97f :3 0
555 97a 981 :2 0
99b 3b :3 0 4c
:3 0 983 984 0
3d :4 0 61 :4 0
40 :2 0 5b :3 0
558 988 98a :3 0
40 :2 0 62 :4 0
55b 98c 98e :3 0
40 :2 0 63 :3 0
64 :3 0 15 :2 0
65 :2 0 55e 991
995 562 990 997
:3 0 565 985 999
:2 0 99b 568 99c
977 99b 0 99d
56b 0 9ab 4e
:3 0 37 :3 0 b6
:3 0 8 :3 0 b5
:3 0 b7 :3 0 58
:4 0 bb 1 :a 0
9a7 :2 0 9ab 99f
9a5 :2 0 7 :3 0
37 :3 0 9a9 :2 0
9ab 56d 9ae :3 0
9ae 0 9ae 9ad
9ab 9ac :6 0 9b0
1 :3 0 572 9b2
574 9b1 9b0 :2 0
9b3 576 :2 0 9b5
579 9b5 9b4 914
9b3 :6 0 9b6 :2 0
2 10 9b5 9b9
:3 0 9b8 9b6 9ba
:8 0 
588
4
:3 0 1 3 1
7 2 6 a
1 14 1 12
1 1b 1 19
1 22 1 20
1 29 1 27
1 30 1 2e
1 37 1 35
1 3e 1 3c
1 45 1 43
1 4a 1 50
1 6a 1 7e
1 9e 1 a4
1 b1 1 bd
2 c0 c2 2
c5 c7 2 c9
cb 2 cd cf
2 d1 d3 1
d9 2 db dc
2 d5 de 2
e0 e2 4 b9
bf c4 e4 1
e6 1 e8 2
f2 f4 3 f0
f1 f6 2 ff
101 2 fe 103
1 105 1 107
1 120 1 126
2 128 129 1
131 2 12d 131
1 136 1 138
2 13b 13c 1
140 2 13e 140
4 14a 14b 14c
14d 1 158 1
15e 2 160 161
1 169 2 165
169 1 16e 1
170 2 17a 17f
2 190 192 3
18e 18f 194 2
19d 19f 2 1a1
1a3 2 1a5 1a7
2 1a9 1ab 2
1ad 1af 3 1b4
1b5 1b6 2 1b1
1b8 2 19c 1ba
1 1bc 1 1be
2 187 1bf 1
1c3 1 182 1
1c7 2 1cd 1ce
1 1d2 2 1d0
1d2 1 1dc 2
1db 1dc 1 1e4
1 1ea 2 1ec
1ed 2 1d9 1ee
2 1ff 201 3
1fd 1fe 203 2
20c 20e 2 210
212 2 214 216
2 218 21a 2
21c 21e 3 223
224 225 2 220
227 2 20b 229
1 22b 1 22d
2 1f6 22e 1
232 1 1f1 1
236 1 245 2
244 245 1 24d
1 253 2 255
256 2 242 257
2 268 26a 3
266 267 26c 2
275 277 2 279
27b 2 27d 27f
2 281 283 2
285 287 3 28c
28d 28e 2 289
290 2 274 292
1 294 1 296
2 25f 297 1
29b 1 25a 1
29f 2 239 2a2
1 2a5 1 2ae
2 2ad 2ae 1
2b6 1 2bc 2
2be 2bf 2 2ab
2c0 2 2d1 2d3
3 2cf 2d0 2d5
2 2de 2e0 2
2e2 2e4 2 2e6
2e8 2 2ea 2ec
2 2ee 2f0 3
2f5 2f6 2f7 2
2f2 2f9 2 2dd
2fb 1 2fd 1
2ff 2 2c8 300
1 304 1 2c3
1 308 1 313
2 30f 313 1
31f 2 31e 31f
1 327 1 32d
2 32f 330 2
31c 331 2 342
344 3 340 341
346 2 34f 351
2 353 355 2
357 359 2 35b
35d 2 35f 361
3 366 367 368
2 363 36a 2
34e 36c 1 36e
1 370 2 339
371 1 375 1
334 1 379 3
37f 380 381 1
385 2 383 385
2 38d 392 2
3a3 3a5 3 3a1
3a2 3a7 2 3b0
3b2 2 3b4 3b6
2 3b8 3ba 2
3bc 3be 2 3c0
3c2 3 3c7 3c8
3c9 2 3c4 3cb
2 3af 3cd 1
3cf 1 3d1 2
39a 3d2 1 3d6
1 395 1 3da
1 3dd 2 3e5
3ea 2 3fb 3fd
3 3f9 3fa 3ff
2 408 40a 2
40c 40e 2 410
412 2 414 416
2 418 41a 3
41f 420 421 2
41c 423 2 407
425 1 427 1
429 2 3f2 42a
1 42e 1 3ed
1 432 1 435
2 438 439 1
447 2 446 447
1 44f 1 455
2 457 458 2
444 459 2 46a
46c 3 468 469
46e 2 477 479
2 47b 47d 2
47f 481 2 483
485 2 487 489
3 48e 48f 490
2 48b 492 2
476 494 1 496
1 498 2 461
499 1 49d 1
45c 1 4a1 3
37c 43a 4a4 1
4b1 2 4b0 4b1
1 4b9 1 4bf
2 4c1 4c2 2
4ae 4c3 2 4d4
4d6 3 4d2 4d3
4d8 2 4e1 4e3
2 4e5 4e7 2
4e9 4eb 2 4ed
4ef 2 4f1 4f3
3 4f8 4f9 4fa
2 4f5 4fc 2
4e0 4fe 1 500
1 502 2 4cb
503 1 507 1
4c6 1 50b 1
50e 2 511 512
1 51a 2 519
51a 1 522 1
528 2 52a 52b
2 517 52c 2
53d 53f 3 53b
53c 541 2 54a
54c 2 54e 550
2 552 554 2
556 558 2 55a
55c 3 561 562
563 2 55e 565
2 549 567 1
569 1 56b 2
534 56c 1 570
1 52f 1 574
1 581 2 580
581 1 589 1
58f 2 591 592
2 57e 593 2
5a4 5a6 3 5a2
5a3 5a8 2 5b1
5b3 2 5b5 5b7
2 5b9 5bb 2
5bd 5bf 2 5c1
5c3 3 5c8 5c9
5ca 2 5c5 5cc
2 5b0 5ce 1
5d0 1 5d2 2
59b 5d3 1 5d7
1 596 1 5db
9 14e 162 171
1ca 2a6 30b 513
577 5de 2 5e5
5eb 2 5fc 5fe
3 5fa 5fb 600
2 609 60b 2
60d 60f 2 611
613 2 615 617
2 619 61b 3
620 621 622 2
61d 624 2 608
626 1 628 1
62a 2 5f3 62b
1 62f 1 5ee
1 633 4 145
5e2 636 639 2
63d 63e 1 642
2 640 642 4
64c 64d 64e 64f
1 65a 1 660
2 662 663 1
66b 2 667 66b
1 670 1 672
3 675 676 677
1 67b 2 679
67b 2 683 688
2 699 69b 3
697 698 69d 2
6a6 6a8 2 6aa
6ac 2 6ae 6b0
2 6b2 6b4 2
6b6 6b8 3 6bd
6be 6bf 2 6ba
6c1 2 6a5 6c3
1 6c5 1 6c7
2 690 6c8 1
6cc 1 68b 1
6d0 1 6d3 2
6db 6e0 2 6f1
6f3 3 6ef 6f0
6f5 2 6fe 700
2 702 704 2
706 708 2 70a
70c 2 70e 710
3 715 716 717
2 712 719 2
6fd 71b 1 71d
1 71f 2 6e8
720 1 724 1
6e3 1 728 1
72b 2 72e 72f
1 740 2 73f
740 1 748 1
74e 2 750 751
2 73d 752 2
763 765 3 761
762 767 2 770
772 2 774 776
2 778 77a 2
77c 77e 2 780
782 3 787 788
789 2 784 78b
2 76f 78d 1
78f 1 791 2
75a 792 1 796
1 755 1 79a
1 7b1 2 7b0
7b1 1 7b9 1
7bf 2 7c1 7c2
2 7ae 7c3 2
7d4 7d6 3 7d2
7d3 7d8 2 7e1
7e3 2 7e5 7e7
2 7e9 7eb 2
7ed 7ef 2 7f1
7f3 3 7f8 7f9
7fa 2 7f5 7fc
2 7e0 7fe 1
800 1 802 2
7cb 803 1 807
1 7c6 1 80b
6 650 664 673
730 79d 80e 2
815 81b 2 82c
82e 3 82a 82b
830 2 839 83b
2 83d 83f 2
841 843 2 845
847 2 849 84b
3 850 851 852
2 84d 854 2
838 856 1 858
1 85a 2 823
85b 1 85f 1
81e 1 863 4
647 812 866 869
2 86c 86b 4
117 12a 139 86d
2 873 879 2
88a 88c 3 888
889 88e 2 897
899 2 89b 89d
2 89f 8a1 2
8a3 8a5 2 8a7
8a9 3 8ae 8af
8b0 2 8ab 8b2
2 896 8b4 1
8b6 1 8b8 2
881 8b9 1 8bd
1 87c 1 8c1
2 8ce 8d0 3
8cc 8cd 8d2 2
8db 8dd 2 8df
8e1 2 8e3 8e5
1 8ed 2 8ef
8f0 2 8e7 8f2
2 8f4 8f6 2
8f8 8fa 2 8fc
8fe 2 900 902
2 8da 904 1
906 1 908 3
90f 910 911 9
e9 108 10b 10e
111 870 8c4 909
913 2 920 922
3 91e 91f 924
2 92d 92f 2
92c 931 2 938
93c 2 93e 940
2 942 946 2
937 948 2 933
94a 1 94c 3
94d 958 95c 1
917 2 96f 971
3 96d 96e 973
2 97c 97e 2
97b 980 2 987
989 2 98b 98d
3 992 993 994
2 98f 996 2
986 998 2 982
99a 1 99c 4
966 99d 9a6 9aa
1 9ae 1 961
2 95f 9b2 e
17 1e 25 2c
33 3a 41 48
4e 54 6b 7f
9f a9 
1
4
0 
9b9
0
1
50
2c
11
0 1 1 1 1 5 6 7
6 9 6 b 6 d 6 f
6 11 6 13 6 15 6 17
6 19 6 1b 5 1d 5 1f
20 1f 22 1f 24 1f 26 5
28 1 2a 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3 1 0
57 1 2
2e 1 0
71 1 3
85 1 4
43 1 0
4a 1 0
35 1 0
50 1 0
27 1 0
12 1 0
3c 1 0
20 1 0
2 0 1
7 1 0
19 1 0
a4 1 0
0

/
SHOW ERRORS FUNCTION SP_TEST_ASSIGN;
ALTER FUNCTION SP_TEST_ASSIGN COMPILE DEBUG;
/*********************************************************************************************************************************************/
Prompt == FUNCTION FC_MIGRATION ==
CREATE OR REPLACE FUNCTION FC_MIGRATION wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
82
2 :e:
1FUNCTION:
1FC_MIGRATION:
1H_PROJECT_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1RETURN:
1PLS_INTEGER:
1H_LEVEL:
10:
1H_ROLLUP_BITS:
1H_TEMP_SC_STATE:
1CURSOR:
1C01:
1PROJECT_ID:
1LEVEL_ID:
1TMT_WBS:
1TYPE_ID:
1PMO_CNST:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1RANK:
1SELECT PROJECT_ID, LEVEL_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (PMO_CNST+
1.SC_PROJECT,PMO_CNST.SC_PROPOSAL,PMO_CNST.SC_PROJ_TYPE1,PMO_CNST.SC_PROJ_TYPE+
12,PMO_CNST.SC_PROJ_TYPE3):n         ORDER BY RANK DESC:
1C02:
1C03:
1ELEMENT_ID:
1SELECT LEVEL_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (PMO_CNST.SC_PROJECT,+
1PMO_CNST.SC_PROPOSAL,PMO_CNST.SC_PROJ_TYPE1,PMO_CNST.SC_PROJ_TYPE2,PMO_CNST.S+
1C_PROJ_TYPE3) AND ELEMENT_ID = h_project_id:n         ORDER BY RANK DESC:
1C04:
1SELECT /*PROJECT_ID,*/ LEVEL_ID:n         FROM TMT_WBS:n         WHERE TYPE_I+
1D IN (PMO_CNST.SC_PROJECT,PMO_CNST.SC_PROPOSAL,PMO_CNST.SC_PROJ_TYPE1,PMO_CNS+
1T.SC_PROJ_TYPE2,PMO_CNST.SC_PROJ_TYPE3) AND ELEMENT_ID = h_project_id:n      +
1   ORDER BY RANK DESC:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_MIGRATION(:
1':
1);:
1CHECK_TRACE:
11:
137:
1+:
1FPUT:
1               ENTER:: FC_MIGRATION(38) :: cplan.sql(20754) :: :
1IS NULL:
1OPEN:
1LOOP:
1FOUND:
1PMO_DB2M:
1SC_STATE:
1100:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
13269638:
1TASK_ASSIGNMENTS:
1ROLLUP_BITS:
1ACTUAL_START:
1SC_SET_ALL_BITS:
1UPDATE TASK_ASSIGNMENTS SET ROLLUP_BITS = CASE WHEN ACTUAL_START IS NuLL THEN+
1 PMO_CNST.SC_SET_ALL_BITS ELSE h_rollup_bits END:n            WHERE PROJECT_I+
1D = h_project_id:
1TRUE:
1=:
1OTHERS:
1SQLCODE:
116:
172:
1           EXCEPTION:: FC_MIGRATION(73) :: cplan.sql(20789) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1PMO_FUNC:
1BIT_OR:
1SC_PLANNED_BIT:
1SC_SCHED_BIT:
1PLANNED_FINISH:
1SCHED_FINISH:
1ACTUAL_FINISH:
1FORECAST_FINISH:
1FORECAST_START:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_CNST.SC_SET_ALL_BITS, PLANNED_FINISH = N+
1uLL, SCHED_FINISH = NuLL,:n            ACTUAL_FINISH = NuLL,:n            FOR+
1ECAST_FINISH = CASE WHEN FORECAST_START IS NuLL THEN FORECAST_FINISH ELSE NuL+
1L END:n            WHERE PROJECT_ID = h_project_id AND (PLANNED_EFFORT + SCHE+
1D_EFFORT > 0):
194:
1           EXCEPTION:: FC_MIGRATION(95) :: cplan.sql(20811) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = h_rollup_bits, PLANNED_FINISH = NuLL, SCHED_+
1FINISH = NuLL:n            WHERE PROJECT_ID = h_project_id AND ((PLANNED_EFFO+
1RT + SCHED_EFFORT) = 0):
1112:
1           EXCEPTION:: FC_MIGRATION(113) :: cplan.sql(20829) :: :
1TMT_CRI:
1UPDATE TMT_CRI SET ROLLUP_BITS = PMO_CNST.SC_SET_ALL_BITS, PLANNED_FINISH = N+
1uLL, SCHED_FINISH = NuLL:n            WHERE PROJECT_ID = h_project_id AND TYP+
1E_ID <> 14:
1130:
1           EXCEPTION:: FC_MIGRATION(131) :: cplan.sql(20847) :: :
1COALESCE:
1FC_ROLLUP:
1COMMIT:
1CLOSE:
1150:
1           EXCEPTION:: FC_MIGRATION(151) :: cplan.sql(20867) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_CNST.SC_SET_ALL_BITS, ACTUAL_FINISH = Nu+
1LL,:n            FORECAST_FINISH = CASE WHEN FORECAST_START IS NuLL THEN FORE+
1CAST_FINISH ELSE NuLL END:n            WHERE PROJECT_ID = h_project_id AND ((+
1PLANNED_EFFORT + SCHED_EFFORT) = 0):
1185:
1           EXCEPTION:: FC_MIGRATION(186) :: cplan.sql(20902) :: :
1205:
1           EXCEPTION:: FC_MIGRATION(206) :: cplan.sql(20922) :: :
1UPDATE TASK_ASSIGNMENTS SET ROLLUP_BITS = PMO_CNST.SC_SET_ALL_BITS WHERE PROJ+
1ECT_ID = h_project_id:
1240:
1           EXCEPTION:: FC_MIGRATION(241) :: cplan.sql(20957) :: :
1260:
1           EXCEPTION:: FC_MIGRATION(261) :: cplan.sql(20977) :: :
1278:
1           EXCEPTION:: FC_MIGRATION(279) :: cplan.sql(20995) :: :
1296:
1           EXCEPTION:: FC_MIGRATION(297) :: cplan.sql(21013) :: :
1316:
1           EXCEPTION:: FC_MIGRATION(317) :: cplan.sql(21033) :: :
1351:
1           EXCEPTION:: FC_MIGRATION(352) :: cplan.sql(21068) :: :
1371:
1           EXCEPTION:: FC_MIGRATION(372) :: cplan.sql(21088) :: :
1378:
1                EXIT:: FC_MIGRATION(379) :: cplan.sql(21095) :: :
1STATE:: :
0

0
0
7d5
2
0 a0 8d 90 :3 a0 b0 3f b4
:2 a0 2c 6a a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a0 f4 b4
bf c8 :f a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :f a0 12a
bd b7 11 a4 b1 a0 f4 b4
bf c8 :10 a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :10 a0 12a
bd b7 11 a4 b1 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
5a :2 a0 e9 dd b3 :4 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c a0 51 d
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 6b :2 a0 6b :2 a0 6b a5
b d :e a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :9 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :3 a0 a5 b
d a0 12a b7 19 3c b7 a0
47 :2 a0 e9 c1 :2 a0 6b a0 d
b7 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 e9 dd
b3 :4 a0 e9 d3 5 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 2b b7 19
3c :c a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :3 a0 a5 b d a0 12a
b7 19 3c b7 a0 47 :2 a0 e9
c1 :2 a0 6b a0 d b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 a0 e9 dd b3 :3 a0
e9 d3 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 2b b7 19 3c :3 a0 6b
:2 a0 6b :2 a0 6b a5 b d :6 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:e a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :3 a0 a5 b d a0
12a b7 19 3c b7 a0 47 :2 a0
e9 c1 :2 a0 6b a0 d b7 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 e9 dd b3 :3 a0
e9 d3 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 2b b7 19 3c :c a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :3 a0
a5 b d a0 12a b7 19 3c
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 a4 b1
11 68 4f 1d 17 b5 
7d5
2
0 3 7 2b 1f 23 27 1e
32 1b 37 3b 3f 43 5f 4b
4f 57 5a 4a 7b 6a 6e 47
76 69 97 86 8a 66 92 85
9e a2 82 b3 b6 ba be c2
c6 ca ce d2 d6 da de e2
e6 ea ee f2 f6 102 107 109
115 119 11b 11f 130 131 134 138
13c 140 144 148 14c 150 154 158
15c 160 164 168 16c 170 174 180
185 187 193 197 199 19d 1ae 1af
1b2 1b6 1ba 1be 1c2 1c6 1ca 1ce
1d2 1d6 1da 1de 1e2 1e6 1ea 1ee
1f2 1f6 202 207 209 215 219 21b
21f 230 231 234 238 23c 240 244
248 24c 250 254 258 25c 260 264
268 26c 270 274 278 284 289 28b
297 29b 29d 2a1 2a5 2a8 2ac 2b0
2b3 2b8 2b9 1 2bb 2c0 2c4 2c8
2cb 2d0 2d4 2d8 2db 2e0 2e1 2e3
2e8 2eb 2ef 2f0 2f5 2fa 2fd 302
303 308 30b 30f 310 315 318 31d
31e 323 326 32b 32c 331 332 337
339 33d 340 344 348 34b 34f 353
356 359 35e 361 364 367 368 36d
36e 1 370 375 379 37d 380 385
38a 38d 391 392 397 398 39d 39f
3a3 3a6 3aa 3ad 3ae 3b3 3b6 3ba
3be 3c3 3c7 3c8 3cc 3d0 3d4 3d8
3dd 3e2 3e6 3ea 3ee 3f3 3f7 3fb
3fe 401 405 407 40b 40f 412 415
419 41b 41f 423 426 42a 42e 431
435 438 43c 43f 440 445 448 44c
452 454 458 45b 45f 462 466 46a
46e 472 476 47a 47e 482 486 492
496 49b 49f 4a2 4a3 4a8 4ac 4b0
4b3 4b6 4ba 4bc 4c0 4c4 4c7 4ca
4ce 4d0 4d4 4d8 4db 4dd 1 4e1
4e5 4e9 4ec 4f0 4f4 4f8 4fc 4ff
503 507 50a 50d 512 515 518 51b
51c 521 522 1 524 529 52d 531
534 539 53e 541 545 546 54b 54e
553 554 559 55c 561 562 567 56a
56e 56f 574 577 57c 57d 582 585
589 58d 590 593 594 596 597 59c
59d 5a2 5a4 5a8 5ab 5ad 5b1 5b3
5bf 5c1 5c3 5c4 5c9 5cd 5cf 5db
5dd 5e1 5e5 5e9 5ec 5f0 5f4 5f7
5fb 5ff 602 603 605 609 60d 611
615 619 61d 621 625 629 62d 631
635 639 63d 641 64d 651 656 65a
65d 65e 663 667 66b 66e 671 675
677 67b 67f 682 685 689 68b 68f
693 696 698 1 69c 6a0 6a4 6a7
6ab 6af 6b3 6b7 6ba 6be 6c2 6c5
6c8 6cd 6d0 6d3 6d6 6d7 6dc 6dd
1 6df 6e4 6e8 6ec 6ef 6f4 6f9
6fc 700 701 706 709 70e 70f 714
717 71c 71d 722 725 729 72a 72f
732 737 738 73d 740 744 748 74b
74e 74f 751 752 757 758 75d 75f
763 766 768 76c 76e 77a 77c 77e
77f 784 788 78a 796 798 79c 7a0
7a4 7a8 7ac 7b0 7b4 7b8 7bc 7c8
7cc 7d1 7d5 7d8 7d9 7de 7e2 7e6
7e9 7ec 7f0 7f2 7f6 7fa 7fd 800
804 806 80a 80e 811 813 1 817
81b 81f 822 826 82a 82e 832 835
839 83d 840 843 848 84b 84e 851
852 857 858 1 85a 85f 863 867
86a 86f 874 877 87b 87c 881 884
889 88a 88f 892 897 898 89d 8a0
8a4 8a5 8aa 8ad 8b2 8b3 8b8 8bb
8bf 8c3 8c6 8c9 8ca 8cc 8cd 8d2
8d3 8d8 8da 8de 8e1 8e3 8e7 8e9
8f5 8f7 8f9 8fa 8ff 903 905 911
913 917 91b 91f 923 927 92b 92f
933 937 943 947 94c 950 953 954
959 95d 961 964 967 96b 96d 971
975 978 97b 97f 981 985 989 98c
98e 1 992 996 99a 99d 9a1 9a5
9a9 9ad 9b0 9b4 9b8 9bb 9be 9c3
9c6 9c9 9cc 9cd 9d2 9d3 1 9d5
9da 9de 9e2 9e5 9ea 9ef 9f2 9f6
9f7 9fc 9ff a04 a05 a0a a0d a12
a13 a18 a1b a1f a20 a25 a28 a2d
a2e a33 a36 a3a a3e a41 a44 a45
a47 a48 a4d a4e a53 a55 a59 a5c
a5e a62 a64 a70 a72 a74 a75 a7a
a7e a80 a8c a8e a92 a96 a99 a9a
a9c a9f aa2 aa3 aa8 aac ab0 ab4
ab5 ab7 abb abf acb acd ad1 ad4
ad6 ada ae1 ae5 ae9 aee af0 af4
af8 afb aff b03 b05 1 b09 b0d
b11 b14 b18 b1c b20 b24 b27 b2b
b2f b32 b35 b3a b3d b40 b43 b44
b49 b4a 1 b4c b51 b55 b59 b5c
b61 b66 b69 b6d b6e b73 b76 b7b
b7c b81 b84 b89 b8a b8f b92 b96
b97 b9c b9f ba4 ba5 baa bad bb1
bb5 bb8 bbb bbc bbe bbf bc4 bc5
bca bcc bd0 bd3 bd5 bd9 bdb be7
be9 beb bec bf1 bf5 bf7 c03 c05
c09 c0d c12 c16 c17 c1b c1f c23
c27 c2c c31 c35 c39 c3d c42 c46
c4a c4d c50 c54 c56 c5a c5e c61
c64 c68 c6a c6e c72 c75 c79 c7d
c80 c84 c87 c8b c8e c8f c94 c97
c9b ca1 ca3 ca7 caa cae cb2 cb6
cba cbe cc2 cc6 cca cce cd2 cd6
cda ce6 cea cef cf3 cf6 cf7 cfc
d00 d04 d07 d0a d0e d10 d14 d18
d1b d1e d22 d24 d28 d2c d2f d31
1 d35 d39 d3d d40 d44 d48 d4c
d50 d53 d57 d5b d5e d61 d66 d69
d6c d6f d70 d75 d76 1 d78 d7d
d81 d85 d88 d8d d92 d95 d99 d9a
d9f da2 da7 da8 dad db0 db5 db6
dbb dbe dc2 dc3 dc8 dcb dd0 dd1
dd6 dd9 ddd de1 de4 de7 de8 dea
deb df0 df1 df6 df8 dfc dff e01
e05 e07 e13 e15 e17 e18 e1d e21
e23 e2f e31 e35 e39 e3c e3d e3f
e42 e45 e46 e4b e4f e53 e57 e58
e5a e5e e62 e6e e70 e74 e77 e79
e7d e84 e88 e8c e91 e93 e97 e9b
e9e ea2 ea6 ea8 1 eac eb0 eb4
eb7 ebb ebf ec3 ec7 eca ece ed2
ed5 ed8 edd ee0 ee3 ee6 ee7 eec
eed 1 eef ef4 ef8 efc eff f04
f09 f0c f10 f11 f16 f19 f1e f1f
f24 f27 f2c f2d f32 f35 f39 f3a
f3f f42 f47 f48 f4d f50 f54 f58
f5b f5e f5f f61 f62 f67 f68 f6d
f6f f73 f76 f78 f7c f7e f8a f8c
f8e f8f f94 f98 f9a fa6 fa8 faa
fae fb2 fb7 fbb fbc fc0 fc4 fc8
fcd fd2 fd6 fda fdf fe3 fe7 fea
fed ff1 ff3 ff7 ffb ffe 1001 1005
1007 100b 100f 1012 1016 101a 101d 1021
1024 1028 102b 102c 1031 1034 1038 103e
1040 1044 1047 104b 104f 1053 1056 105a
105e 1061 1065 1069 106c 106d 106f 1073
1077 107b 107f 1083 1087 108b 1097 109b
10a0 10a4 10a7 10a8 10ad 10b1 10b5 10b8
10bb 10bf 10c1 10c5 10c9 10cc 10cf 10d3
10d5 10d9 10dd 10e0 10e2 1 10e6 10ea
10ee 10f1 10f5 10f9 10fd 1101 1104 1108
110c 110f 1112 1117 111a 111d 1120 1121
1126 1127 1 1129 112e 1132 1136 1139
113e 1143 1146 114a 114b 1150 1153 1158
1159 115e 1161 1166 1167 116c 116f 1173
1174 1179 117c 1181 1182 1187 118a 118e
1192 1195 1198 1199 119b 119c 11a1 11a2
11a7 11a9 11ad 11b0 11b2 11b6 11b8 11c4
11c6 11c8 11c9 11ce 11d2 11d4 11e0 11e2
11e6 11ea 11ee 11f2 11f6 11fa 11fe 1202
1206 120a 120e 1212 1216 121a 1226 122a
122f 1233 1236 1237 123c 1240 1244 1247
124a 124e 1250 1254 1258 125b 125e 1262
1264 1268 126c 126f 1271 1 1275 1279
127d 1280 1284 1288 128c 1290 1293 1297
129b 129e 12a1 12a6 12a9 12ac 12af 12b0
12b5 12b6 1 12b8 12bd 12c1 12c5 12c8
12cd 12d2 12d5 12d9 12da 12df 12e2 12e7
12e8 12ed 12f0 12f5 12f6 12fb 12fe 1302
1303 1308 130b 1310 1311 1316 1319 131d
1321 1324 1327 1328 132a 132b 1330 1331
1336 1338 133c 133f 1341 1345 1347 1353
1355 1357 1358 135d 1361 1363 136f 1371
1375 1379 137d 1381 1385 1389 138d 1391
1395 13a1 13a5 13aa 13ae 13b1 13b2 13b7
13bb 13bf 13c2 13c5 13c9 13cb 13cf 13d3
13d6 13d9 13dd 13df 13e3 13e7 13ea 13ec
1 13f0 13f4 13f8 13fb 13ff 1403 1407
140b 140e 1412 1416 1419 141c 1421 1424
1427 142a 142b 1430 1431 1 1433 1438
143c 1440 1443 1448 144d 1450 1454 1455
145a 145d 1462 1463 1468 146b 1470 1471
1476 1479 147d 147e 1483 1486 148b 148c
1491 1494 1498 149c 149f 14a2 14a3 14a5
14a6 14ab 14ac 14b1 14b3 14b7 14ba 14bc
14c0 14c2 14ce 14d0 14d2 14d3 14d8 14dc
14de 14ea 14ec 14f0 14f4 14f8 14fc 1500
1504 1508 150c 1510 151c 1520 1525 1529
152c 152d 1532 1536 153a 153d 1540 1544
1546 154a 154e 1551 1554 1558 155a 155e
1562 1565 1567 1 156b 156f 1573 1576
157a 157e 1582 1586 1589 158d 1591 1594
1597 159c 159f 15a2 15a5 15a6 15ab 15ac
1 15ae 15b3 15b7 15bb 15be 15c3 15c8
15cb 15cf 15d0 15d5 15d8 15dd 15de 15e3
15e6 15eb 15ec 15f1 15f4 15f8 15f9 15fe
1601 1606 1607 160c 160f 1613 1617 161a
161d 161e 1620 1621 1626 1627 162c 162e
1632 1635 1637 163b 163d 1649 164b 164d
164e 1653 1657 1659 1665 1667 166b 166f
1672 1673 1675 1678 167b 167c 1681 1685
1689 168d 168e 1690 1694 1698 16a4 16a6
16aa 16ad 16af 16b3 16ba 16be 16c2 16c7
16c9 16cd 16d1 16d4 16d8 16dc 16de 1
16e2 16e6 16ea 16ed 16f1 16f5 16f9 16fd
1700 1704 1708 170b 170e 1713 1716 1719
171c 171d 1722 1723 1 1725 172a 172e
1732 1735 173a 173f 1742 1746 1747 174c
174f 1754 1755 175a 175d 1762 1763 1768
176b 176f 1770 1775 1778 177d 177e 1783
1786 178a 178e 1791 1794 1795 1797 1798
179d 179e 17a3 17a5 17a9 17ac 17ae 17b2
17b4 17c0 17c2 17c4 17c5 17ca 17ce 17d0
17dc 17de 17e2 17e6 17eb 17ef 17f0 17f4
17f8 17fc 1801 1806 180a 180e 1813 1817
181b 181e 1821 1825 1827 182b 182f 1832
1835 1839 183b 183f 1843 1846 184a 184e
1851 1855 1858 185c 185f 1860 1865 1868
186c 1872 1874 1878 187b 187f 1883 1887
188b 188f 1893 1897 189b 189f 18a3 18a7
18ab 18b7 18bb 18c0 18c4 18c7 18c8 18cd
18d1 18d5 18d8 18db 18df 18e1 18e5 18e9
18ec 18ef 18f3 18f5 18f9 18fd 1900 1902
1 1906 190a 190e 1911 1915 1919 191d
1921 1924 1928 192c 192f 1932 1937 193a
193d 1940 1941 1946 1947 1 1949 194e
1952 1956 1959 195e 1963 1966 196a 196b
1970 1973 1978 1979 197e 1981 1986 1987
198c 198f 1993 1994 1999 199c 19a1 19a2
19a7 19aa 19ae 19b2 19b5 19b8 19b9 19bb
19bc 19c1 19c2 19c7 19c9 19cd 19d0 19d2
19d6 19d8 19e4 19e6 19e8 19e9 19ee 19f2
19f4 1a00 1a02 1a06 1a0a 1a0d 1a0e 1a10
1a13 1a16 1a17 1a1c 1a20 1a24 1a28 1a29
1a2b 1a2f 1a33 1a3f 1a41 1a45 1a48 1a4a
1a4e 1a55 1a59 1a5d 1a62 1a64 1a68 1a6c
1a6f 1a73 1a77 1a79 1 1a7d 1a81 1a85
1a88 1a8c 1a90 1a94 1a98 1a9b 1a9f 1aa3
1aa6 1aa9 1aae 1ab1 1ab4 1ab7 1ab8 1abd
1abe 1 1ac0 1ac5 1ac9 1acd 1ad0 1ad5
1ada 1add 1ae1 1ae2 1ae7 1aea 1aef 1af0
1af5 1af8 1afd 1afe 1b03 1b06 1b0a 1b0b
1b10 1b13 1b18 1b19 1b1e 1b21 1b25 1b29
1b2c 1b2f 1b30 1b32 1b33 1b38 1b39 1b3e
1b40 1b44 1b47 1b49 1b4d 1b4f 1b5b 1b5d
1b5f 1b60 1b65 1b69 1b6b 1b77 1b79 1b7b
1b7f 1b83 1b86 1b8a 1b8e 1b91 1b95 1b99
1b9c 1b9f 1ba4 1ba7 1baa 1bad 1bae 1bb3
1bb4 1 1bb6 1bbb 1bbf 1bc3 1bc6 1bcb
1bd0 1bd3 1bd7 1bd8 1bdd 1be0 1be5 1be6
1beb 1bee 1bf3 1bf4 1bf9 1bfc 1c00 1c04
1c07 1c08 1c0d 1c0e 1c13 1c15 1c19 1c1c
1c20 1c24 1c28 1c2b 1c2f 1c31 1c35 1c37
1c43 1c47 1c49 1c4a 1c53 
7d5
2
0 1 a 6 16 1a 21 :2 6
1 3 a :2 1 4 :2 c 1b c
:2 4 :2 12 21 12 :2 4 :2 14 23 14
4 7 e 0 :2 7 11 1d 2b
10 1c 25 30 39 45 4e 5c
65 73 7c 13 a :6 7 e 0
:2 7 11 1d 2b 10 1c 25 30
39 45 4e 5c 65 73 7c 13
a :6 7 e 0 :2 7 11 1f 10
1c 25 30 39 45 4e 5c 65
73 7c 8f 9c 13 a :6 7 e
0 :2 7 21 f 10 1c 25 30
39 45 4e 5c 65 73 7c 8f
9c 13 a :6 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
54 5a 5d :2 54 6b 81 8 :2 6b
d 10 :2 6b 1d 20 :2 6b 25 28
:2 6b :2 7 4a :2 4 7 :2 11 23 :2 2d
39 3c 4c 4e 4f :2 4c :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :2 7 52
:2 4 :4 8 :2 7 c :4 7 10 19 27
:3 a d 11 :2 d :2 16 22 d 17
d :2 16 22 d :4 a e :2 17 23
20 :2 2c :2 20 :3 d 3c :3 a 1b a
14 29 41 5b 64 79 13 20
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5b 5c :2 59 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 7 a 1b :2 24 2b :2 34 44
:2 4d :2 1b a 14 20 2e 37 48
5f :2 d 29 45 13 20 32 43
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5b 5c :2 59 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 7 14 20 2e 3d 54 13
20 33 44 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 59 5c
5d :2 59 :2 2f :3 13 :2 19 1e 2a 6a
6d :2 2a 7a 7d :2 2a 81 84 :2 2a
90 93 :2 2a 9b 9e :2 2a aa ad
b4 bd c0 :2 ad :2 2a :2 13 60 :2 10
:2 d :4 19 :2 d a :3 7 14 20 2e
37 48 5f 13 20 31 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 59 5c 5d :2 59 :2 2f :3 13 :2 19
1e 2a 6a 6d :2 2a 7a 7d :2 2a
81 84 :2 2a 90 93 :2 2a 9b 9e
:2 2a aa ad b4 bd c0 :2 ad :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :3 7
d 16 1f :2 d 22 24 :2 22 d
20 2a :2 20 :3 d 26 :2 a 7 b
1e a 10 :3 a :2 13 1f a 7
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 67 6a :2 27 77
7a :2 27 7e 81 :2 27 8d 90 :2 27
98 9b :2 27 a7 aa b1 ba bd
:2 aa :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 1e 7 c :4 7 10 19 27
:3 a d 11 :2 d :2 16 22 d 17
d :2 16 22 d :4 a e :2 17 23
20 :2 2c :2 20 :3 d 3c :2 a 14 20
2e 37 48 d 29 45 13 20
33 44 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 59 5c 5d
:2 59 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 90
93 :2 2a 9b 9e :2 2a aa ad b4
bd c0 :2 ad :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :3 7 d 16 1f :2 d
22 24 :2 22 d 20 2a :2 20 :3 d
26 :2 a 7 b 1e a 10 :3 a
:2 13 1f a 7 :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
67 6a :2 27 77 7a :2 27 7e 81
:2 27 8d 90 :2 27 98 9b :2 27 a7
aa b1 ba bd :2 aa :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :4 1e 7 c
:4 7 10 19 :2 a d 11 :2 d :2 16
22 d 17 d :2 16 22 d :4 a
e :2 17 23 20 :2 2c :2 20 :3 d 3c
:3 a 1b :2 24 2b :2 34 44 :2 4d :2 1b
a 14 29 37 40 56 63 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5c 5d :2 59 :2 2f :3 13
:2 19 1e 2a 6a 6d :2 2a 7a 7d
:2 2a 81 84 :2 2a 90 93 :2 2a 9b
9e :2 2a aa ad b4 bd c0 :2 ad
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:3 7 14 20 2e 37 48 5f :2 d
29 45 13 20 32 43 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 59 5c 5d :2 59 :2 2f :3 13 :2 19
1e 2a 6a 6d :2 2a 7a 7d :2 2a
81 84 :2 2a 90 93 :2 2a 9b 9e
:2 2a aa ad b4 bd c0 :2 ad :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :3 7
14 20 2e 3d 54 13 20 33
44 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 59 5c 5d :2 59
:2 2f :3 13 :2 19 1e 2a 6a 6d :2 2a
7a 7d :2 2a 81 84 :2 2a 90 93
:2 2a 9b 9e :2 2a aa ad b4 bd
c0 :2 ad :2 2a :2 13 60 :2 10 :2 d :4 19
:2 d a :3 7 14 20 2e 37 48
5f 13 20 31 d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 59
5c 5d :2 59 :2 2f :3 13 :2 19 1e 2a
6a 6d :2 2a 7a 7d :2 2a 81 84
:2 2a 90 93 :2 2a 9b 9e :2 2a aa
ad b4 bd c0 :2 ad :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 7 d 16
1f :2 d 22 24 :2 22 d 20 2a
:2 20 :3 d 26 :2 a 7 b 4 a
10 :3 a :2 13 1f a 7 :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8d 90 :2 27 98 9b
:2 27 a7 aa b1 ba bd :2 aa :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 4
7 c :4 7 10 19 :2 a d 11
:2 d :2 16 22 d 17 d :2 16 22
d :4 a e :2 17 23 20 :2 2c :2 20
:3 d 3c :2 a 14 20 2e 37 48
d 29 45 13 20 33 44 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5c 5d :2 59 :2 2f :3 13
:2 19 1e 2a 6a 6d :2 2a 7a 7d
:2 2a 81 84 :2 2a 90 93 :2 2a 9b
9e :2 2a aa ad b4 bd c0 :2 ad
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:3 7 d 16 1f :2 d 22 24 :2 22
d 20 2a :2 20 :3 d 26 :2 a 7
b 4 a 10 :3 a :2 13 1f a
7 :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 67 6a :2 27
77 7a :2 27 7e 81 :2 27 8d 90
:2 27 98 9b :2 27 a7 aa b1 ba
bd :2 aa :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :7 4 7 :2 11 23 :2 2d 39
3c 4c 4f 50 :2 4c :2 23 :3 7 :2 d
12 1e 5e 61 :2 1e 6e 71 :2 1e
75 78 :2 1e 82 85 :2 8e :2 1e :2 7
53 :3 4 b :2 14 4 :9 1 
7d5
4
0 :2 1 :6 3 2
:2 4 :2 1 :6 6 :6 7
:6 8 :2 a 0 :2 a
:3 b :b c d b
:5 a :2 f 0 :2 f
:3 10 :b 11 12 10
:5 f :2 14 0 :2 14
:2 15 :d 16 17 15
:5 14 :2 19 0 :2 19
1a 1b :d 1c 1d
1a :5 19 :b 20 :11 21
22 :2 21 :2 22 :2 21
:2 22 :2 21 :2 22 :4 21
:3 20 :11 25 :b 26 :3 25
:5 29 :5 2c 2e :6 2f
:3 30 :5 31 30 :5 33
32 :3 30 :a 35 :2 36
:3 35 :3 39 :6 3d :2 3e
3d :6 3f :5 40 3f
:5 42 41 :3 3f 3c
:2 45 :5 47 :11 48 :24 49
:3 48 :2 46 :6 45 44
:3 2e :d 4e :6 51 52
:3 53 :4 54 51 :6 55
:5 56 55 :5 58 57
:3 55 50 :2 5b :5 5d
:11 5e :24 5f :3 5e :2 5c
:6 5b 5a :3 2e :5 65
:4 66 65 :6 67 :5 68
67 :5 6a 69 :3 67
64 :2 6d :5 6f :11 70
:24 71 :3 70 :2 6e :6 6d
6c :3 2e :6 77 :3 78
77 :6 79 :5 7a 79
:5 7c 7b :3 79 76
:2 7f :5 81 :11 82 :24 83
:3 82 :2 80 :6 7f 7e
:3 2e :9 88 :6 89 :2 8b
:3 88 2e 8d 29
:4 90 :5 91 8f :2 93
:5 95 :11 96 :24 97 :3 96
:2 94 :6 93 92 :3 29
:5 9e a0 :6 a1 :3 a2
:5 a3 a2 :5 a5 a4
:3 a2 :a a8 :2 a9 :3 a8
:5 ad :3 ae :4 af ad
:6 b0 :5 b1 b0 :5 b3
b2 :3 b0 ac :2 b6
:5 b8 :11 b9 :24 ba :3 b9
:2 b7 :6 b6 b5 :3 a0
:9 bf :6 c0 :2 c2 :3 bf
a0 c4 29 :4 c7
:5 c8 c6 :2 ca :5 cc
:11 cd :24 ce :3 cd :2 cb
:6 ca c9 :4 29 :5 d5
d7 :4 d8 :3 d9 :5 da
d9 :5 dc db :3 d9
:a df :2 e0 :3 df :d e3
:7 e6 :6 e7 :5 e8 e7
:5 ea e9 :3 e7 e5
:2 ed :5 ef :11 f0 :24 f1
:3 f0 :2 ee :6 ed ec
:3 d7 :6 f7 f8 :3 f9
:4 fa f7 :6 fb :5 fc
fb :5 fe fd :3 fb
f6 :2 101 :5 103 :11 104
:24 105 :3 104 :2 102 :6 101
100 :3 d7 :5 10b :4 10c
10b :6 10d :5 10e 10d
:5 110 10f :3 10d 10a
:2 113 :5 115 :11 116 :24 117
:3 116 :2 114 :6 113 112
:3 d7 :6 11d :3 11e 11d
:6 11f :5 120 11f :5 122
121 :3 11f 11c :2 125
:5 127 :11 128 :24 129 :3 128
:2 126 :6 125 124 :3 d7
:9 12e :6 12f :2 131 :3 12e
d7 133 d2 :4 136
:5 137 135 :2 139 :5 13b
:11 13c :24 13d :3 13c :2 13a
:6 139 138 :3 d2 :5 144
146 :4 147 :3 148 :5 149
148 :5 14b 14a :3 148
:a 14e :2 14f :3 14e :5 153
:3 154 :4 155 153 :6 156
:5 157 156 :5 159 158
:3 156 152 :2 15c :5 15e
:11 15f :24 160 :3 15f :2 15d
:6 15c 15b :3 146 :9 165
:6 166 :2 168 :3 165 146
16a d2 :4 16d :5 16e
16c :2 170 :5 172 :11 173
:24 174 :3 173 :2 171 :6 170
16f :4 d2 :3 29 :11 17a
:19 17b :3 17a :5 17d :2 1f
:7 1 
1c55
4
:3 0 1 :3 0 2
:a 0 7d0 1 :7 0
5 :2 0 3 4
:3 0 5 :3 0 6
:3 0 3 :5 0 1
7 6 :3 0 7
:3 0 8 :3 0 9
b 0 7d0 2
c :2 0 a :2 0
7 8 :3 0 f
:7 0 a :2 0 13
10 11 7ce 0
9 :6 0 a :2 0
9 8 :3 0 15
:7 0 19 16 17
7ce 0 b :9 0
b 8 :3 0 1b
:7 0 1f 1c 1d
7ce 0 c :6 0
d :3 0 e :a 0
2 35 :4 0 21
24 0 22 :3 0
f :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
19 :4 0 1a 1
:8 0 36 21 24
37 0 7ce d
37 39 36 38
:6 0 35 :7 0 37
d :3 0 1b :a 0
3 4f :5 0 3b
3e 0 3c :3 0
f :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
19 :4 0 1a 1
:8 0 50 3b 3e
51 0 7ce f
51 53 50 52
:6 0 4f :7 0 51
d :3 0 1c :a 0
4 6a :5 0 55
58 0 56 :3 0
10 :3 0 11 :3 0
12 :3 0 13 :3 0
14 :3 0 13 :3 0
15 :3 0 13 :3 0
16 :3 0 13 :3 0
17 :3 0 13 :3 0
18 :3 0 1d :3 0
3 :3 0 19 :4 0
1e 1 :8 0 6b
55 58 6c 0
7ce 11 6c 6e
6b 6d :6 0 6a
:7 0 6c d :3 0
1f :a 0 5 85
:5 0 70 73 0
71 :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
1d :3 0 3 :3 0
19 :4 0 20 1
:8 0 86 70 73
87 0 7ce 13
87 89 86 88
:6 0 85 :7 0 87
21 :3 0 22 :3 0
8a 8b 0 21
:3 0 23 :3 0 8d
8e 0 2 :4 0
15 8f 91 8c
93 92 :2 0 24
:3 0 25 :3 0 95
96 0 26 :4 0
21 :3 0 27 :3 0
99 9a 0 2
:4 0 17 9b 9d
28 :4 0 29 :2 0
2a :3 0 19 a0
a2 :3 0 2b :4 0
29 :2 0 2c :4 0
1c a5 a7 :3 0
29 :2 0 3 :3 0
1f a9 ab :3 0
29 :2 0 2c :4 0
22 ad af :3 0
29 :2 0 2d :4 0
25 b1 b3 :3 0
28 97 b5 :2 0
b7 2d b8 94
b7 0 b9 2f
0 7cc 21 :3 0
22 :3 0 ba bb
0 21 :3 0 2e
:3 0 bd be 0
2f :2 0 2 :4 0
30 :2 0 31 :2 0
2f :2 0 31 c3
c5 :3 0 34 bf
c7 bc c9 c8
:2 0 24 :3 0 32
:3 0 cb cc 0
26 :4 0 33 :4 0
29 :2 0 2a :3 0
38 d0 d2 :3 0
3b cd d4 :2 0
d6 3e d7 ca
d6 0 d8 40
0 7cc 3 :3 0
34 :2 0 42 da
db :3 0 dc :2 0
35 :3 0 e :4 0
e1 :2 0 43e df
e2 :3 0 36 :3 0
e :3 0 3 :3 0
9 :4 0 e8 :2 0
2df e4 e9 :3 0
44 :3 0 e :3 0
37 :3 0 ea eb
:3 0 38 :3 0 39
:3 0 ed ee 0
a :2 0 ef f0
0 f2 47 f9
38 :3 0 39 :3 0
f3 f4 0 3a
:2 0 f5 f6 0
f8 49 fa ec
f2 0 fb 0
f8 0 fb 4b
0 2df 38 :3 0
39 :3 0 fc fd
0 38 :3 0 3b
:2 0 3c :3 0 ff
101 0 50 100
103 :3 0 104 :2 0
3d :8 0 108 53
109 105 108 0
10a 55 0 2df
b :3 0 3e :2 0
10b 10c 0 2df
3f :3 0 40 :3 0
41 :3 0 13 :3 0
42 :3 0 b :3 0
f :3 0 3 :4 0
43 1 :8 0 12c
37 :4 0 117 :3 0
44 :3 0 45 :2 0
59 11a 11b :3 0
38 :3 0 39 :3 0
11d 11e 0 a
:2 0 11f 120 0
122 5c 129 38
:3 0 39 :3 0 123
124 0 3a :2 0
125 126 0 128
5e 12a 11c 122
0 12b 0 128
0 12b 60 0
12c 63 176 46
:3 0 38 :3 0 39
:3 0 12f 130 0
47 :3 0 131 132
0 16c 21 :3 0
22 :3 0 134 135
0 21 :3 0 2e
:3 0 137 138 0
48 :2 0 2 :4 0
49 :2 0 31 :2 0
2f :2 0 66 13d
13f :3 0 69 139
141 136 143 142
:2 0 24 :3 0 32
:3 0 145 146 0
26 :4 0 4a :4 0
29 :2 0 2a :3 0
6d 14a 14c :3 0
29 :2 0 4b :4 0
70 14e 150 :3 0
29 :2 0 4c :4 0
73 152 154 :3 0
29 :2 0 47 :3 0
76 156 158 :3 0
29 :2 0 4d :4 0
79 15a 15c :3 0
29 :2 0 4e :3 0
4f :3 0 2f :2 0
50 :2 0 7c 15f
163 80 15e 165
:3 0 83 147 167
:2 0 169 86 16a
144 169 0 16b
88 0 16c 8a
16f :3 0 16f 0
16f 16e 16c 16d
:6 0 171 7 :3 0
8d 173 8f 172
171 :2 0 174 91
:2 0 176 0 176
175 12c 174 :6 0
2df 6 :3 0 b
:3 0 51 :3 0 52
:3 0 179 17a 0
13 :3 0 53 :3 0
17c 17d 0 13
:3 0 54 :3 0 17f
180 0 93 17b
182 178 183 0
2df 11 :3 0 40
:3 0 13 :3 0 42
:3 0 55 :3 0 56
:3 0 57 :3 0 58
:3 0 59 :3 0 58
:3 0 f :3 0 3
:3 0 5a :3 0 5b
:4 0 5c 1 :8 0
1a9 37 :4 0 194
:3 0 44 :3 0 45
:2 0 98 197 198
:3 0 38 :3 0 39
:3 0 19a 19b 0
a :2 0 19c 19d
0 19f 9b 1a6
38 :3 0 39 :3 0
1a0 1a1 0 3a
:2 0 1a2 1a3 0
1a5 9d 1a7 199
19f 0 1a8 0
1a5 0 1a8 9f
0 1a9 a2 1f3
46 :3 0 38 :3 0
39 :3 0 1ac 1ad
0 47 :3 0 1ae
1af 0 1e9 21
:3 0 22 :3 0 1b1
1b2 0 21 :3 0
2e :3 0 1b4 1b5
0 48 :2 0 2
:4 0 5d :2 0 31
:2 0 2f :2 0 a5
1ba 1bc :3 0 a8
1b6 1be 1b3 1c0
1bf :2 0 24 :3 0
32 :3 0 1c2 1c3
0 26 :4 0 5e
:4 0 29 :2 0 2a
:3 0 ac 1c7 1c9
:3 0 29 :2 0 4b
:4 0 af 1cb 1cd
:3 0 29 :2 0 4c
:4 0 b2 1cf 1d1
:3 0 29 :2 0 47
:3 0 b5 1d3 1d5
:3 0 29 :2 0 4d
:4 0 b8 1d7 1d9
:3 0 29 :2 0 4e
:3 0 4f :3 0 2f
:2 0 50 :2 0 bb
1dc 1e0 bf 1db
1e2 :3 0 c2 1c4
1e4 :2 0 1e6 c5
1e7 1c1 1e6 0
1e8 c7 0 1e9
c9 1ec :3 0 1ec
0 1ec 1eb 1e9
1ea :6 0 1ee 9
:3 0 cc 1f0 ce
1ef 1ee :2 0 1f1
d0 :2 0 1f3 0
1f3 1f2 1a9 1f1
:6 0 2df 6 :3 0
11 :3 0 40 :3 0
b :3 0 55 :3 0
56 :3 0 f :3 0
3 :3 0 5a :3 0
5b :4 0 5f 1
:8 0 214 37 :4 0
1ff :3 0 44 :3 0
45 :2 0 d4 202
203 :3 0 38 :3 0
39 :3 0 205 206
0 a :2 0 207
208 0 20a d7
211 38 :3 0 39
:3 0 20b 20c 0
3a :2 0 20d 20e
0 210 d9 212
204 20a 0 213
0 210 0 213
db 0 214 de
25e 46 :3 0 38
:3 0 39 :3 0 217
218 0 47 :3 0
219 21a 0 254
21 :3 0 22 :3 0
21c 21d 0 21
:3 0 2e :3 0 21f
220 0 48 :2 0
2 :4 0 60 :2 0
31 :2 0 2f :2 0
e1 225 227 :3 0
e4 221 229 21e
22b 22a :2 0 24
:3 0 32 :3 0 22d
22e 0 26 :4 0
61 :4 0 29 :2 0
2a :3 0 e8 232
234 :3 0 29 :2 0
4b :4 0 eb 236
238 :3 0 29 :2 0
4c :4 0 ee 23a
23c :3 0 29 :2 0
47 :3 0 f1 23e
240 :3 0 29 :2 0
4d :4 0 f4 242
244 :3 0 29 :2 0
4e :3 0 4f :3 0
2f :2 0 50 :2 0
f7 247 24b fb
246 24d :3 0 fe
22f 24f :2 0 251
101 252 22c 251
0 253 103 0
254 105 257 :3 0
257 0 257 256
254 255 :6 0 259
b :3 0 108 25b
10a 25a 259 :2 0
25c 10c :2 0 25e
0 25e 25d 214
25c :6 0 2df 6
:3 0 62 :3 0 40
:3 0 13 :3 0 42
:3 0 55 :3 0 56
:3 0 f :3 0 3
:3 0 12 :4 0 63
1 :8 0 27f 37
:4 0 26a :3 0 44
:3 0 45 :2 0 110
26d 26e :3 0 38
:3 0 39 :3 0 270
271 0 a :2 0
272 273 0 275
113 27c 38 :3 0
39 :3 0 276 277
0 3a :2 0 278
279 0 27b 115
27d 26f 275 0
27e 0 27b 0
27e 117 0 27f
11a 2c9 46 :3 0
38 :3 0 39 :3 0
282 283 0 47
:3 0 284 285 0
2bf 21 :3 0 22
:3 0 287 288 0
21 :3 0 2e :3 0
28a 28b 0 48
:2 0 2 :4 0 64
:2 0 31 :2 0 2f
:2 0 11d 290 292
:3 0 120 28c 294
289 296 295 :2 0
24 :3 0 32 :3 0
298 299 0 26
:4 0 65 :4 0 29
:2 0 2a :3 0 124
29d 29f :3 0 29
:2 0 4b :4 0 127
2a1 2a3 :3 0 29
:2 0 4c :4 0 12a
2a5 2a7 :3 0 29
:2 0 47 :3 0 12d
2a9 2ab :3 0 29
:2 0 4d :4 0 130
2ad 2af :3 0 29
:2 0 4e :3 0 4f
:3 0 2f :2 0 50
:2 0 133 2b2 2b6
137 2b1 2b8 :3 0
13a 29a 2ba :2 0
2bc 13d 2bd 297
2bc 0 2be 13f
0 2bf 141 2c2
:3 0 2c2 0 2c2
2c1 2bf 2c0 :6 0
2c4 d :3 0 144
2c6 146 2c5 2c4
:2 0 2c7 148 :2 0
2c9 0 2c9 2c8
27f 2c7 :6 0 2df
6 :3 0 66 :3 0
9 :3 0 a :2 0
14a 2cb 2ce 45
:2 0 a :2 0 14f
2d0 2d2 :3 0 c
:3 0 67 :3 0 3
:3 0 152 2d5 2d7
2d4 2d8 0 2dc
68 :4 0 68 1
:8 0 2dc 154 2dd
2d3 2dc 0 2de
157 0 2df 159
2e1 36 :4 0 2df
:4 0 43e 69 :3 0
e :4 0 2e5 :2 0
2eb 2e3 0 38
:3 0 39 :3 0 2e6
2e7 0 47 :3 0
2e8 2e9 0 2eb
164 335 46 :3 0
38 :3 0 39 :3 0
2ee 2ef 0 47
:3 0 2f0 2f1 0
32b 21 :3 0 22
:3 0 2f3 2f4 0
21 :3 0 2e :3 0
2f6 2f7 0 48
:2 0 2 :4 0 6a
:2 0 31 :2 0 2f
:2 0 167 2fc 2fe
:3 0 16a 2f8 300
2f5 302 301 :2 0
24 :3 0 32 :3 0
304 305 0 26
:4 0 6b :4 0 29
:2 0 2a :3 0 16e
309 30b :3 0 29
:2 0 4b :4 0 171
30d 30f :3 0 29
:2 0 4c :4 0 174
311 313 :3 0 29
:2 0 47 :3 0 177
315 317 :3 0 29
:2 0 4d :4 0 17a
319 31b :3 0 29
:2 0 4e :3 0 4f
:3 0 2f :2 0 50
:2 0 17d 31e 322
181 31d 324 :3 0
184 306 326 :2 0
328 187 329 303
328 0 32a 189
0 32b 18b 32e
:3 0 32e 0 32e
32d 32b 32c :6 0
330 f :3 0 18e
332 190 331 330
:2 0 333 192 :2 0
335 0 335 334
2eb 333 :6 0 43e
1 :3 0 35 :3 0
1b :4 0 33a :2 0
43e 338 33b :3 0
36 :3 0 1b :3 0
3 :3 0 9 :4 0
341 :2 0 3e6 33d
342 :3 0 194 :3 0
1b :3 0 37 :3 0
343 344 :3 0 38
:3 0 39 :3 0 346
347 0 a :2 0
348 349 0 34b
197 352 38 :3 0
39 :3 0 34c 34d
0 3a :2 0 34e
34f 0 351 199
353 345 34b 0
354 0 351 0
354 19b 0 3e6
38 :3 0 39 :3 0
355 356 0 38
:3 0 3b :2 0 3c
:3 0 358 35a 0
1a0 359 35c :3 0
35d :2 0 3d :8 0
361 1a3 362 35e
361 0 363 1a5
0 3e6 11 :3 0
40 :3 0 13 :3 0
42 :3 0 57 :3 0
58 :3 0 59 :3 0
58 :3 0 f :3 0
3 :3 0 5a :3 0
5b :4 0 6c 1
:8 0 386 37 :4 0
371 :3 0 44 :3 0
45 :2 0 1a9 374
375 :3 0 38 :3 0
39 :3 0 377 378
0 a :2 0 379
37a 0 37c 1ac
383 38 :3 0 39
:3 0 37d 37e 0
3a :2 0 37f 380
0 382 1ae 384
376 37c 0 385
0 382 0 385
1b0 0 386 1b3
3d0 46 :3 0 38
:3 0 39 :3 0 389
38a 0 47 :3 0
38b 38c 0 3c6
21 :3 0 22 :3 0
38e 38f 0 21
:3 0 2e :3 0 391
392 0 48 :2 0
2 :4 0 6d :2 0
31 :2 0 2f :2 0
1b6 397 399 :3 0
1b9 393 39b 390
39d 39c :2 0 24
:3 0 32 :3 0 39f
3a0 0 26 :4 0
6e :4 0 29 :2 0
2a :3 0 1bd 3a4
3a6 :3 0 29 :2 0
4b :4 0 1c0 3a8
3aa :3 0 29 :2 0
4c :4 0 1c3 3ac
3ae :3 0 29 :2 0
47 :3 0 1c6 3b0
3b2 :3 0 29 :2 0
4d :4 0 1c9 3b4
3b6 :3 0 29 :2 0
4e :3 0 4f :3 0
2f :2 0 50 :2 0
1cc 3b9 3bd 1d0
3b8 3bf :3 0 1d3
3a1 3c1 :2 0 3c3
1d6 3c4 39e 3c3
0 3c5 1d8 0
3c6 1da 3c9 :3 0
3c9 0 3c9 3c8
3c6 3c7 :6 0 3cb
12 :3 0 1dd 3cd
1df 3cc 3cb :2 0
3ce 1e1 :2 0 3d0
0 3d0 3cf 386
3ce :6 0 3e6 11
:3 0 66 :3 0 9
:3 0 a :2 0 1e3
3d2 3d5 45 :2 0
a :2 0 1e8 3d7
3d9 :3 0 c :3 0
67 :3 0 3 :3 0
1eb 3dc 3de 3db
3df 0 3e3 68
:4 0 68 1 :8 0
3e3 1ed 3e4 3da
3e3 0 3e5 1f0
0 3e6 1f2 3e8
36 :4 0 3e6 :4 0
43e 69 :3 0 1b
:4 0 3ec :2 0 3f2
3ea 0 38 :3 0
39 :3 0 3ed 3ee
0 47 :3 0 3ef
3f0 0 3f2 1f8
43c 46 :3 0 38
:3 0 39 :3 0 3f5
3f6 0 47 :3 0
3f7 3f8 0 432
21 :3 0 22 :3 0
3fa 3fb 0 21
:3 0 2e :3 0 3fd
3fe 0 48 :2 0
2 :4 0 6f :2 0
31 :2 0 2f :2 0
1fb 403 405 :3 0
1fe 3ff 407 3fc
409 408 :2 0 24
:3 0 32 :3 0 40b
40c 0 26 :4 0
70 :4 0 29 :2 0
2a :3 0 202 410
412 :3 0 29 :2 0
4b :4 0 205 414
416 :3 0 29 :2 0
4c :4 0 208 418
41a :3 0 29 :2 0
47 :3 0 20b 41c
41e :3 0 29 :2 0
4d :4 0 20e 420
422 :3 0 29 :2 0
4e :3 0 4f :3 0
2f :2 0 50 :2 0
211 425 429 215
424 42b :3 0 218
40d 42d :2 0 42f
21b 430 40a 42f
0 431 21d 0
432 21f 435 :3 0
435 0 435 434
432 433 :6 0 437
14 :3 0 222 439
224 438 437 :2 0
43a 226 :2 0 43c
0 43c 43b 3f2
43a :6 0 43e 1
:3 0 228 797 35
:3 0 1c :4 0 442
:2 0 796 440 443
:3 0 36 :3 0 1c
:3 0 9 :4 0 448
:2 0 639 445 446
:3 0 1c :3 0 37
:3 0 449 44a :3 0
38 :3 0 39 :3 0
44c 44d 0 a
:2 0 44e 44f 0
451 22f 458 38
:3 0 39 :3 0 452
453 0 3a :2 0
454 455 0 457
231 459 44b 451
0 45a 0 457
0 45a 233 0
639 38 :3 0 39
:3 0 45b 45c 0
38 :3 0 3b :2 0
3c :3 0 45e 460
0 238 45f 462
:3 0 463 :2 0 3d
:8 0 467 23b 468
464 467 0 469
23d 0 639 b
:3 0 51 :3 0 52
:3 0 46b 46c 0
13 :3 0 53 :3 0
46e 46f 0 13
:3 0 54 :3 0 471
472 0 23f 46d
474 46a 475 0
639 3f :3 0 40
:3 0 13 :3 0 42
:3 0 f :3 0 3
:4 0 71 1 :8 0
493 37 :4 0 47e
:3 0 44 :3 0 45
:2 0 244 481 482
:3 0 38 :3 0 39
:3 0 484 485 0
a :2 0 486 487
0 489 247 490
38 :3 0 39 :3 0
48a 48b 0 3a
:2 0 48c 48d 0
48f 249 491 483
489 0 492 0
48f 0 492 24b
0 493 24e 4dd
46 :3 0 38 :3 0
39 :3 0 496 497
0 47 :3 0 498
499 0 4d3 21
:3 0 22 :3 0 49b
49c 0 21 :3 0
2e :3 0 49e 49f
0 48 :2 0 2
:4 0 72 :2 0 31
:2 0 2f :2 0 251
4a4 4a6 :3 0 254
4a0 4a8 49d 4aa
4a9 :2 0 24 :3 0
32 :3 0 4ac 4ad
0 26 :4 0 73
:4 0 29 :2 0 2a
:3 0 258 4b1 4b3
:3 0 29 :2 0 4b
:4 0 25b 4b5 4b7
:3 0 29 :2 0 4c
:4 0 25e 4b9 4bb
:3 0 29 :2 0 47
:3 0 261 4bd 4bf
:3 0 29 :2 0 4d
:4 0 264 4c1 4c3
:3 0 29 :2 0 4e
:3 0 4f :3 0 2f
:2 0 50 :2 0 267
4c6 4ca 26b 4c5
4cc :3 0 26e 4ae
4ce :2 0 4d0 271
4d1 4ab 4d0 0
4d2 273 0 4d3
275 4d6 :3 0 4d6
0 4d6 4d5 4d3
4d4 :6 0 4d8 17
:3 0 278 4da 27a
4d9 4d8 :2 0 4db
27c :2 0 4dd 0
4dd 4dc 493 4db
:6 0 639 16 :3 0
11 :3 0 40 :3 0
13 :3 0 42 :3 0
55 :3 0 56 :3 0
57 :3 0 58 :3 0
59 :3 0 58 :3 0
f :3 0 3 :3 0
5a :3 0 5b :4 0
5c 1 :8 0 503
37 :4 0 4ee :3 0
44 :3 0 45 :2 0
280 4f1 4f2 :3 0
38 :3 0 39 :3 0
4f4 4f5 0 a
:2 0 4f6 4f7 0
4f9 283 500 38
:3 0 39 :3 0 4fa
4fb 0 3a :2 0
4fc 4fd 0 4ff
285 501 4f3 4f9
0 502 0 4ff
0 502 287 0
503 28a 54d 46
:3 0 38 :3 0 39
:3 0 506 507 0
47 :3 0 508 509
0 543 21 :3 0
22 :3 0 50b 50c
0 21 :3 0 2e
:3 0 50e 50f 0
48 :2 0 2 :4 0
74 :2 0 31 :2 0
2f :2 0 28d 514
516 :3 0 290 510
518 50d 51a 519
:2 0 24 :3 0 32
:3 0 51c 51d 0
26 :4 0 75 :4 0
29 :2 0 2a :3 0
294 521 523 :3 0
29 :2 0 4b :4 0
297 525 527 :3 0
29 :2 0 4c :4 0
29a 529 52b :3 0
29 :2 0 47 :3 0
29d 52d 52f :3 0
29 :2 0 4d :4 0
2a0 531 533 :3 0
29 :2 0 4e :3 0
4f :3 0 2f :2 0
50 :2 0 2a3 536
53a 2a7 535 53c
:3 0 2aa 51e 53e
:2 0 540 2ad 541
51b 540 0 542
2af 0 543 2b1
546 :3 0 546 0
546 545 543 544
:6 0 548 19 :3 0
2b4 54a 2b6 549
548 :2 0 54b 2b8
:2 0 54d 0 54d
54c 503 54b :6 0
639 16 :3 0 11
:3 0 40 :3 0 b
:3 0 55 :3 0 56
:3 0 f :3 0 3
:3 0 5a :3 0 5b
:4 0 5f 1 :8 0
56e 37 :4 0 559
:3 0 44 :3 0 45
:2 0 2bc 55c 55d
:3 0 38 :3 0 39
:3 0 55f 560 0
a :2 0 561 562
0 564 2bf 56b
38 :3 0 39 :3 0
565 566 0 3a
:2 0 567 568 0
56a 2c1 56c 55e
564 0 56d 0
56a 0 56d 2c3
0 56e 2c6 5b8
46 :3 0 38 :3 0
39 :3 0 571 572
0 47 :3 0 573
574 0 5ae 21
:3 0 22 :3 0 576
577 0 21 :3 0
2e :3 0 579 57a
0 48 :2 0 2
:4 0 76 :2 0 31
:2 0 2f :2 0 2c9
57f 581 :3 0 2cc
57b 583 578 585
584 :2 0 24 :3 0
32 :3 0 587 588
0 26 :4 0 77
:4 0 29 :2 0 2a
:3 0 2d0 58c 58e
:3 0 29 :2 0 4b
:4 0 2d3 590 592
:3 0 29 :2 0 4c
:4 0 2d6 594 596
:3 0 29 :2 0 47
:3 0 2d9 598 59a
:3 0 29 :2 0 4d
:4 0 2dc 59c 59e
:3 0 29 :2 0 4e
:3 0 4f :3 0 2f
:2 0 50 :2 0 2df
5a1 5a5 2e3 5a0
5a7 :3 0 2e6 589
5a9 :2 0 5ab 2e9
5ac 586 5ab 0
5ad 2eb 0 5ae
2ed 5b1 :3 0 5b1
0 5b1 5b0 5ae
5af :6 0 5b3 1b
:3 0 2f0 5b5 2f2
5b4 5b3 :2 0 5b6
2f4 :2 0 5b8 0
5b8 5b7 56e 5b6
:6 0 639 16 :3 0
62 :3 0 40 :3 0
13 :3 0 42 :3 0
55 :3 0 56 :3 0
f :3 0 3 :3 0
12 :4 0 63 1
:8 0 5d9 37 :4 0
5c4 :3 0 44 :3 0
45 :2 0 2f8 5c7
5c8 :3 0 38 :3 0
39 :3 0 5ca 5cb
0 a :2 0 5cc
5cd 0 5cf 2fb
5d6 38 :3 0 39
:3 0 5d0 5d1 0
3a :2 0 5d2 5d3
0 5d5 2fd 5d7
5c9 5cf 0 5d8
0 5d5 0 5d8
2ff 0 5d9 302
623 46 :3 0 38
:3 0 39 :3 0 5dc
5dd 0 47 :3 0
5de 5df 0 619
21 :3 0 22 :3 0
5e1 5e2 0 21
:3 0 2e :3 0 5e4
5e5 0 48 :2 0
2 :4 0 78 :2 0
31 :2 0 2f :2 0
305 5ea 5ec :3 0
308 5e6 5ee 5e3
5f0 5ef :2 0 24
:3 0 32 :3 0 5f2
5f3 0 26 :4 0
79 :4 0 29 :2 0
2a :3 0 30c 5f7
5f9 :3 0 29 :2 0
4b :4 0 30f 5fb
5fd :3 0 29 :2 0
4c :4 0 312 5ff
601 :3 0 29 :2 0
47 :3 0 315 603
605 :3 0 29 :2 0
4d :4 0 318 607
609 :3 0 29 :2 0
4e :3 0 4f :3 0
2f :2 0 50 :2 0
31b 60c 610 31f
60b 612 :3 0 322
5f4 614 :2 0 616
325 617 5f1 616
0 618 327 0
619 329 61c :3 0
61c 0 61c 61b
619 61a :6 0 61e
1d :3 0 32c 620
32e 61f 61e :2 0
621 330 :2 0 623
0 623 622 5d9
621 :6 0 639 16
:3 0 66 :3 0 9
:3 0 a :2 0 332
625 628 45 :2 0
a :2 0 337 62a
62c :3 0 c :3 0
67 :3 0 3 :3 0
33a 62f 631 62e
632 0 636 68
:4 0 68 1 :8 0
636 33c 637 62d
636 0 638 33f
0 639 341 63b
36 :4 0 639 :4 0
796 69 :3 0 1c
:4 0 63f :2 0 645
63d 0 38 :3 0
39 :3 0 640 641
0 47 :3 0 642
643 0 645 34b
68f 46 :3 0 38
:3 0 39 :3 0 648
649 0 47 :3 0
64a 64b 0 685
21 :3 0 22 :3 0
64d 64e 0 21
:3 0 2e :3 0 650
651 0 48 :2 0
2 :4 0 7a :2 0
31 :2 0 2f :2 0
34e 656 658 :3 0
351 652 65a 64f
65c 65b :2 0 24
:3 0 32 :3 0 65e
65f 0 26 :4 0
7b :4 0 29 :2 0
2a :3 0 355 663
665 :3 0 29 :2 0
4b :4 0 358 667
669 :3 0 29 :2 0
4c :4 0 35b 66b
66d :3 0 29 :2 0
47 :3 0 35e 66f
671 :3 0 29 :2 0
4d :4 0 361 673
675 :3 0 29 :2 0
4e :3 0 4f :3 0
2f :2 0 50 :2 0
364 678 67c 368
677 67e :3 0 36b
660 680 :2 0 682
36e 683 65d 682
0 684 370 0
685 372 688 :3 0
688 0 688 687
685 686 :6 0 68a
1f :3 0 375 68c
377 68b 68a :2 0
68d 379 :2 0 68f
0 68f 68e 645
68d :6 0 796 1
:3 0 35 :3 0 1f
:4 0 694 :2 0 796
692 695 :3 0 36
:3 0 1f :3 0 9
:4 0 69a :2 0 73e
697 698 :3 0 1f
:3 0 37 :3 0 69b
69c :3 0 38 :3 0
39 :3 0 69e 69f
0 a :2 0 6a0
6a1 0 6a3 37b
6aa 38 :3 0 39
:3 0 6a4 6a5 0
3a :2 0 6a6 6a7
0 6a9 37d 6ab
69d 6a3 0 6ac
0 6a9 0 6ac
37f 0 73e 38
:3 0 39 :3 0 6ad
6ae 0 38 :3 0
3b :2 0 3c :3 0
6b0 6b2 0 384
6b1 6b4 :3 0 6b5
:2 0 3d :8 0 6b9
387 6ba 6b6 6b9
0 6bb 389 0
73e 11 :3 0 40
:3 0 13 :3 0 42
:3 0 57 :3 0 58
:3 0 59 :3 0 58
:3 0 f :3 0 3
:3 0 5a :3 0 5b
:4 0 6c 1 :8 0
6de 37 :4 0 6c9
:3 0 44 :3 0 45
:2 0 38d 6cc 6cd
:3 0 38 :3 0 39
:3 0 6cf 6d0 0
a :2 0 6d1 6d2
0 6d4 390 6db
38 :3 0 39 :3 0
6d5 6d6 0 3a
:2 0 6d7 6d8 0
6da 392 6dc 6ce
6d4 0 6dd 0
6da 0 6dd 394
0 6de 397 728
46 :3 0 38 :3 0
39 :3 0 6e1 6e2
0 47 :3 0 6e3
6e4 0 71e 21
:3 0 22 :3 0 6e6
6e7 0 21 :3 0
2e :3 0 6e9 6ea
0 48 :2 0 2
:4 0 7c :2 0 31
:2 0 2f :2 0 39a
6ef 6f1 :3 0 39d
6eb 6f3 6e8 6f5
6f4 :2 0 24 :3 0
32 :3 0 6f7 6f8
0 26 :4 0 7d
:4 0 29 :2 0 2a
:3 0 3a1 6fc 6fe
:3 0 29 :2 0 4b
:4 0 3a4 700 702
:3 0 29 :2 0 4c
:4 0 3a7 704 706
:3 0 29 :2 0 47
:3 0 3aa 708 70a
:3 0 29 :2 0 4d
:4 0 3ad 70c 70e
:3 0 29 :2 0 4e
:3 0 4f :3 0 2f
:2 0 50 :2 0 3b0
711 715 3b4 710
717 :3 0 3b7 6f9
719 :2 0 71b 3ba
71c 6f6 71b 0
71d 3bc 0 71e
3be 721 :3 0 721
0 721 720 71e
71f :6 0 723 22
:3 0 3c1 725 3c3
724 723 :2 0 726
3c5 :2 0 728 0
728 727 6de 726
:6 0 73e 21 :3 0
66 :3 0 9 :3 0
a :2 0 3c7 72a
72d 45 :2 0 a
:2 0 3cc 72f 731
:3 0 c :3 0 67
:3 0 3 :3 0 3cf
734 736 733 737
0 73b 68 :4 0
68 1 :8 0 73b
3d1 73c 732 73b
0 73d 3d4 0
73e 3d6 740 36
:4 0 73e :4 0 796
69 :3 0 1f :4 0
744 :2 0 74a 742
0 38 :3 0 39
:3 0 745 746 0
47 :3 0 747 748
0 74a 3dc 794
46 :3 0 38 :3 0
39 :3 0 74d 74e
0 47 :3 0 74f
750 0 78a 21
:3 0 22 :3 0 752
753 0 21 :3 0
2e :3 0 755 756
0 48 :2 0 2
:4 0 7e :2 0 31
:2 0 2f :2 0 3df
75b 75d :3 0 3e2
757 75f 754 761
760 :2 0 24 :3 0
32 :3 0 763 764
0 26 :4 0 7f
:4 0 29 :2 0 2a
:3 0 3e6 768 76a
:3 0 29 :2 0 4b
:4 0 3e9 76c 76e
:3 0 29 :2 0 4c
:4 0 3ec 770 772
:3 0 29 :2 0 47
:3 0 3ef 774 776
:3 0 29 :2 0 4d
:4 0 3f2 778 77a
:3 0 29 :2 0 4e
:3 0 4f :3 0 2f
:2 0 50 :2 0 3f5
77d 781 3f9 77c
783 :3 0 3fc 765
785 :2 0 787 3ff
788 762 787 0
789 401 0 78a
403 78d :3 0 78d
0 78d 78c 78a
78b :6 0 78f 24
:3 0 406 791 408
790 78f :2 0 792
40a :2 0 794 0
794 793 74a 792
:6 0 796 1 :3 0
40c 798 dd 43e
0 799 0 796
0 799 413 0
7cc 21 :3 0 22
:3 0 79a 79b 0
21 :3 0 2e :3 0
79d 79e 0 2f
:2 0 2 :4 0 80
:2 0 31 :2 0 2f
:2 0 416 7a3 7a5
:3 0 419 79f 7a7
79c 7a9 7a8 :2 0
24 :3 0 32 :3 0
7ab 7ac 0 26
:4 0 81 :4 0 29
:2 0 2a :3 0 41d
7b0 7b2 :3 0 29
:2 0 4b :4 0 420
7b4 7b6 :3 0 29
:2 0 82 :4 0 423
7b8 7ba :3 0 29
:2 0 38 :3 0 39
:3 0 7bd 7be 0
426 7bc 7c0 :3 0
429 7ad 7c2 :2 0
7c4 42c 7c5 7aa
7c4 0 7c6 42e
0 7cc 7 :3 0
38 :3 0 39 :3 0
7c8 7c9 0 7ca
:2 0 7cc 430 7cf
:3 0 7cf 436 7cf
7ce 7cc 7cd :6 0
7d0 :2 0 2 c
7cf 7d3 :3 0 7d2
7d0 7d4 :8 0 
43e
4
:3 0 1 3 1
8 1 e 1
14 1 1a 1
34 1 4e 1
69 1 84 1
90 1 9c 2
9f a1 2 a4
a6 2 a8 aa
2 ac ae 2
b0 b2 4 98
9e a3 b4 1
b6 1 b8 2
c2 c4 3 c0
c1 c6 2 cf
d1 2 ce d3
1 d5 1 d7
1 d9 2 e5
e6 1 f1 1
f7 2 f9 fa
1 102 2 fe
102 1 107 1
109 1 119 2
118 119 1 121
1 127 2 129
12a 2 116 12b
2 13c 13e 3
13a 13b 140 2
149 14b 2 14d
14f 2 151 153
2 155 157 2
159 15b 3 160
161 162 2 15d
164 2 148 166
1 168 1 16a
2 133 16b 1
16f 1 12e 1
173 2 17e 181
1 196 2 195
196 1 19e 1
1a4 2 1a6 1a7
2 193 1a8 2
1b9 1bb 3 1b7
1b8 1bd 2 1c6
1c8 2 1ca 1cc
2 1ce 1d0 2
1d2 1d4 2 1d6
1d8 3 1dd 1de
1df 2 1da 1e1
2 1c5 1e3 1
1e5 1 1e7 2
1b0 1e8 1 1ec
1 1ab 1 1f0
1 201 2 200
201 1 209 1
20f 2 211 212
2 1fe 213 2
224 226 3 222
223 228 2 231
233 2 235 237
2 239 23b 2
23d 23f 2 241
243 3 248 249
24a 2 245 24c
2 230 24e 1
250 1 252 2
21b 253 1 257
1 216 1 25b
1 26c 2 26b
26c 1 274 1
27a 2 27c 27d
2 269 27e 2
28f 291 3 28d
28e 293 2 29c
29e 2 2a0 2a2
2 2a4 2a6 2
2a8 2aa 2 2ac
2ae 3 2b3 2b4
2b5 2 2b0 2b7
2 29b 2b9 1
2bb 1 2bd 2
286 2be 1 2c2
1 281 1 2c6
2 2cc 2cd 1
2d1 2 2cf 2d1
1 2d6 2 2d9
2db 1 2dd a
e7 fb 10a 10d
176 184 1f3 25e
2c9 2de 2 2e4
2ea 2 2fb 2fd
3 2f9 2fa 2ff
2 308 30a 2
30c 30e 2 310
312 2 314 316
2 318 31a 3
31f 320 321 2
31c 323 2 307
325 1 327 1
329 2 2f2 32a
1 32e 1 2ed
1 332 2 33e
33f 1 34a 1
350 2 352 353
1 35b 2 357
35b 1 360 1
362 1 373 2
372 373 1 37b
1 381 2 383
384 2 370 385
2 396 398 3
394 395 39a 2
3a3 3a5 2 3a7
3a9 2 3ab 3ad
2 3af 3b1 2
3b3 3b5 3 3ba
3bb 3bc 2 3b7
3be 2 3a2 3c0
1 3c2 1 3c4
2 38d 3c5 1
3c9 1 388 1
3cd 2 3d3 3d4
1 3d8 2 3d6
3d8 1 3dd 2
3e0 3e2 1 3e4
5 340 354 363
3d0 3e5 2 3eb
3f1 2 402 404
3 400 401 406
2 40f 411 2
413 415 2 417
419 2 41b 41d
2 41f 421 3
426 427 428 2
423 42a 2 40e
42c 1 42e 1
430 2 3f9 431
1 435 1 3f4
1 439 6 e0
2e1 335 339 3e8
43c 1 450 1
456 2 458 459
1 461 2 45d
461 1 466 1
468 2 470 473
1 480 2 47f
480 1 488 1
48e 2 490 491
2 47d 492 2
4a3 4a5 3 4a1
4a2 4a7 2 4b0
4b2 2 4b4 4b6
2 4b8 4ba 2
4bc 4be 2 4c0
4c2 3 4c7 4c8
4c9 2 4c4 4cb
2 4af 4cd 1
4cf 1 4d1 2
49a 4d2 1 4d6
1 495 1 4da
1 4f0 2 4ef
4f0 1 4f8 1
4fe 2 500 501
2 4ed 502 2
513 515 3 511
512 517 2 520
522 2 524 526
2 528 52a 2
52c 52e 2 530
532 3 537 538
539 2 534 53b
2 51f 53d 1
53f 1 541 2
50a 542 1 546
1 505 1 54a
1 55b 2 55a
55b 1 563 1
569 2 56b 56c
2 558 56d 2
57e 580 3 57c
57d 582 2 58b
58d 2 58f 591
2 593 595 2
597 599 2 59b
59d 3 5a2 5a3
5a4 2 59f 5a6
2 58a 5a8 1
5aa 1 5ac 2
575 5ad 1 5b1
1 570 1 5b5
1 5c6 2 5c5
5c6 1 5ce 1
5d4 2 5d6 5d7
2 5c3 5d8 2
5e9 5eb 3 5e7
5e8 5ed 2 5f6
5f8 2 5fa 5fc
2 5fe 600 2
602 604 2 606
608 3 60d 60e
60f 2 60a 611
2 5f5 613 1
615 1 617 2
5e0 618 1 61c
1 5db 1 620
2 626 627 1
62b 2 629 62b
1 630 2 633
635 1 637 9
447 45a 469 476
4dd 54d 5b8 623
638 2 63e 644
2 655 657 3
653 654 659 2
662 664 2 666
668 2 66a 66c
2 66e 670 2
672 674 3 679
67a 67b 2 676
67d 2 661 67f
1 681 1 683
2 64c 684 1
688 1 647 1
68c 1 6a2 1
6a8 2 6aa 6ab
1 6b3 2 6af
6b3 1 6b8 1
6ba 1 6cb 2
6ca 6cb 1 6d3
1 6d9 2 6db
6dc 2 6c8 6dd
2 6ee 6f0 3
6ec 6ed 6f2 2
6fb 6fd 2 6ff
701 2 703 705
2 707 709 2
70b 70d 3 712
713 714 2 70f
716 2 6fa 718
1 71a 1 71c
2 6e5 71d 1
721 1 6e0 1
725 2 72b 72c
1 730 2 72e
730 1 735 2
738 73a 1 73c
5 699 6ac 6bb
728 73d 2 743
749 2 75a 75c
3 758 759 75e
2 767 769 2
76b 76d 2 76f
771 2 773 775
2 777 779 3
77e 77f 780 2
77b 782 2 766
784 1 786 1
788 2 751 789
1 78d 1 74c
1 791 6 441
63b 68f 693 740
794 2 797 798
2 7a2 7a4 3
7a0 7a1 7a6 2
7af 7b1 2 7b3
7b5 2 7b7 7b9
2 7bb 7bf 2
7ae 7c1 1 7c3
1 7c5 5 b9
d8 799 7c6 7cb
7 12 18 1e
35 4f 6a 85

1
4
0 
7d3
0
1
28
25
9
0 1 1 1 1 1 6 7
6 9 6 b 6 d 1 f
1 11 12 1 14 1 16 17
16 19 16 1b 16 1d 1 1f
1 21 22 1 24 0 0 0

21 1 2
3b 1 3
55 1 4
70 1 5
1a 1 0
14 1 0
2 0 1
e 1 0
3 1 0
0

/
SHOW ERRORS FUNCTION FC_MIGRATION;
ALTER FUNCTION FC_MIGRATION COMPILE DEBUG;
